diff -pruN 5.12.4-1/.github/workflows/sync.yml 5.13.0-1/.github/workflows/sync.yml
--- 5.12.4-1/.github/workflows/sync.yml	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/.github/workflows/sync.yml	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+name: sync
+
+# Controls when the workflow will run
+on:
+  # Trigger the workflow on all pushes
+  push:
+    branches:
+      - "**"
+    tags:
+      - "**"
+
+  # Trigger the workflow when a branch or tag is deleted
+  delete: ~
+
+jobs:
+  # Calls a reusable CI workflow to sync the current with a remote repository.
+  #   It will correctly handle addition of any new and removal of existing Git objects.
+  sync:
+    name: sync
+    uses: ecmwf-actions/reusable-workflows/.github/workflows/sync.yml@v2
+    secrets:
+      target_repository: ecflow/ecflow
+      target_username: ClonedDuck
+      target_token: ${{ secrets.BITBUCKET_PAT }}
diff -pruN 5.12.4-1/.gitignore 5.13.0-1/.gitignore
--- 5.12.4-1/.gitignore	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/.gitignore	2024-06-20 10:11:46.000000000 +0000
@@ -21,6 +21,7 @@ ecflow_*.files
 ecflow_*.cflags
 ecflow_*.cxxflags
 CMakeLists.txt.user
+.qtc_clangd/
 
 #vscode
 .vscode
diff -pruN 5.12.4-1/3rdparty/cereal/include/cereal/details/polymorphic_impl.hpp 5.13.0-1/3rdparty/cereal/include/cereal/details/polymorphic_impl.hpp
--- 5.12.4-1/3rdparty/cereal/include/cereal/details/polymorphic_impl.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/3rdparty/cereal/include/cereal/details/polymorphic_impl.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -186,7 +186,14 @@ namespace cereal
       template <class Derived> inline
       static const Derived * downcast( const void * dptr, std::type_info const & baseInfo )
       {
+#pragma GCC diagnostic push
+#if defined(__GNUC__) && (__GNUC__ >= 13)
+#pragma GCC diagnostic ignored "-Wdangling-reference"
+#endif
+        // Without the warning suppression, the following source line generates a warning in GNU GCC 13.x
+        // The warning is a false positive, reported as a GCC compiler regression: https://gcc.gnu.org/bugzilla/show_bug.cgi?id=107532
         auto const & mapping = lookup( baseInfo, typeid(Derived), [&](){ UNREGISTERED_POLYMORPHIC_CAST_EXCEPTION(save) } );
+#pragma GCC diagnostic pop
 
         for( auto const * dmap : mapping )
           dptr = dmap->downcast( dptr );
@@ -200,7 +207,15 @@ namespace cereal
       template <class Derived> inline
       static void * upcast( Derived * const dptr, std::type_info const & baseInfo )
       {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic push
+#if defined(__GNUC__) && (__GNUC__ >= 13)
+    #pragma GCC diagnostic ignored "-Wdangling-reference"
+#endif
+        // Without the warning suppression, the following source line generates a warning in GNU GCC 13.x
+        // The warning is a false positive, reported as a GCC compiler regression: https://gcc.gnu.org/bugzilla/show_bug.cgi?id=107532
         auto const & mapping = lookup( baseInfo, typeid(Derived), [&](){ UNREGISTERED_POLYMORPHIC_CAST_EXCEPTION(load) } );
+#pragma GCC diagnostic pop
 
         void * uptr = dptr;
         for( auto mIter = mapping.rbegin(), mEnd = mapping.rend(); mIter != mEnd; ++mIter )
@@ -213,7 +228,15 @@ namespace cereal
       template <class Derived> inline
       static std::shared_ptr<void> upcast( std::shared_ptr<Derived> const & dptr, std::type_info const & baseInfo )
       {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic push
+#if defined(__GNUC__) && (__GNUC__ >= 13)
+    #pragma GCC diagnostic ignored "-Wdangling-reference"
+#endif
+        // Without the warning suppression, the following source line generates a warning in GNU GCC 13.x
+        // The warning is a false positive, reported as a GCC compiler regression: https://gcc.gnu.org/bugzilla/show_bug.cgi?id=107532
         auto const & mapping = lookup( baseInfo, typeid(Derived), [&](){ UNREGISTERED_POLYMORPHIC_CAST_EXCEPTION(load) } );
+#pragma GCC diagnostic pop
 
         std::shared_ptr<void> uptr = dptr;
         for( auto mIter = mapping.rbegin(), mEnd = mapping.rend(); mIter != mEnd; ++mIter )
diff -pruN 5.12.4-1/ACore/CMakeLists.txt 5.13.0-1/ACore/CMakeLists.txt
--- 5.12.4-1/ACore/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,191 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-configure_file(
-  src/ecflow/core/ecflow_version.h.in
-  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_version.h)
-configure_file(
-  src/ecflow/core/ecflow_source_build_dir.h.in
-  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_source_build_dir.h)
-
-set(srcs
-  # Headers
-  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_version.h
-  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_source_build_dir.h
-  src/ecflow/core/AssertTimer.hpp
-  src/ecflow/core/Cal.hpp
-  src/ecflow/core/Calendar.hpp
-  src/ecflow/core/CalendarUpdateParams.hpp
-  src/ecflow/core/CheckPt.hpp
-  src/ecflow/core/Child.hpp
-  src/ecflow/core/Chrono.hpp
-  src/ecflow/core/CommandLine.hpp
-  src/ecflow/core/DState.hpp
-  src/ecflow/core/DebugPerf.hpp
-  src/ecflow/core/DurationTimer.hpp
-  src/ecflow/core/Ecf.hpp
-  src/ecflow/core/EcfPortLock.hpp
-  src/ecflow/core/Extract.hpp
-  src/ecflow/core/File.hpp
-  src/ecflow/core/File_r.hpp
-  src/ecflow/core/Filesystem.hpp
-  src/ecflow/core/Host.hpp
-  src/ecflow/core/Indentor.hpp
-  src/ecflow/core/Log.hpp
-  src/ecflow/core/LogVerification.hpp
-  src/ecflow/core/NOrder.hpp
-  src/ecflow/core/NState.hpp
-  src/ecflow/core/NodePath.hpp
-  src/ecflow/core/Overload.hpp
-  src/ecflow/core/Passwd.hpp
-  src/ecflow/core/PasswdFile.hpp
-  src/ecflow/core/PasswordEncryption.hpp
-  src/ecflow/core/Pid.hpp
-  src/ecflow/core/PrintStyle.hpp
-  src/ecflow/core/SState.hpp
-  src/ecflow/core/Serialization.hpp
-  src/ecflow/core/Stl.hpp
-  src/ecflow/core/Str.hpp
-  src/ecflow/core/StringSplitter.hpp
-  src/ecflow/core/TimeSeries.hpp
-  src/ecflow/core/TimeSlot.hpp
-  src/ecflow/core/TimeStamp.hpp
-  src/ecflow/core/User.hpp
-  src/ecflow/core/Version.hpp
-  src/ecflow/core/WhiteListFile.hpp
-  src/ecflow/core/cereal_boost_time.hpp
-  src/ecflow/core/cereal_optional_nvp.hpp
-  src/ecflow/core/perf_timer.hpp
-  # Sources
-  src/ecflow/core/AssertTimer.cpp
-  src/ecflow/core/Cal.cpp
-  src/ecflow/core/Calendar.cpp
-  src/ecflow/core/Child.cpp
-  src/ecflow/core/Chrono.cpp
-  src/ecflow/core/CommandLine.cpp
-  src/ecflow/core/DState.cpp
-  src/ecflow/core/DurationTimer.cpp
-  src/ecflow/core/Ecf.cpp
-  src/ecflow/core/Extract.cpp
-  src/ecflow/core/File.cpp
-  src/ecflow/core/File_r.cpp
-  src/ecflow/core/Filesystem.cpp
-  src/ecflow/core/Host.cpp
-  src/ecflow/core/Indentor.cpp
-  src/ecflow/core/Log.cpp
-  src/ecflow/core/LogVerification.cpp
-  src/ecflow/core/NOrder.cpp
-  src/ecflow/core/NState.cpp
-  src/ecflow/core/NodePath.cpp
-  src/ecflow/core/Passwd.cpp
-  src/ecflow/core/PasswdFile.cpp
-  src/ecflow/core/Pid.cpp
-  src/ecflow/core/PrintStyle.cpp
-  src/ecflow/core/SState.cpp
-  src/ecflow/core/Str.cpp
-  src/ecflow/core/StringSplitter.cpp
-  src/ecflow/core/TimeSeries.cpp
-  src/ecflow/core/TimeSlot.cpp
-  src/ecflow/core/TimeStamp.cpp
-  src/ecflow/core/User.cpp
-  src/ecflow/core/Version.cpp
-  src/ecflow/core/WhiteListFile.cpp
-)
-
-ecbuild_add_library(
-  TARGET
-    core
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-    ${CMAKE_BINARY_DIR}/generated/src
-  PUBLIC_LIBS
-    cereal::cereal # this needs to be public as it appears in public header files used downstream
-    $<$<VERSION_LESS:${Boost_VERSION},1.69.0>:Boost::system>
-    Boost::filesystem
-    Boost::date_time
-    Boost::program_options
-    $<$<NOT:$<BOOL:${APPLE}>>:crypt>
-  DEFINITIONS
-    CMAKE
-)
-target_clangformat(core)
-
-##
-## Notice: test_support is an INTERFACE-only test utility library.
-##
-
-ecbuild_add_library(
-  TARGET
-    test_support
-  NOINSTALL
-  TYPE INTERFACE
-  SOURCES
-    test/TestSerialisation.hpp
-  PUBLIC_INCLUDES
-    test
-)
-target_clangformat(test_support)
-
-set(test_srcs
-  # Headers
-  test/TestVersioning.hpp
-  # Sources
-  test/TestCalendar.cpp
-  test/TestCereal.cpp
-  test/TestCerealOptionalNVP.cpp
-  test/TestCerealWithHierarchy.cpp
-  test/TestChrono.cpp
-  test/TestClassDataMemberInit.cpp
-  test/TestCommandLine.cpp
-  test/TestCore_main.cpp # contains main() function for test driver
-  test/TestExtract.cpp
-  test/TestFile.cpp
-  test/TestGetUserDetails.cpp
-  test/TestLog.cpp
-  test/TestMigration.cpp
-  test/TestNodePath.cpp
-  test/TestPasswdFile.cpp
-  test/TestPasswordEncryption.cpp
-  test/TestPerfTimer.cpp
-  test/TestRealCalendar.cpp
-  test/TestSanitizerAS.cpp
-  test/TestSanitizerUB.cpp
-  test/TestSerialisation.cpp
-  test/TestStr.cpp
-  test/TestStringSplitPerf.cpp
-  test/TestStringSplitter.cpp
-  test/TestTimeSeries.cpp
-  test/TestTimeSlot.cpp
-  test/TestVersion.cpp
-  test/TestVersioning.cpp
-  test/TestWhiteListFile.cpp
-)
-
-ecbuild_add_test(
-  TARGET
-    u_core
-  LABELS
-    unit
-    nightly
-  SOURCES
-    ${test_srcs}
-  LIBS
-    test_support
-    core
-    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-    Boost::timer
-)
-target_clangformat(u_core
-  CONDITION ENABLE_TESTS
-)
diff -pruN 5.12.4-1/ACore/src/ecflow/core/AssertTimer.cpp 5.13.0-1/ACore/src/ecflow/core/AssertTimer.cpp
--- 5.12.4-1/ACore/src/ecflow/core/AssertTimer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/AssertTimer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/AssertTimer.hpp"
-
-#include <iostream>
-
-#include "ecflow/core/Log.hpp"
-
-namespace ecf {
-
-AssertTimer::~AssertTimer() {
-    if (doAssert_ && timeConstraint_ > 0) {
-        int d = duration();
-        if (d >= timeConstraint_) {
-            std::cout << "AssertTimer::~AssertTimer() duration(" << d << ") >= timeConstraint(" << timeConstraint_
-                      << ")\n";
-        }
-        LOG_ASSERT(d < timeConstraint_, "AssertTimer::~AssertTimer()");
-    }
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/AssertTimer.hpp 5.13.0-1/ACore/src/ecflow/core/AssertTimer.hpp
--- 5.12.4-1/ACore/src/ecflow/core/AssertTimer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/AssertTimer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_AssertTimer_HPP
-#define ecflow_core_AssertTimer_HPP
-
-///
-/// \brief Simple class that asserts when a time constraint is not met
-///
-
-#include "ecflow/core/Calendar.hpp"
-
-namespace ecf {
-
-// Local timer class used to ensure a job submission takes less than 60 seconds
-class AssertTimer {
-public:
-    explicit AssertTimer(int t, bool doAssert = true)
-        : timeConstraint_(t),
-          doAssert_(doAssert),
-          start_time_(Calendar::second_clock_time()) {}
-    ~AssertTimer();
-
-    int timeConstraint() const { return timeConstraint_; }
-
-    int duration() const {
-        boost::posix_time::time_duration duration = Calendar::second_clock_time() - start_time_;
-        return duration.total_seconds();
-    }
-
-private:
-    int timeConstraint_;
-    bool doAssert_;
-    boost::posix_time::ptime start_time_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_AssertTimer_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Cal.cpp 5.13.0-1/ACore/src/ecflow/core/Cal.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Cal.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Cal.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,70 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Cal.hpp"
-
-long Cal::julian_to_date(long jdate) {
-    long x, y, d, m, e;
-    long day, month, year;
-
-    x = 4 * jdate - 6884477;
-    y = (x / 146097) * 100;
-    e = x % 146097;
-    d = e / 4;
-
-    x = 4 * d + 3;
-    y = (x / 1461) + y;
-    e = x % 1461;
-    d = e / 4 + 1;
-
-    x = 5 * d - 3;
-    m = x / 153 + 1;
-    e = x % 153;
-    d = e / 5 + 1;
-
-    if (m < 11)
-        month = m + 2;
-    else
-        month = m - 10;
-
-    day  = d;
-    year = y + m / 11;
-
-    return year * 10000 + month * 100 + day;
-}
-
-long Cal::date_to_julian(long ddate) {
-    long m1, y1, a, b, c, d, j1;
-    long month, day, year;
-
-    year = ddate / 10000;
-    ddate %= 10000;
-    month = ddate / 100;
-    ddate %= 100;
-    day = ddate;
-
-    if (month > 2) {
-        m1 = month - 3;
-        y1 = year;
-    }
-    else {
-        m1 = month + 9;
-        y1 = year - 1;
-    }
-    a  = 146097 * (y1 / 100) / 4;
-    d  = y1 % 100;
-    b  = 1461 * d / 4;
-    c  = (153 * m1 + 2) / 5 + day + 1721119;
-    j1 = a + b + c;
-
-    return (j1);
-}
-
-// int main(int ac, char** av){ int a=Cal::date_to_julian(20170219) % 7; printf("%d", a); return 0;}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Cal.hpp 5.13.0-1/ACore/src/ecflow/core/Cal.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Cal.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Cal.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Cal_HPP
-#define ecflow_core_Cal_HPP
-
-class Cal {
-public:
-    // Disable default construction
-    Cal() = delete;
-    // Disable copy (and move) semantics
-    Cal(const Cal&)                  = delete;
-    const Cal& operator=(const Cal&) = delete;
-
-    static long date_to_julian(long);
-    static long julian_to_date(long);
-};
-
-#endif /* ecflow_core_Cal_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Calendar.cpp 5.13.0-1/ACore/src/ecflow/core/Calendar.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Calendar.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Calendar.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,489 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Calendar.hpp"
-
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
-
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/cereal_boost_time.hpp"
-
-#ifdef DEBUG
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-// #define DEBUG_CALENDAR 1;
-
-namespace ecf {
-
-Calendar::Calendar() = default;
-
-Calendar::Calendar(const Calendar& rhs) {
-    assign(rhs);
-}
-
-Calendar& Calendar::operator=(const Calendar& rhs) {
-    assign(rhs);
-    return *this;
-}
-
-bool Calendar::operator==(const Calendar& rhs) const {
-    // Only used for testing the persistence of calendar
-    // Note: We specifically ignore initLocalTime_  and lastTime_ since they are initialised with the current time.
-    //       Otherwise For migration testing, it will fail
-
-    if (ctype_ != rhs.ctype_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "Calendar::operator== ctypes don't match\n";
-#endif
-        return false;
-    }
-    if (initTime_ != rhs.initTime_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "Calendar::operator== initTime_ don't match\n";
-#endif
-        return false;
-    }
-    if (suiteTime_ != rhs.suiteTime_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "Calendar::operator== suiteTime_  don't match\n";
-#endif
-        return false;
-    }
-    if (duration_ != rhs.duration_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "Calendar::operator== duration_  don't match\n";
-#endif
-        return false;
-    }
-    if (dayChanged_ != rhs.dayChanged_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "Calendar::operator== dayChanged_  don't match\n";
-#endif
-        return false;
-    }
-    if (increment_ != rhs.increment_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "Calendar::operator== increment_  don't match\n";
-#endif
-        return false;
-    }
-
-    return true;
-}
-
-void Calendar::assign(const Calendar& rhs) {
-    ctype_         = rhs.ctype_;
-    initTime_      = rhs.initTime_;
-    suiteTime_     = rhs.suiteTime_;
-    duration_      = rhs.duration_;
-    dayChanged_    = rhs.dayChanged_;
-    initLocalTime_ = rhs.initLocalTime_;
-    lastTime_      = rhs.lastTime_;
-    increment_     = rhs.increment_;
-
-    day_of_week_  = rhs.day_of_week_;  // Cache
-    day_of_year_  = rhs.day_of_year_;  // Cache
-    day_of_month_ = rhs.day_of_month_; // Cache
-    month_        = rhs.month_;        // Cache
-    year_         = rhs.year_;         // Cache
-}
-
-void Calendar::init(Clock_t clock) {
-    ctype_ = clock;
-}
-
-void Calendar::init(const boost::posix_time::ptime& time, Clock_t clock) {
-    init(clock);
-    begin(time);
-}
-
-/// Start the Calendar.  Parameter time can include gain.
-void Calendar::begin(const boost::posix_time::ptime& the_time) {
-    duration_  = time_duration(0, 0, 0, 0);
-    increment_ = time_duration(0, 1, 0, 0); // This will get overwritten on update
-                                            // But allows some tests to run
-    suiteTime_     = the_time;              // includes gain _IF_ it was specified
-    initTime_      = the_time;              // includes gain
-    dayChanged_    = false;
-    initLocalTime_ = second_clock_time(); // for real time clock
-    lastTime_      = initLocalTime_;      // for real time clock
-
-    // Cache the most common requests
-    update_cache();
-}
-
-void Calendar::update(const ecf::CalendarUpdateParams& calUpdateParams) {
-    assert(!suiteTime_.is_special()); // begin has not been called.
-
-    // Get the day of week before we update calendar, then same after to determine if the day changed
-    boost::gregorian::date currentdate = suiteTime_.date();
-    int theDayOfWeek                   = currentdate.day_of_week().as_number();
-
-    // However there are two ways of incremented/updating calendar.
-    if (!calUpdateParams.forTest()) {
-
-        if (calUpdateParams.serverPollPeriod().total_seconds() < 60) {
-            // 0/ We are still testing. User wants to speed up calendar.
-            //    i.e. if server poll period is 2 seconds, we increment calendar by 1 minute
-
-            time_duration one_minute(0, 1, 0, 0);
-            duration_ += one_minute;
-            suiteTime_ += one_minute;
-            increment_ = one_minute;
-
-#ifdef DEBUG_CALENDAR
-            std::cout << "Calendar::update:  if (calUpdateParams.serverPollPeriod().total_seconds() < 60) { \n";
-#endif
-        }
-        else {
-            // 1. Always Maintain phase with system clock. The calUpdateParams.timeNow()
-            //    time was constructed from a system call in the server.
-            //
-            // Take a difference, which means we can ignore dates
-            const ptime& time_now = calUpdateParams.timeNow();
-            assert(!time_now.is_special()); // This should have been set
-            duration_  = time_period(initLocalTime_, time_now).length();
-            increment_ = time_now - lastTime_;
-            suiteTime_ += increment_;
-            lastTime_ = time_now;
-#ifdef DEBUG_CALENDAR
-            std::cout << "Calendar::update:  if ( !calUpdateParams.forTest() ) { \n";
-#endif
-        }
-    }
-    else {
-        // 2. Update calendar based on server poll period/ Job submission interval
-        // _OR_ For TESTING allow calendar to be speeded up.
-        // Note: for simulation serverPollPeriod could be 1 hour
-        duration_ += calUpdateParams.serverPollPeriod();
-        suiteTime_ += calUpdateParams.serverPollPeriod();
-        increment_ = calUpdateParams.serverPollPeriod();
-#ifdef DEBUG_CALENDAR
-        std::cout << "Calendar::update:  calUpdateParams.serverPollPeriod() = " << calUpdateParams.serverPollPeriod()
-                  << "\n";
-#endif
-    }
-
-    // Day change required for both REAL and HYBRID. See TimeDependencies.ddoc for reason
-    // This must be done before change date back. (i.e in hybrid case, below)
-    int new_day_of_week = suiteTime_.date().day_of_week().as_number();
-    if (theDayOfWeek != new_day_of_week)
-        dayChanged_ = true;
-    else
-        dayChanged_ = false;
-
-    // With the hybrid calendar the date does not change
-    if (ctype_ == Calendar::HYBRID) {
-        if (suiteTime_.date() != initTime_.date()) {
-
-#ifdef DEBUG_CALENDAR
-            cout << "HYBRID: (suiteTime_.date() != initTime_.date()) suiteTime_ = " << to_simple_string(suiteTime_)
-                 << "\n";
-#endif
-
-            time_duration td = suiteTime_.time_of_day();
-
-            suiteTime_ = ptime(initTime_.date(), td);
-
-#ifdef DEBUG_CALENDAR
-            cout << "suiteTime_ = " << to_simple_string(suiteTime_) << "\n";
-#endif
-        }
-    }
-
-    // update_cache *MUST* be last, so we can take into account hybrid. Date does NOT change.
-    // See ECFLOW-458
-    update_cache();
-
-#ifdef DEBUG_CALENDAR
-    cout << "   Calendar::update serverPollPeriod = " << to_simple_string(calUpdateParams.serverPollPeriod()) << " "
-         << toString() << endl;
-#endif
-}
-
-void Calendar::update_duration_only(boost::posix_time::ptime& time_now) {
-    // 1. Always Maintain phase with system clock. The calUpdateParams.timeNow()
-    //    time was constructed from a system call in the server.
-    //
-    // Take a difference, which means we can ignore dates
-    boost::posix_time::time_duration dur = time_period(initLocalTime_, time_now).length();
-    if (dur > duration_) {
-        duration_ = dur;
-    }
-}
-
-void Calendar::update_cache() const {
-    // begin() has not been called yet
-    if (suiteTime_.is_special())
-        return;
-
-    boost::gregorian::date newDate = suiteTime_.date();
-    day_of_week_                   = newDate.day_of_week().as_number();
-    day_of_year_                   = newDate.day_of_year();
-    day_of_month_                  = newDate.day();
-    month_                         = newDate.month();
-    year_                          = newDate.year();
-}
-int Calendar::day_of_week() const {
-    if (day_of_week_ == -1)
-        update_cache();
-    return day_of_week_;
-}
-int Calendar::day_of_year() const {
-    if (day_of_week_ == -1)
-        update_cache();
-    return day_of_year_;
-}
-int Calendar::day_of_month() const {
-    if (day_of_week_ == -1)
-        update_cache();
-    return day_of_month_;
-}
-int Calendar::month() const {
-    if (day_of_week_ == -1)
-        update_cache();
-    return month_;
-}
-int Calendar::year() const {
-    if (day_of_week_ == -1)
-        update_cache();
-    return year_;
-}
-
-void Calendar::update(const boost::posix_time::time_duration& serverPollPeriod) {
-    CalendarUpdateParams p(serverPollPeriod);
-    update(p);
-}
-
-void Calendar::update(const boost::posix_time::ptime& time_now) {
-    // Used for test even though for_test is false, as we want to test that path in UNIT tests
-    // Tests: path 1. shown above. Note: we pass minutes(1), to ensure path 1. is taken
-    CalendarUpdateParams p(time_now, minutes(1), true /* server running */, false /* for Test*/);
-    update(p);
-}
-
-boost::gregorian::date Calendar::date() const {
-    return suiteTime_.date();
-}
-
-/// for debug
-void Calendar::dump(const std::string& title) const {
-    LOG(Log::LOG,
-        title << " duration_(" << to_simple_string(duration_) << ") initTime_(" << to_simple_string(initTime_)
-              << ") suiteTime_(" << to_simple_string(suiteTime_) << ")");
-}
-
-std::string Calendar::suite_time_str() const {
-    std::string ss;
-    if (day_of_week_ == 0)
-        ss += " SUNDAY";
-    else if (day_of_week_ == 1)
-        ss += " MONDAY";
-    else if (day_of_week_ == 2)
-        ss += " TUESDAY";
-    else if (day_of_week_ == 3)
-        ss += " WEDNESDAY";
-    else if (day_of_week_ == 4)
-        ss += " THURSDAY";
-    else if (day_of_week_ == 5)
-        ss += " FRIDAY";
-    else if (day_of_week_ == 6)
-        ss += " SATURDAY";
-    ss += " ";
-    ss += to_simple_string(suiteTime_);
-    return ss;
-}
-
-std::string Calendar::toString() const {
-    std::stringstream ss;
-    ss << "hybrid(" << hybrid() << ") duration_(" << to_simple_string(duration_) << ") initTime_("
-       << to_simple_string(initTime_) << ") suiteTime_(" << to_simple_string(suiteTime_) << ") dayChanged_("
-       << dayChanged_ << ")";
-    ss << " increment_(" << to_simple_string(increment_) << ")";
-
-    if (day_of_week_ == 0)
-        ss << " SUNDAY";
-    else if (day_of_week_ == 1)
-        ss << " MONDAY";
-    else if (day_of_week_ == 2)
-        ss << " TUESDAY";
-    else if (day_of_week_ == 3)
-        ss << " WEDNESDAY";
-    else if (day_of_week_ == 4)
-        ss << " THURSDAY";
-    else if (day_of_week_ == 5)
-        ss << " FRIDAY";
-    else if (day_of_week_ == 6)
-        ss << " SATURDAY";
-
-    return ss.str();
-}
-
-void Calendar::write_state(std::string& ret) const {
-    if (initTime_.is_special())
-        return;
-
-    bool increment__changed = (!increment_.is_special() && increment_.total_seconds() != 0);
-
-    // cType is obtained from the suite clock attribute, and not persisted
-    ret += " initTime:";
-    ret += to_simple_string(initTime_);
-    ret += " suiteTime:";
-    ret += to_simple_string(suiteTime_);
-    ret += " duration:";
-    ret += to_simple_string(duration_);
-    ret += " initLocalTime:";
-    ret += to_simple_string(initLocalTime_);
-    ret += " lastTime:";
-    ret += to_simple_string(lastTime_);
-    if (increment__changed) {
-        ret += " calendarIncrement:";
-        ret += to_simple_string(increment_);
-    }
-
-    if (dayChanged_)
-        ret += " dayChanged:1";
-}
-
-void Calendar::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
-    // initTime:2012-Jul-16 16:19:35 suiteTime:2012-Jul-16 16:19:35 duration:00:00:00 dayChanged:0
-    // initLocalTime:2012-Jul-16 16:19:35 lastTime:2012-Jul-16 16:19:35 calendarIncrement:00:00:00
-    //   std::cout << "Calendar::read_state:"  << line << "\n";
-    std::string time;
-    size_t line_tokens_size = lineTokens.size();
-    for (size_t i = 0; i < line_tokens_size; i++) {
-        time.clear();
-        const std::string& line_token = lineTokens[i];
-        if (line_token.find("initTime:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token, time))
-                throw std::runtime_error("Calendar::read_state failed: (initTime)");
-            if (i + 1 < line_tokens_size) {
-                time += " ";
-                time += lineTokens[i + 1];
-            }
-            else
-                throw std::runtime_error("Calendar::read_state failed: 1");
-            initTime_ = time_from_string(time);
-        }
-        else if (line_token.find("suiteTime:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token, time))
-                throw std::runtime_error("Calendar::read_state failed: (suiteTime)");
-            if (i + 1 < line_tokens_size) {
-                time += " ";
-                time += lineTokens[i + 1];
-            }
-            else
-                throw std::runtime_error("Calendar::read_state failed: 1");
-            suiteTime_ = time_from_string(time);
-        }
-        else if (line_token.find("initLocalTime:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token, time))
-                throw std::runtime_error("Calendar::read_state failed: (initLocalTime)");
-            if (i + 1 < line_tokens_size) {
-                time += " ";
-                time += lineTokens[i + 1];
-            }
-            else
-                throw std::runtime_error("Calendar::read_state failed: 1");
-            initLocalTime_ = time_from_string(time);
-        }
-        else if (line_token.find("lastTime:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token, time))
-                throw std::runtime_error("Calendar::read_state failed: (lastTime)");
-            if (i + 1 < line_tokens_size) {
-                time += " ";
-                time += lineTokens[i + 1];
-            }
-            else
-                throw std::runtime_error("Calendar::read_state failed: 1");
-            lastTime_ = time_from_string(time);
-        }
-        else if (line_token.find("duration:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token, time))
-                throw std::runtime_error("Calendar::read_state failed: (duration)");
-            duration_ = duration_from_string(time);
-        }
-        else if (line_token.find("calendarIncrement:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token, time))
-                throw std::runtime_error("Calendar::read_state failed: (calendarIncrement)");
-            increment_ = duration_from_string(time);
-        }
-        else if (line_token == "dayChanged:1")
-            dayChanged_ = true;
-    }
-}
-
-bool Calendar::checkInvariants(std::string& errorMsg) const {
-    if (!duration_.is_special()) {
-        if (duration_.is_negative()) {
-            errorMsg += "Calendar::checkInvariants duration is negative " + toString() + "\n";
-            return false;
-        }
-    }
-    return true;
-}
-
-boost::posix_time::ptime Calendar::second_clock_time() {
-    /// Chose UTC since it s compatible with boost deadline timer
-    return second_clock::universal_time(); // UTC
-}
-
-// ==================================================================================
-
-template <class Archive>
-void Calendar::serialize(Archive& ar, std::uint32_t const /*version*/) {
-    if (Archive::is_saving::value) {
-        if (initTime_.is_special()) {
-            // Initialise the ptimes to avoid serialisation exceptions
-            // The serialisation of ptime makes use of exceptions, especially
-            // when dealing with a date that has *not* been initialised.
-            // To avoid this we take a small hit to initialise the calendar with
-            // time now. This will get overridden with suite clock at begin
-            begin(second_clock_time());
-        }
-    }
-    ar(CEREAL_NVP(initTime_));
-    CEREAL_OPTIONAL_NVP(ar, suiteTime_, [this]() { return suiteTime_ != initTime_; });
-    CEREAL_OPTIONAL_NVP(ar, initLocalTime_, [this]() { return initLocalTime_ != initTime_; });
-    CEREAL_OPTIONAL_NVP(ar, lastTime_, [this]() { return lastTime_ != initTime_; });
-    CEREAL_OPTIONAL_NVP(ar, dayChanged_, [this]() { return dayChanged_; });
-    CEREAL_OPTIONAL_NVP(ar, duration_, [this]() { return duration_ != boost::posix_time::time_duration(0, 0, 0, 0); });
-    CEREAL_OPTIONAL_NVP(
-        ar, increment_, [this]() { return increment_ != boost::posix_time::time_duration(0, 1, 0, 0); });
-
-    if (Archive::is_loading::value) {
-        if (lastTime_.is_special())
-            lastTime_ = initTime_;
-        if (initLocalTime_.is_special())
-            initLocalTime_ = initTime_;
-        if (suiteTime_.is_special())
-            suiteTime_ = initTime_;
-    }
-}
-
-CEREAL_TEMPLATE_SPECIALIZE_V(Calendar);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Calendar.hpp 5.13.0-1/ACore/src/ecflow/core/Calendar.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Calendar.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Calendar.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,229 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Calendar_HPP
-#define ecflow_core_Calendar_HPP
-
-///
-/// \brief The calendar encapsulates date and time. The date is derived from the time.
-///        The calendar object is initialised when the suite begins.
-///
-/// After each update the calendar will store the time_duration between the init() function
-/// call and the update() function call.
-/// The calendar is to be used for all reference to time and date
-/// This will stop different time functionality from getting out of step.
-///
-/// Examples of Use of calendar are:
-///   o Generated time variables
-///   o Time dependent attributes: TimeAttr,TodaySeries,CronAttr,DateAttr,DayAttr
-///     ****************************************************************************
-///     ** A time attribute can have a +, which means time relative to suite start
-///     ** This is stored on the TimeSeries, as it isNode/Attribute specific.
-///     ** i.e repeated families will have its own relative start time.
-///     *****************************************************************************
-///
-/// DESIGN CONSIDERATIONS:
-///   Real and Hybrid:
-///   Real
-///     calendar is like a normal calendar where time and date are related
-///     and day/date changes at midnight.
-///   Hybrid:
-///     There is currently confusion about how this is supposed to work.
-///     The date is not supposed to change. (According to John date updates at suite restart?)
-///     This has important implications, i.e does the day change ?
-///     If the day does not change, then many of suites will never complete.
-///       i.e if we use repeat, with a single time series,  "time 10:00"
-///     *** This relies on a day change to reset time attribute at midnight. ****
-///  Conclusion: Will support day change for both REAL and HYBRID (date does not change)
-///
-/// Calendar Updates:
-///   How and when should we update the calendar?
-///     In both the approaches below we need to make a distinction/separation
-///     between the server poll and calendar update. This is required for testing
-///
-///   o Poll/Job submission interval in server is used to update calendar .
-///     +: No time slots will be missed. even if server is suspended/restarted.
-///        since suspending the server, also suspends the calendar updates
-///     +: Suite relative times will continue to work even after server stopped/started
-///     +: Avoids additional system call.
-///     +: Lead's to more deterministic behaviour
-///     -: If server is suspended and restarted the calendar will NOT be in
-///        phase with system clock. (Its not clear to me why this should be an issue?)
-///     ?: If the server is run for several days is there a possibility for the poll
-///        update to get out of skew with real time. This is only possible if
-///        job dependencies take more the 60 seconds to resolve.
-///      *** THIS FUNCTIONALITY NEEDS TO BE ADVERTISED, SO THAT USERS ARE AWARE OF IT
-///      *** THIS FUNCTIONALITY IS AVAILABLE VIA -s flag on the clock attribute .i.e
-///      *** the -s stand's for stop start clock in line with the server
-///            clock real 20.1.2007 +01:00 -s
-///            clock hybrid -s
-///
-///   o Poll/Job submission interval in server is used Initiate an update of calendar via a system call.
-///     +: calendar is always in phase with system clock.
-///        Many task job dependencies depend on ordering based on real time.
-///     -: Requires additional system call for each poll in the server
-///     -: Time slots can be missed. (i.e if server suspended/restarted).
-///        There is no catch up. (?? See TimeDependencies.ddoc)
-///     -: Relative times will not be adhered too, when server stopped/started.
-///     -: Will require more manual intervention ?
-///
-///  Conclusion:: The clock attribute will be changed to add both capabilities
-///
-///  Resolution: Will support 1 minute resolution
-///
-
-#include <cstdint>
-
-#include <boost/date_time/posix_time/posix_time.hpp>
-
-namespace cereal {
-class access;
-}
-
-namespace ecf {
-
-class CalendarUpdateParams; // forward declare
-
-class Calendar {
-public:
-    enum Clock_t {
-        REAL,  // like a normal clock
-        HYBRID // date does not change, but will support day change. See Above.
-    };
-
-    /// Defaults to the REAL clock
-    Calendar();
-    Calendar(const Calendar&);
-    Calendar& operator=(const Calendar&);
-    bool operator==(const Calendar&) const;
-
-    /// Initialise the Calendar.
-    void init(Clock_t clock);
-
-    // for test init and begin calendar
-    void init(const boost::posix_time::ptime& time, Clock_t clock = Calendar::REAL);
-
-    /// Start the Calendar.  Parameter time can include gain.
-    void begin(const boost::posix_time::ptime&);
-
-    /// Update the calendar using the input. Will Store internally the time duration
-    /// between the init() function call and the last update.
-    /// The for_test parameter is *ONLY* used if we are using real time calendar
-    void update(const ecf::CalendarUpdateParams&);
-
-    /// This is used to improve resolution of state change time. ECFLOW-1512
-    void update_duration_only(boost::posix_time::ptime& time_now);
-
-    // Used for test only, will call the function above
-    void update(const boost::posix_time::time_duration&);
-    void update(const boost::posix_time::ptime& time_now);
-
-    // The following were added as a performance optimisation
-    // Represent a day within a week (range 0==Sun to 6==Sat)
-    int day_of_week() const;  // same as suiteTime().date().day_of_week().as_number()
-    int day_of_year() const;  // same as suiteTime().date().day_of_year()
-    int day_of_month() const; // same as suiteTime().date().day()
-    int month() const;        // same as suiteTime().date().month()
-    int year() const;         // same as suiteTime().date().year()
-
-    /// returns true if the day changed, this will update for REAL and HYBRID .
-    bool dayChanged() const { return dayChanged_; }
-
-    /// returns the last calendar increment
-    const boost::posix_time::time_duration& calendarIncrement() const { return increment_; }
-
-    /// return the init() time + the accumulated duration from calls to update(...)
-    /// This should only be used when this calendar is real.
-    const boost::posix_time::ptime& suiteTime() const { return suiteTime_; }
-    std::string suite_time_str() const;
-
-    // duration since last call to init, essentially suite duration
-    const boost::posix_time::time_duration& duration() const { return duration_; }
-
-    /// return real time, when the calendar was begun/initialised.
-    /// This is used to update the duration_, which is recorded for each state change in the node
-    /// Hence to when we can compute when a state change occurred by using:
-    ///   boost::posix_time::ptime time_of_state_change = begin_time() + node->get_state().second(duration)
-    const boost::posix_time::ptime& begin_time() const { return initLocalTime_; }
-
-    /// return the date, for real calendar this corresponds to the date on suiteTime_
-    /// for hybrid,  the date does not change, and hence we return date for initTime_
-    boost::gregorian::date date() const;
-
-    /// The calendar type. For hybrid clocks the date does not update.
-    bool hybrid() const { return (ctype_ == Calendar::HYBRID) ? true : false; }
-
-    /// for debug,  must link with boost date and time library
-    void dump(const std::string& title) const;
-
-    /// for debug,  must link with boost date and time library
-    std::string toString() const;
-
-    void write_state(std::string&) const;
-    void read_state(const std::string& line, const std::vector<std::string>& lineTokens);
-
-    bool checkInvariants(std::string& errorMsg) const;
-
-    // allow Suite memento to update calendar type
-    void set_clock_type(Clock_t ct) { ctype_ = ct; }
-
-    /// Will return either second_clock::universal_time()/UTC ( the other alternative is second_clock::local_time() )
-    /// This is because boost deadline timer is based on UTC clock
-    /// >>> The deadline_timer typedef is based on a UTC clock, and all operations (expires_at, expires_from_now) work
-    /// in UTC time.
-    /// >>> If you want it to use a different clock (such as the local time clock), you can use basic_deadline_timer<>
-    /// with your own traits class.
-    /// >>> Please see the "Timers" example.
-    /// Taken from boost date/time doc
-    /// If you want exact agreement with wall-clock time, you must use either UTC or local time. If you compute a
-    /// duration by subtracting one UTC time from another and you want an answer accurate to the second, the two times
-    /// must not be too far in the future because leap seconds affect the count but are only determined about 6 months
-    /// in advance. With local times a future duration calculation could be off by an entire hour, since legislatures
-    /// can and do change DST rules at will. If you want to handle wall-clock times in the future, you won't be able (in
-    /// the general case) to calculate exact durations, for the same reasons described above. If you want accurate
-    /// calculations with future times, you will have to use TAI or an equivalent, but the mapping from TAI to UTC or
-    /// local time depends on leap seconds, so you will not have exact agreement with wall-clock time.
-    static boost::posix_time::ptime second_clock_time();
-
-    bool is_special() const { return initTime_.is_special(); }
-
-private:
-    void assign(const Calendar& rhs);
-
-    boost::posix_time::ptime initTime_;      // When calendar was started, suite time(could be in the past OR real time)
-    boost::posix_time::ptime suiteTime_;     // The suite time for hybrid DATE does not change.
-    boost::posix_time::ptime initLocalTime_; // Real Time: When calendar was started, used to work out duration_
-    boost::posix_time::ptime lastTime_;      // Real Time: Used to calculate calendarIncrement
-    boost::posix_time::time_duration
-        duration_; // duration since last call to init/begin, used on Node for late and autocancel
-    boost::posix_time::time_duration increment_{0, 1, 0, 0};
-
-private:
-    void update_cache() const;
-    mutable int day_of_week_{-1};  // Cache
-    mutable int day_of_year_{-1};  // Cache
-    mutable int day_of_month_{-1}; // Cache
-    mutable int month_{-1};        // Cache
-    mutable int year_{-1};         // Cache
-
-    Clock_t ctype_{Calendar::REAL}; // *NOT* persisted: can be derived from suite clock attribute
-    bool dayChanged_{false};
-
-private:
-    // Note: The *only* reason to serialise the calendar is so that we can support
-    // why() command on the client side. By default, calendar is initialised in the *server*
-    // at begin time, from the clock attribute
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/);
-};
-} // namespace ecf
-
-#endif /* ecflow_core_Calendar_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/CalendarUpdateParams.hpp 5.13.0-1/ACore/src/ecflow/core/CalendarUpdateParams.hpp
--- 5.12.4-1/ACore/src/ecflow/core/CalendarUpdateParams.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/CalendarUpdateParams.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_CalendarUpdateParams_HPP
-#define ecflow_core_CalendarUpdateParams_HPP
-
-///
-/// \brief Collate list of arguments used to update calendar
-///
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-namespace ecf {
-
-class CalendarUpdateParams {
-public:
-    // For use in the server
-    CalendarUpdateParams(const boost::posix_time::ptime& time_now,
-                         const boost::posix_time::time_duration& serverPollPeriod,
-                         bool serverRunning)
-        : timeNow_(time_now),
-          serverPollPeriod_(serverPollPeriod),
-          serverRunning_(serverRunning),
-          forTest_(false) {}
-
-    // For use in the simulator/ unit tests
-    explicit CalendarUpdateParams(const boost::posix_time::time_duration& serverPollPeriod)
-        : timeNow_(boost::date_time::not_a_date_time),
-          serverPollPeriod_(serverPollPeriod),
-          serverRunning_(true),
-          forTest_(true) {}
-
-    // For use in test
-    CalendarUpdateParams(const boost::posix_time::ptime& time_now,
-                         const boost::posix_time::time_duration& serverPollPeriod,
-                         bool serverRunning,
-                         bool forTest)
-        : timeNow_(time_now),
-          serverPollPeriod_(serverPollPeriod),
-          serverRunning_(serverRunning),
-          forTest_(forTest) {}
-
-    // Disable copy (and move) semantics
-    CalendarUpdateParams(const CalendarUpdateParams&)                  = delete;
-    const CalendarUpdateParams& operator=(const CalendarUpdateParams&) = delete;
-
-    const boost::posix_time::ptime& timeNow() const { return timeNow_; }
-    const boost::posix_time::time_duration& serverPollPeriod() const { return serverPollPeriod_; }
-    bool serverRunning() const { return serverRunning_; }
-    bool forTest() const { return forTest_; }
-
-private:
-    boost::posix_time::ptime timeNow_;                  // Current time and date, not used in simulator
-    boost::posix_time::time_duration serverPollPeriod_; // equivalent to calendar increment
-    bool serverRunning_;                                // Is the server running or stopped
-    bool forTest_;                                      // Used with Simulator
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_CalendarUpdateParams_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/CheckPt.hpp 5.13.0-1/ACore/src/ecflow/core/CheckPt.hpp
--- 5.12.4-1/ACore/src/ecflow/core/CheckPt.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/CheckPt.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_CheckPt_HPP
-#define ecflow_core_CheckPt_HPP
-
-///
-/// \brief This class serialises the edit history when storing a check point.
-///        Provides also check point status enumerates.
-///
-
-namespace ecf {
-
-class CheckPt {
-public:
-    /// NEVER   - the check pt file is never saved
-    /// ON_TIME - the check pt file is saved periodically. specified by checkPtInterval.
-    /// ALWAYS  - the check pt file is saved after any state change
-    /// UNDEFINED   - Internal use only
-    enum Mode { NEVER, ON_TIME, ALWAYS, UNDEFINED };
-
-    // Disable default construction
-    CheckPt() = delete;
-    // Disable copy (and move) semantics
-    CheckPt(const CheckPt&)                  = delete;
-    const CheckPt& operator=(const CheckPt&) = delete;
-
-    /// The interval between automatic saves of check point by server
-    static int default_interval() { return 120; }
-
-    /// If saving check point takes longer than the alarm time, raise late flag on the server
-    static int default_save_time_alarm() { return 20; }
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_CheckPt_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Child.cpp 5.13.0-1/ACore/src/ecflow/core/Child.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Child.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Child.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,146 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Child.hpp"
-
-#include <cassert>
-
-#include "ecflow/core/Enumerate.hpp"
-#include "ecflow/core/Str.hpp"
-
-namespace ecf {
-
-namespace detail {
-
-template <>
-struct EnumTraits<Child::ZombieType>
-{
-    using underlying_t = std::underlying_type_t<Child::ZombieType>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(Child::ZombieType::USER, "user"),
-        std::make_pair(Child::ZombieType::ECF, "ecf"),
-        std::make_pair(Child::ZombieType::ECF_PID, "ecf_pid"),
-        std::make_pair(Child::ZombieType::ECF_PASSWD, "ecf_passwd"),
-        std::make_pair(Child::ZombieType::ECF_PID_PASSWD, "ecf_pid_passwd"),
-        std::make_pair(Child::ZombieType::PATH, "path"),
-        std::make_pair(Child::ZombieType::NOT_SET, "not_set"),
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<Child::ZombieType>::size == map.back().first + 1);
-};
-
-template <>
-struct EnumTraits<Child::CmdType>
-{
-    using underlying_t = std::underlying_type_t<Child::CmdType>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(Child::CmdType::INIT, "init"),
-        std::make_pair(Child::CmdType::EVENT, "event"),
-        std::make_pair(Child::CmdType::METER, "meter"),
-        std::make_pair(Child::CmdType::LABEL, "label"),
-        std::make_pair(Child::CmdType::WAIT, "wait"),
-        std::make_pair(Child::CmdType::QUEUE, "queue"),
-        std::make_pair(Child::CmdType::ABORT, "abort"),
-        std::make_pair(Child::CmdType::COMPLETE, "complete"),
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<Child::CmdType>::size == map.back().first + 1);
-};
-
-} // namespace detail
-
-std::string Child::to_string(Child::ZombieType zt) {
-    if (auto found = Enumerate<Child::ZombieType>::to_string(zt); found) {
-        return std::string{found.value()};
-    }
-    return std::string{};
-}
-
-Child::ZombieType Child::zombie_type(const std::string& s) {
-    return Enumerate<Child::ZombieType>::to_enum(s).value_or(Child::NOT_SET);
-}
-
-bool Child::valid_zombie_type(const std::string& s) {
-    return Enumerate<Child::ZombieType>::is_valid(s);
-}
-
-std::string Child::to_string(const std::vector<Child::CmdType>& vec) {
-    std::string ret;
-    for (size_t i = 0; i < vec.size(); ++i) {
-        if (i != 0) {
-            ret += ",";
-        }
-        ret += to_string(vec[i]);
-    }
-    return ret;
-}
-
-std::string Child::to_string(Child::CmdType ct) {
-    if (auto found = Enumerate<Child::CmdType>::to_string(ct); found) {
-        return std::string{found.value()};
-    }
-    assert(false);
-    return std::string{Enumerate<Child::CmdType>::to_string(Child::INIT).value()};
-}
-
-std::vector<Child::CmdType> Child::child_cmds(const std::string& s) {
-    // expect single or , separated tokens
-    std::vector<std::string> tokens;
-    Str::split(s, tokens, ",");
-    std::vector<Child::CmdType> ret;
-    ret.reserve(tokens.size());
-    for (const auto& token : tokens) {
-        ret.push_back(child_cmd(token));
-    }
-    return ret;
-}
-
-Child::CmdType Child::child_cmd(const std::string& s) {
-    if (auto found = Enumerate<Child::CmdType>::to_enum(s); found) {
-        return found.value();
-    }
-    assert(false);
-    return Child::INIT;
-}
-
-bool Child::valid_child_cmds(const std::string& s) {
-    // empty means all children
-    if (s.empty()) {
-        return true;
-    }
-
-    // expect single or , separated tokens
-    std::vector<std::string> tokens;
-    Str::split(s, tokens, ",");
-    for (const auto& token : tokens) {
-        if (!valid_child_cmd(token)) {
-            return false;
-        }
-    }
-    return true;
-}
-
-bool Child::valid_child_cmd(const std::string& s) {
-    return Enumerate<Child::CmdType>::is_valid(s);
-}
-
-std::vector<Child::CmdType> Child::list() {
-    return Enumerate<Child::CmdType>::enums();
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Child.hpp 5.13.0-1/ACore/src/ecflow/core/Child.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Child.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Child.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Child_HPP
-#define ecflow_core_Child_HPP
-
-///
-/// \brief Specifies the different kinds of child commands, as specified in the
-///        job file and communicated to the server.
-///
-
-#include <string>
-#include <vector>
-
-namespace ecf {
-
-class Child {
-public:
-    enum CmdType {
-        INIT,    // Notify Task start
-        EVENT,   // Notify Task event update
-        METER,   // Notify Task meter update
-        LABEL,   // Notify Task label update
-        WAIT,    // Request to wait until given expression evaluates to true
-        QUEUE,   // Request to interact with Queue (active|complete|abort|...)
-        ABORT,   // Notify Task abortion
-        COMPLETE // Notify Task completion
-    };
-
-    enum ZombieType {
-        USER,           // zombie created by user action
-        ECF,            // two init commands, or aborted and complete, and received any other child command
-        ECF_PID,        // pid miss-match, but password matches,  -> same job submitted twice |
-        ECF_PASSWD,     // password miss-match, but pid matches   -> WTF, user edited ECF_PASS in job file ?
-        ECF_PID_PASSWD, // pid and password missmatch             -> Job re-queued and submitted again
-        PATH,           // zombie, because path to task does not exist in the server
-        NOT_SET
-    };
-
-    // Disable default construction
-    Child() = delete;
-    // Disable copy (and move) semantics
-    Child(const Child&)                  = delete;
-    const Child& operator=(const Child&) = delete;
-
-    static std::string to_string(ZombieType);
-    static bool valid_zombie_type(const std::string&);
-    static ZombieType zombie_type(const std::string&);
-
-    static std::string to_string(const std::vector<Child::CmdType>&);
-    static std::string to_string(Child::CmdType);
-    static std::vector<Child::CmdType> child_cmds(const std::string&);
-    static Child::CmdType child_cmd(const std::string&);
-
-    static std::vector<Child::CmdType> list();
-
-    /// Expect a , separated string
-    static bool valid_child_cmds(const std::string&);
-    static bool valid_child_cmd(const std::string&);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_Child_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Chrono.cpp 5.13.0-1/ACore/src/ecflow/core/Chrono.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Chrono.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Chrono.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,239 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "Chrono.hpp"
-
-#include <array>
-#include <iomanip>
-#include <sstream>
-
-#include <boost/lexical_cast.hpp>
-
-namespace ecf {
-
-namespace {
-
-template <typename C, typename T>
-bool contains(const C& collection, const T& value) {
-    return std::find(std::begin(collection), std::end(collection), value) != std::end(collection);
-}
-
-int days_of_month(int month /* [0-11] */, int year) {
-    if (contains(std::array{0, 2, 4, 6, 7, 9, 11}, month)) {
-        return 31;
-    }
-    if (contains(std::array{3, 5, 8, 10}, month)) {
-        return 30;
-    }
-    if (month == 1) {
-        return (year % 4 == 0 && year % 100) || year % 400 == 0 ? 29 : 28;
-    }
-    throw std::runtime_error("Invalid month detected, while calculating the number of days");
-}
-
-bool is_valid_days_of_month(int day /* [1-31] */, int month /* [0-11] */, int year) {
-    return ((1 <= day) && (day <= days_of_month(month, year)));
-}
-
-} // namespace
-
-Instant Instant::parse(const std::string& value) {
-    std::tm tm = {};
-    std::stringstream ss(value);
-    ss >> std::get_time(&tm, "%Y%m%dT%H%M%S");
-    // Validate if parsing was successful
-    if (ss.fail()) {
-        throw std::runtime_error("Unable to parse invalid instant value: " + value);
-    }
-    // Extra validation of the parsed values (n.b. parsing doesn't ensure number of days is in agreement with the month)
-    if (!is_valid_days_of_month(tm.tm_mday, tm.tm_mon, tm.tm_year + 1900)) {
-        throw std::runtime_error("Detected invalid number of days for instant value: " + value);
-    }
-
-    // Unfortunately, std::mktime does the conversion considering locale, and thus considering timezones e.g. BST.
-    // The following convert std::tm to time_t (i.e. seconds since Posix epoch disregarding the timezone,
-    // adapted from Howard Hinnant's algorithms: http://howardhinnant.github.io/date_algorithms.html (days_from_civil).
-    //
-    // Note: All this can eventually be replaced by using C++20's std::chrono::parse.
-    std::time_t time;
-    {
-        int y      = tm.tm_year + 1900;
-        unsigned m = tm.tm_mon + 1;
-        unsigned d = tm.tm_mday;
-        y -= m <= 2;
-        const int era      = (y >= 0 ? y : y - 399) / 400;
-        const unsigned yoe = static_cast<unsigned>(y - era * 400);           // [0, 399]
-        const unsigned doy = (153 * (m + (m > 2 ? -3 : 9)) + 2) / 5 + d - 1; // [0, 365]
-        const unsigned doe = yoe * 365 + yoe / 4 - yoe / 100 + doy;          // [0, 146096]
-
-        time = (era * 146097 + static_cast<int>(doe) - 719468) * 86400 + tm.tm_hour * 3600 + tm.tm_min * 60 + tm.tm_sec;
-    }
-
-    return Instant{Instant::clock_t::from_time_t(time)};
-}
-
-std::string Instant::format(const Instant& value) {
-    auto tt    = std::chrono::system_clock::to_time_t(value.instant_);
-    std::tm tm = *std::gmtime(&tt);
-
-    std::ostringstream o;
-    o << std::put_time(&tm, "%Y%m%dT%H%M%S");
-    return o.str();
-}
-
-std::ostream& operator<<(std::ostream& o, const Instant& v) {
-    o << Instant::format(v);
-    return o;
-}
-
-bool operator==(const Instant& rhs, const Instant& lhs) {
-    return rhs.instant_ == lhs.instant_;
-}
-
-bool operator!=(const Instant& rhs, const Instant& lhs) {
-    return !(rhs == lhs);
-}
-
-bool operator<(const Instant& rhs, const Instant& lhs) {
-    return rhs.instant_ < lhs.instant_;
-}
-
-bool operator<=(const Instant& rhs, const Instant& lhs) {
-    return rhs == lhs || rhs < lhs;
-}
-
-bool operator>(const Instant& rhs, const Instant& lhs) {
-    return !(rhs <= lhs);
-}
-
-bool operator>=(const Instant& rhs, const Instant& lhs) {
-    return !(rhs < lhs);
-}
-
-Instant operator+(const Instant& rhs, const Duration& lhs) {
-    return Instant{rhs.instant_ + lhs.as_seconds()};
-}
-
-Instant operator-(const Instant& rhs, const Duration& lhs) {
-    return Instant{rhs.instant_ - lhs.as_seconds()};
-}
-
-Duration operator-(const Instant& rhs, const Instant& lhs) {
-    auto diff = rhs.instant_ - lhs.instant_;
-    return Duration{std::chrono::duration_cast<std::chrono::seconds>(diff)};
-}
-
-Instant coerce_to_instant(long value) {
-    auto seconds_since_reference = std::chrono::seconds{value};
-    auto instant                 = Instant{Instant::instant_t{seconds_since_reference}};
-    return instant;
-}
-
-long coerce_from_instant(const Instant& value) {
-    auto seconds_since_reference = std::chrono::duration_cast<std::chrono::seconds>(value.instant_.time_since_epoch());
-    return seconds_since_reference.count();
-}
-
-namespace detail {
-
-template <class DurationIn, class FirstDuration, class... RestDurations>
-std::string format_duration(DurationIn d) {
-    auto value = std::chrono::duration_cast<FirstDuration>(d);
-
-    std::ostringstream oss;
-    oss << std::setw(2) << std::setfill('0') << value.count(); // Ensure left 0-padded value with 2 digits
-    std::string out = oss.str();
-
-    if constexpr (sizeof...(RestDurations) > 0) {
-        // Important!
-        // The whole duration has the same sign as the first component
-        // e.g. -23:59:59, is interpreted as (-23 hours) + (-59 minutes) + (-59 seconds) = -86399 seconds
-        int sign = value >= FirstDuration{0} ? 1 : -1;
-        out += ":" + format_duration<DurationIn, RestDurations...>(sign * (d - value));
-    }
-
-    return out;
-}
-
-template <class DurationOut, class FirstDuration, class... RestDurations>
-DurationOut parse_duration(const std::string& d) {
-    auto found       = d.find(':');
-    std::string head = d.substr(0, found);
-
-    // Convert head (if any) to duration
-    auto value = FirstDuration(0);
-    if (!head.empty()) {
-        value = FirstDuration(boost::lexical_cast<int>(head.c_str()));
-    }
-    DurationOut out = std::chrono::duration_cast<DurationOut>(value);
-
-    if (found == std::string::npos) {
-        return out;
-    }
-
-    // Extract tail
-    std::string tail = d.substr(found + 1, std::string::npos);
-
-    // Important!
-    // The whole duration has the same sign as the first component
-    // e.g. -23:59:59, is interpreted as (-23 hours) + (-59 minutes) + (-59 seconds) = -86399 seconds
-    int sign = value >= FirstDuration{0} ? 1 : -1;
-
-    if constexpr (sizeof...(RestDurations) > 0) {
-        out = out + (sign)*parse_duration<DurationOut, RestDurations...>(tail);
-    }
-
-    return out;
-}
-
-} // namespace detail
-
-Duration Duration::parse(const std::string& value) {
-    return Duration{
-        detail::parse_duration<Duration::duration_t, std::chrono::hours, std::chrono::minutes, std::chrono::seconds>(
-            value)};
-}
-
-std::string Duration::format(const Duration& value) {
-    return detail::
-        format_duration<Duration::duration_t, std::chrono::hours, std::chrono::minutes, std::chrono::seconds>(
-            value.duration_);
-}
-
-std::ostream& operator<<(std::ostream& o, const Duration& v) {
-    o << Duration::format(v);
-    return o;
-}
-
-bool operator==(const Duration& rhs, const Duration& lhs) {
-    return rhs.duration_ == lhs.duration_;
-}
-
-bool operator!=(const Duration& rhs, const Duration& lhs) {
-    return !(rhs == lhs);
-}
-
-bool operator<(const Duration& rhs, const Duration& lhs) {
-    return rhs.duration_ < lhs.duration_;
-}
-
-bool operator<=(const Duration& rhs, const Duration& lhs) {
-    return rhs == lhs || rhs < lhs;
-}
-
-bool operator>(const Duration& rhs, const Duration& lhs) {
-    return !(rhs <= lhs);
-}
-
-bool operator>=(const Duration& rhs, const Duration& lhs) {
-    return !(rhs < lhs);
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Chrono.hpp 5.13.0-1/ACore/src/ecflow/core/Chrono.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Chrono.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Chrono.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,92 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Chrono_HPP
-#define ecflow_core_Chrono_HPP
-
-#include <chrono>
-#include <string>
-
-namespace ecf {
-
-class Instant;
-class Duration;
-
-Instant coerce_to_instant(long value);
-long coerce_from_instant(const Instant& value);
-
-class Instant {
-public:
-    using clock_t   = std::chrono::system_clock;
-    using instant_t = std::chrono::time_point<Instant::clock_t>;
-
-    Instant() : instant_() {}
-    explicit Instant(instant_t instant)
-        : instant_(std::chrono::duration_cast<std::chrono::seconds>(instant.time_since_epoch())) {}
-    explicit Instant(std::chrono::seconds seconds_since_reference) : instant_(seconds_since_reference) {}
-
-    static Instant parse(const std::string& value);
-    static std::string format(const Instant& value);
-
-    friend bool operator==(const Instant& rhs, const Instant& lhs);
-    friend bool operator<(const Instant& rhs, const Instant& lhs);
-
-    friend Instant operator+(const Instant& rhs, const Duration& lhs);
-    friend Instant operator-(const Instant& rhs, const Duration& lhs);
-    friend Duration operator-(const Instant& rhs, const Instant& lhs);
-
-    friend Instant coerce_to_instant(long value);
-    friend long coerce_from_instant(const Instant& value);
-
-private:
-    instant_t instant_;
-};
-
-std::ostream& operator<<(std::ostream& o, const Instant& v);
-
-bool operator==(const Instant& rhs, const Instant& lhs);
-bool operator!=(const Instant& rhs, const Instant& lhs);
-bool operator<(const Instant& rhs, const Instant& lhs);
-bool operator<=(const Instant& rhs, const Instant& lhs);
-bool operator>(const Instant& rhs, const Instant& lhs);
-bool operator>=(const Instant& rhs, const Instant& lhs);
-
-class Duration {
-public:
-    using duration_t = std::chrono::seconds;
-
-    Duration() : duration_{} {}
-    template <typename DURATION>
-    explicit Duration(DURATION duration) : duration_{std::chrono::duration_cast<duration_t>(duration)} {}
-
-    [[nodiscard]] duration_t as_seconds() const { return duration_; }
-
-    static Duration parse(const std::string& value);
-    static std::string format(const Duration& value);
-
-    friend bool operator==(const Duration& rhs, const Duration& lhs);
-    friend bool operator<(const Duration& rhs, const Duration& lhs);
-
-private:
-    duration_t duration_;
-};
-
-std::ostream& operator<<(std::ostream& o, const Duration& v);
-
-bool operator==(const Duration& rhs, const Duration& lhs);
-bool operator!=(const Duration& rhs, const Duration& lhs);
-bool operator<(const Duration& rhs, const Duration& lhs);
-bool operator<=(const Duration& rhs, const Duration& lhs);
-bool operator>(const Duration& rhs, const Duration& lhs);
-bool operator>=(const Duration& rhs, const Duration& lhs);
-
-} // namespace ecf
-
-#endif // ECFLOW_CHRONO_HPP
diff -pruN 5.12.4-1/ACore/src/ecflow/core/CommandLine.cpp 5.13.0-1/ACore/src/ecflow/core/CommandLine.cpp
--- 5.12.4-1/ACore/src/ecflow/core/CommandLine.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/CommandLine.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,229 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/CommandLine.hpp"
-
-#include <boost/program_options.hpp>
-#include <boost/tokenizer.hpp>
-
-namespace impl_detail {
-
-/**
- * The `custom_unix_style_separator` implements a TokenizerFunction (from Boost.Tokenizer), and allows to separate the
- * tokens of Unix style CLI calls. This separation is performed considering that repeated consecutive separators
- * can appear. The following is an example of the expected tokenizing:
- *   Given `   executable  --option    param  " --value "      ""   "\""  --options`, the expected tokens are:
- *     - `executable`
- *     - `--option`
- *     - `param`
- *     - ` --value `
- *     - ``
- *     - `"`
- *     - `--options`
- */
-class custom_unix_style_separator {
-
-private:
-    std::string escape_    = "\\";
-    std::string separator_ = " \t";
-    std::string quote_     = "'\"";
-    bool last_             = false;
-
-    bool is(char e, std::string set) {
-        return std::find_if(set.begin(), set.end(), [e](char c) { return c == e; }) != set.end();
-    }
-
-    bool is_escape(char e) { return is(e, escape_); }
-    bool is_separator(char e) { return is(e, separator_); }
-    bool is_quote(char e) { return is(e, quote_); }
-
-    template <typename iterator>
-    bool advance_separators(iterator& next, iterator& end) {
-
-        // Advance through all separators
-        while (is_separator(*next) && next != end) {
-            next++;
-        }
-
-        return (next == end);
-    }
-
-    template <typename iterator, typename Token>
-    void do_escape(iterator& next, iterator end, Token& tok) {
-        if (++next == end) {
-            throw std::runtime_error(std::string("Unexpected end of escape sequence"));
-        }
-        if (*next == 'n') {
-            tok += '\n';
-            return;
-        }
-        else if (is_quote(*next) || is_separator(*next) || is_escape(*next)) {
-            tok += *next;
-            return;
-        }
-        else {
-            throw std::runtime_error("Unexpected escape sequence");
-        }
-    }
-
-    std::vector<char> selected_quote_ = {};
-
-    bool in_quote() { return !selected_quote_.empty(); }
-
-public:
-    void reset() { last_ = false; }
-
-    template <typename InputIterator, typename Token>
-    bool operator()(InputIterator& next, InputIterator end, Token& tok) {
-        // Reset collected Token
-        tok        = Token();
-        bool valid = false;
-
-        // Consume pre-separators, and handle the case where we reach the end of the iterable
-        if (advance_separators(next, end)) {
-            if (last_) {
-                last_ = false;
-                return true;
-            }
-            return false;
-        }
-
-        // Otherwise, collect the token
-        last_ = false;
-        for (; next != end; ++next) {
-            if (is_escape(*next)) {
-                do_escape(next, end, tok);
-            }
-            else if (is_separator(*next)) {
-                if (!in_quote()) {
-                    // If we are not in quote, then we are done
-                    ++next;
-                    // The last character was a c, that means there is
-                    // 1 more blank field
-                    last_ = true;
-
-                    // Consume post-separators
-                    if (advance_separators(next, end)) {
-                        if (last_) {
-                            last_ = false;
-                            return true;
-                        }
-                        return false;
-                    }
-
-                    return true;
-                }
-                else {
-                    valid = true;
-                    tok += *next;
-                }
-            }
-            else if (is_quote(*next)) {
-
-                if (!in_quote()) {
-                    // Entering quoted sequence...
-                    selected_quote_.push_back(*next);
-                }
-                else if (selected_quote_.back() == *next) {
-                    // Matching quotation marks detected... Ending the quoted sequence!
-                    selected_quote_.pop_back();
-                }
-                else {
-                    // Unmatched quotation marks detected... Keep collecting the quoted sequence!
-                    tok += *next;
-                }
-            }
-            else {
-                valid = true;
-                tok += *next;
-            }
-        }
-
-        // Consume post-separators
-        if (advance_separators(next, end)) {
-            if (last_) {
-                last_ = false;
-                return true;
-            }
-            if (in_quote()) {
-                throw std::runtime_error("Unmatched quotation marks detected");
-            }
-            return valid;
-        }
-
-        if (in_quote()) {
-            throw std::runtime_error("Unmatched quotation marks detected");
-        }
-        return true;
-    }
-};
-
-CommandLine::cl_t reconstruct_command_line(const CommandLine::tokens_t& tokens, const std::string& separator = " ") {
-    std::ostringstream cl;
-    if (!tokens.empty()) {
-        cl << tokens.front();
-        for (size_t i = 1; i < tokens.size(); ++i) {
-            cl << separator << '"' << tokens[i] << '"';
-        }
-    }
-    return cl.str();
-}
-
-CommandLine::tokens_t reconstruct_tokens(int argc, const char** argv) {
-    CommandLine::tokens_t tokens;
-    for (int i = 0; i < argc; ++i) {
-        tokens.push_back(argv[i]);
-    }
-    return tokens;
-}
-
-std::vector<std::string> split_unix(const std::string& cmdline) {
-    using separator_t = custom_unix_style_separator;
-    using tokenizer_t = boost::tokenizer<separator_t, std::string::const_iterator, std::string>;
-
-    tokenizer_t tok(std::begin(cmdline), std::end(cmdline), separator_t());
-
-    std::vector<std::string> result;
-    for (typename tokenizer_t::iterator curT(tok.begin()), endT(tok.end()); curT != endT; ++curT) {
-        result.push_back(*curT);
-    }
-    return result;
-}
-
-} // namespace impl_detail
-
-CommandLine::CommandLine(int argc, char** argv) : CommandLine(argc, const_cast<const char**>(argv)) {
-}
-
-CommandLine::CommandLine(int argc, const char** argv) : tokens_{impl_detail::reconstruct_tokens(argc, argv)} {
-}
-
-CommandLine::CommandLine(const std::string& cl) : tokens_{impl_detail::split_unix(cl)} {
-}
-
-CommandLine::CommandLine(tokens_t tokens) : tokens_{std::move(tokens)} {
-}
-
-CommandLine::cl_t CommandLine::original() const {
-    return impl_detail::reconstruct_command_line(tokens_);
-}
-
-size_t CommandLine::size() const {
-    return tokens_.size();
-}
-
-const CommandLine::tokens_t& CommandLine::tokens() const {
-    return tokens_;
-}
-
-std::ostream& operator<<(std::ostream& os, const CommandLine& cl) {
-    os << "argc=" << cl.tokens_.size() << ", argv=[" << impl_detail::reconstruct_command_line(cl.tokens_, ", ") << "]";
-    return os;
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/CommandLine.hpp 5.13.0-1/ACore/src/ecflow/core/CommandLine.hpp
--- 5.12.4-1/ACore/src/ecflow/core/CommandLine.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/CommandLine.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,111 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_CommandLine_HPP
-#define ecflow_core_CommandLine_HPP
-
-#include <ostream>
-#include <string>
-#include <vector>
-
-/**
- * CommandLine is a thin wrapper/container for the contents of an ecFlow client command line.
- *
- * Note: This class is related to class ArgvCreator, which takes the vector of the command
- * line tokens and converts them into argc+argv.
- */
-class CommandLine {
-public:
-    using cl_t     = std::string;
-    using tokens_t = std::vector<std::string>;
-    using size_t   = tokens_t::size_type;
-
-public:
-    /**
-     * Create a Command Line instance based on argc + argv
-     *
-     * @param argc the number of tokens in the command line
-     * @param argv the tokens in the command line
-     */
-    CommandLine(int argc, char** argv);
-    CommandLine(int argc, const char** argv);
-
-    /**
-     * Create a Command Line instance based on a sequence of characters,
-     * considering that it might include single/double quotes.
-     *
-     * @param cl the command line as a sequence of characters
-     */
-    explicit CommandLine(const cl_t& cl);
-
-    /**
-     * Create a Command Line instance based on a sequence of tokens.
-     *
-     * @param tokens the command line as a sequence of tokens
-     */
-    explicit CommandLine(tokens_t tokens);
-
-    /**
-     * Create a Command Line instance based on multiple tokens.
-     * Tokens can be either strings or collections of strings. In the latter case, the collection of strings are
-     * added to the command line element-by-element.
-     *
-     * @param tokens the command line as multiple tokens
-     */
-    template <typename... TOKENS>
-    static CommandLine make_command_line(TOKENS... tokens) {
-        auto push = Overload{
-            [](std::vector<std::string>& collection, const std::vector<std::string>& tokens) {
-                std::copy(std::begin(tokens), std::end(tokens), std::back_inserter(collection));
-            },
-            [](std::vector<std::string>& collection, const std::string& token) { collection.push_back(token); }};
-
-        std::vector<std::string> ts;
-        ((push(ts, tokens)), ...);
-        return CommandLine(ts);
-    }
-
-    /**
-     * Access the original content of the command line.
-     */
-    [[nodiscard]] cl_t original() const;
-
-    /**
-     * Access the number of tokens composing the command line.
-     *
-     * @return the number of tokens
-     */
-    [[nodiscard]] size_t size() const;
-
-    /**
-     * Access the sequence of tokens composing the command line.
-     *
-     * @return the command line tokens
-     */
-    [[nodiscard]] const tokens_t& tokens() const;
-
-    /**
-     * Pretty print the command line
-     */
-    friend std::ostream& operator<<(std::ostream& os, const CommandLine& cl);
-
-private:
-    tokens_t tokens_;
-
-    // Utility to allow the combination of multiple lambdas
-    template <typename... L>
-    struct Overload : L...
-    {
-        using L::operator()...;
-        constexpr explicit Overload(L... lambda) : L(std::move(lambda))... {}
-    };
-};
-
-#endif /* ecflow_core_CommandLine_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Converter.hpp 5.13.0-1/ACore/src/ecflow/core/Converter.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Converter.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Converter.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Converter_HPP
-#define ecflow_core_Converter_HPP
-
-#include <string>
-#include <utility>
-
-#include <boost/lexical_cast.hpp>
-
-namespace ecf {
-
-struct bad_conversion : public std::runtime_error
-{
-    explicit bad_conversion(const char* m) : std::runtime_error(m) {}
-    explicit bad_conversion(const std::string& m) : std::runtime_error(m) {}
-};
-
-namespace detail {
-
-template <typename To, typename From>
-inline static auto try_lexical_convert(From&& v) {
-    try {
-        return boost::lexical_cast<To>(v);
-    }
-    catch (const boost::bad_lexical_cast& e) {
-        throw bad_conversion(e.what());
-    }
-}
-
-} // namespace detail
-
-template <typename From, typename To>
-struct converter_traits
-{
-    inline static auto convert(From&& v) { return detail::try_lexical_convert<To>(std::forward<From>(v)); }
-};
-
-template <>
-struct converter_traits<char, std::string>
-{
-    inline static auto convert(char v) { return std::string{v}; }
-};
-
-template <>
-struct converter_traits<const char*, std::string>
-{
-    inline static auto convert(const char* v) { return std::string{v}; }
-};
-
-template <typename From>
-struct converter_traits<From, std::enable_if<std::is_integral_v<From> || std::is_floating_point_v<From>, std::string>>
-{
-    inline static auto convert(From&& v) { return std::to_string(v); }
-};
-
-template <typename To, typename From>
-inline auto convert_to(From&& v) {
-    using namespace ecf::detail;
-    return converter_traits<From, To>::convert(std::forward<From>(v));
-}
-
-} // namespace ecf
-
-#endif /* ecflow_core_Converter_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/DState.cpp 5.13.0-1/ACore/src/ecflow/core/DState.cpp
--- 5.12.4-1/ACore/src/ecflow/core/DState.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/DState.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,119 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/DState.hpp"
-
-#include <cassert>
-#include <stdexcept>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Enumerate.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-namespace ecf::detail {
-
-template <>
-struct EnumTraits<DState::State>
-{
-    using underlying_t = std::underlying_type_t<DState::State>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(DState::State::UNKNOWN, "unknown"),
-        std::make_pair(DState::State::COMPLETE, "complete"),
-        std::make_pair(DState::State::QUEUED, "queued"),
-        std::make_pair(DState::State::ABORTED, "aborted"),
-        std::make_pair(DState::State::SUBMITTED, "submitted"),
-        std::make_pair(DState::State::ACTIVE, "active"),
-        std::make_pair(DState::State::SUSPENDED, "suspended"),
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<DState::State>::size == map.back().first + 1);
-};
-
-} // namespace ecf::detail
-
-void DState::setState(State s) {
-    st_              = s;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "DState::setState\n";
-#endif
-}
-
-NState::State DState::convert(DState::State display_state) {
-    switch (display_state) {
-        case DState::UNKNOWN:
-            return NState::UNKNOWN;
-        case DState::COMPLETE:
-            return NState::COMPLETE;
-        case DState::SUSPENDED:
-            return NState::UNKNOWN;
-        case DState::QUEUED:
-            return NState::QUEUED;
-        case DState::ABORTED:
-            return NState::ABORTED;
-        case DState::SUBMITTED:
-            return NState::SUBMITTED;
-        case DState::ACTIVE:
-            return NState::ACTIVE;
-    }
-    return NState::UNKNOWN;
-}
-
-const char* DState::toString(DState::State s) {
-    if (auto found = ecf::Enumerate<DState::State>::to_string(s); found) {
-        return found.value().data();
-    }
-    assert(false);
-    return {};
-}
-
-std::string DState::to_html(DState::State s) {
-    std::string res;
-    if (auto found = ecf::Enumerate<DState::State>::to_string(s); found) {
-        res += "<state>";
-        res += found.value();
-        res += "</state>";
-        return res;
-    }
-    assert(false);
-    return res;
-}
-
-DState::State DState::toState(const std::string& str) {
-    if (auto found = ecf::Enumerate<DState::State>::to_enum(str); found) {
-        return found.value();
-    }
-    throw std::runtime_error("DState::toState: Can change string to a DState :" + str);
-}
-
-bool DState::isValid(const std::string& state) {
-    return ecf::Enumerate<DState::State>::is_valid(state);
-}
-
-std::vector<std::string> DState::allStates() {
-    return ecf::Enumerate<DState::State>::designations();
-}
-
-std::vector<DState::State> DState::states() {
-    return ecf::Enumerate<DState::State>::enums();
-}
-
-// ==========================================================================
-
-template <class Archive>
-void DState::serialize(Archive& ar) {
-    ar(CEREAL_NVP(st_));
-}
-CEREAL_TEMPLATE_SPECIALIZE(DState);
diff -pruN 5.12.4-1/ACore/src/ecflow/core/DState.hpp 5.13.0-1/ACore/src/ecflow/core/DState.hpp
--- 5.12.4-1/ACore/src/ecflow/core/DState.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/DState.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,77 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_DState_HPP
-#define ecflow_core_DState_HPP
-
-///
-/// \brief DState stores the state of a node.
-///
-/// The class DState is used to define the enum.
-/// The number of state changes in stored in `state_change_no`.
-///
-
-#include <string>
-
-#include "ecflow/core/NState.hpp"
-
-class DState {
-public:
-    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5, SUSPENDED = 6 };
-
-    explicit DState(State s) : st_(s), state_change_no_(0) {}
-    DState() : st_(default_state()) {}
-    static DState::State default_state() { return DState::QUEUED; } // NEVER change, or will break client/server
-
-    State state() const { return st_; }
-    void setState(State);
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    bool operator==(const DState& rhs) const { return st_ == rhs.st_; }
-    bool operator!=(const DState& rhs) const { return st_ != rhs.st_; }
-    bool operator==(State s) const { return s == st_; }
-    bool operator!=(State s) const { return s != st_; }
-
-    static NState::State convert(DState::State);
-    static const char* toString(DState::State);
-    static std::string to_html(DState::State);
-    static const char* toString(const DState& ns) { return toString(ns.state()); }
-    static std::string to_string(DState::State s) { return std::string(toString(s)); }
-    static DState::State toState(const std::string&);
-    static bool isValid(const std::string&);
-    static std::vector<std::string> allStates();
-    static std::vector<DState::State> states();
-
-private:
-    State st_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-
-    // *IMPORTANT* no version for a simple class
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-////////////////////////////////////////////////////////////////////////////////////////
-// Thin wrapper over DState, to aid python. i.e Task("t").add(Defstatus(DState.complete))
-class Defstatus {
-public:
-    explicit Defstatus(DState::State state) : st_(state) {}
-    explicit Defstatus(const std::string& ds) : st_(DState::toState(ds)) {}
-    DState::State state() const { return st_; }
-    std::string to_string() const { return DState::to_string(st_); }
-
-private:
-    DState::State st_;
-};
-
-#endif
diff -pruN 5.12.4-1/ACore/src/ecflow/core/DebugPerf.hpp 5.13.0-1/ACore/src/ecflow/core/DebugPerf.hpp
--- 5.12.4-1/ACore/src/ecflow/core/DebugPerf.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/DebugPerf.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_DebugPerf_HPP
-#define ecflow_core_DebugPerf_HPP
-
-// #define DEBUG_PERF 1
-#ifdef DEBUG_PERF
-    #include "ecflow/core/DurationTimer.hpp"
-#endif
-
-#endif /* ecflow_core_DebugPerf_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/DurationTimer.cpp 5.13.0-1/ACore/src/ecflow/core/DurationTimer.cpp
--- 5.12.4-1/ACore/src/ecflow/core/DurationTimer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/DurationTimer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/DurationTimer.hpp"
-
-#include <iostream>
-
-using namespace ecf;
-
-ScopedDurationTimer::~ScopedDurationTimer() {
-    std::cout << msg_ << " " << (double)elapsed().total_milliseconds() / (double)1000 << "s\n";
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/DurationTimer.hpp 5.13.0-1/ACore/src/ecflow/core/DurationTimer.hpp
--- 5.12.4-1/ACore/src/ecflow/core/DurationTimer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/DurationTimer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_DurationTimer_HPP
-#define ecflow_core_DurationTimer_HPP
-
-///
-/// \brief Simple class to report wall clock time duration
-///
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-namespace ecf {
-
-class DurationTimer {
-public:
-    DurationTimer() : start_time_(boost::posix_time::microsec_clock::universal_time()) {}
-    ~DurationTimer() = default;
-
-    int duration() const {
-        boost::posix_time::time_duration duration = boost::posix_time::microsec_clock::universal_time() - start_time_;
-        return duration.total_seconds();
-    }
-
-    boost::posix_time::time_duration elapsed() const {
-        return boost::posix_time::microsec_clock::universal_time() - start_time_;
-    }
-
-    double elapsed_seconds() const { return (double)elapsed().total_milliseconds() / (double)1000; }
-
-private:
-    boost::posix_time::ptime start_time_;
-};
-
-class ScopedDurationTimer {
-public:
-    explicit ScopedDurationTimer(const char* msg)
-        : start_time_(boost::posix_time::microsec_clock::universal_time()),
-          msg_(msg) {}
-    ~ScopedDurationTimer();
-
-    boost::posix_time::time_duration elapsed() const {
-        return boost::posix_time::microsec_clock::universal_time() - start_time_;
-    }
-
-private:
-    boost::posix_time::ptime start_time_;
-    const char* msg_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_DurationTimer_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Ecf.cpp 5.13.0-1/ACore/src/ecflow/core/Ecf.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Ecf.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Ecf.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,108 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Ecf.hpp"
-
-bool Ecf::server_                            = false;
-bool Ecf::debug_equality_                    = false;
-unsigned int Ecf::debug_level_               = 0;
-unsigned int Ecf::state_change_no_           = 0;
-unsigned int Ecf::modify_change_no_          = 0;
-bool DebugEquality::ignore_server_variables_ = false;
-
-const char* Ecf::SERVER_NAME() {
-    static const char* SERVER_NAME = "ecflow_server";
-    return SERVER_NAME;
-}
-const char* Ecf::CLIENT_NAME() {
-    static const char* CLIENT_NAME = "ecflow_client";
-    return CLIENT_NAME;
-}
-
-const std::string& Ecf::LOG_FILE() {
-    static const std::string LOG_FILE = "ecf.log";
-    return LOG_FILE;
-}
-const std::string& Ecf::CHECKPT() {
-    static const std::string CHECKPT = "ecf.check";
-    return CHECKPT;
-}
-const std::string& Ecf::BACKUP_CHECKPT() {
-    static const std::string BACKUP_CHECKPT = "ecf.check.b";
-    return BACKUP_CHECKPT;
-}
-const std::string& Ecf::MICRO() {
-    static const std::string MICRO = "%";
-    return MICRO;
-}
-const std::string& Ecf::JOB_CMD() {
-    static const std::string JOB_CMD = "%ECF_JOB% 1> %ECF_JOBOUT% 2>&1";
-    return JOB_CMD;
-}
-const std::string& Ecf::KILL_CMD() {
-    static const std::string KILL_CMD = "kill -15 %ECF_RID%";
-    return KILL_CMD;
-} // "${ECF_KILL:=/home/ma/emos/bin/ecfkill}   %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1";
-const std::string& Ecf::STATUS_CMD() {
-    static const std::string STATUS_CMD = "ps --pid %ECF_RID% -f > %ECF_JOB%.stat 2>&1";
-    return STATUS_CMD;
-} // "${ECF_STAT:=/home/ma/emos/bin/ecfstatus} %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.stat 2>&1";
-const std::string& Ecf::CHECK_CMD() {
-    static const std::string CHECK_CMD = "ps --pid %ECF_RID% -f";
-    return CHECK_CMD;
-}
-
-// -remote has been removed form firefox, since version 39
-//-remote openfile(file)                    -> -file <file>
-//-remote openurl(url)                      -> -url <url>
-//-remote openurl(url,new-window)           -> -new-window <url>
-//-remote openurl(url,new-tab)              -> -new-tab <url>
-//-remote xfedocommand(openbrowser,url)     -> -browser <url>
-//-remote xfedocommand(openinbox)           -> -mail
-//-remote xfedocommand(composemessage,args) -> -compose args
-const std::string& Ecf::URL_CMD() {
-    static const std::string URL_CMD = "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%";
-    return URL_CMD;
-}
-const std::string& Ecf::URL_BASE() {
-    static const std::string URL_BASE = "https://confluence.ecmwf.int";
-    return URL_BASE;
-}
-const std::string& Ecf::URL() {
-    static const std::string URL = "display/ECFLOW/ecflow+home";
-    return URL;
-}
-
-unsigned int Ecf::incr_state_change_no() {
-    if (server_) {
-        return ++state_change_no_;
-    }
-    return state_change_no_;
-}
-
-unsigned int Ecf::incr_modify_change_no() {
-
-    if (server_) {
-        return ++modify_change_no_;
-    }
-    return modify_change_no_;
-}
-
-// =======================================================
-
-EcfPreserveChangeNo::EcfPreserveChangeNo()
-    : state_change_no_(Ecf::state_change_no()),
-      modify_change_no_(Ecf::modify_change_no()) {
-}
-
-EcfPreserveChangeNo::~EcfPreserveChangeNo() {
-    Ecf::set_state_change_no(state_change_no_);
-    Ecf::set_modify_change_no(modify_change_no_);
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Ecf.hpp 5.13.0-1/ACore/src/ecflow/core/Ecf.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Ecf.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Ecf.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,117 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Ecf_HPP
-#define ecflow_core_Ecf_HPP
-
-///
-/// \brief Provides globals used by server for determining change
-///
-
-#include <string>
-
-// class Ecf: This class is used in the server to determine incremental changes
-//            to the data model. Each Node/attribute stores a state change no
-//            When ever there is a change, we increment local state change
-//            number with this global.
-// When making large scale changes, ie nodes added or deleted we use modify change no
-// Note: The client will need to at some point copy over the full defs
-//       at this point the state change no add modify number is also copied.
-//       The client passes these two number back to server, the server then
-//       uses these two numbers to determine what's changed.
-//
-class Ecf {
-public:
-    // Disable default construction
-    Ecf() = delete;
-    // Disable copy (and move) semantics
-    Ecf(const Ecf&)                  = delete;
-    const Ecf& operator=(const Ecf&) = delete;
-
-    /// Increment and then return state change no
-    static unsigned int incr_state_change_no();
-    static unsigned int state_change_no() { return state_change_no_; }
-    static void set_state_change_no(unsigned int x) { state_change_no_ = x; }
-
-    /// The modify_change_no_ is used for node addition and deletion and re-ordering
-    static unsigned int incr_modify_change_no();
-    static unsigned int modify_change_no() { return modify_change_no_; }
-    static void set_modify_change_no(unsigned int x) { modify_change_no_ = x; }
-
-    /// Returns true if we are on the server side.
-    /// Only in server side do we increment state/modify numbers
-    /// Also used in debug/test: Allows print to add know if in server/client
-    static bool server() { return server_; }
-
-    /// Should only be set by the server, made public so that testing can also set it
-    /// Only in server side do we increment state/modify numbers
-    static void set_server(bool f) { server_ = f; }
-
-    static bool debug_equality() { return debug_equality_; }
-    static void set_debug_equality(bool f) { debug_equality_ = f; }
-
-    // ECFLOW-99
-    static unsigned int debug_level() { return debug_level_; }
-    static void set_debug_level(unsigned int level) { debug_level_ = level; }
-
-    static const char* SERVER_NAME();
-    static const char* CLIENT_NAME();
-
-    static const std::string& LOG_FILE();
-    static const std::string& CHECKPT();
-    static const std::string& BACKUP_CHECKPT();
-    static const std::string& MICRO();
-    static const std::string& JOB_CMD();
-    static const std::string& KILL_CMD();
-    static const std::string& STATUS_CMD(); // Typical run on the server
-    static const std::string& CHECK_CMD();  // Typical run on the client
-    static const std::string& URL_CMD();
-    static const std::string& URL_BASE();
-    static const std::string& URL();
-
-private:
-    static bool server_;
-    static bool debug_equality_;
-    static unsigned int debug_level_;
-    static unsigned int state_change_no_;
-    static unsigned int modify_change_no_;
-};
-
-/// Make sure the Ecf number don't change
-class EcfPreserveChangeNo {
-public:
-    EcfPreserveChangeNo();
-    ~EcfPreserveChangeNo();
-
-private:
-    unsigned int state_change_no_;
-    unsigned int modify_change_no_;
-};
-
-class DebugEquality {
-public:
-    DebugEquality() { Ecf::set_debug_equality(true); }
-    // Disable copy (and move) semantics
-    DebugEquality(const DebugEquality&)                  = delete;
-    const DebugEquality& operator=(const DebugEquality&) = delete;
-
-    ~DebugEquality() {
-        Ecf::set_debug_equality(false);
-        set_ignore_server_variables(false);
-    }
-
-    static bool ignore_server_variables() { return ignore_server_variables_; }
-    static void set_ignore_server_variables(bool flg) { ignore_server_variables_ = flg; }
-
-private:
-    static bool ignore_server_variables_;
-};
-
-#endif /* ecflow_core_Ecf_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/EcfPortLock.hpp 5.13.0-1/ACore/src/ecflow/core/EcfPortLock.hpp
--- 5.12.4-1/ACore/src/ecflow/core/EcfPortLock.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/EcfPortLock.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_EcfPortLock_HPP
-#define ecflow_core_EcfPortLock_HPP
-
-///
-/// \brief This class enables the creation of a lock file file, so that different processes
-///        avoid creating server with same port number.
-///
-///        IMPORTANT: This functionality is used in TESTS only.
-///
-
-#include <iostream>
-#include <sstream>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/File.hpp"
-
-namespace ecf {
-
-class EcfPortLock {
-public:
-    // Disable default construction
-    EcfPortLock() = delete;
-    // Disable copy (and move) semantics
-    EcfPortLock(const EcfPortLock&)                  = delete;
-    const EcfPortLock& operator=(const EcfPortLock&) = delete;
-
-    static bool is_free(int port, bool debug = false) {
-        std::string the_port = ecf::convert_to<std::string>(port);
-        if (fs::exists(port_file(the_port))) {
-            if (debug)
-                std::cout << "  EcfPortLock::is_free(" << port << ") returning FALSE\n ";
-            return false;
-        }
-        if (debug)
-            std::cout << "  EcfPortLock::is_free(" << port << ") returning TRUE\n ";
-        return true;
-    }
-
-    static void create(const std::string& the_port) {
-        std::string the_file = port_file(the_port);
-        std::string errorMsg;
-        if (!ecf::File::create(the_file, "", errorMsg)) {
-            std::stringstream sb;
-            sb << "EcfPortLock::create_free_port_file : could not create file " << the_file;
-            throw std::runtime_error(sb.str());
-        }
-    }
-
-    static void remove(const std::string& the_port) {
-        std::string the_file = port_file(the_port);
-        fs::remove(the_file);
-    }
-
-private:
-    static std::string port_file(const std::string& the_port) {
-        // We need the *SAME* location so that different process find the same file.
-        // When going across compiler the root_build_dir is not sufficient
-        char* ecf_port_lock_dir = getenv("ECF_PORT_LOCK_DIR");
-        std::string path;
-        if (ecf_port_lock_dir)
-            path = ecf_port_lock_dir;
-        else
-            path = File::root_source_dir();
-
-        path += "/";
-        path += the_port;
-        path += ".lock";
-
-        return path;
-    }
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_EcfPortLock_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Enumerate.hpp 5.13.0-1/ACore/src/ecflow/core/Enumerate.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Enumerate.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Enumerate.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,128 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Enumerate_HPP
-#define ecflow_core_Enumerate_HPP
-
-#include <algorithm>
-#include <array>
-#include <optional>
-#include <string>
-#include <string_view>
-#include <vector>
-
-namespace ecf {
-
-namespace detail {
-
-/**
- * EnumTraits defines the mapping between a set of enum values and their designation.
- *
- * EnumTraits must define:
- *  - the mapping `map`, provided as an std::array composes of an std::pair<E, const char *> for each enum value
- *  - the `size`, holding the number os entries in `map`
- *
- * @tparam E
- */
-
-template <typename E>
-struct EnumTraits
-{
-};
-
-} // namespace detail
-
-template <typename E, typename TRAITS = detail::EnumTraits<E>>
-struct Enumerate
-{
-public:
-    using enum_t   = E;
-    using string_t = std::string_view;
-
-    /**
-     * Convert the given enum value to its designation
-     *
-     * @param e the enum value
-     * @return the designation, in case it exists; an empty optional, otherwise
-     */
-    static constexpr std::optional<string_t> to_string(enum_t e) noexcept {
-        if (auto found = std::find_if(
-                std::begin(TRAITS::map), std::end(TRAITS::map), [&](const auto& item) { return item.first == e; });
-            found != std::end(TRAITS::map)) {
-
-            return std::make_optional(found->second);
-        }
-        return std::nullopt;
-    }
-
-    /**
-     * Convert the given designation to the related enum value
-     *
-     * @param s the designation
-     * @return the enum value, in case it exists; an empty optional, otherwise
-     */
-    static constexpr std::optional<E> to_enum(string_t s) noexcept {
-        if (auto found = std::find_if(
-                std::begin(TRAITS::map), std::end(TRAITS::map), [&](const auto& item) { return item.second == s; });
-            found != std::end(TRAITS::map)) {
-
-            return std::make_optional(found->first);
-        }
-        return std::nullopt;
-    }
-
-    /**
-     * Checks if the given designation is valid (i.e. has a related enum value)
-     *
-     * @param s the designation
-     * @return true, if valid; false, otherwise
-     */
-    static constexpr bool is_valid(string_t s) {
-        auto found = std::find_if(
-            std::begin(TRAITS::map), std::end(TRAITS::map), [&](const auto& item) { return item.second == s; });
-        return found != std::end(TRAITS::map);
-    }
-
-    /**
-     * The number of mapped enum values
-     */
-    static const size_t size = TRAITS::size;
-
-    /**
-     * The vector of mapped enum values
-     */
-    static auto enums() {
-        std::vector<E> result;
-        result.reserve(TRAITS::size);
-        std::transform(std::begin(TRAITS::map),
-                       std::end(TRAITS::map),
-                       std::back_inserter(result),
-                       [](const auto& item) { return item.first; });
-        return result;
-    }
-
-    /**
-     * The vector of mapped designations
-     */
-    static auto designations() {
-        std::vector<std::string> result;
-        result.reserve(TRAITS::size);
-        std::transform(std::begin(TRAITS::map),
-                       std::end(TRAITS::map),
-                       std::back_inserter(result),
-                       [](const auto& item) { return std::string{item.second}; });
-
-        return result;
-    }
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_Enumerate_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Extract.cpp 5.13.0-1/ACore/src/ecflow/core/Extract.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Extract.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Extract.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Extract.hpp"
-
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
-
-#include "ecflow/core/Converter.hpp"
-
-// #define DEBUG_PARSER 1
-
-using namespace std;
-using namespace boost;
-using namespace boost::gregorian;
-
-template <class T>
-ostream& operator<<(ostream& os, const vector<T>& v) {
-    copy(v.begin(), v.end(), ostream_iterator<T>(cout, ","));
-    return os;
-}
-
-bool Extract::pathAndName(const std::string& token, std::string& path, std::string& name) {
-    if (token.empty())
-        return false;
-
-    size_t colonPos = token.find_first_of(':');
-    if (colonPos == string::npos) {
-        if (token[0] == '/') {
-            path = token; // token of the form /a/b/c, ie no name
-        }
-        else {
-            name = token;
-        }
-    }
-    else {
-        path = token.substr(0, colonPos);
-        name = token.substr(colonPos + 1);
-    }
-
-    return true;
-}
-
-bool Extract::split_get_second(const std::string& str, std::string& ret, char separator) {
-    // HH:MM
-    // return MM;
-    size_t colonPos = str.find_first_of(separator);
-    if (colonPos == string::npos)
-        return false;
-    ret = str.substr(colonPos + 1);
-    return true;
-}
-
-/// extract integer or throw an std::runtime exception on failure
-int Extract::theInt(const std::string& token, const std::string& errorMsg) {
-    int the_int = -1;
-    try {
-        the_int = ecf::convert_to<int>(token);
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error(errorMsg);
-    }
-    return the_int;
-}
-
-/// extract YMD, integer of the form yyyymmdd
-int Extract::ymd(const std::string& ymdToken, std::string& errorMsg) {
-    if (ymdToken.size() != 8)
-        throw std::runtime_error(errorMsg + " YMD must be 8 characters i.e yyyymmdd");
-
-    // Use date lib to check YMD
-    try {
-        (void)boost::gregorian::date(from_undelimited_string(ymdToken));
-    }
-    catch (std::exception& e) {
-        errorMsg += "\n";
-        errorMsg += e.what();
-        throw std::runtime_error(errorMsg + " YMD is not a valid date");
-    }
-
-    return theInt(ymdToken, errorMsg);
-}
-
-int Extract::optionalInt(const std::vector<std::string>& tokens,
-                         int pos,
-                         int defaultValue,
-                         const std::string& errorMsg) {
-    int the_int = defaultValue;
-    if (static_cast<int>(tokens.size()) >= pos + 1 && tokens[pos][0] != '#') {
-
-        the_int = theInt(tokens[pos], errorMsg);
-    }
-    return the_int;
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Extract.hpp 5.13.0-1/ACore/src/ecflow/core/Extract.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Extract.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Extract.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Extract_HPP
-#define ecflow_core_Extract_HPP
-
-#include <string>
-#include <vector>
-
-class Extract {
-public:
-    // Disable default construction
-    Extract() = delete;
-    // Disable copy (and move) semantics
-    Extract(const Extract&)                  = delete;
-    const Extract& operator=(const Extract&) = delete;
-
-    ///
-    /// Extract path and name from given token.
-    ///
-    /// Given
-    ///   "/suite/family:obj", extracts path = "/suite/family", and name = "obj"
-    ///   "/suite/family", extracts path = "/suite/family", and name = ""
-    ///   "obj", extracts path = "", and name = "obj"
-    /// @returns true if extraction succeeded; false, otherwise
-    ///
-    static bool pathAndName(const std::string& token, std::string& path, std::string& name);
-
-    ///
-    /// Extract 2nd token from the given string (considering provided separator)
-    ///
-    /// Given str = "HH:MM", extracts ret = "MM"
-    ///
-    /// @returns true if extraction succeeded; false, otherwise
-    ///
-    static bool split_get_second(const std::string& str, std::string& ret, char separator = ':');
-
-    ///
-    /// Extract an integer from the given token
-    ///
-    /// @returns the extracted integer
-    /// @throws std::runtime_error if extractions fails, with the provided error message included in exception message
-    ///
-    static int theInt(const std::string& token, const std::string& errorMsg);
-
-    ///
-    /// Extract YMD integer, of the form yyyymmdd, from the given token
-    ///
-    /// @throws std::runtime_error if extractions fails, with the provided error message included in exception message
-    ///
-    static int ymd(const std::string& ymdToken, std::string& errorMsg);
-
-    ///
-    /// Extract (optional) integer, from token in index pos
-    ///
-    /// Notice: when first character of selected token is '#', the return is the provided default value
-    ///
-    /// Example of tokens:
-    ///   ["repeat", "integer", "variable", "1", "2", "#a", "comment"]
-    ///    - extracting from "repeat", "integer", "variable", or "comment" throws std::runtime_error
-    ///    - extracting from "1", returns 1
-    ///    - extracting from "2", returns 3
-    ///    - extracting from "#a", returns the given default value
-    ///   ["repeat", "integer", "variable", "1", "2", "#", "a", "comment"]
-    ///    - extracting from "repeat", "integer", "variable", "a", or "comment" throws std::runtime_error
-    ///    - extracting from "1", returns 1
-    ///    - extracting from "2", returns 3
-    ///    - extracting from "#", returns the given default value
-    ///
-    /// @returns the extracted integer, if extraction succeeded; default value if selected token starts with '#'
-    /// @throws std::runtime_error if extractions fails, with the provided error message included in exception message
-    ///
-    static int optionalInt(const std::vector<std::string>& tokens, int pos, int defValue, const std::string& errorMsg);
-};
-
-#endif /* ecflow_core_Extract_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/File.cpp 5.13.0-1/ACore/src/ecflow/core/File.cpp
--- 5.12.4-1/ACore/src/ecflow/core/File.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/File.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1131 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/File.hpp"
-
-#include <fstream>
-#include <stdexcept>
-
-#include <boost/filesystem.hpp>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/NodePath.hpp"
-#include "ecflow/core/Str.hpp"
-
-#ifdef CMAKE
-    #include "ecflow/core/ecflow_source_build_dir.h"
-#endif
-
-using namespace std;
-using namespace boost;
-
-// #define DEBUG_SERVER_PATH 1
-// #define DEBUG_CLIENT_PATH 1
-
-namespace ecf {
-
-size_t File::MAX_LINES() {
-    return 10000;
-}
-const std::string& File::JOB_EXTN() {
-    static const std::string JOB_EXTN = ".job";
-    return JOB_EXTN;
-}
-const std::string& File::MAN_EXTN() {
-    static const std::string MAN_EXTN = ".man";
-    return MAN_EXTN;
-}
-const std::string& File::USR_EXTN() {
-    static const std::string USR_EXTN = ".usr";
-    return USR_EXTN;
-}
-const std::string& File::ECF_EXTN() {
-    static const std::string ECF_EXTN = ".ecf";
-    return ECF_EXTN;
-}
-
-/// Search for the file, in $PATH return the first path that matches or an empty file, if not
-std::string File::which(const std::string& file) {
-    std::string env_paths = getenv("PATH");
-    if (!env_paths.empty()) {
-        std::string path;
-        std::vector<std::string> paths;
-        Str::split(env_paths, paths, ":");
-        size_t path_size = paths.size();
-        for (size_t i = 0; i < path_size; ++i) {
-            path.clear();
-            path = paths[i];
-            path += '/';
-            path += file;
-            try {
-                if (fs::exists(path)) {
-                    return paths[i];
-                }
-            }
-            catch (...) {
-                // could be permission denied.
-            }
-        }
-    }
-    return std::string();
-}
-
-std::string File::getExt(const std::string& file) {
-    size_t i = file.rfind('.', file.length());
-    if (i != std::string::npos) {
-        return file.substr(i + 1);
-    }
-    return string();
-}
-
-void File::replaceExt(std::string& file, const std::string& newExt) {
-    string::size_type i = file.rfind('.', file.length());
-    if (i != string::npos)
-        file.replace(i + 1, newExt.length(), newExt);
-}
-
-bool File::splitFileIntoLines(const std::string& filename, std::vector<std::string>& lines, bool ignoreEmptyLine) {
-    std::ifstream the_file(filename.c_str(), std::ios_base::in);
-    if (!the_file) {
-        return false;
-    }
-    lines.reserve(lines.size() + 100);
-
-    // Note if we use: while( getline( theEcfFile, line)), then we will miss the *last* *empty* line
-
-    //	int i = 0;
-    string line;
-    while (std::getline(the_file, line)) {
-        //		i++;
-        //		cout << i << ": " << line << "\n";
-        if (ignoreEmptyLine && line.empty())
-            continue;
-        lines.push_back(line); // c++11 - lines.emplace_back(std::move(line)) - actually slower, hence left
-    }
-
-    //	 METHOD1
-    //	 Note Another way to split lines of a file was to use a tokenizer.
-    //	 Much slower ~ 2.5 slower,
-    //	ifstream ifs(filename.c_str());
-    //	if (!ifs) return false;
-    //
-    //	// Note: ss.str() returns a temporary std::string.
-    //	// boost::tokenizer stores a reference to the string.
-    //	// The temporary string is destroyed and tokenizer is left with a dangling reference.
-    //	// hence take a copy
-    //	std::stringstream ss;  ss << ifs.rdbuf();  // Read the whole file into a string
-    //	std::string theFileAsString = ss.str();    // take a copy as ss.str() returns a temporary
-    //	//                                         // while tokenizer stores a reference
-    //	if (ignoreEmptyLine) {
-    //	   char_separator<char> sep("\n",0,boost::drop_empty_tokens);
-    //	   typedef boost::tokenizer<boost::char_separator<char> > tokenizer;
-    //	   tokenizer tokens(theFileAsString, sep);
-    //	   std::copy(tokens.begin(), tokens.end(), back_inserter(lines));
-    //	}
-    //	else {
-    //	   char_separator<char> sep("\n",0,boost::keep_empty_tokens);
-    //	   typedef boost::tokenizer<boost::char_separator<char> > tokenizer;
-    //	   tokenizer tokens(theFileAsString, sep);
-    //	   std::copy(tokens.begin(), tokens.end(), back_inserter(lines));
-    //	}
-
-    // METHOD 2:
-    // Note: The implementation below is 2.5 times slower
-    //	std::ifstream ifs(filename.c_str());
-    //	if (!ifs) return false;
-    //
-    //	std::istreambuf_iterator<char> file_iter(ifs);
-    //	std::istreambuf_iterator<char> end_of_stream;
-    //
-    //	typedef boost::tokenizer<boost::char_separator<char>,
-    //	std::istreambuf_iterator<char> > tokenizer;
-    //
-    //	boost::char_separator<char> sep("\n");
-    //	tokenizer tokens(file_iter,end_of_stream, sep);
-    // std::copy(tokens.begin(), tokens.end(), back_inserter(lines));
-
-    // The current implementation is 2.5 times faster than method 1, and ~4 times faster than method 2
-    return true;
-}
-
-std::string
-File::get_last_n_lines(const std::string& filename, int last_n_lines, size_t& file_size, std::string& error_msg) {
-    file_size = 0;
-    if (last_n_lines <= 0)
-        return string();
-
-    std::ifstream source(filename.c_str(), std::ios_base::in);
-    if (!source) {
-        error_msg = "File::get_last_n_lines: Could not open file " + filename;
-        error_msg += " (";
-        error_msg += strerror(errno);
-        error_msg += ")";
-        return string();
-    }
-
-    size_t const granularity = 100 * last_n_lines;
-    source.seekg(0, std::ios_base::end);
-    file_size = static_cast<size_t>(source.tellg());
-    std::vector<char> buffer;
-    int newlineCount = 0;
-    while (source && buffer.size() != file_size && newlineCount < last_n_lines) {
-        buffer.resize(std::min(buffer.size() + granularity, file_size));
-        source.seekg(-static_cast<std::streamoff>(buffer.size()), std::ios_base::end);
-        source.read(&(buffer.front()), buffer.size());
-        newlineCount = std::count(buffer.begin(), buffer.end(), '\n');
-    }
-
-    auto start = buffer.begin();
-    while (newlineCount > last_n_lines) {
-        start = std::find(start, buffer.end(), '\n') + 1;
-        --newlineCount;
-    }
-
-    // std::vector<char>::iterator end = remove( start, buffer.end(), '\r' ); // for windows
-    return std::string(start, buffer.end());
-}
-
-std::string File::get_last_n_lines(const std::string& filename, int last_n_lines, std::string& error_msg) {
-    size_t file_size = 0;
-    return File::get_last_n_lines(filename, last_n_lines, file_size, error_msg);
-}
-
-std::string File::get_first_n_lines(const std::string& filename, int n_lines, std::string& error_msg) {
-    if (n_lines <= 0)
-        return string();
-
-    std::ifstream source(filename.c_str(), std::ios_base::in);
-    if (!source) {
-        error_msg = "File::get_first_n_lines: Could not open file " + filename;
-        error_msg += " (";
-        error_msg += strerror(errno);
-        error_msg += ")";
-        return string();
-    }
-
-    std::string ret;
-    ret.reserve(1024);
-    std::string line;
-
-    int count = 0;
-    while (std::getline(source, line) && count < n_lines) {
-
-        ret += line;
-        ret += "\n";
-        count++;
-    }
-
-    return ret;
-}
-
-/// Opens the file and returns the contents
-bool File::open(const std::string& filePath, std::string& contents) {
-    std::ifstream infile(filePath.c_str(), std::ios_base::in);
-    if (!infile)
-        return false;
-
-    std::ostringstream temp;
-    temp << infile.rdbuf();
-    contents = temp.str();
-    return true;
-}
-
-bool File::create(const std::string& filename, const std::vector<std::string>& lines, std::string& errorMsg) {
-    // For very large file. This is about 1 second quicker. Then using streams
-    // See Test: TestFile.cpp:test_file_create_perf
-    FILE* theFile = fopen(filename.c_str(), "w");
-    if (theFile == nullptr) {
-        std::stringstream ss;
-        ss << "Could not create file '" << filename << " (" << strerror(errno) << "'\n";
-        errorMsg += ss.str();
-        return false;
-    }
-    size_t size = lines.size();
-    for (size_t i = 0; i < size; ++i) {
-        if (i != 0) {
-            if (fputs("\n", theFile) == EOF) {
-                std::stringstream ss;
-                ss << "Could not write to file '" << filename << "' (" << strerror(errno) << ")\n";
-                errorMsg += ss.str();
-                fclose(theFile);
-                return false;
-            }
-        }
-        if (fputs(lines[i].c_str(), theFile) == EOF) {
-            std::stringstream ss;
-            ss << "Could not write to file '" << filename << "' (" << strerror(errno) << ")\n";
-            errorMsg += ss.str();
-            fclose(theFile);
-            return false;
-        }
-    }
-    fclose(theFile);
-
-    //	std::ofstream theFile( filename.c_str() );
-    //	if ( !theFile ) {
-    //		/// Could be: [ no permissions | file system full | locked by another process ]
-    // 		std::stringstream ss;
-    //		ss << "Could not create file '" << filename << "'\n";
-    //		errorMsg += ss.str();
-    //		return false;
-    //	}
-    //	size_t size = lines.size();
-    //	for (size_t i = 0; i < size; ++i) {
-    //		if (i != 0) theFile << "\n";
-    //		theFile << lines[i];
-    //	}
-    //	if (!theFile.good()) {
-    //      std::stringstream ss;
-    //      ss << "Could not write to file '" << filename << "'\n";
-    //      errorMsg += ss.str();
-    //      theFile.close();
-    //      return false;
-    //	}
-    //	theFile.close();
-
-    return true;
-}
-
-bool File::create(const std::string& filename, const std::string& contents, std::string& errorMsg) {
-    std::ofstream theFile(filename.c_str());
-    if (!theFile) {
-        std::stringstream ss;
-        ss << "Could not create file '" << filename << "' (" << strerror(errno) << ")\n";
-        errorMsg += ss.str();
-        return false;
-    }
-
-    theFile << contents;
-    if (!theFile.good()) {
-        std::stringstream ss;
-        ss << "Could not write to file '" << filename << "' (" << strerror(errno) << ")\n";
-        errorMsg += ss.str();
-        theFile.close();
-        return false;
-    }
-    theFile.close();
-
-    // This is actually 12% slower for large file:
-    //	FILE * theFile = fopen (filename.c_str(),"w");
-    //	if (theFile==NULL) {
-    //		std::stringstream ss;
-    //		ss << "Could not create file '" << filename << "'\n";
-    //		errorMsg += ss.str();
-    //		return false;
-    //	}
-    //   if (fputs(contents.c_str(),theFile) == EOF) {
-    //      std::stringstream ss;
-    //      ss << "Could not write to file '" << filename << "'\n";
-    //      errorMsg += ss.str();
-    //      fclose (theFile);
-    //      return false;
-    //   }
-    //  	fclose (theFile);
-    return true;
-}
-
-std::string File::stream_error_condition(const std::ios& stream) {
-    std::string msg;
-    if (stream.fail())
-        msg += " Logical error on i/o operation";
-    if (stream.bad())
-        msg += " Read/Writing error on i/o operation";
-    if (stream.eof())
-        msg += " End-of-File reached on input operation";
-    if (errno) {
-        msg += ", errno:";
-        msg += std::string(strerror(errno));
-    }
-    return msg;
-}
-
-bool File::find(const fs::path& dir_path,     // from this directory downwards,
-                const std::string& file_name, // search for this name,
-                fs::path& path_found          // placing path here if found
-) {
-    //	std::cout << "Searching '" << dir_path << "' for  " << file_name  << "\n";
-    if (!fs::exists(dir_path))
-        return false;
-
-    fs::directory_iterator end_itr; // default construction yields past-the-end
-    for (fs::directory_iterator itr(dir_path); itr != end_itr; ++itr) {
-
-        if (fs::is_directory(itr->status())) {
-
-            if (File::find(itr->path(), file_name, path_found))
-                return true;
-        }
-        else if (itr->path().filename() == file_name) // see below
-        {
-            path_found = itr->path();
-            return true;
-        }
-    }
-    return false;
-}
-
-void File::findAll(const fs::path& dir_path,          // from this directory downwards
-                   const std::string& file_name,      // search for this name,
-                   std::vector<fs::path>& paths_found // placing path here if found
-) {
-    if (!fs::exists(dir_path))
-        return;
-
-    fs::directory_iterator end_itr; // default construction yields past-the-end
-    for (fs::directory_iterator itr(dir_path); itr != end_itr; ++itr) {
-
-        if (fs::is_directory(itr->status())) {
-
-            findAll(itr->path(), file_name, paths_found);
-        }
-        else if (itr->path().filename() == file_name) // see below
-        {
-            paths_found.push_back(itr->path());
-        }
-    }
-}
-
-void File::find_files_with_extn(const fs::path& dir_path,          // In this directory
-                                const std::string& extn,           // find files matching this extension
-                                std::vector<fs::path>& paths_found // placing path here if found
-) {
-    if (!fs::exists(dir_path)) {
-        return;
-    }
-    fs::directory_iterator end_itr; // default construction yields past-the-end
-    for (fs::directory_iterator itr(dir_path); itr != end_itr; ++itr) {
-        if (fs::is_directory(itr->status()))
-            continue;
-        else if (itr->path().extension() == extn) // see below
-        {
-            paths_found.push_back(itr->path());
-        }
-    }
-}
-
-std::string File::findPath(const fs::path& dir_path,     // from this directory downwards
-                           const std::string& file_name, // search for this name,
-                           const std::string& leafDir    // path must contain this string
-) {
-    std::vector<fs::path> paths;
-    File::findAll(dir_path, file_name, paths);
-    if (!paths.empty()) {
-
-        // find the path that has leafDir in it.
-        for (fs::path path : paths) {
-            std::string thePath = path.string();
-            if (thePath.rfind(leafDir) != std::string::npos)
-                return thePath;
-        }
-    }
-    return std::string();
-}
-
-std::string File::findPath(const fs::path& dir_path,              // from this directory downwards
-                           const std::string& file_name,          // search for this name,
-                           const std::vector<std::string>& tokens // path must contain all these tokens
-) {
-    std::vector<fs::path> paths;
-    File::findAll(dir_path, file_name, paths);
-    if (!paths.empty()) {
-
-        // find the path that has all the tokens specified by the vector tokens
-        for (fs::path path : paths) {
-            std::string thePath = path.string();
-            size_t matches      = 0;
-            for (const std::string& required_path_tokens : tokens) {
-                if (thePath.rfind(required_path_tokens) != std::string::npos)
-                    matches++;
-            }
-            if (matches == tokens.size())
-                return thePath;
-        }
-    }
-    return std::string();
-}
-
-// #define INTEL_DEBUG_ME 1
-bool File::createMissingDirectories(const std::string& pathToFileOrDir) {
-#ifdef INTEL_DEBUG_ME
-    std::cout << "File::createMissingDirectories  " << pathToFileOrDir << std::endl;
-#endif
-    if (pathToFileOrDir.empty())
-        return false;
-
-    // Avoid making unnecessary system calls, by checking to see if directory exists first
-    fs::path fs_path(pathToFileOrDir);
-    if (fs_path.extension().empty()) {
-
-#ifdef INTEL_DEBUG_ME
-        std::cout << "   pure directory no extension" << std::endl;
-#endif
-        // pure directory
-        if (fs::exists(pathToFileOrDir)) {
-
-#ifdef INTEL_DEBUG_ME
-            std::cout << "   " << pathToFileOrDir << " already exists " << std::endl;
-#endif
-
-            return true;
-        }
-    }
-    else {
-
-#ifdef INTEL_DEBUG_ME
-        std::cout << "   pure directory *has* extension" << std::endl;
-#endif
-        // could be /tmp/fred/sms.job, see if /tmp/fred exists
-        if (fs::exists(fs_path.parent_path())) {
-
-#ifdef INTEL_DEBUG_ME
-            std::cout << "   " << pathToFileOrDir << " already exists " << std::endl;
-#endif
-            return true;
-        }
-    }
-
-    std::vector<std::string> thePath;
-    NodePath::split(pathToFileOrDir, thePath);
-    try {
-        if (!thePath.empty()) {
-
-#ifdef INTEL_DEBUG_ME
-            std::cout << "   last file " << thePath.back() << std::endl;
-#endif
-
-            // pathToFileOrDir is of form: /tmp/fred/sms.job
-            //   we should only create directories for /tmp/fred
-            if (thePath.back().find(".") != std::string::npos) {
-                // assume the last token represents a file, hence don't create a directory
-#ifdef INTEL_DEBUG_ME
-                std::cout << "   last file " << thePath.back() << " has a *dot* ignoring " << std::endl;
-#endif
-                thePath.pop_back();
-            }
-
-            std::string pathToCreate;
-
-            // if original path had leading slash then add it here, to preserve path
-            if (pathToFileOrDir[0] == '/')
-                pathToCreate += Str::PATH_SEPERATOR();
-
-            for (const auto& i : thePath) {
-                pathToCreate += i;
-                if (!fs::exists(pathToCreate)) {
-#ifdef INTEL_DEBUG_ME
-                    std::cout << "   " << pathToCreate << " does not exist, creating directory " << std::endl;
-#endif
-                    fs::create_directory(pathToCreate);
-                }
-                pathToCreate += Str::PATH_SEPERATOR();
-            }
-        }
-        else {
-#ifdef INTEL_DEBUG_ME
-            std::cout << "   NO path component in " << pathToFileOrDir << std::endl;
-#endif
-
-            if (pathToFileOrDir.find(".") != std::string::npos) {
-                // assume represents a file, hence don't create a directory fred.job1
-#ifdef INTEL_DEBUG_ME
-                std::cout << "   assuming " << pathToFileOrDir
-                          << " is a file, found a dot, returning without creating dir " << std::endl;
-#endif
-                return true;
-            }
-
-            // assume is a dir
-#ifdef INTEL_DEBUG_ME
-            std::cout << "   about to create dir " << pathToFileOrDir << std::endl;
-#endif
-
-            fs::create_directory(pathToFileOrDir);
-        }
-    }
-    catch (const std::exception& ex) {
-#ifdef INTEL_DEBUG_ME
-        std::cout << "   Exception " << ex.what() << " could not create dir " << pathToFileOrDir << std::endl;
-#endif
-        return false;
-    }
-    return true;
-}
-
-/// Create directories the boost way, with additional check to see if directories exist first
-bool File::createDirectories(const std::string& pathToDir) {
-    if (pathToDir.empty())
-        return false;
-
-    try {
-        if (fs::exists(pathToDir))
-            return true;
-        return fs::create_directories(pathToDir);
-    }
-    catch (std::exception&) {
-    }
-    return false;
-}
-
-/// Returns the difference between 2 files.
-std::string File::diff(const std::string& file,
-                       const std::string& file2,
-                       const std::vector<std::string>& ignoreVec,
-                       std::string& errorMsg,
-                       bool ignoreBlanksLine) {
-    if (!fs::exists(file)) {
-        errorMsg += "First argument File " + file + " does not exist";
-        return std::string();
-    }
-    if (!fs::exists(file2)) {
-        errorMsg += "Second argument File " + file2 + " does not exist";
-        return std::string();
-    }
-
-    std::vector<std::string> fileLines;
-    std::vector<std::string> file2Lines;
-
-    if (!splitFileIntoLines(file, fileLines, ignoreBlanksLine)) {
-        errorMsg += "First argument File " + file + " could not be opened : " + strerror(errno);
-        return std::string();
-    }
-    if (!splitFileIntoLines(file2, file2Lines, ignoreBlanksLine)) {
-        errorMsg += "Second argument File " + file2 + " could not be opened : " + strerror(errno);
-        return std::string();
-    }
-
-    if (fileLines != file2Lines) {
-        std::stringstream ss;
-        if (fileLines.size() != file2Lines.size())
-            ss << "Expected size " << file2Lines.size() << " but found " << fileLines.size() << "\n";
-
-        for (size_t i = 0; i < fileLines.size() || i < file2Lines.size(); ++i) {
-
-            if (i < fileLines.size() && i < file2Lines.size()) {
-
-                if (fileLines[i] != file2Lines[i]) {
-                    bool doIgnore = false;
-                    for (const std::string& ignore : ignoreVec) {
-                        if (fileLines[i].find(ignore) != std::string::npos ||
-                            file2Lines[i].find(ignore) != std::string::npos) {
-                            doIgnore = true;
-                            break;
-                        }
-                    }
-                    if (doIgnore)
-                        continue;
-                    ss << "Mismatch at " << i << "(" << fileLines[i] << ")   ---->   (" << file2Lines[i] << ")\n";
-                }
-                //				else {
-                //					ss << "            " << i << " (" << fileLines[i] << ")   ---->
-                //("
-                //<< file2Lines[i] << ")\n";
-                //				}
-            }
-            else {
-                ss << "Mismatch at " << i;
-                if (i < fileLines.size())
-                    ss << " (" << fileLines[i] << ")   ";
-                else
-                    ss << " ( ---- )   ";
-
-                if (i < file2Lines.size())
-                    ss << "(" << file2Lines[i] << ")\n";
-                else
-                    ss << "( --- )\n";
-            }
-        }
-        return ss.str();
-    }
-    return std::string();
-}
-
-std::string
-File::backwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn) {
-    // Do a backward search of rootPath + nodePath
-    // If task path is of the form /suite/family/family2/task, then we keep
-    // on consuming the first path token this should leave:
-    //   	<root-path>/suite/family/family2/task.ecf
-    //   	<root-path>/family/family2/task.ecf
-    //  	<root-path>/family2/task.ecf
-    //   	<root-path>/task.ecf
-
-    vector<std::string> nodePathTokens;
-    NodePath::split(nodePath, nodePathTokens);
-    LOG_ASSERT(!nodePathTokens.empty(), "");
-
-    std::string leafName; // i.e. task in the example above
-    if (!nodePathTokens.empty())
-        leafName = nodePathTokens[nodePathTokens.size() - 1];
-
-#ifdef DEBUG_TASK_LOCATION
-    cout << "backwardSearch Node " << nodePath << " using root path " << rootPath
-         << " nodePathTokens.size() = " << nodePathTokens.size() << "\n";
-#endif
-    while (nodePathTokens.size() > 0) {
-
-        // Reconstitute the path
-        std::string path = NodePath::createPath(nodePathTokens);
-        path += fileExtn; // .ecf, .man , etc
-
-        std::string combinedPath = rootPath;
-        combinedPath += path;
-
-        try {
-            if (fs::exists(combinedPath)) {
-#ifdef DEBUG_TASK_LOCATION
-                cout << "backwardSearch Node " << nodePath << " the path " << combinedPath << " exists\n";
-#endif
-                return combinedPath;
-            }
-#ifdef DEBUG_TASK_LOCATION
-            else
-                cout << " backwardSearch Node " << nodePath << " the path " << combinedPath << " DOEST NOT EXIST\n";
-#endif
-        }
-        catch (fs::filesystem_error& e) {
-#ifdef DEBUG_TASK_LOCATION
-            std::cout << "Task::backwardSearch Caught exception for fs::exists('" << combinedPath << "')\n"
-                      << e.what() << "\n";
-#endif
-        }
-
-        nodePathTokens.erase(nodePathTokens.begin()); // consume first path token
-    }
-
-    // Look for file in the root path
-    std::string ecf_file  = leafName + fileExtn;
-    fs::path ecf_filePath = fs::path(fs::path(rootPath) / ecf_file);
-    if (fs::exists(ecf_filePath)) {
-#ifdef DEBUG_TASK_LOCATION
-        std::cout << "backwardSearch Node " << leafName << " Found " << ecf_file << " in root path '" << rootPath
-                  << "'\n";
-#endif
-        std::string result = ecf_filePath.string(); // is returned by reference hence must take a copy
-        return result;
-    }
-
-    // failed to find file via backward search
-    return string();
-}
-
-std::string File::forwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn) {
-    /// Do a forward search of rootPath + nodePath + fileExtn
-    /// If task path if of the form /suite/family/family2/task, then we keep
-    /// on consuming the last path token this should leave:
-    ///   <root-path>/suite/family/family2/task.ecf
-    ///   <root-path>/suite/family/task.ecf
-    ///   <root-path>/suite/task.ecf
-    ///   <root-path>/task.ecf
-
-    vector<std::string> nodePathTokens;
-    NodePath::split(nodePath, nodePathTokens);
-    LOG_ASSERT(!nodePathTokens.empty(), "");
-
-    std::string leafName;
-    if (!nodePathTokens.empty())
-        leafName = nodePathTokens[nodePathTokens.size() - 1];
-
-#ifdef DEBUG_TASK_LOCATION
-    cout << "forwardSearch Node " << nodePath << " using root path " << rootPath
-         << " nodePathTokens.size() = " << nodePathTokens.size() << "\n";
-#endif
-    while (nodePathTokens.size() > 0) {
-
-        // Reconstitute the path
-        std::string path = NodePath::createPath(nodePathTokens);
-        path += fileExtn; // .ecf, .man , etc
-
-        std::string combinedPath = rootPath;
-        combinedPath += path;
-
-        try {
-            if (fs::exists(combinedPath)) {
-#ifdef DEBUG_TASK_LOCATION
-                cout << "forwardSearch Node " << nodePath << " the path " << combinedPath << " exists\n";
-#endif
-                return combinedPath;
-            }
-#ifdef DEBUG_TASK_LOCATION
-            else
-                cout << " forwardSearch Node " << nodePath << " the path " << combinedPath << " DOEST NOT EXIST\n";
-#endif
-        }
-        catch (fs::filesystem_error& e) {
-#ifdef DEBUG_TASK_LOCATION
-            std::cout << "Task::forwardSearch Caught exception for fs::exists('" << combinedPath << "')\n"
-                      << e.what() << "\n";
-#endif
-        }
-
-        if (nodePathTokens.size() >= 2) {
-            nodePathTokens.erase(nodePathTokens.begin() + nodePathTokens.size() -
-                                 2); // consume one from last path token
-        }
-        else {
-            nodePathTokens.erase(nodePathTokens.begin());
-        }
-    }
-
-    // Look for file in the root path
-    std::string ecf_file  = leafName + fileExtn;
-    fs::path ecf_filePath = fs::path(fs::path(rootPath) / ecf_file);
-
-    try {
-        if (fs::exists(ecf_filePath)) {
-#ifdef DEBUG_TASK_LOCATION
-            std::cout << "Task::forwardSearch Node " << leafName << " Found " << ecf_file << " in root path '"
-                      << rootPath << "'\n";
-#endif
-            std::string result = ecf_filePath.string(); // is returned by reference hence must take a copy
-            return result;
-        }
-    }
-    catch (fs::filesystem_error& e) {
-#ifdef DEBUG_TASK_LOCATION
-        std::cout << "Task::forwardSearch Caught exception for root_path fs::exists('" << ecf_filePath << "')\n"
-                  << e.what() << "\n";
-#endif
-    }
-
-    // failed to find file via forward search
-    return string();
-}
-
-// Remove a directory recursively ****
-bool File::removeDir(const fs::path& p) {
-    try {
-        fs::directory_iterator end;
-        for (fs::directory_iterator it(p); it != end; ++it) {
-            if (fs::is_directory(*it)) {
-                if (!removeDir(*it)) {
-                    return false;
-                }
-            }
-            else {
-                fs::remove(*it);
-            }
-        }
-    }
-    catch (fs::filesystem_error& e) {
-        return false;
-    }
-
-    // Finally remove dir itself
-    fs::remove(p);
-
-    return true;
-}
-
-// =======================================================================================================
-// bjam
-// =======================================================================================================
-#ifndef CMAKE
-
-static std::string bjam_workspace_dir() {
-    // We need the *SAME* location so that different process find the same file. Get to the workspace directory
-    auto current_path = fs::current_path();
-    std::string stem  = current_path.stem().string();
-    int count         = 0;
-    while (stem.find("ecflow") == std::string::npos) {
-        current_path = current_path.parent_path();
-        stem         = current_path.stem().string();
-        count++;
-        if (count == 100) {
-            char* workspace = getenv("WK");
-            if (workspace == NULL) {
-                throw std::runtime_error("File::bjam_workspace_dir() failed to find ecflow in a directory name, up the "
-                                         "directory tree and WK undefined");
-            }
-            std::string the_workspace_dir = workspace;
-            return the_workspace_dir;
-        }
-    }
-    std::string the_workspace_dir = current_path.string(); // cos string is returned by reference
-    return the_workspace_dir;
-}
-
-static std::string find_bjam_ecf_server_path() {
-    #ifdef DEBUG_SERVER_PATH
-    cout << " File::find_ecf_server_path() using bjam\n";
-    #endif
-
-    // bjam uses in source tree, for build, which is in the workspace dir
-    std::string bin_dir = bjam_workspace_dir() + "/Server/bin/";
-
-    #ifdef DEBUG_SERVER_PATH
-    cout << "  Searching under: " << bin_dir << "\n";
-    #endif
-
-    // We need to take into account that on linux, we may have the GNU and CLANG executables
-    // Hence we need to distinguish between them.
-    std::vector<std::string> required_path_tokens;
-
-    // We have 3 variants debug,release,profile
-    #ifdef DEBUG
-
-    required_path_tokens.push_back(std::string("debug"));
-        #if defined(__clang__)
-    required_path_tokens.push_back(std::string("clang"));
-        #endif
-
-    return File::findPath(bin_dir, Ecf::SERVER_NAME(), required_path_tokens);
-
-    #else
-
-    required_path_tokens.push_back(std::string("release"));
-        #if defined(__clang__)
-    required_path_tokens.push_back(std::string("clang"));
-        #endif
-
-    std::string path = File::findPath(bin_dir, Ecf::SERVER_NAME(), required_path_tokens);
-    if (path.empty()) {
-
-        required_path_tokens.clear();
-        required_path_tokens.push_back(std::string("profile"));
-        #if defined(__clang__)
-        required_path_tokens.push_back(std::string("clang"));
-        #endif
-
-        path = File::findPath(bin_dir, Ecf::SERVER_NAME(), required_path_tokens);
-    }
-    return path;
-    #endif
-}
-
-static std::string find_bjam_ecf_client_path() {
-    #ifdef DEBUG_CLIENT_PATH
-    cout << " find_bjam_ecf_client_path \n";
-    #endif
-
-    // Bjam uses, in source build
-    std::string binDir = bjam_workspace_dir() + "/Client/bin/";
-
-    // We need to take into account that on linux, we may have the GNU and CLANG executables
-    // Hence we need to distinguish between them.
-    std::vector<std::string> required_path_tokens;
-
-    // We have 3 variants debug,release,profile
-    #ifdef DEBUG
-
-    required_path_tokens.push_back(std::string("debug"));
-        #if defined(__clang__)
-    required_path_tokens.push_back(std::string("clang"));
-        #endif
-
-    return File::findPath(binDir, Ecf::CLIENT_NAME(), required_path_tokens);
-
-    #else
-
-    required_path_tokens.push_back(std::string("release"));
-        #if defined(__clang__)
-    required_path_tokens.push_back(std::string("clang"));
-        #endif
-
-    std::string path = File::findPath(binDir, Ecf::CLIENT_NAME(), required_path_tokens);
-    if (path.empty()) {
-
-        required_path_tokens.clear();
-        required_path_tokens.push_back(std::string("profile"));
-        #if defined(__clang__)
-        required_path_tokens.push_back(std::string("clang"));
-        #endif
-
-        path = File::findPath(binDir, Ecf::CLIENT_NAME(), required_path_tokens);
-    }
-    return path;
-    #endif
-}
-#endif
-
-std::string File::find_ecf_server_path() {
-#ifdef CMAKE
-    std::string path = CMAKE_ECFLOW_BUILD_DIR;
-    path += "/bin/";
-    path += Ecf::SERVER_NAME();
-
-    #ifdef DEBUG_SERVER_PATH
-    cout << " File::find_ecf_server_path() path = " << path << "\n";
-    #endif
-
-    return path;
-
-#else
-
-    return find_bjam_ecf_server_path();
-#endif
-}
-
-std::string File::find_ecf_client_path() {
-#ifdef CMAKE
-    std::string path = CMAKE_ECFLOW_BUILD_DIR;
-    path += "/bin/";
-    path += Ecf::CLIENT_NAME();
-
-    #ifdef DEBUG_CLIENT_PATH
-    cout << " File::find_ecf_client_path() returning path " << path << "\n";
-    #endif
-
-    return path;
-
-#else
-
-    return find_bjam_ecf_client_path();
-#endif
-}
-
-std::string File::test_data(const std::string& rel_path, const std::string& dir) {
-    std::string test_file;
-    char* work_space = getenv("WK"); // for ecbuild
-    if (work_space != nullptr) {
-        test_file = std::string(work_space);
-        if (!rel_path.empty() && rel_path[0] != '/')
-            test_file += "/";
-        test_file += rel_path;
-    }
-    else {
-        std::string root_source = root_source_dir();
-        if (!root_source.empty()) {
-            test_file = root_source;
-            if (!rel_path.empty() && rel_path[0] != '/')
-                test_file += "/";
-            test_file += rel_path;
-        }
-        else {
-            fs::path current_path = fs::current_path();
-            if (current_path.stem() == dir) {
-
-                // remove first path, expecting "dir/path/path1" remove dir
-                std::string::size_type pos = rel_path.find("/", 1); // skip over any leading /
-                if (pos != std::string::npos) {
-                    test_file +=
-                        rel_path.substr(pos + 1); // skip over '/' to be left with path/path1, making it relative
-                }
-                else {
-                    test_file += rel_path;
-                }
-            }
-            else {
-                test_file += rel_path;
-            }
-        }
-    }
-    return test_file;
-}
-
-std::string File::test_data_in_current_dir(const std::string& rel_path) {
-    auto data = fs::current_path() / rel_path;
-    return fs::absolute(data).string();
-}
-
-std::string File::root_source_dir() {
-#ifdef CMAKE
-    return CMAKE_ECFLOW_SOURCE_DIR;
-#endif
-
-    // bjam
-    fs::path current_path        = fs::current_path();
-    std::string the_current_path = current_path.string();
-    std::string version_cmake    = the_current_path + "/Jamroot.jam";
-    if (fs::exists(version_cmake)) {
-        return the_current_path;
-    }
-
-    std::string stem = current_path.stem().string();
-    int count        = 0;
-    while (stem.find("ecflow") == std::string::npos) {
-        current_path = current_path.parent_path();
-
-        // bjam
-        std::string jamroot_file = std::string(current_path.string()) + "/Jamroot.jam";
-        if (fs::exists(jamroot_file)) {
-            std::string the_root_source_dir =
-                current_path.string(); // cos current_path.string() is returned by reference
-            return the_root_source_dir;
-        }
-
-        stem = current_path.stem().string();
-        count++;
-        if (count == 1000)
-            break;
-    }
-
-    return string();
-}
-
-std::string File::root_build_dir() {
-#ifdef CMAKE
-    return CMAKE_ECFLOW_BUILD_DIR;
-#endif
-
-    fs::path current_path        = fs::current_path();
-    std::string the_current_path = current_path.string();
-
-    // bjam
-    std::string version_cmake = the_current_path + "/Jamroot.jam";
-    if (fs::exists(version_cmake))
-        return the_current_path;
-
-    // cmake
-    std::string cmake_cache = the_current_path + "/CMakeCache.txt";
-    if (fs::exists(cmake_cache))
-        return the_current_path;
-
-    // bjam or cmake
-    std::string stem = current_path.stem().string();
-    int count        = 0;
-    while (stem.find("ecflow") == std::string::npos) {
-        current_path = current_path.parent_path();
-
-        the_current_path = current_path.string(); // cos current_path.string() is returned by reference
-
-        // bjam
-        std::string jamroot_file = the_current_path + "/Jamroot.jam";
-        if (fs::exists(jamroot_file))
-            return the_current_path;
-
-        // cmake
-        std::string cmake_cache1 = the_current_path + "/CMakeCache.txt";
-        if (fs::exists(cmake_cache1))
-            return the_current_path;
-
-        stem = current_path.stem().string();
-        count++;
-        if (count == 1000)
-            throw std::runtime_error(
-                "File::root_build_dir() failed to find ecflow in a directory name, up the directory tree");
-    }
-
-    throw std::runtime_error("File::root_build_dir() failed to find root build directory");
-    return std::string();
-}
-
-int File::max_open_file_allowed() {
-#ifdef OPEN_MAX
-    return OPEN_MAX;
-#else
-    static int max_open_file_allowed_ = -1;
-    if (max_open_file_allowed_ != -1)
-        return max_open_file_allowed_;
-
-    max_open_file_allowed_ = sysconf(_SC_OPEN_MAX);
-    if (max_open_file_allowed_ < 0) {
-        ecf::LogToCout logToCout;
-        std::string msg = "sysconf (_SC_OPEN_MAX) failed ";
-        msg += " (";
-        msg += strerror(errno);
-        msg += ")";
-        log(Log::ERR, msg);
-    }
-    return max_open_file_allowed_;
-#endif
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/File.hpp 5.13.0-1/ACore/src/ecflow/core/File.hpp
--- 5.12.4-1/ACore/src/ecflow/core/File.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/File.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,177 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_File_HPP
-#define ecflow_core_File_HPP
-
-///
-/// \brief This class is used as a helper class for file utilities
-///
-
-#include <ios>
-#include <string>
-#include <vector>
-
-#include "ecflow/core/Filesystem.hpp"
-
-namespace ecf {
-
-class File {
-public:
-    // Disable default construction
-    File() = delete;
-    // Disable copy (and move) semantics
-    File(const File&)            = delete;
-    File& operator=(const File&) = delete;
-
-    static size_t MAX_LINES();            //  max number of lines, default to 10000
-    static const std::string& JOB_EXTN(); // ".job"
-    static const std::string& MAN_EXTN(); // ".man"
-    static const std::string& USR_EXTN(); // ".usr"
-    static const std::string& ECF_EXTN(); // ".ecf"
-
-    /// Search for the file, in $PATH return the first path that matches or an empty file, if not
-    static std::string which(const std::string& file);
-
-    /// expect string of the form ".ecf" or ".sms"
-    static void set_ecf_extn(const std::string&);
-    static const std::string& ecf_extn(); // return ".ecf" | ".sms" | ".py"
-
-    /// return the file extension
-    static std::string getExt(const std::string& file);
-
-    /// replace file extension with a new one
-    static void replaceExt(std::string& file, const std::string& newExt);
-
-    /// returns the input files, split into a vector of string, where each string
-    /// represent a line in the file. returns true if file open ok , false otherwise
-    /// The additional parameter ignoreEmptyLine  can be used to ignore empty lines
-    /// **Always reads _WHOLE_ file. Not suitable for very large files **
-    static bool
-    splitFileIntoLines(const std::string& filename, std::vector<std::string>& lines, bool ignoreEmptyLine = false);
-
-    /// This is suitable for large files. > several gigabytes, since it does load the entire file
-    static std::string get_last_n_lines(const std::string& filename, int last_n_lines, std::string& error_msg);
-    static std::string
-    get_last_n_lines(const std::string& filename, int last_n_lines, size_t& file_size, std::string& error_msg);
-
-    /// returns the first n line of a file, does not read all the file, hence suitable for very large files
-    static std::string get_first_n_lines(const std::string& filename, int n_lines, std::string& error_msg);
-
-    /// Opens the file and returns the contents
-    static bool open(const std::string& filePath, std::string& contents);
-
-    /// Given a file spath, and a vector of lines, creates a file. returns true if success
-    /// else returns false and an error message
-    static bool create(const std::string& filename, const std::vector<std::string>& lines, std::string& errorMsg);
-    static bool create(const std::string& filename, const std::string& contents, std::string& errorMsg);
-
-    /// When a stream fails, uses this construct the error message
-    static std::string stream_error_condition(const std::ios& stream);
-
-    /// recursively look for a file, given a starting directory
-    /// Return the first file that matches
-    /// return true if file found false otherwise
-    static bool find(const fs::path& dir_path,     // from this directory downwards
-                     const std::string& file_name, // search for this name,
-                     fs::path& path_found          // placing path here if found
-    );
-
-    /// recursively look for a file, given a starting directory
-    /// Returns _ALL_ files that match
-    static void findAll(const fs::path& dir_path,          // from this directory downwards
-                        const std::string& file_name,      // search for this name,
-                        std::vector<fs::path>& paths_found // placing path here if found
-    );
-
-    /// Find all files with given extension must include leading .
-    static void find_files_with_extn(const fs::path& dir_path,          // In this directory
-                                     const std::string& extn,           // find files matching this extension
-                                     std::vector<fs::path>& paths_found // placing path here if found
-    );
-
-    /// recursively look for a file, given a starting directory and path token
-    /// Returns the first match found
-    static std::string findPath(const fs::path& dir_path,     // from this directory downwards
-                                const std::string& file_name, // search for this name,
-                                const std::string& leafDir    // path must contain this string
-    );
-
-    static std::string findPath(const fs::path& dir_path,              // from this directory downwards
-                                const std::string& file_name,          // search for this name,
-                                const std::vector<std::string>& tokens // path must contain all these tokens
-    );
-
-    /// Create missing directories. This is *NOT* the same as boost::create_directories
-    /// as that only works with directories. This function assumes that if a "." exist
-    /// in the string it represents a file.
-    /// Hence this function handles:
-    ///   /tmp/some/dir/fred.job       // i.e the directories  /tmp/some/dir/ will be created
-    ///   /tmp/some/dir
-    ///   fred                         // will create the directory fred
-    ///   fred.job                     // just return true
-    static bool createMissingDirectories(const std::string& pathToFileOrDir);
-
-    /// Create directories the boost way, with additional check to see if directories exist first
-    static bool createDirectories(const std::string& pathToDir);
-
-    /// Returns the difference between 2 files.
-    /// Ignore lines that contain strings in the ignoreVec
-    static std::string diff(const std::string& file,
-                            const std::string& file2,
-                            const std::vector<std::string>& ignoreVec,
-                            std::string& errorMsg,
-                            bool ignoreBlanksLine = true);
-
-    /// Do a backward search of rootPath + nodePath + fileExtn
-    /// If task path if of the form /suite/family/family2/task, then we keep
-    /// on consuming the first path token this should leave:
-    ///     <root-path>/suite/family/family2/task.ecf
-    ///     <root-path>/family/family2/task.ecf
-    ///     <root-path>/family2/task.ecf
-    ///      <root-path>/task.ecf
-    /// Returns an empty string if file not found
-    static std::string
-    backwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn);
-
-    /// Do a forward search of rootPath + nodePath + fileExtn
-    /// If task path if of the form /suite/family/family2/task, then we keep
-    /// on consuming the last path token this should leave:
-    ///     <root-path>/suite/family/family2/task.ecf
-    ///     <root-path>/suite/family/task.ecf
-    ///     <root-path>/suite/task.ecf
-    ///     <root-path>/task.ecf
-    /// Returns an empty string if file not found
-    static std::string
-    forwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn);
-
-    // Remove a directory recursively ****
-    static bool removeDir(const fs::path& p);
-
-    // Locate the path to the server exe
-    static std::string find_ecf_server_path();
-
-    // Locate the path to the client exe
-    static std::string find_ecf_client_path();
-
-    // Locate test data
-    static std::string test_data(const std::string& rel_path, const std::string& dir);
-    static std::string test_data_in_current_dir(const std::string& rel_path);
-    // return ecFlow project source code folder
-    static std::string root_source_dir();
-    // return ecFlow project build folder
-    static std::string root_build_dir();
-
-    static int max_open_file_allowed();
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_File_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/File_r.cpp 5.13.0-1/ACore/src/ecflow/core/File_r.cpp
--- 5.12.4-1/ACore/src/ecflow/core/File_r.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/File_r.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/File_r.hpp"
-
-using namespace std;
-using namespace ecf;
-
-File_r::File_r(const std::string& file_name) : file_name_(file_name), fp_(file_name.c_str(), std::ios_base::in) {
-}
-
-File_r::~File_r() {
-    fp_.close();
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/File_r.hpp 5.13.0-1/ACore/src/ecflow/core/File_r.hpp
--- 5.12.4-1/ACore/src/ecflow/core/File_r.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/File_r.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,43 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_File_r_HPP
-#define ecflow_core_File_r_HPP
-
-#include <fstream>
-#include <string>
-
-namespace ecf {
-
-class File_r {
-public:
-    explicit File_r(const std::string& file_name);
-    // Disable copy (and move) semantics
-    File_r(const File_r&)                  = delete;
-    const File_r& operator=(const File_r&) = delete;
-
-    ~File_r();
-
-    bool ok() const { return (fp_) ? true : false; }
-    std::streamoff pos() { return fp_.tellg(); }
-    //  deepcode ignore MissingOpenCheckOnFile: check called externally
-    void setPos(std::streamoff pos) { fp_.seekg(pos, fp_.beg); }
-    bool good() const { return fp_.good(); }
-    void getline(std::string& line) { std::getline(fp_, line); }
-    const std::string& file_name() const { return file_name_; }
-
-private:
-    std::string file_name_;
-    std::ifstream fp_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_File_r_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Filesystem.cpp 5.13.0-1/ACore/src/ecflow/core/Filesystem.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Filesystem.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Filesystem.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-/*
- * Copyright 2023- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "Filesystem.hpp"
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Filesystem.hpp 5.13.0-1/ACore/src/ecflow/core/Filesystem.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Filesystem.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Filesystem.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-/*
- * Copyright 2023- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ECFLOW_CORE_FILESYSTEM_HPP
-#define ECFLOW_CORE_FILESYSTEM_HPP
-
-#include <cassert>
-
-#include <boost/filesystem.hpp>
-
-namespace fs = boost::filesystem;
-
-#endif
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Host.cpp 5.13.0-1/ACore/src/ecflow/core/Host.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Host.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Host.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Host.hpp"
-
-#include <cassert>
-#include <stdexcept>
-#include <unistd.h> // for gethostname
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-Host::Host() {
-    get_host_name();
-}
-
-Host::Host(const std::string& host) : the_host_name_(host) {
-    if (the_host_name_ == Str::LOCALHOST()) {
-        get_host_name();
-    }
-}
-
-void Host::get_host_name() {
-    static std::string the_host_name;
-    if (the_host_name.empty()) {
-        char hostNameArray[255];
-        if (gethostname(hostNameArray, 255) != -1) {
-            the_host_name = string(hostNameArray);
-        }
-        else {
-            throw std::runtime_error("Host::Host() failed, could not get host name?\n");
-        }
-    }
-    the_host_name_ = the_host_name;
-    assert(!the_host_name_.empty());
-}
-
-std::string Host::name() const {
-    return the_host_name_;
-}
-
-std::string Host::ecf_log_file(const std::string& port) const {
-    return prefix_host_and_port(port, Ecf::LOG_FILE());
-}
-
-std::string Host::ecf_checkpt_file(const std::string& port) const {
-    return prefix_host_and_port(port, Ecf::CHECKPT());
-}
-
-std::string Host::ecf_backup_checkpt_file(const std::string& port) const {
-    return prefix_host_and_port(port, Ecf::BACKUP_CHECKPT());
-}
-
-std::string Host::ecf_lists_file(const std::string& port) const {
-    return prefix_host_and_port(port, Str::WHITE_LIST_FILE());
-}
-
-std::string Host::ecf_passwd_file(const std::string& port) const {
-    return prefix_host_and_port(port, Str::ECF_PASSWD());
-}
-
-std::string Host::ecf_custom_passwd_file(const std::string& port) const {
-    return prefix_host_and_port(port, Str::ECF_CUSTOM_PASSWD());
-}
-
-std::string Host::prefix_host_and_port(const std::string& port, const std::string& file_name) const {
-    // The file name may include a path.  /user/avi/fred.log
-    //    fred.log             ->  <host>.<port>.fred.log
-    //    /user/avi/fred.log   ->  /user/avi/fred.log
-    if (!file_name.empty() && file_name.find("/") != std::string::npos) {
-        return file_name;
-    }
-    std::string ret = host_port_prefix(port);
-    ret += ".";
-    ret += file_name;
-    return ret;
-}
-
-std::string Host::host_port_prefix(const std::string& port) const {
-    std::string ret = the_host_name_;
-    if (!port.empty()) {
-        ret += ".";
-        ret += port;
-    }
-    return ret;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Host.hpp 5.13.0-1/ACore/src/ecflow/core/Host.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Host.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Host.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Host_HPP
-#define ecflow_core_Host_HPP
-
-#include <string>
-
-namespace ecf {
-
-class Host {
-public:
-    /// can throw std::runtime_error if the gethostname fails
-    Host();
-    explicit Host(const std::string& host);
-
-    // Disable copy (and move) semantics
-    Host(const Host&)                  = delete;
-    const Host& operator=(const Host&) = delete;
-
-    /// return the host name
-    std::string name() const;
-
-    /// returns the log file name
-    std::string ecf_log_file(const std::string& port) const;
-
-    /// return checkPoint file
-    std::string ecf_checkpt_file(const std::string& port) const;
-
-    /// return backup checkPoint file
-    std::string ecf_backup_checkpt_file(const std::string& port) const;
-
-    /// return ecf.list file. White list file used for authentication & authorisation
-    std::string ecf_lists_file(const std::string& port) const;
-
-    /// return ecf.passwd file. Used for authentication
-    std::string ecf_passwd_file(const std::string& port) const;
-
-    /// return ecf.custom_passwd file. Used for authentication
-    std::string ecf_custom_passwd_file(const std::string& port) const;
-
-    /// Given a port and file name, will return <host>.<port>.file_name
-    std::string prefix_host_and_port(const std::string& port, const std::string& file_name) const;
-
-private:
-    std::string host_port_prefix(const std::string& port) const;
-    void get_host_name(); // will cache host name, to avoid multiple system calls
-    std::string the_host_name_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_Host_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Indentor.cpp 5.13.0-1/ACore/src/ecflow/core/Indentor.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Indentor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Indentor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Indentor.hpp"
-
-#include <ostream>
-
-namespace ecf {
-
-int Indentor::index_   = 0;
-bool Indentor::indent_ = true;
-
-std::ostream& Indentor::indent(std::ostream& os, int char_spaces) {
-    os << (indent_ ? std::string(index_ * char_spaces, ' ') : "");
-    return os;
-}
-
-void Indentor::indent(std::string& os, int char_spaces) {
-    os += (indent_ ? std::string(index_ * char_spaces, ' ') : "");
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Indentor.hpp 5.13.0-1/ACore/src/ecflow/core/Indentor.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Indentor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Indentor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Indentor_HPP
-#define ecflow_core_Indentor_HPP
-
-///
-/// \brief This class is used as a helper class to produce indented output
-///
-
-#include <iosfwd>
-
-namespace ecf {
-
-class Indentor {
-public:
-    Indentor() { ++index_; }
-    ~Indentor() { --index_; }
-
-    static std::ostream& indent(std::ostream& os, int char_spaces = 2);
-    static void indent(std::string& os, int char_spaces = 2);
-
-private:
-    static int index_;
-
-private:
-    friend class DisableIndentor;
-    static void disable_indent() { indent_ = false; }
-    static void enable_indent() { indent_ = true; }
-    static bool indent_;
-};
-
-class DisableIndentor {
-public:
-    DisableIndentor() { Indentor::disable_indent(); }
-    ~DisableIndentor() { Indentor::enable_indent(); }
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_Indentor_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Log.cpp 5.13.0-1/ACore/src/ecflow/core/Log.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Log.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Log.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,413 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Log.hpp"
-
-#include <cassert>
-#include <iostream>
-#include <stdexcept>
-#include <vector>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeStamp.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-Log* Log::instance_   = nullptr;
-bool LogToCout::flag_ = false;
-
-void Log::create(const std::string& filename) {
-    if (instance_ == nullptr) {
-        instance_ = new Log(filename);
-    }
-}
-
-void Log::destroy() {
-    if (instance_)
-        instance_->flush();
-
-    delete instance_;
-    instance_ = nullptr;
-}
-
-Log::Log(const std::string& fileName) : logImpl_(std::make_unique<LogImpl>(fileName)), fileName_(fileName) {
-}
-
-void Log::create_logimpl() {
-    if (!logImpl_) {
-        logImpl_ = std::make_unique<LogImpl>(fileName_);
-    }
-}
-
-bool Log::log(Log::LogType lt, const std::string& message) {
-    create_logimpl();
-
-    //   if (!logImpl_->log_open_error().empty()) {
-    //      cerr << "Log::log: " << message << "\n";
-    //   }
-
-    if (!logImpl_->log(lt, message)) {
-        // handle write failure and Get the failure reason. This will delete logImpl_ & recreate
-        log_error_ = handle_write_failure();
-
-        (void)logImpl_->log(Log::ERR, log_error_);
-        (void)logImpl_->log(lt, message);
-        return false;
-    }
-    return true;
-}
-
-bool Log::log_no_newline(Log::LogType lt, const std::string& message) {
-    create_logimpl();
-
-    //   if (!logImpl_->log_open_error().empty()) {
-    //      cerr << "Log::log_no_newline : " << message << "\n";
-    //   }
-
-    if (!logImpl_->log_no_newline(lt, message)) {
-        // handle write failure and Get the failure reason. This will delete logImpl_ & recreate
-        log_error_ = handle_write_failure();
-
-        (void)logImpl_->log(Log::ERR, log_error_);
-        (void)logImpl_->log_no_newline(lt, message);
-        return false;
-    }
-    return true;
-}
-
-bool Log::append(const std::string& message) {
-    create_logimpl();
-
-    //   if (!logImpl_->log_open_error().empty()) {
-    //      cerr << "Log::append : " << message << "\n";
-    //   }
-
-    if (!logImpl_->append(message)) {
-        // handle write failure and Get the failure reason. This will delete logImpl_ & recreate
-        log_error_ = handle_write_failure();
-
-        (void)logImpl_->log(Log::ERR, log_error_);
-        (void)logImpl_->append(message);
-        return false;
-    }
-    return true;
-}
-
-void Log::cache_time_stamp() {
-    create_logimpl();
-    logImpl_->create_time_stamp();
-}
-
-const std::string& Log::get_cached_time_stamp() const {
-    return (logImpl_) ? logImpl_->get_cached_time_stamp() : Str::EMPTY();
-}
-
-void Log::flush() {
-    // will close ofstream and force data to be written to disk.
-    // Forcing writing to physical medium can't be guaranteed though!
-    logImpl_.reset();
-}
-
-void Log::flush_only() {
-    if (logImpl_)
-        logImpl_->flush();
-}
-
-void Log::clear() {
-    flush();
-
-    // Open and truncate the file.
-    std::ofstream logfile(fileName_.c_str(), ios::out | ios::trunc);
-    if (logfile.is_open()) {
-        logfile.close(); // force buffers to flush
-    }
-}
-
-void Log::new_path(const std::string& the_new_path) {
-    check_new_path(the_new_path);
-
-    // flush and close log file
-    flush();
-
-    fileName_ = the_new_path;
-}
-
-void Log::check_new_path(const std::string& new_path) {
-    if (new_path.empty()) {
-        throw std::runtime_error("Log::check_new_path: No path name specified for the new log file");
-    }
-
-    fs::path the_new_path = new_path;
-
-    // Allow paths like "fred.log"
-    fs::path parent_path = the_new_path.parent_path();
-    // std::cout << "the_new_path.parent_path() = " << parent_path << "\n";
-    if (!parent_path.empty()) {
-
-        if (!fs::exists(parent_path)) {
-            std::stringstream ss;
-            ss << "Log::check_new_path: Cannot create new log file, since the directory part " << parent_path
-               << " does not exist\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    // Now check that path does not correspond to a directory, can't use that as the new log file location
-    if (fs::is_directory(the_new_path)) {
-        std::stringstream ss;
-        ss << "LogCmd::LogCmd: Cannot create new log file, since the path correspond to a directory " << the_new_path
-           << "\n";
-        throw std::runtime_error(ss.str());
-    }
-}
-
-std::string Log::path() const {
-    if (!fileName_.empty() && fileName_[0] == '/') {
-        // Path is absolute return as is
-        return fileName_;
-    }
-    std::string the_path = fs::current_path().string();
-    the_path += "/";
-    the_path += fileName_;
-    return the_path;
-}
-
-std::string Log::contents(int get_last_n_lines) {
-    if (get_last_n_lines == 0) {
-        return string();
-    }
-
-    // Close the file. Log file may be buffered, hence flush first
-    flush();
-
-    std::string error_msg;
-    if (get_last_n_lines > 0) {
-        return File::get_last_n_lines(fileName_, get_last_n_lines, error_msg);
-    }
-    return File::get_first_n_lines(fileName_, std::abs(get_last_n_lines), error_msg);
-}
-
-std::string Log::handle_write_failure() {
-    std::string msg = logImpl_->log_open_error();
-    if (msg.empty()) {
-        msg += "\nFailed to write to log file: ";
-        msg += File::stream_error_condition(logImpl_->stream());
-    }
-    // Append 'regular' format timestamp to end of message
-    msg += " ";
-    msg += TimeStamp::now();
-
-    // handle write failure, by closing then re-opening log file
-    logImpl_.reset();
-    create_logimpl();
-
-    if (logImpl_->log_open_error().empty())
-        msg += "\nAttempting to close/reopen log file.";
-    else
-        msg += "\nAttempting to close/reopen log file did not work!";
-
-    if (LogToCout::ok())
-        Indentor::indent(cout) << msg << '\n';
-    return msg;
-}
-
-bool log(Log::LogType lt, const std::string& message) {
-    // For debug of simulator enable this
-    //	if (LogToCout::ok()) {
-    //		Indentor::indent(cout) << message << '\n';
-    //	}
-
-    if (Log::instance()) {
-        return Log::instance()->log(lt, message);
-    }
-    else {
-        if (LogToCout::ok()) {
-            Indentor::indent(cout) << message << '\n';
-        }
-    }
-    return true;
-}
-
-bool log_no_newline(Log::LogType lt, const std::string& message) {
-    if (Log::instance()) {
-        return Log::instance()->log_no_newline(lt, message);
-    }
-    else {
-        if (LogToCout::ok()) {
-            Indentor::indent(cout) << message << '\n';
-        }
-    }
-    return true;
-}
-
-bool log_append(const std::string& message) {
-    if (Log::instance()) {
-        return Log::instance()->append(message);
-    }
-    else {
-        if (LogToCout::ok()) {
-            Indentor::indent(cout) << message << '\n';
-        }
-    }
-    return true;
-}
-
-void log_assert(char const* expr, char const* file, long line, const std::string& message) {
-    std::stringstream ss;
-    ss << "ASSERT failure: " << expr << " at " << file << ":" << line << " " << message;
-    std::string assert_msg = ss.str();
-    cerr << assert_msg << "\n";
-    if (Log::instance()) {
-        Log::instance()->log(Log::ERR, assert_msg);
-        exit(1);
-    }
-}
-
-// returns vec = MSG, LOG, ERR, WAR, DBG, OTH
-void Log::get_log_types(std::vector<std::string>& vec) {
-    vec.reserve(6);
-    vec.emplace_back("MSG");
-    vec.emplace_back("LOG");
-    vec.emplace_back("ERR");
-    vec.emplace_back("WAR");
-    vec.emplace_back("DBG");
-    vec.emplace_back("OTH");
-}
-
-//======================================================================================================
-
-LogFlusher::~LogFlusher() {
-    Log* the_log = Log::instance();
-    if (the_log) {
-        the_log->flush_only(); // flush without closing log file.
-    }
-}
-
-//======================================================================================================
-
-TestLog::TestLog(const std::string& log_path) : log_path_(log_path) {
-    Log::create(log_path);
-}
-
-TestLog::~TestLog() {
-
-    // Remove the log file. Comment out for debugging
-    fs::remove(log_path_);
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-}
-
-//======================================================================================================
-
-LogTimer::~LogTimer() {
-    Log* the_log = Log::instance();
-    if (the_log) {
-        std::stringstream ss;
-        ss << " " << msg_ << " " << timer_.elapsed_seconds();
-        the_log->log(Log::DBG, ss.str());
-    }
-}
-
-//======================================================================================================
-LogImpl::LogImpl(const std::string& filename) : file_(filename.c_str(), ios::out | ios::app) {
-    if (!file_.is_open()) {
-        log_open_error_ = "Could not open log file '";
-        log_open_error_ += filename;
-        log_open_error_ += "'. ";
-        log_open_error_ += File::stream_error_condition(file_);
-        // std::cerr << log_open_error_ << "\n";
-        //  Do *NOT* throw std::runtime_error(log_open_error_), HERE as this can cause server to die.
-        //  This would diagnose ECFLOW-1558 but is not acceptable
-    }
-}
-
-LogImpl::~LogImpl() = default;
-
-static void append_log_type(std::string& str, Log::LogType lt) {
-    switch (lt) {
-        case Log::MSG:
-            str.append("MSG:");
-            break;
-        case Log::LOG:
-            str.append("LOG:");
-            break;
-        case Log::ERR:
-            str.append("ERR:");
-            break;
-        case Log::WAR:
-            str.append("WAR:");
-            break;
-        case Log::DBG:
-            str.append("DBG:");
-            break;
-        case Log::OTH:
-            str.append("OTH:");
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-
-bool LogImpl::do_log(Log::LogType lt, const std::string& message, bool newline) {
-    count_++;
-
-    // XXX:[HH:MM:SS D.M.YYYY] chd:fullname [+additional information]
-    // XXX:[HH:MM:SS D.M.YYYY] --<user_cmd> [+additional information]
-    if (time_stamp_.empty() || lt == Log::ERR || lt == Log::WAR || lt == Log::DBG)
-        create_time_stamp();
-
-    // re-use memory allocated to log_type_and_time_stamp_
-    log_type_and_time_stamp_.clear();
-    append_log_type(log_type_and_time_stamp_, lt);
-    log_type_and_time_stamp_ += time_stamp_;
-
-    if (message.find("\n") == std::string::npos) {
-        file_ << log_type_and_time_stamp_ << message;
-        if (newline)
-            file_ << '\n';
-    }
-    else {
-        // If message has \n then split into multiple lines
-        std::vector<std::string> lines;
-        Str::split(message, lines, "\n");
-        size_t theSize = lines.size();
-        for (size_t i = 0; i < theSize; ++i) {
-            file_ << log_type_and_time_stamp_ << lines[i] << '\n';
-        }
-    }
-    return file_.good();
-}
-
-void LogImpl::flush() {
-    // cout << "LogImpl::flush() count = " << count_ << endl;
-    if (count_ != 0) {
-        file_.flush();
-        count_ = 0;
-    }
-}
-
-bool LogImpl::append(const std::string& message) {
-    count_++;
-    file_ << message << '\n';
-    return file_.good();
-}
-
-void LogImpl::create_time_stamp() {
-    TimeStamp::now(time_stamp_);
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Log.hpp 5.13.0-1/ACore/src/ecflow/core/Log.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Log.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Log.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,233 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Log_HPP
-#define ecflow_core_Log_HPP
-
-///
-/// \brief Simple singleton implementation of log
-///
-/// Please note how do we guarantee that file is actually written to disk:
-///   a/ Each log entry should call std::endl
-///   b/ Call flush() on the ofstream
-///   c/ The two methods will force ofstream buffer to be written to disk
-///
-/// Well NOT REALLY dues to file caching by the OS.
-///
-/// The strongest hint we can give th OS to actually write to the physical medium
-/// is to close the file. (This does not guarantee it, but is the closest we can achieve)
-///
-/// Why is this an issue? Testing on cross platform HPUX/linux, requires that
-/// testing has access to the ECF log file. Initially the log file held an
-/// ofstream of log file as a data member. However this meant that flushing
-/// did not guarantee writing ECF log file to disk. Testing requires that we
-/// are able to clear and copy the log file for comparison.
-/// Hence we use another level of indirection, so that we able to close the
-/// log file, and hence can ensure that it gets written to disk
-///
-
-#include <fstream>
-#include <memory>
-#include <string>
-#include <vector>
-
-#include "ecflow/core/DurationTimer.hpp"
-
-namespace ecf {
-
-class LogImpl;
-
-class Log {
-public:
-    enum LogType { MSG, LOG, ERR, WAR, DBG, OTH };
-
-    static void create(const std::string& filename);
-    static void destroy();
-    static Log* instance() { return instance_; }
-
-    // Disable copy (and move) semantics
-    Log(const Log&)                  = delete;
-    const Log& operator=(const Log&) = delete;
-
-    /// If file is closed will open it
-    /// Outputs t the file a message of type XXX:[HH:MM:SS D.M.YYYY] message
-    /// where XXX is one of the LogType
-    ///
-    /// If the message has multiple newlines these are split
-    /// LogType ERR,WAR,DBG will create a time stamp, otherwise the last cached
-    /// time stamp is used.
-    bool log(LogType, const std::string& message);
-
-    /// Single line message is placed in log file without a newline
-    bool log_no_newline(LogType, const std::string& message);
-
-    /// Append to log file file and add newline
-    bool append(const std::string& message);
-
-    /// Set the time stamp once for each request.
-    void cache_time_stamp();
-
-    /// Return the last cached time stamp. Used for time stamping edit history
-    const std::string& get_cached_time_stamp() const;
-
-    /// returns the contents of the log file, or the last n lines
-    /// Will throw an std::runtime_error if the log file cannot be opened
-    /// Will close the file.
-    static int get_last_n_lines_default() { return 100; }
-    std::string contents(int get_last_n_lines);
-
-    /// Will call flush and close the file. See notes above
-    void flush();
-
-    /// will flush the log file without closing it.
-    void flush_only();
-
-    /// clear the log file. Required for testing
-    void clear();
-
-    /// Close the existing log file, and new start writing to the new location
-    void new_path(const std::string& the_new_path);
-
-    /// Returns the current log file path name
-    std::string path() const;
-
-    /// Errors in opening or writing to log file
-    const std::string& log_error() const { return log_error_; }
-
-    // returns vec = MSG, LOG, ERR, WAR, DBG, OTH
-    static void get_log_types(std::vector<std::string>&);
-
-private:
-    /// If writing to the log fails, close log file and re-create it.
-    std::string handle_write_failure();
-
-    /// make sure path is not a directory & path has a parent directory.
-    /// Will throw std::runtime_error for errors
-    static void check_new_path(const std::string& new_path);
-
-    void create_logimpl();
-
-private:
-    explicit Log(const std::string& fileName);
-    static Log* instance_;
-
-    std::unique_ptr<LogImpl> logImpl_;
-    std::string fileName_;
-    std::string log_error_;
-};
-
-// Flush log on destruction
-class LogFlusher {
-public:
-    LogFlusher() = default;
-    // Disable copy (and move) semantics
-    LogFlusher(const LogFlusher&)                  = delete;
-    const LogFlusher& operator=(const LogFlusher&) = delete;
-
-    ~LogFlusher();
-};
-
-class LogTimer {
-public:
-    explicit LogTimer(const char* msg) : msg_(msg) {}
-    // Disable copy (and move) semantics
-    LogTimer(const LogTimer&)                  = delete;
-    const LogTimer& operator=(const LogTimer&) = delete;
-
-    ~LogTimer();
-
-private:
-    const char* msg_;
-    DurationTimer timer_;
-};
-
-/// The LogImpl allows the ofstream object to be closed, and so provide strongest
-/// hint to OS that we want file to be written to physical medium.
-/// This is required for testing purposes, as each test run needs to clear/copy
-/// the log file
-class LogImpl {
-public:
-    explicit LogImpl(const std::string& filename);
-    // Disable copy (and move) semantics
-    LogImpl(const LogImpl&)                  = delete;
-    const LogImpl& operator=(const LogImpl&) = delete;
-
-    ~LogImpl();
-
-    bool log(Log::LogType lt, const std::string& message) { return do_log(lt, message, true); }
-    bool log_no_newline(Log::LogType lt, const std::string& message) { return do_log(lt, message, false); }
-    bool append(const std::string& message);
-
-    void create_time_stamp();
-    const std::string& get_cached_time_stamp() const { return time_stamp_; }
-
-    void flush();
-    const std::ofstream& stream() const { return file_; }
-    const std::string& log_open_error() const { return log_open_error_; }
-
-private:
-    bool do_log(Log::LogType, const std::string& message, bool newline);
-
-    std::string time_stamp_;
-    std::string log_type_and_time_stamp_; // re-use memory
-    std::string log_open_error_;
-    mutable std::ofstream file_;
-    unsigned int count_{0};
-};
-
-/// Utility class used for test, since server assumes log is always present
-class TestLog {
-public:
-    explicit TestLog(const std::string& log_path);
-    ~TestLog();
-
-private:
-    std::string log_path_;
-};
-
-/// Utility class used for debug. Enables log file messages to be written to standard out
-class LogToCout {
-public:
-    LogToCout() { flag_ = true; }
-    // Disable copy (and move) semantics
-    LogToCout(const LogToCout&)                  = delete;
-    const LogToCout& operator=(const LogToCout&) = delete;
-
-    ~LogToCout() { flag_ = false; }
-
-    static bool ok() { return flag_; }
-
-private:
-    static bool flag_;
-};
-
-bool log(Log::LogType, const std::string& message);
-bool log_no_newline(Log::LogType, const std::string& message);
-bool log_append(const std::string& message);
-void log_assert(char const* expr, char const* file, long line, const std::string& message);
-
-// allow user to do the following:
-// LOG(Log::WAR,"this is " << path << " ok ");
-//
-// helper, see STRINGIZE() macro
-template <typename Functor>
-std::string stringize_f(Functor const& f) {
-    std::ostringstream out;
-    f(out);
-    return out.str();
-}
-#define STRINGIZE(EXPRESSION) (ecf::stringize_f([&](std::ostringstream& os) { os << EXPRESSION; }))
-#define LOG(level, EXPRESSION) ecf::log(level, STRINGIZE(EXPRESSION))
-#define LOG_ASSERT(expr, EXPRESSION) \
-    ((expr) ? (static_cast<void>(0)) : ecf::log_assert(#expr, __FILE__, __LINE__, STRINGIZE(EXPRESSION)))
-
-} // namespace ecf
-
-#endif /* ecflow_core_Log_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/LogVerification.cpp 5.13.0-1/ACore/src/ecflow/core/LogVerification.cpp
--- 5.12.4-1/ACore/src/ecflow/core/LogVerification.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/LogVerification.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,144 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/LogVerification.hpp"
-
-#include <sstream>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-bool LogVerification::extractNodePathAndState(const std::string& logfile,
-                                              std::vector<std::pair<std::string, std::string>>& pathStateVec,
-                                              std::string& errorMsg) {
-    // The log file format we are interested is :
-    //       0          1               2                 3
-    // LOG:[14:37:00 20.5.2010]    submitted: /test_abort_cmd/family0/abort duration_(00:00:00) initTime_(2010-May-20
-    // 14:37:00) suiteTime_(2010-May-20 14:37:00)
-
-    // Open log file, and collate of the node paths and corresponding states
-    std::vector<std::string> lines;
-    if (!File::splitFileIntoLines(logfile, lines)) {
-        errorMsg = "Could not open log file " + logfile + " for test verification (" + strerror(errno) + ")";
-        return false;
-    }
-
-    // int line_number = 0;
-    for (auto& line : lines) {
-
-        // line_number++;
-        if (line.find("LOG:") == std::string::npos) {
-            continue; // State changes have type Log::LOG
-        }
-
-        std::vector<std::string> lineTokens;
-        Str::split(line, lineTokens);
-        if (lineTokens.size() < 3) {
-            continue;
-        }
-
-        std::string theState = lineTokens[2];
-        theState.erase(theState.size() - 1); // remove ':' at the end
-        if (!NState::isValid(theState)) {
-            continue;
-        }
-        // cout << line_number << Str::COLON() << *i << "\n";
-
-        pathStateVec.emplace_back(lineTokens[3], theState);
-    }
-    return true;
-}
-
-static bool searchVec(const std::vector<std::pair<std::string, std::string>>& goldenLines,
-                      const std::pair<std::string, std::string>& line,
-                      size_t start_index) {
-    for (size_t i = start_index; i < goldenLines.size(); i++) {
-        if (goldenLines[i] == line) {
-            return true;
-        }
-    }
-    return false;
-}
-
-bool LogVerification::compareNodeStates(const std::string& logfile,
-                                        const std::string& goldenRefLogFile,
-                                        std::string& errorMsg) {
-    // Open log files, and extract just the state changes
-    std::vector<std::pair<std::string, std::string>> lines, goldenLines;
-    if (!extractNodePathAndState(logfile, lines, errorMsg))
-        return false;
-    if (!extractNodePathAndState(goldenRefLogFile, goldenLines, errorMsg))
-        return false;
-
-    if (lines != goldenLines) {
-        std::stringstream ss;
-        ss << "Log file " << logfile << " does not match golden reference file " << goldenRefLogFile << "\n";
-        if (lines.size() != goldenLines.size())
-            ss << "Expected log file size " << goldenLines.size() << " but found " << lines.size() << "\n";
-
-        bool errorFnd = false;
-        for (size_t i = 0; i < lines.size() || i < goldenLines.size(); ++i) {
-
-            std::string theLine, theGoldenLine;
-            if (i < lines.size())
-                theLine = lines[i].second + Str::COLON() + lines[i].first;
-            if (i < goldenLines.size())
-                theGoldenLine = goldenLines[i].second + Str::COLON() + goldenLines[i].first;
-
-            if (i < lines.size() && i < goldenLines.size()) {
-
-                if (lines[i] != goldenLines[i]) {
-                    // Please note that we can't do an exact comparison for certain state changes:
-                    //   - submitted --> active
-                    //   - active    --> complete
-                    // Since this can be OS/scheduler dependent and hence order dependent
-                    // To compensate, we search for a Golden file
-                    if (lines[i].second == "submitted" || lines[i].second == "active" ||
-                        lines[i].second == "complete") {
-                        // search for line in golden file
-                        if (searchVec(goldenLines, lines[i], 0)) {
-                            continue;
-                        }
-                    }
-
-                    ss << "Mismatch at " << i << " log(" << theLine << ")   golden(" << theGoldenLine << ")\n";
-                    errorFnd = true;
-                }
-                else {
-                    ss << "            " << i << " log(" << theLine << ")   golden(" << theGoldenLine << ")\n";
-                }
-            }
-            else {
-                errorFnd = true;
-                ss << "Mismatch at " << i;
-                if (i < lines.size())
-                    ss << " log(" << theLine << ")   ";
-                else
-                    ss << " log( ---- )   ";
-
-                if (i < goldenLines.size())
-                    ss << "golden(" << theGoldenLine << ")\n";
-                else
-                    ss << "golden( --- )\n";
-            }
-        }
-        if (errorFnd)
-            errorMsg = ss.str();
-    }
-
-    return errorMsg.empty();
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/LogVerification.hpp 5.13.0-1/ACore/src/ecflow/core/LogVerification.hpp
--- 5.12.4-1/ACore/src/ecflow/core/LogVerification.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/LogVerification.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_LogVerification_HPP
-#define ecflow_core_LogVerification_HPP
-
-#include <string>
-#include <vector>
-
-namespace ecf {
-
-class LogVerification {
-public:
-    // Disable default construction
-    LogVerification() = delete;
-    // Disable copy (and move) semantics
-    LogVerification(const LogVerification&)                  = delete;
-    const LogVerification& operator=(const LogVerification&) = delete;
-
-    /// Given a log file, extract in order. The node_path and the state
-    static bool extractNodePathAndState(const std::string& logfile,
-                                        std::vector<std::pair<std::string, std::string>>& pathStateVec,
-                                        std::string& errorMsg);
-
-    /// Will compare the input log file, with gold reference.
-    /// Will compare the node state changes only
-    /// Compensate for states that are scheduler dependent
-    static bool
-    compareNodeStates(const std::string& logfile, const std::string& goldenRefLogFile, std::string& errorMsg);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_LogVerification_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/NOrder.cpp 5.13.0-1/ACore/src/ecflow/core/NOrder.cpp
--- 5.12.4-1/ACore/src/ecflow/core/NOrder.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/NOrder.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/NOrder.hpp"
-
-#include <cassert>
-
-#include "ecflow/core/Enumerate.hpp"
-
-namespace ecf::detail {
-
-template <>
-struct EnumTraits<NOrder::Order>
-{
-    using underlying_t = std::underlying_type_t<NOrder::Order>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(NOrder::Order::TOP, "top"),
-        std::make_pair(NOrder::Order::BOTTOM, "bottom"),
-        std::make_pair(NOrder::Order::ALPHA, "alpha"),
-        std::make_pair(NOrder::Order::ORDER, "order"),
-        std::make_pair(NOrder::Order::UP, "up"),
-        std::make_pair(NOrder::Order::DOWN, "down"),
-        std::make_pair(NOrder::Order::RUNTIME, "runtime")
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(std::is_same_v<NOrder::Order, decltype(map)::value_type::first_type>);
-    static_assert(std::is_same_v<const char*, decltype(map)::value_type::second_type>);
-
-    static_assert(EnumTraits<NOrder::Order>::size == map.back().first + 1);
-};
-
-} // namespace ecf::detail
-
-std::string NOrder::toString(NOrder::Order s) {
-    if (auto found = ecf::Enumerate<NOrder::Order>::to_string(s); found) {
-        return std::string{found.value()};
-    }
-    assert(false);
-    return std::string{};
-}
-
-NOrder::Order NOrder::toOrder(const std::string& str) {
-    if (auto found = ecf::Enumerate<NOrder::Order>::to_enum(str); found) {
-        return found.value();
-    }
-    assert(false);
-    return NOrder::TOP;
-}
-
-bool NOrder::isValid(const std::string& order) {
-    return ecf::Enumerate<NOrder::Order>::is_valid(order);
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/NOrder.hpp 5.13.0-1/ACore/src/ecflow/core/NOrder.hpp
--- 5.12.4-1/ACore/src/ecflow/core/NOrder.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/NOrder.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_NOrder_HPP
-#define ecflow_core_NOrder_HPP
-
-#include <string>
-
-class NOrder {
-    NOrder() = default;
-
-public:
-    enum Order { TOP, BOTTOM, ALPHA, ORDER, UP, DOWN, RUNTIME /* state change runtime */ };
-
-    static std::string toString(NOrder::Order);
-    static NOrder::Order toOrder(const std::string&);
-    static bool isValid(const std::string& order);
-};
-
-#endif
diff -pruN 5.12.4-1/ACore/src/ecflow/core/NState.cpp 5.13.0-1/ACore/src/ecflow/core/NState.cpp
--- 5.12.4-1/ACore/src/ecflow/core/NState.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/NState.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,103 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/NState.hpp"
-
-#include <cassert>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Enumerate.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-namespace ecf::detail {
-
-template <>
-struct EnumTraits<NState::State>
-{
-    using underlying_t = std::underlying_type_t<NState::State>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(NState::State::UNKNOWN, "unknown"),
-        std::make_pair(NState::State::COMPLETE, "complete"),
-        std::make_pair(NState::State::QUEUED, "queued"),
-        std::make_pair(NState::State::ABORTED, "aborted"),
-        std::make_pair(NState::State::SUBMITTED, "submitted"),
-        std::make_pair(NState::State::ACTIVE, "active")
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<NState::State>::size == map.back().first + 1);
-};
-
-} // namespace ecf::detail
-
-void NState::setState(State s) {
-    st_              = s;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "NState::setState\n";
-#endif
-}
-
-const char* NState::toString(NState::State s) {
-    if (auto found = ecf::Enumerate<NState::State>::to_string(s); found) {
-        return found.value().data();
-    }
-    assert(false);
-    return nullptr;
-}
-
-std::string NState::to_html(NState::State s) {
-    std::string res;
-    if (auto found = ecf::Enumerate<NState::State>::to_string(s); found) {
-        res += "<state>";
-        res += found.value();
-        res += "</state>";
-        return res;
-    }
-    assert(false);
-    return res;
-}
-
-NState::State NState::toState(const std::string& str) {
-    if (auto found = ecf::Enumerate<NState::State>::to_enum(str); found) {
-        return found.value();
-    }
-    assert(false);
-    return NState::UNKNOWN;
-}
-
-std::pair<NState::State, bool> NState::to_state(const std::string& str) {
-    if (auto found = ecf::Enumerate<NState::State>::to_enum(str); found) {
-        return std::make_pair(found.value(), true);
-    }
-    return std::make_pair(NState::UNKNOWN, false);
-}
-
-bool NState::isValid(const std::string& state) {
-    return ecf::Enumerate<NState::State>::is_valid(state);
-}
-
-std::vector<std::string> NState::allStates() {
-    return ecf::Enumerate<NState::State>::designations();
-}
-
-std::vector<NState::State> NState::states() {
-    return ecf::Enumerate<NState::State>::enums();
-}
-
-template <class Archive>
-void NState::serialize(Archive& ar) {
-    ar(CEREAL_NVP(st_));
-}
-CEREAL_TEMPLATE_SPECIALIZE(NState);
diff -pruN 5.12.4-1/ACore/src/ecflow/core/NState.hpp 5.13.0-1/ACore/src/ecflow/core/NState.hpp
--- 5.12.4-1/ACore/src/ecflow/core/NState.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/NState.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_NState_HPP
-#define ecflow_core_NState_HPP
-
-#include <string>
-#include <vector>
-
-namespace cereal {
-class access;
-}
-
-// NState: stores the state of a node.
-// *The class NState just used to define the enum, however we also
-// needed to know when the state changed. Hence, the use of state_change_no
-// Uses default copy constructor and destructor, and equality
-//
-// The default_state() should *NEVER* change as it will impact client/server communications
-//
-class NState {
-public:
-    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5 };
-
-    explicit NState(State s) : st_(s), state_change_no_(0) {}
-    NState() : st_(default_state()) {}
-    static NState::State default_state() { return NState::UNKNOWN; }
-
-    State state() const { return st_; }
-    void setState(State);
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    bool operator==(const NState& rhs) const { return st_ == rhs.st_; }
-    bool operator!=(const NState& rhs) const { return st_ != rhs.st_; }
-    bool operator==(State s) const { return s == st_; }
-    bool operator!=(State s) const { return s != st_; }
-
-    static const char* toString(NState::State s);
-    static std::string to_html(NState::State s);
-    static const char* toString(const NState& ns) { return toString(ns.state()); }
-    static NState::State toState(const std::string&);
-    static bool isValid(const std::string& state);
-    static std::pair<NState::State, bool> to_state(const std::string&);
-    static std::vector<std::string> allStates();
-    static std::vector<NState::State> states();
-
-private:
-    State st_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-
-    // *IMPORTANT* no version for a simple class
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_core_NState_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/NodePath.cpp 5.13.0-1/ACore/src/ecflow/core/NodePath.cpp
--- 5.12.4-1/ACore/src/ecflow/core/NodePath.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/NodePath.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/NodePath.hpp"
-
-#include "ecflow/core/Str.hpp"
-
-using namespace ecf;
-
-void NodePath::split(const std::string& path, std::vector<std::string>& thePath) {
-    /// The path is of the form "/suite/family/task"
-    Str::split(path, thePath, Str::PATH_SEPERATOR());
-}
-
-bool NodePath::extractHostPort(const std::string& path, std::string& host, std::string& port) {
-    if (path.empty())
-        return false;
-
-    std::vector<std::string> thePath;
-    NodePath::split(path, thePath);
-
-    if (thePath.empty())
-        return false;
-
-    //<host>:<port>/suite/family/task
-    // first path should be of form <host>:<port>
-    size_t colonPos = thePath[0].find_first_of(':');
-    if (colonPos == std::string::npos)
-        return false;
-
-    host = thePath[0].substr(0, colonPos);
-    port = thePath[0].substr(colonPos + 1);
-
-    ecf::algorithm::trim(host);
-    ecf::algorithm::trim(port);
-    if (host.empty())
-        return false;
-    if (port.empty())
-        return false;
-
-    return true;
-}
-
-std::string NodePath::createPath(const std::vector<std::string>& vec) {
-    if (vec.empty())
-        return std::string();
-
-    std::string ret;
-    size_t size = vec.size();
-    for (size_t i = 0; i < size; i++) {
-        ret += Str::PATH_SEPERATOR();
-        ret += vec[i];
-    }
-    return ret;
-}
-
-std::string NodePath::removeHostPortFromPath(const std::string& path) {
-    std::vector<std::string> pathVec;
-    NodePath::split(path, pathVec);
-    pathVec.erase(pathVec.begin());
-    return NodePath::createPath(pathVec);
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/NodePath.hpp 5.13.0-1/ACore/src/ecflow/core/NodePath.hpp
--- 5.12.4-1/ACore/src/ecflow/core/NodePath.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/NodePath.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_NodePath_HPP
-#define ecflow_core_NodePath_HPP
-
-#include <string>
-#include <vector>
-
-class NodePath {
-public:
-    // Disable default construction
-    NodePath() = delete;
-    // Disable copy (and move) semantics
-    NodePath(const NodePath&)                  = delete;
-    const NodePath& operator=(const NodePath&) = delete;
-
-    /// returns the path as a vector of strings, preserving the order
-    /// Note: multiple path separator '/' are treated as one separator.
-    /// Mimics unix path conventions. hence
-    /// '/suite//family///task' will be extracted as 'suite','family','task'
-    static void split(const std::string& path, std::vector<std::string>&);
-
-    /// If the path name if form:
-    ///     //<host>:<port>/suite/family/task
-    /// The extract the host and port, return OK if successful
-    static bool extractHostPort(const std::string& path, std::string& host, std::string& port);
-
-    /// Given a vector of strings , create a path. "suite","family", returns /suite/family
-    static std::string createPath(const std::vector<std::string>&);
-
-    /// Given a path like:   //localhost:3141/suite/family/task
-    /// returns              /suite/family/task
-    static std::string removeHostPortFromPath(const std::string& path);
-};
-
-#endif /* ecflow_core_NodePath_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Overload.hpp 5.13.0-1/ACore/src/ecflow/core/Overload.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Overload.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Overload.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Overload_HPP
-#define ecflow_core_Overload_HPP
-
-namespace ecf {
-
-template <class... Ts>
-struct overload : Ts...
-{
-    using Ts::operator()...;
-};
-
-template <class... Ts>
-overload(Ts...) -> overload<Ts...>; // Deduction guideline not needed from C++20
-
-} // namespace ecf
-
-#endif /* ecflow_core_Overload_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Passwd.cpp 5.13.0-1/ACore/src/ecflow/core/Passwd.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Passwd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Passwd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Passwd.hpp"
-
-#include <ctime>
-#include <unistd.h>
-
-double ecf_drand48();
-
-std::string Passwd::generate() {
-    char pw[9];
-    for (int i = 0; i < 8; i++) { /* generate a random password */
-
-        pw[i] = 64.0 * ecf_drand48() + '.'; /* Just crack this one! */
-        if (pw[i] > '9')
-            pw[i] += 7;
-        if (pw[i] > 'Z')
-            pw[i] += 6;
-    }
-    pw[8] = '\0';
-    return std::string(pw);
-}
-
-double ecf_drand48()
-/**************************************************************************
- ?  Random number with time dependent seed.
- =  [0.0 - 1.0)
- ~  drand48(3) srand48(3) rand(3)
- ************************************o*************************************/
-{
-    //  extern double drand48();
-    //  extern void   srand48();
-    static int been_here;
-
-    if (!been_here) {
-#if defined(RAND_ONLY)
-        srand((int)time(NULL) + getpid());
-#else
-        srand48((long)time(nullptr) + getpid());
-#endif
-        been_here = 1;
-    }
-
-#if defined(RAND_ONLY)
-    return (rand() & 0xffff) / 65535.0001;
-#else
-    return drand48();
-#endif
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Passwd.hpp 5.13.0-1/ACore/src/ecflow/core/Passwd.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Passwd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Passwd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,43 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Passwd_HPP
-#define ecflow_core_Passwd_HPP
-
-///
-/// The tasks send by the ECF will have GENERATED PASSWORD that is not
-/// stored into the any file (except the job file). It only exists in the
-/// ECF_server-memory. If the ECF server fails and a new one is started,
-/// it must be told (by operator) to accept the messages from the unknown jobs.
-///
-/// The GENERATED PASSWORDs are stored into the CHECKPOINT file. So if the
-/// ECF fails and is RESTARTed from a valid CHECKPOINT file, the ECF gets
-/// to know about the tasks.
-///
-/// The user passwords are kept in a file. When ever an user logs into
-/// the ECF or changes the "level" of privileges while already in the
-/// file is consulted.
-///
-
-#include <string>
-
-class Passwd {
-public:
-    // Disable default construction
-    Passwd() = delete;
-    // Disable copy (and move) semantics
-    Passwd(const Passwd&)                  = delete;
-    const Passwd& operator=(const Passwd&) = delete;
-
-    /// generate a random password
-    static std::string generate();
-};
-
-#endif /* ecflow_core_Passwd_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/PasswdFile.cpp 5.13.0-1/ACore/src/ecflow/core/PasswdFile.cpp
--- 5.12.4-1/ACore/src/ecflow/core/PasswdFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/PasswdFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,337 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/PasswdFile.hpp"
-
-#include <iostream>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/PasswordEncryption.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/User.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-PasswdFile::PasswdFile()  = default;
-PasswdFile::~PasswdFile() = default;
-
-// #define DEBUG_ME 1
-
-// Parse the file if any errors found return false and errorMsg
-// The parser expects version number  4.5.0
-bool PasswdFile::load(const std::string& file, bool debug, std::string& errorMsg) {
-#ifdef DEBUG_ME
-    debug = true;
-#endif
-    vec_.clear();
-    passwd_file_ = file;
-    if (debug)
-        std::cout << __func__ << "  " << passwd_file_ << " opening...\n";
-
-    std::vector<std::string> lines;
-    if (!File::splitFileIntoLines(passwd_file_, lines, true /* ignore empty lines */)) {
-        errorMsg += "Could not open file specified by ECF_PASSWD/ECF_CUSTOM_PASSWD ";
-        errorMsg += passwd_file_;
-        errorMsg += " (";
-        errorMsg += strerror(errno);
-        errorMsg += ")";
-        if (debug)
-            std::cout << dump() << "\n";
-        return false;
-    }
-
-    bool foundVersionNumber = false; // can read from version 4.4.0 onwards
-    size_t lines_size       = lines.size();
-    for (size_t i = 0; i < lines_size; ++i) {
-
-        if (lines[i].empty())
-            continue;
-
-        // ignore/remove all comments
-        if (lines[i][0] == '#')
-            continue;
-        std::string theLine           = lines[i];
-        string::size_type comment_pos = theLine.find("#");
-        if (comment_pos != std::string::npos) {
-            theLine.erase(comment_pos);
-        }
-
-        ecf::algorithm::trim(theLine); // remove leading and trailing spaces
-        std::vector<std::string> lineTokens;
-        Str::split(theLine, lineTokens);
-        if (lineTokens.empty())
-            continue;
-
-        // version should be at the start
-        if (!foundVersionNumber) {
-
-            if (!validateVersionNumber(lineTokens[0], errorMsg)) {
-                std::stringstream ss;
-                ss << " " << i + 1 << ": " << lines[i] << "\n";
-                ss << "for ECF_PASSWD/ECF_CUSTOM_PASSWD file " << passwd_file_ << "\n";
-                errorMsg += ss.str();
-                return false;
-            }
-            foundVersionNumber = true;
-            continue;
-        }
-        else {
-            if (!add_user(lineTokens, errorMsg)) {
-                errorMsg += theLine;
-                return false;
-            }
-        }
-    }
-
-    if (debug)
-        std::cout << dump();
-
-    // Now check the user is unique for a given host/port:
-    //   fred host 3141 xxxx
-    //   fred host 3141 yyyy  this is illegal.
-    size_t vec_size = vec_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        for (size_t k = 0; k < vec_size; k++) {
-            if (i == k)
-                continue;
-            if (vec_[i].user() == vec_[k].user() && vec_[i].host() == vec_[k].host() &&
-                vec_[i].port() == vec_[k].port()) {
-                std::stringstream ss;
-                ss << "user " << vec_[i].user() << " can only appear once for given host/port\n";
-                errorMsg += ss.str();
-                return false;
-            }
-        }
-    }
-    return true;
-}
-
-bool PasswdFile::check_at_least_one_user_with_host_and_port(const std::string& host, const std::string& port) {
-    size_t vec_size = vec_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (vec_[i].host() == host && vec_[i].port() == port) {
-            return true;
-        }
-    }
-    return false;
-}
-
-std::string PasswdFile::get_passwd(const std::string& user, const std::string& host, const std::string& port) {
-#ifdef DEBUG_ME
-    cout << "PasswdFile::get_passwd user(" << user << ") host(" << host << ") port(" << port << ")\n";
-#endif
-    size_t vec_size = vec_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (vec_[i].user() == user && vec_[i].host() == host && vec_[i].port() == port) {
-            return vec_[i].passwd();
-        }
-    }
-    return string();
-}
-
-bool PasswdFile::authenticate(const std::string& user, const std::string& passwd) const {
-#ifdef DEBUG_ME
-    cout << "   PasswdFile::authenticate user:" << user << " passwd:" << passwd << " file:" << passwd_file_
-         << " vec_.size(): " << vec_.size() << "\n";
-    cout << dump() << "\n";
-#endif
-
-    if (user.empty()) {
-#ifdef DEBUG_ME
-        cout << "      PasswdFile::authenticate: user empty:  FAIL\n";
-#endif
-        return false;
-    }
-
-    // no password specified, and password file is empty
-    if (passwd.empty() && vec_.empty()) {
-#ifdef DEBUG_ME
-        cout << "      PasswdFile::authenticate no password and password file empty: PASS\n";
-#endif
-        return true;
-    }
-
-    // Only fail if user exists in the passwd file
-    size_t vec_size = vec_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (vec_[i].user() == user) {
-            if (vec_[i].passwd() == passwd) {
-#ifdef DEBUG_ME
-                cout << "      PasswdFile::authenticate user and password match: PASS\n";
-#endif
-                return true;
-            }
-            else {
-#ifdef DEBUG_ME
-                cout << "      PasswdFile::authenticate: user found but passwd did not match: FAIL\n";
-#endif
-                return false;
-            }
-        }
-    }
-
-    // Will ONLY reach here if user not found
-
-    // User not found, but if passwd is not empty, then fail.
-    if (!passwd.empty()) {
-#ifdef DEBUG_ME
-        cout << "      PasswdFile::authenticate: user NOT found, passwd is NOT EMPTY: FAIL\n";
-#endif
-        return false;
-    }
-
-    // Server has a password file, but user not found and passwd is empty.
-    if (vec_.empty()) {
-#ifdef DEBUG_ME
-        cout << "      PasswdFile::authenticate: true, user NOT found, and passwd EMPTY, and password file EMPTY\n";
-#endif
-        return true;
-    }
-
-#ifdef DEBUG_ME
-    cout << "      PasswdFile::authenticate false, user NOT found, and passwd EMPTY\n";
-#endif
-    return false;
-}
-
-bool PasswdFile::validateVersionNumber(const std::string& line, std::string& errorMsg) const {
-    // Expect 4.5.0
-    // If first character is NUMERIC and we have dots
-    bool firstCharIsNumeric = Str::NUMERIC().find(line[0], 0) != string::npos;
-    if (firstCharIsNumeric && line.find(".") != string::npos) {
-
-        std::vector<std::string> versionNumberTokens;
-        Str::split(line, versionNumberTokens, ".");
-        if (versionNumberTokens.size() != 3) {
-            std::stringstream ss;
-            ss << "Expected version of the form <int>.<int>.<int> i.e 4.4.0. but found invalid version number\n";
-            errorMsg += ss.str();
-            return false;
-        }
-
-        try {
-            auto major = ecf::convert_to<int>(versionNumberTokens[0]);
-            auto minor = ecf::convert_to<int>(versionNumberTokens[1]);
-            auto part  = ecf::convert_to<int>(versionNumberTokens[2]);
-            if (major < 4) {
-                errorMsg += "Only passwd files with a version >= 4.5.0 is supported\n";
-                return false;
-            }
-            if (major == 4 && minor < 5) {
-                errorMsg += "Only passwd files with a version >= 4.5.0 is supported\n";
-                return false;
-            }
-            if (major == 4 && minor == 5 && part > 0) {
-                errorMsg += "Only passwd files with a version >= 4.5.0 is supported\n";
-                return false;
-            }
-        }
-        catch (const ecf::bad_conversion&) {
-            errorMsg += "Invalid version number \n";
-            return false;
-        }
-
-        return true;
-    }
-
-    errorMsg += "The version number not found. The version number must appear before the users.\n";
-    return false;
-}
-
-bool PasswdFile::add_user(std::vector<std::string>& tokens, std::string& error_msg) {
-    // Expected format is:
-    // 4.5.0
-    // # comment
-    // <user> <host> <port> <passwd> # comment
-    // <user> <host> <port> <passwd> # comment
-
-    if (tokens.size() < 4) {
-        error_msg = "expected <user> <host> <port> <passwd> # comment\n";
-        return false;
-    }
-
-    try {
-        ecf::convert_to<int>(tokens[2]);
-    }
-    catch (const ecf::bad_conversion&) {
-        error_msg += "Port number must be integer's\n";
-        return false;
-    }
-
-    vec_.emplace_back(tokens[0], tokens[1], tokens[2], PasswordEncryption::encrypt(tokens[3], tokens[0]));
-
-    return true;
-}
-
-std::string PasswdFile::dump() const {
-    std::stringstream ss;
-    int count = 1;
-    for (const auto& i : vec_) {
-        ss << count << ": " << i.user() << " " << i.host() << " " << i.port() << "\n";
-        count++;
-    }
-    return ss.str();
-}
-
-bool PasswdFile::createWithAccess(const std::string& pathToFile,
-                                  const std::string& host,
-                                  const std::string& port,
-                                  const std::string& passwd,
-                                  std::string& errorMsg) {
-    std::vector<std::string> lines;
-    lines.reserve(3);
-
-    lines.emplace_back("4.5.0");
-
-    string line;
-    line += User::login_name();
-    line += " ";
-    line += host;
-    line += " ";
-    line += port;
-    line += " ";
-    line += passwd;
-    lines.push_back(line);
-
-    line.clear();
-    line += User::login_name();
-    line += " ";
-    line += Str::LOCALHOST();
-    line += " ";
-    line += port;
-    line += " ";
-    line += passwd;
-    lines.push_back(line);
-
-    return File::create(pathToFile, lines, errorMsg);
-}
-
-bool PasswdFile::clear(const std::string& pathToFile, std::string& errorMsg) {
-    std::vector<std::string> lines;
-    if (File::splitFileIntoLines(pathToFile, lines, true /* ignore empty lines */)) {
-        // Just leave the version, i.e. the first line.
-        if (lines.size() > 1) {
-            lines.erase(lines.begin() + 1, lines.end());
-
-            // Overwrite the file.
-            return File::create(pathToFile, lines, errorMsg);
-        }
-        return true;
-    }
-    errorMsg += "PasswdFile::clear: Could not open file ";
-    errorMsg += pathToFile;
-    errorMsg += " (";
-    errorMsg += strerror(errno);
-    errorMsg += ")";
-    return false;
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/PasswdFile.hpp 5.13.0-1/ACore/src/ecflow/core/PasswdFile.hpp
--- 5.12.4-1/ACore/src/ecflow/core/PasswdFile.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/PasswdFile.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,97 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_PasswdFile_HPP
-#define ecflow_core_PasswdFile_HPP
-
-///
-/// \brief Parser for password file
-///
-
-#include <string>
-#include <vector>
-
-// ----------------------------------------------------------------
-//
-class Pass_wd {
-public:
-    Pass_wd(const std::string& user, const std::string& host, const std::string& port, const std::string& passwd)
-        : user_(user),
-          host_(host),
-          port_(port),
-          passwd_(passwd) {}
-    ~Pass_wd() = default;
-
-    bool operator==(const Pass_wd& rhs) const {
-        return rhs.user_ == user_ && rhs.host_ == host_ && rhs.port_ == port_ && rhs.passwd_ == passwd_;
-    }
-    const std::string& user() const { return user_; }
-    const std::string& host() const { return host_; }
-    const std::string& port() const { return port_; }
-    const std::string& passwd() const { return passwd_; }
-
-private:
-    std::string user_;
-    std::string host_;
-    std::string port_;
-    std::string passwd_; // always stored as ciphertext
-};
-
-// This class is used to authenticate, user commands, i.e. like ping,alter, etc
-class PasswdFile {
-public:
-    PasswdFile();
-    // Disable copy (and move) semantics
-    PasswdFile(const PasswdFile&)                  = delete;
-    const PasswdFile& operator=(const PasswdFile&) = delete;
-
-    ~PasswdFile();
-
-    bool empty() const { return vec_.empty(); }
-
-    // Parse the file if any errors found return false and errorMsg
-    // The parser expects version number  4.5.0
-    bool load(const std::string& file, bool debug, std::string& errorMsg);
-
-    // to be called by the server, to at least one user with given host and port
-    bool check_at_least_one_user_with_host_and_port(const std::string& host, const std::string& port);
-
-    // get the password for the given user, host and port. Otherwise, return an empty string
-    std::string get_passwd(const std::string& user, const std::string& host, const std::string& port);
-
-    // authenticate the user, given the password.
-    bool authenticate(const std::string& user, const std::string& passwd) const;
-
-    // ===========================================================================
-    // For test/debug
-
-    // Will overwrite the existing file
-    static bool createWithAccess(const std::string& pathToFile,
-                                 const std::string& host,
-                                 const std::string& port,
-                                 const std::string& passwd,
-                                 std::string& errorMsg);
-
-    // Open password file and make it empty
-    static bool clear(const std::string& pathToFile, std::string& errorMsg);
-
-    const std::vector<Pass_wd>& passwds() const { return vec_; }
-    std::string dump() const;
-
-private:
-    bool add_user(std::vector<std::string>& tokens, std::string& error_msg);
-    bool validateVersionNumber(const std::string& line, std::string& errorMsg) const;
-
-private:
-    std::string passwd_file_;
-    std::vector<Pass_wd> vec_;
-};
-
-#endif /* ecflow_core_PasswdFile_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/PasswordEncryption.hpp 5.13.0-1/ACore/src/ecflow/core/PasswordEncryption.hpp
--- 5.12.4-1/ACore/src/ecflow/core/PasswordEncryption.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/PasswordEncryption.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,51 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_PasswordEncryption_HPP
-#define ecflow_core_PasswordEncryption_HPP
-
-///
-/// \brief Provides a generic password encryption mechanism + specific POSIX implementation
-///
-
-#include <stdexcept>
-#include <string>
-#include <unistd.h>
-
-struct PosixEncryption
-{
-    using salt_t      = std::string;
-    using key_t       = std::string;
-    using encrypted_t = std::string;
-
-    static encrypted_t encrypt(const key_t& key, const salt_t& salt) {
-        auto result = crypt(key.c_str(), salt.c_str());
-        if (!result) {
-            throw std::runtime_error("Error: unable to encrypt the given key");
-        }
-        return std::string{result};
-    }
-};
-
-template <typename ENGINE>
-struct BasePasswordEncryption
-{
-    using username_t           = std::string;
-    using plain_password_t     = std::string;
-    using encrypted_password_t = std::string;
-
-    static encrypted_password_t encrypt(const plain_password_t& password, const username_t& username) {
-        return ENGINE::encrypt(password, username);
-    }
-};
-
-using PasswordEncryption = BasePasswordEncryption<PosixEncryption>;
-
-#endif /* ecflow_core_PasswordEncryption_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Pid.cpp 5.13.0-1/ACore/src/ecflow/core/Pid.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Pid.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Pid.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,34 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Pid.hpp"
-
-#include <stdexcept>
-#include <unistd.h> // for getpid
-
-#include "ecflow/core/Converter.hpp"
-
-std::string Pid::getpid() {
-    std::string pid;
-    try {
-        pid = ecf::convert_to<std::string>(::getpid());
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error("Pid::getpid(): Could not convert PID to a string\n");
-    }
-    return pid;
-}
-
-std::string Pid::unique_name(const std::string& prefix) {
-    std::string ret = prefix;
-    ret += "_";
-    ret += Pid::getpid();
-    return ret;
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Pid.hpp 5.13.0-1/ACore/src/ecflow/core/Pid.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Pid.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Pid.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Pid_HPP
-#define ecflow_core_Pid_HPP
-
-#include <string>
-
-class Pid {
-public:
-    // Disable default construction
-    Pid() = delete;
-    // Disable copy (and move) semantics
-    Pid(const Pid&)                  = delete;
-    const Pid& operator=(const Pid&) = delete;
-
-    /// Returns the current Process ID (as a string); otherwise, throws exception(std::runtime_error)
-    static std::string getpid();
-
-    /// Returns a unique name, based on Process ID, composed of prefix + '_' + getpid();
-    /// otherwise, throws exception(std::runtime_error)
-    static std::string unique_name(const std::string& prefix);
-};
-
-#endif /* ecflow_core_Pid_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/PrintStyle.cpp 5.13.0-1/ACore/src/ecflow/core/PrintStyle.cpp
--- 5.12.4-1/ACore/src/ecflow/core/PrintStyle.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/PrintStyle.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,75 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/PrintStyle.hpp"
-
-#include "ecflow/core/Enumerate.hpp"
-
-namespace ecf::detail {
-
-template <>
-struct EnumTraits<PrintStyle::Type_t>
-{
-    using underlying_t = std::underlying_type_t<PrintStyle::Type_t>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(PrintStyle::Type_t::NOTHING, "NOTHING"),
-        std::make_pair(PrintStyle::Type_t::DEFS, "DEFS"),
-        std::make_pair(PrintStyle::Type_t::STATE, "STATE"),
-        std::make_pair(PrintStyle::Type_t::MIGRATE, "MIGRATE"),
-        std::make_pair(PrintStyle::Type_t::NET, "NET"),
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<PrintStyle::Type_t>::size == map.back().first + 1);
-};
-
-} // namespace ecf::detail
-
-static PrintStyle::Type_t style_ = PrintStyle::NOTHING;
-
-PrintStyle::Type_t PrintStyle::getStyle() {
-    return style_;
-}
-
-void PrintStyle::setStyle(PrintStyle::Type_t f) {
-    style_ = f;
-}
-
-bool PrintStyle::defsStyle() {
-    if (getStyle() == PrintStyle::DEFS || getStyle() == PrintStyle::NOTHING) {
-        return true;
-    }
-    return false;
-}
-
-bool PrintStyle::persist_style() {
-    if (getStyle() == PrintStyle::MIGRATE || getStyle() == PrintStyle::NET) {
-        return true;
-    }
-    return false;
-}
-
-bool PrintStyle::is_persist_style(PrintStyle::Type_t t) {
-    if (t == PrintStyle::MIGRATE || t == PrintStyle::NET) {
-        return true;
-    }
-    return false;
-}
-
-std::string PrintStyle::to_string() {
-    return to_string(getStyle());
-}
-
-std::string PrintStyle::to_string(PrintStyle::Type_t t) {
-    return std::string{ecf::Enumerate<PrintStyle::Type_t>::to_string(t).value_or("")};
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/PrintStyle.hpp 5.13.0-1/ACore/src/ecflow/core/PrintStyle.hpp
--- 5.12.4-1/ACore/src/ecflow/core/PrintStyle.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/PrintStyle.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_PrintStyle_HPP
-#define ecflow_core_PrintStyle_HPP
-
-#include <string>
-
-class PrintStyle {
-public:
-    // Use to control the print defs/node output to string or file
-    // Please note: with PrintStyle::NET is used to transfer Defs between client <-> server
-    //              as such there is no need extensive checking on recreating defs.
-    //              i.e. valid name, duplicate nodes, etc
-    enum Type_t {
-        // Does nothing
-        NOTHING = 0,
-
-        // Output the definition that is fully parse-able                       -> On reload *CHECK* everything
-        DEFS = 1,
-
-        // Output definition that includes Node state, and AST, fully parseable -> On reload *CHECK* everything
-        STATE = 2,
-
-        // Output the definition that is fully parse-able & includes state      -> On reload *CHECK* everything
-        MIGRATE = 3,
-
-        // Output the definition that is fully parse-able & includes state      -> On reload relax checking
-        NET = 4
-    };
-
-    explicit PrintStyle(Type_t t) : old_style_(getStyle()) { setStyle(t); }
-
-    // Disable default construction
-    PrintStyle() = delete;
-    // Disable copy (and move) semantics
-    PrintStyle(const PrintStyle&)            = delete;
-    PrintStyle& operator=(const PrintStyle&) = delete;
-
-    ~PrintStyle() { setStyle(old_style_); } // reset to old style on destruction
-
-    /// We want to control the output, so that we can dump in old style defs format
-    /// or choose to dump for debug.
-    static Type_t getStyle();
-    static void setStyle(Type_t);
-
-    static bool defsStyle();
-    static bool persist_style();
-    static bool is_persist_style(Type_t);
-
-    // return current style as a string
-    static std::string to_string();
-    static std::string to_string(PrintStyle::Type_t);
-
-private:
-    Type_t old_style_;
-};
-
-#endif /* ecflow_core_PrintStyle_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/SState.cpp 5.13.0-1/ACore/src/ecflow/core/SState.cpp
--- 5.12.4-1/ACore/src/ecflow/core/SState.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/SState.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/SState.hpp"
-
-#include <cassert>
-
-#include "ecflow/core/Enumerate.hpp"
-
-namespace ecf::detail {
-
-template <>
-struct EnumTraits<SState::State>
-{
-    using underlying_t = std::underlying_type_t<SState::State>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(SState::State::HALTED, "HALTED"),
-        std::make_pair(SState::State::SHUTDOWN, "SHUTDOWN"),
-        std::make_pair(SState::State::RUNNING, "RUNNING")
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<SState::State>::size == map.back().first + 1);
-};
-
-} // namespace ecf::detail
-
-std::string SState::to_string(int status) {
-    return to_string(static_cast<SState::State>(status));
-}
-
-std::string SState::to_string(SState::State state) {
-    if (auto found = ecf::Enumerate<SState::State>::to_string(state); found) {
-        return std::string{found.value()};
-    }
-    return "UNKNOWN??";
-}
-
-SState::State SState::toState(const std::string& str) {
-    if (auto found = ecf::Enumerate<SState::State>::to_enum(str); found) {
-        return found.value();
-    }
-    assert(false);
-    return SState::HALTED;
-}
-
-bool SState::isValid(const std::string& state) {
-    return ecf::Enumerate<SState::State>::is_valid(state);
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/SState.hpp 5.13.0-1/ACore/src/ecflow/core/SState.hpp
--- 5.12.4-1/ACore/src/ecflow/core/SState.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/SState.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_SState_HPP
-#define ecflow_core_SState_HPP
-
-#include <string>
-
-class SState {
-public:
-    /// The following table shows the effect of state, on server behaviour:
-    ///
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    enum State { HALTED, SHUTDOWN, RUNNING };
-
-    // Disable default construction
-    SState() = delete;
-    // Disable copy (and move) semantics
-    SState(const SState&)                  = delete;
-    const SState& operator=(const SState&) = delete;
-
-    /// Given an integer return the server state as a string.
-    /// if int is not  0,1,2 return "UNKNOWN
-    static std::string to_string(int status);
-    static std::string to_string(SState::State);
-
-    static SState::State toState(const std::string&);
-    static bool isValid(const std::string&);
-};
-
-#endif /* ecflow_core_SState_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Serialization.hpp 5.13.0-1/ACore/src/ecflow/core/Serialization.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Serialization.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Serialization.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,90 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Serialization_HPP
-#define ecflow_core_Serialization_HPP
-
-///
-/// \brief Simple class that defines the Archive types used for Serialisation
-///
-
-#include <fstream>
-#include <iostream>
-#include <string>
-
-#include <cereal/archives/json.hpp>
-#include <cereal/types/deque.hpp>
-#include <cereal/types/map.hpp>
-#include <cereal/types/memory.hpp>
-#include <cereal/types/set.hpp>
-#include <cereal/types/utility.hpp>
-#include <cereal/types/vector.hpp>
-
-#include "ecflow/core/cereal_optional_nvp.hpp"
-
-namespace ecf {
-
-template <typename T>
-void save(const std::string& fileName, const T& t) {
-    std::ofstream os(fileName);
-#ifdef DEBUG
-    cereal::JSONOutputArchive oarchive(os); // Use default Indent can be very slow
-#else
-    cereal::JSONOutputArchive oarchive(os, cereal::JSONOutputArchive::Options::NoIndent()); // Create an output archive
-#endif
-    oarchive(cereal::make_nvp(typeid(t).name(), t)); // Write the data to the archive
-}
-
-template <typename T>
-void restore(const std::string& fileName, T& restored) {
-    std::ifstream is(fileName);
-    cereal::JSONInputArchive iarchive(is); // Create an input archive
-    iarchive(restored);                    // Read the data from the archive
-}
-
-template <typename T>
-void save_as_string(std::string& outbound_data, const T& t) {
-    std::ostringstream archive_stream;
-    {
-#ifdef DEBUG
-        cereal::JSONOutputArchive oarchive(archive_stream); // Use default Indent can be very slow
-#else
-        cereal::JSONOutputArchive oarchive(archive_stream,
-                                           cereal::JSONOutputArchive::Options::NoIndent()); // Create an output archive
-#endif
-        // when archive goes out of scope it is guaranteed to have flushed its
-        // contents to its stream.
-        oarchive(cereal::make_nvp(typeid(t).name(), t)); // Write the data to the archive
-    }
-    outbound_data = archive_stream.str();
-}
-
-template <typename T>
-void restore_from_string(const std::string& archive_data, T& restored) {
-    std::istringstream archive_stream(archive_data);
-    cereal::JSONInputArchive iarchive(archive_stream); // Create an input archive
-    iarchive(restored);                                // Read the data from the archive
-}
-
-} // namespace ecf
-
-//// Place archive in CPP file requires we template specialize the archives
-//// Note that we need to instantiate for both loading and saving, even
-//// if we use a single serialize function
-#define CEREAL_TEMPLATE_SPECIALIZE(T)                                                  \
-    template void T::serialize<cereal::JSONOutputArchive>(cereal::JSONOutputArchive&); \
-    template void T::serialize<cereal::JSONInputArchive>(cereal::JSONInputArchive&)
-
-#define CEREAL_TEMPLATE_SPECIALIZE_V(T)                                                     \
-    template void T::serialize<cereal::JSONOutputArchive>(cereal::JSONOutputArchive&,       \
-                                                          std::uint32_t const /*version*/); \
-    template void T::serialize<cereal::JSONInputArchive>(cereal::JSONInputArchive&, std::uint32_t const /*version*/)
-
-#endif
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Stl.hpp 5.13.0-1/ACore/src/ecflow/core/Stl.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Stl.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Stl.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Stl_HPP
-#define ecflow_core_Stl_HPP
-
-#include <algorithm>
-
-namespace ecf {
-/// Helper struct that will aid the deletion of Pointer from a container
-template <typename T>
-struct TSeqDeletor
-{
-    void operator()(T pointer) const {
-        // std::cout << "Destroy of this pointer" << std::endl;
-        delete pointer;
-        pointer = 0;
-    }
-};
-/// This function can be used to delete the pointers in a container
-/// i.e int main (int argc, char **argv) {
-///        std::vector <std::string *> vect;
-///        vect.push_back (new std::string ("Stephane"));
-///        DeletePtrs (vect);
-///     }
-template <typename Container>
-void DeletePtrs(Container& pContainer) {
-    std::for_each(pContainer.begin(), pContainer.end(), TSeqDeletor<typename Container::value_type>());
-    pContainer.clear();
-}
-
-/// Helper struct that will aid the deletion of Pointer from a Associative container
-template <typename TPair>
-struct TAsoDeletor
-{
-    void operator()(TPair& tElem) const {
-        if (tElem.second) {
-            delete tElem.second;
-        }
-    }
-};
-/// This function can be used to delete the pointers in a Assoc container
-/// i.e int main (int argc, char **argv) {
-///        std::map <int,std::string *> theMap;
-///        theMap[0] =  new std::string ("Stephane");
-///        AssoDeletePtrs(theMap);
-///     }
-template <typename Container>
-void AssoDeletePtrs(Container& pContainer) {
-    std::for_each(pContainer.begin(), pContainer.end(), TAsoDeletor<typename Container::value_type>());
-    pContainer.clear();
-}
-} // namespace ecf
-
-#endif /* ecflow_core_Stl_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Str.cpp 5.13.0-1/ACore/src/ecflow/core/Str.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Str.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Str.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,575 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Str.hpp"
-
-#include "ecflow/core/Converter.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-const char* VALID_NODE_CHARS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_.";
-
-const char* Str::CHILD_CMD() {
-    static const char* CHILD_CMD = "chd:";
-    return CHILD_CMD;
-}
-const char* Str::USER_CMD() {
-    static const char* USER_CMD = "--";
-    return USER_CMD;
-}
-const char* Str::SVR_CMD() {
-    static const char* SVR_CMD = "svr:";
-    return SVR_CMD;
-} // Only for automatic check_pt
-
-const std::string& Str::EMPTY() {
-    static std::string empty = std::string();
-    return empty;
-}
-const std::string& Str::ROOT_PATH() {
-    static std::string root_path = "/";
-    return root_path;
-}
-const std::string& Str::PATH_SEPERATOR() {
-    static std::string path_sep = "/";
-    return path_sep;
-}
-const std::string& Str::COLON() {
-    static std::string colon = ":";
-    return colon;
-}
-
-const std::string& Str::STATE_CHANGE() {
-    static std::string state_change = "   state change ";
-    return state_change;
-}
-
-const std::string& Str::TASK() {
-    static std::string task = "TASK";
-    return task;
-}
-const std::string& Str::FAMILY() {
-    static std::string family = "FAMILY";
-    return family;
-}
-const std::string& Str::SUITE() {
-    static std::string suite = "SUITE";
-    return suite;
-}
-const std::string& Str::ALIAS() {
-    static std::string alias = "ALIAS";
-    return alias;
-}
-
-const std::string& Str::DEFAULT_PORT_NUMBER() {
-    static std::string port_number = "3141";
-    return port_number;
-}
-const std::string& Str::LOCALHOST() {
-    static std::string localhost = "localhost";
-    return localhost;
-}
-
-const std::string& Str::ECF_PORT() {
-    static std::string ECF_PORT = "ECF_PORT";
-    return ECF_PORT;
-}
-const std::string& Str::ECF_RID() {
-    static std::string ECF_RID = "ECF_RID";
-    return ECF_RID;
-}
-const std::string& Str::ECF_TRYNO() {
-    static std::string ECF_TRYNO = "ECF_TRYNO";
-    return ECF_TRYNO;
-}
-const std::string& Str::ECF_TRIES() {
-    static std::string ECF_TRIES = "ECF_TRIES";
-    return ECF_TRIES;
-}
-const std::string& Str::ECF_NAME() {
-    static std::string ECF_NAME = "ECF_NAME";
-    return ECF_NAME;
-}
-const std::string& Str::ECF_HOST() {
-    static std::string ECF_HOST = "ECF_HOST";
-    return ECF_HOST;
-}
-const std::string& Str::ECF_PASS() {
-    static std::string ECF_PASS = "ECF_PASS";
-    return ECF_PASS;
-}
-const std::string& Str::ECF_JOB() {
-    static std::string ECF_JOB = "ECF_JOB";
-    return ECF_JOB;
-}
-const std::string& Str::ECF_JOBOUT() {
-    static std::string ECF_JOBOUT = "ECF_JOBOUT";
-    return ECF_JOBOUT;
-}
-const std::string& Str::ECF_SCRIPT() {
-    static std::string ECF_SCRIPT = "ECF_SCRIPT";
-    return ECF_SCRIPT;
-}
-const std::string& Str::ECF_DUMMY_TASK() {
-    static std::string ECF_DUMMY_TASK = "ECF_DUMMY_TASK";
-    return ECF_DUMMY_TASK;
-}
-const std::string& Str::ECF_NO_SCRIPT() {
-    static std::string ECF_NO_SCRIPT = "ECF_NO_SCRIPT";
-    return ECF_NO_SCRIPT;
-}
-const std::string& Str::ECF_MICRO() {
-    static std::string ECF_MICRO = "ECF_MICRO";
-    return ECF_MICRO;
-}
-const std::string& Str::ECF_FILES() {
-    static std::string ECF_FILES = "ECF_FILES";
-    return ECF_FILES;
-}
-const std::string& Str::ECF_FETCH() {
-    static std::string ECF_FETCH = "ECF_FETCH";
-    return ECF_FETCH;
-}
-const std::string& Str::ECF_KILL_CMD() {
-    static std::string ECF_KILL_CMD = "ECF_KILL_CMD";
-    return ECF_KILL_CMD;
-}
-const std::string& Str::ECF_STATUS_CMD() {
-    static std::string ECF_STATUS_CMD = "ECF_STATUS_CMD";
-    return ECF_STATUS_CMD;
-}
-
-const std::string& Str::ECF_HOME() {
-    static std::string ECF_HOME = "ECF_HOME";
-    return ECF_HOME;
-}
-const std::string& Str::ECF_INCLUDE() {
-    static std::string ECF_INCLUDE = "ECF_INCLUDE";
-    return ECF_INCLUDE;
-}
-const std::string& Str::ECF_JOB_CMD() {
-    static std::string ECF_JOB_CMD = "ECF_JOB_CMD";
-    return ECF_JOB_CMD;
-}
-const std::string& Str::ECF_OUT() {
-    static std::string ECF_OUT = "ECF_OUT";
-    return ECF_OUT;
-}
-const std::string& Str::ECF_EXTN() {
-    static std::string ECF_EXTN = "ECF_EXTN";
-    return ECF_EXTN;
-}
-const std::string& Str::ECF_LOG() {
-    static std::string ECF_LOG = "ECF_LOG";
-    return ECF_LOG;
-}
-
-const std::string& Str::WHITE_LIST_FILE() {
-    static std::string WHITE_LIST_FILE = "ecf.lists";
-    return WHITE_LIST_FILE;
-}
-const std::string& Str::ECF_PASSWD() {
-    static std::string ECF_PASSWD = "ecf.passwd";
-    return ECF_PASSWD;
-}
-const std::string& Str::ECF_CUSTOM_PASSWD() {
-    static std::string ECF_CUSTOM_PASSWD = "ecf.custom_passwd";
-    return ECF_CUSTOM_PASSWD;
-}
-
-const std::string& Str::ALPHANUMERIC_UNDERSCORE() {
-    static string ALPHANUMERIC_UNDERSCORE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_";
-    return ALPHANUMERIC_UNDERSCORE;
-}
-
-const std::string& Str::NUMERIC() {
-    static string NUMERIC = "0123456789";
-    return NUMERIC;
-}
-
-void Str::removeQuotes(std::string& s) {
-    if (!s.empty()) {
-        if (s[0] == '"' && s[s.size() - 1] == '"') {
-            s.erase(s.begin());
-            s.erase(s.begin() + s.size() - 1);
-        }
-    }
-}
-// 047 is octal for '
-void Str::removeSingleQuotes(std::string& s) {
-    if (!s.empty()) {
-        if (s[0] == 047 && s[s.size() - 1] == 047) {
-            s.erase(s.begin());
-            s.erase(s.begin() + s.size() - 1);
-        }
-    }
-}
-
-bool Str::replace(std::string& jobLine, const std::string& stringToFind, const std::string& stringToReplace) {
-    size_t pos = jobLine.find(stringToFind);
-    if (pos != string::npos) {
-        jobLine.replace(pos, stringToFind.length(), stringToReplace);
-        return true;
-    }
-    return false;
-}
-
-bool Str::replace_all(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace) {
-    bool replaced = false;
-    size_t pos    = 0;
-    while ((pos = subject.find(stringToFind, pos)) != std::string::npos) {
-        subject.replace(pos, stringToFind.length(), stringToReplace);
-        pos += stringToReplace.length();
-        replaced = true;
-    }
-    return replaced;
-}
-
-bool Str::extract_data_member_value(const std::string& str,
-                                    const std::string& data_member_name,
-                                    std::string& data_member_value) {
-    //        012345678901234567,
-    //    str=cmd 1 user:mao
-    //    data_member_name=user:
-    //    data_member_value=ma0
-    std::string::size_type start = str.find(data_member_name);
-    if (start != std::string::npos) {
-        start += data_member_name.size();
-        data_member_value.clear();
-        for (size_t i = start; i < str.size(); i++) {
-            if (str[i] == ' ')
-                break;
-            data_member_value += str[i];
-        }
-        return true;
-    }
-    return false;
-}
-
-void Str::replaceall(std::string& subject, const std::string& search, const std::string& replace) {
-    boost::replace_all(subject, search, replace);
-}
-
-#define USE_STRINGSPLITTER 1
-void Str::split(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters) {
-#ifdef USE_STRINGSPLITTER
-    Str::split_using_string_view(line, tokens, delimiters);
-#else
-    Str::split_orig(line, tokens, delimiters);
-#endif
-    //   This test will split a line 1000000 times: 'This is a long string that is going to be used to test the
-    //   performance of splitting with different Implementations the fastest times wins ' Time for istreamstream 1000000
-    //   times = 2.131s wall, (2.140s user + 0.000s system = 2.140s) CPU (100.4%) Time for std::getline 1000000 times
-    //   = 1.490s wall, (1.490s user + 0.000s system = 1.490s) CPU (100.0%) Time for boost::split 1000000 times = 0.930s
-    //   wall, (0.920s user + 0.000s system = 0.920s) CPU (99.0%) Time for Str::split_orig 1000000               times
-    //   = 1.065s wall, (1.070s user + 0.000s system = 1.070s) CPU (100.5%) Time for Str::split_orig1 1000000 times =
-    //   0.561s wall, (0.560s user + 0.000s system = 0.560s) CPU (99.9%) Time for Str::split_using_string_view2 1000000
-    //   times = 0.686s wall, (0.690s user + 0.000s system = 0.690s) CPU (100.6%) Time for Str::split_using_string_view
-    //   1000000  times = 0.482s wall, (0.480s user + 0.000s system = 0.480s) CPU (99.6%) Time for
-    //   make_split_iterator::split 1000000    times = 3.611s wall, (3.610s user + 0.000s system = 3.610s) CPU (100.0%)
-    //   Time for std::string_view 1000000            times = 0.769s wall, (0.770s user + 0.000s system = 0.770s) CPU
-    //   (100.1%) Time for std::string_view(2) 1000000         times = 0.688s wall, (0.690s user + 0.000s system =
-    //   0.690s) CPU (100.3%)
-    //  ACore:: ...test_str_split_perf_with_file
-    //   This test will split each line in file ${ECF_TEST_DEFS_DIR}vsms2.31415.def
-    //   Time for istreamstream 2001774                 times = 1.567s wall, (1.570s user + 0.000s system = 1.570s) CPU
-    //   (100.2%) Time for std::getline 2001774                  times = 2.456s wall, (2.460s user + 0.000s system
-    //   = 2.460s) CPU (100.2%) Time for boost::split 2001774                  times = 1.698s wall, (1.690s user +
-    //   0.000s system = 1.690s) CPU (99.5%) Time for Str::split_orig 2001774               times = 0.822s wall, (0.830s
-    //   user + 0.000s system = 0.830s) CPU (101.0%) Time for Str::split_orig1 2001774              times = 0.502s wall,
-    //   (0.500s user + 0.000s system = 0.500s) CPU (99.7%) Time for Str::split_using_string_view 2001774  times =
-    //   0.489s wall, (0.490s user + 0.000s system = 0.490s) CPU (100.3%) Time for Str::split_using_string_view2 2001774
-    //   times = 0.639s wall, (0.630s user + 0.000s system = 0.630s) CPU (98.6%) Time for boost::make_split_iterator
-    //   2001774    times = 3.338s wall, (3.340s user + 0.000s system = 3.340s) CPU (100.1%) Time for std::string_view
-    //   2001774            times = 0.599s wall, (0.600s user + 0.000s system = 0.600s) CPU (100.1%) Time for
-    //   std::string_view(2) 2001774         times = 0.696s wall, (0.700s user + 0.000s system = 0.700s) CPU (100.6%)
-}
-
-void Str::split_orig(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters) {
-    // Skip delimiters at beginning.
-    string::size_type lastPos = line.find_first_not_of(delimiters, 0);
-
-    // Find first "non-delimiter".
-    string::size_type pos = line.find_first_of(delimiters, lastPos);
-
-    while (string::npos != pos || string::npos != lastPos) {
-        tokens.push_back(line.substr(lastPos, pos - lastPos)); // Found a token, add it to the vector.
-        lastPos = line.find_first_not_of(delimiters, pos);     // Skip delimiters.  Note the "not_of"
-        pos     = line.find_first_of(delimiters, lastPos);     // Find next "non-delimiter"
-    }
-}
-
-void Str::split_orig1(const std::string& line, std::vector<std::string>& tokens, const std::string& delims) {
-    auto first = std::cbegin(line);
-    auto end   = std::cend(line);
-
-    while (first != end) {
-        const auto second = std::find_first_of(first, end, std::cbegin(delims), std::cend(delims));
-
-        if (first != second)
-            tokens.emplace_back(first, second);
-
-        if (second == end)
-            break;
-
-        first = std::next(second);
-    }
-}
-
-void Str::split_using_string_view(std::string_view strv, std::vector<std::string>& output, std::string_view delims) {
-    // Uses pointers
-    for (auto first = strv.data(), second = strv.data(), last = first + strv.size(); second != last && first != last;
-         first = second + 1) {
-        second = std::find_first_of(first, last, std::cbegin(delims), std::cend(delims));
-
-        if (first != second)
-            output.emplace_back(first, second - first);
-    }
-}
-
-void Str::split_using_string_view2(std::string_view strv, std::vector<std::string>& output, std::string_view delims) {
-    size_t first = 0;
-
-    size_t strv_size = strv.size();
-    while (first < strv_size) {
-        const auto second = strv.find_first_of(delims, first);
-
-        if (first != second) {
-            std::string_view ref = strv.substr(first, second - first);
-            output.emplace_back(ref.begin(), ref.end());
-        }
-
-        if (second == std::string_view::npos)
-            break;
-
-        first = second + 1;
-    }
-}
-
-bool Str::get_token(std::string_view str, size_t pos, std::string& token, std::string_view delims) {
-    //   Time for StringSplitter::get_token 250000 times = 1.457s wall, (1.460s user + 0.000s system = 1.460s) CPU
-    //   (100.2%) Time for Str::get_token            250000 times = 0.566s wall, (0.560s user + 0.000s system = 0.560s)
-    //   CPU (99.0%) Time for Str::get_token2           250000 times = 0.668s wall, (0.670s user + 0.000s system =
-    //   0.670s) CPU (100.3%) Time for Str::get_token3           250000 times = 0.620s wall, (0.620s user + 0.000s
-    //   system = 0.620s) CPU (100.0%)
-
-    size_t current_pos = 0;
-    auto first         = std::cbegin(str);
-    auto end           = std::cend(str);
-
-    while (first != end) {
-        const auto second = std::find_first_of(first, end, std::cbegin(delims), std::cend(delims));
-
-        if (first != second) {
-            if (current_pos == pos) {
-                token = std::string(first, second);
-                return true;
-            }
-            current_pos++;
-        }
-
-        if (second == end)
-            break;
-
-        first = std::next(second);
-    }
-    return false;
-}
-
-bool Str::get_token2(std::string_view strv, size_t pos, std::string& token, std::string_view delims) {
-    size_t current_pos = 0;
-    size_t first       = 0;
-    while (first < strv.size()) {
-        const auto second = strv.find_first_of(delims, first);
-
-        if (first != second) {
-            if (current_pos == pos) {
-                std::string_view ref = strv.substr(first, second - first);
-                token                = std::string(ref.begin(), ref.end());
-                return true;
-            }
-            current_pos++;
-        }
-
-        if (second == std::string_view::npos)
-            break;
-
-        first = second + 1;
-    }
-    return false;
-}
-
-bool Str::get_token3(std::string_view str, size_t pos, std::string& token, std::string_view delims) {
-    size_t current_pos = 0;
-    for (auto first = str.data(), second = str.data(), last = first + str.size(); second != last && first != last;
-         first = second + 1) {
-
-        second = std::find_first_of(first, last, std::cbegin(delims), std::cend(delims));
-        if (first != second) {
-            if (current_pos == pos) {
-                token = std::string(first, second - first);
-                return true;
-            }
-            current_pos++;
-        }
-    }
-    return false;
-}
-
-boost::split_iterator<std::string::const_iterator> Str::make_split_iterator(const std::string& line,
-                                                                            const std::string& delimiters) {
-    return boost::make_split_iterator(
-        line, boost::algorithm::token_finder(boost::is_any_of(delimiters), boost::algorithm::token_compress_on));
-}
-
-static bool caseInsCharCompare(char a, char b) {
-    return (toupper(a) == toupper(b));
-}
-
-bool Str::caseInsCompare(const std::string& s1, const std::string& s2) {
-    return ((s1.size() == s2.size()) && equal(s1.begin(), s1.end(), s2.begin(), caseInsCharCompare));
-}
-
-bool Str::caseInsLess(const std::string& a, const std::string& b) {
-    return std::lexicographical_compare(a.begin(), a.end(), b.begin(), b.end(), [](char x, char y) -> bool {
-        if (toupper(x) == toupper(y)) {
-            return x > y;
-        }
-        return toupper(static_cast<unsigned char>(x)) < toupper(static_cast<unsigned char>(y));
-    });
-}
-
-bool Str::caseInsGreater(const std::string& a, const std::string& b) {
-    return std::lexicographical_compare(a.begin(), a.end(), b.begin(), b.end(), [](char x, char y) -> bool {
-        if (toupper(x) == toupper(y)) {
-            return x < y;
-        }
-        return toupper(static_cast<unsigned char>(x)) > toupper(static_cast<unsigned char>(y));
-    });
-}
-
-bool Str::valid_name(const std::string& name, std::string& msg) {
-    // valid names are alphabetic (alphanumeric | underscore | .)
-    // however we can't have a leading '.' as that can interfere with trigger expressions
-
-    // verify that the string is not empty
-    if (name.empty()) {
-        msg = "Invalid name. Empty string.";
-        return false;
-    }
-
-    // verify that the first character is alphanumeric or is an underscore
-    bool result = Str::ALPHANUMERIC_UNDERSCORE().find(name[0], 0) != string::npos;
-    if (!result) {
-        msg = "Valid names can only consist of alphanumeric characters, "
-              "underscores and dots (The first character cannot be a dot). "
-              "The first character is not valid (only alphanumeric or an underscore is allowed): ";
-        msg += name;
-        return false;
-    }
-
-    // verify that any other characters are alphanumeric or underscore
-    if (name.size() > 1) {
-        result = name.find_first_not_of(VALID_NODE_CHARS, 1) == string::npos;
-        if (!result) {
-            msg = "Valid names can only consist of alphanumeric characters, "
-                  "underscores and dots (The first character cannot be a dot). ";
-            if (name.find('\r') != string::npos)
-                msg += "Windows line ending ? ";
-            msg += "'";
-            msg += name;
-            msg += "'"; // use '<name>' to show if PC format. i.e carriage return
-        }
-    }
-
-    return result;
-}
-
-bool Str::valid_name(const std::string& name) {
-    // valid names are alphabetic (alphanumeric | underscore | .)
-    // however we can't have a leading '.' as that can interfere with trigger expressions
-
-    // verify that the string is not empty
-    if (name.empty()) {
-        return false;
-    }
-
-    // verify that the first character is alphabetic or has underscore
-    bool result = Str::ALPHANUMERIC_UNDERSCORE().find(name[0], 0) != string::npos;
-    if (!result) {
-        return false;
-    }
-
-    // verify that any other characters are alphanumeric or underscore
-    if (name.size() > 1) {
-        result = name.find_first_not_of(VALID_NODE_CHARS, 1) == string::npos;
-    }
-
-    return result;
-}
-
-int Str::to_int(const std::string& the_str, int error_return) {
-    if (the_str.find_first_of(Str::NUMERIC(), 0) != std::string::npos) {
-        try {
-            return ecf::convert_to<int>(the_str);
-        }
-        catch (const ecf::bad_conversion&) {
-        }
-    }
-    return error_return;
-}
-
-bool Str::truncate_at_start(std::string& fileContents, size_t max_lines) {
-    if (fileContents.empty())
-        return false;
-
-    /// Truncate from the front
-    size_t no_of_new_lines = 0;
-    for (size_t i = fileContents.size() - 1; i > 0; --i) {
-        if (fileContents[i] == '\n')
-            no_of_new_lines++;
-        if (no_of_new_lines >= max_lines) {
-            fileContents.erase(fileContents.begin(), fileContents.begin() + i + 1); // skip new line at start of file
-            return true;
-        }
-    }
-    return false;
-}
-
-bool Str::truncate_at_end(std::string& fileContents, size_t max_lines) {
-    if (fileContents.empty())
-        return false;
-
-    /// Truncate from the back
-    size_t no_of_new_lines = 0;
-    size_t the_size        = fileContents.size();
-    for (size_t i = 0; i < the_size; ++i) {
-        if (fileContents[i] == '\n')
-            no_of_new_lines++;
-        if (no_of_new_lines >= max_lines) {
-            fileContents.erase(fileContents.begin() + i + 1, fileContents.end()); // skip new line at end of file
-            return true;
-        }
-    }
-    return false;
-}
-
-std::string Str::dump_string_vec(const std::vector<std::string>& vec) {
-    std::string str;
-    for (const auto& s : vec) {
-        str += s;
-        str += "\n";
-    }
-    return str;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Str.hpp 5.13.0-1/ACore/src/ecflow/core/Str.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Str.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Str.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,241 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Str_HPP
-#define ecflow_core_Str_HPP
-
-#include <cstring>
-#include <limits>
-#include <string>
-#include <string_view>
-#include <vector>
-
-#include <boost/algorithm/string.hpp>
-
-namespace ecf {
-
-namespace algorithm {
-
-template <typename Sequence1, typename Sequence2 = std::string>
-inline static auto join(const Sequence1& strings, const Sequence2& separator = std::string(", ")) {
-    return ::boost::algorithm::join(strings, separator);
-}
-
-template <typename Sequence, typename SearchSequence, typename ReplaceSequence>
-inline static auto replace_first(Sequence& input, const SearchSequence& search, const ReplaceSequence& replace) {
-    return ::boost::algorithm::replace_first(input, search, replace);
-}
-
-template <typename ResultSequence, typename Sequence1, typename Sequence2>
-inline static ResultSequence& split(ResultSequence& result, const Sequence1& input, const Sequence2& separators) {
-    return ::boost::algorithm::split(result, input, ::boost::is_any_of(separators));
-}
-
-template <typename Sequence1, typename Sequence2>
-inline static bool starts_with(const Sequence1& input, const Sequence2& pattern) {
-    return ::boost::algorithm::starts_with(input, pattern);
-}
-
-template <typename Sequence>
-inline static void trim(Sequence& input) {
-    ::boost::algorithm::trim(input);
-}
-
-template <typename T>
-static std::vector<std::string> transform_to_name_vector(const std::vector<T>& i) {
-    std::vector<std::string> o;
-    o.reserve(i.size());
-    std::transform(std::begin(i), std::end(i), std::back_inserter(o), [](const auto& v) { return v->name(); });
-    return o;
-}
-
-inline std::string tolower(std::string s) {
-    std::transform(std::begin(s), std::end(s), std::begin(s), [](unsigned char c) { return std::tolower(c); });
-    return s;
-}
-
-} // namespace algorithm
-
-class Str {
-public:
-    // Disable default construction
-    Str() = delete;
-    // Disable copy (and move) semantics
-    Str(const Str&)                  = delete;
-    const Str& operator=(const Str&) = delete;
-
-    static int reserve_4() { return 4; }
-    static int reserve_8() { return 8; }
-    static int reserve_16() { return 17; }
-    static int reserve_32() { return 32; }
-    static int reserve_64() { return 64; }
-
-    // remove any quotes on the string, else does nothing
-    // "fred" -> fred
-    //  fred  -> fred
-    static void removeQuotes(std::string&);
-
-    // remove any single quotes on the string, else does nothing
-    // 'fred' -> fred
-    //  fred  -> fred
-    static void removeSingleQuotes(std::string&);
-
-    /// Find 'stringToFind' in 'jobLine' and replace with string 'stringToReplace'
-    /// return true if replace ok else returns false;
-    static bool replace(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace);
-    static bool replace_all(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace);
-    static void replaceall(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace);
-
-    // extract data member value, ie given a string of the form:
-    //   str=cmd a b fred:value
-    //   data_member_name=fred:
-    //   extract value
-    static bool extract_data_member_value(const std::string& str,
-                                          const std::string& data_member_name,
-                                          std::string& data_member_value);
-
-    /// split string using default delimiters of space and tab as a separator;
-    /// The split is based on *ANY* of the characters in the delimiters.
-    /// **** Hence a delimiter of "==" will still split "a = complete"
-    /// **** sequential delimiter character are ignored ****
-    /// This function is used to choose the fastest implementation
-    static void split(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters = " \t");
-
-    static void
-    split_orig(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters = " \t");
-
-    static void
-    split_orig1(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters = " \t");
-
-    static void split_using_string_view(std::string_view line,
-                                        std::vector<std::string>& tokens,
-                                        std::string_view delimiters = " \t");
-
-    static void split_using_string_view2(std::string_view line,
-                                         std::vector<std::string>& tokens,
-                                         std::string_view delimiters = " \t");
-
-    // Get token at a given pos. Two different implementations
-    static bool get_token(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
-    static bool get_token2(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
-    static bool get_token3(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
-
-    // Uses boost::make_split_iterator will remove
-    // consecutive delimiters in the middle of the string
-    // ** However preserves leading and trailing empty tokens *IF* delimiters at start/end
-    //
-    // Usage:
-    //    boost::split_iterator<std::string::const_iterator> tokens = Str::make_split_iterator(str);
-    //    for(; !tokens.eof(); ++tokens ) {
-    //       boost::iterator_range<string::const_iterator> range = *tokens;
-    //       std::string the_string(range.begin(), range.end()) ;
-    //    }
-    //
-    //    std::vector<std::string> vec;
-    //    typedef boost::split_iterator<std::string::const_iterator> split_iter_t;
-    //    for(split_iter_t i = Str::split(s,delim); i != split_iter_t(); i++) {
-    //       vec.push_back(boost::copy_range<std::string>(*i));
-    //    }
-    static boost::split_iterator<std::string::const_iterator>
-    make_split_iterator(const std::string& str, const std::string& delimiters = " \t");
-
-    /// case in sensitive string comparison
-    static bool caseInsCompare(const std::string&, const std::string&);
-
-    /// case insensitive less
-    static bool caseInsLess(const std::string&, const std::string&);
-
-    /// case insensitive Greater
-    static bool caseInsGreater(const std::string&, const std::string&);
-
-    /// Used for checking node names
-    static bool valid_name(const std::string& name, std::string& msg);
-    static bool valid_name(const std::string& name);
-
-    /// This function checks if the given string actually has any digits before attempting the conversion;
-    /// this approach is faster than using ecf::convert_to<int> directly (and thus always attempt to
-    /// perform the conversion).
-    /// Use this function when it is not possible to ensure the string is convertible to an integer (e.g. user input).
-    ///
-    /// This function return the given `error_return` (by default, numeric_limits<int>::max()),
-    /// in cases where the conversion is invalid.
-    static int to_int(const std::string&, int error_return = std::numeric_limits<int>::max());
-
-    /// Truncate the input string at the start/end if exceeds max_lines_ newlines
-    /// returns true if truncated false otherwise
-    static bool truncate_at_start(std::string& fileContents, size_t max_lines);
-    static bool truncate_at_end(std::string& fileContents, size_t max_lines);
-
-    static std::string dump_string_vec(const std::vector<std::string>& vec);
-
-    /// Only use strcmp if the first characters are the same
-    static int local_strcmp(const char* s, const char* t) { return (*s != *t ? *s - *t : strcmp(s, t)); }
-
-    // returns a static string of alphanumerics and underscore
-    static const std::string& ALPHANUMERIC_UNDERSCORE();
-
-    // returns a static string of numerics chars
-    static const std::string& NUMERIC();
-
-    static const char* CHILD_CMD();
-    static const char* USER_CMD();
-    static const char* SVR_CMD(); // Only for automatic check_pt
-
-    // Allows string to be returned by reference
-    static const std::string& EMPTY();
-    static const std::string& ROOT_PATH();      // "/"
-    static const std::string& PATH_SEPERATOR(); // "/"
-    static const std::string& COLON();          // ":"
-
-    static const std::string& STATE_CHANGE();
-
-    static const std::string& TASK();
-    static const std::string& FAMILY();
-    static const std::string& SUITE();
-    static const std::string& ALIAS();
-
-    static const std::string& DEFAULT_PORT_NUMBER(); // "3141"
-    static const std::string& LOCALHOST();
-
-    static const std::string& ECF_PORT();
-    static const std::string& ECF_RID();
-    static const std::string& ECF_TRYNO();
-    static const std::string& ECF_TRIES();
-    static const std::string& ECF_NAME();
-    static const std::string& ECF_HOST();
-    static const std::string& ECF_PASS();
-    static const std::string& ECF_JOB();
-    static const std::string& ECF_JOBOUT();
-    static const std::string& ECF_SCRIPT();
-    static const std::string& ECF_DUMMY_TASK();
-    static const std::string& ECF_NO_SCRIPT();
-    static const std::string& ECF_MICRO();
-    static const std::string& ECF_FILES();
-    static const std::string& ECF_FETCH();
-    static const std::string& ECF_KILL_CMD();
-    static const std::string& ECF_STATUS_CMD();
-
-    static const std::string& ECF_HOME();
-    static const std::string& ECF_INCLUDE();
-    static const std::string& ECF_JOB_CMD();
-    static const std::string& ECF_OUT();
-    static const std::string& ECF_EXTN();
-    static const std::string& ECF_LOG();
-
-    static const std::string& WHITE_LIST_FILE();
-    static const std::string& ECF_PASSWD();
-    static const std::string& ECF_CUSTOM_PASSWD();
-
-    static const char* cpu_timer_format() { return "%ws wall, (%us user + %ss system = %ts) CPU (%p%)"; }
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_Str_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/StringSplitter.cpp 5.13.0-1/ACore/src/ecflow/core/StringSplitter.cpp
--- 5.12.4-1/ACore/src/ecflow/core/StringSplitter.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/StringSplitter.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/StringSplitter.hpp"
-
-namespace ecf {
-
-bool StringSplitter::finished() const {
-    // Skip delimiters at beginning. so for an empty string or string of just separators, we do not call next()
-    // This mirrors the old split functionality
-    if (finished_)
-        return true;
-    first_not_of_ = rem_.find_first_not_of(sep_);
-    if (first_not_of_ == std::string_view::npos)
-        finished_ = true;
-    return finished_;
-}
-
-std::string_view StringSplitter::next() const {
-    if (first_not_of_ != 0)
-        rem_ = rem_.substr(first_not_of_);
-
-    std::string_view::size_type pos = rem_.find_first_of(sep_); // Find first "non-delimiter".
-    if (pos != std::string_view::npos) {
-        std::string_view ret = rem_.substr(0, pos);
-        rem_                 = rem_.substr(pos + 1); // skip over separator
-
-        // if separator is at the end, lose the last empty tokens
-        if (rem_.find_first_not_of(sep_) == std::string_view::npos) {
-            finished_ = true;
-        }
-        return ret;
-    }
-
-    finished_ = true;
-    return rem_;
-}
-
-void StringSplitter::reset() {
-    rem_      = src_;
-    finished_ = false;
-}
-
-void StringSplitter::split(const std::string& str,
-                           std::vector<std::string_view>& lineTokens,
-                           std::string_view delimiters) {
-    StringSplitter string_splitter(str, delimiters);
-    while (!string_splitter.finished()) {
-        lineTokens.push_back(string_splitter.next());
-    }
-}
-
-void StringSplitter::split2(std::string_view str, std::vector<std::string_view>& ret, const char* delimiters) {
-    std::string_view::size_type start = 0;
-
-    auto pos = str.find_first_of(delimiters, start);
-    while (pos != std::string_view::npos) {
-        if (pos != start) {
-            ret.emplace_back(str.substr(start, pos - start));
-        }
-        start = pos + 1;
-        pos   = str.find_first_of(delimiters, start);
-    }
-    if (start < str.length())
-        ret.emplace_back(str.substr(start, str.length() - start));
-}
-
-void StringSplitter::split(const std::string& str, std::vector<std::string>& lineTokens, std::string_view delimiters) {
-    StringSplitter string_splitter(str, delimiters);
-    while (!string_splitter.finished()) {
-        std::string_view ref = string_splitter.next();
-        lineTokens.emplace_back(ref.begin(), ref.end());
-    }
-}
-
-bool StringSplitter::get_token(std::string_view line, size_t pos, std::string& token, std::string_view sep) {
-    size_t count = 0;
-    StringSplitter string_splitter(line, sep);
-    while (!string_splitter.finished()) {
-        std::string_view the_token = string_splitter.next();
-        if (count == pos) {
-            token = std::string(the_token.begin(), the_token.end());
-            return true;
-        }
-        else if (count > pos)
-            return false;
-        count++;
-    }
-    return false;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/StringSplitter.hpp 5.13.0-1/ACore/src/ecflow/core/StringSplitter.hpp
--- 5.12.4-1/ACore/src/ecflow/core/StringSplitter.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/StringSplitter.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_StringSplitter_HPP
-#define ecflow_core_StringSplitter_HPP
-
-#include <string>
-#include <string_view>
-#include <vector>
-
-namespace ecf {
-
-// ****************************************************************************
-// IMPORTANT: std::string_view is a *READ ONLY* REFERENCE to an existing string
-// HENCE:     the reference string *MUST* not change, and its lifetime must EXCEED string_view
-//
-// Will split a string. Will return an empty std::string_view if there's a separator at the end.
-// This shows the fastest split for a string. **** Based on boost 1.64 ****
-//    Method:              time
-//    boost::split:        4.06
-//    Str::split:          2.33
-//    make_split_iterator  4.07
-//    std::string_view    1.42
-
-class StringSplitter {
-    std::string_view src_;
-    mutable std::string_view rem_;
-    std::string_view sep_;
-    mutable std::string_view::size_type first_not_of_;
-    mutable bool finished_;
-
-public:
-    explicit StringSplitter(std::string_view src, std::string_view sep = " \t")
-        : src_(src),
-          rem_(src),
-          sep_(sep),
-          first_not_of_(0),
-          finished_(false) {}
-
-    // this rules out temp strings, it also rules out char * because of two available overloads
-    StringSplitter(const std::string&& src, std::string_view sep) = delete;
-
-    // this re-enables support for string literals (which are never temp)
-    // it even handles correctly char arrays that contain a null terminated string
-    // because string_view does not have a char array constructor!
-    template <std::size_t N>
-    explicit StringSplitter(const char (&sz)[N], std::string_view sep = " \t")
-        : src_(sz),
-          rem_(sz),
-          sep_(sep),
-          first_not_of_(0),
-          finished_(false) {}
-
-    std::string_view next() const;
-    bool finished() const;
-    bool last() const { return finished_; }
-    void reset();
-
-    /// The preferred splitter as it does not create strings
-    static void
-    split(const std::string& str, std::vector<std::string_view>& lineTokens, std::string_view delimiters = " \t");
-
-    // This the fastest splitter at the moment
-    static void split2(std::string_view str, std::vector<std::string_view>& lineTokens, const char* delimiters = " \t");
-
-    /// This was added to maintain compatibility, slightly faster than original Str::split
-    static void
-    split(const std::string& str, std::vector<std::string>& lineTokens, std::string_view delimiters = " \t");
-
-    /// return the token at pos, otherwise returns false.
-    static bool get_token(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_StringSplitter_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/TimeSeries.cpp 5.13.0-1/ACore/src/ecflow/core/TimeSeries.cpp
--- 5.12.4-1/ACore/src/ecflow/core/TimeSeries.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/TimeSeries.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,963 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/TimeSeries.hpp"
-
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/cereal_boost_time.hpp"
-#ifdef DEBUG
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-// #define DEBUG_TIME_SERIES 1
-// #define DEBUG_TIME_SERIES_IS_FREE 1
-#ifdef DEBUG_TIME_SERIES_IS_FREE
-    #include "ecflow/core/Indentor.hpp"
-#endif
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-static void testTimeSlot(const ecf::TimeSlot& ts) {
-    if (ts.hour() < 0 || ts.hour() > 23) {
-        std::stringstream ss;
-        ss << "TimeSeries:  time hour(" << ts.hour() << ") must be in range 0-23";
-        throw std::out_of_range(ss.str());
-    }
-    if (ts.minute() < 0 || ts.minute() > 59) {
-        std::stringstream ss;
-        ss << "TimeSeries:  time minute(" << ts.minute() << ") must be in range 0-59";
-        throw std::out_of_range(ss.str());
-    }
-}
-
-namespace ecf {
-
-TimeSeries::TimeSeries() = default;
-
-TimeSeries::TimeSeries(int hour, int minute, bool relative)
-    : start_(hour, minute),
-      nextTimeSlot_(hour, minute),
-      lastTimeSlot_(start_.duration()),
-      relativeToSuiteStart_(relative) {
-    testTimeSlot(start_);
-}
-
-TimeSeries::TimeSeries(const TimeSlot& t, bool relative)
-    : start_(t),
-      nextTimeSlot_(t),
-      lastTimeSlot_(t.duration()),
-      relativeToSuiteStart_(relative) {
-    testTimeSlot(start_);
-}
-
-TimeSeries::TimeSeries(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative)
-    : start_(start),
-      finish_(finish),
-      incr_(incr),
-      nextTimeSlot_(start),
-      relativeToSuiteStart_(relative) {
-    testTimeSlot(start);
-    testTimeSlot(finish);
-    testTimeSlot(incr);
-
-    if (!finish_.isNULL()) {
-        if (incr_.isNULL()) {
-            std::stringstream ss;
-            ss << "TimeSeries::TimeSeries: Invalid time series: Finish specified without an increment";
-            throw std::out_of_range(ss.str());
-        }
-    }
-
-    if (start.duration() > finish.duration()) {
-        std::stringstream ss;
-        ss << "TimeSeries::TimeSeries: Invalid time series: Start time(" << start.toString()
-           << ") is greater than end time(" << finish.toString() << ")";
-        throw std::out_of_range(ss.str());
-    }
-    if (incr.hour() == 0 && incr.minute() == 0) {
-        throw std::out_of_range(
-            "TimeSeries::TimeSeries Invalid time series:  Increment must be greater than 0 minutes.");
-    }
-    boost::posix_time::time_duration diff = finish.duration() - start.duration();
-    if (incr.duration() > diff) {
-        std::stringstream ss;
-        ss << "TimeSeries::TimeSeries: Invalid time series: Increment(" << incr.toString()
-           << ") is greater than duration " << to_simple_string(diff) << " between start(" << start.toString()
-           << ") and finish(" << finish.toString() << ")";
-        throw std::out_of_range(ss.str());
-    }
-
-    compute_last_time_slot();
-
-    // #ifdef DEBUG_TIME_SERIES
-    //	cout << "TimeSeries::TimeSeries "  << dump() << "\n";
-    // #endif
-}
-
-bool TimeSeries::operator<(const TimeSeries& rhs) const {
-    return start_ < rhs.start_;
-}
-
-void TimeSeries::compute_last_time_slot() {
-    if (!finish_.isNULL()) {
-        lastTimeSlot_ = start_.duration();
-        while (lastTimeSlot_ <= finish_.duration())
-            lastTimeSlot_ += incr_.duration();
-        lastTimeSlot_ -= incr_.duration();
-    }
-}
-
-bool TimeSeries::calendarChanged(const ecf::Calendar& c) {
-    if (relativeToSuiteStart_) {
-        relativeDuration_ += c.calendarIncrement();
-        return true;
-    }
-    else if (c.dayChanged()) {
-
-        // Clear expired flag and next slot. Needed since requeuing will expire flag when pastime slot
-        // Hence we need something to reset. Otherwise, for next day isFree will always return false;
-        isValid_      = true;
-        nextTimeSlot_ = start_;
-        return true;
-    }
-    return false;
-}
-
-bool TimeSeries::resetRelativeDuration() {
-    if (relativeToSuiteStart_) {
-        relativeDuration_ = time_duration(0, 0, 0, 0);
-
-#ifdef DEBUG_TIME_SERIES
-        log(Log::DBG, "TimeSeries::resetRelativeDuration " + dump());
-#endif
-
-        return true;
-    }
-#ifdef DEBUG_TIME_SERIES
-    log(Log::DBG, "TimeSeries::resetRelativeDuration " + dump());
-#endif
-    return false;
-}
-
-void TimeSeries::reset_only() {
-    isValid_      = true;
-    nextTimeSlot_ = start_;
-    (void)resetRelativeDuration();
-}
-
-void TimeSeries::reset(const ecf::Calendar& c) {
-    reset_only();
-
-    // Note: **difference between reset and re-queue,
-    //  Hence if at begin(), time slot same as current time, allow job to run.
-    //  reset  : while( current_time >  nextTimeSlot_.duration()) {  // need for why command
-    //              if (current_time >  start_.duration() ) {
-    //  requeue: while( current_time >= nextTimeSlot_.duration()) {
-    //              if (current_time >= start_.duration() ) {
-
-    // Update nextTimeSlot_ so that why command works out of the box, when nodes have been begun.
-    // *if* the current time is *AT* the start do *not* increment nextTimeSlot_, otherwise we will miss first time slot
-    time_duration current_time = duration(c);
-    if (hasIncrement()) {
-
-        // only used when we have a series, and *NOT* relative. A relative time series does not care about midnight.
-        if (!relativeToSuiteStart_) {
-            suiteTimeAtReque_ = TimeSlot(c.suiteTime().time_of_day());
-        }
-
-        while (current_time > nextTimeSlot_.duration()) {
-            time_duration value = nextTimeSlot_.duration();
-            value += incr_.duration();
-            nextTimeSlot_ = TimeSlot(value.hours(), value.minutes());
-        }
-        if (nextTimeSlot_ > finish_) {
-            isValid_ = false; // time has expired
-        }
-    }
-    else {
-        if (current_time > start_.duration()) {
-            isValid_ = false; // time has expired
-        }
-    }
-
-#ifdef DEBUG_TIME_SERIES
-    //	LogToCout toCoutAsWell;
-    log(Log::DBG, "TimeSeries::reset   " + dump());
-#endif
-}
-
-void TimeSeries::requeue(const ecf::Calendar& c, bool reset_next_time_slot) {
-    // cout << "TimeSeries::requeue " << c.toString()  << "\n";
-
-    // *RESET* to handle case where time slot has been advanced, but at requeue it must be reset
-    // This is important otherwise user can never reset and time slot that had been advanced
-    // by using miss_next_time_slot()
-    if (reset_next_time_slot) {
-        isValid_      = true;
-        nextTimeSlot_ = start_;
-    }
-
-    //   time 13:00 // nextTimeSlot_ is initialised to 13:00, on TimeSeries::requeue() invalidate time series
-    //              // to stop multiple job submissions on same time slot
-    //                       -------------------- nextTimeSlot_
-    //                       |     -------------- isValid = false
-    //                       V     V
-    //   10:00 11:00 12:00 13:00 14:00 15:00 16:00 17:00 18:00 19:00 20:00
-    //     |     |     |     |     |     |     |     |     |     |     |
-    //  ------time----------->
-    //
-    // TimeSeries::requeue(..) is called at the *re-queue* stage. *after*:
-    //   a/ task has completed
-    //   b/ checkForRequeue() has passed.
-    // hence if we get here for a single slot time, where calendar time >= start time
-    // then this time series is no longer valid. This will stop multiple job submission
-    // for the same time slot
-    time_duration current_time = duration(c);
-    if (!hasIncrement()) {
-        if (current_time >= start_.duration()) {
-            isValid_ = false; // time has expired
-#ifdef DEBUG_TIME_SERIES
-            LOG(Log::DBG,
-                "TimeSeries::requeue HOLDING TIME EXPIRED (duration(c) >= start_.duration() ) "
-                    << dump() << " duration=" << to_simple_string(duration(c)));
-#endif
-        }
-        return;
-    }
-
-    // Only used when we have a series, and NOT relative. A relative time series does not care about midnight
-    if (!relativeToSuiteStart_) {
-        suiteTimeAtReque_ = TimeSlot(c.suiteTime().time_of_day());
-    }
-
-    // the nextTimeSlot_ needs to be set to a multiple of incr
-    // However the nextTimeSlot_ cannot just be incremented by incr
-    // since we can't assume that a task completes within the given time slots
-    // *hence increments to NEXT TIME SLOT large than calendar time.
-    // time 10::00 20:00 01:00
-    //                       --------------------------------------------------------nextTimeSlot_ must greater than
-    //                       current time. |                                               --------isValid = false V V
-    //   10:00 11:00 12:00 13:00 14:00 15:00 16:00 17:00 18:00 19:00 20:00 21:00
-    //     |     |     |     |     |     |     |     |     |     |     |     |
-    //  ------time---->
-    //
-    while (current_time >= nextTimeSlot_.duration()) {
-        time_duration value = nextTimeSlot_.duration();
-        value += incr_.duration();
-        nextTimeSlot_ = TimeSlot(value.hours(), value.minutes());
-    }
-
-    if (nextTimeSlot_ > finish_) {
-        isValid_          = false;      // time has expired
-        suiteTimeAtReque_ = TimeSlot(); // expire for new requeue
-#ifdef DEBUG_TIME_SERIES
-        log(Log::DBG, "TimeSeries::requeue  HOLDING TIME EXPIRED (nextTimeSlot_ > finish_) " + dump());
-#endif
-    }
-}
-
-TimeSlot TimeSeries::compute_next_time_slot(const ecf::Calendar& c) const {
-    // This functionality needs to mirror TimeSeries::requeue
-    time_duration current_time = duration(c);
-    if (!hasIncrement()) {
-        if (current_time >= start_.duration()) {
-            return {}; // time has expired
-        }
-        return start_;
-    }
-
-    TimeSlot nextTimeSlot = start_;
-    while (current_time >= nextTimeSlot.duration()) {
-        time_duration value = nextTimeSlot.duration();
-        value += incr_.duration();
-        nextTimeSlot = TimeSlot(value.hours(), value.minutes());
-    }
-
-    if (nextTimeSlot > finish_) {
-        return {}; // time has expired
-    }
-    return nextTimeSlot;
-}
-
-bool TimeSeries::requeueable(const ecf::Calendar& c) const {
-    boost::posix_time::time_duration calendar_time = duration(c);
-    if (calendar_time < start().duration())
-        return true;
-    if (hasIncrement()) {
-        if (calendar_time < finish().duration()) {
-            return true;
-        }
-    }
-    return false;
-}
-
-bool TimeSeries::isFree(const ecf::Calendar& calendar) const {
-#ifdef DEBUG_TIME_SERIES_IS_FREE
-    LogToCout toCoutAsWell;
-    Indentor indent;
-#endif
-
-    if (!isValid_) {
-        // time has expired, hence time is not free
-#ifdef DEBUG_TIME_SERIES_IS_FREE
-        log(Log::DBG, "TimeSeries::isFree (!isValid_) HOLDING " + dump());
-#endif
-        return false;
-    }
-
-    // Matched calendar duration with the current value of the time series
-    // or match with one of time slots.
-
-    // Note:: the definition file has time series format of hh:mm this
-    //        means we have a minute resolution. The clock/calendar
-    //        duration has seconds based resolution. hence we must
-    //        compensate for this.
-    //
-    //   time 10:00 20:00 01:00
-    //   start
-    //     |                 ----- next time slot                      --- finish
-    //     |                 |                                         |
-    //     V                 V                                         V
-    //   10:00 11:00 12:00 13:00 14:00 15:00 16:00 17:00 18:00 19:00 20:00
-    //     |     |     |     |     |     |     |     |     |     |     |
-    //  ------time---->
-    //
-    bool ret = match_duration_with_time_series(duration(calendar));
-    //	if (ret) {
-    //	   std::cout << "TimeSeries::isFree " << dump() << " is free at calendar: " << calendar.toString() << "\n";
-    //	}
-    return ret;
-}
-
-bool TimeSeries::match_duration_with_time_series(const boost::posix_time::time_duration& relative_or_real_td) const {
-#ifdef DEBUG_TIME_SERIES_IS_FREE
-    Indentor ident;
-#endif
-
-    if (!hasIncrement()) {
-        // We ignore seconds, hence +00:02  will match 2.58 (two minutes 58 seconds) relative duration
-        time_duration start_td = start_.duration();
-        if (relative_or_real_td.hours() == start_td.hours() && relative_or_real_td.minutes() == start_td.minutes()) {
-#ifdef DEBUG_TIME_SERIES_IS_FREE
-            LOG(Log::DBG,
-                "TimeSeries::match_duration_with_time_series " << dump() << " FREE at "
-                                                               << to_simple_string(relative_or_real_td));
-#endif
-            return true;
-        }
-
-#ifdef DEBUG_TIME_SERIES_IS_FREE
-        LOG(Log::DBG,
-            "TimeSeries::match_duration_with_time_series " << dump() << " HOLDING at "
-                                                           << to_simple_string(relative_or_real_td));
-#endif
-        return false;
-    }
-
-    time_duration endDuration     = finish_.duration();
-    time_duration incrDuration    = incr_.duration();
-    time_duration nextTimeSlot_td = nextTimeSlot_.duration();
-    long hours                    = relative_or_real_td.hours();
-    long minutes                  = relative_or_real_td.minutes();
-    while (nextTimeSlot_td <= endDuration) {
-
-        if (hours == nextTimeSlot_td.hours() && minutes == nextTimeSlot_td.minutes()) {
-#ifdef DEBUG_TIME_SERIES_IS_FREE
-            LOG(Log::DBG,
-                "TimeSeries::match_duration_with_time_series (nextTimeSlot_td == duration)  "
-                    << dump() << " FREE at " << to_simple_string(relative_or_real_td));
-#endif
-            return true;
-        }
-        nextTimeSlot_td += incrDuration;
-    }
-
-#ifdef DEBUG_TIME_SERIES
-    LOG(Log::DBG,
-        "TimeSeries::match_duration_with_time_series HOLDING (nextTimeSlot_td > endDuration)  "
-            << dump() << " HOLDING at " << to_simple_string(relative_or_real_td));
-#endif
-    return false;
-}
-
-void TimeSeries::miss_next_time_slot() {
-    if (!hasIncrement()) {
-        // single slot, does not have a next time slot, hence expire time
-        isValid_ = false;
-    }
-    else {
-        time_duration value = nextTimeSlot_.duration();
-        value += incr_.duration();
-        nextTimeSlot_ = TimeSlot(value.hours(), value.minutes());
-        if (nextTimeSlot_ > finish_) {
-            // time has expired,
-            isValid_ = false;
-        }
-    }
-}
-
-bool TimeSeries::checkForRequeue(const ecf::Calendar& calendar,
-                                 const TimeSlot& the_min,
-                                 const TimeSlot& the_max,
-                                 bool cmd_context) const {
-    // ************************************************************************
-    // THIS IS CALLED IN THE CONTEXT WHERE NODE HAS COMPLETED. Hence ****asynchronous****
-    // RETURNING TRUE FROM HERE WILL FORCE NODE TO QUEUED STATE
-    // HENCE THIS FUNCTION MUST RETURN FALSE, WHEN END OF TIME SLOT HAS BEEN REACHED/expired
-    // The resolution is in minutes
-    // *************************************************************************
-    // cout << "TimeSeries::checkForRequeue " << calendar.suite_time_str() << " min: " << the_min << " max: " << the_max
-    // << " cmd_context(" << cmd_context << ") +++++++++++++++\n";
-#ifdef DEBUG_TIME_SERIES
-    log(Log::DBG, "TimeSeries::checkForRequeue: " + dump());
-#endif
-
-    if (!isValid_) {
-        // time has expired, hence can no longer re-queues, i.e no future time dependency
-#ifdef DEBUG_TIME_SERIES
-        // cout << " TimeSeries::checkForRequeue " << calendar.suite_time_str() << "  HOLDING\n";
-        log(Log::DBG, "TimeSeries::checkForRequeue HOLDING !isValid_  " + dump());
-#endif
-        return false;
-    }
-
-    if (hasIncrement()) {
-        // Note if we are equal to the finish and were called as part of completeCmd
-        // then completeCmd will initiate a job submission immediately
-        //  start  00:01
-        //  finish 00:04   Node will be queued 4 times
-        //  incr   00:01
-
-        // If the current value is greater that finish, then returning true would increment
-        // value past the end, and force node state to be stuck in state queue.
-        if (nextTimeSlot_ > finish_) {
-#ifdef DEBUG_TIME_SERIES
-            // cout << " TimeSeries::checkForRequeue ( nextTimeSlot_ > finish_ )    HOLDING\n";
-            log(Log::DBG, "TimeSeries::checkForRequeue HOLDING  ( nextTimeSlot_ > finish_ )  " + dump());
-#endif
-            return false;
-        }
-
-        // ECFLOW-130 jobs that start before midnight and finish after midnight should not re-queue
-        // This should ONLY apply to non relative time series, since a relative time series does care about midnight
-        if (!relativeToSuiteStart_ && !suiteTimeAtReque_.isNULL()) {
-            TimeSlot suiteTimeNow(calendar.suiteTime().time_of_day());
-            // cout << "TimeSeries::checkForRequeue suiteTimeNow = " << suiteTimeNow << "
-            // =====================================================\n";
-            //  we use >= specifically for unit test, to pass.
-            if (suiteTimeNow >= suiteTimeAtReque_) {
-                // normal flow, i.e same day
-                suiteTimeAtReque_ = TimeSlot(); // make NULL, allow requeuing to reset.
-            }
-            else {
-                // The day changed between (requeue/reset):->queued->submitted->active->complete->(checkForRequeue)
-#ifdef DEBUG_TIME_SERIES
-                // cout << " TimeSeries::checkForRequeue day changed
-                // ===================================================== HOLDING\n";
-                log(Log::DBG, "TimeSeries::checkForRequeue HOLDING suiteTimeNow < suiteTimeAtReque_  " + dump());
-#endif
-                return false;
-            }
-        }
-
-        time_duration calendar_duration = duration(calendar);
-        if (cmd_context) {
-            // In the *COMMAND* context, allow re-queue if we are *BEFORE* the last time slot
-            if (calendar_duration < lastTimeSlot_) {
-                return true;
-            }
-        }
-        else {
-            if (calendar_duration >= start_.duration() && calendar_duration < lastTimeSlot_) {
-                return true;
-            }
-        }
-
-#ifdef DEBUG_TIME_SERIES
-        log(Log::DBG,
-            "TimeSeries::checkForRequeue  HOLDING calendar_duration < start_ || calendar_duration >= lastTimeSlot_)  " +
-                dump());
-#endif
-        return false;
-    }
-
-    // *** When we have a single time slots we cannot make a decision, whether
-    // *** we should re-queue based on this attribute *alone*. (i.e when we have > 1 time/today attributes)
-    // *** Hence we pass min and max time slots, over all the time bases attributes of the same kind.
-    // *** In our case we only do this for Time and Today attributes.
-    // *** The the_min/the_max have been computed for all attribute (i.e single time slots and ranges)
-
-    // We have a single time slot, *OR* multiple with same time slot
-    if (the_min == the_max) {
-        // cout << " TimeSeries::checkForRequeue (the_min == the_max) HOLDING \n";
-#ifdef DEBUG_TIME_SERIES
-        log(Log::DBG, "TimeSeries::checkForRequeue  HOLDING  the_min == the_max  " + dump());
-#endif
-        return false;
-    }
-
-    // The the_min/the_max takes into account *all* start/finish Time and Today attributes
-    time_duration calendar_duration = duration(calendar);
-    if (cmd_context) {
-        // In the *COMMAND* context, allow re-queue if we are *BEFORE* the max time slot
-        if (calendar_duration < the_max.duration()) {
-            // cout << " TimeSeries::checkForRequeue *COMMAND* context calendar_duration < the_max.duration()) --> allow
-            // requeue\n";
-            return true;
-        }
-    }
-    else {
-        if (calendar_duration >= the_min.duration() && calendar_duration < the_max.duration()) {
-            // cout << " TimeSeries::checkForRequeue (calendar_duration > the_min.duration() && calendar_duration <
-            // the_max.duration()) --> allow requeue\n";
-            return true;
-        }
-    }
-
-    // cout << " TimeSeries::checkForRequeue calendar duration " << to_simple_string(calendar_duration) << " not in
-    // range " <<  to_simple_string(the_min.duration())  << "-" <<  to_simple_string(the_max.duration()) << "  HOLDING
-    // \n";
-#ifdef DEBUG_TIME_SERIES
-    log(Log::DBG, "TimeSeries::checkForRequeue HOLDING multiple slots not in range " + dump());
-#endif
-    return false;
-}
-
-void TimeSeries::min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const {
-    if (the_min.isNULL() || start_ < the_min)
-        the_min = start_;
-    if (the_max.isNULL() || start_ > the_max)
-        the_max = start_;
-    if (hasIncrement()) {
-        if (finish_ < the_min)
-            the_min = finish_;
-        if (finish_ > the_max)
-            the_max = finish_;
-    }
-}
-
-void TimeSeries::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
-    std::stringstream ss;
-    ss << " ( next run time is ";
-    if (relativeToSuiteStart_)
-        ss << "+";
-    ss << nextTimeSlot_.toString();
-
-    TimeSlot currentTime = TimeSlot(duration(c));
-    ss << ", current suite time is ";
-    if (relativeToSuiteStart_)
-        ss << "+";
-    ss << currentTime.toString() << " )";
-    theReasonWhy += ss.str();
-}
-
-boost::posix_time::time_duration TimeSeries::duration(const ecf::Calendar& c) const {
-    // return with a minute resolution
-    if (relativeToSuiteStart_) {
-
-        // relative to suite start only
-        return {relativeDuration_.hours(), relativeDuration_.minutes(), 0, 0};
-    }
-
-    LOG_ASSERT(!c.suiteTime().is_special(), "init has not been called on calendar. TimeSeries::duration");
-    time_duration time_of_day = c.suiteTime().time_of_day();
-    return {time_of_day.hours(), time_of_day.minutes(), 0, 0};
-}
-
-void TimeSeries::free_slots(std::vector<boost::posix_time::time_duration>& vec) const {
-    if (hasIncrement()) {
-
-        time_duration i            = start_.duration();
-        time_duration endDuration  = finish_.duration();
-        time_duration incrDuration = incr_.duration();
-        while (i < endDuration) {
-            vec.push_back(i);
-            i += incrDuration;
-        }
-        vec.push_back(finish_.duration());
-        return;
-    }
-
-    vec.push_back(start_.duration());
-}
-
-bool TimeSeries::structureEquals(const TimeSeries& rhs) const {
-    if (relativeToSuiteStart_ != rhs.relativeToSuiteStart_)
-        return false;
-    if (start_ != rhs.start_)
-        return false;
-    if (finish_ != rhs.finish_)
-        return false;
-    if (incr_ != rhs.incr_)
-        return false;
-    return true;
-}
-
-bool TimeSeries::operator==(const TimeSeries& rhs) const {
-    // additional state
-    if (isValid_ != rhs.isValid_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "TimeSeries::operator==  ( isValid_ != rhs.isValid_) " << toString() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (nextTimeSlot_ != rhs.nextTimeSlot_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "TimeSeries::operator==  ( nextTimeSlot_(" << nextTimeSlot_.toString()
-                      << ") != rhs.nextTimeSlot_(" << rhs.nextTimeSlot_.toString() << ")) " << toString() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (relativeDuration_ != rhs.relativeDuration_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "TimeSeries::operator==  ( relativeDuration_ != rhs.relativeDuration_) " << toString() << "\n";
-        }
-#endif
-        return false;
-    }
-    return structureEquals(rhs);
-}
-
-void TimeSeries::print(std::string& os) const {
-    write(os);
-    os += "\n";
-}
-
-std::string TimeSeries::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void TimeSeries::write(std::string& ret) const {
-    if (relativeToSuiteStart_)
-        ret += "+";
-    start_.write(ret);
-    if (!finish_.isNULL()) {
-        ret += " ";
-        finish_.write(ret);
-        ret += " ";
-        incr_.write(ret);
-    }
-}
-
-std::string TimeSeries::dump() const {
-    std::stringstream ss;
-    ss << toString();
-    ss << " isValid_(" << isValid_ << ")";
-    ss << " nextTimeSlot_(" << nextTimeSlot_.toString() << ")";
-    ss << " relativeDuration_(" << to_simple_string(relativeDuration_) << ")";
-    ss << " lastTimeSlot_(" << to_simple_string(lastTimeSlot_) << ")";
-    ss << " suiteTimeAtReque_(" << suiteTimeAtReque_.toString() << ")";
-    return ss.str();
-}
-
-bool TimeSeries::checkInvariants(std::string& errormsg) const {
-    if (!finish_.isNULL()) {
-        if (incr_.isNULL()) {
-            errormsg += "TimeSeries::checkInvariants increment cannot be NULL when we have a time series";
-            cout << errormsg << "  " << toString() << "\n";
-            return false;
-        }
-        if (incr_.hour() == 0 && incr_.minute() == 0) {
-            errormsg += "TimeSeries::checkInvariants increment must greater than zero";
-            cout << errormsg << "  " << toString() << "\n";
-            return false;
-        }
-
-        if (start_.duration() > finish_.duration()) {
-            errormsg += "TimeSeries::checkInvariants Invalid time series start() > finish()";
-            cout << errormsg << "  " << toString() << "\n";
-            return false;
-        }
-
-        if (lastTimeSlot_ <= start_.duration() && lastTimeSlot_ > finish_.duration()) {
-            errormsg += "TimeSeries::checkInvariants Invalid last time slot";
-            cout << errormsg << "  " << toString() << "\n";
-            return false;
-        }
-    }
-    if (relativeDuration_.is_special()) {
-        errormsg += "TimeSeries::checkInvariants relativeDuration_ should not be special";
-        cout << errormsg << "  " << toString() << "\n";
-        return false;
-    }
-
-    if (!relativeToSuiteStart_ && relativeDuration_.total_seconds() > 0) {
-        errormsg += "TimeSeries::checkInvariants Can only have RelativeDuration if relativeToSuiteStart_ flag is set";
-        cout << errormsg << "  " << toString() << "\n";
-        return false;
-    }
-
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const TimeSeries* d) {
-    if (d) {
-        string s;
-        d->print(s);
-        os << s;
-        return os;
-    }
-    return os << "TimeSlot == NULL";
-}
-std::ostream& operator<<(std::ostream& os, const TimeSeries& d) {
-    string s;
-    d.print(s);
-    os << s;
-    return os;
-}
-
-ecf::TimeSeries TimeSeries::create(const std::string& str) {
-    std::vector<std::string> lineTokens;
-    Str::split(str, lineTokens);
-    size_t index = 0;
-    return TimeSeries::create(index, lineTokens);
-}
-
-std::string TimeSeries::state_to_string(bool isFree) const {
-    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e.
-    //                 task a; task b;
-    //             Hence use of '/' character
-    // time 10:30 # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
-    std::string ret;
-    write_state(ret, isFree);
-    return ret;
-}
-
-void TimeSeries::write_state(std::string& ret, bool isFree) const {
-    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e.
-    //                 task a; task b;
-    //             Hence use of '/' character
-    // time 10:30 # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
-    bool next_time_slot_changed    = (nextTimeSlot_ != start_);
-    bool relative_duration_changed = (!relativeDuration_.is_special() && relativeDuration_.total_seconds() != 0);
-    if (isFree || !isValid_ || next_time_slot_changed || relative_duration_changed) {
-        ret += " #";
-        if (isFree)
-            ret += " free";
-        if (!isValid_)
-            ret += " isValid:false";
-        if (next_time_slot_changed) {
-            ret += " nextTimeSlot/";
-            ret += nextTimeSlot_.toString();
-        }
-        if (relative_duration_changed) {
-            ret += " relativeDuration/";
-            ret += to_simple_string(relativeDuration_);
-        }
-    }
-}
-
-void TimeSeries::write_state_for_gui(std::string& ret, bool isFree) const {
-    bool next_time_slot_changed    = (nextTimeSlot_ != start_);
-    bool relative_duration_changed = (!relativeDuration_.is_special() && relativeDuration_.total_seconds() != 0);
-    if (isFree || !isValid_ || next_time_slot_changed || relative_duration_changed) {
-        ret += " #";
-        if (isFree)
-            ret += " free";
-        if (!isValid_)
-            ret += " expired";
-        if (next_time_slot_changed) {
-            ret += " nextTimeSlot=";
-            ret += nextTimeSlot_.toString();
-        }
-        if (relative_duration_changed) {
-            ret += " relDuration=";
-            ret += to_simple_string(relativeDuration_);
-        }
-    }
-}
-
-void TimeSeries::parse_state(size_t index, const std::vector<std::string>& lineTokens, ecf::TimeSeries& ts) {
-    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e.
-    //                 task a; task b;
-    //             Hence use of '/' character
-    //
-    // Here free is attribute state & not time series state hence ignore
-    // time 10:30              # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
-    // cron 10:00 20:00 01:00  # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
-    bool comment_fnd        = false;
-    size_t line_tokens_size = lineTokens.size();
-    for (size_t i = index; i < line_tokens_size; i++) {
-        if (comment_fnd) {
-            if (lineTokens[i] == "isValid:false") {
-                ts.isValid_ = false;
-                continue;
-            }
-            if (lineTokens[i].find("nextTimeSlot") != std::string::npos) {
-                std::string nextTimeSlot;
-                if (Extract::split_get_second(lineTokens[i], nextTimeSlot, '/')) {
-                    // Note: we do *not* check for valid time since nextTimeSlot, relative times can be incremented past
-                    // 24 hours, i.e. cron +00:00 18:00 06:00 # isValid:false nextTimeSlot/523:00
-                    int startHour = -1;
-                    int startMin  = -1;
-                    getTime(nextTimeSlot, startHour, startMin, false /*check_time*/);
-                    ts.nextTimeSlot_ = TimeSlot(startHour, startMin);
-                }
-                else
-                    throw std::runtime_error("TimeSeries::parse_state: could not extract state.");
-            }
-            if (lineTokens[i].find("relativeDuration") != std::string::npos) {
-                std::string relativeDuration;
-                if (Extract::split_get_second(lineTokens[i], relativeDuration, '/')) {
-                    ts.relativeDuration_ = time_duration(duration_from_string(relativeDuration));
-                }
-                else
-                    throw std::runtime_error("TimeSeries::parse_state: could not extract state.");
-            }
-        }
-        if (lineTokens[i] == "#")
-            comment_fnd = true;
-    }
-    ts.compute_last_time_slot();
-}
-
-ecf::TimeSeries TimeSeries::create(size_t& index, const std::vector<std::string>& lineTokens, bool read_state) {
-    size_t line_tokens_size = lineTokens.size();
-    assert(index < line_tokens_size);
-    int startHour = -1;
-    int startMin  = -1;
-
-    // cron 10:00 20:00 01:00
-    // index is on 10:00, ie index should have value of 1 in this case
-    string startStr = lineTokens[index];
-    bool relative   = false;
-    if (startStr[0] == '+') {
-        relative = true;
-        startStr.erase(startStr.begin()); // remove leading +
-                                          // string must be of form 12:00
-    }
-    getTime(startStr, startHour, startMin);
-    TimeSlot start(startHour, startMin);
-
-    index++; // on 20:00
-    if (index < line_tokens_size && lineTokens[index][0] != '#') {
-
-        // if third token is not a comment the time must be of the form
-        // cron 10:00 20:00 01:00
-        if (index + 1 >= line_tokens_size)
-            throw std::runtime_error("TimeSeries::create: Invalid time series :");
-
-        int finishHour = -1;
-        int finishMin  = -1;
-        getTime(lineTokens[index], finishHour, finishMin);
-        TimeSlot finish(finishHour, finishMin);
-
-        index++;
-
-        int incrHour = -1;
-        int incrMin  = -1;
-        getTime(lineTokens[index], incrHour, incrMin);
-        TimeSlot incr(incrHour, incrMin);
-
-        if (read_state) {
-            TimeSeries ts(start, finish, incr, relative);
-            parse_state(index, lineTokens, ts);
-            return ts;
-        }
-        return TimeSeries(start, finish, incr, relative);
-    }
-
-    if (read_state) {
-        TimeSeries ts(start, relative);
-        parse_state(index, lineTokens, ts);
-        return ts;
-    }
-    return TimeSeries(start, relative);
-}
-
-bool TimeSeries::getTime(const std::string& time, int& hour, int& min, bool check_time) {
-    // HH:MM
-    // +HH:MM  for other clients
-    size_t colonPos = time.find_first_of(':');
-    if (colonPos == string::npos)
-        throw std::runtime_error("TimeSeries::getTime: Invalid time :'" + time + "'");
-
-    std::string theHour;
-    bool relative = false;
-    if (time[0] == '+') {
-        relative = true;
-        theHour  = time.substr(1, colonPos - 1);
-    }
-    else
-        theHour = time.substr(0, colonPos);
-
-    std::string theMin = time.substr(colonPos + 1);
-
-    if (check_time && theHour.size() != 2)
-        throw std::runtime_error("TimeSeries::getTime: Invalid hour :" + theHour);
-    if (theMin.size() != 2)
-        throw std::runtime_error("TimeSeries::getTime: Invalid minute :" + theMin);
-
-    hour = Extract::theInt(theHour, "TimeSeries::getTime: hour must be a integer : " + theHour);
-    min  = Extract::theInt(theMin, "TimeSeries::getTime: minute must be integer : " + theMin);
-
-    if (check_time)
-        testTime(hour, min);
-    return relative;
-}
-
-void TimeSeries::testTime(int hour, int minute) {
-    if (hour == -1 || minute == -1) {
-        throw std::runtime_error("TimeSeries::testTime: Failed to extract time");
-    }
-    if (hour < 0 || hour > 23) {
-        std::stringstream ss;
-        ss << "TimeSeries::testTime: time hour(" << hour << ") must be in range 0-23";
-        throw std::runtime_error(ss.str());
-    }
-    if (minute < 0 || minute > 59) {
-        std::stringstream ss;
-        ss << "TimeSeries::testTime: time minute(" << minute << ") must be in range 0-59";
-        throw std::runtime_error(ss.str());
-    }
-}
-
-template <class Archive>
-void TimeSeries::serialize(Archive& ar, std::uint32_t const /*version*/) {
-    ar(CEREAL_NVP(start_));
-    CEREAL_OPTIONAL_NVP(ar, finish_, [this]() { return !finish_.isNULL(); });
-    CEREAL_OPTIONAL_NVP(ar, incr_, [this]() { return !incr_.isNULL(); });
-    CEREAL_OPTIONAL_NVP(ar, nextTimeSlot_, [this]() { return !nextTimeSlot_.isNULL() && nextTimeSlot_ != start_; });
-    CEREAL_OPTIONAL_NVP(
-        ar, relativeDuration_, [this]() { return relativeDuration_ != boost::posix_time::time_duration(0, 0, 0, 0); });
-    CEREAL_OPTIONAL_NVP(ar, relativeToSuiteStart_, [this]() { return relativeToSuiteStart_; });
-    CEREAL_OPTIONAL_NVP(ar, isValid_, [this]() { return !isValid_; });
-
-    if (Archive::is_loading::value) {
-        if (nextTimeSlot_.isNULL())
-            nextTimeSlot_ = start_;
-        if (!finish_.isNULL())
-            compute_last_time_slot();
-    }
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(TimeSeries);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/TimeSeries.hpp 5.13.0-1/ACore/src/ecflow/core/TimeSeries.hpp
--- 5.12.4-1/ACore/src/ecflow/core/TimeSeries.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/TimeSeries.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,211 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_TimeSeries_HPP
-#define ecflow_core_TimeSeries_HPP
-
-///
-/// \brief Represents a set of time instants (possibly just one)
-///
-
-#include <cstdint>
-#include <vector>
-
-#include <boost/date_time/posix_time/posix_time.hpp>
-
-#include "ecflow/core/TimeSlot.hpp"
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-namespace ecf {
-/// TimeSeries can have a single time slot or a series of time slots
-///
-///
-/// We need nextTimeSlot_ data member to record the next valid time slot, otherwise when
-/// we have a time series, all times within the time series would be valid for
-/// Job submission. We do not know how long a job will run, hence when incrementing
-/// the nextTimeSlot_, we need the *NEXT* available time slot *after* the current calendar time.
-///
-/// Usage pattern is :
-///           TimeSeries.calendarChanged()   // Called every minute. Calls isFree(). Once free we stay free, until
-///           requeue.
-///                                          // At midnight clear time expiration and reset next time slot
-///           TimeSeries.isFree(..)          // called when node is QUEUED:
-///                                          // during dependency evaluation, checks next time slot, against calendar
-///                                          time
-///                                          // Once free a node stays free, until requeue()
-///           TimeSeries.checkForRequeue();  // called when node is COMPLETE: Checks if next available time slot is
-///           valid
-///                                          // *Must* return false for last time slot
-///                                          // ECFLOW-130 jobs that start before midnight and finish after midnight
-///                                          should not requeue
-///           TimeSeries.requeue();          // called when node is re-queued.
-///                                          // Sets value to next valid time slot after calendar time.
-///                                          // Can *expire* the time, relies on TimeSeries.calendarChanged() to clear
-///                                          time expiration
-///                                          // after midnight
-/// ECFLOW-130 jobs that start before midnight and finish after midnight should not requeue
-
-// Use compiler, destructor, copy constructor and assignment operator
-class TimeSeries {
-public:
-    TimeSeries();
-    TimeSeries(int hour, int minute, bool relative = false);
-    explicit TimeSeries(const TimeSlot&, bool relative = false);
-    TimeSeries(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative = false);
-
-    bool operator<(const TimeSeries& rhs) const;
-
-    // returns true if a state change is made
-    // Will clear time expiration flag at midnight
-    bool calendarChanged(const ecf::Calendar& c);
-
-    // relative duration stored locally since it can be reset, when used with repeats
-    // returns true if relative duration is reset/ i.e state change has been made
-    bool resetRelativeDuration();
-    void reset_only();
-    void reset(const ecf::Calendar& c);
-
-    // Increment time series. Will find the next time slot after current calendar
-    // record the current suite time, to check of jobs finish after midnight
-    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true);
-
-    // Since we can miss next time slot , allow its computation for the
-    // use with why command, returns a NULL timeslot if next time is invalid
-    // This functionality will mirror the requeue(..) function
-    TimeSlot compute_next_time_slot(const ecf::Calendar& c) const;
-
-    // Return true calendar is before or within scheduled time
-    bool requeueable(const ecf::Calendar& c) const;
-
-    /// if relativeToSuiteStart returns the relative duration, else returns calendar suite time of day.
-    /// The returned resolution is in minutes
-    boost::posix_time::time_duration duration(const ecf::Calendar& calendar) const;
-
-    /// If time has expired, returns false
-    /// Note: relative means relative to suite start, or relative to the beginning of repeated node.
-    /// Is of the form hh:mm.   This means relative has a range 00:00->99.59
-    /// For a single slot time series, should not be re queued again, and hence
-    /// should fail checkForRequeue. Likewise when the the current value is
-    /// the finish, then node should also not be re queued, otherwise the
-    /// node will be stuck in queued state.
-    bool isFree(const ecf::Calendar& calendar) const;
-
-    /// For single slot time based attributes we need additional context (i.e the_min,the_max parameter)
-    /// in order to determine whether we should re-queue.
-    /// Additionally when we have a time range, what if the last jobs runs over midnight. In this case
-    /// we need to return false. i.e do not re-queue ECFLOW-130
-    bool checkForRequeue(const ecf::Calendar& calendar,
-                         const TimeSlot& the_min,
-                         const TimeSlot& the_max,
-                         bool cmd_context = false) const;
-
-    void min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const;
-
-    // Called when explicitly Free holding time dependency. via FreeDepCmd
-    // We want to avoid the next time slot.
-    void miss_next_time_slot();
-
-    void why(const ecf::Calendar&, std::string& theReasonWhy) const;
-
-    bool hasIncrement() const { return !finish_.isNULL(); }
-    const TimeSlot& start() const { return start_; }
-    const TimeSlot& finish() const { return finish_; }
-    const TimeSlot& incr() const { return incr_; }
-    const TimeSlot& value() const { return nextTimeSlot_; }
-    bool relative() const { return relativeToSuiteStart_; }
-    void free_slots(std::vector<boost::posix_time::time_duration>&) const;
-
-    void print(std::string&) const;
-    bool operator==(const TimeSeries& rhs) const;
-    bool operator!=(const TimeSeries& rhs) const { return !operator==(rhs); }
-    bool structureEquals(const TimeSeries& rhs) const;
-
-    /// returns true if no time specified
-    bool isNULL() const { return start_.isNULL(); }
-
-    std::string state_to_string(bool isFree) const;
-    void write_state(std::string&, bool free) const;
-    void write_state_for_gui(std::string&, bool free) const;
-    std::string toString() const;
-    void write(std::string&) const;
-    std::string dump() const;
-    bool checkInvariants(std::string& errormsg) const;
-
-    /// expects HH:MM or +HH:MM will throw std:runtime_error for errors,
-    /// *if* hour not in range(0-24), minutes(0-59), *and* check_time parameter is enabled
-    static bool getTime(const std::string& time, int& hour, int& min, bool check_time = true);
-
-    /// extract string like
-    ///     time +00:00 20:00 00:10 # this is a comment which will be ignored. index = 1
-    ///     time +20:00        // index = 1
-    ///     today 20:00        // index = 1
-    ///     +00:00 20:00 00:10 // index = 0
-    ///     +20:00             // index = 0
-    /// will throw std:runtime_error for errors
-    /// will assert if index >= lineTokens.size()
-    static ecf::TimeSeries create(size_t& index, // where we should start
-                                  const std::vector<std::string>& lineTokens,
-                                  bool read_state = false);
-
-    // like above but string should not contain "time"
-    static ecf::TimeSeries create(const std::string& str);
-
-    // Parse state associated with the time series: Ignores attributes like free.
-    static void parse_state(size_t index, const std::vector<std::string>& lineTokens, ecf::TimeSeries& ts);
-    void set_isValid(bool b) { isValid_ = b; }                          // for test only
-    void set_next_time_slot(const TimeSlot& ts) { nextTimeSlot_ = ts; } // needed for test only
-    const TimeSlot& get_next_time_slot() const { return nextTimeSlot_; }
-
-    // Is the time still valid, return false means time has expired.
-    bool is_valid() const { return isValid_; }
-
-private:
-    static void testTime(int hour, int minute);
-
-    // HANDLE CASE WHERE FINISH MINUTES IS NOT DIVISIBLE BY THE INCREMENT
-    // time 00:00 23:59 00:10  last valid time is 23:50
-    // time 00:30 23:59 04:00  last valid time is 20:30
-    // The last valid time here is 23:50/20:30 must return false, to stop node being
-    // stuck in queued mode In the case where the FINISH is NOT a multiple of the increment
-    // Need a different mechanism to determine the end.
-    void compute_last_time_slot(); // only call for series
-
-    bool match_duration_with_time_series(const boost::posix_time::time_duration& relative_or_real_td) const;
-
-private:
-    TimeSlot start_;
-    TimeSlot finish_;
-    TimeSlot incr_;
-    TimeSlot nextTimeSlot_;             // nextTimeSlot_ >= start && is incremented by incr
-    mutable TimeSlot suiteTimeAtReque_; // NOT persisted, check of day change, between requeue -> checkForRequeue, when
-                                        // we have series
-    boost::posix_time::time_duration relativeDuration_;
-    boost::posix_time::time_duration lastTimeSlot_; // Only used when we have a series, can be generated
-    bool relativeToSuiteStart_{false};
-    bool isValid_{true}; // Needed for single slot to avoid multiple jobs submissions
-
-private:
-    // Note: isValid_      is persisted for use by why() command on the client side.
-    // Note: nextTimeSlot_ is persisted for use by why() command on the client side.
-    // Note: relativeDuration_ is persisted for use by why() command on the client side.
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/);
-};
-
-std::ostream& operator<<(std::ostream& os, const TimeSeries*);
-std::ostream& operator<<(std::ostream& os, const TimeSeries&);
-
-} // namespace ecf
-
-#endif /* ecflow_core_TimeSeries_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/TimeSlot.cpp 5.13.0-1/ACore/src/ecflow/core/TimeSlot.cpp
--- 5.12.4-1/ACore/src/ecflow/core/TimeSlot.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/TimeSlot.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,104 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/TimeSlot.hpp"
-
-#include <ostream>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace boost::posix_time;
-
-namespace ecf {
-
-///////////////////////////////////////////////////////////////////////////////////////////
-
-bool TimeSlot::operator<(const TimeSlot& rhs) const {
-    if (h_ < rhs.hour())
-        return true;
-    if (h_ == rhs.hour()) {
-        return m_ < rhs.minute();
-    }
-    return false;
-}
-
-bool TimeSlot::operator>(const TimeSlot& rhs) const {
-    if (h_ > rhs.hour())
-        return true;
-    if (h_ == rhs.hour()) {
-        return m_ > rhs.minute();
-    }
-    return false;
-}
-
-bool TimeSlot::operator<=(const TimeSlot& rhs) const {
-    if (operator<(rhs))
-        return true;
-    return operator==(rhs);
-}
-
-bool TimeSlot::operator>=(const TimeSlot& rhs) const {
-    if (operator>(rhs))
-        return true;
-    return operator==(rhs);
-}
-
-std::string TimeSlot::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void TimeSlot::write(std::string& ret) const {
-    if (isNULL()) {
-        ret += "00:00";
-        return;
-    }
-
-    if (h_ < 10)
-        ret += "0";
-    ret += ecf::convert_to<std::string>(h_);
-
-    ret += Str::COLON();
-    if (m_ < 10)
-        ret += "0";
-    ret += ecf::convert_to<std::string>(m_);
-}
-
-boost::posix_time::time_duration TimeSlot::duration() const {
-    assert(!isNULL());
-    return boost::posix_time::time_duration(hours(h_) + minutes(m_));
-}
-
-std::ostream& operator<<(std::ostream& os, const TimeSlot* d) {
-    if (d) {
-        std::string s;
-        d->print(s);
-        os << s;
-        return os;
-    }
-    return os << "TimeSlot == NULL";
-}
-std::ostream& operator<<(std::ostream& os, const TimeSlot& d) {
-    std::string s;
-    d.print(s);
-    os << s;
-    return os;
-}
-
-template <class Archive>
-void TimeSlot::serialize(Archive& ar) {
-    ar(CEREAL_NVP(h_), CEREAL_NVP(m_));
-}
-CEREAL_TEMPLATE_SPECIALIZE(TimeSlot);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/TimeSlot.hpp 5.13.0-1/ACore/src/ecflow/core/TimeSlot.hpp
--- 5.12.4-1/ACore/src/ecflow/core/TimeSlot.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/TimeSlot.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_TimeSlot_HPP
-#define ecflow_core_TimeSlot_HPP
-
-#include <iosfwd>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-namespace cereal {
-class access;
-}
-
-namespace ecf {
-
-// Use compiler , generated destructor, assignment,  copy constructor
-// *relative* times can extend to a maximum of 99 hours and 59 seconds
-//
-// TimeSlot is used in many other attributes, i.e. like AutoCancelAttr,AutoArchiveAttr
-// in this case user can specify days, which we convert to hours, hence it
-// is possible for a TimeSlot hour to have any integer value
-class TimeSlot {
-public:
-    static std::string type() { return "TimeSlot"; }
-    TimeSlot() = default;
-    TimeSlot(int hour, int min) : h_(hour), m_(min) { assert(hour >= 0 && min >= 0); }
-    explicit TimeSlot(const boost::posix_time::time_duration& td) : h_(td.hours()), m_(td.minutes()) {
-        assert(h_ < 60 && m_ < 60);
-    }
-
-    bool operator==(const TimeSlot& rhs) const { return ((h_ == rhs.h_) && (m_ == rhs.m_)); }
-    bool operator!=(const TimeSlot& rhs) const { return !operator==(rhs); }
-
-    bool operator<(const TimeSlot& rhs) const;
-    bool operator>(const TimeSlot& rhs) const;
-    bool operator<=(const TimeSlot& rhs) const;
-    bool operator>=(const TimeSlot& rhs) const;
-
-    int hour() const { return h_; }
-    int minute() const { return m_; }
-    bool isNULL() const { return (h_ == -1 && m_ == -1); }
-    void print(std::string& os) const { write(os); }
-
-    /// returns the corresponding duration.
-    boost::posix_time::time_duration duration() const;
-
-    // returns  struct in the format hh:mm
-    std::string toString() const;
-    void write(std::string&) const;
-
-private:
-    int h_{-1};
-    int m_{-1};
-
-    // *IMPORTANT* no version for a simple class
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-std::ostream& operator<<(std::ostream& os, const TimeSlot*);
-std::ostream& operator<<(std::ostream& os, const TimeSlot&);
-} // namespace ecf
-
-#endif /* ecflow_core_TimeSlot_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/TimeStamp.cpp 5.13.0-1/ACore/src/ecflow/core/TimeStamp.cpp
--- 5.12.4-1/ACore/src/ecflow/core/TimeStamp.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/TimeStamp.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/TimeStamp.hpp"
-
-#include <ctime>
-
-namespace ecf {
-namespace TimeStamp {
-
-namespace {
-
-struct regular
-{
-    static constexpr char const* format = "[%H:%M:%S %d.%m.%Y] ";
-    static constexpr size_t size        = 23;
-};
-
-struct brief
-{
-    static constexpr char const* format = "[%H:%M:%S %d.%m] ";
-    static constexpr size_t size        = 18;
-};
-
-template <typename FMT = regular>
-std::string format_now() {
-    std::time_t now = std::time(nullptr);
-    char buffer[FMT::size];
-    std::strftime(buffer, sizeof(buffer), FMT::format, std::localtime(&now));
-    return buffer;
-}
-
-} // namespace
-
-std::string now() {
-    return format_now();
-}
-
-void now(std::string& time_stamp) {
-    time_stamp = format_now();
-}
-
-void now_in_brief(std::string& time_stamp) {
-    time_stamp = format_now<brief>();
-}
-
-} // namespace TimeStamp
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/TimeStamp.hpp 5.13.0-1/ACore/src/ecflow/core/TimeStamp.hpp
--- 5.12.4-1/ACore/src/ecflow/core/TimeStamp.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/TimeStamp.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_TimeStamp_HPP
-#define ecflow_core_TimeStamp_HPP
-
-#include <string>
-
-namespace ecf {
-namespace TimeStamp {
-
-/// Generate a 'regular' time stamp.
-///
-/// Format specified as
-///  - "[%02d:%02d:%02d %d.%d.%d] ", considering "[hour:min:sec day.month.year]
-///  "
-///
-/// Results in the following examples
-///  - "[05:26:20 29.10.2014] "
-///  - "[05:26:20 17.1.2023] "
-///
-std::string now();
-void now(std::string&);
-
-/// Generate a 'brief' time stamp.
-///
-/// Format specified as
-///  - "[%02d:%02d:%02d %d.%d] ", considering "[hour:min:sec day.month] "
-///
-/// Results in the following examples
-///  - "[05:26:20 29.10] "
-///  - "[05:26:20 17.1] "
-///
-void now_in_brief(std::string&);
-
-} // namespace TimeStamp
-} // namespace ecf
-
-#endif /* ecflow_core_TimeStamp_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/User.cpp 5.13.0-1/ACore/src/ecflow/core/User.cpp
--- 5.12.4-1/ACore/src/ecflow/core/User.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/User.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,94 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/User.hpp"
-
-#include <cassert>
-#include <cerrno>  // for errno()
-#include <cstring> // for strerror()
-#include <pwd.h>   // for getpwuid()
-#include <sstream>
-#include <stdexcept>
-#include <unistd.h> // ofr getuid()
-
-#include "ecflow/core/Enumerate.hpp"
-
-namespace ecf {
-
-namespace detail {
-
-template <>
-struct EnumTraits<User::Action>
-{
-    using underlying_t = std::underlying_type_t<User::Action>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(User::Action::FOB, "fob"),
-        std::make_pair(User::Action::FAIL, "fail"),
-        std::make_pair(User::Action::ADOPT, "adopt"),
-        std::make_pair(User::Action::REMOVE, "remove"),
-        std::make_pair(User::Action::BLOCK, "block"),
-        std::make_pair(User::Action::KILL, "kill"),
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<User::Action>::size == map.back().first + 1);
-};
-
-} // namespace detail
-
-bool User::valid_user_action(const std::string& s) {
-    return Enumerate<User::Action>::is_valid(s);
-}
-
-User::Action User::user_action(const std::string& s) {
-    return Enumerate<User::Action>::to_enum(s).value_or(User::BLOCK);
-}
-
-std::string User::to_string(User::Action uc) {
-    if (auto found = Enumerate<User::Action>::to_string(uc); found) {
-        return std::string{found.value()};
-    }
-    assert(false);
-    return std::string();
-}
-
-std::string User::login_name() {
-    static std::string the_user_name;
-    if (the_user_name.empty()) {
-
-        // Get the uid of the running process and use it to get a record from /etc/passwd */
-        // getuid() cannot fail, but getpwuid can fail.
-        errno                         = 0;
-        uid_t real_user_id_of_process = getuid();
-        struct passwd* thePassWord    = getpwuid(real_user_id_of_process);
-        if (thePassWord == nullptr) {
-            if (errno != 0) {
-                std::string theError = strerror(errno);
-                throw std::runtime_error("UserCmd::get_user: could not determine user name. Because: " + theError);
-            }
-
-            std::stringstream ss;
-            ss << "UserCmd::get_user: could not determine user name for uid " << real_user_id_of_process;
-            throw std::runtime_error(ss.str());
-        }
-
-        the_user_name = thePassWord->pw_name; // equivalent to the login name
-        if (the_user_name.empty()) {
-            throw std::runtime_error(
-                "UserCmd::get_user: could not determine user name. Because: thePassWord->pw_name is empty");
-        }
-    }
-    return the_user_name;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/User.hpp 5.13.0-1/ACore/src/ecflow/core/User.hpp
--- 5.12.4-1/ACore/src/ecflow/core/User.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/User.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_User_HPP
-#define ecflow_core_User_HPP
-
-#include <string>
-
-namespace ecf {
-
-class User {
-public:
-    enum Action { FOB, FAIL, ADOPT, REMOVE, BLOCK, KILL };
-
-    // Disable default construction
-    User(const User&) = delete;
-    // Disable copy (and move) semantics
-    const User& operator=(const User&) = delete;
-    User()                             = delete;
-
-    static bool valid_user_action(const std::string&);
-    static Action user_action(const std::string&);
-    static std::string to_string(Action);
-
-    // return login name: will throw if there are any errors
-    static std::string login_name();
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_User_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Version.cpp 5.13.0-1/ACore/src/ecflow/core/Version.cpp
--- 5.12.4-1/ACore/src/ecflow/core/Version.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Version.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,127 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Version.hpp"
-
-#include <sstream>
-
-#include <boost/version.hpp>
-#include <cereal/version.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/ecflow_version.h"
-
-namespace ecf {
-
-// ********************************************************************
-// IMPORTANT:
-// The version number is extracted externally.
-//   see ACore/doc/extracting_version_number.ddoc
-//
-//   See ACore/src/ecflow_version.h
-//   This file is generated when cmake is run, i.e.
-//     `sh -x $WK/cmake.sh debug`
-//
-// When changing the version change remember to:
-//    - re-login into remote system to update ECFLOW_INSTALL_DIR & ECFLOW_PYTHON_INSTALL_DIR
-//      required for interactive install
-//
-// To Install a new version on all the different platforms:
-//  . build_scripts/nightly/quick_install_.sh
-// This is because the definition hold's the last version.
-// Hence, we must rerun to update the version.
-//
-// ************************************************************************************
-// Use  <minor_number>rc<number> for release candidates, Once release we revert back:
-//      0rc1    -> 0
-//      10rc3   -> 10
-// ************************************************************************************
-//
-// **Please update file history.ddoc with the changed made for each release ***
-// ********************************************************************
-#ifdef DEBUG
-const std::string Version::TAG = " (debug)"; // Old tag: beta(debug)
-#else
-const std::string Version::TAG = ""; // Old tag: beta
-#endif
-
-// See: http://www.cmake.org/cmake/help/cmake_tutorial.html
-// For defining version numbers. This is done is a separate file
-// that is then included
-std::string Version::description() {
-    std::stringstream ss;
-    ss << "Ecflow" << Version::TAG << " version(" << ECFLOW_RELEASE << "." << ECFLOW_MAJOR << "." << ECFLOW_MINOR;
-
-    ss << ") boost(" << Version::boost() << ")";
-    std::string the_comp = compiler();
-    if (!the_comp.empty())
-        ss << " compiler(" << the_comp << ")";
-
-    ss << " protocol(JSON cereal " << CEREAL_VERSION_MAJOR << "." << CEREAL_VERSION_MINOR << "." << CEREAL_VERSION_PATCH
-       << ")";
-
-#ifdef ECF_OPENSSL
-    ss << " openssl(enabled)";
-#endif
-
-    ss << " Compiled on " << __DATE__ << " " << __TIME__;
-    return ss.str();
-}
-
-std::string Version::version() {
-    std::string ret = "ecflow_";
-    ret += ecf::convert_to<std::string>(ECFLOW_RELEASE);
-    ret += "_";
-    ret += ecf::convert_to<std::string>(ECFLOW_MAJOR);
-    ret += "_";
-    ret += ecf::convert_to<std::string>(ECFLOW_MINOR);
-    return ret;
-}
-
-std::string Version::raw() {
-    std::string ret = ecf::convert_to<std::string>(ECFLOW_RELEASE);
-    ret += ".";
-    ret += ecf::convert_to<std::string>(ECFLOW_MAJOR);
-    ret += ".";
-    ret += ecf::convert_to<std::string>(ECFLOW_MINOR);
-    return ret;
-}
-
-std::string Version::boost() {
-    std::stringstream ss;
-    ss << BOOST_VERSION / 100000 << "."     // major version
-       << BOOST_VERSION / 100 % 1000 << "." // minor version
-       << BOOST_VERSION % 100;              // patch level
-    return ss.str();
-}
-
-std::string Version::compiler() {
-    std::stringstream ss;
-#if defined(_AIX)
-    ss << "aix " << __IBMCPP__;
-#elif defined(HPUX)
-    ss << "aCC " << __HP_aCC; // type aCC +help, this will show compiler manual, search for Predefined Macros
-#else
-    #if defined(__clang__)
-    //  To find the list of defines for clang use:
-    //  echo | /usr/local/apps/clang/current/bin/clang++ -dM -E -
-    ss << "clang " << __clang_major__ << "." << __clang_minor__;
-    #elif defined(__INTEL_COMPILER)
-    ss << "intel " << __INTEL_COMPILER;
-    #elif defined(_CRAYC)
-    ss << "cray " << _CRAYC;
-    #else
-    ss << "gcc " << __GNUC__ << "." << __GNUC_MINOR__ << "." << __GNUC_PATCHLEVEL__;
-    #endif
-#endif
-    return ss.str();
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ACore/src/ecflow/core/Version.hpp 5.13.0-1/ACore/src/ecflow/core/Version.hpp
--- 5.12.4-1/ACore/src/ecflow/core/Version.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/Version.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_Version_HPP
-#define ecflow_core_Version_HPP
-
-///
-/// \brief Holds the version of ECFlow. Checked against definition file.
-///         For each major release the major number should be incremented.
-///
-/// If the parsing comes across a construct it does not recognize, then
-/// an exception is thrown. i.e if a construct added in release 2.0 of ECF
-/// is read in by version 1.0 of ECF. The exception should indicate the
-/// current release
-///
-
-#include <string>
-
-namespace ecf {
-
-class Version {
-public:
-    // Disable default construction
-    Version() = delete;
-    // Disable copy (and move) semantics
-    Version(const Version&)                  = delete;
-    const Version& operator=(const Version&) = delete;
-
-    /// Outputs a string of the form:
-    /// ECF <tag> version release_.major_.minor_
-    static std::string description();
-
-    /// Outputs string of form: ecflow_<release>_<major>_<minor>
-    /// This could be used by install
-    static std::string version();
-
-    /// Outputs string of form: <release>.<major>.<minor>
-    static std::string raw();
-
-private:
-    static const std::string TAG; // alpha, beta, release
-
-    /// return version of the boost library
-    static std::string boost();
-
-    // Return the version of the compiler. Can return empty string
-    static std::string compiler();
-};
-
-} // namespace ecf
-
-#endif /* ecflow_core_Version_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/WhiteListFile.cpp 5.13.0-1/ACore/src/ecflow/core/WhiteListFile.cpp
--- 5.12.4-1/ACore/src/ecflow/core/WhiteListFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/WhiteListFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,603 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/WhiteListFile.hpp"
-
-#include <iostream>
-#include <vector>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/User.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-WhiteListFile::WhiteListFile() = default;
-
-WhiteListFile::~WhiteListFile() = default;
-
-bool WhiteListFile::verify_read_access(const std::string& user) const {
-    // Please note that the presence of * , even with paths means all users, have access
-    // Command like --news has no paths, hence allow access to all if * specified
-    if (all_users_have_read_access_)
-        return true;
-    if (users_with_read_access_.empty() && users_with_write_access_.empty())
-        return true;
-
-    if (users_with_read_access_.find(user) != users_with_read_access_.end())
-        return true;
-    if (users_with_read_access_.find("*") != users_with_read_access_.end())
-        return true;
-
-    // user with write access also have read access
-    if (users_with_write_access_.find(user) != users_with_write_access_.end())
-        return true;
-    if (users_with_write_access_.find("*") != users_with_write_access_.end())
-        return true;
-    return false;
-}
-
-bool WhiteListFile::verify_write_access(const std::string& user) const {
-    if (all_users_have_write_access_)
-        return true;
-    if (users_with_read_access_.empty() && users_with_write_access_.empty())
-        return true;
-
-    if (verify_path_access(user, Str::EMPTY(), users_with_write_access_))
-        return true;
-    if (verify_path_access("*", Str::EMPTY(), users_with_write_access_))
-        return true;
-    return false;
-}
-
-bool WhiteListFile::verify_read_access(const std::string& user, const std::string& path) const {
-    if (all_users_have_read_access_)
-        return true;
-    if (users_with_read_access_.empty() && users_with_write_access_.empty())
-        return true;
-    if (verify_path_access(user, path, users_with_read_access_))
-        return true;
-    if (verify_path_access("*", path, users_with_read_access_))
-        return true;
-
-    // user with write access also have read access
-    if (verify_path_access(user, path, users_with_write_access_))
-        return true;
-    if (verify_path_access("*", path, users_with_write_access_))
-        return true;
-
-    return false;
-}
-
-bool WhiteListFile::verify_write_access(const std::string& user, const std::string& path) const {
-    if (all_users_have_write_access_)
-        return true;
-    if (users_with_read_access_.empty() && users_with_write_access_.empty())
-        return true;
-
-    if (verify_path_access(user, path, users_with_write_access_))
-        return true;
-    if (verify_path_access("*", path, users_with_write_access_))
-        return true;
-
-    return false;
-}
-
-bool WhiteListFile::verify_read_access(const std::string& user, const std::vector<std::string>& paths) const {
-    //   std::cout << "WhiteListFile::verify_read_access user " << user << " paths( ";
-    //   for(size_t i = 0; i < paths.size(); i++) { std::cout << paths[i] << " "; }
-    //   std::cout << ") \n";
-    //   std::cout << "  all_users_have_read_access_: " << all_users_have_read_access_ << "\n";
-    //   std::cout << "  users_with_read_access_.size(): " << users_with_read_access_.size() << "\n";
-    //   std::cout << "  users_with_write_access_.size(): " << users_with_write_access_.size() << "\n";
-    //   std::cout << dump_valid_users() << "\n\n";
-
-    if (all_users_have_read_access_)
-        return true;
-    if (users_with_read_access_.empty() && users_with_write_access_.empty())
-        return true;
-    if (verify_path_access(user, paths, users_with_read_access_))
-        return true;
-    if (verify_path_access("*", paths, users_with_read_access_))
-        return true;
-
-    // user with write access also have read access
-    if (verify_path_access(user, paths, users_with_write_access_))
-        return true;
-    if (verify_path_access("*", paths, users_with_write_access_))
-        return true;
-
-    return false;
-}
-
-bool WhiteListFile::verify_write_access(const std::string& user, const std::vector<std::string>& paths) const {
-    if (all_users_have_write_access_)
-        return true;
-    if (users_with_read_access_.empty() && users_with_write_access_.empty())
-        return true;
-    if (verify_path_access(user, paths, users_with_write_access_))
-        return true;
-    if (verify_path_access("*", paths, users_with_write_access_))
-        return true;
-    return false;
-}
-
-static bool path_access(const std::vector<std::string>& paths, const std::vector<std::string>& allowed_paths) {
-    if (allowed_paths.empty())
-        return true; // no paths are specified in PASSWORD file allow access
-
-    // Paths specified in PASSWORD file.
-    if (paths.empty())
-        return false; // INPUT user path empty deny access
-
-    // when we have a set of paths, supplied by the GUI. These can be random path selections
-    // Hence to allow access *ALL* paths need to pass access
-    //
-    // need to correctly check for subsets
-    //    allowed_paths              paths               valid
-    //    /ecflow                    /ecflow_1182        FALSE
-    //    /ecflow/fred               /ecflow/freddy      FALSE
-    //    /ecflow/fred               /ecflow/fred/me     TRUE
-
-    size_t allowed_paths_size = allowed_paths.size();
-    size_t paths_size         = paths.size();
-    for (size_t i = 0; i < paths_size; i++) {
-        const std::string& path          = paths[i];
-        bool found_path_in_allowed_paths = false;
-
-        for (size_t ap = 0; ap < allowed_paths_size; ap++) {
-            const std::string& allowed_path = allowed_paths[ap];
-            //         cout << "path " << path << "\n";
-            //         cout << "allowed_path " <<  allowed_path << "\n";
-            //         if (path.size() > allowed_paths[ap].size()) {
-            //            cout << "path[allowed_path.size()] " << path[ allowed_path.size()] << "\n";
-            //         }
-            if (path.find(allowed_path) == 0) {
-                if (path.size() > allowed_path.size() && path[allowed_path.size()] != '/') {
-                    // FALSE case above
-                    continue;
-                }
-
-                found_path_in_allowed_paths = true;
-                continue; // all paths must match, or fail
-            }
-        }
-        if (!found_path_in_allowed_paths)
-            return false;
-    }
-    return true;
-}
-
-static bool path_access(const std::string& path, const std::vector<std::string>& allowed_paths) {
-    if (allowed_paths.empty())
-        return true;
-    if (path.empty())
-        return false;
-
-    size_t allowed_paths_size = allowed_paths.size();
-    for (size_t ap = 0; ap < allowed_paths_size; ap++) {
-        const std::string& allowed_path = allowed_paths[ap];
-
-        if (path.find(allowed_path) == 0) {
-            // found path in allowed paths, check correct SUB_PATH
-            if (path.size() > allowed_path.size() && path[allowed_path.size()] != '/') {
-                // FALSE case above
-                continue;
-            }
-            return true;
-        }
-    }
-    return false;
-}
-
-bool WhiteListFile::verify_path_access(const std::string& user,
-                                       const std::vector<std::string>& paths,
-                                       const mymap& user_path_map) const {
-    auto it = user_path_map.find(user);
-    if (it != user_path_map.end()) {
-        return path_access(paths, it->second);
-    }
-    return false;
-}
-
-bool WhiteListFile::verify_path_access(const std::string& user,
-                                       const std::string& path,
-                                       const mymap& user_path_map) const {
-    auto it = user_path_map.find(user);
-    if (it != user_path_map.end()) {
-        return path_access(path, it->second);
-    }
-    return false;
-}
-
-bool WhiteListFile::load(const std::string& file, bool debug, std::string& errorMsg) {
-    if (debug) {
-        std::cout << "  White list file " << file << " opening...\n";
-    }
-
-    white_list_file_             = file;
-    all_users_have_read_access_  = false;
-    all_users_have_write_access_ = false;
-    users_with_read_access_.clear();
-    users_with_write_access_.clear();
-
-    std::vector<std::string> lines;
-    if (File::splitFileIntoLines(white_list_file_, lines, true /* ignore empty lines */)) {
-
-        bool foundVersionNumber = false; // can read from version 4.4.5 onwards
-        size_t lines_size       = lines.size();
-        for (size_t i = 0; i < lines_size; ++i) {
-
-            if (lines[i].empty())
-                continue;
-
-            // ignore/remove all comments
-            if (lines[i][0] == '#')
-                continue;
-            std::string theLine           = lines[i];
-            string::size_type comment_pos = theLine.find("#");
-            if (comment_pos != std::string::npos) {
-                theLine.erase(comment_pos);
-            }
-
-            ecf::algorithm::trim(theLine); // remove leading and trailing spaces
-            std::vector<std::string> lineTokens;
-            Str::split(theLine, lineTokens);
-            if (lineTokens.empty())
-                continue;
-
-            // version should be at the start
-            if (!foundVersionNumber) {
-
-                if (!validateVersionNumber(lineTokens[0], errorMsg)) {
-                    std::stringstream ss;
-                    ss << " " << i + 1 << ": " << lines[i] << "\n";
-                    ss << "for ECF_LISTS file " << white_list_file_ << "\n";
-                    errorMsg += ss.str();
-                    return false;
-                }
-                foundVersionNumber = true;
-                continue;
-            }
-            else {
-                if (!add_user(lineTokens, errorMsg)) {
-                    return false;
-                }
-            }
-        }
-
-        // remove duplicates
-        mymap::iterator i;
-        for (i = users_with_read_access_.begin(); i != users_with_read_access_.end(); ++i) {
-            std::vector<std::string>& paths = (*i).second;
-            std::sort(paths.begin(), paths.end());
-            paths.erase(std::unique(paths.begin(), paths.end()), paths.end());
-        }
-        for (i = users_with_write_access_.begin(); i != users_with_write_access_.end(); ++i) {
-            std::vector<std::string>& paths = (*i).second;
-            std::sort(paths.begin(), paths.end());
-            paths.erase(std::unique(paths.begin(), paths.end()), paths.end());
-        }
-
-        if (debug)
-            std::cout << dump_valid_users() << "\n";
-
-        return true;
-    }
-
-    errorMsg += "Could not open file specified by ECF_LISTS ";
-    errorMsg += white_list_file_;
-    errorMsg += " (";
-    errorMsg += strerror(errno);
-    errorMsg += ")";
-    if (debug)
-        std::cout << dump_valid_users() << "\n";
-    return false;
-}
-
-std::string WhiteListFile::dump_valid_users() const {
-    std::stringstream ss;
-    ss << "ECF_LISTS = '" << white_list_file_ << "'\n";
-    if (users_with_read_access_.empty() && users_with_write_access_.empty())
-        ss << " No users specified. Everyone has read/write access\n";
-    if (all_users_have_read_access_)
-        ss << " All users have read access\n";
-    if (all_users_have_write_access_)
-        ss << " All users have write access\n";
-
-    mymap::const_iterator i;
-    for (i = users_with_read_access_.begin(); i != users_with_read_access_.end(); ++i) {
-        ss << " User: " << (*i).first << " ";
-        const std::vector<std::string>& paths = (*i).second;
-        for (const auto& path : paths)
-            ss << path << ",";
-        ss << " has read access\n";
-    }
-    for (i = users_with_write_access_.begin(); i != users_with_write_access_.end(); ++i) {
-        ss << " User: " << (*i).first << " ";
-        const std::vector<std::string>& paths = (*i).second;
-        for (const auto& path : paths)
-            ss << path << ",";
-        ss << " has read/write access\n";
-    }
-
-    return ss.str();
-}
-
-bool WhiteListFile::validateVersionNumber(const std::string& line, std::string& errorMsg) const {
-    // Expect 4.4.14, Current syntax in force after 4.4.5
-    // If first character is NUMERIC and we have dots
-    bool firstCharIsNumeric = Str::NUMERIC().find(line[0], 0) != string::npos;
-    if (firstCharIsNumeric && line.find(".") != string::npos) {
-
-        std::vector<std::string> versionNumberTokens;
-        Str::split(line, versionNumberTokens, ".");
-        if (versionNumberTokens.size() != 3) {
-            std::stringstream ss;
-            ss << "Expected version of the form <int>.<int>.<int> i.e 4.4.14. but found invalid version number\n";
-            errorMsg += ss.str();
-            return false;
-        }
-
-        try {
-            auto major = ecf::convert_to<int>(versionNumberTokens[0]);
-            auto minor = ecf::convert_to<int>(versionNumberTokens[1]);
-            auto part  = ecf::convert_to<int>(versionNumberTokens[2]);
-            if (major < 4) {
-                errorMsg += "Only white list files with a version >= 4.4.5 is supported\n";
-                return false;
-            }
-            if (major == 4 && minor < 4) {
-                errorMsg += "Only white list files with a version >= 4.4.5 is supported\n";
-                return false;
-            }
-            if (major == 4 && minor == 4 && part < 5) {
-                errorMsg += "Only white list files with a version >= 4.4.5 is supported\n";
-                return false;
-            }
-        }
-        catch (const ecf::bad_conversion&) {
-            errorMsg += "Invalid version number \n";
-            return false;
-        }
-
-        return true;
-    }
-
-    errorMsg += "The version number not found. The version number must appear before the users.\n";
-    return false;
-}
-
-bool WhiteListFile::add_user(std::vector<std::string>& tokens, std::string& error_msg) {
-    // # please note if the same user appear multiple times, then the access right are additive
-    // # Hence if the user has been given write access, then other change to access rights for
-    // # same user are ignored
-    //
-    // # These user have read and write access to the server
-    // uid1  # a comment
-    // uid2  # a comment
-    // cog   # a comment
-    //
-    // # Read only users
-    //-*     # *all* users have read access to *all* suites
-    //-fred
-    //
-    //*   # *all* user have read/write access, to *all* suites
-    //
-    // # access to suites
-    //-fred /suiteX  # user fred is only allowed read access to suiteX only
-    // bill    /suiteX,/suiteB # user bill is allowed read/write access to suiteX and suiteB only
-    //-*      /open   # all user are allowed access to suite /open
-    // joe    /        # has read/write access to everything, this same as 'joe' by itself
-    //*      /        # all users have read/write access
-    //*      /x,/y    # all user have read/write access to suite /x, /y
-
-    // Use of * by itself means *all* user have read/write access to *all* suites
-    if (all_users_have_write_access_)
-        return true;
-
-    if (tokens.size() == 1) {
-        std::string user = tokens[0];
-        if (user[0] == '-') {
-
-            // Read access
-            user.erase(user.begin());
-
-            // if we see -* all users have read access
-            if (user == "*") {
-                all_users_have_read_access_ = true;
-                users_with_read_access_.clear();
-            }
-            else {
-                if (!all_users_have_read_access_)
-                    users_with_read_access_.insert(std::make_pair(user, std::vector<std::string>()));
-            }
-            return true;
-        }
-
-        // write access , this also IMPLIES read access
-        // if we see * all users have read and write access
-        if (user == "*") {
-            all_users_have_write_access_ = true;
-            all_users_have_read_access_  = true;
-            users_with_write_access_.clear();
-            users_with_read_access_.clear();
-        }
-        else {
-            if (!all_users_have_read_access_)
-                users_with_read_access_.insert(std::make_pair(user, std::vector<std::string>()));
-            if (!all_users_have_write_access_)
-                users_with_write_access_.insert(std::make_pair(user, std::vector<std::string>()));
-        }
-        return true;
-    }
-
-    bool clear_paths = false;
-    bool read_only   = false;
-    std::string user;
-    std::vector<std::string> paths;
-    for (auto tok : tokens) {
-        if (tok.empty())
-            continue;
-        if (tok[0] == '-') {
-            // read only user for a given set of paths
-            read_only = true;
-            tok.erase(tok.begin());
-            if (!tok.empty()) {
-                if (!user.empty()) {
-                    error_msg = "Can only have one user per line, first user:";
-                    error_msg += user;
-                    error_msg += " second user:";
-                    error_msg += tok;
-                    return false;
-                }
-                user = tok; // user =  <name> || *
-            }
-        }
-        else if (tok[0] == '*') {
-            // all user have read/write access for a given set of suites ?
-            if (!user.empty()) {
-                error_msg = "Can only have one user per line, first user:";
-                error_msg += user;
-                error_msg += " second user:";
-                error_msg += tok;
-                return false;
-            }
-            user = "*";
-        }
-        else if (tok[0] == '/') {
-            // path or set of paths
-            std::vector<std::string> local_paths;
-            Str::split(tok, local_paths, ",");
-            std::copy(local_paths.begin(), local_paths.end(), std::back_inserter(paths));
-
-            // root path '/' means apply to all suites, in which case the paths may as well be empty.
-            for (const auto& path : paths) {
-                if (path == "/") {
-                    clear_paths = true;
-                    break;
-                }
-            }
-        }
-        else {
-            // read/write user
-            if (!user.empty()) {
-                error_msg = "Can only have one user per line, first user:";
-                error_msg += user;
-                error_msg += " second user:";
-                error_msg += tok;
-                return false;
-            }
-            user = tok;
-        }
-    }
-
-    if (clear_paths) {
-        paths.clear(); // user has used root path '/'
-
-        // * user means all users
-        if (user == "*") {
-            if (read_only) {
-                // -* /
-                all_users_have_read_access_ = true;
-                users_with_read_access_.clear();
-            }
-            else {
-                // * /
-                all_users_have_write_access_ = true;
-                users_with_write_access_.clear();
-            }
-        }
-    }
-
-    // check all paths start with '/'
-    for (auto& path : paths) {
-        if (!path.empty() && path[0] != '/') {
-            error_msg = "Paths must start with '/'";
-            return false;
-        }
-    }
-
-    if (read_only) {
-        if (!all_users_have_read_access_) {
-            auto it = users_with_read_access_.find(user);
-            if (it == users_with_read_access_.end())
-                users_with_read_access_.insert(std::make_pair(user, paths));
-            else
-                std::copy(paths.begin(), paths.end(), std::back_inserter(it->second));
-        }
-    }
-    else {
-        if (!all_users_have_write_access_) {
-            auto it = users_with_write_access_.find(user);
-            if (it == users_with_write_access_.end())
-                users_with_write_access_.insert(std::make_pair(user, paths));
-            else
-                std::copy(paths.begin(), paths.end(), std::back_inserter(it->second));
-        }
-    }
-    return true;
-}
-
-bool WhiteListFile::createWithReadAccess(const std::string& pathToFile, std::string& errorMsg) {
-    std::vector<std::string> lines;
-    lines.reserve(2);
-
-    lines.emplace_back("4.4.14");
-    lines.push_back("-" + User::login_name());
-
-    return File::create(pathToFile, lines, errorMsg);
-}
-
-bool WhiteListFile::createWithWriteAccess(const std::string& pathToFile, std::string& errorMsg) {
-    std::vector<std::string> lines;
-    lines.reserve(2);
-
-    lines.emplace_back("4.4.14");
-    lines.push_back(User::login_name()); // equivalent to the login name
-
-    return File::create(pathToFile, lines, errorMsg);
-}
-
-bool WhiteListFile::createWithNoAccess(const std::string& pathToFile, std::string& errorMsg) {
-    std::vector<std::string> lines;
-    lines.reserve(5);
-
-    lines.emplace_back("4.4.14");
-    lines.emplace_back("userXX");
-    lines.emplace_back("userYY");
-    lines.emplace_back("-userZZ");
-    lines.emplace_back("-userZY");
-
-    return File::create(pathToFile, lines, errorMsg);
-}
-
-bool WhiteListFile::createEmpty(const std::string& pathToFile, std::string& errorMsg) {
-    std::vector<std::string> lines;
-    lines.reserve(1);
-    lines.emplace_back("4.4.14");
-
-    return File::create(pathToFile, lines, errorMsg);
-}
-
-void WhiteListFile::allow_write_access_for_server_user() {
-    std::string user = User::login_name();
-    if (verify_write_access(user))
-        return;
-
-    // add write access
-    auto it = users_with_write_access_.find(user);
-    if (it == users_with_write_access_.end()) {
-        users_with_write_access_.insert(std::make_pair(user, std::vector<std::string>()));
-    }
-}
diff -pruN 5.12.4-1/ACore/src/ecflow/core/WhiteListFile.hpp 5.13.0-1/ACore/src/ecflow/core/WhiteListFile.hpp
--- 5.12.4-1/ACore/src/ecflow/core/WhiteListFile.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/WhiteListFile.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,96 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_WhiteListFile_HPP
-#define ecflow_core_WhiteListFile_HPP
-
-///
-/// \brief Parser for whitelist file
-///
-
-#include <string>
-#include <unordered_map>
-#include <vector>
-
-// ----------------------------------------------------------------
-// The whiteList file, is used to indicate users who are allowed
-// read/write access to the server when calling *user* commands
-
-class WhiteListFile {
-public:
-    WhiteListFile();
-    // Disable copy (and move) semantics
-    WhiteListFile(const WhiteListFile&)                  = delete;
-    const WhiteListFile& operator=(const WhiteListFile&) = delete;
-
-    ~WhiteListFile();
-
-    // If any user in read/write lists, then it has read access.
-    // However, when paths are specified the returns may not be the same. i.e,
-    //    verify_read_access("userX") != verify_read_access("userX","/f")
-    // This is is because different commands, call different functions:
-    // Hence if we have:
-    //              verify_read_access(userX) verify_read_access(userX,'/f') verify_read_access(userX,'/s1')
-    //  userX  /s1               TRUE                  FALSE                        TRUE
-    //  -userX /s2               TRUE                  FALSE                        FALSE
-    //
-    // If we also add * in the mix: All users have read/write access to suite `/a`, and read access to `/b`
-    //  *  /a
-    //  -* /b
-    //  userX  /s1
-    //  -userX /s2
-    // HENCE:
-    //    verify_read_access(userX)   -> TRUE
-    //    verify_read_access(yy)      -> TRUE  // yy qualifies as all users
-    //   verify_read_access(userX,/a) -> TRUE
-    //   verify_read_access(yy,/a)    -> TRUE
-    bool verify_read_access(const std::string& user) const;
-    bool verify_read_access(const std::string& user, const std::string& path) const;
-    bool verify_read_access(const std::string& user, const std::vector<std::string>& paths) const;
-
-    bool verify_write_access(const std::string& user) const;
-    bool verify_write_access(const std::string& user, const std::string& path) const;
-    bool verify_write_access(const std::string& user, const std::vector<std::string>& paths) const;
-
-    std::string dump_valid_users() const;
-
-    // Parse the file if any errors found return false and errorMsg
-    // The parser expects version number  4.4.5
-    bool load(const std::string& file, bool debug, std::string& errorMsg);
-
-    // Function used in test:
-    // Will overwrite the existing file
-    static bool createWithReadAccess(const std::string& pathToFile, std::string& errorMsg);
-    static bool createWithWriteAccess(const std::string& pathToFile, std::string& errorMsg);
-    static bool createWithNoAccess(const std::string& pathToFile, std::string& errorMsg);
-    static bool createEmpty(const std::string& pathToFile, std::string& errorMsg);
-
-    size_t read_access_size() const { return users_with_read_access_.size(); }
-    size_t write_access_size() const { return users_with_write_access_.size(); }
-
-    // return true if current user has write access
-    void allow_write_access_for_server_user();
-
-private:
-    bool validateVersionNumber(const std::string& line, std::string& errorMsg) const;
-    bool add_user(std::vector<std::string>& tokens, std::string& error_msg);
-
-    typedef std::unordered_map<std::string, std::vector<std::string>> mymap;
-    bool verify_path_access(const std::string& user, const std::vector<std::string>& paths, const mymap&) const;
-    bool verify_path_access(const std::string& user, const std::string& path, const mymap&) const;
-
-    bool all_users_have_read_access_{false};
-    bool all_users_have_write_access_{false};
-    std::string white_list_file_;
-    mymap users_with_read_access_;  // user,paths
-    mymap users_with_write_access_; // user,paths
-};
-
-#endif /* ecflow_core_WhiteListFile_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/cereal_boost_time.hpp 5.13.0-1/ACore/src/ecflow/core/cereal_boost_time.hpp
--- 5.12.4-1/ACore/src/ecflow/core/cereal_boost_time.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/cereal_boost_time.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_cereal_boost_time_HPP
-#define ecflow_core_cereal_boost_time_HPP
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/date_time/posix_time/time_serialize.hpp>
-#include <cereal/archives/json.hpp>
-#include <cereal/details/traits.hpp>
-
-namespace cereal {
-
-// ===================================================================================
-// Handle boost::posix_time::time_duration
-template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
-inline void save(Archive& ar, boost::posix_time::time_duration const& d) {
-    ar(cereal::make_nvp("duration", to_simple_string(d)));
-}
-
-//! Loading for std::map<std::string, std::string> for text based archives
-template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
-inline void load(Archive& ar, boost::posix_time::time_duration& d) {
-    std::string value;
-    ar(value);
-    d = boost::posix_time::duration_from_string(value);
-}
-
-// ===================================================================================
-// Handle boost::posix_time::ptime
-template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
-inline void save(Archive& ar, boost::posix_time::ptime const& d) {
-    ar(cereal::make_nvp("ptime", to_simple_string(d)));
-}
-
-//! Loading for std::map<std::string, std::string> for text based archives
-template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
-inline void load(Archive& ar, boost::posix_time::ptime& d) {
-    std::string value;
-    ar(value);
-    d = boost::posix_time::time_from_string(value);
-}
-
-// ===================================================================================
-// Handle boost::gregorian::date
-template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
-inline void save(Archive& ar, boost::gregorian::date const& d) {
-    ar(cereal::make_nvp("date", to_simple_string(d)));
-}
-
-//! Loading for std::map<std::string, std::string> for text based archives
-template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
-inline void load(Archive& ar, boost::gregorian::date& d) {
-    std::string value;
-    ar(value);
-    d = boost::gregorian::from_simple_string(value);
-}
-
-} // namespace cereal
-
-#endif /* ecflow_core_cereal_boost_time_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/cereal_optional_nvp.hpp 5.13.0-1/ACore/src/ecflow/core/cereal_optional_nvp.hpp
--- 5.12.4-1/ACore/src/ecflow/core/cereal_optional_nvp.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/cereal_optional_nvp.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-/*
- * The MIT License (MIT)
- * Copyright (c) 2017 Yehonatan Ballas
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- */
-
-#ifndef ecflow_core_cereal_optional_nvp_HPP
-#define ecflow_core_cereal_optional_nvp_HPP
-
-///
-/// Example
-///
-/// struct B
-/// {
-/// int x, y, z;
-///
-/// template <class Archive>
-/// void serialize(Archive & ar)
-/// {
-///       cereal::make_optional_nvp(ar, "x", x);
-///       CEREAL_OPTIONAL_NVP(ar, y);
-///       CEREAL_OPTIONAL_NVP(ar, z, [this]() {return z != 1; }); // conditionally save
-/// }
-/// };
-///
-
-#include <type_traits> // for std::enable_if_t
-
-#include <cereal/cereal.hpp>
-#include <cereal/details/traits.hpp>
-
-namespace cereal {
-class JSONInputArchive;
-class XMLInputArchive;
-
-// Optionally load an NVP if its name equals to the current node's name
-// Loading members should be done in the same order they were saved
-// return true if NVP found
-template <class Archive, class T>
-typename std::enable_if_t<traits::is_same_archive<Archive, JSONInputArchive>::value ||
-                              traits::is_same_archive<Archive, XMLInputArchive>::value,
-                          bool>
-make_optional_nvp(Archive& ar, const char* name, T&& value) {
-    const auto node_name = ar.getNodeName();
-
-    // if names are equal
-    if (node_name != nullptr && strcmp(name, node_name) == 0) {
-        ar(make_nvp(name, std::forward<T>(value))); // load the NVP. Advances to the next node
-        return true;
-    }
-
-    return false;
-}
-
-template <class Archive, class T>
-void make_optional_nvp(OutputArchive<Archive>& ar, const char* name, T&& value) {
-    ar(make_nvp(name, std::forward<T>(value)));
-}
-
-// Saves NVP if predicate is true. Useful for avoiding splitting into save & load if also saving optionally.
-template <class Archive, class T, class Predicate>
-void make_optional_nvp(OutputArchive<Archive>& ar, const char* name, T&& value, Predicate predicate) {
-    if (predicate())
-        ar(make_nvp(name, std::forward<T>(value)));
-}
-
-template <class Archive, class T, class Predicate>
-typename std::enable_if_t<traits::is_same_archive<Archive, JSONInputArchive>::value ||
-                              traits::is_same_archive<Archive, XMLInputArchive>::value,
-                          bool>
-make_optional_nvp(Archive& ar, const char* name, T&& value, Predicate predicate) {
-    return make_optional_nvp(ar, name, std::forward<T>(value));
-}
-} // namespace cereal
-
-// Macros for using the variable name as the NVP name
-#define EXPAND(x) x
-#define GET_CEREAL_OPTIONAL_NVP_MACRO(_1, _2, _3, NAME, ...) NAME
-#define CEREAL_OPTIONAL_NVP(...) \
-    EXPAND(GET_CEREAL_OPTIONAL_NVP_MACRO(__VA_ARGS__, CEREAL_OPTIONAL_NVP_3, CEREAL_OPTIONAL_NVP_2)(__VA_ARGS__))
-
-#define CEREAL_OPTIONAL_NVP_2(ar, T) ::cereal::make_optional_nvp(ar, #T, T)
-#define CEREAL_OPTIONAL_NVP_3(ar, T, P) ::cereal::make_optional_nvp(ar, #T, T, P)
-
-#endif /* ecflow_core_cereal_optional_nvp_HPP */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/ecflow_source_build_dir.h.in 5.13.0-1/ACore/src/ecflow/core/ecflow_source_build_dir.h.in
--- 5.12.4-1/ACore/src/ecflow/core/ecflow_source_build_dir.h.in	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/ecflow_source_build_dir.h.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_ecflow_source_build_dir_H
-#define ecflow_core_ecflow_source_build_dir_H
- 
-#define CMAKE_ECFLOW_SOURCE_DIR "@PROJECT_SOURCE_DIR@"
-#define CMAKE_ECFLOW_BUILD_DIR  "@PROJECT_BINARY_DIR@"
-
-#endif /* ecflow_core_ecflow_source_build_dir_H */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/ecflow_version.h.in 5.13.0-1/ACore/src/ecflow/core/ecflow_version.h.in
--- 5.12.4-1/ACore/src/ecflow/core/ecflow_version.h.in	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/ecflow_version.h.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_ecflow_version_config_H
-#define ecflow_core_ecflow_version_config_H
-
-// clang-format off
-#define ECFLOW_VERSION   "@ecflow_VERSION@"
-#define ECFLOW_RELEASE   "@ecflow_VERSION_MAJOR@"
-#define ECFLOW_MAJOR     "@ecflow_VERSION_MINOR@"
-#define ECFLOW_MINOR     "@ecflow_VERSION_PATCH@"
-
-// available but not used
-// PROJECT_VERSION=@PROJECT_VERSION@
-// PROJECT_VERSION_MAJOR=@PROJECT_VERSION_MAJOR@
-// PROJECT_VERSION_MINOR=@PROJECT_VERSION_MINOR@
-// PROJECT_VERSION_PATCH=@PROJECT_VERSION_PATCH@
-
-#endif /* ecflow_core_ecflow_version_config_H */
diff -pruN 5.12.4-1/ACore/src/ecflow/core/perf_timer.hpp 5.13.0-1/ACore/src/ecflow/core/perf_timer.hpp
--- 5.12.4-1/ACore/src/ecflow/core/perf_timer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/src/ecflow/core/perf_timer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_perf_timer_HPP
-#define ecflow_core_perf_timer_HPP
-
-#include <cassert>
-#include <chrono>
-#include <functional> // std::ref
-#include <iostream>
-#include <string>
-#include <vector>
-
-// TODO: remove when we use c++17
-template <typename F, typename... Args>
-auto invoke(F f, Args&&... args) -> decltype(std::ref(f)(std::forward<Args>(args)...)) {
-    return std::ref(f)(std::forward<Args>(args)...);
-}
-
-template <typename Time = std::chrono::microseconds, typename Clock = std::chrono::high_resolution_clock>
-struct perf_timer
-{
-    template <typename F, typename... Args>
-    static Time duration(F&& f, Args... args) {
-        auto start = Clock::now();
-
-        // std::invoke(std::forward<F>(f), std::forward<Args>(args)...); // c++17
-        invoke(std::forward<F>(f), std::forward<Args>(args)...);
-
-        auto end = Clock::now();
-        return std::chrono::duration_cast<Time>(end - start);
-    }
-};
-
-template <class Resolution = std::chrono::milliseconds>
-class Timer {
-public:
-    using Clock = std::conditional_t<std::chrono::high_resolution_clock::is_steady,
-                                     std::chrono::high_resolution_clock,
-                                     std::chrono::steady_clock>;
-
-private:
-    const Clock::time_point start_ = Clock::now();
-
-public:
-    Timer()  = default;
-    ~Timer() = default;
-    void elapsed(const char* msg) const {
-        const auto end = Clock::now();
-        std::cout << msg << " " << std::chrono::duration_cast<Resolution>(end - start_).count() << std::endl;
-    }
-
-    Resolution elapsed() const { return std::chrono::duration_cast<Resolution>(Clock::now() - start_); }
-};
-
-#endif /* ecflow_core_perf_timer_HPP */
diff -pruN 5.12.4-1/ACore/test/TestCalendar.cpp 5.13.0-1/ACore/test/TestCalendar.cpp
--- 5.12.4-1/ACore/test/TestCalendar.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestCalendar.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,520 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/date_time/posix_time/time_formatters.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Cal.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Calendar)
-
-BOOST_AUTO_TEST_CASE(test_calendar_default_ptime) {
-    cout << "ACore:: ...test_calendar_default_ptime \n";
-
-    ptime time;
-    BOOST_CHECK_MESSAGE(time.is_special(), "Default ptime is special");
-    BOOST_CHECK_MESSAGE(time.is_not_a_date_time(), "Default ptime is_not_a_date_time");
-    BOOST_CHECK_MESSAGE(!time.is_infinity(), "Expected Default ptime not is_infinity");
-    BOOST_CHECK_MESSAGE(!time.is_pos_infinity(), "Expected default ptime not is_pos_infinity");
-    BOOST_CHECK_MESSAGE(!time.is_neg_infinity(), "Expected default ptime not is_neg_infinity");
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_state_parsing) {
-    cout << "ACore:: ...test_calendar_state_parsing\n";
-
-    Calendar calendar;
-    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Default calendar type should be real");
-
-    // init the calendar to 2009, Feb, 10th, then write out the state
-    boost::gregorian::date theDate(2009, 2, 10);
-    ptime time(theDate, hours(23) + minutes(59));
-    calendar.init(time, Calendar::REAL);
-    std::string calendar_state;
-    calendar.write_state(calendar_state);
-
-    // read the state, into a different calendar & compare
-    std::vector<std::string> lineTokens;
-    Str::split(calendar_state, lineTokens);
-    Calendar calendar2;
-    calendar2.read_state(calendar_state, lineTokens);
-    BOOST_CHECK_MESSAGE(calendar == calendar2,
-                        "Calendar should be the same\n"
-                            << calendar.toString() << "\n"
-                            << calendar2.toString());
-
-    // Update calendar.
-    calendar.update(minutes(2));
-    BOOST_CHECK_MESSAGE(!(calendar == calendar2), "Calendar should be different");
-
-    // re-compare after reloading state
-    lineTokens.clear();
-    calendar_state.clear();
-    calendar.write_state(calendar_state);
-
-    Str::split(calendar_state, lineTokens);
-    calendar2.read_state(calendar_state, lineTokens);
-
-    BOOST_CHECK_MESSAGE(calendar == calendar2, "Calendar should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_1) {
-    cout << "ACore:: ...test_calendar_1\n";
-
-    Calendar calendar;
-    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Default calendar type should be real");
-
-    // init the calendar to 2009, Feb, 10th,  15 minutes past midnight
-    boost::gregorian::date theDate(2009, 2, 10);
-    ptime time(theDate, hours(23) + minutes(59));
-    calendar.init(time, Calendar::HYBRID);
-    BOOST_CHECK_MESSAGE(calendar.hybrid(), "init failed to reset calendar type");
-
-    calendar.update(minutes(2));
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar) {
-    cout << "ACore:: ...test_calendar_basic\n";
-
-    Calendar calendar;
-    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Default calendar type should be real");
-
-    // init the calendar to 2009, Feb, 10th,  15 minutes past midnight
-    boost::gregorian::date theDate(2009, 2, 10);
-    ptime time(theDate, minutes(15));
-    calendar.init(time, Calendar::REAL);
-    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Calendar should now be REAL");
-
-    std::string expectedTime = "2009-Feb-10 00:15:00";
-    std::string actualTime   = to_simple_string(calendar.suiteTime());
-    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
-
-    time_duration td = hours(1) + minutes(10);
-    calendar.update(td);
-    expectedTime = "2009-Feb-10 01:25:00";
-    actualTime   = to_simple_string(calendar.suiteTime());
-    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
-
-    // Increment by 24 hours
-    calendar.update(hours(24));
-    expectedTime = "2009-Feb-11 01:25:00";
-    actualTime   = to_simple_string(calendar.suiteTime());
-    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_time_series_relative) {
-    cout << "ACore:: ...test_calendar_time_series_relative\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
-
-    std::string expectedTime = "2010-Feb-10 00:00:00";
-    std::string actualTime   = to_simple_string(calendar.suiteTime());
-    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
-
-    // Create a test when we can match a time series. Need to sync hour with suite time
-    // at hour 1, suite time should also be 01:00, for test to work
-    //
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr    1:00
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), true /*relative*/);
-
-    for (int hour = 1; hour < 24; hour++) {
-        // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
-        calendar.update(time_duration(hours(1)));
-        timeSeries.calendarChanged(calendar);
-
-        //		cerr << "hour = " << hour << " suiteTime " << to_simple_string(calendar.suiteTime()) << "\n";
-        if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                "Calendar should match relative time series at hour " << hour);
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                "Calendar should NOT match relative time series at hour " << hour);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_time_series_relative_complex) {
-    cout << "ACore:: ...test_calendar_time_series_relative_complex\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
-
-    // Create a test when we can match a time series
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr   00:15
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15), true /*relative*/);
-
-    for (int hour = 0; hour < 24; hour++) {
-        for (int minute = 0; minute < 60; minute++) {
-
-            // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
-            calendar.update(minutes(1));
-            timeSeries.calendarChanged(calendar);
-
-            tm suiteTm = to_tm(calendar.suiteTime());
-
-            bool matches = timeSeries.isFree(calendar);
-
-            bool intersects =
-                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
-                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
-            // Ovoid overshooting past end of series
-            bool boundaryOk = true;
-            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
-                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
-            }
-
-            if (intersects && boundaryOk) {
-                BOOST_CHECK_MESSAGE(matches,
-                                    "Calendar should match relative time series at "
-                                        << suiteTm.tm_hour << Str::COLON() << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-                if (!matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!matches,
-                                    "Calendar should NOT match relative time series at "
-                                        << suiteTm.tm_hour << Str::COLON() << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-
-                if (matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_time_series_real) {
-    cout << "ACore:: ...test_calendar_time_series_real\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    std::string expectedTime = "2010-Feb-10 00:00:00";
-    std::string actualTime   = to_simple_string(calendar.suiteTime());
-    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
-
-    // Create a test when we can match a time series
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr    1:00
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0));
-
-    for (int hour = 1; hour < 24; hour++) {
-        // Update calendar every hour, then see we can match time series, in REAL
-        // Update will set the local time from the computers system clock, however
-        // for testing this will need to be overriden below.
-        calendar.update(time_duration(hours(1)));
-
-        // cerr << "hour = " << hour << " suiteTime " << to_simple_string(calendar.suiteTime())  << "\n";
-        if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar), "Calendar should match time series at hour " << hour);
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Calendar should NOT match time series at hour " << hour);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_time_series_real_complex) {
-    cout << "ACore:: ...test_calendar_time_series_real_complex\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr   00:15
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15));
-
-    for (int hour = 0; hour < 24; hour++) {
-        for (int minute = 0; minute < 60; minute++) {
-
-            // Update calendar every minute, then see we can match time series, *RELATIVE* to suite start
-            calendar.update(minutes(1));
-
-            tm suiteTm = to_tm(calendar.suiteTime());
-
-            bool matches = timeSeries.isFree(calendar);
-
-            bool intersects =
-                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
-                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
-            // Ovoid overshooting past end of series
-            bool boundaryOk = true;
-            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
-                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
-            }
-
-            if (intersects && boundaryOk) {
-                BOOST_CHECK_MESSAGE(matches,
-                                    "Calendar should match relative time series at "
-                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-                if (!matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!matches,
-                                    "Calendar should NOT match relative time series at "
-                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-
-                if (matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_hybrid) {
-    cout << "ACore:: ...test_calendar_hybrid\n";
-
-    // The hybrid calendar should not change the suite date.
-    // Test by updateing calendar by more than 24 hours
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
-    BOOST_CHECK_MESSAGE(calendar.hybrid(), "calendar type should be hybrid");
-
-    std::string expectedTime = "2010-Feb-10 00:00:00";
-    std::string actualTime   = to_simple_string(calendar.suiteTime());
-    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
-
-    std::string expectedDate = "2010-Feb-10";
-
-    // Check cache is correct
-    int expected_day_of_week  = calendar.day_of_week();
-    int expected_day_of_year  = calendar.day_of_year();
-    int expected_day_of_month = calendar.day_of_month();
-    int expected_month        = calendar.month();
-    int expected_year         = calendar.year();
-
-    for (int hour = 1; hour < 73; hour++) {
-        // Update calendar every hour, for 73 hours
-        // the date should be the same, i.e 2009, Feb, 10th
-
-        ptime timeBeforeUpdate = calendar.suiteTime();
-
-        calendar.update(time_duration(hours(1)));
-
-        ptime timeAfterUpdate = calendar.suiteTime();
-
-        //		cerr << "hour = " << hour << " timeBeforeUpdate " << to_simple_string(timeBeforeUpdate)
-        //		    << "   timeAfterUpdate = " << to_simple_string(timeAfterUpdate) <<  "\n";
-
-        if (hour != 24 && hour != 48 && hour != 72) {
-            time_period diff(timeBeforeUpdate, timeAfterUpdate);
-            time_duration gap = diff.length();
-            BOOST_CHECK_MESSAGE(gap.hours() == 1,
-                                "Expected one hour difference but found " << gap.hours() << " at hour " << hour);
-        }
-
-        std::string actualDate = to_simple_string(calendar.suiteTime().date());
-        BOOST_CHECK_MESSAGE(actualDate == expectedDate,
-                            "Expected '" << expectedDate << "' but found " << actualDate << " at hour " << hour);
-
-        // check cache ECFLOW-458
-        int actual_day_of_week  = calendar.day_of_week();
-        int actual_day_of_year  = calendar.day_of_year();
-        int actual_day_of_month = calendar.day_of_month();
-        int actual_month        = calendar.month();
-        int actual_year         = calendar.year();
-        BOOST_CHECK_MESSAGE(actual_day_of_week == expected_day_of_week,
-                            "Expected day of week '" << expected_day_of_week << "' but found " << actual_day_of_week
-                                                     << " at hour " << hour);
-        BOOST_CHECK_MESSAGE(actual_day_of_year == expected_day_of_year,
-                            "Expected day of year '" << expected_day_of_year << "' but found " << actual_day_of_year
-                                                     << " at hour " << hour);
-        BOOST_CHECK_MESSAGE(actual_day_of_month == expected_day_of_month,
-                            "Expected day of month '" << expected_day_of_month << "' but found " << actual_day_of_month
-                                                      << " at hour " << hour);
-        BOOST_CHECK_MESSAGE(actual_month == expected_month,
-                            "Expected month '" << expected_month << "' but found " << actual_month << " at hour "
-                                               << hour);
-        BOOST_CHECK_MESSAGE(actual_year == expected_year,
-                            "Expected year '" << expected_year << "' but found " << actual_year << " at hour " << hour);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_day_changed_for_real) {
-    cout << "ACore:: ...test_day_changed_for_real\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "calendar type should be real");
-
-    // Check cache is correct
-    int expected_day_of_week  = calendar.day_of_week();
-    int expected_day_of_year  = calendar.day_of_year();
-    int expected_day_of_month = calendar.day_of_month();
-
-    for (int hour = 1; hour < 73; hour++) {
-        // Update calendar every hour, for 72 hours
-        calendar.update(time_duration(hours(1)));
-
-        if (hour == 24 || hour == 48 || hour == 72) {
-            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
-                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
-            expected_day_of_week++;
-            expected_day_of_year++;
-            expected_day_of_month++;
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
-                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
-        }
-
-        // check cache ECFLOW-458
-        int actual_day_of_week  = calendar.day_of_week();
-        int actual_day_of_year  = calendar.day_of_year();
-        int actual_day_of_month = calendar.day_of_month();
-        BOOST_CHECK_MESSAGE(actual_day_of_week == expected_day_of_week,
-                            "Expected day of week '" << expected_day_of_week << "' but found " << actual_day_of_week
-                                                     << " at hour " << hour);
-        BOOST_CHECK_MESSAGE(actual_day_of_year == expected_day_of_year,
-                            "Expected day of year '" << expected_day_of_year << "' but found " << actual_day_of_year
-                                                     << " at hour " << hour);
-        BOOST_CHECK_MESSAGE(actual_day_of_month == expected_day_of_month,
-                            "Expected day of month '" << expected_day_of_month << "' but found " << actual_day_of_month
-                                                      << " at hour " << hour);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_day_changed_for_hybrid) {
-    cout << "ACore:: ...test_day_changed_for_hybrid\n";
-
-    // init the calendar
-    Calendar calendar; // default clock is real
-    calendar.init(ptime(date(2015, 10, 31), minutes(0)), Calendar::HYBRID);
-    BOOST_CHECK_MESSAGE(calendar.hybrid(), "calendar type should be hybrid");
-
-    // HYBRID calendars allow for day change but not date.
-    std::string expected_date = to_simple_string(calendar.date());
-
-    // Check cache is correct
-    int expected_day_of_week  = calendar.day_of_week();
-    int expected_day_of_year  = calendar.day_of_year();
-    int expected_day_of_month = calendar.day_of_month();
-
-    for (int hour = 1; hour < 73; hour++) {
-        // Update calendar every hour, for 72 hours
-        calendar.update(time_duration(hours(1)));
-
-        BOOST_CHECK_MESSAGE(expected_date == to_simple_string(calendar.date()),
-                            "Unexpected date change for hybrid calendar at hour " << hour);
-
-        // Day should change even for hybrid calendar,
-        if (hour == 24 || hour == 48 || hour == 72) {
-            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
-                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
-                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
-        }
-
-        // check cache ECFLOW-458
-        int actual_day_of_week  = calendar.day_of_week();
-        int actual_day_of_year  = calendar.day_of_year();
-        int actual_day_of_month = calendar.day_of_month();
-        BOOST_CHECK_MESSAGE(actual_day_of_week == expected_day_of_week,
-                            "Expected day of week '" << expected_day_of_week << "' but found " << actual_day_of_week
-                                                     << " at hour " << hour);
-        BOOST_CHECK_MESSAGE(actual_day_of_year == expected_day_of_year,
-                            "Expected day of year '" << expected_day_of_year << "' but found " << actual_day_of_year
-                                                     << " at hour " << hour);
-        BOOST_CHECK_MESSAGE(actual_day_of_month == expected_day_of_month,
-                            "Expected day of month '" << expected_day_of_month << "' but found " << actual_day_of_month
-                                                      << " at hour " << hour);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_calendar_julian) {
-    cout << "ACore:: ...test_calendar_julian\n";
-
-    Calendar calendar;
-    calendar.init(ptime(date(2017, 1, 1), minutes(0)), Calendar::REAL);
-    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "calendar type should be real");
-
-    int days = 0;
-    while (calendar.year() != 2018) {
-
-        boost::gregorian::date cal_date = calendar.date();
-        long boost_julian               = cal_date.julian_day();
-
-        std::string iso_string = to_iso_string(cal_date);
-        auto date_as_long      = ecf::convert_to<long>(iso_string);
-        long ecmwf_julian      = Cal::date_to_julian(date_as_long);
-
-        BOOST_CHECK_MESSAGE(boost_julian == ecmwf_julian,
-                            "boost julian " << boost_julian << " != ecmwf julian " << ecmwf_julian << " for "
-                                            << iso_string);
-
-        // Update calendar every day for a year
-        calendar.update(time_duration(hours(24)));
-        days++;
-    }
-    BOOST_CHECK_MESSAGE(days == 365, "expected 365 days but found " << days);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestCereal.cpp 5.13.0-1/ACore/test/TestCereal.cpp
--- 5.12.4-1/ACore/test/TestCereal.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestCereal.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,116 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestSerialisation.hpp"
-#include "ecflow/core/Filesystem.hpp"
-
-using namespace ecf;
-using namespace boost;
-using namespace std;
-
-class MyClass {
-public:
-    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5, SUSPENDED = 6 };
-    MyClass() = default;
-    bool operator==(const MyClass& rhs) const { return x == rhs.x && y == rhs.y && state_ == rhs.state_; }
-    void print(std::ostream& os) const { os << "MyClass: x(" << x << ") y(" << y << ") state(" << state_ << ")"; }
-
-private:
-    // This method lets cereal know which data members to serialize
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& archive, std::uint32_t const version) {
-        archive(CEREAL_NVP(x), CEREAL_NVP(y), CEREAL_NVP(state_));
-    }
-    int x{2}, y{2};
-    State state_{State::SUSPENDED};
-};
-CEREAL_CLASS_VERSION(MyClass, 1)
-
-class MyTop : public MyClass {
-public:
-    MyTop() = default;
-    void set(int x, int y, int z) {
-        x_ = x;
-        y_ = y;
-        z_ = z;
-    }
-    bool operator==(const MyTop& rhs) const {
-        return (MyClass::operator==(rhs)) && x_ == rhs.x_ && y_ == rhs.y_ && z_ == rhs.z_;
-    }
-    void print(std::ostream& os) const {
-        os << "MyTop:";
-        MyClass::print(os);
-        os << ": x(" << x_ << ") y(" << y_ << ") z(" << z_ << ")";
-    }
-
-private:
-    // This method lets cereal know which data members to serialize
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& archive, std::uint32_t const version) {
-        archive(cereal::base_class<MyClass>(this), CEREAL_NVP(x_), CEREAL_NVP(y_), CEREAL_NVP(z_));
-    }
-    int x_{1}, y_{1}, z_{1};
-};
-CEREAL_CLASS_VERSION(MyTop, 1)
-
-std::ostream& operator<<(std::ostream& os, MyTop const& m) {
-    m.print(os);
-    return os;
-}
-
-// =================================================================================
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Cereal)
-
-BOOST_AUTO_TEST_CASE(test_cereal_json) {
-    cout << "ACore:: ...test_cereal_json \n";
-    std::string path = "test_cereal_json";
-    {
-        std::ofstream os(path);
-        cereal::JSONOutputArchive oarchive(os); // Create an output archive
-
-        MyTop m1, m2, m3;
-        oarchive(cereal::make_nvp("MyTop", m1), m2, m3); // Write the data to the archive
-    }                                                    // archive goes out of scope, ensuring all contents are flushed
-
-    {
-        BOOST_CHECK_MESSAGE(fs::exists(path), " Expected file to exist");
-
-        std::ifstream is(path);
-        cereal::JSONInputArchive iarchive(is); // Create an input archive
-
-        MyTop m1, m2, m3;
-        iarchive(m1, m2, m3); // Read the data from the archive
-
-        fs::remove(path); // Remove the file. Comment out for debugging
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_cereal_json2) {
-    cout << "ACore:: ...test_cereal_json2\n";
-    MyTop m1;
-    m1.set(10, 10, 10);
-    std::string path = "test_cereal_json2";
-    { ecf::doSave(path, m1); }
-    { ecf::doRestore(path, m1); }
-    { ecf::doSaveAndRestore<MyTop>(path); }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestCerealOptionalNVP.cpp 5.13.0-1/ACore/test/TestCerealOptionalNVP.cpp
--- 5.12.4-1/ACore/test/TestCerealOptionalNVP.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestCerealOptionalNVP.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-using namespace ecf;
-using namespace boost;
-using namespace std;
-
-class Base {
-public:
-    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5, SUSPENDED = 6 };
-    Base() = default;
-    explicit Base(bool test) : test_(test) {}
-    bool operator==(const Base& rhs) const {
-        return x == rhs.x && y == rhs.y && state_ == rhs.state_ && test_ == rhs.test_;
-    }
-    void print(std::ostream& os) const {
-        os << "Base: x(" << x << ") y(" << y << ") state(" << state_ << ") test(" << test_ << ")";
-    }
-
-private:
-    // This method lets cereal know which data members to serialize
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(CEREAL_NVP(x), CEREAL_NVP(y), CEREAL_NVP(state_));
-        CEREAL_OPTIONAL_NVP(ar, test_, [this]() { return test_; }); // conditionally save
-    }
-    int x{2}, y{2};
-    State state_{State::SUSPENDED};
-    bool test_{false};
-};
-
-std::ostream& operator<<(std::ostream& os, Base const& m) {
-    m.print(os);
-    return os;
-}
-
-// =================================================================================
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_CerealOptionalNVP)
-
-BOOST_AUTO_TEST_CASE(test_cereal_optional) {
-    cout << "ACore:: ...test_cereal_optional\n";
-    Base original;
-    Base original1(true);
-    std::string path = "test_cereal_optional";
-    {
-        std::ofstream os(path);
-        cereal::JSONOutputArchive oarchive(os); // Create an output archive
-        oarchive(cereal::make_nvp("Base", original),
-                 cereal::make_nvp("Base", original1)); // Write the data to the archive
-    }                                                  // archive goes out of scope, ensuring all contents are flushed
-
-    {
-        BOOST_CHECK_MESSAGE(fs::exists(path), " Expected file to exist");
-
-        std::ifstream is(path);
-        cereal::JSONInputArchive iarchive(is); // Create an input archive
-
-        Base restored;
-        Base restored1;
-        iarchive(restored, restored1); // Read the data from the archive
-        BOOST_CHECK_MESSAGE(restored == original, "restored(" << restored << ") != original(" << original << ")");
-        BOOST_CHECK_MESSAGE(restored1 == original1, "restored1(" << restored1 << ") != original1(" << original1 << ")");
-        fs::remove(path); // Remove the file. Comment out for debugging
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestCerealWithHierarchy.cpp 5.13.0-1/ACore/test/TestCerealWithHierarchy.cpp
--- 5.12.4-1/ACore/test/TestCerealWithHierarchy.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestCerealWithHierarchy.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-using namespace ecf;
-using namespace boost;
-using namespace std;
-
-// ======================================================================================
-
-class BaseCmd {
-public:
-    BaseCmd()          = default;
-    virtual ~BaseCmd() = default;
-
-    bool operator==(const BaseCmd& rhs) const { return true; }
-    void print(std::ostream& os) const {}
-    virtual bool equals(BaseCmd* rhs) const = 0;
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& archive, std::uint32_t const version) {}
-};
-
-class Derived1 : public BaseCmd {
-public:
-    Derived1() = default;
-    explicit Derived1(int x) : BaseCmd(), x_(x) {}
-    ~Derived1() override = default;
-
-    int get_x() const { return x_; }
-
-    bool equals(BaseCmd* rhs) const override {
-        auto* the_rhs = dynamic_cast<Derived1*>(rhs);
-        if (!the_rhs)
-            return false;
-        if (x_ != the_rhs->get_x())
-            return false;
-        return true;
-    }
-
-    void print(std::ostream& os) const {
-        os << "Derived1:";
-        BaseCmd::print(os);
-        os << ": x(" << x_ << ")";
-    }
-
-private:
-    int x_{0};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<BaseCmd>(this), x_);
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, Derived1 const& m) {
-    m.print(os);
-    return os;
-}
-
-class CmdContainer {
-public:
-    CmdContainer() = default;
-    explicit CmdContainer(std::shared_ptr<BaseCmd> cmd) : cmd_(cmd) {}
-
-    bool operator==(const CmdContainer& rhs) const {
-        if (!cmd_.get() && !rhs.cmd_.get())
-            return true;
-        if (cmd_.get() && !rhs.cmd_.get())
-            return false;
-        if (!cmd_.get() && rhs.cmd_.get())
-            return false;
-        return (cmd_->equals(rhs.cmd_.get()));
-    }
-
-    void print(std::ostream& os) const {
-        if (cmd_.get())
-            cmd_->print(os);
-        os << "NULL request";
-    }
-
-private:
-    std::shared_ptr<BaseCmd> cmd_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& archive) {
-        archive(CEREAL_NVP(cmd_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, CmdContainer const& m) {
-    m.print(os);
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(Derived1)
-
-// =================================================================================
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_CerealWithHierarchy)
-
-BOOST_AUTO_TEST_CASE(test_cereal_save_as_string_and_save_as_filename) {
-    cout << "ACore:: ...test_cereal_save_as_string_and_save_as_filename\n";
-
-    std::shared_ptr<BaseCmd> cmd = std::make_shared<Derived1>(10);
-    CmdContainer originalCmd(cmd);
-    std::string saved_cmd_as_string;
-
-    // SAVE as string and file
-    {
-        BOOST_REQUIRE_NO_THROW(ecf::save("ACore.txt", originalCmd)); // save as filename
-        ecf::save_as_string(saved_cmd_as_string, originalCmd); // save as string, this is buggy forgets trailing '}'
-    }
-
-    // RESTORE from filename and string
-    {
-        CmdContainer restoredCmd;
-        BOOST_REQUIRE_NO_THROW(ecf::restore("ACore.txt", restoredCmd)); // restore from filename
-        BOOST_REQUIRE_MESSAGE(restoredCmd == originalCmd,
-                              "restoredCmd " << restoredCmd << "  originalCmd " << originalCmd);
-    }
-    {
-        // cout <<  saved_cmd_as_string << "\n";
-        CmdContainer restoredCmd;
-        ecf::restore_from_string(saved_cmd_as_string, restoredCmd); // restore form string fails, due to missing '}'
-        BOOST_REQUIRE_MESSAGE(restoredCmd == originalCmd,
-                              "restoredCmd " << restoredCmd << "  originalCmd " << originalCmd);
-    }
-
-    fs::remove("ACore.txt");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestChrono.cpp 5.13.0-1/ACore/test/TestChrono.cpp
--- 5.12.4-1/ACore/test/TestChrono.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestChrono.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,126 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Chrono.hpp"
-
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Chrono)
-
-BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_create_reference_instant) {
-    Instant instant;
-    BOOST_CHECK_EQUAL(Instant::format(instant), "19700101T000000");
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono__is_able_to_create_instant_based_on_std_chrono_time_point) {
-    Instant original{std::chrono::system_clock::now()};
-
-    auto timestamp        = Instant::format(original);
-    Instant reconstructed = Instant::parse(timestamp);
-    auto timestamp2       = Instant::format(reconstructed);
-
-    BOOST_CHECK_EQUAL(original, reconstructed);
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_parse_and_format_instant) {
-    {
-        std::string value = "19700101T000000";
-        Instant instant   = Instant::parse(value);
-        BOOST_CHECK_EQUAL(Instant::format(instant), value);
-    }
-    {
-        std::string value = "20000101T235959";
-        Instant instant   = Instant::parse(value);
-        BOOST_CHECK_EQUAL(Instant::format(instant), value);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_compare_instants_for_equality) {
-    Instant instant0 = Instant::parse("20000101T235959");
-
-    Instant instant1 = instant0;
-    Instant instant2 = Instant::parse("20000102T000000");
-    Instant instant3 = Instant::parse("20000102T000001");
-
-    BOOST_CHECK(instant0 == instant1);
-
-    BOOST_CHECK(instant1 == instant1);
-    BOOST_CHECK(instant1 != instant2);
-    BOOST_CHECK(instant1 != instant3);
-
-    BOOST_CHECK(instant2 != instant1);
-    BOOST_CHECK(instant2 == instant2);
-    BOOST_CHECK(instant2 != instant3);
-
-    BOOST_CHECK(instant3 != instant1);
-    BOOST_CHECK(instant3 != instant2);
-    BOOST_CHECK(instant3 == instant3);
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_compare_instants_for_inequality) {
-    Instant instant1 = Instant::parse("20000101T235959");
-    Instant instant2 = Instant::parse("20000102T000000");
-    Instant instant3 = Instant::parse("20000102T000001");
-
-    BOOST_CHECK(instant1 < instant2);
-    BOOST_CHECK(instant1 < instant3);
-
-    BOOST_CHECK(instant2 > instant1);
-    BOOST_CHECK(instant2 < instant3);
-
-    BOOST_CHECK(instant3 > instant1);
-    BOOST_CHECK(instant3 > instant2);
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_add_duration_to_instant) {
-    {
-        Instant instant = Instant::parse("20000101T235959");
-        Instant next    = instant + Duration{std::chrono::seconds{1}};
-        BOOST_CHECK_EQUAL(Instant::format(next), "20000102T000000");
-    }
-    {
-        Instant instant = Instant::parse("20000101T235959");
-        Instant next    = instant + Duration{-std::chrono::seconds{1}};
-        BOOST_CHECK_EQUAL(Instant::format(next), "20000101T235958");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_subtract_duration_from_instant) {
-    {
-        Instant instant = Instant::parse("20000101T235959");
-        Instant next    = instant - Duration{std::chrono::seconds{1}};
-        BOOST_CHECK_EQUAL(Instant::format(next), "20000101T235958");
-    }
-    {
-        Instant instant = Instant::parse("20000101T235959");
-        Instant next    = instant - Duration{-std::chrono::seconds{1}};
-        BOOST_CHECK_EQUAL(Instant::format(next), "20000102T000000");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono_parsing_invalid_value_throws) {
-    using expected = std::runtime_error;
-    BOOST_CHECK_THROW(Instant::parse("20000101T235961"), expected);
-    BOOST_CHECK_THROW(Instant::parse("20000101T236059"), expected);
-    BOOST_CHECK_THROW(Instant::parse("20000101T240000"), expected);
-    BOOST_CHECK_THROW(Instant::parse("20000101T555555"), expected);
-    BOOST_CHECK_THROW(Instant::parse("20000132T000000"), expected);
-    BOOST_CHECK_THROW(Instant::parse("20000230T000000"), expected);
-    BOOST_CHECK_THROW(Instant::parse("20000431T000000"), expected);
-    BOOST_CHECK_THROW(Instant::parse("20000631T000000"), expected);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestClassDataMemberInit.cpp 5.13.0-1/ACore/test/TestClassDataMemberInit.cpp
--- 5.12.4-1/ACore/test/TestClassDataMemberInit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestClassDataMemberInit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,113 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-#include <vector>
-
-#include <boost/test/unit_test.hpp>
-
-using namespace boost;
-using namespace std;
-
-// #define DEBUG_ME 1
-
-class MyType {
-public:
-    explicit MyType(std::string str) : mName(std::move(str)) {
-#ifdef DEBUG_ME
-        std::cout << "MyType::MyType " << mName << " my_int:" << my_int_ << '\n';
-#endif
-    }
-
-    ~MyType() {
-#ifdef DEBUG_ME
-        std::cout << "MyType::~MyType " << mName << " my_int:" << my_int_ << '\n';
-#endif
-    }
-
-    MyType(const MyType& other) : mName(other.mName) {
-#ifdef DEBUG_ME
-        std::cout << "MyType::MyType(const MyType&) " << mName << " my_int:" << my_int_ << '\n';
-#endif
-    }
-
-    MyType(MyType&& other) noexcept
-        : mName(std::move(other.mName)) { // vector needs noexcept to call move copy constructor during resize.
-#ifdef DEBUG_ME
-        std::cout << "MyType::MyType(MyType&&) " << mName << " my_int:" << my_int_ << '\n';
-#endif
-    }
-
-    MyType& operator=(const MyType& other) {
-        if (this != &other)
-            mName = other.mName;
-#ifdef DEBUG_ME
-        std::cout << "MyType::operator=(const MyType&) " << mName << " my_int:" << my_int_ << '\n';
-#endif
-        return *this;
-    }
-
-    MyType& operator=(MyType&& other) noexcept {
-        if (this != &other)
-            mName = std::move(other.mName);
-#ifdef DEBUG_ME
-        std::cout << "MyType::operator=(MyType&&) " << mName << " my_int:" << my_int_ << '\n';
-#endif
-        return *this;
-    }
-
-    int my_int() const { return my_int_; }
-    int* my_ptr() const { return my_ptr_; }
-
-private:
-    std::string mName;
-    int my_int_{3};        //  show be applied for all constructor types
-    int* my_ptr_{nullptr}; //  show be applied for all constructor types
-};
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_ClassDataMemberInit)
-
-BOOST_AUTO_TEST_CASE(test_class_data_member_init) {
-    cout << "ACore:: ...test_class_data_member_init \n";
-
-    {
-        MyType type("ABC");
-        auto tmoved = std::move(type);
-        BOOST_CHECK_MESSAGE(tmoved.my_int() == 3, "Error found");
-        BOOST_CHECK_MESSAGE(tmoved.my_ptr() == nullptr, "Error found");
-    }
-    {
-        MyType type("ABC");
-        auto tcopied = MyType(type);
-        BOOST_CHECK_MESSAGE(tcopied.my_int() == 3, "Error found");
-        BOOST_CHECK_MESSAGE(tcopied.my_ptr() == nullptr, "Error found");
-    }
-    {
-        MyType tassigned("XYZ");
-        MyType type("ABC");
-        tassigned = type;
-        BOOST_CHECK_MESSAGE(tassigned.my_int() == 3, "Error found");
-        BOOST_CHECK_MESSAGE(tassigned.my_ptr() == nullptr, "Error found");
-    }
-    {
-        MyType tassigned("XYZ");
-        MyType temp("ABC");
-        tassigned = std::move(temp);
-        BOOST_CHECK_MESSAGE(tassigned.my_int() == 3, "Error found");
-        BOOST_CHECK_MESSAGE(tassigned.my_ptr() == nullptr, "Error found");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestCommandLine.cpp 5.13.0-1/ACore/test/TestCommandLine.cpp
--- 5.12.4-1/ACore/test/TestCommandLine.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestCommandLine.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,128 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/CommandLine.hpp"
-#include "ecflow/core/Converter.hpp"
-
-using namespace boost;
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_CommandLine)
-
-static void doCheck(const std::vector<std::string>& theArgs) {
-    CommandLine cl(theArgs);
-
-    BOOST_CHECK_MESSAGE(cl.size() == theArgs.size(), " argc incorrect");
-
-    for (size_t i = 0; i < cl.size(); i++) {
-        const auto& arg = cl.tokens()[i];
-        BOOST_CHECK_MESSAGE(string(arg) == theArgs[i],
-                            "Mismatch in args expected " << theArgs[i] << " but found " << arg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_with_0_args) {
-    std::vector<std::string> theArgs;
-    doCheck(theArgs);
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_with_1_arg) {
-    std::vector theArgs = {"arg1"s};
-    doCheck(theArgs);
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_with_2_args) {
-    std::vector theArgs = {"arg1"s, "arg2"s};
-    doCheck(theArgs);
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_with_10_args) {
-    std::vector<std::string> theArgs(10);
-    for (int i = 0; i < 10; i++) {
-        theArgs.push_back("arg"s + ecf::convert_to<std::string>(i));
-    }
-    doCheck(theArgs);
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_even_quotes) {
-    CommandLine cl{R"(ecflow_client --alter=change variable VARIABLE "some long value string" /path/to/task)"};
-
-    BOOST_REQUIRE_EQUAL(cl.size(), 6ul);
-    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "ecflow_client");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "some long value string");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "/path/to/task");
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_incorrect_quotes) {
-    BOOST_REQUIRE_THROW(
-        CommandLine{R"(ecflow_client --alter=change variable name "some incorrectly ' quoted value" "/some/path)"},
-        std::runtime_error);
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_unmatched_quotes) {
-    BOOST_REQUIRE_THROW(CommandLine{R"(ecflow_client --alter=change variable name "some unclosed value /some/path)"},
-                        std::runtime_error);
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_matched_quotes) {
-    CommandLine cl{R"(ecflow_client --alter=change variable name "some correctly 'inner' quotes value" '/some/path')"};
-
-    BOOST_REQUIRE_EQUAL(cl.size(), 6ul);
-    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "ecflow_client");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "some correctly 'inner' quotes value");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "/some/path");
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_single_option) {
-    CommandLine cl{R"(executable --option)"};
-
-    BOOST_CHECK_EQUAL(cl.tokens().size(), 2ul);
-    BOOST_CHECK_EQUAL(cl.tokens()[0], "executable");
-    BOOST_CHECK_EQUAL(cl.tokens()[1], "--option");
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_empty_value_parameters) {
-    CommandLine cl{R"(   executable --option parameter  type name    ""   "   "   " value " "\"" /some/path  )"};
-
-    BOOST_REQUIRE_EQUAL(cl.tokens().size(), 10ul);
-    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "executable");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[1], "--option");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[2], "parameter");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[3], "type");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "name");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[6], "   ");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[7], " value ");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[8], "\"");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[9], "/some/path");
-}
-
-BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_single_quotes_in_double_quotes) {
-    CommandLine cl{R"(ecflow_client --alter change variable name "'value'" /some/path  )"};
-
-    BOOST_REQUIRE_EQUAL(cl.tokens().size(), 7ul);
-    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "ecflow_client");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[1], "--alter");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[2], "change");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[3], "variable");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "name");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "'value'");
-    BOOST_REQUIRE_EQUAL(cl.tokens()[6], "/some/path");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestConverter.cpp 5.13.0-1/ACore/test/TestConverter.cpp
--- 5.12.4-1/ACore/test/TestConverter.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestConverter.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/gregorian/gregorian.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Converter.hpp"
-
-/*
- * The following dummy classes are defined to support test `can_use_custom_conversion_traits` and confirms that
- * customization point ::ecf::converter_traits<From, To>::convert(...) can be provided.
- */
-struct Widget
-{
-};
-struct Gizmo
-{
-};
-
-template <>
-struct ecf::converter_traits<Widget, Gizmo>
-{
-    inline static Gizmo convert(const Widget&) { return Gizmo{}; }
-};
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Converter)
-
-BOOST_AUTO_TEST_CASE(can_convert_from_numeric_to_string) {
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(0), "0");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(123), "123");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(123L), "123");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>('c'), "c");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>("s"), "s");
-
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(0.0), "0");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(0.00), "0");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(1.0), "1");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(-3.5), "-3.5");
-}
-
-BOOST_AUTO_TEST_CASE(can_convert_from_string_to_numeric) {
-    BOOST_CHECK_EQUAL(ecf::convert_to<int>("-0"), 0);
-    BOOST_CHECK_EQUAL(ecf::convert_to<int>("-123"), -123);
-    BOOST_CHECK_EXCEPTION(ecf::convert_to<int>("s"), ecf::bad_conversion, [](const auto& e) { return true; });
-    BOOST_CHECK_EXCEPTION(ecf::convert_to<int>('c'), ecf::bad_conversion, [](const auto& e) { return true; });
-
-    BOOST_CHECK_EQUAL(ecf::convert_to<unsigned int>("-0"), 0U);
-    BOOST_CHECK_EQUAL(ecf::convert_to<unsigned int>("-123"), static_cast<unsigned int>(-123));
-    BOOST_CHECK_EXCEPTION(ecf::convert_to<unsigned int>("s"), ecf::bad_conversion, [](const auto& e) { return true; });
-    BOOST_CHECK_EXCEPTION(ecf::convert_to<unsigned int>('c'), ecf::bad_conversion, [](const auto& e) { return true; });
-
-    BOOST_CHECK_EQUAL(ecf::convert_to<long>("-0"), 0);
-    BOOST_CHECK_EQUAL(ecf::convert_to<long>(-123), -123);
-    BOOST_CHECK_EXCEPTION(ecf::convert_to<long>("s"), ecf::bad_conversion, [](const auto& e) { return true; });
-    BOOST_CHECK_EXCEPTION(ecf::convert_to<long>('c'), ecf::bad_conversion, [](const auto& e) { return true; });
-
-    BOOST_CHECK_EQUAL(ecf::convert_to<double>("0.0"), 0);
-    BOOST_CHECK_EQUAL(ecf::convert_to<double>("0.00"), 0);
-    BOOST_CHECK_EQUAL(ecf::convert_to<double>("1.0"), 1);
-    BOOST_CHECK_EQUAL(ecf::convert_to<double>("-3.5"), -3.5);
-}
-
-BOOST_AUTO_TEST_CASE(can_convert_from_boost_object_to_string) {
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(boost::gregorian::greg_day{23}), "23");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(boost::gregorian::greg_month{2}), "Feb");
-    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(boost::gregorian::greg_year{2000}), "2000");
-}
-
-BOOST_AUTO_TEST_CASE(can_use_custom_conversion_traits) {
-    // By compiling, the following expression confirms that a Widget can be converted to a Gizmo.
-    ecf::convert_to<Gizmo>(Widget{});
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestCore_main.cpp 5.13.0-1/ACore/test/TestCore_main.cpp
--- 5.12.4-1/ACore/test/TestCore_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestCore_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Core
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/ACore/test/TestExtract.cpp 5.13.0-1/ACore/test/TestExtract.cpp
--- 5.12.4-1/ACore/test/TestExtract.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestExtract.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,106 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Extract.hpp"
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Extract)
-
-BOOST_AUTO_TEST_CASE(can_extract_path_and_name) {
-    using namespace std::string_literals;
-    {
-        auto token = "/suite/family:obj"s;
-        std::string path;
-        std::string name;
-        BOOST_CHECK(Extract::pathAndName(token, path, name));
-        BOOST_CHECK_EQUAL(path, "/suite/family"s);
-        BOOST_CHECK_EQUAL(name, "obj"s);
-    }
-    {
-        auto token = "/suite/family"s;
-        std::string path;
-        std::string name;
-        BOOST_CHECK(Extract::pathAndName(token, path, name));
-        BOOST_CHECK_EQUAL(path, "/suite/family"s);
-        BOOST_CHECK_EQUAL(name, ""s);
-    }
-    {
-        auto token = "obj"s;
-        std::string path;
-        std::string name;
-        BOOST_CHECK(Extract::pathAndName(token, path, name));
-        BOOST_CHECK_EQUAL(path, ""s);
-        BOOST_CHECK_EQUAL(name, "obj"s);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(can_extract_second_token) {
-    using namespace std::string_literals;
-    {
-        auto token = "First:Second"s;
-        std::string second;
-        BOOST_CHECK(Extract::split_get_second(token, second));
-        BOOST_CHECK_EQUAL(second, "Second"s);
-    }
-    {
-        auto token = "/suite/family:obj"s;
-        std::string second;
-        BOOST_CHECK(Extract::split_get_second(token, second));
-        BOOST_CHECK_EQUAL(second, "obj"s);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(can_extract_integer) {
-    using namespace std::string_literals;
-    { BOOST_CHECK_THROW(Extract::theInt("", "error message"s), std::runtime_error); }
-    { BOOST_CHECK_THROW(Extract::theInt("a", "error message"s), std::runtime_error); }
-    { BOOST_CHECK_THROW(Extract::theInt("abc", "error message"s), std::runtime_error); }
-    { BOOST_CHECK_THROW(Extract::theInt("#", "error message"s), std::runtime_error); }
-    { BOOST_CHECK_THROW(Extract::theInt(":", "error message"s), std::runtime_error); }
-    { BOOST_CHECK_EQUAL(Extract::theInt("42", "error message"s), 42); }
-    { BOOST_CHECK_EQUAL(Extract::theInt("-42", "error message"s), -42); }
-    { BOOST_CHECK_THROW(Extract::theInt("42 ", "error message"s), std::runtime_error); }
-    { BOOST_CHECK_THROW(Extract::theInt("42 42", "error message"s), std::runtime_error); }
-    { BOOST_CHECK_THROW(Extract::theInt("42.42", "error message"s), std::runtime_error); }
-}
-
-BOOST_AUTO_TEST_CASE(can_extract_optional_integer) {
-    using namespace std::string_literals;
-    {
-        auto tokens = std::vector{"repeat"s, "integer"s, "variable"s, "1"s, "2"s, "#a"s, "comment"s};
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 0, 42, "error message"s), std::runtime_error); }
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 1, 42, "error message"s), std::runtime_error); }
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 2, 42, "error message"s), std::runtime_error); }
-        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 3, 42, "error message"), 1); }
-        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 4, 42, "error message"), 2); }
-        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 5, 42, "error message"), 42); }
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 6, 42, "error message"s), std::runtime_error); }
-    }
-    {
-        auto tokens = std::vector{"repeat"s, "integer"s, "variable"s, "1"s, "2"s, "#"s, "a"s, "comment"s};
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 0, 42, "error message"s), std::runtime_error); }
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 1, 42, "error message"s), std::runtime_error); }
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 2, 42, "error message"s), std::runtime_error); }
-        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 3, 42, "error message"s), 1); }
-        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 4, 42, "error message"s), 2); }
-        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 5, 42, "error message"s), 42); }
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 6, 42, "error message"s), std::runtime_error); }
-        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 7, 42, "error message"s), std::runtime_error); }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestFile.cpp 5.13.0-1/ACore/test/TestFile.cpp
--- 5.12.4-1/ACore/test/TestFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,556 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib> // for getenv()
-#include <fstream> // for std::ofstream
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Converter.hpp"
-
-// #define FILE_PERF_CHECK_IMPLEMENTATIONS 1;
-#ifdef FILE_PERF_CHECK_IMPLEMENTATIONS
-    #include <boost/timer/timer.hpp>
-
-    #include "ecflow/core/Str.hpp"
-#endif
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/NodePath.hpp"
-#include "ecflow/core/User.hpp"
-
-using namespace boost;
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_File)
-
-BOOST_AUTO_TEST_CASE(test_splitFileIntoLines) {
-    // This is sanity test for splitFileIntoLines used extensively
-    cout << "ACore:: ...test_splitFileIntoLines\n";
-
-    std::string path = File::test_data("ACore/test/data/test_splitFileIntoLines.txt", "ACore");
-
-    std::string theText = "This is a test string";
-    {
-        {
-            std::ofstream file_with_one_line(path.c_str());
-            file_with_one_line << theText;
-        }
-
-        std::vector<std::string> lines;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
-                            " Failed to open file " << path << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(lines.size() == 1, " Expected 1 line but found " << lines.size());
-
-        fs::remove(path); // Remove the file. Comment out for debugging
-    }
-
-    {
-        {
-            std::ofstream file_with_one_line(path.c_str());
-            file_with_one_line << theText << "\n"; // addition of '/n' , should still be one line
-        }
-
-        std::vector<std::string> lines;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
-                            " Failed to open file " << path << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(lines.size() == 1, " Expected 1 line but found " << lines.size());
-
-        fs::remove(path); // Remove the file. Comment out for debugging
-    }
-
-    {
-        {
-            std::ofstream file_with_two_line(path.c_str());
-            file_with_two_line << theText << "\n";
-            file_with_two_line << theText;
-        }
-
-        std::vector<std::string> lines;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
-                            " Failed to open file " << path << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(lines.size() == 2, " Expected 2 line but found " << lines.size());
-
-        fs::remove(path); // Remove the file. Comment out for debugging
-    }
-
-    {
-        {
-            std::ofstream file_with_three_line(path.c_str());
-            file_with_three_line << theText << "\n";
-            file_with_three_line << theText << "\n";
-            file_with_three_line << theText;
-        }
-
-        std::vector<std::string> lines;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
-                            " Failed to open file " << path << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(lines.size() == 3, " Expected 3 line but found " << lines.size());
-
-        fs::remove(path); // Remove the file. Comment out for debugging
-    }
-
-    {
-        {
-            std::ofstream file_with_three_line(path.c_str());
-            file_with_three_line << theText << "\n";
-            file_with_three_line << theText << "\n";
-            file_with_three_line << theText << "\n";
-        }
-
-        std::vector<std::string> lines;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
-                            " Failed to open file " << path << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(lines.size() == 3, " Expected 3 line but found " << lines.size());
-
-        fs::remove(path); // Remove the file. Comment out for debugging
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_file_tokenizer) {
-    cout << "ACore:: ...test_file_tokenizer\n";
-
-    std::string path = File::test_data("ACore/test/data/test_file_tokenizer.txt", "ACore");
-
-    size_t linesWithText = 100;
-    std::string theText  = "This is a test string";
-    {
-        std::ofstream file(path.c_str());
-        for (size_t i = 0; i < linesWithText; i++) {
-            if (i % 2 == 0)
-                file << "\n";        // 51 empty lines
-            file << theText << "\n"; // 100  text lines
-        }
-    }
-    {
-        std::vector<std::string> lines;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines, true /*ignore empty lines*/),
-                            " Failed to open file " << path << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(lines.size() == linesWithText,
-                            "Expected " << linesWithText << " but found " << lines.size());
-        BOOST_CHECK_MESSAGE(lines[0] == theText, "Expected '" << theText << "' but found " << lines[0]);
-        BOOST_CHECK_MESSAGE(lines[linesWithText - 1] == theText,
-                            "Expected '" << theText << "' but found " << lines[linesWithText - 1]);
-
-        lines.clear();
-        size_t totalLines = 151;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
-                            " Failed to open file " << path << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(lines.size() == totalLines - 1,
-                            "Expected " << totalLines - 1 << " but found " << lines.size());
-        BOOST_CHECK_MESSAGE(lines[0] == "", "Expected empty string  but found " << lines[0]);
-        BOOST_CHECK_MESSAGE(lines[1] == theText, "Expected '" << theText << "' but found " << lines[1]);
-        BOOST_CHECK_MESSAGE(lines[2] == theText, "Expected '" << theText << "' but found " << lines[2]);
-        BOOST_CHECK_MESSAGE(lines[3] == "", "Expected empty string  but found " << lines[3]);
-    }
-
-#ifdef FILE_PERF_CHECK_IMPLEMENTATIONS
-    {
-        size_t openFileNTimes = 100000;
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < openFileNTimes; i++) {
-            std::vector<std::string> lines;
-            BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
-                                " Failed to open file " << path << " (" << strerror(errno) << ")");
-        }
-        cout << "Time for opening file " << openFileNTimes << " times = " << timer.format(3, Str::cpu_timer_format())
-             << "\n";
-    }
-#endif
-
-    // Remove the file. Comment out for debugging
-    fs::remove(path);
-}
-
-BOOST_AUTO_TEST_CASE(test_file_backwardSearch) {
-    cout << "ACore:: ...test_file_backwardSearch\n";
-
-    std::string nodePath = "dir0/dir1/dir2/dir3/dir4/dir5";
-    std::string rootPath = File::test_data("ACore/test/data", "ACore");
-    std::string expected = File::test_data("ACore/test/data/", "ACore") + nodePath;
-
-    std::string path = rootPath;
-    std::string dir  = "dir";
-    for (int i = 0; i < 6; i++) {
-        path += "/" + dir + ecf::convert_to<std::string>(i);
-    }
-    // Should have test/data/dir0/dir1/dir3/dir3/dir4/dir5
-    //         or  ACore/test/data/dir0/dir1/dir3/dir3/dir4/dir5
-    BOOST_REQUIRE_MESSAGE(path == expected, " Error expected " << expected << " but found " << path);
-
-    // Create the missing directories
-    BOOST_REQUIRE_MESSAGE(File::createDirectories(path), "Failed to create dirs");
-
-    // Create a file in each of the directories. See Page 21 SMS User Guide.
-    std::vector<std::string> fileContents;
-    fileContents.emplace_back("something");
-    vector<std::string> nodePathTokens;
-    NodePath::split(nodePath, nodePathTokens);
-    while (nodePathTokens.size() > 0) {
-
-        // Reconstitute the path
-        std::string path         = NodePath::createPath(nodePathTokens);
-        std::string combinedPath = rootPath + path;
-
-        BOOST_REQUIRE_MESSAGE(File::createDirectories(combinedPath), "Failed to create dirs " << combinedPath);
-
-        combinedPath += File::ECF_EXTN(); // .ecf, .man , etc
-
-        // std::cout << "Creating file " << combinedPath << "\n";
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(File::create(combinedPath, fileContents, errorMsg),
-                              "Failed to create " << combinedPath << " because " << errorMsg);
-
-        nodePathTokens.erase(nodePathTokens.begin()); // consume first path token
-    }
-
-    // Now do a backward search for them
-    int filesFound = 0;
-    for (int i = 0; i < 6; i++) {
-        std::string theFile = File::backwardSearch(rootPath, nodePath, File::ECF_EXTN());
-        BOOST_CHECK_MESSAGE(!theFile.empty(),
-                            i << ": Failed to find dir5.ecf with rootPath " << rootPath << " and node path "
-                              << nodePath);
-        if (!theFile.empty()) {
-            filesFound++;
-            //			std::cout << "About to remove file " << theFile << "\n";
-            fs::remove(theFile); // remove it so we don't find it again.
-        }
-    }
-    // Expect the following files to be found:
-    //	test/data/dir0/dir1/dir2/dir3/dir4/dir5.ecf
-    //	test/data/dir1/dir2/dir3/dir4/dir5.ecf
-    //	test/data/dir2/dir3/dir4/dir5.ecf
-    //	test/data/dir3/dir4/dir5.ecf
-    //	test/data/dir4/dir5.ecf
-    //	test/data/dir5.ecf
-    BOOST_CHECK_MESSAGE(filesFound == 6, " expect to find 6 files but found " << filesFound);
-
-    // Remove the test dir. Comment out for debugging
-    for (int i = 0; i < 6; i++) {
-        path = rootPath + "/" + dir + ecf::convert_to<std::string>(i);
-        BOOST_CHECK_MESSAGE(File::removeDir(path), "Failed to remove dir " << path);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_file_forwardSearch) {
-    cout << "ACore:: ...test_file_forwardSearch user:" << ecf::User::login_name() << "\n";
-
-    std::string dir_path = "/dir0/dir1/dir2/dir3/dir4";
-    std::string nodePath = dir_path + "/task";
-    std::string rootPath = File::test_data("ACore/test/data", "ACore");
-    std::string expected = File::test_data("ACore/test/data", "ACore") + nodePath;
-
-    std::string path = rootPath;
-    std::string dir  = "dir";
-    for (int i = 0; i < 6; i++) {
-        if (i == 5)
-            path += "/task";
-        else
-            path += "/" + dir + ecf::convert_to<std::string>(i);
-    }
-    // Should have test/data/dir0/dir1/dir3/dir3/dir4/task
-    //         or  ACore/test/data/dir0/dir1/dir3/dir3/dir4/task
-    BOOST_REQUIRE_MESSAGE(path == expected, " Error expected " << expected << " but found " << path);
-
-    string combined_dir_path = rootPath + dir_path;
-    // cout << " creating directories  : " << combined_dir_path  << "\n";
-    BOOST_REQUIRE_MESSAGE(File::createDirectories(combined_dir_path), "Failed to create dirs" << combined_dir_path);
-
-    // cout << " Create a file(task.ecf) in each of the directories  nodePath: " << nodePath << "\n";
-    std::vector<std::string> fileContents;
-    fileContents.emplace_back("something");
-    vector<std::string> nodePathTokens;
-    NodePath::split(nodePath, nodePathTokens);
-    while (nodePathTokens.size() > 0) {
-
-        std::string path = NodePath::createPath(nodePathTokens);
-        // cout << "   Reconstituted path  : " << path << " from nodePathTokens.size() " << nodePathTokens.size() <<
-        // "\n";
-
-        std::string combinedPath = rootPath + path + File::ECF_EXTN(); // .ecf, .man , etc
-        // cout << "   Creating file       : " << combinedPath << "\n";
-
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(File::create(combinedPath, fileContents, errorMsg),
-                              "Failed to create " << combinedPath << " because " << errorMsg);
-
-        // Preserve the last token, i.e task
-        if (nodePathTokens.size() >= 2)
-            nodePathTokens.erase(nodePathTokens.begin() + nodePathTokens.size() -
-                                 2); // consume one from last path token
-        else
-            nodePathTokens.erase(nodePathTokens.begin());
-    }
-    BOOST_REQUIRE_MESSAGE(nodePathTokens.empty(), "Expected nodePathTokens vec to be empty");
-
-    // Now do a forward search for them:
-    // Expect the following files to be found:
-    // test/data/dir0/dir1/dir2/dir3/dir4/task.ecf
-    // test/data/dir0/dir1/dir2/dir3/task.ecf
-    // test/data/dir0/dir1/dir2/task.ecf
-    // test/data/dir0/dir1/task.ecf
-    // test/data/dir0/task.ecf
-    // test/data/task.ecf
-    // cout << "rootPath: " << rootPath << "\n";
-    // cout << "ECF_EXTN: " << File::ECF_EXTN()  << "\n";
-    int filesFound = 0;
-    for (int i = 0; i < 6; i++) {
-        BOOST_REQUIRE_MESSAGE(i >= 0, "Dummy to debug on macos");
-        std::string theFile = File::forwardSearch(rootPath, nodePath, File::ECF_EXTN());
-        BOOST_CHECK_MESSAGE(!theFile.empty(),
-                            i << ": Failed to find task.ecf with rootPath " << rootPath << " and node path "
-                              << nodePath);
-        if (!theFile.empty()) {
-            filesFound++;
-            // std::cout << "Found file at: " << theFile << "\n";
-            fs::remove(theFile); // *remove* so we don't find it again
-        }
-    }
-    BOOST_CHECK_MESSAGE(filesFound == 6, " expect to find 6 files but found " << filesFound);
-
-    // Remove the test dir0. Comment out for debugging
-    BOOST_CHECK_MESSAGE(File::removeDir(rootPath + "/dir0"), "Failed to remove dir " << rootPath + "/dir0");
-}
-
-BOOST_AUTO_TEST_CASE(test_create_missing_directories) {
-    cout << "ACore:: ...test_create_missing_directories";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    std::string nodePath = "dir0/dir1/dir2/dir3/dir4/dir5";
-    std::string rootPath = File::test_data("ACore/test/data", "ACore");
-    std::string expected = File::test_data("ACore/test/data/", "ACore") + nodePath;
-
-    std::string dir_remove = rootPath + "/dir0";
-    {
-        // Test basics first, expect "ACore/test/data/dir0/dir1/dir2/dir3/dir4/dir5" to be created
-        BOOST_CHECK_MESSAGE(File::createMissingDirectories(expected),
-                            expected << " expected directories to be created");
-        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
-
-        // remove the directory
-        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
-
-        //      fs::path fs_path(expected);
-        //      std::cout << "parent path " << fs_path.parent_path() << "\n";
-        //      std::cout << "root path " << fs_path.root_path()  << "\n";
-        //      std::cout << "root name " << fs_path.root_name()  << "\n";
-        //      std::cout << "root directory " << fs_path.root_directory()  << "\n";
-        //      std::cout << "relative_path " << fs_path.relative_path()  << "\n";
-        //      std::cout << "filename " << fs_path.filename()  << "\n";
-        //      std::cout << "stem " << fs_path.stem()  << "\n";
-        //      std::cout << "extension " << fs_path.extension()  << "\n";
-    }
-    {
-        // Test "ACore/test/data/dir0/dir1/dir2/dir3/dir4/dir5/fred.ecf" to be created
-        std::string dir_with_file = expected + "/fred.ecf";
-        BOOST_CHECK_MESSAGE(File::createMissingDirectories(dir_with_file),
-                            "Expected '" << dir_with_file << "' to be created");
-        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
-
-        // remove the directory
-        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
-
-        //      fs::path fs_path(dir_with_file);
-        //      std::cout << "parent path " << fs_path.parent_path() << "\n";
-        //      std::cout << "root path " << fs_path.root_path()  << "\n";
-        //      std::cout << "root name " << fs_path.root_name()  << "\n";
-        //      std::cout << "root directory " << fs_path.root_directory()  << "\n";
-        //      std::cout << "relative_path " << fs_path.relative_path()  << "\n";
-        //      std::cout << "filename " << fs_path.filename()  << "\n";
-        //      std::cout << "stem " << fs_path.stem()  << "\n";
-        //      std::cout << "extension " << fs_path.extension()  << "\n";
-    }
-
-    {
-        // Create directories twice. Need to minimise call to fstat
-        BOOST_CHECK_MESSAGE(File::createMissingDirectories(expected), "expected file to be created");
-        BOOST_CHECK_MESSAGE(File::createMissingDirectories(expected), "expected file to be created");
-        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
-
-        // remove the directory
-        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
-    }
-
-    {
-        // Create directories twice. Need to minimise call to fstat
-        std::string dir_with_file = expected + "/fred.ecf";
-        BOOST_CHECK_MESSAGE(File::createMissingDirectories(dir_with_file), "expected file to be created");
-        BOOST_CHECK_MESSAGE(File::createMissingDirectories(dir_with_file), "expected file to be created");
-        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
-
-        // remove the directory
-        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_get_last_lines_of_a_file) {
-    cout << "ACore:: ...test_get_last_lines_of_a_file\n";
-
-    std::string path = File::test_data("ACore/test/data/test_get_last_lines_of_a_file.txt", "ACore");
-    std::string last_100_lines;
-    size_t no_of_lines = 100;
-    { // create file with 100 lines 0-99
-        std::stringstream ss;
-        std::ofstream file(path.c_str());
-        for (size_t i = 0; i < no_of_lines; i++) {
-            file << i << ": the line\n";
-            ss << i << ": the line\n";
-        }
-        last_100_lines = ss.str();
-    }
-    { // get negative lines
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, -1, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
-    }
-    { // get no lines
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, 0, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
-    }
-    { // get the last line only
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, 1, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "99: the line\n", "Expected '99: the line\n' but found " << last_lines);
-    }
-    { // get the last 2 line only
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, 2, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "98: the line\n99: the line\n",
-                              "Expected last 2 lines but got " << last_lines);
-    }
-    { // get the last 100 line only
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, no_of_lines, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == last_100_lines,
-                              "Expected last " << no_of_lines << " lines but got " << last_lines);
-    }
-    { // get the last 1000 line only
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, 1000, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == last_100_lines,
-                              "Expected last " << no_of_lines << " lines but got " << last_lines);
-    }
-
-    fs::remove(path); // Remove the file. Comment out for debugging
-
-    // ===================================================================================
-    // Now check empty file
-    // ===================================================================================
-    {
-        std::ofstream file(path.c_str()); // create empty file
-        BOOST_REQUIRE_MESSAGE(file.good(), "failed");
-    }
-
-    { // get no lines ?
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, 0, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
-    }
-    { // get the last line only
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, 1, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
-    }
-    { // get the last 2 line only
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, 2, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
-    }
-    { // get the last 100 line only
-        std::string error_msg;
-        std::string last_lines = File::get_last_n_lines(path, no_of_lines, error_msg);
-        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
-        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
-    }
-
-    fs::remove(path); // Remove the file. Comment out for debugging
-}
-
-BOOST_AUTO_TEST_CASE(test_directory_traversal) {
-    cout << "ACore:: ...test_directory_traversal\n";
-
-    int regular_file = 0;
-    //    int directory    = 0;
-    //    int symlink      = 0;
-    //    int other        = 0;
-
-    for (auto& entry : fs::directory_iterator(fs::current_path())) {
-        if (is_regular_file(entry))
-            regular_file++;
-        //        if (is_directory(entry))
-        //            directory++;
-        //        if (is_symlink(entry))
-        //            symlink++;
-        //        if (is_other(entry))
-        //            other++;
-        //      cout << "name.path()            " << entry.path() << "\n";
-        //      cout << "name.path().string()   " << entry.path().string() << "\n";
-        //      cout << "name.path().filename() " << entry.path().filename() << "\n";
-        if (is_regular_file(entry)) {
-            boost::uintmax_t entry_size = fs::file_size(entry);
-            boost::uintmax_t path_size  = fs::file_size(entry.path());
-            BOOST_REQUIRE_MESSAGE(entry_size == path_size,
-                                  "Directory entry file size " << entry_size << " not the same as entry.path() "
-                                                               << path_size);
-            BOOST_REQUIRE_MESSAGE(fs::last_write_time(entry) == fs::last_write_time(entry.path()),
-                                  "Directory entry last write time, not the same as entry.path()");
-            //         cout << "file_size " << fs::file_size(entry) << "\n";
-        }
-    }
-    //   cout << "regular_file " << regular_file << "\n";
-    //   cout << "directory  " <<  directory << "\n";
-    //   cout << "symlink  " << symlink  << "\n";
-    //   cout << "other  " << other  << "\n";
-    BOOST_REQUIRE_MESSAGE(regular_file > 0, "Expected some files in directory");
-}
-
-BOOST_AUTO_TEST_CASE(test_get_all_files_by_extension) {
-    cout << "ACore:: ...test_get_all_files_by_extension\n";
-    {
-        std::string rootPath = File::test_data("ACore/test/data/badPasswdFiles", "ACore");
-        std::vector<fs::path> vec;
-        File::find_files_with_extn(rootPath, ".passwd", vec);
-        // for(auto& file: vec)  std::cout << file << "\n";
-        BOOST_REQUIRE_MESSAGE(vec.size() == 6, "Expected 6 files in directory " << rootPath);
-    }
-    {
-        std::string rootPath = File::test_data("ACore/test/data/badWhiteListFiles", "ACore");
-        std::vector<fs::path> vec;
-        File::find_files_with_extn(rootPath, ".lists", vec);
-        // for(auto& file: vec)  std::cout << file << "\n";
-        BOOST_REQUIRE_MESSAGE(vec.size() == 7, "Expected 7 files in directory " << rootPath);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestGetUserDetails.cpp 5.13.0-1/ACore/test/TestGetUserDetails.cpp
--- 5.12.4-1/ACore/test/TestGetUserDetails.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestGetUserDetails.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,43 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdio>
-#include <iostream>
-#include <pwd.h> /* getpwdid */
-#include <string>
-#include <unistd.h>
-
-#include <boost/test/unit_test.hpp>
-#include <sys/types.h>
-
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_GetUserDetails)
-
-BOOST_AUTO_TEST_CASE(test_get_user_details, *boost::unit_test::disabled()) {
-    cout << "ACore:: ...test_get_user_details\n";
-
-    /* Get the uid of the running processand use it to get a record from /etc/passwd */
-    struct passwd* passwd = getpwuid(getuid());
-
-    printf("\n The Real User Name is %s ", passwd->pw_gecos);
-    printf("\n The Login Name is %s ", passwd->pw_name);
-    printf("\n The Home Directory is %s", passwd->pw_dir);
-    printf("\n The Login Shell is %s ", passwd->pw_shell);
-    printf("\n The Passwd is %s ", getpwuid(getuid())->pw_passwd);
-    printf("\n The uid is %lu ", (unsigned long)getpwuid(getuid())->pw_uid);
-    printf("\n The gid is %lu \n\n", (unsigned long)getpwuid(getuid())->pw_gid);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestLog.cpp 5.13.0-1/ACore/test/TestLog.cpp
--- 5.12.4-1/ACore/test/TestLog.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestLog.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,383 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Pid.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Log)
-
-static std::string getLogPath() {
-
-    // ECFLOW-712, generate unique name for log file, To allow parallel test
-    std::string log_file = "ACore/test/logfile";
-    log_file += Pid::getpid(); // can throw
-    log_file += ".txt";
-    return File::test_data(log_file, "ACore");
-}
-
-BOOST_AUTO_TEST_CASE(test_log) {
-    std::string path = getLogPath();
-    cout << "ACore:: ...test_log " << path << "\n";
-
-    // delete the log file if it exists.
-    fs::remove(path);
-    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path);
-
-    LogFlusher logFlusher;
-    Log::create(path);
-    LOG(Log::MSG, "First Message");
-    LOG(Log::LOG, "LOG");
-    LOG(Log::ERR, "ERROR");
-    LOG(Log::WAR, "WARNING");
-    LOG(Log::DBG, "DEBUG");
-    LOG(Log::OTH, "OTHER");
-    log(Log::OTH, "test: void log(Log::LogType,const std::string& message)");
-
-    LOG(Log::OTH, "test: LOG(level,path << path) " << path << " " << path);
-
-    Log::instance()->log(Log::OTH, "OTHER2");
-
-    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
-}
-
-BOOST_AUTO_TEST_CASE(test_log_append) {
-    cout << "ACore:: ...test_log_append\n";
-
-    std::string path = getLogPath();
-
-    BOOST_REQUIRE_MESSAGE(fs::exists(path), "log file " << path << " not created by previous test\n");
-
-    {
-        LogFlusher logFlusher;
-        LOG(Log::MSG, "Last Message");
-    }
-
-    // Load the log file into a vector, of strings, and test content
-    std::vector<std::string> lines;
-    BOOST_REQUIRE_MESSAGE(File::splitFileIntoLines(path, lines, true /*IGNORE EMPTY LINE AT THE END*/),
-                          "Failed to open log file"
-                              << " (" << strerror(errno) << ")");
-    BOOST_REQUIRE(lines.size() != 0);
-    BOOST_CHECK_MESSAGE(lines.size() == 10, " Expected 10 lines in log, but found " << lines.size() << "\n");
-    BOOST_CHECK_MESSAGE(lines[0].find("First Message") != string::npos,
-                        "Expected first line to contain 'First Message' but found " << lines[0] << "\n");
-    BOOST_CHECK_MESSAGE(lines.back().find("Last Message") != string::npos,
-                        "Expected last line to contain 'Last Message' but found " << lines.back() << "\n");
-
-    // Clear the log file. Comment out for debugging
-    Log::instance()->clear();
-    BOOST_CHECK_MESSAGE(fs::file_size(path) == 0, "Clear of log file failed\n");
-
-    // Remove the log file. Comment out for debugging
-    fs::remove(path);
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_log_path) {
-    cout << "ACore:: ...test_log_path\n";
-
-    Log::create("test_log_path.log");
-
-    // make sure path returned is absolute
-    std::string path = Log::instance()->path();
-    BOOST_REQUIRE_MESSAGE(path[0] == '/', "Expected absolute paths for log file but found " << path);
-
-    // Remove the log file. Comment out for debugging
-    fs::remove(path);
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_log_new_path_errors) {
-    cout << "ACore:: ...test_log_new_path_errors\n";
-
-    // delete the log file if it exists.
-    std::string path = getLogPath();
-    fs::remove(path);
-
-    // create a now log file.
-    Log::create(path);
-    LOG(Log::MSG, "First Message");
-    LOG(Log::LOG, "LOG");
-
-    // Specify bad paths for new log file
-    // First test empty path throws
-    BOOST_REQUIRE_THROW(Log::instance()->new_path(""), std::runtime_error);
-
-    // If a path is specified make sure parent directory exists
-    fs::path current_path = fs::current_path();
-    std::string path2     = current_path.string();
-    path2 += "/a/made/up/path/fred.log";
-    // cout << path2<< "\n";
-    BOOST_REQUIRE_THROW(Log::instance()->new_path(path2), std::runtime_error);
-
-    // Make sure path does not correspond to a directory
-    // cout << "parent directory: " << current_path.parent_path() << "\n";
-    BOOST_REQUIRE_THROW(Log::instance()->new_path(current_path.parent_path().string()), std::runtime_error);
-
-    //   {
-    //      fs::path valid_path = getLogPath();
-    //      std::cout << "valid_path = " << valid_path << "\n";
-    //      std::cout << "valid_path.root_path(): " << valid_path.root_path() << "\n";
-    //      std::cout << "valid_path.root_name() : " << valid_path.root_name()  << "\n";
-    //      std::cout << "valid_path.root_directory()  : " << valid_path.root_directory()   << "\n";
-    //      std::cout << "valid_path.relative_path()  : " << valid_path.relative_path()   << "\n";
-    //      std::cout << "valid_path.parent_path()  : " << valid_path.parent_path()   << "\n";
-    //      std::cout << "valid_path.filename()  : " << valid_path.filename()   << "\n";
-    //      std::cout << "valid_path.stem()  : " << valid_path.stem()   << "\n";
-    //      std::cout << "valid_path.extension()  : " << valid_path.extension()   << "\n";
-    //   }
-
-    // Remove the log file. Comment out for debugging
-    fs::remove(Log::instance()->path());
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_log_new_path) {
-    cout << "ACore:: ...test_log_new_path\n";
-
-    // delete the log file if it exists.
-    std::string path = getLogPath();
-    fs::remove(path);
-
-    // create a new log file.
-    Log::create(path);
-    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()),
-                        "Log file should be created after explicit call to Log::create()\n");
-    LOG(Log::LOG, "LOG");
-    fs::remove(Log::instance()->path());
-
-    // Specify a new log path. Path could be a relative path like "test/logfile.log"
-    std::string relative_path = File::test_data("ACore/test/logfile.log", "ACore");
-
-    BOOST_REQUIRE_NO_THROW(Log::instance()->new_path(relative_path));
-    BOOST_CHECK_MESSAGE(!fs::exists(Log::instance()->path()),
-                        "Log file should *NOT* be created until first message is logged\n");
-    LOG(Log::LOG, "LOG");
-    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()),
-                        "Log file should be created after first message is logged\n");
-    fs::remove(Log::instance()->path());
-
-    // Specify a new log path. This time we just specify a file name, without a path.
-    BOOST_REQUIRE_NO_THROW(Log::instance()->new_path("testlog.log"));
-    BOOST_CHECK_MESSAGE(!fs::exists(Log::instance()->path()),
-                        "Log file should not be created until first message is logged\n");
-    // File not created until a message is logged
-    LOG(Log::LOG, "LOG");
-    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()),
-                        "Log file should be created after first message is logged\n");
-
-    fs::remove(Log::instance()->path());
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_get_last_n_lines_from_log) {
-    cout << "ACore:: ...test_get_last_n_lines_from_log\n";
-
-    // delete the log file if it exists.
-    std::string path = getLogPath();
-    fs::remove(path);
-    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path);
-
-    // Create the log file;
-    Log::create(path);
-    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
-
-    // Log file should be empty
-    const int NO_OF_LINES_IN_LOG_FILE = 200;
-    {
-        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
-            std::string line = Log::instance()->contents(i);
-            BOOST_CHECK_MESSAGE(line.empty(), "Expected empty string but found\n" << line);
-        }
-    }
-
-    // Populate the log file
-    std::string msg = "This is message ";
-    for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; ++i)
-        LOG(Log::MSG, msg << i);
-
-    // Now check, getting the lines
-    {
-        std::string line = Log::instance()->contents(0);
-        BOOST_CHECK_MESSAGE(line.empty(), "Expected empty string but found\n" << line);
-    }
-    {
-        // Check we get back the number of line requested
-        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
-            std::string lines = Log::instance()->contents(i);
-            int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
-            BOOST_CHECK_MESSAGE(i == newlineCount, "expected to  " << i << " newlines but found " << newlineCount);
-        }
-    }
-    {
-        // Check we get back *ALL* lines requested
-        std::string lines = Log::instance()->contents(NO_OF_LINES_IN_LOG_FILE);
-        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
-            std::stringstream ss;
-            ss << msg << i;
-            std::string str_to_find = ss.str();
-            BOOST_CHECK_MESSAGE(lines.find(str_to_find) != std::string::npos,
-                                "expected to find " << str_to_find << " in the log file");
-        }
-    }
-
-    {
-        // Request more than is available, should only get back whats there
-        std::string lines = Log::instance()->contents(NO_OF_LINES_IN_LOG_FILE * 2);
-        int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
-        BOOST_CHECK_MESSAGE(NO_OF_LINES_IN_LOG_FILE == newlineCount,
-                            "expected " << NO_OF_LINES_IN_LOG_FILE << " newlines but found " << newlineCount);
-    }
-
-    fs::remove(Log::instance()->path());
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_get_first_n_lines_from_log) {
-    cout << "ACore:: ...test_get_first_n_lines_from_log\n";
-
-    // delete the log file if it exists.
-    std::string path = getLogPath();
-    fs::remove(path);
-    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path << " not created \n");
-
-    // Create the log file;
-    Log::create(path);
-    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
-
-    // Populate the log file
-    const int NO_OF_LINES_IN_LOG_FILE = 200;
-    std::string msg                   = "This is message ";
-    for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; ++i)
-        LOG(Log::MSG, msg << i);
-
-    // Now check, getting the lines
-    {
-        // Get the first line
-        std::string line     = Log::instance()->contents(-1);
-        std::string expected = msg + "0";
-        BOOST_CHECK_MESSAGE(line.find(expected) != std::string::npos,
-                            "Expected '" << expected << "' but found\n"
-                                         << line);
-    }
-    {
-        // Get the first & second line
-        std::string line      = Log::instance()->contents(-2);
-        std::string expected0 = msg + "0";
-        std::string expected1 = msg + "1";
-        BOOST_CHECK_MESSAGE(line.find(expected0) != std::string::npos,
-                            "Expected '" << expected0 << "' but found\n"
-                                         << line);
-        BOOST_CHECK_MESSAGE(line.find(expected1) != std::string::npos,
-                            "Expected '" << expected1 << "' but found\n"
-                                         << line);
-    }
-    {
-        // Check we get back the number of line requested
-        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
-            std::string lines = Log::instance()->contents(-i);
-            int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
-            BOOST_CHECK_MESSAGE(i == newlineCount, "expected to  " << i << " newlines but found " << newlineCount);
-        }
-    }
-    {
-        std::string lines = Log::instance()->contents(-NO_OF_LINES_IN_LOG_FILE);
-        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
-            std::stringstream ss;
-            ss << msg << i;
-            std::string expected = ss.str();
-            BOOST_CHECK_MESSAGE(lines.find(expected) != std::string::npos,
-                                "Expected '" << expected << "' but found for i " << i);
-        }
-    }
-
-    {
-        // Request more than is available, should only get back whats there
-        std::string lines = Log::instance()->contents(-NO_OF_LINES_IN_LOG_FILE * 2);
-        int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
-        BOOST_CHECK_MESSAGE(NO_OF_LINES_IN_LOG_FILE == newlineCount,
-                            "expected " << NO_OF_LINES_IN_LOG_FILE << " newlines but found " << newlineCount);
-    }
-
-    fs::remove(Log::instance()->path());
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_get_log_timing) {
-    cout << "ACore:: ...test_get_log_timing: " << flush;
-
-    // *************************************************************************************
-    // This test was used with *DIFFERENT* implementations for Log::instance()->contents(1)
-    // What is shows, is that for optimal performance we should *NOT* load the entire log file
-    // This can be several giga bytes.
-    // **************************************************************************************
-
-    // delete the log file if it exists.
-    std::string path = getLogPath();
-    fs::remove(getLogPath());
-    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path << " not created \n");
-
-    // Create the log file;
-    Log::create(path);
-    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
-
-    // Populate the log file
-    const int NO_OF_LINES_IN_LOG_FILE = 20000;
-    std::string msg                   = "This is message ";
-    for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; ++i)
-        LOG(Log::MSG, msg << i);
-
-    DurationTimer timer;
-
-    {
-        const int LOOP = 100;
-        for (int i = 0; i < LOOP; i++) {
-            std::string lines = Log::instance()->contents(1);
-            BOOST_CHECK_MESSAGE(!lines.empty(), "expected entry");
-        }
-    }
-
-    fs::remove(Log::instance()->path());
-
-    // Explicitly destroy log. To keep valgrind happy
-    Log::destroy();
-
-    cout << timer.duration() << "s\n" << flush;
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestMigration.cpp 5.13.0-1/ACore/test/TestMigration.cpp
--- 5.12.4-1/ACore/test/TestMigration.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestSerialisation.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/DState.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Migration)
-
-// If you are updating the tests, *MAKE SURE* to check out test/data/migration/* files
-// #define UPDATE_TESTS 1
-
-BOOST_AUTO_TEST_CASE(test_migration_restore_cereal) {
-    cout << "ACore:: ...test_migration_restore_cereal\n";
-
-    std::string file_name = File::test_data("ACore/test/data/migration/", "ACore");
-
-    // Note: default calendar constructor will init with current time: Hence set for comparison
-    Calendar calendar;
-    boost::gregorian::date theDate(2011, 2, 10);
-    ptime time(theDate, hours(23) + minutes(59));
-    calendar.init(time, Calendar::REAL); // Calendar type is derived from the clock attribute & hence is not persisted
-
-    DebugEquality debug_equality; // only as affect in DEBUG build
-
-    string cereal_version = "_1_2_2_";
-
-#ifdef UPDATE_TESTS
-    doSave<TimeSlot>(file_name + "timeslot_default_constructor" + cereal_version);
-    doSave<TimeSeries>(file_name + "timeseries_default_constructor" + cereal_version);
-    doSave<Calendar>(file_name + "calendar" + cereal_version, calendar);
-    doSave(file_name + "timeslot" + cereal_version + "11", TimeSlot(1, 1));
-    doSave(file_name + "timeslot" + cereal_version + "9959", TimeSlot(99, 59));
-    doSave(file_name + "timeseries" + cereal_version + "1010", TimeSeries(TimeSlot(10, 10)));
-    doSave(file_name + "dstate" + cereal_version, DState());
-    doSave(file_name + "nstate" + cereal_version, NState());
-#else
-    do_restore<TimeSlot>(file_name + "timeslot_default_constructor" + cereal_version, TimeSlot());
-    do_restore<TimeSeries>(file_name + "timeseries_default_constructor" + cereal_version, TimeSeries());
-    do_restore<Calendar>(file_name + "calendar" + cereal_version, calendar);
-    do_restore<TimeSlot>(file_name + "timeslot" + cereal_version + "11", TimeSlot(1, 1));
-    do_restore<TimeSlot>(file_name + "timeslot" + cereal_version + "9959", TimeSlot(99, 59));
-    do_restore<TimeSeries>(file_name + "timeseries" + cereal_version + "1010", TimeSeries(TimeSlot(10, 10)));
-    do_restore<DState>(file_name + "dstate" + cereal_version, DState());
-    do_restore<NState>(file_name + "nstate" + cereal_version, NState());
-#endif
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestNodePath.cpp 5.13.0-1/ACore/test/TestNodePath.cpp
--- 5.12.4-1/ACore/test/TestNodePath.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestNodePath.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,144 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <iterator> // std::ostream_iterator
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-#include <boost/timer/timer.hpp>
-
-#include "ecflow/core/NodePath.hpp"
-
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_NodePath)
-
-static void checkPath(const std::vector<std::string>& expectedPath, const std::string& path) {
-    std::vector<std::string> thePath;
-    NodePath::split(path, thePath);
-    if (thePath != expectedPath) {
-        BOOST_CHECK_MESSAGE(false, "Failed for " << path);
-        std::cout << "Expected '";
-        std::copy(expectedPath.begin(), expectedPath.end(), std::ostream_iterator<std::string>(std::cout, " "));
-        std::cout << "'\nbut found '";
-        std::copy(thePath.begin(), thePath.end(), std::ostream_iterator<std::string>(std::cout, " "));
-        std::cout << "'\n";
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_path_extractor_constructor) {
-    cout << "ACore:: ...test_path_extractor_constructor\n";
-    BOOST_CHECK(true); // stop boost test from complaining about no checks
-
-    std::vector<std::string> theExpectedPath;
-    checkPath(theExpectedPath, "");
-
-    theExpectedPath.emplace_back("suite");
-    checkPath(theExpectedPath, "/suite");
-    checkPath(theExpectedPath, "suite");
-}
-
-BOOST_AUTO_TEST_CASE(test_path_extractor) {
-    cout << "ACore:: ...test_path_extractor\n";
-    BOOST_CHECK(true); // stop boost test from complaining about no checks
-
-    std::vector<std::string> theExpectedPath;
-    theExpectedPath.emplace_back("suite");
-    theExpectedPath.emplace_back("family");
-    theExpectedPath.emplace_back("task");
-
-    checkPath(theExpectedPath, "/suite/family/task");
-    checkPath(theExpectedPath, "/suite/family/task/");
-}
-
-BOOST_AUTO_TEST_CASE(test_unix_path_extractor) {
-    cout << "ACore:: ...test_unix_path_extractor\n";
-    BOOST_CHECK(true); // stop boost test from complaining about no checks
-
-    // On Unix multiple '/' are treated as one.
-    std::vector<std::string> theExpectedPath;
-    theExpectedPath.emplace_back("suite");
-    theExpectedPath.emplace_back("family");
-    theExpectedPath.emplace_back("task");
-
-    checkPath(theExpectedPath, "/suite///family////task");
-    checkPath(theExpectedPath, "/suite///family////task//");
-    checkPath(theExpectedPath, "//suite///family////task//");
-    checkPath(theExpectedPath, "///suite///family////task//");
-    checkPath(theExpectedPath, "///suite///family////task///");
-}
-
-BOOST_AUTO_TEST_CASE(test_extractHostPort) {
-    cout << "ACore:: ...test_extractHostPort\n";
-
-    std::string path;
-    std::string host;
-    std::string port;
-    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
-
-    path = "Apath";
-    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
-
-    path = " : ";
-    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
-
-    path = "host:";
-    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
-
-    path = ":port";
-    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
-
-    path = "host:port";
-    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
-    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
-
-    path = "//host:port";
-    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
-    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
-
-    path = "//host:port/";
-    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
-    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
-
-    path = "//host:port/suite";
-    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
-    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
-
-    path = "//host:port/suite/family/task";
-    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
-    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
-}
-
-BOOST_AUTO_TEST_CASE(test_NodePath_perf, *boost::unit_test::disabled()) {
-    cout << "ACore:: ...test_NodePath_perf \n";
-
-    // Timing using:
-    //    StringSplitter : 6.35
-    //    Str::split     : 8.64
-    // See: Str::split -> define USE_STRINGSPLITTER
-
-    // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-    boost::timer::auto_cpu_timer timer;
-    int n = 10000000;
-    std::vector<std::string> thePath;
-    thePath.reserve(20);
-    for (int i = 0; i < n; i++) {
-        thePath.clear();
-        NodePath::split("/this/is/a/test/string/that/will/be/used/to/check/perf/of/node/path/extraction", thePath);
-    }
-    cout << "Timing for " << n << " NodePath is  " << timer.elapsed().wall << endl;
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestPasswdFile.cpp 5.13.0-1/ACore/test/TestPasswdFile.cpp
--- 5.12.4-1/ACore/test/TestPasswdFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestPasswdFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,153 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/PasswdFile.hpp"
-#include "ecflow/core/PasswordEncryption.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// #define DEBUG_ME 1
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_PasswdFile)
-
-void test_passwd_files(const std::string& directory, bool pass) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-#if DEBUG_ME
-    std::cout << "...In directory: " << full_path.relative_path() << "\n";
-#endif
-
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (fs::is_directory(dir_itr->status())) {
-                test_passwd_files(relPath.string(), pass);
-                continue;
-            }
-#if DEBUG_ME
-            std::cout << "......Parsing file " << relPath.string() << "\n";
-#endif
-            PasswdFile theFile;
-            std::string errorMsg;
-            bool parsedOk = theFile.load(relPath.string(), false /*debug*/, errorMsg);
-            if (pass) {
-                // Test expected to pass
-                BOOST_CHECK_MESSAGE(parsedOk,
-                                    "Failed to parse file " << relPath << "\n"
-                                                            << errorMsg << "\n"
-                                                            << theFile.dump());
-            }
-            else {
-                // test expected to fail
-                BOOST_CHECK_MESSAGE(!parsedOk,
-                                    "Parse expected to fail for " << relPath << "\n"
-                                                                  << errorMsg << "\n"
-                                                                  << theFile.dump());
-#if DEBUG_ME
-                cout << "\n" << errorMsg << "\n";
-#endif
-            }
-        }
-        catch (const std::exception& ex) {
-            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_for_good_passwd_files) {
-    cout << "ACore:: ...test_parsing_for_good_passwd_files\n";
-
-    std::string path = File::test_data("ACore/test/data/goodPasswdFiles", "ACore");
-
-    // All the files in this directory are expected to pass
-    test_passwd_files(path, true);
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_for_bad_passwd_files) {
-    cout << "ACore:: ...test_parsing_for_bad_passwd_files\n";
-
-    std::string path = File::test_data("ACore/test/data/badPasswdFiles", "ACore");
-
-    // All the files in this directory are expected to fail
-    test_passwd_files(path, false);
-}
-
-BOOST_AUTO_TEST_CASE(test_passwd_empty_file) {
-    cout << "ACore:: ...test_passwd_empty_file\n";
-
-    std::string path = File::test_data("ACore/test/data/goodPasswdFiles/empty.passwd", "ACore");
-
-    PasswdFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    BOOST_REQUIRE_MESSAGE(theFile.passwds().empty(), "expected empty file ");
-    BOOST_REQUIRE_MESSAGE(theFile.get_passwd("fred", "host", "port") == string(), "expected empty string");
-    BOOST_REQUIRE_MESSAGE(theFile.authenticate("fred", ""),
-                          "expected to authenticate. TEST CASE with empty password file");
-    BOOST_REQUIRE_MESSAGE(!theFile.authenticate("fred", "passwd"), "expected not to authenticate");
-    BOOST_REQUIRE_MESSAGE(!theFile.authenticate("", "passwd"), "expected not to authenticate");
-    BOOST_REQUIRE_MESSAGE(!theFile.authenticate("", ""), "expected not to authenticate");
-}
-
-BOOST_AUTO_TEST_CASE(test_passwd) {
-    cout << "ACore:: ...test_passwd\n";
-
-    std::string path = File::test_data("ACore/test/data/goodPasswdFiles/ecf.passwd", "ACore");
-
-    PasswdFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    BOOST_CHECK_MESSAGE(theFile.check_at_least_one_user_with_host_and_port("host", "3141"), "expected to pass");
-    BOOST_CHECK_MESSAGE(theFile.check_at_least_one_user_with_host_and_port("host3", "3143"), "expected to pass");
-    BOOST_CHECK_MESSAGE(theFile.check_at_least_one_user_with_host_and_port("host4", "3145"), "expected to pass");
-    BOOST_CHECK_MESSAGE(!theFile.check_at_least_one_user_with_host_and_port("xxxx", "3141"), "expected fail ");
-    BOOST_CHECK_MESSAGE(!theFile.check_at_least_one_user_with_host_and_port("host", "13141"), "expected fail ");
-
-    // make sure we find all the users and the access right are correct
-    //   4.4.0  # comment
-    //
-    //   # comment
-    //   fred host 3141  x12ggg # comment
-    //   fred host3 3143 passwd
-    //   fred host4 3145 x12ggg
-    //   # comment
-    //
-    //   jake host 3141  x12ggg
-    //   tom host3 3143    x12ggg # sdsdsd
-
-    std::vector<Pass_wd> expected_passwds;
-    expected_passwds.emplace_back("fred", "host", "3141", PasswordEncryption::encrypt("x12ggg", "fred"));
-    expected_passwds.emplace_back("fred", "host3", "3143", PasswordEncryption::encrypt("passwd", "fred"));
-    expected_passwds.emplace_back("fred", "host4", "3145", PasswordEncryption::encrypt("x12ggg", "fred"));
-    expected_passwds.emplace_back("jake", "host", "3141", PasswordEncryption::encrypt("x12ggg", "jake"));
-    expected_passwds.emplace_back("tom", "host3", "3143", PasswordEncryption::encrypt("x12ggg", "tom"));
-
-    BOOST_REQUIRE_MESSAGE(expected_passwds == theFile.passwds(), "expected passwords to match");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestPasswordEncryption.cpp 5.13.0-1/ACore/test/TestPasswordEncryption.cpp
--- 5.12.4-1/ACore/test/TestPasswordEncryption.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestPasswordEncryption.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,36 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-///
-/// \brief Tests the functionality provided by PasswordEncryption
-///
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/PasswordEncryption.hpp"
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_PasswordEncryption)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_encrypt_password) {
-    PasswordEncryption::username_t user               = "username";
-    PasswordEncryption::plain_password_t plain        = "password";
-    PasswordEncryption::encrypted_password_t expected = "usjRS48E8ZADM";
-    // Expected was obtained by calling `$ openssl passwd -salt username password`
-
-    auto encrypted = PasswordEncryption::encrypt(plain, user);
-
-    BOOST_REQUIRE(encrypted == expected);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestPerfTimer.cpp 5.13.0-1/ACore/test/TestPerfTimer.cpp
--- 5.12.4-1/ACore/test/TestPerfTimer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestPerfTimer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/perf_timer.hpp"
-
-using namespace boost;
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_PerfTimer)
-
-static void func(int const count = 100000) {
-    // std::cout << " func : count " << count << "\n";
-    for (int i = 0; i < count; i++) {
-        std::string s = std::string("fred");
-        s += ecf::convert_to<std::string>(i);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_perf_with_chrono) {
-    cout << "ACore:: ...test_perf_with_chrono\n";
-
-    // using namespace std::chrono_literals;
-
-    auto t = perf_timer<>::duration(func, 100000);
-
-    std::cout << "   " << std::chrono::duration<double, std::micro>(t).count() << " micro" << std::endl;
-    std::cout << "   " << std::chrono::duration<double, std::milli>(t).count() << " milli" << std::endl;
-    std::cout << "   " << std::chrono::duration<double, std::nano>(t).count() << " nano" << std::endl;
-
-    // This does not work, ie calling func with no arguments ?? with our hacked invoke, wait till c++ 17
-    // auto t0= perf_timer<std::chrono::nanoseconds>::duration(func);
-
-    auto t1 = perf_timer<std::chrono::nanoseconds>::duration(func, 10);
-    auto t2 = perf_timer<std::chrono::microseconds>::duration(func, 100);
-    auto t3 = perf_timer<std::chrono::milliseconds>::duration(func, 100000);
-    std::cout << "   " << std::chrono::duration<double, std::milli>(t1 + t2 + t3).count() << " milli" << std::endl;
-    BOOST_CHECK_MESSAGE(true, "dummy to keep unit test happy");
-}
-
-BOOST_AUTO_TEST_CASE(test_chrono_timer) {
-    cout << "ACore:: ... test_chrono_timer\n";
-
-    // using namespace std::chrono_literals;
-    {
-        Timer<std::chrono::milliseconds> timer;
-        func();
-        timer.elapsed("   func with default args , milliseconds");
-        std::cout << "    " << std::chrono::duration<double, std::micro>(timer.elapsed()).count() << " micro"
-                  << std::endl;
-        std::cout << "    " << std::chrono::duration<double, std::milli>(timer.elapsed()).count() << " milli"
-                  << std::endl;
-        std::cout << "    " << std::chrono::duration<double, std::nano>(timer.elapsed()).count() << " nano"
-                  << std::endl;
-    }
-    {
-        Timer<std::chrono::microseconds> timer;
-        func();
-        timer.elapsed("   func with default args , microseconds");
-    }
-    {
-        Timer<std::chrono::nanoseconds> timer;
-        func();
-        timer.elapsed("   func with default args , nanoseconds");
-    }
-    {
-        Timer<std::chrono::seconds> timer;
-        func();
-        timer.elapsed("   func with default args , seconds");
-    }
-    BOOST_CHECK_MESSAGE(true, "dummy to keep unit test happy");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestRealCalendar.cpp 5.13.0-1/ACore/test/TestRealCalendar.cpp
--- 5.12.4-1/ACore/test/TestRealCalendar.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestRealCalendar.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,350 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/date_time/posix_time/time_formatters.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_RealCalendar)
-
-BOOST_AUTO_TEST_CASE(test_REAL_calendar) {
-    cout << "ACore:: ...test_REAL_calendar\n";
-
-    // init the calendar to 2009, Feb, 10th,
-    boost::gregorian::date theDate(2009, 2, 10);
-    ptime time(theDate, hours(22) + minutes(10));
-
-    Calendar calendar;
-    calendar.init(time, Calendar::REAL);
-
-    // record the time for the test
-    boost::posix_time::ptime theSuiteTime        = calendar.suiteTime();
-    boost::posix_time::time_duration theDuration = calendar.duration();
-
-    // Take time now and add 2 minutes, use this to update calendar by 2 minutes
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-    time_now += minutes(2);
-    theSuiteTime += minutes(2);
-    theDuration += minutes(2);
-
-    calendar.update(time_now);
-
-    BOOST_CHECK_MESSAGE(calendar.suiteTime() == theSuiteTime,
-                        " Expected " << to_simple_string(theSuiteTime) << " but found "
-                                     << to_simple_string(calendar.suiteTime()));
-    BOOST_CHECK_MESSAGE(calendar.duration() == theDuration,
-                        " Expected " << to_simple_string(theDuration) << " but found "
-                                     << to_simple_string(calendar.duration()));
-
-    time_now += hours(24);
-    theSuiteTime += hours(24);
-    theDuration += hours(24);
-
-    calendar.update(time_now);
-
-    BOOST_CHECK_MESSAGE(calendar.suiteTime() == theSuiteTime,
-                        " Expected " << to_simple_string(theSuiteTime) << " but found "
-                                     << to_simple_string(calendar.suiteTime()));
-    BOOST_CHECK_MESSAGE(calendar.duration() == theDuration,
-                        " Expected " << to_simple_string(theDuration) << " but found "
-                                     << to_simple_string(calendar.duration()));
-}
-
-BOOST_AUTO_TEST_CASE(test_REAL_calendar_time_series_relative_complex) {
-    cout << "ACore:: ...test_REAL_calendar_time_series_relative_complex\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
-
-    // Create a test when we can match a time series
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr   00:15
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15), true /*relative*/);
-
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-
-    for (int hour = 0; hour < 24; hour++) {
-        for (int minute = 0; minute < 60; minute++) {
-
-            // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
-            time_now += minutes(1);
-
-            calendar.update(time_now);
-
-            timeSeries.calendarChanged(calendar);
-
-            tm suiteTm = to_tm(calendar.suiteTime());
-
-            bool matches = timeSeries.isFree(calendar);
-
-            bool intersects =
-                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
-                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
-            // Ovoid overshooting past end of series
-            bool boundaryOk = true;
-            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
-                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
-            }
-
-            if (intersects && boundaryOk) {
-                BOOST_CHECK_MESSAGE(matches,
-                                    "Calendar should match relative time series at "
-                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-                if (!matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!matches,
-                                    "Calendar should NOT match relative time series at "
-                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-
-                if (matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_REAL_calendar_time_series) {
-    cout << "ACore:: ...test_REAL_calendar_time_series\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr    1:00
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0));
-
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-
-    for (int hour = 1; hour < 24; hour++) {
-        // Update calendar every hour, then see we can match time series, in REAL
-        // Update will set the local time from the computers system clock, however
-        // for testing this will need to be overriden below.
-
-        time_now += hours(1);
-
-        calendar.update(time_now);
-
-        // cerr << "hour = " << hour << " suiteTime " << to_simple_string(calendar.suiteTime())  << "\n";
-        if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar), "Calendar should match time series at hour " << hour);
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Calendar should NOT match time series at hour " << hour);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_REAL_calendar_time_series_complex) {
-    cout << "ACore:: ...test_REAL_calendar_time_series_complex\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr   00:15
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15));
-
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-
-    for (int hour = 0; hour < 24; hour++) {
-        for (int minute = 0; minute < 60; minute++) {
-
-            // Update calendar every minute, then see we can match time series, *RELATIVE* to suite start
-            time_now += minutes(1);
-            calendar.update(time_now);
-
-            tm suiteTm = to_tm(calendar.suiteTime());
-
-            bool matches = timeSeries.isFree(calendar);
-
-            bool intersects =
-                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
-                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
-            // Ovoid overshooting past end of series
-            bool boundaryOk = true;
-            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
-                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
-            }
-
-            if (intersects && boundaryOk) {
-                BOOST_CHECK_MESSAGE(matches,
-                                    "Calendar should match relative time series at "
-                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-                if (!matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!matches,
-                                    "Calendar should NOT match relative time series at "
-                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
-                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
-
-                if (matches) {
-                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
-                         << " timeSeries.start().hour() " << timeSeries.start().hour()
-                         << " timeSeries.start().minute() " << timeSeries.start().minute()
-                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
-                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
-                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
-                }
-            }
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_REAL_calendar_hybrid_date) {
-    cout << "ACore:: ...test_REAL_calendar_hybrid_date\n";
-
-    // The hybrid calendar should not change the suite date.
-    // Test by updateing calendar by more than 24 hours
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
-
-    std::string expectedDate          = "2010-Feb-10";
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-
-    for (int hour = 1; hour < 60; hour++) {
-        // Update calendar every hour, for 60 hours
-        // the date should be the same, i.e 2009, Feb, 10th
-
-        ptime timeBeforeUpdate = calendar.suiteTime();
-
-        time_now += hours(1);
-
-        calendar.update(time_now);
-
-        ptime timeAfterUpdate = calendar.suiteTime();
-
-        //		cerr << "hour = " << hour << " timeBeforeUpdate " << to_simple_string(timeBeforeUpdate)
-        //		    << "   timeAfterUpdate = " << to_simple_string(timeAfterUpdate) <<  "\n";
-
-        if (hour != 24 && hour != 48) {
-            time_period diff(timeBeforeUpdate, timeAfterUpdate);
-            time_duration gap = diff.length();
-            BOOST_CHECK_MESSAGE(gap.hours() == 1,
-                                "Expected one hour difference but found " << gap.hours() << " at hour " << hour);
-        }
-
-        std::string actualDate = to_simple_string(calendar.suiteTime().date());
-        BOOST_CHECK_MESSAGE(actualDate == expectedDate,
-                            "Expected '" << expectedDate << "' but found " << actualDate << " at hour " << hour);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_REAL_day_changed) {
-    cout << "ACore:: ...test_REAL_day_changed \n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "calendar type should be real");
-
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-
-    for (int hour = 1; hour < 73; hour++) {
-        // Update calendar every hour, for 72 hours
-
-        time_now += hours(1);
-
-        calendar.update(time_now);
-
-        if (hour == 24 || hour == 48 || hour == 72) {
-            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
-                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
-                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_REAL_day_changed_for_hybrid) {
-    cout << "ACore:: ...test_REAL_day_changed_for_hybrid\n";
-
-    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
-    BOOST_CHECK_MESSAGE(calendar.hybrid(), "calendar type should be real");
-
-    // HYBRID calendars allow for day change but not date.
-    std::string expected_date = to_simple_string(calendar.date());
-
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-
-    for (int hour = 1; hour < 73; hour++) {
-        // Update calendar every hour, for 72 hours
-
-        time_now += hours(1);
-        calendar.update(time_now);
-
-        BOOST_CHECK_MESSAGE(expected_date == to_simple_string(calendar.date()),
-                            "Unexpected date change for hybrid calendar at hour " << hour);
-
-        // Day should change even for hybrid calendar,
-        if (hour == 24 || hour == 48 || hour == 72) {
-            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
-                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
-                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestSanitizerAS.cpp 5.13.0-1/ACore/test/TestSanitizerAS.cpp
--- 5.12.4-1/ACore/test/TestSanitizerAS.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestSanitizerAS.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-using namespace boost;
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_SanitizerAS)
-
-bool bool_returning_function() {
-    return true;
-}
-int integer_returning_function() {
-    return 3;
-}
-
-#if defined(__GNUC__) and !defined(__clang__)
-    #pragma GCC diagnostic push
-    #pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
-#endif
-
-// *** This test does not seem work with address sanitiser ****
-BOOST_AUTO_TEST_CASE(test_sanitizer_use_of_out_of_scope_stack_memory) {
-    char* test_me = getenv("ECF_TEST_SANITIZER_AS");
-    if (test_me) {
-        cout << "ACore:: ...test_sanitizer_use_of_out_of_scope_stack_memory\n";
-
-        int* pointer = NULL;
-        if (bool_returning_function()) {
-            int value = integer_returning_function();
-            pointer   = &value;
-        }
-        cout << "dodgy pointer:" << *pointer << "\n"; // Error: invalid access of stack memory out of declaration scope
-        *pointer = 42;
-        cout << "dodgy pointer:" << *pointer << "\n";
-        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
-    }
-}
-
-#if defined(__GNUC__) and !defined(__clang__)
-    #pragma GCC diagnostic pop
-#endif
-
-#if defined(__GNUC__) and !defined(__clang__)
-    #pragma GCC diagnostic push
-    #pragma GCC diagnostic ignored "-Warray-bounds"
-#endif
-
-BOOST_AUTO_TEST_CASE(test_sanitizer_vector_overflow) {
-    char* test_me = getenv("ECF_TEST_SANITIZER_AS");
-    if (test_me) {
-        cout << "ACore:: ...test_sanitizer_vector_overflow\n";
-        // This check detects when a libc++ container is accessed beyond the region [container.begin(), container.end())
-        // — even when the accessed memory is in a heap-allocated buffer used internally by a container.
-
-        // the following example, the vector variable has valid indexes in the range [0, 2], but is accessed at index 3,
-        // causing an overflow.
-        std::vector<int> vector{0, 1, 2};
-        auto* pointer = &vector[0];
-        cout << pointer[3]; // Error: out of bounds access for vector
-        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
-    }
-}
-
-#if defined(__GNUC__) and !defined(__clang__)
-    #pragma GCC diagnostic pop
-#endif
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestSanitizerUB.cpp 5.13.0-1/ACore/test/TestSanitizerUB.cpp
--- 5.12.4-1/ACore/test/TestSanitizerUB.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestSanitizerUB.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,120 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-using namespace boost;
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_SanitizerUB)
-
-struct Base
-{
-    int pad1{0};
-};
-struct Derived : Base
-{
-    int pad2{0};
-};
-Derived* getDerived() {
-    return static_cast<Derived*>(new Base); // Error: invalid downcast
-}
-
-#if defined(__GNUC__) and !defined(__clang__)
-    #pragma GCC diagnostic push
-    #pragma GCC diagnostic ignored "-Warray-bounds"
-#endif
-
-BOOST_AUTO_TEST_CASE(test_sanitizer_invalid_object_size) {
-    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
-    if (test_me) {
-        cout << "ACore:: ...test_sanitizer_invalid_object_size\n";
-
-        // This check detects pointer casts in which the size of the source type is less than the size of the
-        // destination type. Using the result of such a cast to access out-of-bounds data has undefined behaviour
-        cout << getDerived()->pad2 << "\n";
-        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
-    }
-}
-
-#if defined(__GNUC__) and !defined(__clang__)
-    #pragma GCC diagnostic pop
-#endif
-
-BOOST_AUTO_TEST_CASE(test_sanitizer_misaligned_structure_pointer_assignment) {
-    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
-    if (test_me) {
-        cout << "ACore:: ...test_sanitizer_misaligned_structure_pointer_assignment\n";
-        // In the following example, the pointer variable is required to have 8-byte alignment, but is only 1-byte
-        // aligned.
-
-        struct A
-        {
-            int32_t i32;
-            int64_t i64;
-        };
-        int8_t* buffer    = (int8_t*)malloc(32);
-        struct A* pointer = (struct A*)(buffer + 1);
-        pointer->i32      = 7; // Error: pointer is misaligned
-
-        BOOST_CHECK_MESSAGE(pointer->i32 == 7, "expected error");
-
-        // solution
-        // One solution is to mark the struct as packed. In the following example, the A structure is packed,
-        // preventing the compiler from adding padding between members.
-        // struct A { ... } __attribute__((packed));
-        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_sanitizer_out_of_bounds_array_access) {
-    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
-    if (test_me) {
-        cout << "ACore:: ...test_sanitizer_out_of_bounds_array_access\n";
-
-        // This check detects out-of-bounds access of arrays with fixed or variable-length sizes.
-        // Out-of-bounds array accesses have undefined behaviour, and can result in crashes or incorrect program output.
-        int array[5] = {0, 0, 0, 0, 0};
-        for (int i = 0; i <= 5; ++i) {
-            array[i] += 1; // Error: out-of-bounds access on the last iteration
-            BOOST_REQUIRE_NO_THROW(array[i] += 1);
-        }
-    }
-}
-
-struct A
-{
-    int x;
-    int getX() {
-        //        if (!this) { // Warning: redundant null check may be removed
-        //            return 0;
-        //        }
-        return x; // Warning: 'this' pointer is null, but is dereferenced here
-    }
-};
-
-BOOST_AUTO_TEST_CASE(test_sanitizer_member_access_through_null_pointer) {
-    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
-    if (test_me) {
-        cout << "ACore:: ...test_sanitizer_member_access_through_null_pointer \n";
-
-        A* a  = nullptr;
-        int x = a->getX(); // Error: member access through null pointer
-        BOOST_CHECK_MESSAGE(x, "stop boost test from complaining");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestSerialisation.cpp 5.13.0-1/ACore/test/TestSerialisation.cpp
--- 5.12.4-1/ACore/test/TestSerialisation.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestSerialisation.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "TestSerialisation.hpp"
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-static std::string fileName = "test.txt";
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Serialisation)
-
-BOOST_AUTO_TEST_CASE(test_calendar_serialisation) {
-    cout << "ACore:: ...test_calendar_serialisation \n";
-
-    Calendar cal;
-    doSaveAndRestore(fileName, cal);
-}
-
-BOOST_AUTO_TEST_CASE(test_TimeSlot_serialisation) {
-    cout << "ACore:: ...test_TimeSlot_serialisation \n";
-
-    { doSaveAndRestore<TimeSlot>(fileName); }
-
-    {
-        TimeSlot saved(1, 1);
-        doSaveAndRestore(fileName, saved);
-    }
-
-    {
-        TimeSlot saved(99, 59);
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_TimeSeries_serialisation) {
-    cout << "ACore:: ...test_TimeSeries_serialisation \n";
-
-    { doSaveAndRestore<TimeSeries>(fileName); }
-    {
-        TimeSeries saved = TimeSeries(TimeSlot(10, 10));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        TimeSeries saved = TimeSeries(TimeSlot(0, 0), TimeSlot(10, 10), TimeSlot(0, 10));
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestSerialisation.hpp 5.13.0-1/ACore/test/TestSerialisation.hpp
--- 5.12.4-1/ACore/test/TestSerialisation.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestSerialisation.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_TestSerialisation_HPP
-#define ecflow_core_TestSerialisation_HPP
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Serialization.hpp"
-
-namespace ecf {
-
-template <typename T>
-void do_restore(const std::string& fileName, const T& saved) {
-    T restored;
-    try {
-        ecf::restore(fileName, restored);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Restore failed because: " << e.what());
-    }
-    BOOST_CHECK_MESSAGE(saved == restored, "save and restored don't match for " << fileName << "\n");
-}
-
-template <typename T>
-void doRestore(const std::string& fileName, const T& saved) {
-    do_restore(fileName, saved);
-    std::remove(fileName.c_str());
-}
-
-template <typename T>
-void doSave(const std::string& fileName, const T& saved) {
-    try {
-        ecf::save(fileName, saved);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Save  failed because: " << e.what());
-    }
-}
-
-template <typename T>
-void doSave(const std::string& fileName) {
-    T saved;
-    doSave(fileName, saved);
-}
-
-template <typename T>
-void doSaveAndRestore(const std::string& fileName, const T& saved) {
-    doSave(fileName, saved);
-    doRestore(fileName, saved);
-}
-
-template <typename T>
-void doSaveAndRestore(const std::string& fileName) {
-    T saved;
-    doSaveAndRestore(fileName, saved);
-}
-
-} // namespace ecf
-
-#endif /* ecflow_core_TestSerialisation_HPP */
diff -pruN 5.12.4-1/ACore/test/TestStr.cpp 5.13.0-1/ACore/test/TestStr.cpp
--- 5.12.4-1/ACore/test/TestStr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestStr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,939 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <algorithm>
-#include <functional>
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-#include <boost/timer/timer.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/StringSplitter.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Str)
-
-BOOST_AUTO_TEST_CASE(test_str) {
-    cout << "ACore:: ...test_str\n";
-
-    {
-        std::string str;
-        std::string expected;
-        Str::removeQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-
-        str      = "\"\"";
-        expected = "";
-        Str::removeQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-
-        str      = "fred";
-        expected = "fred";
-        Str::removeQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-
-        str      = "\"fred\"";
-        expected = "fred";
-        Str::removeQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-    }
-    {
-        std::string str;
-        std::string expected;
-        Str::removeSingleQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-
-        str      = "''";
-        expected = "";
-        Str::removeSingleQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-
-        str      = "fred";
-        expected = "fred";
-        Str::removeSingleQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-
-        str      = "'fred'";
-        expected = "fred";
-        Str::removeSingleQuotes(str);
-        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
-    }
-    {
-        string test;
-        BOOST_CHECK_MESSAGE(!Str::truncate_at_start(test, 7), "Empty sring should return false");
-
-        test            = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
-        string expected = "line";
-        BOOST_CHECK_MESSAGE(Str::truncate_at_start(test, 1) && test == expected,
-                            "Expected:\n"
-                                << expected << "\nbut found:\n"
-                                << test);
-
-        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
-        expected = "a\nstring\nwith\nlots\nof\nnew\nline";
-        BOOST_CHECK_MESSAGE(Str::truncate_at_start(test, 7) && test == expected,
-                            "Expected:\n"
-                                << expected << "\nbut found:\n"
-                                << test);
-
-        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
-        expected = test;
-        BOOST_CHECK_MESSAGE(!Str::truncate_at_start(test, 9) && test == expected,
-                            "Expected:\n"
-                                << expected << "\nbut found:\n"
-                                << test);
-    }
-    {
-        string test;
-        BOOST_CHECK_MESSAGE(!Str::truncate_at_end(test, 7), "Empty string should return false");
-
-        test            = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
-        string expected = "this\n";
-        BOOST_CHECK_MESSAGE(Str::truncate_at_end(test, 1) && test == expected,
-                            "Expected:\n"
-                                << expected << "\nbut found:\n"
-                                << test);
-
-        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
-        expected = "this\nis\n";
-        BOOST_CHECK_MESSAGE(Str::truncate_at_end(test, 2) && test == expected,
-                            "Expected:\n"
-                                << expected << "\nbut found:\n"
-                                << test);
-
-        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
-        expected = "this\nis\na\nstring\nwith\nlots\nof\n";
-        BOOST_CHECK_MESSAGE(Str::truncate_at_end(test, 7) && test == expected,
-                            "Expected:\n"
-                                << expected << "\nbut found:\n"
-                                << test);
-
-        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
-        expected = test;
-        BOOST_CHECK_MESSAGE(!Str::truncate_at_end(test, 9) && test == expected,
-                            "Expected:\n"
-                                << expected << "\nbut found:\n"
-                                << test);
-    }
-}
-
-static void
-check(const std::string& line, const std::vector<std::string>& result, const std::vector<std::string>& expected) {
-    BOOST_CHECK_MESSAGE(result.size() == expected.size(),
-                        "expected size " << expected.size() << " but found " << result.size() << " for '" << line
-                                         << "'");
-    BOOST_CHECK_MESSAGE(result == expected, "failed for '" << line << "'");
-    if (result != expected) {
-        cout << "Line    :'" << line << "'\n";
-        cout << "Actual  :";
-        for (const string& t : result) {
-            cout << "'" << t << "'";
-        }
-        cout << "\n";
-        cout << "Expected:";
-        for (const string& t : expected) {
-            cout << "'" << t << "'";
-        }
-        cout << "\n";
-    }
-}
-
-static void
-check(const std::string& line, const std::vector<std::string_view>& result2, const std::vector<std::string>& expected) {
-    std::vector<std::string> result;
-    for (auto ref : result2) {
-        result.emplace_back(ref.begin(), ref.end());
-    }
-    check(line, result, expected);
-}
-
-static void check(const std::string& line,
-                  boost::split_iterator<std::string::const_iterator> res,
-                  const std::vector<std::string>& expected) {
-    std::vector<std::string> result;
-    typedef boost::split_iterator<std::string::const_iterator> split_iter_t;
-    for (; res != split_iter_t(); res++)
-        result.push_back(boost::copy_range<std::string>(*res));
-    check(line, result, expected);
-}
-
-static void check_splitters(const std::string& line, const std::vector<std::string>& expected) {
-    std::vector<std::string> result, result1, result2, result3;
-    std::vector<std::string_view> result4;
-
-    Str::split_orig(line, result);
-    check(line, result, expected);
-    Str::split_orig1(line, result1);
-    check(line, result1, expected);
-    Str::split_using_string_view(line, result2);
-    check(line, result2, expected);
-    Str::split_using_string_view2(line, result3);
-    check(line, result3, expected);
-    StringSplitter::split(line, result4);
-    check(line, result4, expected);
-
-    // While were at it also check get_token
-    for (size_t i = 0; i < result1.size(); i++) {
-        std::string token;
-        BOOST_CHECK_MESSAGE(Str::get_token(line, i, token) && token == result1[i],
-                            "Str::get_token failed for pos " << i << " line:'" << line << "' expected '" << result1[i]
-                                                             << "' but found '" << token << "'");
-
-        token.clear();
-        BOOST_CHECK_MESSAGE(Str::get_token2(line, i, token) && token == result1[i],
-                            "Str::get_token2 failed for pos " << i << " line:'" << line << "' expected '" << result1[i]
-                                                              << "' but found '" << token << "'");
-
-        token.clear();
-        BOOST_CHECK_MESSAGE(Str::get_token3(line, i, token) && token == result1[i],
-                            "Str::get_token3 failed for pos " << i << " line:'" << line << "' expected '" << result1[i]
-                                                              << "' but found '" << token << "'");
-
-        token.clear();
-        BOOST_CHECK_MESSAGE(StringSplitter::get_token(line, i, token) && token == result1[i],
-                            "StringSplitter::get_token failed for pos " << i << " line:'" << line << "' expected '"
-                                                                        << result1[i] << "' but found '" << token
-                                                                        << "'");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_str_split) {
-    cout << "ACore:: ...test_str_split\n";
-
-    std::vector<std::string> expected;
-
-    std::string line = "This is a string";
-    expected.emplace_back("This");
-    expected.emplace_back("is");
-    expected.emplace_back("a");
-    expected.emplace_back("string");
-    check_splitters(line, expected);
-
-    expected.clear();
-    line = "  ";
-    check_splitters(line, expected);
-
-    line = "a";
-    expected.clear();
-    expected.emplace_back("a");
-    check_splitters(line, expected);
-
-    // Some implementation fail this test
-    line = "\n";
-    expected.clear();
-    expected.emplace_back("\n");
-    check_splitters(line, expected);
-
-    line = "a ";
-    expected.clear();
-    expected.emplace_back("a");
-    check_splitters(line, expected);
-
-    line = " a";
-    expected.clear();
-    expected.emplace_back("a");
-    check_splitters(line, expected);
-
-    line = "	a"; // check tabs
-    expected.clear();
-    expected.emplace_back("a");
-    check_splitters(line, expected);
-
-    line = "		a		"; // check sequential tabs
-    expected.clear();
-    expected.emplace_back("a");
-    check_splitters(line, expected);
-
-    line = " a ";
-    expected.clear();
-    expected.emplace_back("a");
-    check_splitters(line, expected);
-
-    line = "        a     b     c       d        ";
-    expected.clear();
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    expected.emplace_back("d");
-    check_splitters(line, expected);
-
-    line = " - !   $ % ^ & * ( ) - + ?";
-    expected.clear();
-    expected.emplace_back("-");
-    expected.emplace_back("!");
-    expected.emplace_back("$");
-    expected.emplace_back("%");
-    expected.emplace_back("^");
-    expected.emplace_back("&");
-    expected.emplace_back("*");
-    expected.emplace_back("(");
-    expected.emplace_back(")");
-    expected.emplace_back("-");
-    expected.emplace_back("+");
-    expected.emplace_back("?");
-    check_splitters(line, expected);
-
-    // Check tabs
-    line = "		 verify complete:8		                # 4 sundays in october hence expect 8 task "
-           "completions";
-    expected.clear();
-    expected.emplace_back("verify");
-    expected.emplace_back("complete:8");
-    expected.emplace_back("#");
-    expected.emplace_back("4");
-    expected.emplace_back("sundays");
-    expected.emplace_back("in");
-    expected.emplace_back("october");
-    expected.emplace_back("hence");
-    expected.emplace_back("expect");
-    expected.emplace_back("8");
-    expected.emplace_back("task");
-    expected.emplace_back("completions");
-    check_splitters(line, expected);
-}
-
-BOOST_AUTO_TEST_CASE(test_str_split_make_split_iterator) {
-    cout << "ACore:: ...test_str_split_make_split_iterator\n";
-
-    std::string line = "This is a string";
-    std::vector<std::string> expected;
-    expected.emplace_back("This");
-    expected.emplace_back("is");
-    expected.emplace_back("a");
-    expected.emplace_back("string");
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    expected.emplace_back("");
-    line = "";
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    expected.emplace_back("");
-    expected.emplace_back("");
-    line = "  "; // If start/end is delimeter, then preserved as empty token
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = "a";
-    expected.emplace_back("a");
-    check(line, Str::make_split_iterator(line), expected);
-
-    // Some implementation fail this test
-    expected.clear();
-    line = "\n";
-    expected.emplace_back("\n");
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = "a ";
-    expected.emplace_back("a");
-    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = " a";
-    expected.emplace_back("");
-    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = " a"; // check tabs
-    expected.emplace_back("");
-    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = "    a     "; // check sequential tabs
-    expected.emplace_back("");
-    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
-    expected.emplace_back("");
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = " a ";
-    expected.emplace_back("");
-    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
-    expected.emplace_back("");
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = "        a     b     c       d        ";
-    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    expected.emplace_back("d");
-    expected.emplace_back("");
-    check(line, Str::make_split_iterator(line), expected);
-
-    expected.clear();
-    line = " - !   $ % ^  & * ( ) - + ?";
-    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
-    expected.emplace_back("-");
-    expected.emplace_back("!");
-    expected.emplace_back("$");
-    expected.emplace_back("%");
-    expected.emplace_back("^");
-    expected.emplace_back("&");
-    expected.emplace_back("*");
-    expected.emplace_back("(");
-    expected.emplace_back(")");
-    expected.emplace_back("-");
-    expected.emplace_back("+");
-    expected.emplace_back("?");
-    check(line, Str::make_split_iterator(line), expected);
-
-    // Check tabs
-    expected.clear();
-    line = "     verify complete:8                      # 4 sundays in october hence expect 8 task completions";
-    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
-    expected.emplace_back("verify");
-    expected.emplace_back("complete:8");
-    expected.emplace_back("#");
-    expected.emplace_back("4");
-    expected.emplace_back("sundays");
-    expected.emplace_back("in");
-    expected.emplace_back("october");
-    expected.emplace_back("hence");
-    expected.emplace_back("expect");
-    expected.emplace_back("8");
-    expected.emplace_back("task");
-    expected.emplace_back("completions");
-    check(line, Str::make_split_iterator(line), expected);
-}
-
-static void
-test_replace(std::string& testStr, const std::string& find, const std::string& replace, const std::string& expected) {
-    BOOST_CHECK_MESSAGE(Str::replace(testStr, find, replace),
-                        "Replace failed for " << testStr << " find(" << find << ") replace(" << replace << ")");
-    BOOST_CHECK_MESSAGE(testStr == expected, "Expected '" << expected << "' but found '" << testStr << "'");
-}
-
-static void test_replace_all(std::string& testStr,
-                             const std::string& find,
-                             const std::string& replace,
-                             const std::string& expected) {
-    std::string testStrCopy = testStr;
-
-    BOOST_CHECK_MESSAGE(Str::replace_all(testStr, find, replace),
-                        "Replace failed for " << testStr << " find(" << find << ") replace(" << replace << ")");
-    BOOST_CHECK_MESSAGE(testStr == expected, "Expected '" << expected << "' but found '" << testStr << "'");
-
-    Str::replaceall(testStrCopy, find, replace);
-    BOOST_CHECK_MESSAGE(testStr == testStrCopy, "Expected '" << testStrCopy << "' but found '" << testStr << "'");
-}
-
-BOOST_AUTO_TEST_CASE(test_str_replace) {
-    cout << "ACore:: ...test_str_replace\n";
-
-    std::string testStr = "This is a string";
-    test_replace(testStr, "This", "That", "That is a string");
-
-    testStr = "This is a string";
-    test_replace(testStr, "This is a string", "", "");
-
-    testStr = "This is a string";
-    test_replace(testStr, "is a", "was a", "This was a string");
-
-    testStr = "This\n is a string";
-    test_replace(testStr, "\n", "\\n", "This\\n is a string");
-
-    testStr = "This\n is\n a\n string\n";
-    test_replace_all(testStr, "\n", "\\n", R"(This\n is\n a\n string\n)");
-
-    // Test case insenstive string comparison
-    BOOST_CHECK_MESSAGE(Str::caseInsCompare("", ""), " bug1");
-    BOOST_CHECK_MESSAGE(!Str::caseInsCompare("Str", "Str1"), " bug1");
-    BOOST_CHECK_MESSAGE(!Str::caseInsCompare("", "Str1"), " bug1");
-    BOOST_CHECK_MESSAGE(Str::caseInsCompare("Str", "STR"), " bug1");
-    BOOST_CHECK_MESSAGE(Str::caseInsCompare("Case", "CaSE"), " bug1");
-}
-
-BOOST_AUTO_TEST_CASE(test_str_replace_all) {
-    cout << "ACore:: ...test_str_replace_all\n";
-
-    std::string testStr = "This is a string";
-    test_replace_all(testStr, "This", "That", "That is a string");
-
-    testStr = "This is a string";
-    test_replace_all(testStr, "This is a string", "", "");
-
-    testStr = "This is a string";
-    test_replace_all(testStr, "is a", "was a", "This was a string");
-
-    testStr = "This\n is a string";
-    test_replace_all(testStr, "\n", "\\n", "This\\n is a string");
-
-    testStr = "This\n is\n a\n string\n";
-    test_replace_all(testStr, "\n", "\\n", R"(This\n is\n a\n string\n)");
-
-    testStr = "This\n is\n a\n string\n";
-    test_replace_all(testStr, "\n", "", "This is a string");
-}
-
-BOOST_AUTO_TEST_CASE(test_str_to_int) {
-    cout << "ACore:: ...test_str(to_int)\n";
-    BOOST_CHECK_MESSAGE(Str::to_int("0") == 0, "Expected 0");
-    BOOST_CHECK_MESSAGE(Str::to_int("1") == 1, "Expected 1");
-    BOOST_CHECK_MESSAGE(Str::to_int("-0") == 0, "Expected 0");
-    BOOST_CHECK_MESSAGE(Str::to_int("-1") == -1, "Expected -1");
-    BOOST_CHECK_MESSAGE(Str::to_int("") == std::numeric_limits<int>::max(), "Expected max int");
-    BOOST_CHECK_MESSAGE(Str::to_int("-") == std::numeric_limits<int>::max(), "Expected max int");
-    BOOST_CHECK_MESSAGE(Str::to_int(" ") == std::numeric_limits<int>::max(), "Expected max int");
-    BOOST_CHECK_MESSAGE(Str::to_int("q") == std::numeric_limits<int>::max(), "Expected max int");
-    BOOST_CHECK_MESSAGE(Str::to_int("q22") == std::numeric_limits<int>::max(), "Expected max int");
-    BOOST_CHECK_MESSAGE(Str::to_int("q22", -1) == -1, "Expected -1 on failure");
-    BOOST_CHECK_MESSAGE(Str::to_int("99 99") == std::numeric_limits<int>::max(), "Expected max int");
-    BOOST_CHECK_MESSAGE(Str::to_int("99 99", 0) == 0, "Expected 0 for failure");
-}
-
-BOOST_AUTO_TEST_CASE(test_extract_data_member_value) {
-    cout << "ACore:: ...test_extract_data_member_value\n";
-    std::string expected = "value";
-    std::string actual;
-    std::string str = "aa bb c fred:value";
-    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "fred:", actual), " failed");
-    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
-
-    str      = "fred:x  bill:zzz jake:12345 1234:99  6677";
-    expected = "x";
-    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "fred:", actual), " failed");
-    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
-
-    expected = "zzz";
-    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "bill:", actual), " failed");
-    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
-
-    expected = "12345";
-    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "jake:", actual), " failed");
-    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
-
-    expected = "99";
-    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "1234:", actual), " failed");
-    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
-
-    expected = "77";
-    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "66", actual), " failed");
-    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
-}
-
-std::string toString(const std::vector<std::string>& c) {
-    std::stringstream ss;
-    std::copy(c.begin(), c.end(), std::ostream_iterator<std::string>(ss, ", "));
-    return ss.str();
-}
-
-BOOST_AUTO_TEST_CASE(test_str_less_greater) {
-    cout << "ACore:: ...test_str_less_greater\n";
-
-    std::vector<std::string> expected;
-    expected.emplace_back("a1");
-    expected.emplace_back("A2");
-    expected.emplace_back("b1");
-    expected.emplace_back("B2");
-    expected.emplace_back("c");
-
-    std::vector<std::string> expectedGreater;
-    expectedGreater.emplace_back("c");
-    expectedGreater.emplace_back("B2");
-    expectedGreater.emplace_back("b1");
-    expectedGreater.emplace_back("A2");
-    expectedGreater.emplace_back("a1");
-
-    std::vector<std::string> vec;
-    vec.emplace_back("c");
-    vec.emplace_back("A2");
-    vec.emplace_back("a1");
-    vec.emplace_back("b1");
-    vec.emplace_back("B2");
-
-    std::sort(vec.begin(), vec.end(), Str::caseInsLess);
-    BOOST_REQUIRE_MESSAGE(vec == expected, "expected " << toString(expected) << " but found " << toString(vec));
-
-    std::sort(vec.begin(), vec.end(), Str::caseInsGreater);
-    BOOST_REQUIRE_MESSAGE(vec == expectedGreater,
-                          "expected " << toString(expectedGreater) << " but found " << toString(vec));
-
-    // --------------------------------------------------------------------
-
-    expected.clear();
-    expected.emplace_back("a");
-    expected.emplace_back("A");
-    expected.emplace_back("b");
-    expected.emplace_back("B");
-    expected.emplace_back("c");
-
-    expectedGreater.clear();
-    expectedGreater.emplace_back("c");
-    expectedGreater.emplace_back("B");
-    expectedGreater.emplace_back("b");
-    expectedGreater.emplace_back("A");
-    expectedGreater.emplace_back("a");
-
-    vec.clear();
-    vec.emplace_back("c");
-    vec.emplace_back("B");
-    vec.emplace_back("A");
-    vec.emplace_back("b");
-    vec.emplace_back("a");
-
-    std::sort(vec.begin(), vec.end(), Str::caseInsLess);
-    BOOST_REQUIRE_MESSAGE(vec == expected, "expected " << toString(expected) << " but found " << toString(vec));
-
-    std::sort(vec.begin(), vec.end(), Str::caseInsGreater);
-    BOOST_REQUIRE_MESSAGE(vec == expectedGreater,
-                          "expected " << toString(expectedGreater) << " but found " << toString(vec));
-
-    // --------------------------------------------------------------------
-
-    expected.clear();
-    expected.emplace_back("1234");
-    expected.emplace_back("baSE");
-    expected.emplace_back("Base");
-    expected.emplace_back("case");
-    expected.emplace_back("CaSe");
-    expected.emplace_back("suite");
-    expected.emplace_back("SUITE");
-
-    expectedGreater.clear();
-    expectedGreater.emplace_back("SUITE");
-    expectedGreater.emplace_back("suite");
-    expectedGreater.emplace_back("CaSe");
-    expectedGreater.emplace_back("case");
-    expectedGreater.emplace_back("Base");
-    expectedGreater.emplace_back("baSE");
-    expectedGreater.emplace_back("1234");
-
-    vec.clear();
-    vec.emplace_back("suite");
-    vec.emplace_back("SUITE");
-    vec.emplace_back("baSE");
-    vec.emplace_back("Base");
-    vec.emplace_back("case");
-    vec.emplace_back("CaSe");
-    vec.emplace_back("1234");
-
-    std::sort(vec.begin(), vec.end(), Str::caseInsLess);
-    BOOST_REQUIRE_MESSAGE(vec == expected, "expected " << toString(expected) << " but found " << toString(vec));
-
-    std::sort(vec.begin(), vec.end(), Str::caseInsGreater);
-    BOOST_REQUIRE_MESSAGE(vec == expectedGreater,
-                          "expected " << toString(expectedGreater) << " but found " << toString(vec));
-}
-
-//// ==============================================================
-//// Timing to find the fastest looping
-//// ==============================================================
-class Fred {
-public:
-    explicit Fred(int i = 0) : i_(i) { /*std::cout << "Fred constructor\n"*/
-        // Do nothing...
-    }
-    Fred(const Fred& rhs) : i_(rhs.i_) { /*std::cout << "Fred copy constructor\n";*/
-        // Do nothing...
-    }
-    Fred& operator=(const Fred& rhs) { /*std::cout << "assignment operator\n";*/
-        i_ = rhs.i_;
-        return *this;
-    }
-    ~Fred() { /*std::cout << "Fred destructor\n";*/
-        // Do nothing...
-    }
-
-    void inc() { i_++; }
-
-private:
-    int i_;
-};
-
-BOOST_AUTO_TEST_CASE(test_loop, *boost::unit_test::disabled()) {
-    const size_t size = 200000000;
-    std::vector<Fred> vec;
-    vec.reserve(size);
-    for (size_t i = 0; i < size; i++) {
-        vec.push_back(Fred(i));
-    }
-
-    {
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (auto& fred : vec) {
-            fred.inc();
-        }
-        cout << "Time: for(auto &fred : vec) { fred.inc(); }                                                "
-             << timer.format(3, Str::cpu_timer_format()) << "\n";
-    }
-
-    {
-        boost::timer::cpu_timer timer;
-        std::for_each(vec.begin(), vec.end(), [](Fred& fred) { fred.inc(); });
-        cout << "Time: std::for_each(vec.begin(),vec.end(),[](Fred& fred) { fred.inc();} );                 "
-             << timer.format(3, Str::cpu_timer_format()) << "\n";
-    }
-
-    {
-        boost::timer::cpu_timer timer;
-        std::vector<Fred>::iterator theEnd = vec.end();
-        for (std::vector<Fred>::iterator i = vec.begin(); i < theEnd; i++) {
-            (*i).inc();
-        }
-        cout << "Time: for (std::vector<Fred>::iterator  i = vec.begin(); i < theEnd ; i++) { (*i).inc(); } "
-             << timer.format(3, Str::cpu_timer_format()) << "\n";
-    }
-
-    {
-        boost::timer::cpu_timer timer;
-        size_t theSize = vec.size();
-        for (size_t i = 0; i < theSize; i++) {
-            vec[i].inc();
-        }
-        cout << "Time: for (size_t i = 0; i < theSize ; i++) { vec[i].inc(); }                              "
-             << timer.format(3, Str::cpu_timer_format()) << "\n";
-    }
-}
-
-/// ==============================================================
-/// Timing to find the fastest conversion from string to int
-/// ==============================================================
-static void methodX(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
-    // 0.81
-    // for bad conversion istringstream seems to return 0, hence add guard
-    if (str.find_first_of(Str::NUMERIC(), 0) == 0) {
-        int number = 0;
-        std::istringstream(str) >> number;
-        numberRes.push_back(number);
-    }
-    else {
-        stringRes.push_back(str);
-    }
-}
-
-static void method1(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
-    // 12.2
-    try {
-        int number = ecf::convert_to<int>(str);
-        numberRes.push_back(number);
-    }
-    catch (const ecf::bad_conversion&) {
-        stringRes.push_back(str);
-    }
-}
-
-static void method2(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
-    // 0.6
-    if (str.find_first_of(Str::NUMERIC(), 0) == 0) {
-        try {
-            int number = ecf::convert_to<int>(str);
-            numberRes.push_back(number);
-        }
-        catch (const ecf::bad_conversion&) {
-            stringRes.push_back(str);
-        }
-    }
-    else {
-        stringRes.push_back(str);
-    }
-}
-
-static void method3(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
-    // 0.14
-    // atoi return 0 for errors,
-    int number = atoi(str.c_str()); // does not handle errors
-    if (number == 0 && str.size() != 1) {
-        stringRes.push_back(str);
-    }
-    else {
-        numberRes.push_back(number);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_lexical_cast_perf, *boost::unit_test::disabled()) {
-    cout << "ACore:: ...test_string_to_int_conversion\n";
-
-    size_t the_size = 1000000;
-    std::vector<std::string> stringTokens;
-    std::vector<std::string> numberTokens;
-    std::vector<int> expectedNumberRes;
-    for (size_t i = 0; i < the_size; i++) {
-        stringTokens.push_back("astring");
-    }
-    for (size_t i = 0; i < the_size; i++) {
-        numberTokens.push_back(ecf::convert_to<std::string>(i));
-        expectedNumberRes.push_back(i);
-    }
-
-    std::vector<std::string> stringRes;
-    stringTokens.reserve(stringTokens.size());
-    std::vector<int> numberRes;
-    numberRes.reserve(expectedNumberRes.size());
-
-    {
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (size_t i = 0; i < stringTokens.size(); i++) {
-            method1(stringTokens[i], stringRes, numberRes);
-        }
-        for (size_t i = 0; i < numberTokens.size(); i++) {
-            method1(numberTokens[i], stringRes, numberRes);
-        }
-        cout << "Time for method1  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes, " method 1 wrong");
-        BOOST_CHECK_MESSAGE(stringTokens == stringRes, "method 1 wrong");
-        numberRes.clear();
-        stringRes.clear();
-    }
-
-    {
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (size_t i = 0; i < stringTokens.size(); i++) {
-            methodX(stringTokens[i], stringRes, numberRes);
-        }
-        for (size_t i = 0; i < numberTokens.size(); i++) {
-            methodX(numberTokens[i], stringRes, numberRes);
-        }
-        cout << "Time for methodX  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes, " method X wrong");
-        BOOST_CHECK_MESSAGE(stringTokens == stringRes, "method X wrong");
-        numberRes.clear();
-        stringRes.clear();
-    }
-
-    {
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (size_t i = 0; i < stringTokens.size(); i++) {
-            method2(stringTokens[i], stringRes, numberRes);
-        }
-        for (size_t i = 0; i < numberTokens.size(); i++) {
-            method2(numberTokens[i], stringRes, numberRes);
-        }
-        cout << "Time for method2  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes, "method 2 wrong");
-        BOOST_CHECK_MESSAGE(stringTokens == stringRes, "method 2 wrong");
-        numberRes.clear();
-        stringRes.clear();
-    }
-
-    {
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (size_t i = 0; i < stringTokens.size(); i++) {
-            method3(stringTokens[i], stringRes, numberRes);
-        }
-        for (size_t i = 0; i < numberTokens.size(); i++) {
-            method3(numberTokens[i], stringRes, numberRes);
-        }
-        cout << "Time for method3  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes,
-                            " method3 wrong numberRes.size()=" << numberRes.size()
-                                                               << " expected size = " << expectedNumberRes.size());
-        BOOST_CHECK_MESSAGE(stringTokens == stringRes,
-                            " method3 wrong stringRes.size()=" << stringRes.size()
-                                                               << " expected size = " << stringTokens.size());
-        numberRes.clear();
-        stringRes.clear();
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_int_to_str_perf, *boost::unit_test::disabled()) {
-    cout << "ACore:: ...test_int_to_str_perf\n";
-
-    // Lexical_cast is approx twice as fast as using streams
-    // time for ostream = 0.97
-    // time for lexical_cast = 0.45
-
-    const int the_size = 1000000;
-    {
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < the_size; i++) {
-            std::ostringstream st;
-            st << i;
-            std::string s = st.str();
-        }
-        cout << "Time for int to string using ostringstream  elapsed time = "
-             << timer.format(3, Str::cpu_timer_format()) << "\n";
-    }
-
-    {
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < the_size; i++) {
-            std::string s = ecf::convert_to<std::string>(i);
-        }
-        cout << "Time for int to string using ecf::convert_to elapsed time = "
-             << timer.format(3, Str::cpu_timer_format()) << "\n";
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_str_valid_name) {
-    cout << "ACore:: ...test_str_valid_name\n";
-
-    std::vector<std::string> valid;
-    valid.emplace_back("a");
-    valid.emplace_back("a122345");
-    valid.emplace_back("_a122345");
-    valid.emplace_back("_");
-    valid.emplace_back("0");
-    valid.emplace_back("1");
-    valid.emplace_back("2");
-    valid.emplace_back("3");
-    valid.emplace_back("4");
-    valid.emplace_back("5");
-    valid.emplace_back("6");
-    valid.emplace_back("7");
-    valid.emplace_back("8");
-    valid.emplace_back("9");
-    valid.emplace_back("11");
-    valid.emplace_back("111");
-    for (const auto& i : valid) {
-        std::string msg;
-        BOOST_CHECK_MESSAGE(Str::valid_name(i, msg), "Expected " << i << " to be valid");
-        BOOST_CHECK_MESSAGE(Str::valid_name(i), "Expected " << i << " to be valid");
-    }
-
-    BOOST_CHECK_MESSAGE(!Str::valid_name(""), "Expected empty string to be in-valid");
-    BOOST_CHECK_MESSAGE(!Str::valid_name("."), "Expected '.' string to be in-valid");
-    std::vector<std::string> invalid;
-    invalid.emplace_back("?");
-    invalid.emplace_back("!");
-    invalid.emplace_back("\"");
-    invalid.emplace_back("$");
-    invalid.emplace_back("%");
-    invalid.emplace_back("^");
-    invalid.emplace_back("*");
-    invalid.emplace_back("(");
-    invalid.emplace_back(")");
-    invalid.emplace_back("-");
-    invalid.emplace_back("+");
-    invalid.emplace_back(":");
-    invalid.emplace_back(";");
-    invalid.emplace_back("@");
-    invalid.emplace_back("~");
-    invalid.emplace_back("<");
-    invalid.emplace_back(">");
-    invalid.emplace_back("!");
-    for (const auto& i : invalid) {
-        std::string msg;
-        BOOST_CHECK_MESSAGE(!Str::valid_name(i, msg), "Expected " << i << " to be in-valid");
-        BOOST_CHECK_MESSAGE(!Str::valid_name(i), "Expected " << i << " to be in-valid");
-
-        std::string s = "a" + i;
-        BOOST_CHECK_MESSAGE(!Str::valid_name(s, msg), "Expected " << s << " to be in-valid");
-        BOOST_CHECK_MESSAGE(!Str::valid_name(s), "Expected " << s << " to be in-valid");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestStringSplitPerf.cpp 5.13.0-1/ACore/test/TestStringSplitPerf.cpp
--- 5.12.4-1/ACore/test/TestStringSplitPerf.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestStringSplitPerf.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,481 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-// **************************************************************************************************************
-// IMPORTANT: Str:split uses StringSplitter:
-//            to run these tests, please switch off Str.cpp::USE_STRINGSPLITTER
-// **************************************************************************************************************
-// #define STRING_SPLIT_IMPLEMENTATIONS_PERF_CHECK_ 1;
-
-#ifdef STRING_SPLIT_IMPLEMENTATIONS_PERF_CHECK_
-    #include <fstream>
-    #include <iostream>
-
-    #include <boost/timer/timer.hpp>
-
-    #include "ecflow/core/File.hpp"
-    #include "ecflow/core/Str.hpp"
-    #include "ecflow/core/StringSplitter.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-#endif
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_StringSplitPerf)
-
-#ifdef STRING_SPLIT_IMPLEMENTATIONS_PERF_CHECK_
-
-std::vector<std::string> split_using_getline(const std::string& s, char delimiter) {
-    std::vector<std::string> tokens;
-    std::string token;
-    std::istringstream tokenStream(s);
-    while (std::getline(tokenStream, token, delimiter)) {
-        tokens.push_back(token);
-    }
-    return tokens;
-}
-
-BOOST_AUTO_TEST_CASE(test_str_split_perf) {
-    cout << "ACore:: ...test_str_split_perf\n";
-    //   Time for istreamstream 1000000 times = 2.59404
-    //   Time for std::getline 1000000 times = 1.83148
-    //   Time for boost::split 1000000 times = 1.18149
-    //   Time for Str::split_orig 1000000 times = 1.3015
-    //   Time for make_split_iterator::split 1000000 times = 4.1821
-    //   Time for std::string_view 1000000 times =  0.975816
-    //   Time for std::string_view(2) 1000000 times = 0.780003
-
-    std::string line = "This is a long string that is going to be used to test the performance of splitting with "
-                       "different Implementations the fastest times wins ";
-    size_t times     = 1000000;
-    cout << " This test will split a line " << times << " times: '" << line << "'\n";
-
-    string reconstructed;
-    reconstructed.reserve(line.size());
-
-    { // istreamstream    https://www.fluentcpp.com/2017/04/21/how-to-split-a-string-in-c/
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (size_t i = 0; i < times; i++) {
-            std::istringstream iss(line);
-            std::vector<std::string> result((std::istream_iterator<std::string>(iss)),
-                                            std::istream_iterator<std::string>());
-            reconstructed.clear();
-            for (const std::string& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for istreamstream " << times
-             << "                 times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
-    }
-
-    { // split using std::get_line    https://www.fluentcpp.com/2017/04/21/how-to-split-a-string-in-c/
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (size_t i = 0; i < times; i++) {
-            std::vector<std::string> result = split_using_getline(line, ' ');
-            reconstructed.clear();
-            for (const std::string& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for std::getline " << times
-             << "                  times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
-    }
-
-    { // BOOST SPLIT
-        std::vector<std::string> result;
-        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        for (size_t i = 0; i < times; i++) {
-            result.clear();
-            // boost::algorithm::split(result, line, boost::is_any_of(" \t"),boost::algorithm::token_compress_on);
-            boost::split(result, line, [](char c) { return c == ' '; });
-
-            reconstructed.clear();
-            for (const std::string& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for boost::split " << times
-             << "                  times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        // BOOST_CHECK_MESSAGE(line==reconstructed,"\n'" << line << "'\n'" << reconstructed << "'"); // add extra space
-    }
-
-    { // Str::split_orig
-        std::vector<std::string> result;
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            result.clear();
-            Str::split_orig(line, result);
-
-            reconstructed.clear();
-            for (const std::string& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for Str::split_orig " << times
-             << "               times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
-    }
-    { // Str::split_orig1
-        std::vector<std::string> result;
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            result.clear();
-            Str::split_orig1(line, result);
-
-            reconstructed.clear();
-            for (const std::string& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for Str::split_orig1 " << times
-             << "              times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
-    }
-    { // Str::split_using_string_view2
-        std::vector<std::string> result;
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            result.clear();
-            Str::split_using_string_view2(line, result);
-
-            reconstructed.clear();
-            for (const std::string& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for Str::split_using_string_view2 " << times
-             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
-    }
-    { // Str::split_using_string_view
-        std::vector<std::string> result;
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            result.clear();
-            Str::split_using_string_view(line, result);
-
-            reconstructed.clear();
-            for (const std::string& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for Str::split_using_string_view " << times
-             << "  times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
-    }
-
-    typedef boost::split_iterator<string::const_iterator> split_iter_t;
-    { // boost::make_split_iterator
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-
-            split_iter_t tokens = Str::make_split_iterator(line);
-
-            std::stringstream ss;
-            for (; !tokens.eof(); ++tokens) {
-                boost::iterator_range<string::const_iterator> range = *tokens;
-                ss << range << " ";
-            }
-            reconstructed = ss.str();
-        }
-        cout << " Time for make_split_iterator::split " << times
-             << "    times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        // BOOST_CHECK_MESSAGE(line==reconstructed,"\n'" << line << "'\n'" << reconstructed << "'");
-    }
-
-    { // std::string_view
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            StringSplitter string_splitter(line);
-
-            reconstructed.clear();
-            while (!string_splitter.finished()) {
-                std::string_view sv = string_splitter.next();
-                reconstructed += std::string(sv.begin(), sv.end());
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for std::string_view " << times
-             << "            times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
-    }
-
-    { // std::string_view
-        boost::timer::cpu_timer timer;
-        std::vector<std::string_view> result;
-        for (size_t i = 0; i < times; i++) {
-
-            result.clear();
-            StringSplitter::split2(line, result);
-
-            reconstructed.clear();
-            for (const auto& s : result) {
-                reconstructed += std::string(s.begin(), s.end());
-                reconstructed += " ";
-            }
-        }
-        cout << " Time for std::string_view(2) " << times
-             << "         times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_str_split_perf_with_file) {
-    cout << "ACore:: ...test_str_split_perf_with_file\n";
-    //   Time for istreamstream 2001774 times = 1.81123
-    //   Time for std::getline 2001774 times = 2.89138
-    //   Time for boost::split 2001774 times = 1.98556
-    //   Time for Str::split_orig 2001774 times = 0.947959
-    //   Time for boost::make_split_iterator 2001774 times = 3.921
-    //   Time for std::string_view 2001774 times = 0.765805
-    //   Time for std::string_view(2) 2001774 times = 0.752472
-
-    // Now test performance of splitting with a big DEFS file
-    char* ecf_test_defs_dir = getenv("ECF_TEST_DEFS_DIR");
-    if (!ecf_test_defs_dir) {
-        std::cout << "Ingoring test, since directory defined by environment variable(ECF_TEST_DEFS_DIR) is missing";
-        return;
-    }
-    std::string path = std::string(ecf_test_defs_dir) + "/vsms2.31415.def";
-    if (!fs::exists(path)) {
-        std::cout << "Ingoring test, since file defined by environment variable(ECF_TEST_DEFS_DIR) " << path
-                  << " is missing";
-        return;
-    }
-
-    std::vector<std::string> file_contents;
-    if (File::splitFileIntoLines(path, file_contents, true /* ignore empty lines*/)) {
-
-        cout << " This test will split each line in file " << path << "\n";
-
-        std::vector<std::string> result;
-        result.reserve(300);
-
-        auto reconstruct_line = [](const std::vector<std::string>& result) {
-            string reconstructed;
-            for (const auto& s : result) {
-                reconstructed += s;
-                reconstructed += " ";
-            }
-        };
-
-        { // istreamstream
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-                std::istringstream iss(file_contents[i]);
-                std::vector<std::string> result1((std::istream_iterator<std::string>(iss)),
-                                                 std::istream_iterator<std::string>());
-                reconstruct_line(result1);
-            }
-            cout << " Time for istreamstream " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-        { // std::getline
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-                reconstruct_line(split_using_getline(file_contents[i], ' '));
-            }
-            cout << " Time for std::getline " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-        {
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-                result.clear();
-                // boost::algorithm::split(result,file_contents[i], boost::is_any_of("
-                // \t"),boost::algorithm::token_compress_on);
-                boost::split(result, file_contents[i], [](char c) { return c == ' '; });
-
-                reconstruct_line(result);
-            }
-            cout << " Time for boost::split " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-        {
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-                result.clear();
-                Str::split_orig(file_contents[i], result);
-
-                reconstruct_line(result);
-            }
-            cout << " Time for Str::split_orig " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-        {
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-                result.clear();
-                Str::split_orig1(file_contents[i], result);
-
-                reconstruct_line(result);
-            }
-            cout << " Time for Str::split_orig1 " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-        {
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-                result.clear();
-                Str::split_using_string_view(file_contents[i], result);
-
-                reconstruct_line(result);
-            }
-            cout << " Time for Str::split_using_string_view " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-        {
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-                result.clear();
-                Str::split_using_string_view2(file_contents[i], result);
-
-                reconstruct_line(result);
-            }
-            cout << " Time for Str::split_using_string_view2 " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-        {
-            typedef boost::split_iterator<string::const_iterator> split_iter_t;
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-
-                std::stringstream ss;
-                split_iter_t tokens = Str::make_split_iterator(file_contents[i]);
-
-                for (; !tokens.eof(); ++tokens) {
-                    boost::iterator_range<string::const_iterator> range = *tokens;
-                    ss << range << " ";
-                }
-                string reconstructed = ss.str();
-            }
-            cout << " Time for boost::make_split_iterator " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-
-        {
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-
-                StringSplitter string_splitter(file_contents[i]);
-
-                string reconstructed;
-                while (!string_splitter.finished()) {
-                    std::string_view sv = string_splitter.next();
-                    reconstructed += std::string(sv.begin(), sv.end());
-                    reconstructed += " ";
-                }
-            }
-            cout << " Time for std::string_view " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-
-        {
-            std::vector<std::string_view> result1;
-            boost::timer::cpu_timer timer;
-            for (size_t i = 0; i < file_contents.size(); i++) {
-
-                StringSplitter::split2(file_contents[i], result1);
-
-                string reconstructed;
-                for (const auto& s : result1) {
-                    reconstructed += std::string(s.begin(), s.end());
-                    reconstructed += " ";
-                }
-                result1.clear();
-            }
-            cout << " Time std::string_view(2) " << file_contents.size()
-                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_str_get_token_perf) {
-    cout << "ACore:: ...test_str_get_token_perf\n";
-
-    std::vector<std::string> result;
-    std::string line = "This is a long string that is going to be used to test the performance of splitting with "
-                       "different Implementations the fastest times wins ";
-    size_t times     = 250000;
-    cout << " This test will split a line " << times << " times: '" << line << "'\n";
-
-    Str::split_using_string_view(line, result);
-    size_t result_size = result.size();
-    std::string token;
-
-    {
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            for (size_t r = 0; r < result_size; r++) {
-                token.clear();
-                (void)StringSplitter::get_token(line, r, token);
-            }
-        }
-        cout << " Time for StringSplitter::get_token " << times
-             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
-    }
-    {
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            for (size_t r = 0; r < result_size; r++) {
-                token.clear();
-                (void)Str::get_token(line, r, token);
-            }
-        }
-        cout << " Time for Str::get_token            " << times
-             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
-    }
-    {
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            for (size_t r = 0; r < result_size; r++) {
-                token.clear();
-                (void)Str::get_token2(line, r, token);
-            }
-        }
-        cout << " Time for Str::get_token2           " << times
-             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
-    }
-    {
-        boost::timer::cpu_timer timer;
-        for (size_t i = 0; i < times; i++) {
-            for (size_t r = 0; r < result_size; r++) {
-                token.clear();
-                (void)Str::get_token3(line, r, token);
-            }
-        }
-        cout << " Time for Str::get_token3           " << times
-             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
-        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
-    }
-}
-
-#endif
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestStringSplitter.cpp 5.13.0-1/ACore/test/TestStringSplitter.cpp
--- 5.12.4-1/ACore/test/TestStringSplitter.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestStringSplitter.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,319 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/StringSplitter.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_StringSplitter)
-
-static void
-check(const std::string& line, const StringSplitter& string_splitter, const std::vector<std::string>& expected) {
-    std::vector<std::string> result;
-    while (!string_splitter.finished()) {
-        std::string_view ref = string_splitter.next();
-        // std::cout << "ref:'" << ref << "'\n";
-        result.emplace_back(ref.begin(), ref.end());
-    }
-    BOOST_CHECK_MESSAGE(result.size() == expected.size(),
-                        "expected size " << expected.size() << " but found " << result.size() << " for '" << line
-                                         << "'");
-    BOOST_CHECK_MESSAGE(result == expected, "failed for '" << line << "'");
-    if (result != expected) {
-        cout << "Line    :'" << line << "'\n";
-        cout << "Actual  :";
-        for (const string& t : result) {
-            cout << "'" << t << "'";
-        }
-        cout << "\n";
-        cout << "Expected:";
-        for (const string& t : expected) {
-            cout << "'" << t << "'";
-        }
-        cout << "\n";
-    }
-}
-
-static void check(const std::string& line, const std::vector<std::string>& expected, const char* delims = " \t") {
-    std::vector<std::string> result;
-    std::vector<std::string_view> result2;
-    StringSplitter::split2(line, result2, delims);
-    std::transform(result2.begin(), result2.end(), std::back_inserter(result), [](const std::string_view& sv) {
-        return std::string(sv.begin(), sv.end());
-    });
-
-    BOOST_CHECK_MESSAGE(result.size() == expected.size(),
-                        "expected size " << expected.size() << " but found " << result.size() << " for '" << line
-                                         << "'");
-    BOOST_CHECK_MESSAGE(result == expected, "failed for '" << line << "'");
-    if (result != expected) {
-        cout << "Line    :'" << line << "'\n";
-        cout << "Actual  :";
-        for (const string& t : result) {
-            cout << "'" << t << "'";
-        }
-        cout << "\n";
-        cout << "Expected:";
-        for (const string& t : expected) {
-            cout << "'" << t << "'";
-        }
-        cout << "\n";
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_StringSplitter) {
-    cout << "ACore:: ...test_StringSplitter\n";
-
-    std::string line = "This is a string please split me";
-    std::vector<std::string> expected;
-
-    expected.emplace_back("This");
-    expected.emplace_back("is");
-    expected.emplace_back("a");
-    expected.emplace_back("string");
-    expected.emplace_back("please");
-    expected.emplace_back("split");
-    expected.emplace_back("me");
-    StringSplitter string_splitter(line);
-    check(line, string_splitter, expected);
-    check(line, expected);
-
-    // reset
-    string_splitter.reset();
-    check(line, string_splitter, expected);
-}
-
-BOOST_AUTO_TEST_CASE(test_str_split_StringSplitter) {
-    cout << "ACore:: ...test_str_split_StringSplitter\n";
-
-    // If end is delimeter, then preserved as empty token
-
-    std::string line = "This is a string";
-    std::vector<std::string> expected;
-
-    expected.emplace_back("This");
-    expected.emplace_back("is");
-    expected.emplace_back("a");
-    expected.emplace_back("string");
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter("This is a string"), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = "";
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter(""), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = "  ";
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter("  "), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = "a";
-    expected.emplace_back("a");
-    check(line, StringSplitter(line), expected);
-    check(line, expected);
-
-    // Some implementation fail this test
-    expected.clear();
-    line = "\n";
-    expected.emplace_back("\n");
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter("\n"), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = "a ";
-    expected.emplace_back("a");
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter("a "), expected);
-    check(line, expected);
-
-    expected.clear();
-    expected.emplace_back("a");
-    line = " a";
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter(" a"), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = "  a  "; // check sequential tabs
-    expected.emplace_back("a");
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter("  a  "), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = " a ";
-    expected.emplace_back("a");
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter(" a "), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = "        a     b     c       d        ";
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    expected.emplace_back("d");
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter("        a     b     c       d        "), expected);
-    check(line, expected);
-
-    expected.clear();
-    line = " - !   $ % ^  & * ( ) - + ? ";
-    expected.emplace_back("-");
-    expected.emplace_back("!");
-    expected.emplace_back("$");
-    expected.emplace_back("%");
-    expected.emplace_back("^");
-    expected.emplace_back("&");
-    expected.emplace_back("*");
-    expected.emplace_back("(");
-    expected.emplace_back(")");
-    expected.emplace_back("-");
-    expected.emplace_back("+");
-    expected.emplace_back("?");
-    check(line, StringSplitter(line), expected);
-    check(line, StringSplitter(" - !   $ % ^  & * ( ) - + ? "), expected);
-    check(line, expected);
-
-    // Check tabs
-    expected.clear();
-    line = "     verify complete:8                      # 4 sundays in october hence expect 8 task completions";
-    expected.emplace_back("verify");
-    expected.emplace_back("complete:8");
-    expected.emplace_back("#");
-    expected.emplace_back("4");
-    expected.emplace_back("sundays");
-    expected.emplace_back("in");
-    expected.emplace_back("october");
-    expected.emplace_back("hence");
-    expected.emplace_back("expect");
-    expected.emplace_back("8");
-    expected.emplace_back("task");
-    expected.emplace_back("completions");
-    check(line, StringSplitter(line), expected);
-    check(line,
-          StringSplitter(
-              "     verify complete:8                      # 4 sundays in october hence expect 8 task completions"),
-          expected);
-    check(line, expected);
-
-    // Check paths
-    expected.clear();
-    expected.emplace_back("a");
-    line = "/a";
-    check(line, StringSplitter(line, "/"), expected);
-    check(line, StringSplitter("/a", "/"), expected);
-    check(line, expected, "/");
-
-    expected.clear();
-    line = "";
-    check(line, StringSplitter(line, "/"), expected);
-    check(line, StringSplitter("", "/"), expected);
-    check(line, expected, "/");
-
-    expected.clear();
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    expected.emplace_back("c");
-    expected.emplace_back("e");
-    line = "/a/b/c/c//e";
-    check(line, StringSplitter(line, "/"), expected);
-    check(line, expected, "/");
-
-    expected.clear();
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    expected.emplace_back("c");
-    expected.emplace_back("e");
-    line = "///a/b/c/c//e";
-    check(line, StringSplitter(line, "/"), expected);
-    check(line, StringSplitter("///a/b/c/c//e", "/"), expected);
-    check(line, expected, "/");
-
-    expected.clear();
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    expected.emplace_back("c");
-    expected.emplace_back("e");
-    line = "//a/b/c/c//e/";
-    check(line, StringSplitter(line, "/"), expected);
-    check(line, StringSplitter("//a/b/c/c//e/", "/"), expected);
-    check(line, expected, "/");
-
-    expected.clear();
-    expected.emplace_back("a ");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    expected.emplace_back("c e");
-    line = "/a /b/c/c e";
-    check(line, StringSplitter(line, "/"), expected);
-    check(line, StringSplitter("/a /b/c/c e", "/"), expected);
-    check(line, expected, "/");
-}
-
-static void test_get_token(const std::string& line, const char* delims = " \t") {
-    std::vector<std::string> tokens;
-    Str::split_orig(line, tokens, delims);
-    for (size_t i = 0; i < tokens.size(); i++) {
-        std::string token;
-        BOOST_CHECK_MESSAGE(StringSplitter::get_token(line, i, token, delims) && token == tokens[i],
-                            "Expected to find " << tokens[i] << " but found " << token);
-    }
-    std::string token;
-    BOOST_CHECK_MESSAGE(!StringSplitter::get_token(line, tokens.size(), token), "Expected to fail");
-}
-
-BOOST_AUTO_TEST_CASE(test_StringSplitter_get_token) {
-    cout << "ACore:: ...test_StringSplitter_get_token \n";
-
-    std::vector<std::string> test_data = {"This is a string",
-                                          "a",
-                                          " a",
-                                          "a ",
-                                          " a ",
-                                          "        a     b     c       d        ",
-                                          " - !   $ % ^  & * ( ) - + ? ",
-                                          "\n"};
-
-    std::vector<std::string> test_data1 = {
-        "/a",
-        "///a/b/c/c//e",
-        "//a/b/c/c//e/",
-    };
-
-    for (const auto& s : test_data) {
-        test_get_token(s);
-    }
-    for (const auto& s : test_data1) {
-        test_get_token(s, "/");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestTimeSeries.cpp 5.13.0-1/ACore/test/TestTimeSeries.cpp
--- 5.12.4-1/ACore/test/TestTimeSeries.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestTimeSeries.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,782 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/date_time/posix_time/time_formatters.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-using namespace boost;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_TimeSeries)
-
-BOOST_AUTO_TEST_CASE(test_default_boost_time_duration) {
-    cout << "ACore:: ...test_default_boost_time_duration\n";
-
-    boost::posix_time::time_duration td;
-    BOOST_CHECK_MESSAGE(td.is_special() == false,
-                        "Default constructed boost::posix_time::time_duration, should not be special");
-    BOOST_CHECK_MESSAGE(td.hours() == 0, "Expected 0 for hours");
-    BOOST_CHECK_MESSAGE(td.minutes() == 0, "Expected 0 for minutes");
-    BOOST_CHECK_MESSAGE(td.seconds() == 0, "Expected 0 for seconds ");
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_min_max_time_slots) {
-    cout << "ACore:: ...test_time_series_min_max_time_slots\n";
-
-    TimeSlot the_min;
-    TimeSlot the_max;
-
-    TimeSeries a(9, 0, true);
-    a.min_max_time_slots(the_min, the_max);
-    BOOST_CHECK_MESSAGE(the_min == TimeSlot(9, 0), "Max min time slot failed");
-    BOOST_CHECK_MESSAGE(the_max == TimeSlot(9, 0), "Max min time slot failed");
-
-    TimeSeries b(TimeSlot(10, 12), false);
-    b.min_max_time_slots(the_min, the_max);
-    BOOST_CHECK_MESSAGE(the_min == TimeSlot(9, 0), "Max min time slot failed");
-    BOOST_CHECK_MESSAGE(the_max == TimeSlot(10, 12), "Max min time slot failed");
-
-    TimeSeries c(TimeSlot(0, 10), TimeSlot(10, 13), TimeSlot(0, 1));
-    c.min_max_time_slots(the_min, the_max);
-    BOOST_CHECK_MESSAGE(the_min == TimeSlot(0, 10), "Max min time slot failed");
-    BOOST_CHECK_MESSAGE(the_max == TimeSlot(10, 13), "Max min time slot failed");
-
-    TimeSeries x;
-    x.min_max_time_slots(the_min, the_max);
-    BOOST_CHECK_MESSAGE(the_min == TimeSlot(), "Max min time slot failed");
-    BOOST_CHECK_MESSAGE(the_max == TimeSlot(10, 13), "Max min time slot failed");
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_constrcution) {
-    cout << "ACore:: ...test_time_series_constrcution\n";
-
-    {
-        TimeSeries x;
-        TimeSeries y;
-        BOOST_CHECK_MESSAGE(x == y, "Equality operator expected to succeed");
-
-        TimeSeries a(10, 12, true);
-        TimeSeries b(10, 12, true);
-        BOOST_CHECK_MESSAGE(a == b, "Equality operator expected to succeed");
-
-        TimeSeries c(10, 12, false);
-        TimeSeries d(10, 12, false);
-        BOOST_CHECK_MESSAGE(c == d, "Equality operator expected to succeed");
-
-        TimeSeries e(TimeSlot(14, 59), false);
-        TimeSeries f(TimeSlot(14, 59), false);
-        BOOST_CHECK_MESSAGE(e == f, "Equality operator expected to succeed");
-
-        TimeSeries g(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1));
-        TimeSeries h(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1));
-        BOOST_CHECK_MESSAGE(g == h, "Equality operator expected to succeed");
-    }
-    {
-        TimeSeries a(10, 12, false);
-        TimeSeries b(10, 12, true);
-        BOOST_CHECK_MESSAGE(a != b, "Equality operator expected to fail");
-
-        TimeSeries c(10, 13, false);
-        TimeSeries d(10, 12, false);
-        BOOST_CHECK_MESSAGE(c != d, "Equality operator expected to fail");
-
-        TimeSeries e(TimeSlot(14, 59), false);
-        TimeSeries f(TimeSlot(14, 10), false);
-        BOOST_CHECK_MESSAGE(e != f, "Equality operator expected to fail");
-
-        TimeSeries g(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1), true);
-        TimeSeries h(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1), false);
-        BOOST_CHECK_MESSAGE(g != h, "Equality operator expected to fail");
-    }
-
-    /// Basic test for time series of getters and setters
-    TimeSeries timeSeries(TimeSlot(0, 1), TimeSlot(0, 4), TimeSlot(0, 1));
-    BOOST_CHECK_MESSAGE(timeSeries.hasIncrement(), "expected increment");
-    std::string errMsg;
-    BOOST_CHECK_MESSAGE(timeSeries.checkInvariants(errMsg), errMsg);
-
-    TimeSeries another = timeSeries;
-    BOOST_CHECK_MESSAGE(another == timeSeries, "copy constructor failed for TimeSeries ");
-    BOOST_CHECK_MESSAGE(another.checkInvariants(errMsg), errMsg);
-    BOOST_CHECK_MESSAGE(timeSeries.checkInvariants(errMsg), errMsg);
-
-    TimeSeries timeSeries2(TimeSlot(0, 1), TimeSlot(0, 4), TimeSlot(0, 1));
-    BOOST_CHECK_MESSAGE(timeSeries2.checkInvariants(errMsg), errMsg);
-    another = timeSeries2;
-    BOOST_CHECK_MESSAGE(another == timeSeries2, "assignment operator failed for TimeSeries ");
-    BOOST_CHECK_MESSAGE(another.checkInvariants(errMsg), errMsg);
-
-    TimeSeries timeSeries3(TimeSlot(0, 1));
-    BOOST_CHECK_MESSAGE(timeSeries3.checkInvariants(errMsg), errMsg);
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series) {
-    cout << "ACore:: ...test_time_series\n";
-
-    /// Basic test for time series of getters and setters
-    TimeSeries timeSeries(TimeSlot(0, 1), TimeSlot(0, 4), TimeSlot(0, 1));
-    BOOST_CHECK_MESSAGE(timeSeries.hasIncrement(), "expected increment");
-
-    std::string expected = "00:01:00";
-    std::string actual   = to_simple_string(timeSeries.start().duration());
-    BOOST_CHECK_MESSAGE(expected == actual, " expected " << expected << " but found " << actual);
-
-    expected = "00:04:00";
-    actual   = to_simple_string(timeSeries.finish().duration());
-    BOOST_CHECK_MESSAGE(expected == actual, " expected " << expected << " but found " << actual);
-
-    expected = "00:01:00";
-    actual   = to_simple_string(timeSeries.incr().duration());
-    BOOST_CHECK_MESSAGE(expected == actual, " expected " << expected << " but found " << actual);
-
-    TimeSeries timeSeries2(TimeSlot(0, 1));
-    BOOST_CHECK_MESSAGE(!timeSeries2.hasIncrement(), "Not expecting time series");
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_increment_real) {
-    cout << "ACore:: ...test_time_series_increment_real\n";
-
-    // Test time series with  a calendar, we update calendar then
-    // test time series isFree(), and checkForRequeue
-    Calendar c;
-    c.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series. Need to sync hour with suite time
-    // at hour 1, suite time should also be 01:00, for test to work
-    //
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr    1:00
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), true /* relative */);
-    TimeSeries timeSeries2(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), true /* relative */);
-    TimeSeries timeSeries3(TimeSlot(15, 0), true /* relative */);
-
-    TimeSlot t1_min, t1_max, t2_min, t2_max, t3_min, t3_max;
-    timeSeries.min_max_time_slots(t1_min, t1_max);
-    timeSeries2.min_max_time_slots(t2_min, t2_max);
-    timeSeries3.min_max_time_slots(t3_min, t3_max);
-    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(20, 0), "Not as expected");
-    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(11, 0) && t2_max == TimeSlot(15, 0), "Not as expected");
-    BOOST_CHECK_MESSAGE(t3_min == TimeSlot(15, 0) && t3_max == TimeSlot(15, 0), "Not as expected");
-
-    // Follow normal process
-    timeSeries.reset(c);
-    timeSeries2.reset(c);
-    timeSeries3.reset(c);
-
-    bool cmd_context = true;
-    for (int hour = 1; hour < 24; hour++) {
-        // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
-        c.update(time_duration(hours(1)));
-        timeSeries.calendarChanged(c);
-        timeSeries2.calendarChanged(c);
-        timeSeries3.calendarChanged(c);
-
-        //		cerr << "hour = " << hour << " calendar_duration " << to_simple_string(timeSeries.duration(c))
-        //		    << " timeSeries=" << timeSeries.toString() << " timeSeries2=" << timeSeries2.toString() << "
-        // timeSeries3=" << timeSeries3.toString() << "\n";
-        if (hour < timeSeries.start().hour()) {
-            BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(c, t1_min, t1_max, cmd_context),
-                                " Time series " << timeSeries.toString() << " checkForRequeue should pass at "
-                                                << c.suite_time_str());
-            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(c, t1_min, t1_max),
-                                " Time series " << timeSeries.toString() << " checkForRequeue should fail at "
-                                                << c.suite_time_str());
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(c),
-                                "Time series " << timeSeries.toString() << " should NOT be free at hour " << hour);
-        }
-        else if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(c),
-                                "Time series " << timeSeries.toString() << " should be free at hour " << hour);
-
-            /// At the last hour checkForRequeue should return false; This ensures that value will
-            /// not get incremented and so, should leave node in the complete state.
-            if (hour < timeSeries.finish().hour()) {
-                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(c, t1_min, t1_max),
-                                    "Time series " << timeSeries.toString()
-                                                   << " checkForRequeue should be free at hour " << hour);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(c, t1_min, t1_max),
-                                    "Time series " << timeSeries.toString()
-                                                   << "checkForRequeue should Not free at hour " << hour);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(c),
-                                "Time series " << timeSeries.toString() << " should NOT be free at hour " << hour);
-            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(c, t1_min, t1_max),
-                                " Time series " << timeSeries.toString() << " should fail at " << hour);
-        }
-
-        if (hour < timeSeries2.start().hour()) {
-            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(c, t1_min, t1_max),
-                                " Time series " << timeSeries2.toString() << "checkForRequeue should pass at " << hour);
-            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(c),
-                                "Time series " << timeSeries2.toString() << " should NOT be free at hour " << hour);
-        }
-        else if (hour >= timeSeries2.start().hour() && hour <= timeSeries2.finish().hour()) {
-            BOOST_CHECK_MESSAGE(timeSeries2.isFree(c),
-                                "Time series " << timeSeries2.toString() << " should be free at hour " << hour);
-
-            /// At the last hour checkForRequeue should return false;
-            if (hour < timeSeries2.finish().hour()) {
-                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(c, t2_min, t2_max),
-                                    "Time series " << timeSeries2.toString()
-                                                   << " checkForRequeue should be free at hour " << hour);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(c, t2_min, t2_max),
-                                    "Time series " << timeSeries2.toString()
-                                                   << "checkForRequeue should Not free at hour " << hour);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(c),
-                                "Time series " << timeSeries2.toString() << " not be free at hour " << hour);
-            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(c, t2_min, t2_max),
-                                " Time series " << timeSeries2.toString() << " should fail at " << hour);
-        }
-
-        if (hour == timeSeries3.start().hour()) {
-            BOOST_CHECK_MESSAGE(timeSeries3.isFree(c),
-                                "Time series " << timeSeries3.toString() << " should be free at hour " << hour);
-        }
-        else if (hour < timeSeries3.start().hour()) {
-            BOOST_CHECK_MESSAGE(!timeSeries3.isFree(c),
-                                "Time series " << timeSeries3.toString() << " isFree should fail at hour " << hour);
-        }
-        else if (hour > timeSeries3.start().hour()) {
-            BOOST_CHECK_MESSAGE(!timeSeries3.isFree(c),
-                                "Time series " << timeSeries3.toString() << " is Free should fail at hour " << hour);
-        }
-        BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(c, t3_min, t3_max),
-                            " Time series " << timeSeries3.toString() << " checkForRequeue should fail at " << hour);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_requeueable_and_compute_next_time_slot) {
-    cout << "ACore:: ...test_time_series_requeueable_and_compute_next_time_slot\n";
-
-    // Test time series with  a calendar, we update calendar then
-    // test time series requeueable(), and compute_next_time_slot
-    // This are used with the WHY command
-    Calendar c;
-    c.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series. Need to sync hour with suite time
-    // at hour 1, suite time should also be 01:00, for test to work
-    //
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr    1:00
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), true /* relative */);
-    TimeSeries timeSeries2(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), true /* relative */);
-    TimeSeries timeSeries3(TimeSlot(15, 0), true /* relative */);
-
-    for (int hour = 1; hour < 24; hour++) {
-        // Update calendar every hour, then see we can match time series,
-        c.update(time_duration(hours(1)));
-        timeSeries.calendarChanged(c);
-        timeSeries2.calendarChanged(c);
-        timeSeries3.calendarChanged(c);
-
-        //    cerr << "hour = " << hour << " calendar_duration " << to_simple_string(timeSeries.duration(c))
-        //        << " timeSeries=" << timeSeries.toString() << " timeSeries2=" << timeSeries2.toString() << "
-        //        timeSeries3=" << timeSeries3.toString() << "\n";
-        if (hour < timeSeries.start().hour()) {
-            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
-            TimeSlot expected(10, 0);
-            BOOST_CHECK_MESSAGE(next_time_slot == expected,
-                                " Time series " << timeSeries.toString() << " at " << hour
-                                                << " expected next time slot at " << expected.toString()
-                                                << " but found " << next_time_slot.toString());
-            BOOST_CHECK_MESSAGE(timeSeries.requeueable(c),
-                                "Time series " << timeSeries.toString() << " should be requeueable at hour " << hour);
-        }
-        else if (hour == timeSeries.start().hour()) {
-            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
-            TimeSlot expected(11, 0);
-            BOOST_CHECK_MESSAGE(next_time_slot == expected,
-                                " Time series " << timeSeries.toString() << " at " << hour
-                                                << " expected next time slot at " << expected.toString()
-                                                << " but found " << next_time_slot.toString());
-            BOOST_CHECK_MESSAGE(timeSeries.requeueable(c),
-                                "Time series " << timeSeries.toString() << " should be requeueable at hour " << hour);
-        }
-        else if (hour > timeSeries.start().hour() && hour < timeSeries.finish().hour()) {
-            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
-            TimeSlot expected(hour + 1, 0);
-            BOOST_CHECK_MESSAGE(next_time_slot == expected,
-                                " Time series " << timeSeries.toString() << " at " << hour
-                                                << " expected next time slot at " << expected.toString()
-                                                << " but found " << next_time_slot.toString());
-            BOOST_CHECK_MESSAGE(timeSeries.requeueable(c),
-                                "Time series " << timeSeries.toString() << " should be requeueable at hour " << hour);
-        }
-        else if (hour == timeSeries.finish().hour()) {
-            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
-            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
-                                " Time series " << timeSeries.toString() << " at " << hour
-                                                << " expected next time slot  to be NULL");
-            BOOST_CHECK_MESSAGE(!timeSeries.requeueable(c),
-                                "Time series " << timeSeries.toString() << " should NOT be requeueable at hour "
-                                               << hour);
-        }
-        else if (hour > timeSeries.finish().hour()) {
-            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
-            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
-                                " Time series " << timeSeries.toString() << " at " << hour
-                                                << " expected next time slot to be NULL");
-            BOOST_CHECK_MESSAGE(!timeSeries.requeueable(c),
-                                "Time series " << timeSeries.toString() << " should NOT be requeueable at hour "
-                                               << hour);
-        }
-
-        if (hour < timeSeries2.start().hour()) {
-            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
-            TimeSlot expected(11, 0);
-            BOOST_CHECK_MESSAGE(next_time_slot == expected,
-                                " Time series " << timeSeries2.toString() << " at " << hour
-                                                << " expected next time slot at " << expected.toString()
-                                                << " but found " << next_time_slot.toString());
-            BOOST_CHECK_MESSAGE(timeSeries2.requeueable(c),
-                                "Time series " << timeSeries2.toString() << " should be requeueable at hour " << hour);
-        }
-        else if (hour == timeSeries2.start().hour()) {
-            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
-            TimeSlot expected(12, 0);
-            BOOST_CHECK_MESSAGE(next_time_slot == expected,
-                                " Time series " << timeSeries2.toString() << " at " << hour
-                                                << " expected next time slot at " << expected.toString()
-                                                << " but found " << next_time_slot.toString());
-            BOOST_CHECK_MESSAGE(timeSeries2.requeueable(c),
-                                "Time series " << timeSeries2.toString() << " should NOT be requeueable at hour "
-                                               << hour);
-        }
-        else if (hour > timeSeries2.start().hour() && hour < timeSeries2.finish().hour()) {
-            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
-            TimeSlot expected(hour + 1, 0);
-            BOOST_CHECK_MESSAGE(next_time_slot == expected,
-                                " Time series " << timeSeries2.toString() << " at " << hour
-                                                << " expected next time slot at " << expected.toString()
-                                                << " but found " << next_time_slot.toString());
-            BOOST_CHECK_MESSAGE(timeSeries2.requeueable(c),
-                                "Time series " << timeSeries2.toString() << " should be requeueable at hour " << hour);
-        }
-        else if (hour == timeSeries2.finish().hour()) {
-            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
-            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
-                                " Time series " << timeSeries2.toString() << " at " << hour
-                                                << " expected next time slot  to be NULL");
-            BOOST_CHECK_MESSAGE(!timeSeries2.requeueable(c),
-                                "Time series " << timeSeries2.toString() << " should NOT be requeueable at hour "
-                                               << hour);
-        }
-        else if (hour > timeSeries2.finish().hour()) {
-            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
-            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
-                                " Time series " << timeSeries2.toString() << " at " << hour
-                                                << " expected next time slot to be NULL");
-            BOOST_CHECK_MESSAGE(!timeSeries2.requeueable(c),
-                                "Time series " << timeSeries2.toString() << " should NOT be requeueable at hour "
-                                               << hour);
-        }
-
-        if (hour < timeSeries3.start().hour()) {
-            TimeSlot next_time_slot = timeSeries3.compute_next_time_slot(c);
-            TimeSlot expected(15, 0);
-            BOOST_CHECK_MESSAGE(next_time_slot == expected,
-                                " Time series " << timeSeries3.toString() << " at " << hour
-                                                << " expected next time slot at " << expected.toString()
-                                                << " but found " << next_time_slot.toString());
-            BOOST_CHECK_MESSAGE(timeSeries3.requeueable(c),
-                                "Time series " << timeSeries3.toString() << " should be requeueable at hour " << hour);
-        }
-        else if (hour == timeSeries3.start().hour()) {
-            TimeSlot next_time_slot = timeSeries3.compute_next_time_slot(c);
-            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
-                                " Time series " << timeSeries3.toString() << " at " << hour
-                                                << " expected next time slot to be NULL");
-            BOOST_CHECK_MESSAGE(!timeSeries3.requeueable(c),
-                                "Time series " << timeSeries3.toString() << " should NOT be requeueable at hour "
-                                               << hour);
-        }
-        else if (hour > timeSeries3.start().hour()) {
-            TimeSlot next_time_slot = timeSeries3.compute_next_time_slot(c);
-            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
-                                " Time series " << timeSeries3.toString() << " at " << hour
-                                                << " expected next time slot to be NULL");
-            BOOST_CHECK_MESSAGE(!timeSeries3.requeueable(c),
-                                "Time series " << timeSeries3.toString() << " should NOT be requeueable at hour "
-                                               << hour);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_finish_not_divisble_by_increment) {
-    cout << "ACore:: ...test_time_series_finish_not_divisble_by_increment\n";
-
-    // HANDLE CASE WHERE FINISH MINUTES IS NOT DIVISIBLE BY THE INCREMENT
-
-    // Test time series with  a calendar, we update calendar then
-    // test time series isFree(), and checkForRequeue
-    Calendar calendar;
-    calendar.init(ptime(date(2008, 10, 8), hours(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series.
-    // NOTE: Finish minute is not a multiple of INCREMENT hence last valid time slot is 23:50
-    //
-    // Create the time series: start  00:00
-    //                         finish 23:59
-    //                         incr   00:10
-    TimeSeries timeSeries(TimeSlot(0, 0), TimeSlot(23, 59), TimeSlot(0, 10), false /* relative */);
-    TimeSeries timeSeries2(TimeSlot(0, 30), TimeSlot(23, 59), TimeSlot(4, 0), false /* relative */);
-
-    TimeSlot t1_min, t1_max, t2_min, t2_max;
-    timeSeries.min_max_time_slots(t1_min, t1_max);
-    timeSeries2.min_max_time_slots(t2_min, t2_max);
-    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(0, 0) && t1_max == TimeSlot(23, 59), "Not as expected");
-    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(0, 30) && t2_max == TimeSlot(23, 59), "Not as expected");
-
-    time_duration last  = hours(23) + minutes(50); // last valid time is 23:50
-    time_duration last2 = hours(20) + minutes(30); // last valid time is 20:30
-
-    // follow normal process
-    timeSeries.reset(calendar);
-    timeSeries2.reset(calendar);
-
-    for (int hour = 0; hour < 24; hour++) {
-        for (int minute = 0; minute < 60; minute++) {
-
-            calendar.update(minutes(1));
-            timeSeries.calendarChanged(calendar);
-            timeSeries2.calendarChanged(calendar);
-
-            // cout << to_simple_string(calendar.suiteTime()) << "\n";
-
-            if (calendar.dayChanged()) {
-                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    " expected " << timeSeries.toString() << " checkForRequeue to pass at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-            else if (calendar.suiteTime().time_of_day() < timeSeries.start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    " expected " << timeSeries.toString() << " checkForRequeue to pass at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-            else if (calendar.suiteTime().time_of_day() >= timeSeries.start().duration() &&
-                     calendar.suiteTime().time_of_day() < last) {
-                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    " expected " << timeSeries.toString() << " checkForRequeue to pass at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    " expected " << timeSeries.toString() << " checkForRequeue to fail at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-
-            if (calendar.dayChanged()) {
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-            else if (calendar.suiteTime().time_of_day() < timeSeries2.start().duration()) {
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-            else if (calendar.suiteTime().time_of_day() >= timeSeries2.start().duration() &&
-                     calendar.suiteTime().time_of_day() < last2) {
-                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    " expected " << timeSeries2.toString() << " checkForRequeue to fail at "
-                                                 << to_simple_string(calendar.suiteTime()));
-            }
-
-            //         if (calendar.dayChanged()) {
-            //            timeSeries.reset(calendar);
-            //            timeSeries2.reset(calendar);
-            //         }
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_miss_time_slot) {
-    cout << "ACore:: ...test_time_series_miss_time_slot\n";
-
-    Calendar calendar;
-    calendar.init(ptime(date(2008, 10, 8), hours(10)), Calendar::REAL);
-
-    // Create a test when we can match a time series.
-    // NOTE: Finish minute is not a multiple of INCREMENT hence last valid time slot is 23:50
-    //
-    // Create the time series: start  10:00
-    //                         finish 23:59
-    //                         incr   00:10
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(23, 59), TimeSlot(0, 10), false /* relative */);
-    timeSeries.miss_next_time_slot(); // will increment next_time_slot
-    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 10), "miss time slot not working ");
-
-    timeSeries.miss_next_time_slot(); // will increment next_time_slot
-    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 20), "miss time slot not working ");
-
-    // requeue time series,
-    timeSeries.requeue(calendar); // calendar time is at midnight 10:00
-    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 10), "Expected requeue to reset time series");
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_miss_time_slot_1) {
-    cout << "ACore:: ...test_time_series_miss_time_slot_1\n";
-
-    // Create calendar before time series
-    {
-        Calendar calendar;
-        calendar.init(ptime(date(2008, 10, 8), hours(9)), Calendar::REAL); // 09:00
-
-        TimeSeries timeSeries(10, 0, false /* relative */); // 10:00
-
-        TimeSlot t1_min, t1_max;
-        timeSeries.min_max_time_slots(t1_min, t1_max);
-        BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(10, 0), "Not as expected");
-
-        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time holding at 10:00 since calendar is 09:00");
-        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                            "Expected checkForRequeue to return false always");
-
-        timeSeries.miss_next_time_slot();
-        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time to hold");
-        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                            "Expected checkForRequeue to return false");
-
-        timeSeries.requeue(calendar);
-        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time holding at 10:00 since calendar is 09:00");
-        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                            "Expected checkForRequeue to return false after Requeue");
-    }
-    {
-        // Create a time after the time series
-        Calendar calendar;
-        calendar.init(ptime(date(2008, 10, 8), hours(11)), Calendar::REAL); // 11:00
-
-        TimeSeries timeSeries(10, 0, false /* relative */); // 10:00
-
-        TimeSlot t1_min, t1_max;
-        timeSeries.min_max_time_slots(t1_min, t1_max);
-        BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(10, 0), "Not as expected");
-
-        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                            "Expected time NOT to be free, since calendar time is after time slot");
-        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                            "Expected checkForRequeue to return false, since calendar time > slot time");
-
-        timeSeries.miss_next_time_slot();
-        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time to hold");
-        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                            "Expected checkForRequeue to return false");
-
-        timeSeries.requeue(calendar);
-        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                            "Expected time to hold, since calendar time is after time slot");
-        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                            "Expected checkForRequeue to return false,since calendar time is after time slot");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_reset) {
-    cout << "ACore:: ...test_time_series_reset\n";
-
-    // Create a test when we can match a time series.
-    // NOTE: Finish minute is not a multiple of INCREMENT hence last valid time slot is 23:50
-    //
-    // Create the time series: start  10:00
-    //                         finish 23:59
-    //                         incr   00:10
-    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(23, 59), TimeSlot(0, 10), false /* relative */);
-    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0), "defaults not correct");
-
-    { // set calendar before time series start & then reset
-
-        Calendar calendar;
-        calendar.init(ptime(date(2008, 10, 8), hours(9)), Calendar::REAL);
-        timeSeries.reset(calendar);
-        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0),
-                            "Reset should set value(next_valid_time_slot) to start." << timeSeries.dump());
-
-        timeSeries.miss_next_time_slot();
-
-        timeSeries.requeue(calendar);
-        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0),
-                            "requeue should set value(next_valid_time_slot) to start." << timeSeries.dump());
-    }
-    { // set calendar at time series start & then reset
-
-        Calendar calendar;
-        calendar.init(ptime(date(2008, 10, 8), hours(10)), Calendar::REAL);
-        timeSeries.reset(calendar);
-        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0),
-                            "Reset should set value(next_valid_time_slot) to start." << timeSeries.dump());
-
-        timeSeries.miss_next_time_slot();
-
-        timeSeries.requeue(calendar);
-        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 10),
-                            "requeue should set value(next_valid_time_slot) to start." << timeSeries.dump());
-    }
-    { // set calendar after time series start & before time series end, then reset
-
-        Calendar calendar;
-        calendar.init(ptime(date(2008, 10, 8), hours(11)), Calendar::REAL);
-        timeSeries.reset(calendar);
-        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(11, 0),
-                            "Reset should update free slot." << timeSeries.dump());
-
-        timeSeries.miss_next_time_slot();
-
-        timeSeries.requeue(calendar);
-        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(11, 10),
-                            "requeue should update to first time slot." << timeSeries.dump());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_parsing) {
-    cout << "ACore:: ...test_time_series_parsing\n";
-
-    BOOST_CHECK_MESSAGE(TimeSeries::create("00:30") == ecf::TimeSeries(0, 30), "Error ");
-    BOOST_CHECK_MESSAGE(TimeSeries::create("+00:30") == ecf::TimeSeries(0, 30, true), "Error ");
-
-    ecf::TimeSlot start(0, 30);
-    ecf::TimeSlot finish(21, 03);
-    ecf::TimeSlot incr(1, 30);
-    BOOST_CHECK_MESSAGE(TimeSeries::create("00:30 21:03 01:30") == ecf::TimeSeries(start, finish, incr), "Error");
-    BOOST_CHECK_MESSAGE(TimeSeries::create("+00:30 21:03 01:30") == ecf::TimeSeries(start, finish, incr, true),
-                        "Error");
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series_state_parsing) {
-    cout << "ACore:: ...test_time_series_state_parsing\n";
-
-    /// extract string like
-    ///     time +00:00 20:00 00:10 # this is a comment which will be ignored. index = 1
-    ///     time +20:00        // index = 1
-    ///     today 20:00        // index = 1
-    ///     +00:00 20:00 00:10 // index = 0
-    ///     +20:00             // index = 0
-    /// will throw std:runtime_error for errors
-    /// will assert if index >= lineTokens.size()
-    {
-        size_t index         = 0;
-        std::string the_time = "+00:00 20:00 00:10";
-        std::vector<std::string> lineTokens;
-        Str::split(the_time, lineTokens);
-        BOOST_CHECK_MESSAGE(TimeSeries::create(index, lineTokens) ==
-                                ecf::TimeSeries(TimeSlot(0, 0), TimeSlot(20, 0), TimeSlot(0, 10), true),
-                            "Error");
-    }
-    {
-        size_t index         = 0;
-        std::string the_time = "+10:10";
-        std::vector<std::string> lineTokens;
-        Str::split(the_time, lineTokens);
-        BOOST_CHECK_MESSAGE(TimeSeries::create(index, lineTokens) == ecf::TimeSeries(TimeSlot(10, 10), true), "Error");
-    }
-    {
-        size_t index         = 0;
-        std::string the_time = "+10:10 # free isValid:false";
-        ecf::TimeSeries expected(TimeSlot(10, 10), true);
-        expected.set_isValid(false);
-
-        std::vector<std::string> lineTokens;
-        Str::split(the_time, lineTokens);
-        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
-        BOOST_CHECK_MESSAGE(parsed_ts == expected,
-                            "Expected \n'" << expected.toString() << expected.state_to_string(false) << "'"
-                                           << " But found \n'" << parsed_ts.toString()
-                                           << parsed_ts.state_to_string(false) << "'");
-    }
-    {
-        size_t index         = 0;
-        std::string the_time = "+10:10 # free isValid:false nextTimeSlot/10:10 relativeDuration/00:00:00";
-        ecf::TimeSeries expected(TimeSlot(10, 10), true);
-        expected.set_isValid(false);
-
-        std::vector<std::string> lineTokens;
-        Str::split(the_time, lineTokens);
-        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
-        BOOST_CHECK_MESSAGE(parsed_ts == expected,
-                            "Expected \n'" << expected.toString() << expected.state_to_string(false) << "'"
-                                           << " But found\n'" << parsed_ts.toString()
-                                           << parsed_ts.state_to_string(false) << "'");
-    }
-    {
-        // Update relative duration
-        size_t index         = 0;
-        std::string the_time = "+10:10 # free isValid:false nextTimeSlot/10:10 relativeDuration/01:00:00";
-        ecf::TimeSeries expected(TimeSlot(10, 10), true);
-        expected.set_isValid(false);
-
-        Calendar calendar;
-        calendar.init(ptime(date(2008, 10, 8), hours(0)), Calendar::REAL);
-        calendar.update(time_duration(hours(1)));
-        expected.calendarChanged(calendar);
-
-        std::vector<std::string> lineTokens;
-        Str::split(the_time, lineTokens);
-        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
-        BOOST_CHECK_MESSAGE(parsed_ts == expected,
-                            "Expected \n'" << expected.toString() << expected.state_to_string(false) << "'"
-                                           << " But found\n'" << parsed_ts.toString()
-                                           << parsed_ts.state_to_string(false) << "'");
-    }
-
-    {
-        // Update nextTimeSlot, create calendar at 09:00 and increment time series.
-        std::string the_time = "09:00 12:00 01:00 # isValid:false nextTimeSlot/10:00 relativeDuration/00:00:00";
-        ecf::TimeSeries expected(TimeSlot(9, 0), TimeSlot(12, 0), TimeSlot(1, 0), false);
-        expected.set_isValid(false);
-
-        Calendar calendar;
-        calendar.init(ptime(date(2008, 10, 8), hours(9)), Calendar::REAL);
-        expected.requeue(calendar); // this will reset isValid to true
-        expected.set_isValid(false);
-
-        std::vector<std::string> lineTokens;
-        Str::split(the_time, lineTokens);
-        size_t index              = 0;
-        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
-
-        BOOST_CHECK_MESSAGE(parsed_ts == expected,
-                            "Expected \n'" << expected.dump() << expected.state_to_string(false) << "'"
-                                           << " But found\n'" << parsed_ts.dump() << parsed_ts.state_to_string(false)
-                                           << "'");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestTimeSlot.cpp 5.13.0-1/ACore/test/TestTimeSlot.cpp
--- 5.12.4-1/ACore/test/TestTimeSlot.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestTimeSlot.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,101 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/TimeSlot.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_TimeSlot)
-
-BOOST_AUTO_TEST_CASE(test_time_slot) {
-    cout << "ACore:: ...test_time_slot\n";
-
-    // test timeslot operator
-    {
-        TimeSlot x;
-        TimeSlot y;
-        BOOST_CHECK_MESSAGE(x.isNULL(), "Expected NULL");
-        BOOST_CHECK_MESSAGE(y.isNULL(), "Expected NULL");
-        BOOST_CHECK_MESSAGE(x == y, "Equality operator expected to succeed");
-        BOOST_CHECK_MESSAGE(!(x < y), "Less than operator expected to fail");
-        BOOST_CHECK_MESSAGE(!(x > y), "Greater than operator expected to fail");
-        BOOST_CHECK_MESSAGE(x <= y, "<= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(x >= y, ">= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(y <= x, "<= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(y >= x, ">= operator expected to succeed");
-
-        TimeSlot a(10, 12);
-        TimeSlot b(10, 12);
-        BOOST_CHECK_MESSAGE(!a.isNULL(), "Expected NOT NULL");
-        BOOST_CHECK_MESSAGE(!b.isNULL(), "Expected NOT NULL");
-        BOOST_CHECK_MESSAGE(a == b, "Equality operator expected to succeed");
-        BOOST_CHECK_MESSAGE(!(a < b), "Less than operator expected to fail");
-        BOOST_CHECK_MESSAGE(!(a > b), "Greater than operator expected to fail");
-        BOOST_CHECK_MESSAGE(a <= b, "<= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(a >= b, ">= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(b <= a, "<= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(b >= a, ">= operator expected to succeed");
-
-        TimeSlot c(0, 0);
-        TimeSlot d(0, 0);
-        BOOST_CHECK_MESSAGE(!c.isNULL(), "Expected NOT NULL");
-        BOOST_CHECK_MESSAGE(!d.isNULL(), "Expected NOT NULL");
-        BOOST_CHECK_MESSAGE(c == d, "Equality operator expected to succeed");
-        BOOST_CHECK_MESSAGE(!(c < d), "Less than operator expected to fail");
-        BOOST_CHECK_MESSAGE(!(c > d), "Greater than operator expected to fail");
-        BOOST_CHECK_MESSAGE(c <= d, "<= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(c >= d, ">= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(d <= c, "<= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(d >= c, ">= operator expected to succeed");
-
-        TimeSlot a1(10, 1);
-        TimeSlot b1(10, 12);
-        BOOST_CHECK_MESSAGE(!a1.isNULL(), "Expected NOT NULL");
-        BOOST_CHECK_MESSAGE(!b1.isNULL(), "Expected NOT NULL");
-        BOOST_CHECK_MESSAGE(a1 != b1, "Equality operator expected to fail");
-        BOOST_CHECK_MESSAGE(a1 < b1, "Less than operator expected to succeed");
-        BOOST_CHECK_MESSAGE(!(a1 > b1), "Greater than operator expected to fail");
-        BOOST_CHECK_MESSAGE(!(a1 >= b1), ">= than operator expected to fail");
-        BOOST_CHECK_MESSAGE(b1 > a1, "Greater than operator expected to succeed");
-        BOOST_CHECK_MESSAGE(b1 >= a1, ">= expected to succeed");
-
-        TimeSlot xx(10, 1);
-        TimeSlot yy(23, 12);
-        BOOST_CHECK_MESSAGE(xx != yy, "Equality operator expected to fail");
-        BOOST_CHECK_MESSAGE(xx < yy, "Less than operator expected to succeed");
-        BOOST_CHECK_MESSAGE(xx <= yy, "<= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(yy > xx, "Greater than operator expected to succeed");
-        BOOST_CHECK_MESSAGE(yy >= xx, ">= operator expected to succeed");
-        BOOST_CHECK_MESSAGE(!(xx > yy), "Greater than operator expected to fail");
-        BOOST_CHECK_MESSAGE(!(xx >= yy), ">= operator expected to fail");
-
-        TimeSlot x1(11, 0);
-        TimeSlot y1(10, 0);
-        BOOST_CHECK_MESSAGE(x1 != y1, "Equality operator expected to fail");
-        BOOST_CHECK_MESSAGE(!(x1 < y1), "Less than operator expected to fail");
-        BOOST_CHECK_MESSAGE(!(x1 <= y1), "<= operator expected to fail");
-        BOOST_CHECK_MESSAGE(x1 > y1, "Greater than operator expected to succced");
-        BOOST_CHECK_MESSAGE(x1 >= y1, ">= operator expected to succced");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestVersion.cpp 5.13.0-1/ACore/test/TestVersion.cpp
--- 5.12.4-1/ACore/test/TestVersion.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestVersion.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,78 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Version)
-
-BOOST_AUTO_TEST_CASE(test_version) {
-    std::string desc = Version::description();
-    BOOST_CHECK_MESSAGE(!desc.empty(), "Expected version");
-    cout << "ACore:: ...test_version:" << desc << endl;
-}
-
-BOOST_AUTO_TEST_CASE(test_version_against_cmake) {
-    cout << "ACore:: ...test_version_against_cmake" << endl;
-
-    // Open the file CMakeList.txt
-    std::string version_cmake_file = File::root_source_dir() + "/CMakeLists.txt";
-    std::vector<std::string> lines;
-    BOOST_REQUIRE_MESSAGE(File::splitFileIntoLines(version_cmake_file, lines, true /* impore empty lines */),
-                          "Failed to open file " << version_cmake_file << " (" << strerror(errno) << ")");
-    BOOST_REQUIRE_MESSAGE(!lines.empty(), "File " << version_cmake_file << " does not contain version info ??");
-
-    // Expecting lines like:
-    //   project( ecflow LANGUAGES CXX VERSION 5.3.1 )
-    // Compare against VERSION
-    std::string cmake_version;
-    for (auto& line : lines) {
-        std::vector<std::string> tokens;
-        Str::split(line, tokens);
-
-        if (line.find("project") != std::string::npos && line.find("ecflow") != std::string::npos &&
-            line.find("LANGUAGES") != std::string::npos && line.find("CXX") != std::string::npos &&
-            line.find("VERSION") != std::string::npos) {
-            for (size_t i = 0; i < tokens.size(); i++) {
-                if (tokens[i] == "VERSION") {
-                    if (i + 1 < tokens.size()) {
-                        cmake_version = tokens[i + 1];
-                        break;
-                    }
-                }
-            }
-        }
-    }
-
-    // The if they don't match, we have failed to regenrate and check in ecflow_version.h
-    BOOST_REQUIRE_MESSAGE(!cmake_version.empty(),
-                          "Expected to find 'project( ecflow LANGUAGES CXX VERSION N.N.N )' in file "
-                              << version_cmake_file);
-    BOOST_REQUIRE_MESSAGE(
-        Version::raw() == cmake_version,
-        "\n  Expected " << cmake_version << " but found " << Version::raw()
-                        << ", Please regenerate file $WK/ACore/src/ecflow_version.h by calling 'sh -x $WK/cmake.sh'");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestVersioning.cpp 5.13.0-1/ACore/test/TestVersioning.cpp
--- 5.12.4-1/ACore/test/TestVersioning.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestVersioning.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "TestVersioning.hpp"
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-using namespace std;
-using namespace boost;
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_Versioning)
-
-// This class will create a Class X. This is serialised.
-// This class is then reloaded, with different kinds of version changes, to base version 0;
-// Note: we simulate different release of class X, by using name spaces
-//       This is possible since the name space is not written.
-BOOST_AUTO_TEST_CASE(test_versioning) {
-    cout << "ACore:: ...test_versioning\n";
-    {
-        // write out version 0; This will be reloaded with different version of X
-        const version0::X t = version0::X(10);
-        ecf::save("version0", t);
-    }
-
-    {
-        // Version 1 adds a new data member: i.e min_
-        version_new_data_member::X t;
-        ecf::restore("version0", t);
-        BOOST_CHECK_MESSAGE(t == version_new_data_member::X(10, 0), "Should be the same");
-    }
-
-    {
-        // Version 1 change data member name: from hour_ -> hours_:
-        // This required no change at all. Since serialisation relies on order.
-        version_change_dm_name::X t;
-        ecf::restore("version0", t);
-        BOOST_CHECK_MESSAGE(t == version_change_dm_name::X(10), "Should be the same");
-    }
-
-    {
-        // Version 1 change data member type: from int -> string :
-        version_change_dm_type::X t;
-        ecf::restore("version0", t);
-        BOOST_CHECK_MESSAGE(t == version_change_dm_type::X("10"),
-                            "Reading integer as string expected '10', but found string " << t.str());
-    }
-
-    // remove the generate file
-    fs::remove("version0");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/TestVersioning.hpp 5.13.0-1/ACore/test/TestVersioning.hpp
--- 5.12.4-1/ACore/test/TestVersioning.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestVersioning.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,110 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_test_TestVersioning_HPP
-#define ecflow_core_test_TestVersioning_HPP
-
-#include "TestSerialisation.hpp"
-#include "ecflow/core/Converter.hpp"
-
-/// To simulate changing of data model over time, we will
-/// namespace's. The actual serialisation does not appears to
-/// persist the name space
-
-namespace version0 {
-class X {
-public:
-    static std::string type() { return "X"; }
-    explicit X(int h = 0) : hour_(h) {}
-    bool operator==(const X& rhs) const { return hour_ == rhs.hour_; }
-
-private:
-    int hour_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar & hour_;
-    }
-};
-} // namespace version0
-
-namespace version_new_data_member {
-class X {
-public:
-    static std::string type() { return "X"; }
-    explicit X(int h = 0, int m = 0) : hour_(h), min_(m) {}
-    bool operator==(const X& rhs) const { return hour_ == rhs.hour_ && min_ == rhs.min_; }
-
-private:
-    int hour_;
-    int min_;
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        // When *loading* the version pertains to loaded version in the data
-        // When *saving* the version always pertains to the latest version
-        ar & hour_;
-        if (version > 0)
-            ar & min_;
-    }
-};
-} // namespace version_new_data_member
-CEREAL_CLASS_VERSION(version_new_data_member::X, 1)
-
-namespace version_change_dm_name {
-class X {
-public:
-    static std::string type() { return "X"; }
-    explicit X(int h = 0) : hours_(h) {}
-    bool operator==(const X& rhs) const { return hours_ == rhs.hours_; }
-
-private:
-    int hours_;
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar & hours_;
-    }
-};
-} // namespace version_change_dm_name
-CEREAL_CLASS_VERSION(version_change_dm_name::X, 1)
-
-namespace version_change_dm_type {
-class X {
-public:
-    explicit X(const std::string& h = "") : hour_(h) {}
-    bool operator==(const X& rhs) const { return hour_ == rhs.hour_; }
-    std::string str() const { return hour_; }
-
-private:
-    std::string hour_;
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        // When *loading* the version pertains to loaded version in the data
-        // When *saving* the version always pertains to the latest version
-        if (version == 0) {
-            // Change data member type: int(version0)--->string(version1)
-            int the_old_hour = 0;
-            ar & the_old_hour;
-            hour_ = ecf::convert_to<std::string>(the_old_hour);
-        }
-        else {
-            ar & hour_;
-        }
-    }
-};
-
-} // namespace version_change_dm_type
-
-CEREAL_CLASS_VERSION(version_change_dm_type::X, 1)
-
-#endif /* ecflow_core_test_TestVersioning_HPP */
diff -pruN 5.12.4-1/ACore/test/TestWhiteListFile.cpp 5.13.0-1/ACore/test/TestWhiteListFile.cpp
--- 5.12.4-1/ACore/test/TestWhiteListFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/TestWhiteListFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,689 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/WhiteListFile.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// #define DEBUG_ME 1
-
-BOOST_AUTO_TEST_SUITE(U_Core)
-
-BOOST_AUTO_TEST_SUITE(T_WhiteListFile)
-
-void test_white_list_files(const std::string& directory, bool pass) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (fs::is_directory(dir_itr->status())) {
-                test_white_list_files(relPath.string(), pass);
-                continue;
-            }
-
-#if DEBUG_ME
-            std::cout << "......Parsing file " << relPath.string() << "\n";
-#endif
-
-            WhiteListFile theFile;
-            std::string errorMsg;
-            bool parsedOk = theFile.load(relPath.string(), false /*debug*/, errorMsg);
-            if (pass) {
-                // Test expected to pass
-                BOOST_CHECK_MESSAGE(parsedOk,
-                                    "Failed to parse file " << relPath << "\n"
-                                                            << errorMsg << "\n"
-                                                            << theFile.dump_valid_users());
-            }
-            else {
-                // test expected to fail
-                BOOST_CHECK_MESSAGE(!parsedOk,
-                                    "Parse expected to fail for " << relPath << "\n"
-                                                                  << errorMsg << "\n"
-                                                                  << theFile.dump_valid_users());
-#if DEBUG_ME
-                cout << "\n" << errorMsg << "\n";
-#endif
-            }
-        }
-        catch (const std::exception& ex) {
-            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_for_good_white_list_files) {
-    cout << "ACore:: ...test_parsing_for_good_white_list_files\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles", "ACore");
-
-    // All the files in this directory are expected to pass
-    test_white_list_files(path, true);
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_for_bad_white_list_files) {
-    cout << "ACore:: ...test_parsing_for_bad_white_list_files\n";
-
-    std::string path = File::test_data("ACore/test/data/badWhiteListFiles", "ACore");
-
-    // All the files in this directory are expected to fail
-    test_white_list_files(path, false);
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list_default) {
-    cout << "ACore:: ...test_white_list_default\n";
-
-    WhiteListFile theFile;
-
-    BOOST_REQUIRE_MESSAGE(0 == theFile.read_access_size(),
-                          "expected 0 users with read access but found " << theFile.read_access_size());
-    BOOST_REQUIRE_MESSAGE(0 == theFile.write_access_size(),
-                          "expected 0 users with write access but found " << theFile.write_access_size());
-
-    // test random user
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", "/x"), "Expected user xxtt to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", paths), "Expected user xxtt to have read access ");
-
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("yyyy"), "Expected user yyyy to have write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", "/y"), "Expected user zzzz to have write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", paths), "Expected user zzzz to have write access ");
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list_empty_file) {
-    cout << "ACore:: ...test_white_list_empty_file\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles/empty.lists", "ACore");
-
-    WhiteListFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    BOOST_REQUIRE_MESSAGE(0 == theFile.read_access_size(),
-                          "expected 0 users with read access but found " << theFile.read_access_size());
-    BOOST_REQUIRE_MESSAGE(0 == theFile.write_access_size(),
-                          "expected 0 users with write access but found " << theFile.write_access_size());
-
-    // test random user
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", "/x"), "Expected user xxtt to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", paths), "Expected user xxtt to have read access ");
-
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("yyyy"), "Expected user yyyy to have write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", "/y"), "Expected user zzzz to have write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", paths), "Expected user zzzz to have write access ");
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list) {
-    cout << "ACore:: ...test_white_list\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles/good1.lists", "ACore");
-
-    WhiteListFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    // make sure we find all the users and the access right are correct
-    // 	uid1    # a comment
-    // 	uid2  # a comment
-    // 	cog   # a comment
-    //
-    // 	#
-    // 	# Read only uisers
-    // 	#
-    // 	-fred  # a comment
-    // 	-bill # a comment
-    // 	-jake # a comment
-
-    // 	avi   /suite/write
-    // 	-avi  /suite/read
-    std::vector<std::string> expected_users_with_read_access;
-    expected_users_with_read_access.emplace_back("fred");
-    expected_users_with_read_access.emplace_back("bill");
-    expected_users_with_read_access.emplace_back("jake");
-
-    expected_users_with_read_access.emplace_back("uid1"); // users with write access also have read access
-    expected_users_with_read_access.emplace_back("uid2"); // users with write access also have read access
-    expected_users_with_read_access.emplace_back("cog");  // users with write access also have read access
-
-    std::vector<std::string> expected_users_with_read_write_access;
-    expected_users_with_read_write_access.emplace_back("uid1");
-    expected_users_with_read_write_access.emplace_back("uid2");
-    expected_users_with_read_write_access.emplace_back("cog");
-
-    std::vector<std::string> expected_users_with_read_access_to_paths_only;
-    expected_users_with_read_access_to_paths_only.emplace_back("avi");
-
-    std::vector<std::string> expected_users_with_write_access_to_paths_only;
-    expected_users_with_write_access_to_paths_only.emplace_back("avi");
-
-    BOOST_REQUIRE_MESSAGE(
-        expected_users_with_read_access.size() + expected_users_with_read_access_to_paths_only.size() ==
-            theFile.read_access_size(),
-        " expected " << expected_users_with_read_access.size() + expected_users_with_write_access_to_paths_only.size()
-                     << " users with read access but found " << theFile.read_access_size());
-    BOOST_REQUIRE_MESSAGE(expected_users_with_read_write_access.size() +
-                                  expected_users_with_write_access_to_paths_only.size() ==
-                              theFile.write_access_size(),
-                          " expected " << expected_users_with_read_write_access.size() +
-                                              expected_users_with_write_access_to_paths_only.size()
-                                       << " users with write access but found " << theFile.write_access_size());
-
-    // Users who have read access, to all including paths
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    std::vector<std::string>::const_iterator i;
-    for (i = expected_users_with_read_access.begin(); i != expected_users_with_read_access.end(); ++i) {
-        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i), "Expected user " << *i << " to have read access ");
-        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i, "/x"), "Expected user " << *i << " to have read access ");
-        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i, paths), "Expected user " << *i << " to have read access ");
-    }
-    for (i = expected_users_with_read_write_access.begin(); i != expected_users_with_read_write_access.end(); ++i) {
-        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i), "Expected user " << *i << " to have write access ");
-        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i, "/x"), "Expected user " << *i << " to have write access ");
-        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i, paths), "Expected user " << *i << " to have write access ");
-    }
-
-    // Users who have restricted read/write access to certain paths only.
-    vector<string> read_paths;
-    read_paths.emplace_back("/suite/read");
-    read_paths.emplace_back("/suite/read/f1");
-    read_paths.emplace_back("/suite/read/f1/t1");
-    for (i = expected_users_with_read_access_to_paths_only.begin();
-         i != expected_users_with_read_access_to_paths_only.end();
-         ++i) {
-        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i), "Expected user " << *i << " to have read access ");
-        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i, read_paths),
-                            "Expected user " << *i << " to have read access to paths");
-        BOOST_CHECK_MESSAGE(!theFile.verify_read_access(*i, paths),
-                            "Expected user " << *i << " to NOT have read access to paths /a, /b , /c");
-        BOOST_CHECK_MESSAGE(!theFile.verify_read_access(*i, "/suite"),
-                            "Expected user " << *i << " to NOT have read access to paths /suite only /suite/read");
-        BOOST_CHECK_MESSAGE(!theFile.verify_read_access(*i, "/suite/read_me"),
-                            "Expected user "
-                                << *i << " with path '/suite/read_me' to NOT have read access to path /suite/read");
-    }
-
-    vector<string> write_paths;
-    write_paths.emplace_back("/suite/write");
-    write_paths.emplace_back("/suite/write/f1");
-    write_paths.emplace_back("/suite/write/f1/t1");
-    for (i = expected_users_with_write_access_to_paths_only.begin();
-         i != expected_users_with_write_access_to_paths_only.end();
-         ++i) {
-        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i),
-                            "Expected user " << *i << " to NOT have generic write access ");
-        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i, write_paths),
-                            "Expected user " << *i << " to have write access to paths");
-        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i, paths),
-                            "Expected user " << *i << " to have NOT has write access to paths /a, /b , /c");
-        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i, "/suite"),
-                            "Expected user " << *i << " to NOT have write access to paths /suite only /suite/write");
-        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i, "/suite/write_me"),
-                            "Expected user "
-                                << *i << " with path '/suite/write_me' to NOT have write access to paths /suite/write");
-    }
-
-    // test random user
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("xxxx"), "Expected user xxxx to NOT have read access ");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("xxxx", "/x"), "Expected user xxxx to NOT have read access ");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("xxxx", paths), "Expected user xxxx to NOT have read access ");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("*"), "Expected user *  to NOT have read access ");
-
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("yyyy"), "Expected user yyyy  to NOT have write access ");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("zzzz", "/x"), "Expected user zzzz  to NOT have write access ");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("zzzz", paths), "Expected user zzzz  to NOT have write access ");
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list_all_users_have_read_access) {
-    cout << "ACore:: ...test_white_list_all_users_have_read_access\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles/all_read_access.lists", "ACore");
-
-    WhiteListFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    // make sure we find all the users and the access right are correct
-    // # These user have read and write access to the server
-    // uid1  # a comment
-    // uid2  # a comment
-    // cog   # a comment
-    //
-    //
-    // # Read only users
-    //-*
-    //-fred  # a comment
-    //-bill # a comment
-    //-jake # a comment
-
-    std::vector<std::string> expected_users_with_read_write_access;
-    expected_users_with_read_write_access.emplace_back("uid1");
-    expected_users_with_read_write_access.emplace_back("uid2");
-    expected_users_with_read_write_access.emplace_back("cog");
-
-    // When all users have read access, the read access size should be empty
-    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
-
-    BOOST_REQUIRE_MESSAGE(expected_users_with_read_write_access.size() == theFile.write_access_size(),
-                          " expected " << expected_users_with_read_write_access.size()
-                                       << " users with write access but found " << theFile.write_access_size());
-
-    // Any user should have read access
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", "/x"), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("bill"), "Expected user bill  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("uid1"), "Expected user xxxx  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("uid2"), "Expected user xxxx  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("cog"), "Expected user xxxx  to have read access ");
-
-    std::vector<std::string>::const_iterator i;
-    for (i = expected_users_with_read_write_access.begin(); i != expected_users_with_read_write_access.end(); ++i) {
-        BOOST_REQUIRE_MESSAGE(theFile.verify_write_access(*i), "Expected user " << *i << " to have write access ");
-        BOOST_REQUIRE_MESSAGE(theFile.verify_write_access(*i, "/x"),
-                              "Expected user " << *i << " to have write access ");
-        BOOST_REQUIRE_MESSAGE(theFile.verify_write_access(*i, paths),
-                              "Expected user " << *i << " to have write access ");
-    }
-
-    // test random user for write access
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("yyyy"), "Expected user yyyy  to NOT have write access ");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("zzzz"), "Expected user zzzz  to NOT have write access ");
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list_all_users_have_write_access) {
-    cout << "ACore:: ...test_white_list_all_users_have_write_access\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles/all_write_access.lists", "ACore");
-
-    WhiteListFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    // make sure we find all the users and the access right are correct
-    //   uid1  # a comment
-    //   uid2  # a comment
-    //   cog   # a comment
-    //   *
-    //
-    //   # Read only users
-    //   -*
-    //   -fred  # a comment
-    //   -bill # a comment
-    //   -jake # a comment
-
-    // When all users have read access, the read access size should be empty
-    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
-    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
-
-    // Any user should have read access
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", "/x"), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("bill"), "Expected user bill  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", "/x"), "Expected user xxxx  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", paths), "Expected user xxxx  to have read access ");
-
-    // Any user should have read write access
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred"), "Expected user fred  to have read/write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzzzz"), "Expected user zzzzzz  to have read/write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzzzz", "/x"),
-                          "Expected user zzzzzz  to have read/write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzzzz", paths),
-                          "Expected user zzzzzz  to have read/write access ");
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list_all_path_users_have_write_access) {
-    cout << "ACore:: ...test_white_list_all_path_users_have_write_access\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles/all_path_write_access.lists", "ACore");
-
-    WhiteListFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    //   4.4.14
-    //   * /  # same as '*'
-
-    // When all users have read/write access, the read/write access size should be empty
-    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
-    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 0, " expected 0  but found " << theFile.write_access_size());
-
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    vector<string> paths1;
-    paths1.emplace_back("/a");
-    paths1.emplace_back("/b");
-    // Any user should have read/write access
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", "/x"), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths1), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred"), "Expected user fred  to have read/write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", "/x"), "Expected user fred  to have read/write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths), "Expected user fred  to have read/write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths1),
-                          "Expected user fred  to have read/write access ");
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list_all_path_users_have_read_access) {
-    cout << "ACore:: ...test_white_list_all_path_users_have_read_access\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles/all_path_read_access.lists", "ACore");
-
-    WhiteListFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    //   4.4.14
-    //   -* /  # same as '*'
-
-    // When all users have read/write access, the size should be empty
-    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
-    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 0, " expected 0  but found " << theFile.write_access_size());
-
-    // When no write access specified all user have write access
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    vector<string> paths1;
-    paths1.emplace_back("/a");
-    paths1.emplace_back("/b");
-    // Any user should have read/write access
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred"), "Expected user fred  to have read access ");
-
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths1), "Expected user fred  to have read access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths), "Expected user fred  to have read/write access ");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths1),
-                          "Expected user fred  to have read/write access ");
-}
-
-BOOST_AUTO_TEST_CASE(test_white_list_path_access_list) {
-    cout << "ACore:: ...test_white_list_path_access_list\n";
-
-    std::string path = File::test_data("ACore/test/data/goodWhiteListFiles/path_access.lists", "ACore");
-
-    WhiteListFile theFile;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
-
-    //   4.4.14
-    //
-    //   user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
-    //   user2 /a
-    //   user2 /b
-    //   user2 /c       # user2 has read write access to suite /a /b /c
-    //   user3 /a /b /c # user3 has read write access to suite /a /b /c
-    //
-    //   /a /b /c userx # userx has read write access to suite /a /b /c
-    //   /a,/b,/c usery # userx has read write access to suite /a /b /c
-    //
-    //   /a userz
-    //   /b userz
-    //   /c userz
-    //
-    //   -user4 /a,/b,/c  # user4 has read access to suite /a /b /c
-    //   -user5 /a
-    //   -user5 /b
-    //   -user5 /c    # user5 has read access to suite /a /b /c
-    //   -user6 /a /b /c   # user6 has read access to suite /a /b /c
-    //
-    //   /a /b /c -userxx # userxx has read  access to suite /a /b /c
-    //   /a,/b,/c -useryy # userxy has read  access to suite /a /b /c
-    //
-    //   /a -userzz
-    //   /b -userzz
-    //   /c -userzz
-    //
-    // ##################################
-    //*  /x /y   # all user have read/write access  suites /x /y
-    //-* /w /z   # all user have read access to suite /w /z
-
-    // When all users have read access, the read access size should be empty
-    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 7,
-                          " expected 7  but found " << theFile.read_access_size() << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 7,
-                          " expected 7  but found " << theFile.write_access_size() << theFile.dump_valid_users());
-
-    // When no write access specified all user have write access
-    vector<string> paths;
-    paths.emplace_back("/a");
-    paths.emplace_back("/b");
-    paths.emplace_back("/c");
-    vector<string> partial_paths;
-    partial_paths.emplace_back("/a");
-    partial_paths.emplace_back("/b");
-
-    // read/write
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1", partial_paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user1", paths),
-                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user1", partial_paths),
-                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user2", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user2", paths),
-                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user3", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user3", paths),
-                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userx", paths),
-                          "Expected userx to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("userx", paths),
-                          "Expected userx to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("usery", paths),
-                          "Expected userx to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("usery", paths),
-                          "Expected userx to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
-
-    // read only
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user4", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user5", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user6", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userxx", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("useryy", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userzz", paths),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-
-    // single path, read/write
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user1", "/a"),
-                          "Expected user to have read/write access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user2", "/a"),
-                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user2", "/a"),
-                          "Expected user to have read/write access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user3", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user3", "/a"),
-                          "Expected user to have read/write access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userx", "/a"),
-                          "Expected userx to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("userx", "/a"),
-                          "Expected userx to have read/write access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("usery", "/a"),
-                          "Expected userx to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("usery", "/a"),
-                          "Expected userx to have read/write access to /a" << theFile.dump_valid_users());
-
-    // single path, read
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user4", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user5", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user6", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userxx", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("useryy", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userzz", "/a"),
-                          "Expected user to have read access to /a" << theFile.dump_valid_users());
-
-    // ============================================================================================
-    // test * user, * means all users
-    //*  /x /y   # all user have read/write access  suites /x /y
-    //-* /w /z   # all user have read access to suite /w /z
-    vector<string> single_pathx;
-    single_pathx.emplace_back("/x");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"),
-                          "Expected *ALL* user to have read access" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", single_pathx),
-                          "Expected *ALL* user to have read access to /x" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("xxxx", single_pathx),
-                          "Expected *ALL* user to have read/write access to /x" << theFile.dump_valid_users());
-
-    vector<string> single_pathw;
-    single_pathw.emplace_back("/w");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", single_pathw),
-                          "Expected *ALL* user to have read access to /w" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("xxxx", single_pathw),
-                          "Expected failure for write access to /w" << theFile.dump_valid_users());
-
-    vector<string> multiple_pathsxy;
-    multiple_pathsxy.emplace_back("/x");
-    multiple_pathsxy.emplace_back("/y");
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", multiple_pathsxy),
-                          "Expected *ALL* user to have read access to /x,/y" << theFile.dump_valid_users());
-
-    // ============================================================================================
-    // Failure
-    // ============================================================================================
-
-    // single path failure
-    //   user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
-    vector<string> single_path_failure;
-    single_path_failure.emplace_back("/fail");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", "/fail"),
-                          "Expected user to not have read access to /fail" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", single_path_failure),
-                          "Expected user to not have read access to /fail" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", "/fail"),
-                          "Expected user to not have read/write access to /fail" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", single_path_failure),
-                          "Expected user to not have read/write access to /fail" << theFile.dump_valid_users());
-
-    // multi path failure
-    //   user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
-    vector<string> multiple_paths_failure;
-    multiple_paths_failure.emplace_back("/a");
-    multiple_paths_failure.emplace_back("/b");
-    multiple_paths_failure.emplace_back("/fail");
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", multiple_paths_failure),
-                          "Expected user to not have read access to /fail\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", multiple_paths_failure),
-                          "Expected user to not have read/write access to /fail\n"
-                              << theFile.dump_valid_users());
-
-    // Presence of *, should allow read access to all including unknown users
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown"),
-                          "Expected unknown user to pass due to presence of *\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/x"),
-                          "Expected pass \n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/y"), "Expected pass\n" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/w"), "Expected pass\n" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/z"), "Expected pass\n" << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("unknown", "/x"),
-                          "Expected pass\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("unknown", "/y"),
-                          "Expected pass\n"
-                              << theFile.dump_valid_users());
-
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("unknown", "/a"),
-                          "Expected failure for unknown user for path /a\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("unknown", "/a"),
-                          "Expected failure for unknown user for path /a\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("unknown", paths),
-                          "Expected failure for unknown user\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("unknown", paths),
-                          "Expected failure for unknown user\n"
-                              << theFile.dump_valid_users());
-
-    // user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
-    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1"),
-                          "Expected user1 to not have read access, EVEN if no paths specified, --news has no paths\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", vector<string>()),
-                          "Expected user to not have read access if no paths specified\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", ""),
-                          "Expected user to not have read access if no paths specified\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1"),
-                          "Expected user to not have read/write if no paths specified\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", ""),
-                          "Expected user to not have read/write if no paths specified\n"
-                              << theFile.dump_valid_users());
-    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", vector<string>()),
-                          "Expected user to not have read/write if no paths specified\n"
-                              << theFile.dump_valid_users());
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ACore/test/data/badPasswdFiles/ecf.passwd 5.13.0-1/ACore/test/data/badPasswdFiles/ecf.passwd
--- 5.12.4-1/ACore/test/data/badPasswdFiles/ecf.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badPasswdFiles/ecf.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4.
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badPasswdFiles/ecf1.passwd 5.13.0-1/ACore/test/data/badPasswdFiles/ecf1.passwd
--- 5.12.4-1/ACore/test/data/badPasswdFiles/ecf1.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badPasswdFiles/ecf1.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3.1.0
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badPasswdFiles/ecf2.passwd 5.13.0-1/ACore/test/data/badPasswdFiles/ecf2.passwd
--- 5.12.4-1/ACore/test/data/badPasswdFiles/ecf2.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badPasswdFiles/ecf2.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-4.5.0
-fred host port passwd #  port should be an integer
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badPasswdFiles/ecf3.passwd 5.13.0-1/ACore/test/data/badPasswdFiles/ecf3.passwd
--- 5.12.4-1/ACore/test/data/badPasswdFiles/ecf3.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badPasswdFiles/ecf3.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-4.5.0
-fred host port #  port sould be an integer
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badPasswdFiles/ecf4.passwd 5.13.0-1/ACore/test/data/badPasswdFiles/ecf4.passwd
--- 5.12.4-1/ACore/test/data/badPasswdFiles/ecf4.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badPasswdFiles/ecf4.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-4.5.0
-#  missing passwd
-fred host port  
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badPasswdFiles/ecf5.passwd 5.13.0-1/ACore/test/data/badPasswdFiles/ecf5.passwd
--- 5.12.4-1/ACore/test/data/badPasswdFiles/ecf5.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badPasswdFiles/ecf5.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-4.5.0
-fred host 3141 xxxx
-fred host 3141 yyyy  # cant connect to same host:port with two different passwords with same user
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badWhiteListFiles/bad2.lists 5.13.0-1/ACore/test/data/badWhiteListFiles/bad2.lists
--- 5.12.4-1/ACore/test/data/badWhiteListFiles/bad2.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badWhiteListFiles/bad2.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-#
-4.   #   version number is wrong
-
-#
-# These user have read and write access to the server
-#
-uid1    # a comment
-uid2  # a comment
-  
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badWhiteListFiles/bad3.lists 5.13.0-1/ACore/test/data/badWhiteListFiles/bad3.lists
--- 5.12.4-1/ACore/test/data/badWhiteListFiles/bad3.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badWhiteListFiles/bad3.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-#
-2.10.14   #  valid version number should be greater than 4.4.5
-   
-#
-# These user have read and write access to the server
-#
-uid1    # a comment
-uid2  # a comment
-  
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badWhiteListFiles/bad5.lists 5.13.0-1/ACore/test/data/badWhiteListFiles/bad5.lists
--- 5.12.4-1/ACore/test/data/badWhiteListFiles/bad5.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badWhiteListFiles/bad5.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-# missing version number
- 
-#
-# These user have read and write access to the server
-#
-uid1    # a comment
-uid2  # a comment
-cog   # a comment
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badWhiteListFiles/bad_paths.lists 5.13.0-1/ACore/test/data/badWhiteListFiles/bad_paths.lists
--- 5.12.4-1/ACore/test/data/badWhiteListFiles/bad_paths.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badWhiteListFiles/bad_paths.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-4.4.14 
-fred /x,/y,fred
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badWhiteListFiles/badsms.lists 5.13.0-1/ACore/test/data/badWhiteListFiles/badsms.lists
--- 5.12.4-1/ACore/test/data/badWhiteListFiles/badsms.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badWhiteListFiles/badsms.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-
-uid1
-uid2
-cog
-
-
-4.4.14   #  error version number should be at the start
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badWhiteListFiles/multipleWriteUsers.lists 5.13.0-1/ACore/test/data/badWhiteListFiles/multipleWriteUsers.lists
--- 5.12.4-1/ACore/test/data/badWhiteListFiles/multipleWriteUsers.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badWhiteListFiles/multipleWriteUsers.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-4.4.14 
-uid1 uid3 
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/badWhiteListFiles/mutipleReadUser.lists 5.13.0-1/ACore/test/data/badWhiteListFiles/mutipleReadUser.lists
--- 5.12.4-1/ACore/test/data/badWhiteListFiles/mutipleReadUser.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/badWhiteListFiles/mutipleReadUser.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-4.4.14 
--fred -joe
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/goodPasswdFiles/ecf.passwd 5.13.0-1/ACore/test/data/goodPasswdFiles/ecf.passwd
--- 5.12.4-1/ACore/test/data/goodPasswdFiles/ecf.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodPasswdFiles/ecf.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-4.5.0  # comment
-
-# comment
-fred host 3141  x12ggg # comment
-fred host3 3143 passwd
-fred host4 3145 x12ggg
-# comment
-
-jake host 3141  x12ggg
-tom host3 3143    x12ggg # sdsdsd
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/goodPasswdFiles/empty.passwd 5.13.0-1/ACore/test/data/goodPasswdFiles/empty.passwd
--- 5.12.4-1/ACore/test/data/goodPasswdFiles/empty.passwd	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodPasswdFiles/empty.passwd	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4.5.0
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_path_read_access.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_path_read_access.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_path_read_access.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_path_read_access.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-4.4.14
--* /  # same as '-*'
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_path_write_access.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_path_write_access.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_path_write_access.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_path_write_access.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-4.4.14 
-* /  # same as '*'
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_read_access.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_read_access.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_read_access.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_read_access.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-#
-4.4.14   #   comment
-
-# These user have read and write access to the server
-uid1  # a comment
-uid2  # a comment
-cog   # a comment
-
-
-# Read only users
--*
--fred  # a comment
--bill # a comment
--jake # a comment
-
-# a comment
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_write_access.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_write_access.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/all_write_access.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/all_write_access.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-
-4.4.14   # comment
-
-# These user have read and write access to the server
-uid1  
-uid2   
-cog    
-*     # all users have read and write access 
-
-# Read only users
--*
--fred # a comment
--bill # a comment
--jake # a comment
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/empty.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/empty.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/empty.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/empty.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4.4.14   # comment
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/good1.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/good1.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/good1.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/good1.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-#
-4.4.14   #   comment
-
-# These user have read and write access to the server
-uid1  # a comment
-uid2  # a comment
-cog   # a comment
-
-
-# Read only users
--fred  # a comment
--bill # a comment
--jake # a comment
-
-avi   /suite/write
--avi  /suite/read
-# a comment
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/goodsms.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/goodsms.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/goodsms.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/goodsms.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-
-4.4.14   # comment
-
-uid1
-uid2
-cog
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/long_path_access.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/long_path_access.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/long_path_access.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/long_path_access.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-4.4.14 
-
-user1 /a/b/c/d,/b,/c  # user1 has read write access to suite /a /b /c
-/a/b/c/d /b /c userx # userx has read write access to suite /a /b /c
- 
-/a/b/c/d/e userz
-/b userz
-/c userz
-/c userz # duplicates should be ignored
-
--user4 /a,/b,/c/e/f/g/h  # user4 has read access to suite /a /b /c
--user4 /a,/b,/c/e/f/g/h
-
-##################################
-* /x/y/a /y   # all user have read/write access  suites /x /y
--* /w /z  # all user have read access to suite /w /z
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/goodWhiteListFiles/path_access.lists 5.13.0-1/ACore/test/data/goodWhiteListFiles/path_access.lists
--- 5.12.4-1/ACore/test/data/goodWhiteListFiles/path_access.lists	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/goodWhiteListFiles/path_access.lists	1970-01-01 00:00:00.000000000 +0000
@@ -1,35 +0,0 @@
-4.4.14 
-
-user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
-user1 /a,/b,/c  # duplicate should be ignored
-user2 /a
-user2 /b
-user2 /c       # user2 has read write access to suite /a /b /c
-user3 /a /b /c # user3 has read write access to suite /a /b /c
-
-/a /b /c userx # userx has read write access to suite /a /b /c
-/a,/b,/c usery # userx has read write access to suite /a /b /c
-
-/a userz
-/a userz  # duplicate should be ignored
-/b userz
-/c userz
-
--user4 /a,/b,/c  # user4 has read access to suite /a /b /c
--user4 /a,/b,/c  # duplicate should be ignored
--user5 /a
--user5 /b
--user5 /c         # user5 has read access to suite /a /b /c
--user6 /a /b /c   # user6 has read access to suite /a /b /c
-
-/a /b /c -userxx # userxx has read  access to suite /a /b /c
-/a,/b,/c -useryy # userxy has read  access to suite /a /b /c
-
-/a -userzz
-/b -userzz
-/c -userzz
-/c -userzz       # duplicate should be ignored
-
-##################################
-* /x /y   # all user have read/write access  suites /x /y
--* /w /z  # all user have read access to suite /w /z
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/calendar_1_2_2_ 5.13.0-1/ACore/test/data/migration/calendar_1_2_2_
--- 5.12.4-1/ACore/test/data/migration/calendar_1_2_2_	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/calendar_1_2_2_	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8CalendarE":{"cereal_class_version":0,"initTime_":{"ptime":"2011-Feb-10 23:59:00"},"initLocalTime_":{"ptime":"2018-Aug-20 10:10:33"},"lastTime_":{"ptime":"2018-Aug-20 10:10:33"}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/dstate_1_2_2_ 5.13.0-1/ACore/test/data/migration/dstate_1_2_2_
--- 5.12.4-1/ACore/test/data/migration/dstate_1_2_2_	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/dstate_1_2_2_	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"6DState":{"st_":2}}
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/nstate_1_2_2_ 5.13.0-1/ACore/test/data/migration/nstate_1_2_2_
--- 5.12.4-1/ACore/test/data/migration/nstate_1_2_2_	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/nstate_1_2_2_	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"6NState":{"st_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/timeseries_1_2_2_1010 5.13.0-1/ACore/test/data/migration/timeseries_1_2_2_1010
--- 5.12.4-1/ACore/test/data/migration/timeseries_1_2_2_1010	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/timeseries_1_2_2_1010	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf10TimeSeriesE":{"cereal_class_version":0,"start_":{"h_":10,"m_":10}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/timeseries_default_constructor_1_2_2_ 5.13.0-1/ACore/test/data/migration/timeseries_default_constructor_1_2_2_
--- 5.12.4-1/ACore/test/data/migration/timeseries_default_constructor_1_2_2_	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/timeseries_default_constructor_1_2_2_	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf10TimeSeriesE":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/timeslot_1_2_2_11 5.13.0-1/ACore/test/data/migration/timeslot_1_2_2_11
--- 5.12.4-1/ACore/test/data/migration/timeslot_1_2_2_11	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/timeslot_1_2_2_11	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8TimeSlotE":{"h_":1,"m_":1}}
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/timeslot_1_2_2_9959 5.13.0-1/ACore/test/data/migration/timeslot_1_2_2_9959
--- 5.12.4-1/ACore/test/data/migration/timeslot_1_2_2_9959	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/timeslot_1_2_2_9959	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8TimeSlotE":{"h_":99,"m_":59}}
\ No newline at end of file
diff -pruN 5.12.4-1/ACore/test/data/migration/timeslot_default_constructor_1_2_2_ 5.13.0-1/ACore/test/data/migration/timeslot_default_constructor_1_2_2_
--- 5.12.4-1/ACore/test/data/migration/timeslot_default_constructor_1_2_2_	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ACore/test/data/migration/timeslot_default_constructor_1_2_2_	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8TimeSlotE":{"h_":-1,"m_":-1}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/CMakeLists.txt 5.13.0-1/ANattr/CMakeLists.txt
--- 5.12.4-1/ANattr/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-set(srcs
-  # Headers
-  src/ecflow/attribute/AutoArchiveAttr.hpp
-  src/ecflow/attribute/AutoCancelAttr.hpp
-  src/ecflow/attribute/ClockAttr.hpp
-  src/ecflow/attribute/CronAttr.hpp
-  src/ecflow/attribute/DateAttr.hpp
-  src/ecflow/attribute/DayAttr.hpp
-  src/ecflow/attribute/GenericAttr.hpp
-  src/ecflow/attribute/LateAttr.hpp
-  src/ecflow/attribute/NodeAttr.hpp
-  src/ecflow/attribute/QueueAttr.hpp
-  src/ecflow/attribute/RepeatAttr.hpp
-  src/ecflow/attribute/TimeAttr.hpp
-  src/ecflow/attribute/TodayAttr.hpp
-  src/ecflow/attribute/Variable.hpp
-  src/ecflow/attribute/VerifyAttr.hpp
-  src/ecflow/attribute/Zombie.hpp
-  src/ecflow/attribute/ZombieAttr.hpp
-  # Sources
-  src/ecflow/attribute/AutoArchiveAttr.cpp
-  src/ecflow/attribute/AutoCancelAttr.cpp
-  src/ecflow/attribute/ClockAttr.cpp
-  src/ecflow/attribute/CronAttr.cpp
-  src/ecflow/attribute/DateAttr.cpp
-  src/ecflow/attribute/DayAttr.cpp
-  src/ecflow/attribute/GenericAttr.cpp
-  src/ecflow/attribute/LateAttr.cpp
-  src/ecflow/attribute/NodeAttr.cpp
-  src/ecflow/attribute/QueueAttr.cpp
-  src/ecflow/attribute/RepeatAttr.cpp
-  src/ecflow/attribute/TimeAttr.cpp
-  src/ecflow/attribute/TodayAttr.cpp
-  src/ecflow/attribute/Variable.cpp
-  src/ecflow/attribute/VerifyAttr.cpp
-  src/ecflow/attribute/Zombie.cpp
-  src/ecflow/attribute/ZombieAttr.cpp
-)
-
-ecbuild_add_library(
-  TARGET
-    attributes
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-  PUBLIC_LIBS
-    core
-    Boost::date_time
-)
-target_clangformat(attributes)
-
-
-set(test_srcs
-  # Sources
-  test/TestAttributes_main.cpp
-  test/TestAttrSerialization.cpp
-  test/TestCron.cpp
-  test/TestDateAttr.cpp
-  test/TestDayAttr.cpp
-  test/TestLabel.cpp
-  test/TestLateAttr.cpp
-  test/TestMigration.cpp
-  test/TestRepeat.cpp
-  test/TestSizeOf.cpp
-  test/TestTimeAttr.cpp
-  test/TestTodayAttr.cpp
-  test/TestVariable.cpp
-  test/TestVariableMap.cpp
-  test/TestZombieAttr.cpp
-)
-
-ecbuild_add_test(
-  TARGET
-    u_attributes
-  LABELS
-    unit
-    nightly
-  SOURCES
-    ${test_srcs}
-  LIBS
-    test_support
-    attributes
-  TEST_DEPENDS
-    u_core
-    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-)
-target_clangformat(u_attributes
-  CONDITION ENABLE_TESTS
-)
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,124 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-#ifdef DEBUG
-    #include <boost/date_time/posix_time/time_formatters.hpp>
-#endif
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-namespace ecf {
-
-void AutoArchiveAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += "\n";
-}
-
-std::string AutoArchiveAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void AutoArchiveAttr::write(std::string& ret) const {
-    ret += "autoarchive ";
-    if (days_) {
-        ret += ecf::convert_to<std::string>(time_.hour() / 24);
-        if (idle_)
-            ret += " -i";
-        return;
-    }
-    if (relative_)
-        ret += "+";
-    time_.print(ret);
-    if (idle_)
-        ret += " -i";
-}
-
-bool AutoArchiveAttr::operator==(const AutoArchiveAttr& rhs) const {
-    if (relative_ != rhs.relative_)
-        return false;
-    if (days_ != rhs.days_)
-        return false;
-    if (idle_ != rhs.idle_)
-        return false;
-    return time_.operator==(rhs.time_);
-}
-
-bool AutoArchiveAttr::isFree(
-    const ecf::Calendar& calendar,
-    const std::pair<NState, boost::posix_time::time_duration>& last_state_and_change_duration) const {
-    //                                                               suiteTime()
-    //  suiteDurationAtComplete        autoarchive time              calendar duration
-    //        |                             |                             |
-    //        V                             V                             V
-    // ----------------------------------------------------------------------------------> time
-    //        ^                                                           ^
-    //        |--------elapsed time---------------------------------------|
-    //
-    //
-
-    bool is_valid_state = false;
-    if (last_state_and_change_duration.first == NState::COMPLETE)
-        is_valid_state = true;
-    if (idle_) {
-        if (last_state_and_change_duration.first == NState::QUEUED)
-            is_valid_state = true;
-        if (last_state_and_change_duration.first == NState::ABORTED)
-            is_valid_state = true;
-    }
-    if (!is_valid_state) {
-        return false;
-    }
-
-    if (relative_) {
-        time_duration time_elapsed = calendar.duration() - last_state_and_change_duration.second;
-        LOG_ASSERT(!time_elapsed.is_negative(), "should always be positive or some things gone wrong");
-        if (time_elapsed >= time_.duration()) {
-            return true;
-        }
-    }
-    else {
-        // real time
-        // #ifdef DEBUG
-        //     cout << "real time time_(" << to_simple_string(time_.duration())
-        //          << ") calendar.suiteTime().time_of_day(" << to_simple_string(calendar.suiteTime().time_of_day()) <<
-        //          ")\n";
-        // #endif
-        if (calendar.suiteTime().time_of_day() >= time_.duration()) {
-            return true;
-        }
-    }
-
-    return false;
-}
-
-template <class Archive>
-void AutoArchiveAttr::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(time_));
-    CEREAL_OPTIONAL_NVP(ar, relative_, [this]() { return !relative_; }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, days_, [this]() { return days_; });          // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, idle_, [this]() { return idle_; });          // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(AutoArchiveAttr);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/AutoArchiveAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_AutoArchiveAttr_HPP
-#define ecflow_attribute_AutoArchiveAttr_HPP
-
-#include <cstdint>
-
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/TimeSlot.hpp"
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-namespace ecf {
-
-// Use compiler ,  destructor, assignment, copy constructor
-class AutoArchiveAttr {
-public:
-    AutoArchiveAttr() = default;
-    AutoArchiveAttr(int hour, int minute, bool relative, bool idle = false)
-        : time_(hour, minute),
-          relative_(relative),
-          idle_(idle) {}
-    AutoArchiveAttr(const TimeSlot& ts, bool relative, bool idle = false)
-        : time_(ts),
-          relative_(relative),
-          idle_(idle) {}
-    explicit AutoArchiveAttr(int days, bool idle = false) : time_(TimeSlot(days * 24, 0)), days_(true), idle_(idle) {}
-
-    void print(std::string&) const;
-    bool operator==(const AutoArchiveAttr& rhs) const;
-    bool operator<(const AutoArchiveAttr& rhs) const { return time_ < rhs.time(); }
-    bool isFree(const ecf::Calendar&,
-                const std::pair<NState, boost::posix_time::time_duration>& last_state_and_change_duration) const;
-
-    std::string toString() const;
-
-    const TimeSlot& time() const { return time_; }
-    bool relative() const { return relative_; }
-    bool days() const { return days_; }
-    bool idle() const { return idle_; }
-
-private:
-    void write(std::string&) const;
-
-private:
-    TimeSlot time_;
-    bool relative_{true};
-    bool days_{false};
-    bool idle_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_attribute_AutoArchiveAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/AutoCancelAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/AutoCancelAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/AutoCancelAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/AutoCancelAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,103 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-#ifdef DEBUG
-    #include <boost/date_time/posix_time/time_formatters.hpp>
-#endif
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-namespace ecf {
-
-void AutoCancelAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += "\n";
-}
-
-std::string AutoCancelAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void AutoCancelAttr::write(std::string& ret) const {
-    ret += "autocancel ";
-    if (days_) {
-        ret += ecf::convert_to<std::string>(time_.hour() / 24);
-        return;
-    }
-
-    if (relative_)
-        ret += "+";
-    time_.print(ret);
-}
-
-bool AutoCancelAttr::operator==(const AutoCancelAttr& rhs) const {
-    if (relative_ != rhs.relative_)
-        return false;
-    if (days_ != rhs.days_)
-        return false;
-    return time_.operator==(rhs.time_);
-}
-
-bool AutoCancelAttr::isFree(const ecf::Calendar& calendar,
-                            const boost::posix_time::time_duration& suiteDurationAtComplete) const {
-    //                                                               suiteTime()
-    //  suiteDurationAtComplete        autocancel time               calendar duration
-    //        |                             |                             |
-    //        V                             V                             V
-    // ----------------------------------------------------------------------------------> time
-    //        ^                                                           ^
-    //        |--------elapsed time---------------------------------------|
-    //
-    //
-
-    if (relative_) {
-        time_duration timeElapsedAfterComplete = calendar.duration() - suiteDurationAtComplete;
-        LOG_ASSERT(!timeElapsedAfterComplete.is_negative(), "should always be positive or some things gone wrong");
-        if (timeElapsedAfterComplete >= time_.duration()) {
-            return true;
-        }
-    }
-    else {
-        // real time
-        // #ifdef DEBUG
-        //		cout << "real time time_(" << to_simple_string(time_.duration())
-        //		     << ") calendar.suiteTime().time_of_day(" <<
-        // to_simple_string(calendar.suiteTime().time_of_day()) << ")\n"; #endif
-        if (calendar.suiteTime().time_of_day() >= time_.duration()) {
-            return true;
-        }
-    }
-
-    return false;
-}
-
-template <class Archive>
-void AutoCancelAttr::serialize(Archive& ar, std::uint32_t const /*version*/) {
-    ar(CEREAL_NVP(time_));
-    CEREAL_OPTIONAL_NVP(ar, relative_, [this]() { return !relative_; }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, days_, [this]() { return days_; });          // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(AutoCancelAttr);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/AutoCancelAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/AutoCancelAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/AutoCancelAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/AutoCancelAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_AutoCancelAttr_HPP
-#define ecflow_attribute_AutoCancelAttr_HPP
-
-#include <cstdint>
-
-#include "ecflow/core/TimeSlot.hpp"
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-namespace ecf {
-
-// Use compiler ,  destructor, assignment, copy constructor
-class AutoCancelAttr {
-public:
-    AutoCancelAttr() = default;
-    AutoCancelAttr(int hour, int minute, bool relative) : time_(hour, minute), relative_(relative) {}
-    AutoCancelAttr(const TimeSlot& ts, bool relative) : time_(ts), relative_(relative) {}
-    explicit AutoCancelAttr(int days) : time_(TimeSlot(days * 24, 0)), days_(true) {}
-
-    void print(std::string&) const;
-    bool operator==(const AutoCancelAttr& rhs) const;
-    bool operator<(const AutoCancelAttr& rhs) const { return time_ < rhs.time(); }
-    bool isFree(const ecf::Calendar&, const boost::posix_time::time_duration& suiteDurationAtComplete) const;
-
-    std::string toString() const;
-
-    const TimeSlot& time() const { return time_; }
-    bool relative() const { return relative_; }
-    bool days() const { return days_; }
-
-private:
-    void write(std::string& ret) const;
-
-private:
-    TimeSlot time_;
-    bool relative_{true};
-    bool days_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_attribute_AutoCancelAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/ClockAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/ClockAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/ClockAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/ClockAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,221 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/ClockAttr.hpp"
-
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-//==========================================================================================
-
-ClockAttr::ClockAttr(const boost::posix_time::ptime& time, bool hybrid, bool positiveGain)
-    : gain_(0),
-      state_change_no_(Ecf::incr_state_change_no()),
-      hybrid_(hybrid),
-      positiveGain_(positiveGain) {
-    boost::gregorian::date theDate = time.date();
-    day_                           = theDate.day();
-    month_                         = theDate.month();
-    year_                          = theDate.year();
-
-    tm t  = to_tm(time);
-    gain_ = t.tm_hour * 3600 + t.tm_min * 60 + t.tm_sec;
-}
-
-ClockAttr::ClockAttr(int day, int month, int year, bool hybrid)
-    : gain_(0),
-      day_(day),
-      month_(month),
-      year_(year),
-      state_change_no_(Ecf::incr_state_change_no()),
-      hybrid_(hybrid) {
-    // Will throw std::out_of_range exception
-    DateAttr::checkDate(day, month, year, false /* for calendars we don't allow wild carding */);
-}
-
-ClockAttr::ClockAttr(bool hybrid) : state_change_no_(Ecf::incr_state_change_no()), hybrid_(hybrid) {
-}
-
-void ClockAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += "\n";
-}
-
-std::string ClockAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void ClockAttr::write(std::string& ss) const {
-    if (!end_clock_) {
-        ss += "clock ";
-        if (hybrid_)
-            ss += "hybrid ";
-        else
-            ss += "real ";
-    }
-    else {
-        ss += "endclock ";
-    }
-
-    if (day_ != 0) {
-        ss += ecf::convert_to<std::string>(day_);
-        ss += ".";
-        ss += ecf::convert_to<std::string>(month_);
-        ss += ".";
-        ss += ecf::convert_to<std::string>(year_);
-        ss += " ";
-    }
-
-    if (gain_ != 0) {
-        if (positiveGain_)
-            ss += "+";
-        ss += ecf::convert_to<std::string>(gain_);
-    }
-}
-
-bool ClockAttr::operator==(const ClockAttr& rhs) const {
-    if (hybrid_ != rhs.hybrid_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "hybrid_ != rhs.hybrid_\n";
-        }
-#endif
-        return false;
-    }
-
-    if (day_ != rhs.day_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "day(" << day_ << ") != rhs.day(" << rhs.day_ << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (month_ != rhs.month_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "month_(" << month_ << ") != rhs.month_(" << rhs.month_ << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (year_ != rhs.year_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "year_(" << year_ << ") != rhs.year_(" << rhs.year_ << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (gain_ != rhs.gain_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "gain_(" << gain_ << ") != rhs.gain_(" << rhs.gain_ << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (positiveGain_ != rhs.positiveGain_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "positiveGain_(" << positiveGain_ << ") != rhs.positiveGain_(" << rhs.positiveGain_ << ")\n";
-        }
-#endif
-        return false;
-    }
-
-    return true;
-}
-
-void ClockAttr::date(int day, int month, int year) {
-    // Will throw std::out_of_range exception
-    DateAttr::checkDate(day, month, year, false /* for calendars we don't allow wild carding */);
-    day_             = day;
-    month_           = month;
-    year_            = year;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ClockAttr::set_gain(int hour, int min, bool positiveGain) {
-    positiveGain_    = positiveGain;
-    gain_            = (hour * 3600) + min * 60;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ClockAttr::set_gain_in_seconds(long theGain, bool positiveGain) {
-    positiveGain_    = positiveGain;
-    gain_            = theGain;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ClockAttr::hybrid(bool f) {
-    hybrid_          = f;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ClockAttr::sync() {
-    // When begin_calendar() is called we will sync with computer clock.
-    positiveGain_    = false;
-    gain_            = 0;
-    day_             = 0;
-    month_           = 0;
-    year_            = 0;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ClockAttr::init_calendar(ecf::Calendar& calendar) {
-    Calendar::Clock_t clockType = (hybrid_) ? Calendar::HYBRID : Calendar::REAL;
-    calendar.init(clockType);
-}
-
-void ClockAttr::begin_calendar(ecf::Calendar& calendar) const {
-    calendar.begin(ptime());
-}
-
-boost::posix_time::ptime ClockAttr::ptime() const {
-    if (day_ != 0) {
-        // Use the date given. ie we start from midnight on the given day + gain.
-        boost::gregorian::date theDate(year_, month_, day_);
-        return {theDate, seconds(gain_)};
-    }
-
-    // Get the local time, second level resolution, based on the time zone settings of the computer.
-    boost::posix_time::ptime the_time(Calendar::second_clock_time());
-    the_time += seconds(gain_);
-    return the_time;
-}
-
-template <class Archive>
-void ClockAttr::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(hybrid_));
-    CEREAL_OPTIONAL_NVP(ar, positiveGain_, [this]() { return positiveGain_; });
-    CEREAL_OPTIONAL_NVP(ar, gain_, [this]() { return gain_ != 0; });
-    CEREAL_OPTIONAL_NVP(ar, day_, [this]() { return day_ != 0; });
-    CEREAL_OPTIONAL_NVP(ar, month_, [this]() { return month_ != 0; });
-    CEREAL_OPTIONAL_NVP(ar, year_, [this]() { return year_ != 0; });
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(ClockAttr);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/ClockAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/ClockAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/ClockAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/ClockAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_ClockAttr_HPP
-#define ecflow_attribute_ClockAttr_HPP
-
-#include <cstdint>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-namespace cereal {
-class access;
-}
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-/// The clock attribute is defined on the suite ONLY
-/// Use default copy constructor and assignment operator, destructor
-/// The clock attribute is used to initialise the calendar object
-/// **********************************************************************
-/// In the OLD sms the date is actually used as a gain factor(well at least
-/// according to the user/reference manual), in the ec-flow
-/// a date, is a date. i.e. it allows us to start a suite in the past.
-///
-/// The Constructor will update the State change number, since it can be added
-/// by the AlterCmd. in the Client Context, state change number is not incremented
-/// ************************************************************************
-///
-class ClockAttr {
-public:
-    /// The following constructor is used for test only. It allows us to
-    /// create a clock attribute initialised with given date and time
-    explicit ClockAttr(const boost::posix_time::ptime&, bool hybrid = false, bool positiveGain = true);
-    ClockAttr(int day, int month, int year, bool hybrid = false);
-    explicit ClockAttr(bool hybrid = false);
-
-    void print(std::string&) const;
-    bool operator==(const ClockAttr& rhs) const;
-
-    void date(int day, int month, int year);
-    void set_gain(int hour, int min, bool positiveGain = true);
-    void set_gain_in_seconds(long theGain, bool positiveGain = true);
-
-    void hybrid(bool f);
-    void set_end_clock() { end_clock_ = true; }
-
-    // clear local attributes so, than when we re-queue suite, we sync with computer clock
-    void sync();
-
-    void init_calendar(ecf::Calendar&);
-    void begin_calendar(ecf::Calendar&) const;
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    // access
-    int day() const { return day_; }
-    int month() const { return month_; }
-    int year() const { return year_; }
-    long gain() const { return gain_; }
-    bool positive_gain() const { return positiveGain_; }
-    bool hybrid() const { return hybrid_; }
-    std::string toString() const;
-    boost::posix_time::ptime ptime() const;
-
-private:
-    void write(std::string& os) const;
-
-private:
-    long gain_{0}; // in seconds
-    int day_{0};
-    int month_{0};
-    int year_{0};
-
-    unsigned int state_change_no_; // *not* persisted, only used on server side
-    bool hybrid_{false};
-    bool positiveGain_{false};
-    bool end_clock_{false}; // *NOT* persisted, used for end clock, simulator only
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_attribute_ClockAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/CronAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/CronAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/CronAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/CronAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,892 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/CronAttr.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
-#include <boost/token_functions.hpp>
-#include <boost/tokenizer.hpp>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-// #define DEBUG_CRON_ATTR 1
-// #define DEBUG_CRON_PARSING 1
-// #define DEBUG_CRON_SIM 1
-
-namespace ecf {
-
-CronAttr::CronAttr() = default;
-
-CronAttr::CronAttr(const std::string& str) {
-    if (str.empty())
-        throw std::runtime_error("CronAttr::CronAttr : empty string passed");
-    std::vector<std::string> tokens;
-    Str::split(str, tokens);
-    if (tokens.empty())
-        throw std::runtime_error("CronAttr::CronAttr : incorrect time string ?");
-
-    size_t index = 0;
-    timeSeries_  = TimeSeries::create(index, tokens, false /*parse_state*/);
-}
-
-void CronAttr::addWeekDays(const std::vector<int>& w) {
-    weekDays_ = w;
-    for (int day : weekDays_) {
-        if (day < 0 || day > 6) {
-            std::stringstream ss;
-            ss << "Invalid range for day(" << day << ") of the week expected range is 0==Sun to 6==Sat";
-            throw std::out_of_range(ss.str());
-        }
-        auto result = std::find(std::begin(last_week_days_of_month_), std::end(last_week_days_of_month_), day);
-        if (result != std::end(last_week_days_of_month_)) {
-            std::stringstream ss;
-            ss << "Duplicate day(" << day << ") of the week also found in last week day of the month";
-            throw std::runtime_error(ss.str());
-        }
-    }
-}
-void CronAttr::add_last_week_days_of_month(const std::vector<int>& w) {
-    last_week_days_of_month_ = w;
-    for (int day : last_week_days_of_month_) {
-        if (day < 0 || day > 6) {
-            std::stringstream ss;
-            ss << "Invalid range for day(" << day << ") of the week expected range is 0==Sun to 6==Sat";
-            throw std::out_of_range(ss.str());
-        }
-        auto result = std::find(std::begin(weekDays_), std::end(weekDays_), day);
-        if (result != std::end(weekDays_)) {
-            std::stringstream ss;
-            ss << "Duplicate last week day (" << day << ") of the month also found in week day";
-            throw std::runtime_error(ss.str());
-        }
-    }
-}
-
-void CronAttr::addDaysOfMonth(const std::vector<int>& d) {
-    daysOfMonth_ = d;
-    for (int day_of_month : daysOfMonth_) {
-        if (day_of_month < 1 || day_of_month > 31) {
-            std::stringstream ss;
-            ss << "Invalid range for day of month(" << day_of_month << ") expected range is  1-31";
-            throw std::out_of_range(ss.str());
-        }
-    }
-}
-
-void CronAttr::addMonths(const std::vector<int>& m) {
-    months_ = m;
-    for (int month : months_) {
-        if (month < 1 || month > 12) {
-            std::stringstream ss;
-            ss << "Invalid range for month(" << month << ")  expected range is 1==Jan to 12==Dec";
-            throw std::out_of_range(ss.str());
-        }
-    }
-}
-
-void CronAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        timeSeries_.write_state(os, free_);
-    }
-    os += "\n";
-}
-
-std::string CronAttr::name() const {
-    std::string ret;
-    write(ret);
-    timeSeries_.write_state_for_gui(ret, free_);
-    return ret;
-}
-
-std::string CronAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void CronAttr::write(std::string& ret) const {
-    ret += "cron ";
-    if (!weekDays_.empty()) {
-        ret += "-w ";
-        for (size_t i = 0; i < weekDays_.size(); ++i) {
-            ret += ecf::convert_to<std::string>(weekDays_[i]);
-            if (i != weekDays_.size() - 1)
-                ret += ",";
-        }
-        if (last_week_days_of_month_.empty())
-            ret += " ";
-        else
-            ret += ",";
-    }
-    if (!last_week_days_of_month_.empty()) {
-        if (weekDays_.empty())
-            ret += "-w ";
-        for (size_t i = 0; i < last_week_days_of_month_.size(); ++i) {
-            ret += ecf::convert_to<std::string>(last_week_days_of_month_[i]);
-            ret += 'L';
-            if (i != last_week_days_of_month_.size() - 1)
-                ret += ",";
-        }
-        ret += " ";
-    }
-
-    if (!daysOfMonth_.empty()) {
-        ret += "-d ";
-        for (size_t i = 0; i < daysOfMonth_.size(); ++i) {
-            ret += ecf::convert_to<std::string>(daysOfMonth_[i]);
-            if (i != daysOfMonth_.size() - 1)
-                ret += ",";
-        }
-        if (!last_day_of_month_)
-            ret += " ";
-    }
-    if (last_day_of_month_) {
-        if (daysOfMonth_.empty())
-            ret += "-d L ";
-        else
-            ret += ",L ";
-    }
-
-    if (!months_.empty()) {
-        ret += "-m ";
-        for (size_t i = 0; i < months_.size(); ++i) {
-            ret += ecf::convert_to<std::string>(months_[i]);
-            if (i != months_.size() - 1)
-                ret += ",";
-        }
-        ret += " ";
-    }
-
-    timeSeries_.write(ret); // no new line added, up to caller
-}
-
-std::string CronAttr::dump() const {
-    std::stringstream ss;
-    ss << toString();
-    if (free_)
-        ss << " (free)";
-    else
-        ss << " (holding)";
-    return ss.str();
-}
-
-bool CronAttr::operator==(const CronAttr& rhs) const {
-    if (free_ != rhs.free_) {
-        return false;
-    }
-    if (last_day_of_month_ != rhs.last_day_of_month_)
-        return false;
-    if (weekDays_ != rhs.weekDays_)
-        return false;
-    if (last_week_days_of_month_ != rhs.last_week_days_of_month_)
-        return false;
-    if (daysOfMonth_ != rhs.daysOfMonth_)
-        return false;
-    if (months_ != rhs.months_)
-        return false;
-    return timeSeries_.operator==(rhs.timeSeries_);
-}
-bool CronAttr::structureEquals(const CronAttr& rhs) const {
-    if (last_day_of_month_ != rhs.last_day_of_month_)
-        return false;
-    if (weekDays_ != rhs.weekDays_)
-        return false;
-    if (daysOfMonth_ != rhs.daysOfMonth_)
-        return false;
-    if (last_week_days_of_month_ != rhs.last_week_days_of_month_)
-        return false;
-    if (months_ != rhs.months_)
-        return false;
-    return timeSeries_.structureEquals(rhs.timeSeries_);
-}
-
-void CronAttr::calendarChanged(const ecf::Calendar& c) {
-    // ensure this called first , since we need always update for relative duration ECFLOW-1648
-    // This assumes that calendarChanged will set TimeSeries::isValid = true, at day change
-    if (timeSeries_.calendarChanged(c)) {
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-
-    if (free_) {
-        return;
-    }
-
-    // Once a cron is free, it stays free until re-queue
-    if (isFree(c)) {
-        setFree();
-    }
-    // A cron is always re-queable, hence we use isFree to control when it can actually run.
-}
-
-void CronAttr::resetRelativeDuration() {
-    if (timeSeries_.resetRelativeDuration()) {
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-}
-
-void CronAttr::setFree() {
-    free_            = true;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "CronAttr::setFree()\n";
-#endif
-}
-
-void CronAttr::clearFree() {
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "CronAttr::clearFree()\n";
-#endif
-}
-
-void CronAttr::miss_next_time_slot() {
-    // A cron attribute with a single time slot is repeated indefinitely hence always re-queues
-    timeSeries_.miss_next_time_slot();
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-// **************************************************************************************
-// FOR DEBUG THIS IS THE MAIN FUNCTION, AS THIS DECIDES WHETHER WE CONTINE OR STOP
-// **************************************************************************************
-bool CronAttr::checkForRequeue(const ecf::Calendar& calendar) const {
-    // checkForRequeue is called when a task/family has reach the complete state
-    // This simple checks if node should be put in re-queued state
-    // A cron is always re-queable
-
-    // Hence: In order to use this it should be used in conjunction with a
-    // with a parent node that has complete  expression, (& maybe a dummy task)
-    // This will allow its use with a parent repeat somewhere in the hierarchy
-    return true;
-}
-
-bool CronAttr::validForHybrid(const ecf::Calendar& calendar) const {
-    if (timeSeries_.hasIncrement()) {
-        if (last_day_of_month_)
-            return false; // relies on day change
-        if (!months_.empty())
-            return false; // relies on day change
-        if (!daysOfMonth_.empty())
-            return false; // relies on day change
-        if (!weekDays_.empty()) {
-            if (weekDays_.size() != 1)
-                return false; // relies on day change
-            return (weekDays_[0] == calendar.day_of_week());
-        }
-
-        // cron 10:00 20:00 01:00  // valid for hybrid ?
-        return true;
-    }
-
-    // A time series that does not have an increment runs indefinitely and hence relies on day change
-    // cron 23:00
-    return false;
-}
-
-bool CronAttr::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
-    // This will logically AND all the times
-    if (isFree(c))
-        return false;
-
-    // We are here because:
-    //  1/ Not on a valid time slot in the time series
-    //  *OR*
-    //  2/ Logical *AND* of day of week, day of month, or month returned false
-    theReasonWhy += "is cron dependent";
-
-    // Lets say that the time series was NOT free.
-    // First check if week day, day of month, month, matches
-    if (is_day_of_week_day_of_month_and_month_free(c)) {
-
-        if (timeSeries_.is_valid()) {
-
-            // This can apply to single and series
-            boost::posix_time::time_duration calendar_time = timeSeries_.duration(c);
-            if (calendar_time < timeSeries_.start().duration()) {
-                timeSeries_.why(c, theReasonWhy);
-                return true;
-            }
-
-            // calendar_time >= timeSeries_.start().duration()
-            if (timeSeries_.hasIncrement()) {
-                if (calendar_time < timeSeries_.finish().duration()) {
-                    timeSeries_.why(c, theReasonWhy);
-                    return true;
-                }
-            }
-        }
-        // calendar_time >= timeSeries_.start().duration() && calendar_time >= timeSeries_.finish().duration()
-        // past the end of time slot, find next valid date
-    }
-
-    // take into account, user can use run/force complete to miss time slots
-    bool do_a_requeue = timeSeries_.requeueable(c);
-    if (do_a_requeue && weekDays_.empty() && daysOfMonth_.empty() && months_.empty()) {
-        TimeSlot the_next_time_slot = timeSeries_.compute_next_time_slot(c);
-        if (the_next_time_slot.isNULL()) {
-            theReasonWhy += " ( *re-queue* to run at this time ";
-        }
-        else {
-            theReasonWhy += " ( *re-queue* to run at ";
-            theReasonWhy += the_next_time_slot.toString();
-        }
-
-        theReasonWhy += ", otherwise next run is at ";
-    }
-    else {
-        theReasonWhy += " ( next run is at ";
-    }
-
-    // Find the *NEXT* date that matches, and use the first time slot
-    boost::gregorian::date the_next_date = next_date(c);
-    theReasonWhy += timeSeries_.start().toString();
-    theReasonWhy += " ";
-    theReasonWhy += to_simple_string(the_next_date);
-
-    std::stringstream ss;
-    TimeSlot currentTime = TimeSlot(timeSeries_.duration(c));
-    ss << ", current time ";
-    if (timeSeries_.relative())
-        ss << "+";
-    ss << currentTime.toString() << " " << to_simple_string(c.date()) << " )";
-    theReasonWhy += ss.str();
-    return true;
-}
-
-void CronAttr::reset_only() {
-    clearFree();
-    timeSeries_.reset_only();
-}
-
-void CronAttr::reset(const ecf::Calendar& c) {
-    clearFree();
-    timeSeries_.reset(c);
-}
-
-void CronAttr::requeue(const ecf::Calendar& c, bool reset_next_time_slot) {
-    clearFree();
-    timeSeries_.requeue(c, reset_next_time_slot);
-}
-
-bool CronAttr::isFree(const ecf::Calendar& c) const {
-    // The FreeDepCmd can be used to free the crons,
-    if (free_) {
-        return true;
-    }
-
-    if (!timeSeries_.isFree(c))
-        return false;
-
-    // Ok time series is Free
-
-    // ********************************************************************
-    // IMPORTANT: when we have multiple week days, days of month and months
-    // Then we are *ONLY* free, if *ALL* are free, i.e we need AND behaviour
-    // ********************************************************************
-    return is_day_of_week_day_of_month_and_month_free(c);
-}
-
-bool CronAttr::is_day_of_week_day_of_month_and_month_free(const ecf::Calendar& c) const {
-#ifdef DEBUG_CRON_SIM
-    cout << toString() << "  cal : " << to_simple_string(c.date()) << " c.day_of_week:" << c.day_of_week()
-         << " c.day_of_month:" << c.day_of_month();
-    cout.flush();
-#endif
-
-    bool the_week_day_matches =
-        weekDays_.empty() && last_week_days_of_month_.empty(); // week day matches if no week days
-    bool the_day_of_month_matches = daysOfMonth_.empty();      // day of month if no days of month
-    bool the_month_matches        = months_.empty();           // month matches if no months
-
-    if (!weekDays_.empty())
-        the_week_day_matches = week_day_matches(c.day_of_week());
-    if (!the_week_day_matches && !last_week_days_of_month_.empty())
-        the_week_day_matches = last_week_day_of_month_matches(c);
-
-    if (!daysOfMonth_.empty() || last_day_of_month_)
-        the_day_of_month_matches = day_of_month_matches(c.day_of_month(), c);
-    if (!months_.empty())
-        the_month_matches = month_matches(c.month());
-
-    // Remember we *AND* across -w, -d, -m or *OR* for each element in -w, -d,-m
-    bool matches = false;
-    if (daysOfMonth_.empty() && !last_day_of_month_ && months_.empty()) {
-        // cron -w 0L 10:00    # run on the last sunday of each month
-        matches = the_week_day_matches; // only week day,
-    }
-    else {
-        matches = the_week_day_matches && the_day_of_month_matches && the_month_matches;
-    }
-
-#ifdef DEBUG_CRON_SIM
-    if (matches) {
-        cout << " *MATCHES*";
-    }
-    cout << "\n";
-#endif
-
-    return matches;
-}
-
-bool CronAttr::week_day_matches(int theDayOfWeek) const {
-    for (int theWeekDay : weekDays_) {
-        if (theDayOfWeek == theWeekDay)
-            return true;
-    }
-    return false;
-}
-
-bool CronAttr::last_week_day_of_month_matches(const ecf::Calendar& c) const {
-    int cal_day_of_week                                                     = c.day_of_week();
-    boost::gregorian::date last_day_of_month                                = c.date().end_of_month();
-    boost::gregorian::date_duration diff_current_date_and_last_day_of_month = last_day_of_month - c.date();
-
-    for (int cron_last_week_day_of_month : last_week_days_of_month_) {
-        if (cal_day_of_week == cron_last_week_day_of_month) {
-
-            if (diff_current_date_and_last_day_of_month.days() < 7) {
-                return true;
-            }
-        }
-    }
-    return false;
-}
-
-bool CronAttr::day_of_month_matches(int theDayOfMonth, const ecf::Calendar& c) const {
-    for (int dayOfMonth : daysOfMonth_) {
-        if (theDayOfMonth == dayOfMonth)
-            return true;
-    }
-    if (last_day_of_month_) {
-        return c.date() == c.date().end_of_month();
-    }
-    return false;
-}
-
-bool CronAttr::month_matches(int theMonth) const {
-    for (int month : months_) {
-        if (theMonth == month)
-            return true;
-    }
-    return false;
-}
-
-//------------------------------------------------------------------
-
-bool CronAttr::checkInvariants(std::string& errormsg) const {
-    return timeSeries_.checkInvariants(errormsg);
-}
-
-//--------------------------------------------------------------
-
-boost::gregorian::date CronAttr::next_date(const ecf::Calendar& calendar) const {
-    // Find the next date that matches, day of week, day of year, and month
-    // that is greater than todays date. This *ASSUMES* day of week, day of month,
-    // and month is *ANDED* together
-    boost::gregorian::date_duration one_day(1);
-    boost::gregorian::date future_date = calendar.date(); // todays date
-
-#ifdef DEBUG_CRON_SIM
-    cout << "cron : " << toString() << "\n";
-    cout << "future_date start : " << to_simple_string(future_date) << "\n";
-#endif
-    future_date += one_day; // add one day, so its in the future
-
-    while (true) {
-
-        bool week_day_matches                   = weekDays_.empty();                // week day matches if no week days
-        bool the_last_week_day_of_month_matches = last_week_days_of_month_.empty(); // matches if EMPTY
-        bool day_of_month_matches               = daysOfMonth_.empty();             // day of month if no days of month
-        bool month_matches                      = months_.empty();                  // month matches if no months
-        if (daysOfMonth_.empty() && last_day_of_month_)
-            day_of_month_matches = false;
-
-        // deal with case where we have: cron -w 0,1
-        for (int weekDay : weekDays_) {
-            if (future_date.day_of_week().as_number() == weekDay) {
-                week_day_matches = true;
-                break;
-            }
-        }
-        // *IMPORTANT* the days in weekDays_ and last_week_days_of_month_ can *NOT* overlap.
-        for (int weekDay : last_week_days_of_month_) {
-            if (future_date.day_of_week().as_number() == weekDay) {
-                boost::gregorian::date_duration diff = future_date - future_date.end_of_month();
-                if (diff.days() < 7) {
-                    the_last_week_day_of_month_matches = true;
-                }
-                break;
-            }
-        }
-
-        // deal with case where we have: cron  -d 14,15,16,L  # L means last day of month
-        if (!daysOfMonth_.empty() || last_day_of_month_) {
-            for (int d : daysOfMonth_) {
-                if (future_date.day() == d) {
-                    day_of_month_matches = true;
-                    break;
-                }
-            }
-            if (last_day_of_month_ && future_date == future_date.end_of_month()) {
-                day_of_month_matches = true;
-            }
-        }
-
-        // deal with case where we have: cron -w 0,1 -d 14,15,16 -m 8, 9
-        for (int month : months_) {
-            if (future_date.month() == month) {
-                month_matches = true;
-                break;
-            }
-        }
-
-        // if it all matches, then return the future day
-        // Remember we *AND* across -w, -d, -m or *OR* for each element in -w, -d,-m
-        if ((week_day_matches || the_last_week_day_of_month_matches) && day_of_month_matches && month_matches) {
-            break; // return future_date, replaced with break to  keep HPUX compiler happy
-                   // otherwise it complains that return at the end of the function is
-                   // unreachable
-        }
-
-        future_date += one_day;
-#ifdef DEBUG_CRON_SIM
-        cout << "future_date " << to_simple_string(future_date) << "\n";
-#endif
-    }
-    return future_date; // should never happen, i.e we can find future date that matches
-}
-
-//=========================================================================================================
-// code for parsing a cron:
-
-static bool isComment(const std::string& token) {
-    if (token.find("#") == std::string::npos)
-        return false;
-    return true;
-}
-
-static bool isTimeSpec(const std::string& token) {
-    if (token.find(Str::COLON()) == std::string::npos)
-        return false;
-    return true;
-}
-
-static bool isOption(const std::string& token) {
-    if (token.find("-w") != std::string::npos)
-        return true;
-    if (token.find("-d") != std::string::npos)
-        return true;
-    if (token.find("-m") != std::string::npos)
-        return true;
-    return false;
-}
-
-static std::string nextToken(size_t& index, const std::vector<std::string>& lineTokens) {
-    assert(index < lineTokens.size());
-    index++;
-    if (index < lineTokens.size()) {
-#ifdef DEBUG_CRON_PARSING
-        cerr << "nextToken lineTokens[" << index << "] = " << lineTokens[index] << "\n";
-#endif
-        return lineTokens[index];
-    }
-#ifdef DEBUG_CRON_PARSING
-    cerr << "nextToken empty \n";
-#endif
-    return string();
-}
-
-std::string extract_list(size_t& index, const std::vector<std::string>& lineTokens) {
-    // cron -w 0,1L,2L,3 -d 1,12,14,L   -m 5,6,7,8   10:00 20:00 01:00
-    assert(index < lineTokens.size());
-
-    // Collate the list of integers, these may have been separated by spaces
-    // since we stop on option or time spec, the top level code should decrement index
-    std::string theIntList;
-    while (index < lineTokens.size() && (!isOption(lineTokens[index]) || !isTimeSpec(lineTokens[index]))) {
-        string theNextToken = nextToken(index, lineTokens);
-        if (theNextToken.empty())
-            break;
-        if (isOption(theNextToken))
-            break;
-        if (isTimeSpec(theNextToken))
-            break;
-        theIntList += theNextToken;
-    }
-#ifdef DEBUG_CRON_PARSING
-    cerr << "theIntList = " << theIntList << "\n";
-#endif
-    return theIntList;
-}
-
-std::vector<int> extract_month(size_t& index, const std::vector<std::string>& lineTokens, const std::string& option) {
-    // cron -w 0,1L,2L,3 -d 1,12,14,L   -m 5,6,7,8   10:00 20:00 01:00
-    assert(index < lineTokens.size());
-
-    // Collate the list of integers, these may have been separated by spaces
-    // since we stop on option or time spec, the top level code should decrement index
-    std::string theIntList = extract_list(index, lineTokens);
-
-    // should have 0,1,2,3
-    std::vector<int> theIntVec;
-    char_separator<char> sep(",", nullptr, boost::drop_empty_tokens);
-    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
-    tokenizer theTokenizer(theIntList, sep);
-
-    for (tokenizer::iterator beg = theTokenizer.begin(); beg != theTokenizer.end(); ++beg) {
-        string theIntToken = *beg;
-        ecf::algorithm::trim(theIntToken);
-        if (theIntToken.empty())
-            continue;
-
-        try {
-            auto theInt = ecf::convert_to<int>(theIntToken);
-            theIntVec.push_back(theInt);
-        }
-        catch (const ecf::bad_conversion&) {
-            std::stringstream ss;
-            ss << "Invalid cron option: " << option;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    return theIntVec;
-}
-
-void extract_days_of_week(size_t& index,
-                          const std::vector<std::string>& lineTokens,
-                          const std::string& option,
-                          std::vector<int>& days_of_week,
-                          std::vector<int>& last_week_days_of_month) {
-    // cron -w 0,1L,2L,3 10:00 20:00 01:00
-    assert(index < lineTokens.size());
-
-    // Collate the list of integers, these may have been separated by spaces
-    // since we stop on option or time spec, the top level code should decrement index
-    std::string theIntList = extract_list(index, lineTokens);
-
-    // should have 0,1,2,3,4L
-    char_separator<char> sep(",", nullptr, boost::drop_empty_tokens);
-    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
-    tokenizer theTokenizer(theIntList, sep);
-
-    for (tokenizer::iterator beg = theTokenizer.begin(); beg != theTokenizer.end(); ++beg) {
-        string theIntToken = *beg;
-        ecf::algorithm::trim(theIntToken);
-        if (theIntToken.empty())
-            continue;
-
-        try {
-            if (theIntToken.size() == 2) {
-                if (theIntToken[1] != 'L') {
-                    std::stringstream ss;
-                    ss << "Invalid cron option: " << option << " " << theIntToken;
-                    throw std::runtime_error(ss.str());
-                }
-                auto theInt = ecf::convert_to<int>(theIntToken[0]);
-                last_week_days_of_month.push_back(theInt);
-            }
-            else {
-                auto theInt = ecf::convert_to<int>(theIntToken);
-                days_of_week.push_back(theInt);
-            }
-        }
-        catch (const ecf::bad_conversion&) {
-            std::stringstream ss;
-            ss << "Invalid cron option: " << option;
-            throw std::runtime_error(ss.str());
-        }
-    }
-}
-
-void extract_days_of_month(size_t& index,
-                           const std::vector<std::string>& lineTokens,
-                           const std::string& option,
-                           std::vector<int>& days_of_month,
-                           bool& last_day_of_month) {
-    // cron -d 1,12,14,L 10:00 20:00 01:00
-
-    assert(index < lineTokens.size());
-
-    // Collate the list of integers, these may have been separated by spaces
-    // since we stop on option or time spec, the top level code should decrement index
-    std::string theIntList = extract_list(index, lineTokens);
-
-    // should have 0,1,2,3,4L
-    char_separator<char> sep(",", nullptr, boost::drop_empty_tokens);
-    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
-    tokenizer theTokenizer(theIntList, sep);
-
-    for (tokenizer::iterator beg = theTokenizer.begin(); beg != theTokenizer.end(); ++beg) {
-        string theIntToken = *beg;
-        ecf::algorithm::trim(theIntToken);
-        if (theIntToken.empty())
-            continue;
-
-        try {
-            if (theIntToken == "L")
-                last_day_of_month = true;
-            else {
-                auto theInt = ecf::convert_to<int>(theIntToken);
-                days_of_month.push_back(theInt);
-            }
-        }
-        catch (const ecf::bad_conversion&) {
-            std::stringstream ss;
-            ss << "Invalid cron option: " << option;
-            throw std::runtime_error(ss.str());
-        }
-    }
-}
-
-void extractOption(CronAttr& cronAttr, size_t& index, const std::vector<std::string>& lineTokens) {
-    assert(index < lineTokens.size());
-    if (lineTokens[index] == "-w") {
-        std::vector<int> days_of_week;
-        std::vector<int> last_week_days_of_month;
-        extract_days_of_week(index, lineTokens, "week days", days_of_week, last_week_days_of_month);
-
-        cronAttr.addWeekDays(days_of_week);
-        cronAttr.add_last_week_days_of_month(last_week_days_of_month);
-    }
-    else if (lineTokens[index] == "-d") {
-        std::vector<int> days_of_month;
-        bool last_day_of_month = false;
-        extract_days_of_month(index, lineTokens, "Days of the month", days_of_month, last_day_of_month);
-
-        cronAttr.addDaysOfMonth(days_of_month);
-        if (last_day_of_month)
-            cronAttr.add_last_day_of_month();
-    }
-    else if (lineTokens[index] == "-m") {
-        cronAttr.addMonths(extract_month(index, lineTokens, "Months"));
-    }
-    else
-        throw std::runtime_error("extractOption: Invalid cron option :" + lineTokens[index]);
-}
-
-void CronAttr::parse(CronAttr& cronAttr, const std::vector<std::string>& lineTokens, size_t index, bool parse_state) {
-    // cron 23:00                 # run every day at 23:00
-    // cron 10:00 20:00 01:00     # run every hour between 10am and 8pm
-    // cron -w 0,1 10:00          # run every sunday and monday at 10am
-    // cron -d 10,11,12 12:00     # run 10th, 11th and 12th of each month at noon
-    // cron -m 1,2,3 12:00        # run on Jan,Feb and March every day at noon.
-    // cron -w 0 -m 5,6,7,8 10:00 20:00 01:00 # run every sunday, between May-Aug, every hour between 10am and 8pm
-    // cron -w 0,1,2L -d 5,6,L  23:00 # run every sunday,monday, and last tuesday of the month, 5,6 on month, and *last*
-    // day of month @11 pm
-
-    // make *sure* a time spec is specified
-    bool time_spec_specified = false;
-    size_t line_tokens_size  = lineTokens.size();
-    while (index < line_tokens_size) {
-
-        const std::string& token = lineTokens[index];
-#ifdef DEBUG_CRON_PARSING
-        cerr << "CronAttr::doParse " << token << "\n";
-#endif
-
-        if (isOption(token)) {
-#ifdef DEBUG_CRON_PARSING
-            cerr << "CronAttr::doParse isOption \n";
-#endif
-            extractOption(cronAttr, index, lineTokens);
-            index--; // since we did a look ahead
-        }
-        else if (!time_spec_specified && isTimeSpec(token)) {
-#ifdef DEBUG_CRON_PARSING
-            cerr << "CronAttr::doParse isTimeSpec \n";
-#endif
-            // index is passed by *reference*, and used skip over time series
-            cronAttr.addTimeSeries(TimeSeries::create(index, lineTokens, parse_state));
-            time_spec_specified = true;
-            if (parse_state) {
-                //  if index is on the comment, back track, so that we can add cron state( free)
-                if (index < line_tokens_size && lineTokens[index] == "#") {
-                    index--;
-                }
-            }
-            else
-                break; // need to read state after comment
-        }
-        else if (isComment(token)) {
-            // cron -m 1,2,3 12:00        # free
-            if (parse_state && index + 1 < line_tokens_size) {
-                if (lineTokens[index + 1] == "free") {
-                    cronAttr.setFree();
-                }
-            }
-            break;
-        }
-        index++;
-    }
-
-    if (!time_spec_specified) {
-        throw std::runtime_error("Invalid cron, no time specified");
-    }
-
-#ifdef DEBUG_CRON_PARSING
-    cronAttr.print(cerr);
-    cerr << "\n";
-#endif
-}
-
-CronAttr CronAttr::create(const std::string& cronString) {
-    std::vector<std::string> lineTokens;
-    Str::split(cronString, lineTokens);
-
-    CronAttr theCronAttr;
-    if (lineTokens.empty()) {
-        return theCronAttr;
-    }
-
-    // adjust the index
-    size_t index = 0;
-    if (lineTokens[0] == "cron") {
-        index = 1;
-    }
-
-    parse(theCronAttr, lineTokens, index);
-    return theCronAttr;
-}
-
-template <class Archive>
-void CronAttr::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(timeSeries_));
-    CEREAL_OPTIONAL_NVP(ar, weekDays_, [this]() { return !weekDays_.empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(
-        ar, last_week_days_of_month_, [this]() { return !last_week_days_of_month_.empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, daysOfMonth_, [this]() { return !daysOfMonth_.empty(); });         // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, months_, [this]() { return !months_.empty(); });                   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; });                                // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, last_day_of_month_, [this]() { return last_day_of_month_; });      // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, w_, [this]() { return w_ != 0; });                                 // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(CronAttr);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/CronAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/CronAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/CronAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/CronAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,140 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_CronAttr_HPP
-#define ecflow_attribute_CronAttr_HPP
-
-#include "ecflow/core/TimeSeries.hpp"
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-namespace ecf {
-
-// *****************************************************************
-// A cron attribute with a single time slot is repeated indefinitely
-// ******************************************************************
-// Use compiler ,  destructor, assignment, copy constructor,
-class CronAttr {
-public:
-    CronAttr();
-    explicit CronAttr(const std::string& time_series);
-    CronAttr(const TimeSlot& s, const TimeSlot& f, const TimeSlot& i) : timeSeries_(s, f, i) {}
-    explicit CronAttr(const TimeSeries& ts) : timeSeries_(ts) {}
-    CronAttr(int h, int m, bool relative = false) : timeSeries_(h, m, relative) {}
-
-    void print(std::string&) const;
-    bool operator==(const CronAttr& rhs) const;
-    bool operator<(const CronAttr& rhs) const { return timeSeries_ < rhs.timeSeries_; }
-    bool structureEquals(const CronAttr& rhs) const;
-
-    void addWeekDays(const std::vector<int>& w);
-    void add_last_week_days_of_month(const std::vector<int>& w);
-    void addDaysOfMonth(const std::vector<int>& d);
-    void add_last_day_of_month() { last_day_of_month_ = true; }
-    void addMonths(const std::vector<int>& m);
-
-    void addTimeSeries(const TimeSlot& s, const TimeSlot& f, const TimeSlot& i) { timeSeries_ = TimeSeries(s, f, i); }
-    void addTimeSeries(const TimeSeries& ts) { timeSeries_ = ts; }
-    void add_time_series(int h, int m, bool relative = false) { timeSeries_ = TimeSeries(h, m, relative); }
-
-    // Once a cron is free its stays free, until re-queue is called
-    void calendarChanged(const ecf::Calendar& c); // can set attribute free
-    void resetRelativeDuration();
-
-    void reset_only();
-    void reset(const ecf::Calendar& c);
-    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true);
-
-    void miss_next_time_slot();
-    void setFree(); // ensures that isFree() always returns true
-    bool isSetFree() const { return free_; }
-    bool isFree(const ecf::Calendar&) const;
-    bool checkForRequeue(const ecf::Calendar&) const;
-    bool validForHybrid(const ecf::Calendar&) const;
-    bool why(const ecf::Calendar&, std::string& theReasonWhy) const;
-    bool last_day_of_the_month() const { return last_day_of_month_; }
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    // Note: changes in state of timeSeries_, i.e affect the equality operator (used in test)
-    //       must be captured. i.e things like relative duration & next_time_slot are
-    //       reported by the Why command, & hence need to be synced.
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    bool checkInvariants(std::string& errormsg) const;
-
-    // Query:
-    const TimeSeries& time() const { return timeSeries_; }
-    const TimeSeries& time_series() const { return timeSeries_; }
-    bool last_day_of_month() const { return last_day_of_month_; }
-    std::vector<int>::const_iterator week_days_begin() const { return weekDays_.begin(); }
-    std::vector<int>::const_iterator week_days_end() const { return weekDays_.end(); }
-    std::vector<int>::const_iterator last_week_days_of_month_begin() const { return last_week_days_of_month_.begin(); }
-    std::vector<int>::const_iterator last_week_days_end_of_month_end() const { return last_week_days_of_month_.end(); }
-    std::vector<int>::const_iterator days_of_month_begin() const { return daysOfMonth_.begin(); }
-    std::vector<int>::const_iterator days_of_month_end() const { return daysOfMonth_.end(); }
-    std::vector<int>::const_iterator months_begin() const { return months_.begin(); }
-    std::vector<int>::const_iterator months_end() const { return months_.end(); }
-
-    std::string name() const; // for display/gui
-    std::string toString() const;
-    std::string dump() const;
-
-    /// parse the line tokens an create a cron attribute. Can throw std::runtime_error
-    /// The index parameter allows us to parse:
-    /// cron -w 0,1 10:00      // index = 1
-    /// -w 0,1 10:00           // index = 0
-    /// Expect to parse:
-    /// 	cron 23:00                 # run every day at 23:00
-    /// 	cron 10:00 20:00 01:00     # run every hour between 10am and 8pm
-    ///   cron -w 0,1 10:00          # run every sunday and monday at 10am
-    ///   cron -w 0,1L  10:00        # run every sunday and last monday of the month at 10am
-    ///   cron -d 10,11,12 12:00     # run 10th, 11th and 12th of each month at noon
-    ///   cron -d 10,L     12:00     # run 10th, and last day of the month at noon
-    /// 	cron -m 1,2,3 12:00        # run on Jan,Feb and March every day at noon.
-    ///   cron -w 0   -m 5,6,7,8 10:00 20:00 01:00 # run every sunday, between May-Aug, every hour between 10am and 8pm
-    ///   cron -d 1,L -m 5,6,7,8 10:00 20:00 01:00 # run on first and last day of month, between May-Aug, every hour
-    ///   between 10am and 8pm
-    static void parse(CronAttr&, const std::vector<std::string>& lineTokens, size_t index, bool parse_state = false);
-    static CronAttr create(const std::string& cronString);
-
-private:
-    void write(std::string&) const;
-
-private:
-    void clearFree(); // resets the free flag
-    bool is_day_of_week_day_of_month_and_month_free(const ecf::Calendar&) const;
-
-    bool week_day_matches(int) const;
-    bool last_week_day_of_month_matches(const ecf::Calendar&) const;
-    bool day_of_month_matches(int, const ecf::Calendar& c) const;
-    bool month_matches(int) const;
-
-    boost::gregorian::date next_date(const ecf::Calendar& calendar) const;
-
-    TimeSeries timeSeries_;
-    std::vector<int> weekDays_;
-    std::vector<int> last_week_days_of_month_;
-    std::vector<int> daysOfMonth_;
-    std::vector<int> months_;
-    unsigned int w_{0};               // NOT implemented, weekday nearest the given day of the month 15W
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool last_day_of_month_{false};
-    bool free_{false}; // persisted for use by why() on client side
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_attribute_CronAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/DateAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/DateAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/DateAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/DateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,400 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/DateAttr.hpp"
-
-#include <ostream>
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-//==========================================================================================
-
-DateAttr::DateAttr(int day, int month, int year) : day_(day), month_(month), year_(year) {
-    checkDate(day_, month_, year_, true /* allow wild cards */);
-}
-
-DateAttr::DateAttr(const std::string& str) {
-    DateAttr::getDate(str, day_, month_, year_);
-    checkDate(day_, month_, year_, true /* allow wild cards */);
-}
-
-bool DateAttr::operator<(const DateAttr& rhs) const {
-    if (year_ < rhs.year_)
-        return true;
-    if (year_ == rhs.year_) {
-        if (month_ < rhs.month_)
-            return true;
-        if (month_ == rhs.month_) {
-            return day_ < rhs.day_;
-        }
-    }
-    return false;
-}
-
-void DateAttr::checkDate(int day, int month, int year, bool allow_wild_cards) {
-    if (allow_wild_cards) {
-        if (day != 0 && (day < 1 || day > 31)) {
-            throw std::out_of_range(
-                "Invalid Date(day,month,year) : the day >= 0 and day < 31, where 0 means wild card ");
-        }
-        if (month != 0 && (month < 1 || month > 12)) {
-            throw std::out_of_range(
-                "Invalid Date(day,month,year): the month >=0 and month <= 12, where 0 means wild card");
-        }
-        if (year < 0) {
-            throw std::out_of_range("Invalid Date(day,month,year): the year >=0, where 0 means wild card");
-        }
-    }
-    else {
-        if (day < 1 || day > 31) {
-            throw std::out_of_range("Invalid date attribute : the day >= 1 and day < 31");
-        }
-        if (month < 1 || month > 12) {
-            throw std::out_of_range("Invalid date attribute: the month >=1 and month <= 12");
-        }
-        if (year <= 0) {
-            throw std::out_of_range("Invalid date attribute: the year >0");
-        }
-    }
-
-    if (day != 0 && month != 0 && year != 0) {
-
-        // let boost validate the date
-        boost::gregorian::date theDate(year, month, day);
-    }
-}
-
-void DateAttr::calendarChanged(const ecf::Calendar& c, bool clear_at_midnight) {
-    // See ECFLOW-337 versus ECFLOW-1550
-    if (c.dayChanged()) {
-        if (clear_at_midnight)
-            clearFree();
-    }
-
-    if (free_) {
-        return;
-    }
-
-    if (is_free(c)) {
-        setFree();
-    }
-}
-
-void DateAttr::reset() {
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void DateAttr::requeue() {
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void DateAttr::setFree() {
-    free_            = true;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "DateAttr::setFree()\n";
-#endif
-}
-
-void DateAttr::clearFree() {
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "DateAttr::clearFree()\n";
-#endif
-}
-
-bool DateAttr::isFree(const ecf::Calendar& calendar) const {
-    // The FreeDepCmd can be used to free the dates,
-    if (free_) {
-        return true;
-    }
-    return is_free(calendar);
-}
-
-bool DateAttr::is_free(const ecf::Calendar& calendar) const {
-    bool dayMatches   = true;
-    bool monthMatches = true;
-    bool yearMatches  = true;
-    if (day_ != 0)
-        dayMatches = calendar.day_of_month() == day_;
-    if (month_ != 0)
-        monthMatches = calendar.month() == month_;
-    if (year_ != 0)
-        yearMatches = calendar.year() == year_;
-
-    return (dayMatches && monthMatches && yearMatches);
-}
-
-bool DateAttr::checkForRequeue(const ecf::Calendar& calendar) const {
-    // if calendar is hybrid, we can't re-queue
-    if (calendar.hybrid()) {
-        return false;
-    }
-
-    // checkForRequeue is called when we are deciding whether to re-queue the node.
-    // If this date is in the future, they we should re-queue
-    if (day_ != 0 && month_ != 0 && year_ != 0) {
-        date theDate(year_, month_, day_);
-        if (theDate > calendar.date()) {
-            // #ifdef DEBUG
-            //			cout << toString() << "   > " << " calendar date " << to_simple_string( calendar.date())
-            //<<
-            //"\n"; #endif
-            return true;
-        }
-        return false;
-    }
-
-    bool futureDayMatches   = true;
-    bool futureMonthMatches = true;
-    bool futureYearMatches  = true;
-    if (day_ != 0)
-        futureDayMatches = day_ > calendar.day_of_month();
-    if (month_ != 0)
-        futureMonthMatches = month_ > calendar.month();
-    if (year_ != 0)
-        futureYearMatches = year_ > calendar.year();
-
-    // #ifdef DEBUG
-    //   	if ( futureDayMatches ) {
-    //  		cout << "futureDayMatches " << toString() << " > " << calendar.day_of_month() << "\n";
-    //  	}
-    //	if ( futureMonthMatches ) {
-    //  		cout << "futureMonthMatches " << toString() << " > " << calendar.month() << "\n";
-    //  	}
-    //	if ( futureYearMatches ) {
-    //  		cout << "futureYearMatches " << toString() << " > " << calendar.year() << "\n";
-    //  	}
-    // #endif
-
-    return (futureDayMatches || futureMonthMatches || futureYearMatches);
-}
-
-bool DateAttr::validForHybrid(const ecf::Calendar& calendar) const {
-    if (day_ == 0)
-        return false; // relies on day change i.e. date *.10.2009
-    if (month_ == 0)
-        return false; // relies on day change i.e. date 12.*.2009
-    if (year_ == 0)
-        return false; // relies on day change i.e. date 12.10.*
-
-    // if the date matches exactly for today
-    return (day_ == calendar.day_of_month() && month_ == calendar.month() && year_ == calendar.year());
-}
-
-bool DateAttr::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
-    if (isFree(c))
-        return false;
-
-    std::stringstream ss;
-    ss << " is date dependent ( next run on " << to_simple_string(next_matching_date(c)) << " the current date is ";
-    ss << c.day_of_month() << "/" << c.month() << "/" << c.year() << " )";
-    theReasonWhy += ss.str();
-    return true;
-}
-
-void DateAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        if (free_) {
-            os += " # free";
-        }
-    }
-    os += "\n";
-}
-
-std::string DateAttr::name() const {
-    std::string os;
-    write(os);
-    if (free_) {
-        os += " # free";
-    }
-    return os;
-}
-
-std::string DateAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void DateAttr::write(std::string& ret) const {
-    ret += "date ";
-    if (day_ == 0)
-        ret += "*.";
-    else {
-        ret += ecf::convert_to<std::string>(day_);
-        ret += ".";
-    }
-
-    if (month_ == 0)
-        ret += "*.";
-    else {
-        ret += ecf::convert_to<std::string>(month_);
-        ret += ".";
-    }
-
-    if (year_ == 0)
-        ret += "*";
-    else
-        ret += ecf::convert_to<std::string>(year_);
-}
-
-std::string DateAttr::dump() const {
-    std::stringstream ss;
-    ss << toString();
-    if (free_)
-        ss << " (free)";
-    else
-        ss << " (holding)";
-    return ss.str();
-}
-
-bool DateAttr::operator==(const DateAttr& rhs) const {
-    if (free_ != rhs.free_) {
-        return false;
-    }
-    return structureEquals(rhs);
-}
-bool DateAttr::structureEquals(const DateAttr& rhs) const {
-    if (day_ != rhs.day_)
-        return false;
-    if (month_ != rhs.month_)
-        return false;
-    if (year_ != rhs.year_)
-        return false;
-    return true;
-}
-
-DateAttr DateAttr::create(const std::string& dateString) {
-    int day = -1, month = -1, year = -1;
-    getDate(dateString, day, month, year);
-    return {day, month, year};
-}
-
-DateAttr DateAttr::create(const std::vector<std::string>& lineTokens, bool read_state) {
-    //  date 15.11.2009 # free   // with PersistStyle::STATE & MIGRATE
-    //  date 15.*.*     #
-    //  date *.1.*
-
-    //   for(size_t i =0; i < lineTokens.size() ; i++) {
-    //      cout << "lineTokens[" << i << "] = '" << lineTokens[i] << "'\n";
-    //   }
-
-    DateAttr date = DateAttr::create(lineTokens[1]);
-    if (read_state) {
-        for (size_t i = 3; i < lineTokens.size(); i++) {
-            if (lineTokens[i] == "free")
-                date.setFree();
-        }
-    }
-    return date;
-}
-
-void DateAttr::getDate(const std::string& date, int& day, int& month, int& year) {
-    size_t firstDotPos = date.find_first_of('.');
-    size_t lastDotPos  = date.find_first_of('.', firstDotPos + 1);
-    if (firstDotPos == std::string::npos)
-        throw std::runtime_error("DateAttr::getDate Invalid date missing first dot :" + date);
-    if (lastDotPos == std::string::npos)
-        throw std::runtime_error("DateAttr::getDate: Invalid date missing second dot :" + date);
-    if (firstDotPos == lastDotPos)
-        throw std::runtime_error("DateAttr::getDate: Invalid date :" + date);
-
-    std::string theDay   = date.substr(0, firstDotPos);
-    std::string theMonth = date.substr(firstDotPos + 1, (lastDotPos - firstDotPos) - 1);
-    std::string theYear  = date.substr(lastDotPos + 1);
-
-    if (theDay == "*")
-        day = 0;
-    else {
-        day = Extract::theInt(theDay, "DateAttr::getDate: Invalid day :" + date);
-        if (day < 1 || day > 31)
-            throw std::runtime_error("DateAttr::getDate: Invalid clock date: " + date);
-    }
-
-    if (theMonth == "*")
-        month = 0;
-    else {
-        month = Extract::theInt(theMonth, "DateAttr::getDate: Invalid month :" + date);
-        if (month < 1 || month > 12)
-            throw std::runtime_error("DateAttr::getDate Invalid clock date: " + date);
-    }
-
-    if (theYear == "*")
-        year = 0;
-    else
-        year = Extract::theInt(theYear, "DateAttr::getDate: Invalid year :" + date);
-
-    if (day == -1 || month == -1 || year == -1)
-        throw std::runtime_error("DateAttr::getDate: Invalid clock date:" + date);
-
-    // let boost validate the date
-    if (day != 0 && month != 0 && year != 0) {
-
-        boost::gregorian::date theDate(year, month, day);
-    }
-
-    //	cerr << " DateParser::getDate date=" << date << " day=" << day << " month=" << month << " year=" << year <<
-    //"\n";
-}
-
-boost::gregorian::date DateAttr::next_matching_date(const ecf::Calendar& c) const {
-    boost::gregorian::date next_matching_date = c.date(); // todays date
-
-    boost::gregorian::date_duration one_day(1);
-
-    bool day_matches   = (day_ == 0) ? true : false;
-    bool month_matches = (month_ == 0) ? true : false;
-    bool year_matches  = (year_ == 0) ? true : false;
-    ;
-
-    for (int i = 0; i < 365; i++) {
-        next_matching_date += one_day;
-        if (day_ != 0 && next_matching_date.day() == day_)
-            day_matches = true;
-        if (month_ != 0 && next_matching_date.month() == month_)
-            month_matches = true;
-        if (year_ != 0 && next_matching_date.year() == year_)
-            year_matches = true;
-        if (day_matches && month_matches && year_matches) {
-            return next_matching_date;
-        }
-    }
-    return c.date();
-}
-
-template <class Archive>
-void DateAttr::serialize(Archive& ar) {
-    ar(CEREAL_NVP(day_), CEREAL_NVP(month_), CEREAL_NVP(year_));
-    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE(DateAttr);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/DateAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/DateAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/DateAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/DateAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_DateAttr_HPP
-#define ecflow_attribute_DateAttr_HPP
-
-///
-/// \note calendarChanged() once a Date is free, it stays free. It relies on parent cron/repeat to re-queue
-///
-
-#include <string>
-#include <vector>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-namespace cereal {
-class access;
-}
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-// Use default copy constructor, assignment operator, destructor
-// Value of 0 for day,month,year means *, i.e. means any value
-class DateAttr {
-public:
-    DateAttr(int day, int month, int year); // will throw std::out_of_range for if invalid date
-    explicit DateAttr(const std::string&);  // will throw std::runtime_error for if invalid date
-    DateAttr() = default;                   // for serialisation
-    explicit DateAttr(const boost::gregorian::date& date)
-        : day_(date.day()),
-          month_(date.month()),
-          year_(date.year()) {} // for test
-
-    void print(std::string&) const;
-    bool operator==(const DateAttr& rhs) const;
-    bool operator<(const DateAttr& rhs) const;
-    bool structureEquals(const DateAttr& rhs) const;
-
-    void reset();
-    void requeue();
-
-    void setFree();   // ensures that isFree() always returns true
-    void clearFree(); // resets the free flag
-    bool isSetFree() const { return free_; }
-    void calendarChanged(const ecf::Calendar& c, bool clear_at_midnight = true); // can set attribute free
-    bool isFree(const ecf::Calendar&) const;
-    bool checkForRequeue(const ecf::Calendar&) const;
-    bool validForHybrid(const ecf::Calendar&) const;
-    bool why(const ecf::Calendar&, std::string& theReasonWhy) const;
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    std::string name() const; // for display/gui only
-    std::string toString() const;
-    std::string dump() const;
-
-    /// Check the date, will throw std::out_of_range or derivative if invalid
-    static void checkDate(int day, int month, int year, bool allow_wild_cards);
-
-    /// Extract the date, if return integer is zero, date was of the *, i.e. any day,month,year
-    /// will throw std::runtime_error for parse errors
-    /// expect:
-    ///    15.11.2009
-    ///    15.*.*
-    ///    *.1.*
-    static void getDate(const std::string& date, int& day, int& month, int& year);
-    static DateAttr create(const std::string& dateString);
-    static DateAttr create(const std::vector<std::string>& lineTokens, bool read_state);
-
-    boost::gregorian::date next_matching_date(const ecf::Calendar&) const;
-
-    // access
-    int day() const { return day_; }
-    int month() const { return month_; }
-    int year() const { return year_; }
-
-    bool is_free(const ecf::Calendar&) const; // ignores free_
-private:
-    void write(std::string&) const;
-
-private:
-    int day_{0};
-    int month_{0};
-    int year_{0};
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool free_{false};                // persisted for use by why() on client side
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_attribute_DateAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/DayAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/DayAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/DayAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/DayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,557 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/DayAttr.hpp"
-
-#include <cassert>
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/cereal_boost_time.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-
-// #define DEBUG_DAYS 1
-
-//===============================================================================
-
-static const char* theDay(DayAttr::Day_t day) {
-    switch (day) {
-        case DayAttr::SUNDAY:
-            return "sunday";
-            break;
-        case DayAttr::MONDAY:
-            return "monday";
-            break;
-        case DayAttr::TUESDAY:
-            return "tuesday";
-            break;
-        case DayAttr::WEDNESDAY:
-            return "wednesday";
-            break;
-        case DayAttr::THURSDAY:
-            return "thursday";
-            break;
-        case DayAttr::FRIDAY:
-            return "friday";
-            break;
-        case DayAttr::SATURDAY:
-            return "saturday";
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    return nullptr;
-}
-
-//===============================================================================
-
-void DayAttr::calendarChanged(const ecf::Calendar& c, bool clear_at_midnight) {
-    // See ECFLOW-337
-    //	repeat ....
-    //    family start
-    //      family 0
-    //        time 10:00
-    //        day monday        # if there was no c.dayChanged(), then after re-queue, & before midnight Monday is still
-    //        free. task dummy        # hence we will end up also running on Tuesday at 10:00
-    //          complete 1==1
-    //          trigger 0==1
-    //
-    //  ECFLOW-1550            # If children of a family with day/date are still active/submitted/queued, then don't
-    //  clear at midnight. repeat ....            # This is only applicable for NodeContainers, for task with day/date
-    //  always CLEAR at midnight
-    //	family f1
-    //	   day monday
-    //	   time 23:00
-    //	   task t1             # Task t1 took longer than 1 hour
-    //	   task t2             # allow task t2 to continue to the next day, i.e clear_at_midnight = False
-    //	      trigger t1 == complete
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::calendarChanged " << dump() << " clear_at_midnight " << clear_at_midnight
-         << " calendar:" << c.suite_time_str() << "\n";
-#endif
-    if (expired_) {
-        // ********* TREAT this Day Attribute as deleted ECFLOW-128 **********
-        return;
-    }
-
-    if (c.dayChanged()) {
-        if (clear_at_midnight) {
-            clearFree();
-#ifdef DEBUG_DAYS
-            cout << " DayAttr::calendarChanged MIDNIGHT " << dump() << " calendar:" << c.suite_time_str() << "\n";
-#endif
-        }
-    }
-
-    if (free_) {
-        return;
-    }
-
-    if (is_free(c)) {
-        setFree();
-#ifdef DEBUG_DAYS
-        cout << " DayAttr::calendarChanged SET FREE " << dump() << " calendar:" << c.suite_time_str() << "\n";
-#endif
-    }
-}
-
-void DayAttr::reset() {
-    expired_         = false;
-    free_            = false;
-    date_            = boost::gregorian::date();
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::reset :" << dump() << "\n";
-#endif
-}
-
-void DayAttr::handle_migration(const ecf::Calendar& c) {
-    // <TODO> temp once in Bologna, and when ecflow4 no longer used.
-    if (date_.is_special()) {
-        if (!c.is_special()) {
-            date_ = matching_date(c);
-        }
-    }
-}
-
-void DayAttr::reset(const ecf::Calendar& c) {
-    reset();
-    date_ = matching_date(c);
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::reset(calendar) :" << dump() << " calendar:" << c.suite_time_str() << "\n";
-#endif
-}
-
-void DayAttr::requeue_time() {
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::requeue " << dump() << "\n";
-#endif
-
-    if (expired_) {
-        // ********* TREAT this Day Attribute as deleted **********
-#ifdef DEBUG_DAYS
-        cout << " DayAttr::requeue_time " << dump() << " EXPIRED(do nothing) returning\n";
-#endif
-        return;
-    }
-
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void DayAttr::requeue_manual(const ecf::Calendar& c) {
-    reset();
-    date_ = matching_date(c);
-
-#ifdef DEBUG_DAYS
-    cout << "  DayAttr::requeue_manual(calendar) " << dump() << " calendar:" << c.suite_time_str() << "\n";
-#endif
-}
-
-void DayAttr::requeue_repeat_increment(const ecf::Calendar& c) {
-    reset();
-    date_ = next_matching_date(c);
-
-#ifdef DEBUG_DAYS
-    cout << "  DayAttr::requeue_repeat_increment(calendar) " << dump() << " calendar:" << c.suite_time_str() << "\n";
-#endif
-}
-
-bool DayAttr::isFree(const ecf::Calendar& c) const {
-    if (expired_) {
-        // ********* TREAT this Day Attribute as deleted **********
-#ifdef DEBUG_DAYS
-        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " HOLDING due to EXPIRED flag\n";
-#endif
-        return false;
-    }
-
-    // The FreeDepCmd can be used to free the dates,
-    if (free_) {
-#ifdef DEBUG_DAYS
-        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " FREE free_ = TRUE\n";
-#endif
-        return true;
-    }
-
-    bool res = is_free(c);
-
-#ifdef DEBUG_DAYS
-    if (res)
-        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " date is FREE\n";
-    else
-        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " date is HOLDING\n";
-#endif
-    return res;
-}
-
-bool DayAttr::is_free(const ecf::Calendar& c) const {
-    return (c.date() == date_);
-}
-
-void DayAttr::setFree() {
-    free_            = true;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::setFree() " << dump() << "\n";
-#endif
-}
-
-void DayAttr::clearFree() {
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::clearFree() " << dump() << "\n";
-#endif
-}
-
-void DayAttr::set_expired() {
-    expired_         = true;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::set_expired() " << dump() << "\n";
-#endif
-}
-
-void DayAttr::clear_expired() {
-    expired_         = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::clear_expired() " << dump() << "\n";
-#endif
-}
-
-void DayAttr::check_for_expiration(const ecf::Calendar& c) {
-#ifdef DEBUG_DAYS
-    cout << "DayAttr::check_for_expiration " << dump() << " calendar:" << c.suite_time_str() << "\n";
-#endif
-    // This function is called when a Node has COMPLETED. Avoid running again on same day date <= calendar, expire the
-    // date Note: time attribute, they get handled before. i.e allowing multiple re-queues on the same date This
-    // function *MUST* be called before checkForRequeue.
-
-    if (date_.is_special()) {
-        // migration 4->5, or 5->5 from checkpoint
-        date_ = matching_date(c);
-    }
-
-    if (day_ == c.day_of_week()) {
-        set_expired();
-        return;
-    }
-
-    if (date_ <= c.date()) {
-        set_expired();
-    }
-}
-
-bool DayAttr::checkForRequeue(const ecf::Calendar& c) const {
-    if (expired_) {
-#ifdef DEBUG_DAYS
-        cout << " DayAttr::check_for_requeue ALREADY EXPIRED " << dump() << " calendar:" << c.suite_time_str()
-             << "  HOLDING <<<<<<<<<<<<\n";
-#endif
-        return false;
-    }
-
-    // if calendar is hybrid, we can't requeue
-    if (c.hybrid()) {
-        return false;
-    }
-
-    // checkForRequeue is called when we are deciding whether to re-queue the node
-    // Hence we *MUST* have completed. Also crons,time,today have all returned false.
-    // *IF* this date is in the future, they we should re-queue
-
-    assert(!date_.is_special());
-
-    bool future_date = (date_ > c.date());
-
-#ifdef DEBUG_DAYS
-    cout << " DayAttr::check_for_requeue " << dump() << " calendar:" << c.suite_time_str() << " returning "
-         << future_day << " ************\n";
-#endif
-    return future_date;
-}
-
-bool DayAttr::validForHybrid(const ecf::Calendar& calendar) const {
-    return isFree(calendar);
-}
-
-bool DayAttr::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
-    if (isFree(c))
-        return false;
-
-    theReasonWhy += " is day dependent ( next run on ";
-    theReasonWhy += theDay(day_);
-    theReasonWhy += " ";
-    if (date_.is_special())
-        theReasonWhy += to_simple_string(next_matching_date(c));
-    else
-        theReasonWhy += to_simple_string(date_);
-    theReasonWhy += " the current day is ";
-    theReasonWhy += theDay(static_cast<DayAttr::Day_t>(c.day_of_week()));
-    theReasonWhy += " )";
-    return true;
-}
-
-void DayAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        bool added_hash = false;
-        if (free_) {
-            os += " # free";
-            added_hash = true;
-        }
-        if (expired_) {
-            if (added_hash)
-                os += " expired";
-            else
-                os += " # expired";
-            added_hash = true;
-        }
-
-        if (added_hash) {
-            os += " date:";
-            os += to_simple_string(date_);
-        }
-        else {
-            os += " # date:";
-            os += to_simple_string(date_);
-        }
-    }
-    os += "\n";
-}
-
-std::string DayAttr::name() const {
-    // for display/GUI only
-    std::string os;
-    write(os);
-    bool added_hash = false;
-
-    if (expired_) {
-        os += " # expired";
-        added_hash = true;
-    }
-    else {
-        if (free_) {
-            os += " # free";
-            added_hash = true;
-        }
-    }
-
-    if (added_hash) {
-        os += " ";
-        os += to_simple_string(date_);
-    }
-    else {
-        os += " # ";
-        os += to_simple_string(date_);
-    }
-
-    return os;
-}
-
-std::string DayAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void DayAttr::write(std::string& ret) const {
-    ret += "day ";
-    ret += theDay(day_);
-}
-
-std::string DayAttr::dump() const {
-    std::stringstream ss;
-    ss << toString();
-    if (free_)
-        ss << " (free)";
-    if (expired_)
-        ss << " (expired)";
-    ss << " " << to_simple_string(date_);
-    return ss.str();
-}
-
-bool DayAttr::operator==(const DayAttr& rhs) const {
-    if (free_ != rhs.free_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "DayAttr::operator== free_ != rhs.free_   (free_:" << free_ << " rhs.free_:" << rhs.free_
-                      << ") " << dump() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (expired_ != rhs.expired_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "DayAttr::operator== expired_ != rhs.expired_   (expired_:" << expired_
-                      << " rhs.expired_:" << rhs.expired_ << ") " << dump() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (date_ != rhs.date_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "DayAttr::operator== date_ != rhs.date_   (date_:" << date_ << " rhs.date_:" << rhs.date_
-                      << ") " << dump() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    return structureEquals(rhs);
-}
-
-bool DayAttr::structureEquals(const DayAttr& rhs) const {
-    return (day_ == rhs.day_);
-}
-
-DayAttr DayAttr::create(const std::string& dayStr) {
-    return DayAttr(getDay(dayStr));
-}
-
-DayAttr DayAttr::create(const std::vector<std::string>& lineTokens, bool read_state) {
-    if (lineTokens.size() < 2) {
-        throw std::runtime_error("DayAttr::create date tokens to short :");
-    }
-
-    //   for(size_t i =0; i < lineTokens.size() ; i++) {
-    //      cout << "lineTokens[" << i << "] = '" << lineTokens[i] << "'\n";
-    //   }
-
-    // day monday  # free expired date:****
-    // day monday  # expired
-    DayAttr day = DayAttr::create(lineTokens[1]);
-
-    // state
-    if (read_state) {
-        day.read_state(lineTokens);
-    }
-    return day;
-}
-
-void DayAttr::read_state(const std::vector<std::string>& lineTokens) {
-    std::string date;
-
-    for (size_t i = 3; i < lineTokens.size(); i++) {
-        if (lineTokens[i] == "free")
-            free_ = true;
-        else if (lineTokens[i] == "expired")
-            expired_ = true;
-        else if (lineTokens[i].find("date:") != std::string::npos) {
-            if (!Extract::split_get_second(lineTokens[i], date))
-                throw std::runtime_error("DayAttr::read_state failed: (date:)");
-            // when a date_ is special date = not-a-date-time\n"
-            if (date.find("not") == std::string::npos) {
-                date_ = from_simple_string(date);
-            }
-        }
-    }
-}
-
-DayAttr::Day_t DayAttr::getDay(const std::string& day) {
-    if (day == "monday")
-        return DayAttr::MONDAY;
-    if (day == "tuesday")
-        return DayAttr::TUESDAY;
-    if (day == "wednesday")
-        return DayAttr::WEDNESDAY;
-    if (day == "thursday")
-        return DayAttr::THURSDAY;
-    if (day == "friday")
-        return DayAttr::FRIDAY;
-    if (day == "saturday")
-        return DayAttr::SATURDAY;
-    if (day == "sunday")
-        return DayAttr::SUNDAY;
-
-    std::stringstream ss;
-    ss << "Invalid day(" << day
-       << ") specification expected one of [monday,tuesday,wednesday,thursday,friday,saturday,sunday]: ";
-    throw std::runtime_error(ss.str());
-
-    return DayAttr::SUNDAY;
-}
-
-std::vector<std::string> DayAttr::allDays() {
-    std::vector<std::string> vec;
-    vec.reserve(7);
-    vec.emplace_back("monday");
-    vec.emplace_back("tuesday");
-    vec.emplace_back("wednesday");
-    vec.emplace_back("thursday");
-    vec.emplace_back("friday");
-    vec.emplace_back("saturday");
-    vec.emplace_back("sunday");
-    return vec;
-}
-
-boost::gregorian::date DayAttr::matching_date(const ecf::Calendar& c) const {
-    boost::gregorian::date_duration one_day(1);
-    boost::gregorian::date matching_date = c.date(); // todays date
-
-    for (int i = 0; i < 7; i++) {
-        if (matching_date.day_of_week().as_number() == day_) {
-            return matching_date;
-        }
-        matching_date += one_day;
-    }
-    assert(false); // no matching day ?s
-    return c.date();
-}
-
-boost::gregorian::date DayAttr::next_matching_date(const ecf::Calendar& c) const {
-    boost::gregorian::date_duration one_day(1);
-    boost::gregorian::date the_next_matching_date = c.date(); // todays date
-
-    for (int i = 0; i < 7; i++) {
-        the_next_matching_date += one_day;
-        if (the_next_matching_date.day_of_week().as_number() == day_) {
-            return the_next_matching_date;
-        }
-    }
-    assert(false);
-    return c.date();
-}
-
-template <class Archive>
-void DayAttr::serialize(Archive& ar) {
-    ar(CEREAL_NVP(day_));
-    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, expired_, [this]() {
-        return expired_;
-    }); // conditionally save, new to ecflow 5.4.0, should be ignored by old clients. see tests
-    CEREAL_OPTIONAL_NVP(ar, date_, [this]() {
-        return !date_.is_special();
-    }); // conditionally save, new to ecflow 5.5.0, should be ignored by old clients. see tests
-}
-CEREAL_TEMPLATE_SPECIALIZE(DayAttr);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/DayAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/DayAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/DayAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/DayAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,132 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_DayAttr_HPP
-#define ecflow_attribute_DayAttr_HPP
-
-#include <vector>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-namespace cereal {
-class access;
-}
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-// Use default copy constructor, assignment operator, destructor
-class DayAttr {
-public:
-    enum Day_t { SUNDAY = 0, MONDAY = 1, TUESDAY = 2, WEDNESDAY = 3, THURSDAY = 4, FRIDAY = 5, SATURDAY = 6 };
-    DayAttr() = default;
-    explicit DayAttr(Day_t day) : day_(day) {}
-    explicit DayAttr(const std::string& str) : day_(DayAttr::getDay(str)) {}
-    explicit DayAttr(const boost::gregorian::date& date)
-        : day_(static_cast<DayAttr::Day_t>(date.day_of_week().as_number())),
-          date_(date) {}
-
-    void print(std::string&) const;
-    bool operator==(const DayAttr& rhs) const;
-    bool operator<(const DayAttr& rhs) const { return day_ < rhs.day_; }
-    bool structureEquals(const DayAttr& rhs) const;
-
-    /// called when definition is restored from a file/checkpoint. handle reset of date_
-    void handle_migration(const ecf::Calendar&);
-
-    // called at begin time.
-    void reset();
-    void reset(const ecf::Calendar& c);
-
-    // called when we need a reque based on a time attribute. Should *NOT* clear expired flag.
-    void requeue_time();
-
-    // called when re-queing because of:
-    //    - automatic re-queue due to repeat increment
-    //    - manual re-queue
-    // Clears expired flag, and sets day attribute to a next matching *FUTURE* day or current day
-    void requeue_manual(const ecf::Calendar& c);           // can match today if today is match day
-    void requeue_repeat_increment(const ecf::Calendar& c); // match *FUTURE* day
-
-    // Called after a node has completed, if calendar day corresponds to *THIS* day. *Expire* it
-    // This should be called just before: checkForRequeue.
-    // This day attribute should be treated as being deleted. returns false from
-    //  - isFree()          stops re-queue on expired day
-    //  - calendarChanged() stops clearing of free.
-    // Expired flag is RESET only by:
-    //    - void requeue_manual(const ecf::Calendar& c);
-    //    - void requeue_repeat_increment(const ecf::Calendar& c);
-    void check_for_expiration(const ecf::Calendar&);
-
-    // We must use a real date, using enum is not sufficient as in ecflow4
-    //     0,1,2,3,4,5,6
-    //     ^           ^
-    //    sunday      saturday
-    // old/buggy: check_for_requeue() { return (day_ > calendar.day_of_week() );}
-    // The old check for re-queue would determine if this day is in the future, with reference to calendar day.
-    // Hence day_(Saturday) is would always re-queue, day_(Sunday) is would never re-queue
-    // When multiple days were involved, it would get even more buggier.
-    // By using a real date, we fix the issue, the real date is updated during manual re-queue, or automatically vi
-    // repeat increment.
-    bool checkForRequeue(const ecf::Calendar&) const;
-
-    void setFree(); // ensures that isFree() always returns true
-    bool isSetFree() const { return free_; }
-    void calendarChanged(const ecf::Calendar& c, bool clear_at_midnight = true); // can set attribute free
-    bool isFree(const ecf::Calendar&) const;
-    bool validForHybrid(const ecf::Calendar&) const;
-    bool why(const ecf::Calendar&, std::string& theReasonWhy) const;
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    std::string name() const; // for display/gui only
-    std::string toString() const;
-    std::string dump() const;
-
-    // return the days, if input is not valid will throw a runtime_error
-    static DayAttr create(const std::string& dayStr);
-    static DayAttr create(const std::vector<std::string>& lineTokens, bool read_state);
-    static DayAttr::Day_t getDay(const std::string&);
-
-    static std::vector<std::string> allDays();
-
-    // access
-    DayAttr::Day_t day() const { return day_; }
-    const boost::gregorian::date& date() const { return date_; }
-
-    boost::gregorian::date next_matching_date(const ecf::Calendar& c) const;
-
-    void set_expired(); // ********* TREAT this Day Attribute as deleted **********
-    bool expired() const { return expired_; }
-
-    void read_state(const std::vector<std::string>& lineTokens);
-
-private:
-    void clearFree(); // resets the free flag
-    void clear_expired();
-    bool is_free(const ecf::Calendar&) const; // ignores free_
-    boost::gregorian::date matching_date(const ecf::Calendar& c) const;
-    void write(std::string&) const;
-
-private:
-    DayAttr::Day_t day_{DayAttr::SUNDAY};
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool free_{false};                // persisted for use by why() on client side
-    bool expired_{false};             // added for ecflow 5.4.0
-
-    boost::gregorian::date date_; // corresponding to day_
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_attribute_DayAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/GenericAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/GenericAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/GenericAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/GenericAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,78 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/GenericAttr.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace ecf;
-using namespace boost;
-using namespace std;
-
-const GenericAttr& GenericAttr::EMPTY() {
-    static const GenericAttr GENERICATTR = GenericAttr();
-    return GENERICATTR;
-}
-
-GenericAttr::GenericAttr(const std::string& name, const std::vector<std::string>& values)
-    : name_(name),
-      values_(values) {
-    string msg;
-    if (!Str::valid_name(name, msg)) {
-        throw std::runtime_error("GenericAttr::GenericAttr : Invalid generic name : " + msg);
-    }
-}
-
-GenericAttr::GenericAttr(const std::string& name) : name_(name) {
-    string msg;
-    if (!Str::valid_name(name, msg)) {
-        throw std::runtime_error("GenericAttr::GenericAttr : Invalid generic name : " + msg);
-    }
-}
-
-bool GenericAttr::operator==(const GenericAttr& rhs) const {
-    if (name_ != rhs.name_)
-        return false;
-    if (values_ != rhs.values_)
-        return false;
-    return true;
-}
-
-void GenericAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += "\n";
-}
-
-std::string GenericAttr::to_string() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void GenericAttr::write(std::string& ret) const {
-    ret += "generic ";
-    ret += name_;
-    for (const auto& value : values_) {
-        ret += " ";
-        ret += value;
-    }
-}
-
-template <class Archive>
-void GenericAttr::serialize(Archive& ar) {
-    ar(CEREAL_NVP(name_), CEREAL_NVP(values_));
-}
-CEREAL_TEMPLATE_SPECIALIZE(GenericAttr);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/GenericAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/GenericAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/GenericAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/GenericAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_GenericAttr_HPP
-#define ecflow_attribute_GenericAttr_HPP
-
-#include <string>
-#include <vector>
-namespace cereal {
-class access;
-}
-
-// Class GenericAttr:
-// Use compiler , generated destructor, assignment, copy constructor
-// GenericAttr does *not* have any changeable state
-class GenericAttr {
-public:
-    GenericAttr(const std::string& name, const std::vector<std::string>& values);
-    explicit GenericAttr(const std::string& name);
-    GenericAttr() = default;
-
-    bool operator==(const GenericAttr& rhs) const;
-    bool operator<(const GenericAttr& rhs) const { return name_ < rhs.name(); }
-    void print(std::string&) const;
-    bool empty() const { return name_.empty(); }
-
-    const std::string& name() const { return name_; }
-    const std::vector<std::string>& values() const { return values_; }
-
-    std::vector<std::string>::const_iterator values_begin() const { return values_.begin(); } // for python
-    std::vector<std::string>::const_iterator values_end() const { return values_.end(); }     // for python
-
-    std::string to_string() const;
-
-    // Added to support return by reference
-    static const GenericAttr& EMPTY();
-
-private:
-    void write(std::string& ret) const;
-
-private:
-    std::string name_;
-    std::vector<std::string> values_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_attribute_GenericAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/LateAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/LateAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/LateAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/LateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,269 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/LateAttr.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-namespace ecf {
-
-LateAttr::LateAttr() = default;
-
-void LateAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        if (isLate_)
-            os += " # late";
-    }
-    os += "\n";
-}
-
-std::string LateAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void LateAttr::write(std::string& ret) const {
-    ret += "late";
-    if (!s_.isNULL()) {
-        ret += " -s +";
-        s_.write(ret);
-    }
-    if (!a_.isNULL()) {
-        ret += " -a ";
-        a_.write(ret);
-    }
-    if (!c_.isNULL()) {
-        ret += " -c ";
-        if (c_is_rel_)
-            ret += "+";
-        c_.write(ret);
-    }
-}
-
-bool LateAttr::operator==(const LateAttr& rhs) const {
-    if (c_is_rel_ != rhs.c_is_rel_)
-        return false;
-    if (s_ != rhs.s_)
-        return false;
-    if (a_ != rhs.a_)
-        return false;
-    if (c_ != rhs.c_)
-        return false;
-    if (isLate_ != rhs.isLate_)
-        return false;
-    return true;
-}
-
-bool LateAttr::isNull() const {
-    return (s_.isNULL() && a_.isNULL() && c_.isNULL());
-}
-
-void LateAttr::checkForLateness(const std::pair<NState, boost::posix_time::time_duration>& state,
-                                const ecf::Calendar& calendar) {
-    if (isLate_ || isNull()) {
-        return;
-    }
-    if (check_for_lateness(state, calendar)) {
-        setLate(true);
-    }
-}
-
-bool LateAttr::check_for_lateness(const std::pair<NState, boost::posix_time::time_duration>& state,
-                                  const ecf::Calendar& calendar) const {
-    if (isNull())
-        return false;
-
-    if (state.first == NState::SUBMITTED || state.first == NState::QUEUED) {
-
-        // Submitted is always relative, ASSUME this means relative to suite start
-        if (state.first == NState::SUBMITTED && !s_.isNULL()) {
-
-            // ECFLOW-322
-            // The late attr check for being late in submitted state, is always *RELATIVE*
-            // Previously we had:
-            //
-            //       if ( calendar.duration() >= s_.duration()  ) {
-            //          setLate(true);
-            //          return;
-            //       }
-            // This is incorrect since calendar.duration() is essentially duration until
-            // the last call to Calendar::init() i.e suite duration time. Hence late was
-            // set straight away.
-            //
-            // to check for submitted, we need the duration *after* state went into submitted state
-            // state.second is when state went SUBMITTED, relative to suite start
-            boost::posix_time::time_duration time_in_submitted_state = calendar.duration() - state.second;
-            if (time_in_submitted_state >= s_.duration()) {
-                return true;
-            }
-        }
-
-        // In Submitted or queued state, check for active, in REAL time
-        if (!a_.isNULL() && calendar.suiteTime().time_of_day() >= a_.duration()) {
-            return true;
-        }
-    }
-    else if (state.first == NState::ACTIVE && !c_.isNULL()) {
-        if (c_is_rel_) {
-            // to check for complete, we need the duration when state went into active state
-            // state.second is when state went ACTIVE, relative to suite start
-            boost::posix_time::time_duration runtime = calendar.duration() - state.second;
-            if (runtime >= c_.duration()) {
-                return true;
-            }
-        }
-        else {
-            // Real time
-            if (calendar.suiteTime().time_of_day() >= c_.duration()) {
-                return true;
-            }
-        }
-    }
-    return false;
-}
-
-void LateAttr::setLate(bool f) {
-    if (f != isLate_) {
-        // minimise changes to state_change_no_
-        isLate_          = f;
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "LateAttr::setLate changed=" << (f != isLate_) << "\n";
-#endif
-}
-
-void LateAttr::override_with(LateAttr* in_late) {
-    if (in_late) {
-        if (!in_late->submitted().isNULL())
-            s_ = in_late->submitted();
-        if (!in_late->active().isNULL())
-            a_ = in_late->active();
-        if (!in_late->complete().isNULL())
-            c_ = in_late->complete();
-        c_is_rel_ = in_late->complete_is_relative();
-
-        // DO NOT override isLate_, because if the parent is late, we do not want *ALL* children to be set late
-        // isLate_ = in_late->isLate();
-    }
-}
-
-void LateAttr::parse(LateAttr& lateAttr,
-                     const std::string& line,
-                     const std::vector<std::string>& lineTokens,
-                     size_t index) {
-    // late -s +00:15  -a  20:00  -c +02:00     #The option can be in any order
-    //  0   1    2      3   4     5     6        7     8     9  10 11 12  13
-    // late -s +00:15  -c +02:00                # not all options are needed
-    //  0    1   2      3   4                   5
-
-    assert(lateAttr.isNull());
-
-    size_t line_token_size = lineTokens.size();
-    for (size_t i = index; i < line_token_size; i += 1) {
-        if (lineTokens[i][0] == '#')
-            break;
-
-        if (lineTokens[i] == "-s") {
-            if (!lateAttr.submitted().isNULL())
-                throw std::runtime_error("LateParser::doParse: Invalid late, submitted specified twice :" + line);
-            if (i + 1 < line_token_size) {
-                int hour = -1;
-                int min  = -1;
-                TimeSeries::getTime(lineTokens[i + 1], hour, min);
-                lateAttr.addSubmitted(TimeSlot(hour, min));
-                i++;
-            }
-            else
-                throw std::runtime_error("LateParser::doParse: Invalid late, submitted time not specified :" + line);
-        }
-        else if (lineTokens[i] == "-a") {
-            if (!lateAttr.active().isNULL())
-                throw std::runtime_error("LateParser::doParse: Invalid late, active specified twice :" + line);
-            if (i + 1 < line_token_size) {
-                int hour = -1;
-                int min  = -1;
-                TimeSeries::getTime(lineTokens[i + 1], hour, min);
-                lateAttr.addActive(TimeSlot(hour, min));
-                i++;
-            }
-            else
-                throw std::runtime_error("LateParser::doParse: Invalid late, active time not specified :" + line);
-        }
-        else if (lineTokens[i] == "-c") {
-            if (!lateAttr.complete().isNULL())
-                throw std::runtime_error("LateParser::doParse: Invalid late, complete specified twice :" + line);
-            if (i + 1 < line_token_size) {
-                int hour      = -1;
-                int min       = -1;
-                bool relative = TimeSeries::getTime(lineTokens[i + 1], hour, min);
-                lateAttr.addComplete(TimeSlot(hour, min), relative);
-                i++;
-            }
-            else
-                throw std::runtime_error("LateParser::doParse: Invalid late, active time not specified :" + line);
-        }
-        else
-            throw std::runtime_error("LateParser::doParse:5: Invalid late :" + line);
-    }
-
-    if (lateAttr.isNull()) {
-        throw std::runtime_error("LateParser::doParse:6: Invalid late :" + line);
-    }
-}
-
-LateAttr LateAttr::create(const std::string& lateString) {
-    std::vector<std::string> lineTokens;
-    Str::split(lateString, lineTokens);
-
-    if (lineTokens.empty()) {
-        throw std::runtime_error("LateParser::create: empty string no late specified ?" + lateString);
-    }
-
-    // adjust the index
-    size_t index = 0;
-    if (lineTokens[0] == "late") {
-        index = 1;
-    }
-
-    LateAttr lateAttr;
-    parse(lateAttr, lateString, lineTokens, index);
-    return lateAttr;
-}
-
-template <class Archive>
-void LateAttr::serialize(Archive& ar) {
-    CEREAL_OPTIONAL_NVP(ar, s_, [this]() { return !s_.isNULL(); });
-    CEREAL_OPTIONAL_NVP(ar, a_, [this]() { return !a_.isNULL(); });
-    CEREAL_OPTIONAL_NVP(ar, c_, [this]() { return !c_.isNULL(); });
-    CEREAL_OPTIONAL_NVP(ar, c_is_rel_, [this]() { return c_is_rel_; });
-    CEREAL_OPTIONAL_NVP(ar, isLate_, [this]() { return isLate_; });
-}
-CEREAL_TEMPLATE_SPECIALIZE(LateAttr);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/LateAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/LateAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/LateAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/LateAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,123 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_LateAttr_HPP
-#define ecflow_attribute_LateAttr_HPP
-
-#include <string>
-#include <utility> // for pair
-#include <vector>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/core/TimeSlot.hpp"
-
-class NState;
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-namespace ecf {
-/// ========================================================================
-/// Use compiler,  destructor, assignment, copy constructor,
-///
-/// ************************************************************************
-/// late attribute: Only applies to a task, it can be set on suite/family
-///                 but this is treated as an inherited attribute.
-///                 late attribute lower down the hierarchy overrides it.
-/// ************************************************************************
-/// The late late attribute will not work correctly when the suites clock
-/// start and stops with the server. Since the late relies on real time
-/// for some of its functionality.
-/// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
-///               relative, so + is simple ignored, if present. If the node stays submitted
-///               longer than the time specified, the late flag is set
-/// -a Active   : The time of day the node must have become active (format hh:mm). If the node
-///               is still queued or submitted, the late flag is set
-/// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
-///               taken from the time the node became active, otherwise node must be complete by
-///               the time given.
-/// ========================================================================
-class LateAttr {
-public:
-    LateAttr();
-
-    void print(std::string&) const;
-    bool operator==(const LateAttr& rhs) const;
-
-    void addSubmitted(const TimeSlot& s) { s_ = s; }
-    void add_submitted(int hour, int minute) { s_ = TimeSlot(hour, minute); }
-    void addActive(const TimeSlot& s) { a_ = s; }
-    void add_active(int hour, int minute) { a_ = TimeSlot(hour, minute); }
-    void addComplete(const TimeSlot& s, bool relative) {
-        c_        = s;
-        c_is_rel_ = relative;
-    }
-    void add_complete(int hour, int minute, bool relative) {
-        c_        = TimeSlot(hour, minute);
-        c_is_rel_ = relative;
-    }
-
-    const TimeSlot& submitted() const { return s_; }
-    const TimeSlot& active() const { return a_; }
-    const TimeSlot& complete() const { return c_; }
-    bool complete_is_relative() const { return c_is_rel_; }
-
-    /// i.e no time structs specified
-    bool isNull() const;
-
-    /// Given the state and time of state change, and calendar work out if we are late
-    /// if we are sets the late flag
-    void checkForLateness(const std::pair<NState, boost::posix_time::time_duration>& state, const ecf::Calendar& c);
-    bool check_for_lateness(const std::pair<NState, boost::posix_time::time_duration>& state,
-                            const ecf::Calendar& c) const;
-
-    ///  To be used by GUI to inform used that a node is late
-    bool isLate() const { return isLate_; }
-
-    /// To be called at begin and re-queue time
-    void reset() { setLate(false); }
-
-    // Overide this late attributes with the settings form the input.
-    void override_with(LateAttr*);
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    /// set flag to be late
-    void setLate(bool f);
-
-    std::string toString() const;
-    std::string name() const { return toString(); }
-
-    static void parse(LateAttr&, const std::string& line, const std::vector<std::string>& lineTokens, size_t index);
-    static LateAttr create(const std::string& lateString);
-
-private:
-    void write(std::string&) const;
-
-private:
-    TimeSlot s_; // relative by default
-    TimeSlot a_;
-    TimeSlot c_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool c_is_rel_{false};
-    bool isLate_{false};
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_attribute_LateAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/NodeAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/NodeAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/NodeAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/NodeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,512 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/NodeAttr.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-const std::string& Event::SET() {
-    static const std::string SET = "set";
-    return SET;
-}
-const std::string& Event::CLEAR() {
-    static const std::string CLEAR = "clear";
-    return CLEAR;
-}
-const Event& Event::EMPTY() {
-    static const Event EVENT = Event();
-    return EVENT;
-}
-const Meter& Meter::EMPTY() {
-    static const Meter METER = Meter();
-    return METER;
-}
-const Label& Label::EMPTY() {
-    static const Label LABEL = Label();
-    return LABEL;
-}
-
-////////////////////////////////////////////////////////////////////////////////////////////
-
-Event::Event(int number, const std::string& eventName, bool iv, bool check_name)
-    : n_(eventName),
-      number_(number),
-      v_(iv),
-      iv_(iv) {
-    if (!eventName.empty() && check_name) {
-        string msg;
-        if (!Str::valid_name(eventName, msg)) {
-            throw std::runtime_error("Event::Event: Invalid event name : " + msg);
-        }
-    }
-}
-
-Event::Event(const std::string& eventName, bool iv) : n_(eventName), v_(iv), iv_(iv) {
-    if (eventName.empty()) {
-        throw std::runtime_error("Event::Event: Invalid event name : name must be specified if no number supplied");
-    }
-
-    // If the eventName is a integer, then treat it as such, by setting number_ and clearing n_
-    // This was added after migration failed, since *python* api allowed:
-    //       ta.add_event(1);
-    //       ta.add_event("1");
-    // and when we called ecflow_client --migrate/--get it generated
-    //       event 1
-    //       event 1
-    // which then did *not* load.
-    //
-    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
-    if (eventName.find_first_of(Str::NUMERIC()) == 0) {
-        try {
-            number_ = ecf::convert_to<int>(eventName);
-            n_.clear();
-            return;
-        }
-        catch (const ecf::bad_conversion&) {
-            // cast failed, a real string, carry on
-        }
-    }
-
-    string msg;
-    if (!Str::valid_name(eventName, msg)) {
-        throw std::runtime_error("Event::Event: Invalid event name : " + msg);
-    }
-}
-
-void Event::set_value(bool b) {
-    v_               = b;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Event::set_value\n";
-#endif
-}
-
-std::string Event::name_or_number() const {
-    if (n_.empty()) {
-        std::stringstream ss;
-        ss << number_;
-        return ss.str();
-    }
-    return n_;
-}
-
-bool Event::operator<(const Event& rhs) const {
-    if (!n_.empty() && !rhs.name().empty()) {
-        return n_ < rhs.name();
-    }
-    if (n_.empty() && rhs.name().empty()) {
-        return number_ < rhs.number();
-    }
-    return name_or_number() < rhs.name_or_number();
-}
-
-bool Event::operator==(const Event& rhs) const {
-    if (v_ != rhs.v_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "v_ != rhs.v_   (v_:" << v_ << " rhs.v_:" << rhs.v_ << ") " << toString() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (number_ != rhs.number_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "number_ != rhs.number_   (number_:" << number_ << " rhs.number_:" << rhs.number_ << ") "
-                      << toString() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (n_ != rhs.n_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "n_ != rhs.n_  (n_:" << n_ << " rhs.n_:" << rhs.n_ << ") " << toString() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (iv_ != rhs.iv_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "iv_ != rhs.iv_   (iv_:" << iv_ << " rhs.iv_:" << rhs.iv_ << ") " << toString() << "\n";
-        }
-#endif
-        return false;
-    }
-    return true;
-}
-
-bool Event::compare(const Event& rhs) const {
-    if (number_ != rhs.number_) {
-        return false;
-    }
-    if (n_ != rhs.n_) {
-        return false;
-    }
-    return true;
-}
-
-void Event::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        if (iv_ != v_) { // initial value and value differ
-            if (v_) {
-                os += " # ";
-                os += Event::SET();
-            }
-            else {
-                os += " # ";
-                os += Event::CLEAR();
-            }
-        }
-    }
-    os += "\n";
-}
-
-std::string Event::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void Event::write(std::string& ret) const {
-    ret += "event ";
-    if (number_ == std::numeric_limits<int>::max())
-        ret += n_;
-    else {
-        ret += ecf::convert_to<std::string>(number_);
-        ret += " ";
-        ret += n_;
-    }
-
-    if (iv_)
-        ret += " set"; // initial value
-}
-
-std::string Event::dump() const {
-    std::stringstream ss;
-    ss << toString() << " value(" << v_ << ")  used(" << used_ << ")";
-    return ss.str();
-}
-
-bool Event::isValidState(const std::string& state) {
-    if (state == Event::SET())
-        return true;
-    if (state == Event::CLEAR())
-        return true;
-    return false;
-}
-
-////////////////////////////////////////////////////////////////////////////////////////////
-
-Meter::Meter(const std::string& name, int min, int max, int colorChange, int value, bool check)
-    : min_(min),
-      max_(max),
-      v_(value),
-      cc_(colorChange),
-      n_(name) {
-    if (check) {
-        if (!Str::valid_name(name)) {
-            throw std::runtime_error("Meter::Meter: Invalid Meter name: " + name);
-        }
-    }
-
-    if (min > max)
-        throw std::out_of_range("Meter::Meter: Invalid Meter(name,min,max,color_change) : min must be less than max");
-
-    if (colorChange == std::numeric_limits<int>::max()) {
-        cc_ = max_;
-    }
-
-    if (value == std::numeric_limits<int>::max()) {
-        v_ = min_;
-    }
-
-    if (cc_ < min || cc_ > max) {
-        std::stringstream ss;
-        ss << "Meter::Meter: Invalid Meter(name,min,max,color_change) color_change(" << cc_ << ") must be between min("
-           << min_ << ") and max(" << max_ << ")";
-        throw std::out_of_range(ss.str());
-    }
-}
-
-void Meter::set_value(int v) {
-
-    if (!isValidValue(v)) {
-        std::stringstream ss;
-        ss << "Meter::set_value(int): The meter(" << n_ << ") value must be in the range[" << min() << "->" << max()
-           << "] but found '" << v << "'";
-        throw std::runtime_error(ss.str());
-    }
-
-    v_               = v;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Meter::set_value\n";
-#endif
-}
-
-bool Meter::operator==(const Meter& rhs) const {
-    if (v_ != rhs.v_) {
-        return false;
-    }
-    if (min_ != rhs.min_) {
-        return false;
-    }
-    if (max_ != rhs.max_) {
-        return false;
-    }
-    if (cc_ != rhs.cc_) {
-        return false;
-    }
-    if (n_ != rhs.n_) {
-        return false;
-    }
-    return true;
-}
-
-void Meter::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        if (v_ != min_) {
-            os += " # ";
-            os += ecf::convert_to<std::string>(v_);
-        }
-    }
-    os += "\n";
-}
-
-std::string Meter::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void Meter::write(std::string& ret) const {
-    ret += "meter ";
-    ret += n_;
-    ret += " ";
-    ret += ecf::convert_to<std::string>(min_);
-    ret += " ";
-    ret += ecf::convert_to<std::string>(max_);
-    ret += " ";
-    ret += ecf::convert_to<std::string>(cc_);
-}
-
-std::string Meter::dump() const {
-    std::stringstream ss;
-    ss << "meter " << n_ << " min(" << min_ << ") max (" << max_ << ") colorChange(" << cc_ << ") value(" << v_
-       << ") used(" << used_ << ")";
-    return ss.str();
-}
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
-Label::Label(const std::string& name, const std::string& value, const std::string& new_value, bool check_name)
-    : n_(name),
-      v_(value),
-      new_v_(new_value),
-      state_change_no_(0) {
-    if (check_name && !Str::valid_name(n_)) {
-        throw std::runtime_error("Label::Label: Invalid Label name :" + n_);
-    }
-}
-
-void Label::print(std::string& os) const {
-
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        if (!new_v_.empty()) {
-            if (new_v_.find("\n") == std::string::npos) {
-                os += " # \"";
-                os += new_v_;
-                os += "\"";
-            }
-            else {
-                std::string value = new_v_;
-                Str::replaceall(value, "\n", "\\n");
-                os += " # \"";
-                os += value;
-                os += "\"";
-            }
-        }
-    }
-    os += "\n";
-}
-
-std::string Label::toString() const {
-    // parsing always STRIPS the quotes, hence add them back
-    std::string ret;
-    ret.reserve(n_.size() + v_.size() + 10);
-    write(ret);
-    return ret;
-}
-
-void Label::write(std::string& ret) const {
-    // parsing always STRIPS the quotes, hence add them back
-    ret += "label ";
-    ret += n_;
-    ret += " \"";
-    if (v_.find("\n") == std::string::npos)
-        ret += v_;
-    else {
-        // replace \n, otherwise re-parse will fail
-        std::string value = v_;
-        Str::replaceall(value, "\n", "\\n");
-        ret += value;
-    }
-    ret += "\"";
-}
-
-std::string Label::dump() const {
-    std::stringstream ss;
-    ss << toString() << " : \"" << new_v_ << "\"";
-    return ss.str();
-}
-
-void Label::set_new_value(const std::string& l) {
-    new_v_           = l;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Label::set_new_value\n";
-#endif
-}
-
-void Label::reset() {
-    new_v_.clear();
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Label::reset()\n";
-#endif
-}
-
-void Label::parse(const std::string& line, std::vector<std::string>& lineTokens, bool parse_state) {
-    parse(line, lineTokens, parse_state, n_, v_, new_v_);
-}
-
-void Label::parse(const std::string& line,
-                  std::vector<std::string>& lineTokens,
-                  bool parse_state,
-                  std::string& the_name,
-                  std::string& the_value,
-                  std::string& the_new_value) {
-    size_t line_token_size = lineTokens.size();
-    if (line_token_size < 3)
-        throw std::runtime_error("Label::parse: Invalid label :" + line);
-
-    the_name = lineTokens[1];
-
-    // parsing will always STRIP single or double quotes, print will add double quotes
-    // label simple_label 'ecgems'
-    if (line_token_size == 3) {
-        Str::removeQuotes(lineTokens[2]);
-        Str::removeSingleQuotes(lineTokens[2]);
-        the_value = lineTokens[2];
-        if (the_value.find("\\n") != std::string::npos) {
-            Str::replaceall(the_value, "\\n", "\n");
-        }
-    }
-    else {
-
-        // label complex_label "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # fred
-        // label simple_label "fred" #  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"
-        std::string value;
-        value.reserve(line.size());
-        for (size_t i = 2; i < line_token_size; ++i) {
-            if (lineTokens[i].at(0) == '#')
-                break;
-            if (i != 2)
-                value += " ";
-            value += lineTokens[i];
-        }
-
-        Str::removeQuotes(value);
-        Str::removeSingleQuotes(value);
-        the_value = value;
-        if (the_value.find("\\n") != std::string::npos) {
-            Str::replaceall(the_value, "\\n", "\n");
-        }
-
-        // state
-        if (parse_state) {
-            // label name "value" # "new  value"
-            bool comment_fnd                 = false;
-            size_t first_quote_after_comment = 0;
-            size_t last_quote_after_comment  = 0;
-            for (size_t i = line.size() - 1; i > 0; i--) {
-                if (line[i] == '#') {
-                    comment_fnd = true;
-                    break;
-                }
-                if (line[i] == '"') {
-                    if (last_quote_after_comment == 0)
-                        last_quote_after_comment = i;
-                    first_quote_after_comment = i;
-                }
-            }
-            if (comment_fnd && first_quote_after_comment != last_quote_after_comment) {
-                std::string new_value = line.substr(first_quote_after_comment + 1,
-                                                    last_quote_after_comment - first_quote_after_comment - 1);
-                // std::cout << "new label = '" << new_value << "'\n";
-                the_new_value = new_value;
-
-                if (the_new_value.find("\\n") != std::string::npos) {
-                    Str::replaceall(the_new_value, "\\n", "\n");
-                }
-            }
-        }
-    }
-}
-
-template <class Archive>
-void Label::serialize(Archive& ar) {
-    ar(CEREAL_NVP(n_));
-    CEREAL_OPTIONAL_NVP(ar, v_, [this]() { return !v_.empty(); });
-    CEREAL_OPTIONAL_NVP(ar, new_v_, [this]() { return !new_v_.empty(); }); // conditionally save
-}
-
-template <class Archive>
-void Event::serialize(Archive& ar) {
-    CEREAL_OPTIONAL_NVP(ar, n_, [this]() { return !n_.empty(); });
-    CEREAL_OPTIONAL_NVP(ar, number_, [this]() { return number_ != std::numeric_limits<int>::max(); });
-    CEREAL_OPTIONAL_NVP(ar, v_, [this]() { return v_; });
-    CEREAL_OPTIONAL_NVP(ar, iv_, [this]() { return iv_; });
-}
-
-template <class Archive>
-void Meter::serialize(Archive& ar) {
-    ar(CEREAL_NVP(min_), CEREAL_NVP(max_), CEREAL_NVP(v_), CEREAL_NVP(n_), CEREAL_NVP(cc_));
-}
-
-CEREAL_TEMPLATE_SPECIALIZE(Label);
-CEREAL_TEMPLATE_SPECIALIZE(Event);
-CEREAL_TEMPLATE_SPECIALIZE(Meter);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/NodeAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/NodeAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/NodeAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/NodeAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,199 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_NodeAttr_HPP
-#define ecflow_attribute_NodeAttr_HPP
-
-#include <limits> // for std::numeric_limits<int>::max()
-#include <string>
-#include <vector>
-
-#include <boost/operators.hpp>
-
-namespace cereal {
-class access;
-}
-
-////////////////////////////////////////////////////////////////////////////////////////
-// Class Label:
-// Use compiler , generated destructor, assignment,  copy constructor
-class Label : public boost::equality_comparable<Label> {
-public:
-    Label(const std::string& name, const std::string& value, const std::string& new_value = "", bool check_name = true);
-    Label() = default;
-
-    void print(std::string&) const;
-    const std::string& name() const { return n_; }
-    const std::string& value() const { return v_; }
-    const std::string& new_value() const { return new_v_; }
-    void set_new_value(const std::string& new_label);
-    void reset();
-    bool empty() const { return n_.empty(); }
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    // 2 kinds of equality, structure and state
-    friend bool operator==(const Label& lhs, const Label& rhs) {
-        if (lhs.n_ != rhs.n_) {
-            // std::cout << "lhs.n_ '" << lhs.n_ << "' != rhs.n_ '" << rhs.n_ << "'\n";
-            return false;
-        }
-        if (lhs.new_v_ != rhs.new_v_) {
-            // std::cout << "lhs.new_v_ '" << lhs.new_v_ << "' != rhs.new_v_ '" << rhs.new_v_ << "'\n";
-            return false;
-        }
-        if (lhs.v_ != rhs.v_) {
-            // std::cout << "lhs.v_ '" << lhs.v_ << "' != rhs.v_ '" << rhs.v_ << "'\n";
-            return false;
-        }
-        return true;
-    }
-    bool operator<(const Label& rhs) const { return n_ < rhs.name(); }
-
-    std::string toString() const;
-    std::string dump() const;
-
-    void parse(const std::string& line, std::vector<std::string>& lineTokens, bool parse_state);
-    static void parse(const std::string& line,
-                      std::vector<std::string>& lineTokens,
-                      bool parse_state,
-                      std::string&,
-                      std::string&,
-                      std::string&);
-    static const Label& EMPTY(); // Added to support return by reference
-
-private:
-    void write(std::string&) const;
-
-private:
-    std::string n_;
-    std::string v_;
-    std::string new_v_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-// Class Event:
-// events with the number 007 are the same as 7.
-// Use compiler , generated destructor, assignment, copy constructor
-//
-// Don't use -1, to represent that no number was specified, as on
-// AIX portable binary archive can't cope with this
-// use std::numeric_limits<int>::max()
-class Event {
-public:
-    explicit Event(int number, const std::string& eventName = "", bool initial_val = false, bool check_name = true);
-    explicit Event(const std::string& eventName, bool initial_val = false);
-    Event() = default;
-
-    std::string name_or_number() const; // if name present return, else return number
-    const std::string& name() const { return n_; }
-    void print(std::string&) const;
-    bool value() const { return v_; }
-    void reset() { set_value(iv_); }
-    bool empty() const { return (n_.empty() && number_ == std::numeric_limits<int>::max()); }
-    void set_initial_value(bool iv) { iv_ = iv; }
-    bool initial_value() const { return iv_; }
-
-    int number() const { return number_; }
-    bool operator==(const Event& rhs) const;
-    bool operator<(const Event& rhs) const;
-    bool compare(const Event& rhs) const; // two events the same if name/number the same, ignores state
-    void set_value(bool b);               // updates state_change_no_
-    bool usedInTrigger() const { return used_; }
-    void usedInTrigger(bool b) { used_ = b; }
-
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    std::string toString() const;
-    std::string dump() const;
-
-    static bool isValidState(const std::string&); // return true for "set" | "clear"
-    static const std::string& SET();
-    static const std::string& CLEAR();
-    static const Event& EMPTY(); // Added to support return by reference
-
-private:
-    void write(std::string&) const;
-
-private:
-    std::string n_;
-    int number_{std::numeric_limits<int>::max()};
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool v_{false};
-    bool iv_{false};   // initial value ECFLOW-1526
-    bool used_{false}; // used by the simulator not persisted
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-// Class Meter:
-// Use compiler , generated destructor, assignment, copy constructor
-// For this class we don't check the value member for the equality functionality
-// Can have negative min/max however max >= min, and color change should be in the
-// range min-max
-class Meter {
-public:
-    Meter(const std::string& name,
-          int min,
-          int max,
-          int colorChange = std::numeric_limits<int>::max(),
-          int value       = std::numeric_limits<int>::max(),
-          bool check      = true);
-    Meter() = default;
-
-    void print(std::string&) const;
-    void reset() { set_value(min_); }
-    void set_value(int v); // can throw throw std::runtime_error if out of range
-    bool empty() const { return n_.empty(); }
-
-    const std::string& name() const { return n_; }
-    int value() const { return v_; }
-    int min() const { return min_; }
-    int max() const { return max_; }
-    int colorChange() const { return cc_; }
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    bool operator==(const Meter& rhs) const;
-    bool operator<(const Meter& rhs) const { return n_ < rhs.name(); }
-
-    bool usedInTrigger() const { return used_; }
-    void usedInTrigger(bool b) { used_ = b; }
-    std::string toString() const;
-    std::string dump() const;
-
-    static const Meter& EMPTY(); // Added to support return by reference
-
-private:
-    void write(std::string&) const;
-    bool isValidValue(int v) const { return (v >= min_ && v <= max_); }
-
-    int min_{0};
-    int max_{0};
-    int v_{0};                        // value
-    int cc_{0};                       // Colour change, used by gui ?
-    std::string n_;                   // name
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool used_{false};                // used by the simulator not persisted
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_attribute_NodeAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/QueueAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/QueueAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/QueueAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/QueueAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,297 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/QueueAttr.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
-const QueueAttr& QueueAttr::EMPTY() {
-    static const QueueAttr queueAttr = QueueAttr();
-    return queueAttr;
-}
-QueueAttr& QueueAttr::EMPTY1() {
-    static QueueAttr queueAttr = QueueAttr();
-    return queueAttr;
-}
-
-QueueAttr::QueueAttr(const std::string& name, const std::vector<std::string>& theQueue)
-    : theQueue_(theQueue),
-      name_(name) {
-    string msg;
-    if (!Str::valid_name(name, msg)) {
-        throw std::runtime_error("QueueAttr::QueueAttr: Invalid queue name : " + msg);
-    }
-    if (theQueue.empty()) {
-        throw std::runtime_error("QueueAttr::QueueAttr: No queue items specified");
-    }
-    for (size_t i = 0; i < theQueue.size(); i++)
-        state_vec_.push_back(NState::QUEUED);
-}
-
-QueueAttr::~QueueAttr() = default;
-
-void QueueAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        os += " # ";
-        os += ecf::convert_to<std::string>(currentIndex_);
-        for (auto i : state_vec_) {
-            os += " ";
-            os += NState::toString(i);
-        }
-    }
-    os += "\n";
-}
-
-bool QueueAttr::operator==(const QueueAttr& rhs) const {
-    if (name_ != rhs.name_)
-        return false;
-    if (theQueue_ != rhs.theQueue_)
-        return false;
-    if (state_vec_ != rhs.state_vec_)
-        return false;
-    if (currentIndex_ != rhs.currentIndex_)
-        return false;
-    return true;
-}
-
-std::string QueueAttr::value() const {
-    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theQueue_.size())) {
-        return theQueue_[currentIndex_];
-    }
-    return "<NULL>";
-}
-
-int QueueAttr::index_or_value() const {
-    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theQueue_.size())) {
-        try {
-            return ecf::convert_to<int>(theQueue_[currentIndex_]);
-        }
-        catch (ecf::bad_conversion&) {
-            // Ignore and return currentIndex_
-        }
-    }
-    return currentIndex_;
-}
-
-NState::State QueueAttr::state(const std::string& step) const {
-    for (size_t i = 0; i < theQueue_.size(); i++) {
-        if (step == theQueue_[i]) {
-            if (i >= state_vec_.size())
-                throw std::runtime_error("QueueAttr::state: index out of range");
-            return state_vec_[i];
-        }
-    }
-    throw std::runtime_error("QueueAttr::state: could not find step " + step);
-    return NState::UNKNOWN;
-}
-
-void QueueAttr::requeue() {
-    currentIndex_ = 0;
-    for (auto& i : state_vec_)
-        i = NState::QUEUED;
-    incr_state_change_no();
-}
-
-std::string QueueAttr::active() {
-    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theQueue_.size())) {
-        state_vec_[currentIndex_] = NState::ACTIVE;
-        std::string ret           = theQueue_[currentIndex_];
-        currentIndex_++;
-        incr_state_change_no();
-        return ret;
-    }
-    return "<NULL>";
-}
-
-void QueueAttr::complete(const std::string& step) {
-    for (size_t i = 0; i < theQueue_.size(); i++) {
-        if (step == theQueue_[i]) {
-            state_vec_[i] = NState::COMPLETE;
-            incr_state_change_no();
-            return;
-        }
-    }
-    std::stringstream ss;
-    ss << "QueueAttr::complete: Could not find " << step << " in queue " << name_;
-    throw std::runtime_error(ss.str());
-}
-
-void QueueAttr::aborted(const std::string& step) {
-    for (size_t i = 0; i < theQueue_.size(); i++) {
-        if (step == theQueue_[i]) {
-            state_vec_[i] = NState::ABORTED;
-            incr_state_change_no();
-            return;
-        }
-    }
-    std::stringstream ss;
-    ss << "QueueAttr::aborted: Could not find " << step << " in queue " << name_;
-    throw std::runtime_error(ss.str());
-}
-
-std::string QueueAttr::no_of_aborted() const {
-    int count = 0;
-    for (auto i : state_vec_) {
-        if (i == NState::ABORTED)
-            count++;
-    }
-    if (count != 0)
-        return ecf::convert_to<std::string>(count);
-    return std::string();
-}
-
-void QueueAttr::reset_index_to_first_queued_or_aborted() {
-    for (size_t i = 0; i < state_vec_.size(); i++) {
-        if (state_vec_[i] == NState::QUEUED || state_vec_[i] == NState::ABORTED) {
-            currentIndex_ = i;
-            incr_state_change_no();
-            break;
-        }
-    }
-}
-
-std::string QueueAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void QueueAttr::write(std::string& ret) const {
-    ret += "queue ";
-    ret += name_;
-    for (const auto& i : theQueue_) {
-        ret += " ";
-        ret += i;
-    }
-}
-
-std::string QueueAttr::dump() const {
-    std::stringstream ss;
-    ss << toString() << " # " << currentIndex_;
-    for (auto i : state_vec_)
-        ss << " " << i;
-    return ss.str();
-}
-
-void QueueAttr::incr_state_change_no() {
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void QueueAttr::parse(QueueAttr& queAttr,
-                      const std::string& line,
-                      std::vector<std::string>& lineTokens,
-                      bool parse_state) {
-    size_t line_tokens_size = lineTokens.size();
-    if (line_tokens_size < 3) {
-        std::stringstream ss;
-        ss << "QueueAttr::parse: expected at least 3 tokens, found " << line_tokens_size << " on line:" << line << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // queue name "first" "second" "last" #   current_index state state state
-    //   0     1     2        3       4   5   6
-    queAttr.set_name(lineTokens[1]);
-
-    std::vector<std::string> theEnums;
-    theEnums.reserve(line_tokens_size);
-    for (size_t i = 2; i < line_tokens_size; i++) {
-        std::string theEnum = lineTokens[i];
-        if (theEnum[0] == '#')
-            break;
-        Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
-        Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
-        theEnums.push_back(theEnum);
-    }
-    if (theEnums.empty())
-        throw std::runtime_error("queue: has no values " + line);
-
-    int index = 0;
-    std::vector<NState::State> state_vec;
-
-    if (parse_state) {
-        // queue VARIABLE a b c d # index active complete aborted queued
-        for (size_t i = 3; i < line_tokens_size; i++) {
-            if (lineTokens[i] == "#" && i + 1 < line_tokens_size) {
-                i++;
-                index = Extract::theInt(lineTokens[i], "QueueAttr::parse, could not extract index");
-                i++;
-                for (; i < line_tokens_size; i++) {
-                    NState::State state = NState::toState(lineTokens[i]);
-                    state_vec.push_back(state);
-                }
-                break;
-            }
-        }
-    }
-
-    queAttr.set_queue(theEnums, index, state_vec);
-}
-
-void QueueAttr::set_queue(const std::vector<std::string>& theQueue,
-                          int index,
-                          const std::vector<NState::State>& state_vec) {
-    if (theQueue.empty())
-        throw std::runtime_error("QueueAttr::set_queue: No queue items specified");
-
-    if (!state_vec.empty()) {
-        if (state_vec.size() != theQueue.size()) {
-            std::stringstream ss;
-            ss << "QueueAttr::set_state: for queue " << name_ << " size " << theQueue.size()
-               << " does not match state size " << state_vec.size();
-            throw std::runtime_error(ss.str());
-        }
-        state_vec_ = state_vec;
-    }
-    else {
-        for (size_t i = 0; i < theQueue.size(); i++)
-            state_vec_.push_back(NState::QUEUED);
-    }
-
-    currentIndex_ = index;
-    theQueue_     = theQueue;
-}
-
-void QueueAttr::set_state_vec(const std::vector<NState::State>& state_vec) {
-    state_vec_ = state_vec;
-    if (theQueue_.size() != state_vec_.size()) {
-        std::cout << "QueueAttr::set_state_vec: for queue " << name_ << " queue size " << theQueue_.size()
-                  << " not equal to state_vec size " << state_vec_.size() << "\n";
-    }
-}
-
-void QueueAttr::set_name(const std::string& name) {
-    string msg;
-    if (!Str::valid_name(name, msg)) {
-        throw std::runtime_error("QueueAttr::set_name: Invalid queue name : " + msg);
-    }
-    name_ = name;
-}
-
-template <class Archive>
-void QueueAttr::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(theQueue_), CEREAL_NVP(state_vec_), CEREAL_NVP(name_), CEREAL_NVP(currentIndex_));
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(QueueAttr);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/QueueAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/QueueAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/QueueAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/QueueAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_QueueAttr_HPP
-#define ecflow_attribute_QueueAttr_HPP
-
-#include <cstdint>
-
-#include "ecflow/core/NState.hpp"
-
-/////////////////////////////////////////////////////////////////////////
-class QueueAttr {
-public:
-    QueueAttr(const std::string& name, const std::vector<std::string>& theQueue);
-    QueueAttr() = default;
-    ~QueueAttr();
-
-    void print(std::string&) const;
-    bool operator==(const QueueAttr& rhs) const;
-    bool operator<(const QueueAttr& rhs) const { return name_ < rhs.name(); }
-
-    /// Accessor
-    const std::string& name() const { return name_; }
-    std::string value() const;
-    int index_or_value() const;
-    int index() const { return currentIndex_; }
-    bool empty() const { return name_.empty(); }
-    const std::vector<std::string>& list() const { return theQueue_; }
-    const std::vector<NState::State>& state_vec() const { return state_vec_; }
-    NState::State state(const std::string& step) const;
-
-    std::string toString() const;
-    std::string dump() const;
-
-    // Mutators
-    void requeue();
-
-    std::string active();                   // return current index and value, make active, increment index
-    void complete(const std::string& step); // step is more index:value
-    void aborted(const std::string& step);
-    std::string no_of_aborted() const;
-    void reset_index_to_first_queued_or_aborted();
-
-    void set_used_in_trigger(bool f) { used_in_trigger_ = f; } // used by simulator only
-    bool used_in_trigger() const { return used_in_trigger_; }
-
-    static void parse(QueueAttr&, const std::string& line, std::vector<std::string>& lineTokens, bool parse_state);
-    void set_name(const std::string& name);
-    void set_queue(const std::vector<std::string>& theQueue, int index, const std::vector<NState::State>& state_vec);
-    void set_state_vec(const std::vector<NState::State>& state_vec);
-    void set_index(int index) { currentIndex_ = index; };
-
-    // Added to support return by reference
-    static const QueueAttr& EMPTY();
-    static QueueAttr& EMPTY1();
-
-    unsigned int state_change_no() const { return state_change_no_; }
-
-private:
-    void incr_state_change_no();
-    void write(std::string&) const;
-
-private:
-    std::vector<std::string> theQueue_;
-    std::vector<NState::State> state_vec_;
-    std::string name_;
-    int currentIndex_{0};
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool used_in_trigger_{false};     // *not* persisted, used by simulator only
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_attribute_QueueAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/RepeatAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/RepeatAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/RepeatAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/RepeatAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1855 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/RepeatAttr.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include <boost/date_time.hpp>
-#include <boost/date_time/posix_time/time_parsers.hpp>
-
-#include "ecflow/core/Cal.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-const Repeat& Repeat::EMPTY() {
-    static const Repeat REPEAT = Repeat();
-    return REPEAT;
-}
-
-//=========================================================================
-
-Repeat::Repeat() = default;
-Repeat::Repeat(const RepeatDate& r) : type_(std::make_unique<RepeatDate>(r)) {
-}
-Repeat::Repeat(const RepeatDateTime& r) : type_(std::make_unique<RepeatDateTime>(r)) {
-}
-Repeat::Repeat(const RepeatDateList& r) : type_(std::make_unique<RepeatDateList>(r)) {
-}
-Repeat::Repeat(const RepeatInteger& r) : type_(std::make_unique<RepeatInteger>(r)) {
-}
-Repeat::Repeat(const RepeatEnumerated& r) : type_(std::make_unique<RepeatEnumerated>(r)) {
-}
-Repeat::Repeat(const RepeatString& r) : type_(std::make_unique<RepeatString>(r)) {
-}
-Repeat::Repeat(const RepeatDay& r) : type_(std::make_unique<RepeatDay>(r)) {
-}
-
-Repeat::~Repeat() = default;
-
-Repeat::Repeat(const Repeat& rhs) {
-    if (rhs.type_) {
-        type_.reset(rhs.type_->clone());
-    }
-}
-
-Repeat& Repeat::operator=(const Repeat& rhs) {
-    type_.reset(nullptr);
-    if (rhs.type_) {
-        type_.reset(rhs.type_->clone());
-    }
-    return *this;
-}
-
-Repeat& Repeat::operator=(Repeat&& rhs) {
-    type_ = std::move(rhs.type_); // since rhs.type_ is a unique_ptr no need to set rhs.type_ to NULL
-    return *this;
-}
-
-bool Repeat::operator==(const Repeat& rhs) const {
-    if (!type_ && rhs.type_)
-        return false;
-    if (type_ && !rhs.type_)
-        return false;
-    if (!type_ && !rhs.type_)
-        return true;
-    return type_->compare(rhs.type_.get());
-}
-
-const std::string& Repeat::name() const {
-    return (type_.get()) ? type_->name() : Str::EMPTY();
-}
-
-void Repeat::print(std::string& os) const {
-    if (type_) {
-        Indentor in;
-        Indentor::indent(os);
-        write(os);
-        os += "\n";
-    }
-}
-
-// =========================================================================
-RepeatBase::~RepeatBase() = default;
-
-void RepeatBase::incr_state_change_no() {
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "RepeatBase::incr_state_change_no()\n";
-#endif
-}
-
-void RepeatBase::update_repeat_genvar() const {
-    // **** reset name since generated variables are not persisted
-    var_.set_name(name_);
-
-    // valueAsString() use the last_valid_value() which should always be in range.
-    // Note repeat::value() can be on e past the last valid value, at expiration of Repeat loop
-    //      However Repeat::last_valid_value() will just return the last valid value.
-    var_.set_value(valueAsString());
-}
-
-std::string RepeatBase::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-// =============================================================
-
-RepeatDate::RepeatDate(const std::string& variable, int start, int end, int delta /* always in days*/
-                       )
-    : RepeatBase(variable),
-      start_(start),
-      end_(end),
-      delta_(delta),
-      value_(start) {
-    if (!Str::valid_name(variable)) {
-        throw std::runtime_error("RepeatDate::RepeatDate: Invalid name: " + variable);
-    }
-
-    if (delta == 0) {
-        std::stringstream ss;
-        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-        throw std::runtime_error("Invalid Repeat date: the delta cannot be zero" + ss.str());
-    }
-
-    std::string theStart = ecf::convert_to<std::string>(start);
-    if (theStart.size() != 8) {
-        std::stringstream ss;
-        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-        throw std::runtime_error("Invalid Repeat date: The start is not a valid date. Please use yyyymmdd format." +
-                                 ss.str());
-    }
-    std::string theEnd = ecf::convert_to<std::string>(end);
-    if (theEnd.size() != 8) {
-        std::stringstream ss;
-        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-        throw std::runtime_error("Invalid Repeat date: The end is not a valid date. Please use yyyymmdd format." +
-                                 ss.str());
-    }
-
-    if (delta_ > 0) {
-        // assert end => start
-        if (!(end >= start)) {
-            std::stringstream ss;
-            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-            throw std::runtime_error(
-                "Invalid Repeat date: The end must be greater than the start date, when delta is positive " + ss.str());
-        }
-    }
-    else {
-        // assert start >= end
-        if (!(start >= end)) {
-            std::stringstream ss;
-            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-            throw std::runtime_error(
-                "Invalid Repeat date: The start must be greater than the end date, when delta is negative " + ss.str());
-        }
-    }
-
-    // Use date lib to check YMD
-    try {
-        (void)boost::gregorian::date(from_undelimited_string(theStart));
-        (void)boost::gregorian::date(from_undelimited_string(theEnd));
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-        throw std::runtime_error("Invalid Repeat date: The start/end is not a valid date." + ss.str());
-    }
-}
-
-void RepeatDate::gen_variables(std::vector<Variable>& vec) const {
-    vec.push_back(yyyy_);
-    vec.push_back(mm_);
-    vec.push_back(dom_);
-    vec.push_back(dow_);
-    vec.push_back(julian_);
-    RepeatBase::gen_variables(vec);
-}
-
-const Variable& RepeatDate::find_gen_variable(const std::string& name) const {
-    if (name == name_)
-        return var_;
-    if (name == julian_.name())
-        return julian_;
-    if (name == dow_.name())
-        return dow_;
-    if (name == dom_.name())
-        return dom_;
-    if (name == mm_.name())
-        return mm_;
-    if (name == yyyy_.name())
-        return yyyy_;
-    return Variable::EMPTY();
-}
-
-void RepeatDate::update_repeat_genvar() const {
-    RepeatBase::update_repeat_genvar();
-
-    yyyy_.set_name(name_ + "_YYYY");
-    yyyy_.set_value("<invalid>");
-    mm_.set_name(name_ + "_MM");
-    mm_.set_value("<invalid>");
-    dom_.set_name(name_ + "_DD");
-    dom_.set_value("<invalid>");
-    dow_.set_name(name_ + "_DOW");
-    dom_.set_value("<invalid>");
-    julian_.set_name(name_ + "_JULIAN");
-    julian_.set_value("<invalid>");
-
-    yyyy_.set_name(name_ + "_YYYY");
-    mm_.set_name(name_ + "_MM");
-    dom_.set_name(name_ + "_DD");
-    dow_.set_name(name_ + "_DOW");
-    julian_.set_name(name_ + "_JULIAN");
-
-    update_repeat_genvar_value();
-}
-
-void RepeatDate::update_repeat_genvar_value() const {
-    std::string date_as_string = valueAsString();
-    if (valid()) {
-        try {
-            boost::gregorian::date the_date(from_undelimited_string(date_as_string));
-            if (the_date.is_special()) {
-                std::stringstream ss;
-                ss << "RepeatDate::update_repeat_genvar(): invalid current date: " << date_as_string << " is_special";
-                log(Log::ERR, ss.str());
-                return;
-            }
-            // int day_of_year  = the_date.day_of_year();
-            int day_of_week  = the_date.day_of_week().as_number();
-            int day_of_month = the_date.day();
-            int month        = the_date.month();
-            int year         = the_date.year();
-
-            yyyy_.set_value(ecf::convert_to<std::string>(year));
-            mm_.set_value(ecf::convert_to<std::string>(month));
-            dom_.set_value(ecf::convert_to<std::string>(day_of_month));
-            dow_.set_value(ecf::convert_to<std::string>(day_of_week));
-
-            long last_value = last_valid_value();
-            long julian     = Cal::date_to_julian(last_value);
-            julian_.set_value(ecf::convert_to<std::string>(julian));
-        }
-        catch (std::exception& e) {
-            std::stringstream ss;
-            ss << "RepeatDate::update_repeat_genvar_value : " << toString() << "\n The current date(" << date_as_string
-               << ") is not valid";
-            log(Log::ERR, ss.str());
-            return;
-        }
-    }
-}
-
-bool RepeatDate::compare(RepeatBase* rb) const {
-    auto* rhs = dynamic_cast<RepeatDate*>(rb);
-    if (!rhs)
-        return false;
-    return operator==(*rhs);
-}
-
-void RepeatDate::setToLastValue() {
-    set_value(end_);
-}
-
-long RepeatDate::last_valid_value() const {
-    return valid_value(value_);
-}
-
-long RepeatDate::valid_value(long value) const {
-    if (delta_ > 0) {
-        if (value < start_)
-            return start_;
-        if (value > end_)
-            return end_;
-        return value;
-    }
-    if (value > start_)
-        return start_;
-    if (value < end_)
-        return end_;
-    return value;
-}
-
-long RepeatDate::last_valid_value_minus(int val) const {
-    long last_value = last_valid_value();
-    long julian     = Cal::date_to_julian(last_value);
-    julian -= val;
-    return Cal::julian_to_date(julian);
-}
-
-long RepeatDate::last_valid_value_plus(int val) const {
-    long last_value = last_valid_value();
-    long julian     = Cal::date_to_julian(last_value);
-    julian += val;
-    return Cal::julian_to_date(julian);
-}
-
-void RepeatDate::reset() {
-    set_value(start_);
-}
-
-void RepeatDate::write(std::string& ret) const {
-    ret += "repeat date ";
-    ret += name_;
-    ret += " ";
-    ret += ecf::convert_to<std::string>(start_);
-    ret += " ";
-    ret += ecf::convert_to<std::string>(end_);
-    ret += " ";
-    ret += ecf::convert_to<std::string>(delta_);
-
-    if (!PrintStyle::defsStyle() && (value_ != start_)) {
-        ret += " # ";
-        ret += ecf::convert_to<std::string>(value_);
-    }
-}
-
-std::string RepeatDate::dump() const {
-    std::stringstream ss;
-    ss << toString() << " value(" << value_ << ")";
-    return ss.str();
-}
-
-bool RepeatDate::operator==(const RepeatDate& rhs) const {
-    if (name_ != rhs.name_) {
-        return false;
-    }
-    if (start_ != rhs.start_) {
-        return false;
-    }
-    if (end_ != rhs.end_) {
-        return false;
-    }
-    if (delta_ != rhs.delta_) {
-        return false;
-    }
-    if (value_ != rhs.value_) {
-        return false;
-    }
-    return true;
-}
-
-std::string RepeatDate::valueAsString() const {
-    /// will throw an ecf::bad_conversion if value is not convertible to a string
-    try {
-        return ecf::convert_to<std::string>(last_valid_value());
-    }
-    catch (const ecf::bad_conversion&) {
-        LOG_ASSERT(false, "RepeatDate::valueAsString(): could not convert value " << value_ << " to a string");
-    }
-    return string();
-}
-
-std::string RepeatDate::value_as_string(int index) const {
-    /// will throw an ecf::bad_conversion if value is not convertible to a string
-    try {
-        return ecf::convert_to<std::string>(index);
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-    return string();
-}
-
-std::string RepeatDate::next_value_as_string() const {
-    long val = last_valid_value();
-
-    long julian = Cal::date_to_julian(val);
-    julian += delta_;
-    val = Cal::julian_to_date(julian);
-
-    try {
-        return ecf::convert_to<std::string>(valid_value(val));
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-    return string();
-}
-
-std::string RepeatDate::prev_value_as_string() const {
-    long val = last_valid_value();
-
-    long julian = Cal::date_to_julian(val);
-    julian -= delta_;
-    val = Cal::julian_to_date(julian);
-
-    try {
-        return ecf::convert_to<std::string>(valid_value(val));
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-    return string();
-}
-
-void RepeatDate::increment() {
-    long julian = Cal::date_to_julian(value_);
-    julian += delta_;
-    set_value(Cal::julian_to_date(julian));
-}
-
-void RepeatDate::change(const std::string& newdate) {
-    if (newdate.size() != 8) {
-        std::stringstream ss;
-        ss << "RepeatDate::change: " << toString()
-           << " The new date is not valid, expected 8 characters in yyyymmdd format but found " << newdate;
-        throw std::runtime_error(ss.str());
-    }
-
-    long the_new_date = 0;
-    try {
-        the_new_date = ecf::convert_to<long>(newdate);
-    }
-    catch (const ecf::bad_conversion&) {
-        std::stringstream ss;
-        ss << "RepeatDate::change: " << toString() << " The new date(" << newdate << ") is not convertible to an long";
-        throw std::runtime_error(ss.str());
-    }
-
-    // Use date lib to check YMD
-    try {
-        (void)boost::gregorian::date(from_undelimited_string(newdate));
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "RepeatDate::change: " << toString() << " The new date(" << newdate << ") is not valid";
-        throw std::runtime_error(ss.str());
-    }
-
-    changeValue(the_new_date);
-}
-
-void RepeatDate::changeValue(long the_new_date) {
-    if (delta_ > 0) {
-        if (the_new_date < start_ || the_new_date > end_) {
-            std::stringstream ss;
-            ss << "RepeatDate::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
-               << " : " << end_ << "] but found " << the_new_date;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else {
-        if (the_new_date > start_ || the_new_date < end_) {
-            std::stringstream ss;
-            ss << "RepeatDate::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
-               << " : " << end_ << "] but found " << the_new_date;
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    // Check new value is in step. ECFLOW-325 repeat date 7
-    long julian_new_date = Cal::date_to_julian(the_new_date);
-    long julian_start    = Cal::date_to_julian(start_);
-    long diff            = julian_new_date - julian_start;
-    if (diff % delta_ != 0) {
-        std::stringstream ss;
-        ss << "RepeatDate::changeValue: " << toString() << "\nThe new date " << the_new_date
-           << " is not in line with the delta/step";
-        throw std::runtime_error(ss.str());
-    }
-
-    set_value(the_new_date);
-}
-
-void RepeatDate::set_value(long the_new_date) {
-    // Note: the node is incremented one past, the last value
-    // In Node we increment() then check for validity
-    // hence the_new_value may be outside of the valid range.
-    // This can be seen when do a incremental sync,
-    // *hence* allow memento to copy the value as is.
-    value_ = the_new_date;
-    update_repeat_genvar_value();
-    incr_state_change_no();
-}
-
-// =============================================================
-
-RepeatDateTime::RepeatDateTime(const std::string& variable,
-                               const std::string& start,
-                               const std::string& end,
-                               const std::string& delta)
-    : RepeatDateTime(variable, Instant::parse(start), Instant::parse(end), Duration::parse(delta)) {
-}
-
-RepeatDateTime::RepeatDateTime(const std::string& variable, Instant start, Instant end, Duration delta)
-    : RepeatBase(variable),
-      start_(start),
-      end_(end),
-      delta_(delta),
-      value_(start) {
-    if (!Str::valid_name(variable)) {
-        throw std::runtime_error("RepeatDateTime::RepeatDateTime: Invalid name: " + variable);
-    }
-
-    if (delta == Duration{std::chrono::seconds{0}}) {
-        std::stringstream ss;
-        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-        throw std::runtime_error("Invalid Repeat datetime: the delta cannot be zero" + ss.str());
-    }
-
-    auto theStart = boost::lexical_cast<std::string>(start);
-    if (theStart.size() != 15) {
-        std::stringstream ss;
-        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-        throw std::runtime_error(
-            "Invalid Repeat datetime: The start is not a valid date+time. Please use yyyymmddTMMHHSS format." +
-            ss.str());
-    }
-    auto theEnd = boost::lexical_cast<std::string>(end);
-    if (theEnd.size() != 15) {
-        std::stringstream ss;
-        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-        throw std::runtime_error(
-            "Invalid Repeat datetime: The end is not a valid date+time. Please use yyyymmddTHHMMSS format." + ss.str());
-    }
-
-    if (delta_ > Duration{std::chrono::seconds{0}}) {
-        // assert end => start
-        if (!(end >= start)) {
-            std::stringstream ss;
-            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-            throw std::runtime_error(
-                "Invalid Repeat datetime: The end must be greater than the start date+time, when delta is positive " +
-                ss.str());
-        }
-    }
-    else {
-        // assert start >= end
-        if (!(start >= end)) {
-            std::stringstream ss;
-            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
-            throw std::runtime_error(
-                "Invalid Repeat datetime: The start must be greater than the end date+time, when delta is negative " +
-                ss.str());
-        }
-    }
-}
-
-void RepeatDateTime::gen_variables(std::vector<Variable>& vec) const {
-    for (const auto& entry : generated_) {
-        vec.push_back(entry);
-    }
-    RepeatBase::gen_variables(vec);
-}
-
-const Variable& RepeatDateTime::find_gen_variable(const std::string& name) const {
-    if (name == name_) {
-        return var_;
-    }
-    for (const auto& entry : generated_) {
-        if (entry.name() == name) {
-            return entry;
-        }
-    }
-    return Variable::EMPTY();
-}
-
-void RepeatDateTime::update_repeat_genvar() const {
-    RepeatBase::update_repeat_genvar();
-
-    // Reset variables values
-    generated_.set_value("<invalid>");
-
-    update_repeat_genvar_value();
-}
-
-void RepeatDateTime::update_repeat_genvar_value() const {
-    std::string date_as_string = valueAsString();
-    if (valid()) {
-        try {
-            auto dt = boost::posix_time::from_iso_string(date_as_string);
-            // Using boost posix_time/gregorian, since C++17 still doesn't include calendar types.
-
-            auto d = dt.date();
-            // Date
-            generated_[name_ + "_DATE"].set_value(boost::gregorian::to_iso_string(d));
-            // Date Components
-            generated_[name_ + "_YYYY"].set_value(std::to_string(d.year()));
-            generated_[name_ + "_MM"].set_value(std::to_string(d.month()));
-            generated_[name_ + "_DD"].set_value(std::to_string(d.day()));
-            generated_[name_ + "_JULIAN"].set_value(std::to_string(d.julian_day()));
-
-            auto t = dt.time_of_day();
-            // Time
-            generated_[name_ + "_TIME"].set_value(boost::posix_time::to_iso_string(t));
-            // Time Components
-            generated_[name_ + "_HOURS"].set_value(std::to_string(t.hours()));
-            generated_[name_ + "_MINUTES"].set_value(std::to_string(t.minutes()));
-            generated_[name_ + "_SECONDS"].set_value(std::to_string(t.seconds()));
-        }
-        catch (std::exception& e) {
-            std::stringstream ss;
-            ss << "RepeatDateTime::update_repeat_genvar_value : " << toString() << "\n The current date("
-               << date_as_string << ") is not valid";
-            log(Log::ERR, ss.str());
-            return;
-        }
-    }
-}
-
-bool RepeatDateTime::compare(RepeatBase* rb) const {
-    auto* rhs = dynamic_cast<RepeatDateTime*>(rb);
-    if (!rhs)
-        return false;
-    return operator==(*rhs);
-}
-
-void RepeatDateTime::setToLastValue() {
-    set_value(coerce_from_instant(end_));
-}
-
-long RepeatDateTime::last_valid_value() const {
-    Instant valid = valid_value(value_);
-    return coerce_from_instant(valid);
-}
-
-Instant RepeatDateTime::valid_value(const Instant& value) const {
-    if (delta_ > Duration{std::chrono::seconds{0}}) {
-        if (value < start_)
-            return start_;
-        if (value > end_)
-            return end_;
-        return value;
-    }
-    if (value > start_)
-        return start_;
-    if (value < end_)
-        return end_;
-    return value;
-}
-
-long RepeatDateTime::last_valid_value_minus(int val) const {
-    Instant last_value    = coerce_to_instant(last_valid_value());
-    Instant updated_value = last_value - Duration{std::chrono::seconds{val}};
-    return coerce_from_instant(updated_value);
-}
-
-long RepeatDateTime::last_valid_value_plus(int val) const {
-    Instant last_value    = coerce_to_instant(last_valid_value());
-    Instant updated_value = last_value + Duration{std::chrono::seconds{val}};
-    return coerce_from_instant(updated_value);
-}
-
-void RepeatDateTime::reset() {
-    set_value(ecf::coerce_from_instant(start_));
-}
-
-void RepeatDateTime::write(std::string& ret) const {
-    ret += "repeat datetime ";
-    ret += name_;
-    ret += " ";
-    ret += boost::lexical_cast<std::string>(start_);
-    ret += " ";
-    ret += boost::lexical_cast<std::string>(end_);
-    ret += " ";
-    ret += boost::lexical_cast<std::string>(delta_);
-
-    if (!PrintStyle::defsStyle() && (value_ != start_)) {
-        ret += " # ";
-        ret += boost::lexical_cast<std::string>(value_);
-    }
-}
-
-std::string RepeatDateTime::dump() const {
-    std::stringstream ss;
-    ss << toString() << " value(" << value_ << ")";
-    return ss.str();
-}
-
-bool RepeatDateTime::operator==(const RepeatDateTime& rhs) const {
-    if (name_ != rhs.name_) {
-        return false;
-    }
-    if (start_ != rhs.start_) {
-        return false;
-    }
-    if (end_ != rhs.end_) {
-        return false;
-    }
-    if (delta_ != rhs.delta_) {
-        return false;
-    }
-    if (value_ != rhs.value_) {
-        return false;
-    }
-    return true;
-}
-
-std::string RepeatDateTime::valueAsString() const {
-    /// will throw a boost::bad_lexical_cast& if value is not convertible to a string
-    try {
-        long value      = last_valid_value();
-        Instant instant = coerce_to_instant(value);
-        return boost::lexical_cast<std::string>(instant);
-    }
-    catch (boost::bad_lexical_cast&) {
-        LOG_ASSERT(false, "RepeatDateTime::valueAsString(): could not convert value " << value_ << " to a string");
-    }
-    return {};
-}
-
-std::string RepeatDateTime::value_as_string(int index) const {
-    /// will throw a boost::bad_lexical_cast& if value is not convertible to a string
-    try {
-        return boost::lexical_cast<std::string>(index);
-    }
-    catch (boost::bad_lexical_cast&) {
-    }
-    return {};
-}
-
-std::string RepeatDateTime::next_value_as_string() const {
-    Instant next = coerce_to_instant(last_valid_value()) + delta_;
-
-    try {
-        return boost::lexical_cast<std::string>(valid_value(next));
-    }
-    catch (boost::bad_lexical_cast&) {
-    }
-    return {};
-}
-
-std::string RepeatDateTime::prev_value_as_string() const {
-    Instant previous = coerce_to_instant(last_valid_value()) - delta_;
-
-    try {
-        return boost::lexical_cast<std::string>(valid_value(previous));
-    }
-    catch (boost::bad_lexical_cast&) {
-    }
-    return {};
-}
-
-void RepeatDateTime::increment() {
-    auto new_value = value_ + delta_;
-    set_value(ecf::coerce_from_instant(new_value));
-}
-
-void RepeatDateTime::change(const std::string& newdate) {
-
-    long the_new_date;
-    try {
-        auto instant = Instant::parse(newdate);
-        the_new_date = ecf::coerce_from_instant(instant);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "RepeatDateTime::change: " << toString() << " The new date(" << newdate << ") is not valid";
-        throw std::runtime_error(ss.str());
-    }
-
-    changeValue(the_new_date);
-}
-
-void RepeatDateTime::changeValue(long the_new_date) {
-
-    auto new_date = ecf::coerce_to_instant(the_new_date);
-    if (delta_ > Duration{std::chrono::seconds{0}}) {
-        if (new_date < start_ || new_date > end_) {
-            std::stringstream ss;
-            ss << "RepeatDateTime::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
-               << " : " << end_ << "] but found " << new_date;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else {
-        if (new_date > start_ || new_date < end_) {
-            std::stringstream ss;
-            ss << "RepeatDateTime::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
-               << " : " << end_ << "] but found " << the_new_date;
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    // Ensure that new value is in step
-    auto diff = new_date - start_;
-    if (diff.as_seconds().count() % delta_.as_seconds().count() != 0) {
-        std::stringstream ss;
-        ss << "RepeatDateTime::changeValue: " << toString() << "\nThe new date " << the_new_date
-           << " is not in line with the delta/step";
-        throw std::runtime_error(ss.str());
-    }
-
-    set_value(the_new_date);
-}
-
-void RepeatDateTime::set_value(long the_new_date) {
-    // Note: the node is incremented one past, the last value
-    // In Node we increment() then check for validity
-    // hence the_new_value may be outside of the valid range.
-    // This can be seen when do a incremental sync,
-    // *hence* allow memento to copy the value as is.
-    value_ = coerce_to_instant(the_new_date);
-    update_repeat_genvar_value();
-    incr_state_change_no();
-}
-
-//======================================================================================
-
-RepeatDateList::RepeatDateList(const std::string& variable, const std::vector<int>& l)
-    : RepeatBase(variable),
-      list_(l) {
-    if (!Str::valid_name(variable)) {
-        throw std::runtime_error("RepeatDateList: Invalid name: " + variable);
-    }
-    if (list_.empty())
-        throw std::runtime_error("RepeatDateList: " + variable + " is empty");
-
-    for (int i : list_) {
-        std::string date_i = ecf::convert_to<std::string>(i);
-        if (date_i.size() != 8) {
-            std::stringstream ss;
-            ss << "Invalid Repeat datelist : " << variable << " the date " << i
-               << " is not valid. Please use yyyymmdd format.";
-            throw std::runtime_error("Invalid Repeat datelist " + ss.str());
-        }
-
-        try {
-            (void)boost::gregorian::date(from_undelimited_string(date_i));
-        }
-        catch (std::exception& e) {
-            std::stringstream ss;
-            ss << "Invalid Repeat datelist : " << variable << " the date " << i
-               << " is not valid. Please use yyyymmdd format.";
-            throw std::runtime_error("Invalid Repeat datelist " + ss.str());
-        }
-    }
-}
-
-void RepeatDateList::gen_variables(std::vector<Variable>& vec) const {
-    vec.push_back(yyyy_);
-    vec.push_back(mm_);
-    vec.push_back(dom_);
-    vec.push_back(dow_);
-    vec.push_back(julian_);
-    RepeatBase::gen_variables(vec);
-}
-
-const Variable& RepeatDateList::find_gen_variable(const std::string& name) const {
-    if (name == name_)
-        return var_;
-    if (name == yyyy_.name())
-        return yyyy_;
-    if (name == mm_.name())
-        return mm_;
-    if (name == dom_.name())
-        return dom_;
-    if (name == dow_.name())
-        return dow_;
-    if (name == julian_.name())
-        return julian_;
-    return Variable::EMPTY();
-}
-
-void RepeatDateList::update_repeat_genvar() const {
-    RepeatBase::update_repeat_genvar();
-
-    yyyy_.set_name(name_ + "_YYYY");
-    yyyy_.set_value("<invalid>");
-    mm_.set_name(name_ + "_MM");
-    mm_.set_value("<invalid>");
-    dom_.set_name(name_ + "_DD");
-    dom_.set_value("<invalid>");
-    dow_.set_name(name_ + "_DOW");
-    dom_.set_value("<invalid>");
-    julian_.set_name(name_ + "_JULIAN");
-    julian_.set_value("<invalid>");
-
-    update_repeat_genvar_value();
-}
-
-void RepeatDateList::update_repeat_genvar_value() const {
-    if (valid()) {
-        std::string date_as_string = valueAsString();
-        try {
-            boost::gregorian::date the_date(from_undelimited_string(date_as_string));
-            if (the_date.is_special()) {
-                std::stringstream ss;
-                ss << "RepeatDateList::update_repeat_genvar_value(): " << toString()
-                   << "\n invalid current date: " << date_as_string << " is special ";
-                log(Log::ERR, ss.str());
-                return;
-            }
-
-            // int day_of_year  = the_date.day_of_year();
-            int day_of_week  = the_date.day_of_week().as_number();
-            int day_of_month = the_date.day();
-            int month        = the_date.month();
-            int year         = the_date.year();
-
-            yyyy_.set_value(ecf::convert_to<std::string>(year));
-            mm_.set_value(ecf::convert_to<std::string>(month));
-            dom_.set_value(ecf::convert_to<std::string>(day_of_month));
-            dow_.set_value(ecf::convert_to<std::string>(day_of_week));
-
-            long last_value = last_valid_value();
-            long julian     = Cal::date_to_julian(last_value);
-            julian_.set_value(ecf::convert_to<std::string>(julian));
-        }
-        catch (std::exception& e) {
-            std::stringstream ss;
-            ss << "RepeatDateList::update_repeat_genvar_value(): " << toString()
-               << "\n invalid current date: " << date_as_string;
-            log(Log::ERR, ss.str());
-        }
-    }
-}
-
-int RepeatDateList::start() const {
-    if (list_.empty())
-        return 0;
-    return list_[0];
-}
-int RepeatDateList::end() const {
-    if (list_.empty())
-        return 0;
-    return list_[list_.size() - 1];
-}
-
-bool RepeatDateList::compare(RepeatBase* rb) const {
-    auto* rhs = dynamic_cast<RepeatDateList*>(rb);
-    if (!rhs)
-        return false;
-    return operator==(*rhs);
-}
-
-void RepeatDateList::write(std::string& ret) const {
-    ret += "repeat datelist ";
-    ret += name_;
-    for (int date : list_) {
-        ret += " \"";
-        ret += ecf::convert_to<std::string>(date);
-        ret += "\"";
-    }
-    if (!PrintStyle::defsStyle() && (currentIndex_ != 0)) {
-        ret += " # ";
-        ret += ecf::convert_to<std::string>(currentIndex_);
-    }
-}
-
-std::string RepeatDateList::dump() const {
-    std::stringstream ss;
-    ss << toString() << " ordinal-value(" << value() << ") value-as-string(" << valueAsString() << ")";
-    return ss.str();
-}
-
-void RepeatDateList::reset() {
-    set_value(0);
-}
-
-void RepeatDateList::increment() {
-    set_value(currentIndex_ + 1);
-}
-
-long RepeatDateList::value() const {
-    if (list_.empty())
-        return 0;
-
-    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(list_.size())) {
-        return list_[currentIndex_];
-    }
-    return 0;
-}
-
-long RepeatDateList::last_valid_value() const {
-    if (list_.empty())
-        return 0;
-
-    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(list_.size())) {
-        return list_[currentIndex_];
-    }
-    if (currentIndex_ < 0)
-        return list_[0];
-    if (currentIndex_ >= static_cast<int>(list_.size()))
-        return list_[list_.size() - 1];
-    return 0;
-}
-
-long RepeatDateList::last_valid_value_minus(int val) const {
-    long last_value = last_valid_value();
-    if (last_value == 0)
-        return 0;
-
-    long julian = Cal::date_to_julian(last_value);
-    julian -= val;
-    return Cal::julian_to_date(julian);
-}
-
-long RepeatDateList::last_valid_value_plus(int val) const {
-    long last_value = last_valid_value();
-    if (last_value == 0)
-        return 0;
-
-    long julian = Cal::date_to_julian(last_value);
-    julian += val;
-    return Cal::julian_to_date(julian);
-}
-
-void RepeatDateList::setToLastValue() {
-    if (list_.empty())
-        return;
-    set_value(static_cast<int>(list_.size() - 1));
-}
-
-std::string RepeatDateList::valueAsString() const {
-    return ecf::convert_to<std::string>(last_valid_value());
-}
-
-std::string RepeatDateList::value_as_string(int index) const {
-    if (list_.empty())
-        return string("0");
-    if (index >= 0 && index < static_cast<int>(list_.size())) {
-        return ecf::convert_to<std::string>(list_[index]);
-    }
-    if (index < 0)
-        return ecf::convert_to<std::string>(list_[0]);
-    if (index >= static_cast<int>(list_.size()))
-        return ecf::convert_to<std::string>(list_[list_.size() - 1]);
-    return std::string();
-}
-
-std::string RepeatDateList::next_value_as_string() const {
-    if (list_.empty())
-        return string("0");
-
-    int index = currentIndex_;
-    index++;
-    return value_as_string(index);
-}
-
-std::string RepeatDateList::prev_value_as_string() const {
-    if (list_.empty())
-        return string("0");
-
-    int index = currentIndex_;
-    index--;
-    return value_as_string(index);
-}
-
-void RepeatDateList::change(const std::string& newValue) {
-    // See if if matches one of the dates
-    int new_val = 0;
-    try {
-        new_val = ecf::convert_to<int>(newValue);
-    }
-    catch (...) {
-        std::stringstream ss;
-        ss << "RepeatDateList::change: " << toString() << "\nThe new value " << newValue
-           << " is must be convertible to integer, and correspond to an existing value\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    for (size_t i = 0; i < list_.size(); i++) {
-        if (list_[i] == new_val) {
-            set_value(i);
-            return;
-        }
-    }
-
-    std::stringstream ss;
-    ss << "RepeatDateList::change: " << toString() << "\nThe new value " << newValue
-       << " is not a valid member of the date list\n";
-    throw std::runtime_error(ss.str());
-}
-
-void RepeatDateList::changeValue(long the_new_index) {
-    if (list_.empty())
-        return;
-
-    if (the_new_index < 0 || the_new_index >= static_cast<int>(list_.size())) {
-        std::stringstream ss;
-        ss << "RepeatDateList::changeValue:" << toString() << "\nThe new value '" << the_new_index
-           << "' is not a valid index ";
-        ss << "expected range[0-" << list_.size() - 1 << "] but found '" << the_new_index << "'";
-        throw std::runtime_error(ss.str());
-    }
-    set_value(the_new_index);
-}
-
-void RepeatDateList::set_value(long the_new_index) {
-    if (list_.empty())
-        return;
-
-    // Note: the node is incremented one past, the last value
-    // In Node we increment() then check for validity
-    // hence the_new_value may be outside of the valid range.
-    // This can be seen when do a incremental sync,
-    // *hence* allow memento to copy the value as is.
-    currentIndex_ = the_new_index;
-    update_repeat_genvar_value();
-    incr_state_change_no();
-}
-
-bool RepeatDateList::operator==(const RepeatDateList& rhs) const {
-    if (name_ != rhs.name_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatDateList::operator==( name_(" << name_ << ") != rhs.name_(" << rhs.name_ << "))\n";
-        }
-#endif
-        return false;
-    }
-    if (list_ != rhs.list_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatDateList::operator==( list_ != rhs.list_ )\n";
-        }
-#endif
-        return false;
-    }
-    if (currentIndex_ != rhs.currentIndex_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatDateList::operator==( currentIndex_(" << currentIndex_ << ") != rhs.currentIndex_("
-                      << rhs.currentIndex_ << "))\n";
-        }
-#endif
-        return false;
-    }
-    return true;
-}
-
-//======================================================================================
-
-RepeatInteger::RepeatInteger(const std::string& variable, int start, int end, int delta)
-    : RepeatBase(variable),
-      start_(start),
-      end_(end),
-      delta_(delta),
-      value_(start) {
-    // cout << toString() << "\n";
-    if (!Str::valid_name(variable)) {
-        throw std::runtime_error("RepeatInteger: Invalid name: " + variable);
-    }
-}
-RepeatInteger::RepeatInteger() = default;
-
-bool RepeatInteger::compare(RepeatBase* rb) const {
-    auto* rhs = dynamic_cast<RepeatInteger*>(rb);
-    if (!rhs)
-        return false;
-    return operator==(*rhs);
-}
-
-void RepeatInteger::reset() {
-    value_ = start_;
-    incr_state_change_no();
-}
-
-long RepeatInteger::last_valid_value() const {
-    return valid_value(value_);
-}
-
-long RepeatInteger::valid_value(long value) const {
-    if (delta_ > 0) {
-        if (value < start_)
-            return start_;
-        if (value > end_)
-            return end_;
-        return value;
-    }
-    if (value > start_)
-        return start_;
-    if (value < end_)
-        return end_;
-    return value;
-}
-
-void RepeatInteger::increment() {
-    value_ += delta_;
-    incr_state_change_no();
-}
-
-void RepeatInteger::change(const std::string& newValue) {
-    long the_new_value = 0;
-    try {
-        the_new_value = ecf::convert_to<long>(newValue);
-    }
-    catch (const ecf::bad_conversion&) {
-        std::stringstream ss;
-        ss << "RepeatInteger::change:" << toString() << " The new value(" << newValue
-           << ") is not convertible to an long";
-        throw std::runtime_error(ss.str());
-    }
-    changeValue(the_new_value);
-}
-
-void RepeatInteger::changeValue(long the_new_value) {
-    if (delta_ > 0) {
-        if (the_new_value < start_ || the_new_value > end_) {
-            std::stringstream ss;
-            ss << "RepeatInteger::changeValue:" << toString() << ". The new value should be in the range[" << start_
-               << "-" << end_ << "] but found " << the_new_value;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else {
-        if (the_new_value > start_ || the_new_value < end_) {
-            std::stringstream ss;
-            ss << "RepeatInteger::changeValue:" << toString() << ". The new value should be in the range[" << start_
-               << "-" << end_ << "] but found " << the_new_value;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    set_value(the_new_value);
-}
-
-void RepeatInteger::set_value(long the_new_value) {
-    // To be used by Memento only. as it does no checking
-    // Note: the node is incremented one past, the last value
-    // In Node we increment() then check for validity
-    // hence the_new_value may be outside of the valid range.
-    // This can be seen when do a incremental sync,
-    // *hence* allow memento to copy the value as is.
-    value_ = the_new_value;
-    incr_state_change_no();
-}
-
-void RepeatInteger::setToLastValue() {
-    value_ = end_;
-    incr_state_change_no();
-}
-
-void RepeatInteger::write(std::string& ret) const {
-    ret += "repeat integer ";
-    ret += name_;
-    ret += " ";
-    ret += ecf::convert_to<std::string>(start_);
-    ret += " ";
-    ret += ecf::convert_to<std::string>(end_);
-    if (delta_ != 1) {
-        ret += " ";
-        ret += ecf::convert_to<std::string>(delta_);
-    }
-
-    if (!PrintStyle::defsStyle() && (value_ != start_)) {
-        ret += " # ";
-        ret += ecf::convert_to<std::string>(value_);
-    }
-}
-
-std::string RepeatInteger::dump() const {
-    std::stringstream ss;
-    ss << toString() << " value(" << value_ << ")";
-    return ss.str();
-}
-
-bool RepeatInteger::operator==(const RepeatInteger& rhs) const {
-    if (name_ != rhs.name_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatInteger::operator==( name_(" << name_ << ") != rhs.name_(" << rhs.name_ << "))"
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (start_ != rhs.start_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatInteger::operator==( start_(" << start_ << ") != rhs.start_(" << rhs.start_ << "))"
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (end_ != rhs.end_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatInteger::operator==( end_(" << end_ << ") != rhs.end_(" << rhs.end_ << "))"
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (delta_ != rhs.delta_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatInteger::operator==( delta_(" << delta_ << ") != rhs.delta_(" << rhs.delta_ << "))"
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (value_ != rhs.value_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatInteger::operator==( value_(" << value_ << ") != rhs.value_(" << rhs.value_ << "))"
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    return true;
-}
-
-std::string RepeatInteger::valueAsString() const {
-    /// will throw an ecf::bad_conversion if value is not convertible to a string
-    try {
-        return ecf::convert_to<std::string>(last_valid_value());
-    }
-    catch (const ecf::bad_conversion&) {
-        LOG_ASSERT(false, "");
-    }
-    return string();
-}
-
-std::string RepeatInteger::value_as_string(int index) const {
-    /// will throw an ecf::bad_conversion if value is not convertible to a string
-    try {
-        return ecf::convert_to<std::string>(index);
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-    return string();
-}
-
-std::string RepeatInteger::next_value_as_string() const {
-    long val = last_valid_value();
-    val += delta_;
-    try {
-        return ecf::convert_to<std::string>(valid_value(val));
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-    return string();
-}
-
-std::string RepeatInteger::prev_value_as_string() const {
-    long val = last_valid_value();
-    val -= delta_;
-    try {
-        return ecf::convert_to<std::string>(valid_value(val));
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-    return string();
-}
-
-//======================================================================================
-
-RepeatEnumerated::RepeatEnumerated(const std::string& variable, const std::vector<std::string>& theEnums)
-    : RepeatBase(variable),
-      theEnums_(theEnums) {
-    if (!Str::valid_name(variable)) {
-        throw std::runtime_error("RepeatEnumerated: Invalid name: " + variable);
-    }
-    if (theEnums.empty()) {
-        throw std::runtime_error("RepeatEnumerated: " + variable + " is empty");
-    }
-}
-
-int RepeatEnumerated::end() const {
-    if (theEnums_.empty())
-        return 0;
-    return static_cast<int>(theEnums_.size() - 1);
-}
-
-bool RepeatEnumerated::compare(RepeatBase* rb) const {
-    auto* rhs = dynamic_cast<RepeatEnumerated*>(rb);
-    if (!rhs)
-        return false;
-    return operator==(*rhs);
-}
-
-void RepeatEnumerated::write(std::string& ret) const {
-    ret += "repeat enumerated ";
-    ret += name_;
-    for (const string& s : theEnums_) {
-        ret += " \"";
-        ret += s;
-        ret += "\"";
-    }
-    if (!PrintStyle::defsStyle() && (currentIndex_ != 0)) {
-        ret += " # ";
-        ret += ecf::convert_to<std::string>(currentIndex_);
-    }
-}
-
-std::string RepeatEnumerated::dump() const {
-    std::stringstream ss;
-    ss << toString() << " ordinal-value(" << value() << ")   value-as-string(" << valueAsString() << ")";
-    return ss.str();
-}
-
-void RepeatEnumerated::reset() {
-    currentIndex_ = 0;
-    incr_state_change_no();
-}
-
-void RepeatEnumerated::increment() {
-    currentIndex_++;
-    incr_state_change_no();
-}
-
-long RepeatEnumerated::value() const {
-    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theEnums_.size())) {
-        try {
-            return ecf::convert_to<int>(theEnums_[currentIndex_]);
-        }
-        catch (const ecf::bad_conversion&) {
-            // Ignore and return currentIndex_
-        }
-    }
-    return currentIndex_;
-}
-
-long RepeatEnumerated::last_valid_value() const {
-    if (!theEnums_.empty()) {
-        if (currentIndex_ < 0) {
-            try {
-                return ecf::convert_to<int>(theEnums_[0]);
-            }
-            catch (const ecf::bad_conversion&) { /* Ignore and return first index */
-            }
-            return 0;
-        }
-        if (currentIndex_ >= static_cast<int>(theEnums_.size())) {
-
-            try {
-                return ecf::convert_to<int>(theEnums_[theEnums_.size() - 1]);
-            }
-            catch (const ecf::bad_conversion&) { /* Ignore and return last index */
-            }
-            return static_cast<long>(theEnums_.size() - 1);
-        }
-
-        // return current value as integer or as index
-        return value();
-    }
-    return 0;
-}
-
-void RepeatEnumerated::setToLastValue() {
-    currentIndex_ = static_cast<int>(theEnums_.size() - 1);
-    if (currentIndex_ < 0)
-        currentIndex_ = 0;
-    incr_state_change_no();
-}
-
-std::string RepeatEnumerated::valueAsString() const {
-    // This must always return a valid value
-    if (!theEnums_.empty()) {
-
-        // Returns the last valid value
-        if (currentIndex_ < 0)
-            return theEnums_[0]; // return first
-
-        if (currentIndex_ >= static_cast<int>(theEnums_.size())) {
-            return theEnums_[theEnums_.size() - 1]; // return last
-        }
-
-        return theEnums_[currentIndex_];
-    }
-    return std::string();
-}
-
-std::string RepeatEnumerated::value_as_string(int index) const {
-    if (index >= 0 && index < static_cast<int>(theEnums_.size())) {
-        return theEnums_[index];
-    }
-    return std::string();
-}
-
-std::string RepeatEnumerated::next_value_as_string() const {
-    if (theEnums_.empty())
-        return string();
-
-    int index = currentIndex_;
-    index++;
-    if (index < 0)
-        return theEnums_[0]; // return first
-    if (index >= static_cast<int>(theEnums_.size()))
-        return theEnums_[theEnums_.size() - 1]; // return last
-    return theEnums_[index];
-}
-
-std::string RepeatEnumerated::prev_value_as_string() const {
-    if (theEnums_.empty())
-        return string();
-
-    int index = currentIndex_;
-    index--;
-    if (index < 0)
-        return theEnums_[0]; // return first
-    if (index >= static_cast<int>(theEnums_.size()))
-        return theEnums_[theEnums_.size() - 1]; // return last
-    return theEnums_[index];
-}
-
-void RepeatEnumerated::change(const std::string& newValue) {
-    // See if if matches one of the enums
-    for (size_t i = 0; i < theEnums_.size(); i++) {
-        if (theEnums_[i] == newValue) {
-            currentIndex_ = i;
-            incr_state_change_no();
-            return;
-        }
-    }
-
-    // If the value is convertible to an integer, treat as an index
-    try {
-        auto the_new_value = ecf::convert_to<long>(newValue);
-        changeValue(the_new_value); // can throw if out of range
-        return;
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-
-    std::stringstream ss;
-    ss << "RepeatEnumerated::change:" << toString() << "\nThe new value " << newValue
-       << " is not a valid index or a member of the enumerated list\n";
-    throw std::runtime_error(ss.str());
-}
-
-void RepeatEnumerated::changeValue(long the_new_value) {
-    if (the_new_value < 0 || the_new_value >= static_cast<int>(theEnums_.size())) {
-        std::stringstream ss;
-        ss << "RepeatEnumerated::changeValue:" << toString() << "\nThe new value '" << the_new_value
-           << "' is not a valid index ";
-        ss << "expected range[0-" << theEnums_.size() - 1 << "] but found '" << the_new_value << "'";
-        throw std::runtime_error(ss.str());
-    }
-    set_value(the_new_value);
-}
-
-void RepeatEnumerated::set_value(long the_new_value) {
-    // Note: the node is incremented one past, the last value
-    // In Node we increment() then check for validity
-    // hence the_new_value may be outside of the valid range.
-    // This can be seen when do a incremental sync,
-    // *hence* allow memento to copy the value as is.
-    currentIndex_ = the_new_value;
-    incr_state_change_no();
-}
-
-bool RepeatEnumerated::operator==(const RepeatEnumerated& rhs) const {
-    if (name_ != rhs.name_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatEnumerated::operator==( name_(" << name_ << ") != rhs.name_(" << rhs.name_ << "))\n";
-        }
-#endif
-        return false;
-    }
-    if (theEnums_ != rhs.theEnums_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatEnumerated::operator==( theEnums_ != rhs.theEnums_ )\n";
-        }
-#endif
-        return false;
-    }
-    if (currentIndex_ != rhs.currentIndex_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "RepeatEnumerated::operator==( currentIndex_(" << currentIndex_ << ") != rhs.currentIndex_("
-                      << rhs.currentIndex_ << "))\n";
-        }
-#endif
-        return false;
-    }
-    return true;
-}
-
-//======================================================================================
-
-RepeatString::RepeatString(const std::string& variable, const std::vector<std::string>& theEnums)
-    : RepeatBase(variable),
-      theStrings_(theEnums) {
-    if (!Str::valid_name(variable)) {
-        throw std::runtime_error("RepeatString:: Invalid name: " + variable);
-    }
-    if (theEnums.empty()) {
-        throw std::runtime_error("RepeatString : " + variable + " is empty");
-    }
-}
-
-int RepeatString::end() const {
-    if (theStrings_.empty())
-        return 0;
-    return static_cast<int>(theStrings_.size() - 1);
-}
-
-bool RepeatString::compare(RepeatBase* rb) const {
-    auto* rhs = dynamic_cast<RepeatString*>(rb);
-    if (!rhs)
-        return false;
-    return operator==(*rhs);
-}
-
-void RepeatString::write(std::string& ret) const {
-    ret += "repeat string ";
-    ret += name_;
-    for (const string& s : theStrings_) {
-        ret += " \"";
-        ret += s;
-        ret += "\"";
-    }
-    if (!PrintStyle::defsStyle() && (currentIndex_ != 0)) {
-        ret += " # ";
-        ret += ecf::convert_to<std::string>(value());
-    }
-}
-
-std::string RepeatString::dump() const {
-    std::stringstream ss;
-    ss << toString() << " ordinal-value(" << value() << ")   value-as-string(" << valueAsString() << ")";
-    return ss.str();
-}
-
-void RepeatString::reset() {
-    currentIndex_ = 0;
-    incr_state_change_no();
-}
-
-long RepeatString::last_valid_value() const {
-    if (!theStrings_.empty()) {
-        if (currentIndex_ < 0)
-            return 0;
-        if (currentIndex_ >= static_cast<int>(theStrings_.size()))
-            return static_cast<long>(theStrings_.size() - 1);
-        return currentIndex_;
-    }
-    return 0;
-}
-
-std::string RepeatString::next_value_as_string() const {
-    if (!theStrings_.empty()) {
-        int index = currentIndex_;
-        index++;
-        if (index < 0)
-            return theStrings_[0]; // return first
-        if (index >= static_cast<int>(theStrings_.size()))
-            return theStrings_[theStrings_.size() - 1]; // return last
-        return theStrings_[index];
-    }
-    return string();
-}
-
-std::string RepeatString::prev_value_as_string() const {
-    if (!theStrings_.empty()) {
-        int index = currentIndex_;
-        index--;
-        if (index < 0)
-            return theStrings_[0]; // return first
-        if (index >= static_cast<int>(theStrings_.size()))
-            return theStrings_[theStrings_.size() - 1]; // return last
-        return theStrings_[index];
-    }
-    return string();
-}
-
-void RepeatString::increment() {
-    currentIndex_++;
-    incr_state_change_no();
-}
-
-void RepeatString::setToLastValue() {
-    currentIndex_ = static_cast<int>(theStrings_.size() - 1);
-    if (currentIndex_ < 0)
-        currentIndex_ = 0;
-    incr_state_change_no();
-}
-
-std::string RepeatString::valueAsString() const {
-    if (!theStrings_.empty())
-        return theStrings_[last_valid_value()];
-    return std::string();
-}
-
-std::string RepeatString::value_as_string(int index) const {
-    if (index >= 0 && index < static_cast<int>(theStrings_.size())) {
-        return theStrings_[index];
-    }
-    return std::string();
-}
-
-void RepeatString::change(const std::string& newValue) {
-    // See if if matches one of the strings
-    for (size_t i = 0; i < theStrings_.size(); i++) {
-        if (theStrings_[i] == newValue) {
-            currentIndex_ = i;
-            incr_state_change_no();
-            return;
-        }
-    }
-
-    // If the value is convertible to an integer, treat as an index
-    try {
-        long the_new_value = ecf::convert_to<int>(newValue);
-        changeValue(the_new_value);
-        return;
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-
-    std::stringstream ss;
-    ss << "RepeatString::change: " << toString() << "\nThe new value " << newValue
-       << " is not a valid index or member of the string list";
-    throw std::runtime_error(ss.str());
-}
-
-void RepeatString::changeValue(long the_new_value) {
-    if (the_new_value < 0 || the_new_value >= static_cast<int>(theStrings_.size())) {
-        std::stringstream ss;
-        ss << "RepeatString::change: " << toString() << " The new the integer " << the_new_value
-           << " is not a valid index ";
-        ss << "expected range[0-" << theStrings_.size() - 1 << "]'";
-        throw std::runtime_error(ss.str());
-    }
-    set_value(the_new_value);
-}
-
-void RepeatString::set_value(long the_new_value) {
-    // Note: the node is incremented one past, the last value
-    // In Node we increment() then check for validity
-    // hence the_new_value may be outside of the valid range.
-    // This can be seen when do a incremental sync,
-    // *hence* allow memento to copy the value as is.
-    currentIndex_ = the_new_value;
-    incr_state_change_no();
-}
-
-bool RepeatString::operator==(const RepeatString& rhs) const {
-    if (name_ != rhs.name_) {
-        return false;
-    }
-    if (theStrings_ != rhs.theStrings_) {
-        return false;
-    }
-    if (currentIndex_ != rhs.currentIndex_) {
-        return false;
-    }
-    return true;
-}
-
-//=======================================================================================
-
-bool RepeatDay::compare(RepeatBase* rb) const {
-    auto* rhs = dynamic_cast<RepeatDay*>(rb);
-    if (!rhs)
-        return false;
-    return operator==(*rhs);
-}
-
-void RepeatDay::write(std::string& ret) const {
-    ret += "repeat day ";
-    ret += ecf::convert_to<std::string>(step_);
-}
-
-std::string RepeatDay::dump() const {
-    return toString();
-}
-
-bool RepeatDay::operator==(const RepeatDay& rhs) const {
-    if (step_ != rhs.step_) {
-        return false;
-    }
-    return true;
-}
-// =========================================================================================
-
-template <class Archive>
-void RepeatBase::serialize(Archive& ar) {
-    ar(CEREAL_NVP(name_));
-}
-
-template <class Archive>
-void RepeatDate::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<RepeatBase>(this),
-       CEREAL_NVP(start_),
-       CEREAL_NVP(end_),
-       CEREAL_NVP(delta_),
-       CEREAL_NVP(value_));
-}
-
-template <class Archive>
-void RepeatDateTime::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<RepeatBase>(this),
-       CEREAL_NVP(start_),
-       CEREAL_NVP(end_),
-       CEREAL_NVP(delta_),
-       CEREAL_NVP(value_));
-}
-
-template <class Archive>
-void RepeatInteger::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<RepeatBase>(this),
-       CEREAL_NVP(start_),
-       CEREAL_NVP(end_),
-       CEREAL_NVP(delta_),
-       CEREAL_NVP(value_));
-}
-
-template <class Archive>
-void RepeatEnumerated::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(theEnums_), CEREAL_NVP(currentIndex_));
-}
-
-template <class Archive>
-void RepeatDateList::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(list_), CEREAL_NVP(currentIndex_));
-}
-
-template <class Archive>
-void RepeatString::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(theStrings_), CEREAL_NVP(currentIndex_));
-}
-
-template <class Archive>
-void RepeatDay::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(step_));
-}
-
-template <class Archive>
-void Repeat::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(type_));
-}
-
-CEREAL_TEMPLATE_SPECIALIZE(RepeatBase);
-CEREAL_TEMPLATE_SPECIALIZE_V(RepeatDate);
-CEREAL_TEMPLATE_SPECIALIZE_V(RepeatDateList);
-CEREAL_TEMPLATE_SPECIALIZE_V(RepeatInteger);
-CEREAL_TEMPLATE_SPECIALIZE_V(RepeatEnumerated);
-CEREAL_TEMPLATE_SPECIALIZE_V(RepeatString);
-CEREAL_TEMPLATE_SPECIALIZE_V(RepeatDay);
-CEREAL_TEMPLATE_SPECIALIZE_V(Repeat);
-
-CEREAL_REGISTER_TYPE(RepeatDate)
-CEREAL_REGISTER_TYPE(RepeatDateList)
-CEREAL_REGISTER_TYPE(RepeatInteger)
-CEREAL_REGISTER_TYPE(RepeatEnumerated)
-CEREAL_REGISTER_TYPE(RepeatString)
-CEREAL_REGISTER_TYPE(RepeatDay)
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/RepeatAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/RepeatAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/RepeatAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/RepeatAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,723 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_RepeatAttr_HPP
-#define ecflow_attribute_RepeatAttr_HPP
-
-///
-/// \brief Repeat Attribute. Please note that for repeat string, enumeration
-///        the positional index is used for evaluation.
-///
-/// Simulation: Simulation must not affect the real job submission in the server.
-///   o Infinite repeats cause problems with simulation, hence we have
-///     a mechanism to stop this, when reset is called, via server this is disabled
-///
-
-#include <cstdint>
-#include <iomanip>
-#include <iostream>
-#include <memory>
-#include <sstream>
-#include <vector>
-
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/core/Chrono.hpp"
-
-/////////////////////////////////////////////////////////////////////////
-// Node can only have one repeat.
-//
-class RepeatBase {
-public:
-    explicit RepeatBase(const std::string& name) : name_(name) {}
-    RepeatBase() = default;
-    virtual ~RepeatBase();
-
-    /// make non virtual so that it can be in-lined. Called millions of times
-    const std::string& name() const { return name_; }
-    virtual int start() const = 0;
-    virtual int end() const   = 0;
-    virtual int step() const  = 0;
-
-    // Handle generated variables
-    virtual void gen_variables(std::vector<Variable>& vec) const { vec.push_back(var_); }
-    virtual const Variable& find_gen_variable(const std::string& name) const {
-        return name == name_ ? var_ : Variable::EMPTY();
-    }
-    virtual void update_repeat_genvar() const;
-
-    // After Repeat expiration the last call to increment() can cause
-    // value to be beyond the last valid value
-    // Depending on the kind of repeat the returned can be value or the current index
-    // RepeatDate       -> value
-    // RepeatDateTime   -> value
-    // RepeatDateList   -> value
-    // RepeatString     -> index into array of strings
-    // RepeatInteger    -> value
-    // RepeatEnumerated -> index | value return value at index if cast-able to integer, otherwise return index ******
-    // RepeatDay        -> value
-    virtual long value() const = 0;
-
-    // Depending on the kind of repeat the returned can be value or *current* index
-    // RepeatDate       -> value
-    // RepeatDateTime   -> value
-    // RepeatDateList   -> value
-    // RepeatString     -> index  ( will always return a index)
-    // RepeatInteger    -> value
-    // RepeatEnumerated -> index  ( will always return a index)
-    // RepeatDay        -> value
-    virtual long index_or_value() const = 0;
-    virtual void increment()            = 0;
-
-    // returns a value with in the range start/end
-    // Hence at Repeat expiration will return value associated with end()
-    virtual long last_valid_value() const = 0;
-    virtual long last_valid_value_minus(int val) const { return last_valid_value() - val; }
-    virtual long last_valid_value_plus(int val) const { return last_valid_value() + val; }
-
-    virtual RepeatBase* clone() const                    = 0;
-    virtual bool compare(RepeatBase*) const              = 0;
-    virtual bool valid() const                           = 0;
-    virtual void setToLastValue()                        = 0;
-    virtual std::string valueAsString() const            = 0; // uses last_valid_value
-    virtual std::string value_as_string(int index) const = 0; // used in test only
-    virtual std::string next_value_as_string() const     = 0;
-    virtual std::string prev_value_as_string() const     = 0;
-    virtual void reset()                                 = 0;
-    virtual void change(const std::string& newValue)     = 0; // can throw std::runtime_error
-    virtual void changeValue(long newValue)              = 0; // can throw std::runtime_error
-    virtual void set_value(long new_value_or_index)      = 0; // will NOT throw, allows any value
-    std::string toString() const;
-    virtual void write(std::string&) const = 0;
-    virtual std::string dump() const       = 0;
-
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    /// Simulator functions:
-    virtual bool isInfinite() const = 0;
-
-    virtual bool is_repeat_day() const { return false; }
-
-    virtual bool isDate() const { return false; }
-    virtual bool isDateTime() const { return false; }
-    virtual bool isDateList() const { return false; }
-    virtual bool isInteger() const { return false; }
-    virtual bool isEnumerated() const { return false; }
-    virtual bool isString() const { return false; }
-    virtual bool isDay() const { return false; }
-
-protected:
-    void incr_state_change_no();
-
-    mutable Variable var_; // *not* persisted
-    std::string name_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-///
-/// The date has no meaning in a physical sense, only used as a for loop over dates
-class RepeatDate final : public RepeatBase {
-public:
-    RepeatDate(const std::string& variable, int start, int end, int delta = 1 /* always in days*/);
-    RepeatDate() = default;
-
-    void gen_variables(std::vector<Variable>& vec) const override;
-    const Variable& find_gen_variable(const std::string& name) const override;
-    void update_repeat_genvar() const override;
-
-    int start() const override { return start_; }
-    int end() const override { return end_; }
-    int step() const override { return delta_; }
-    long value() const override { return value_; }
-    long index_or_value() const override { return value_; }
-    long last_valid_value() const override;
-    long last_valid_value_minus(int value) const override;
-    long last_valid_value_plus(int value) const override;
-
-    void delta(int d) { delta_ = d; }
-    bool operator==(const RepeatDate& rhs) const;
-    bool operator<(const RepeatDate& rhs) const { return name() < rhs.name(); }
-
-    RepeatDate* clone() const override { return new RepeatDate(name_, start_, end_, delta_, value_); }
-    bool compare(RepeatBase*) const override;
-    bool valid() const override { return (delta_ > 0) ? (value_ <= end_) : (value_ >= end_); }
-    std::string valueAsString() const override;
-    std::string value_as_string(int index) const override;
-    std::string next_value_as_string() const override;
-    std::string prev_value_as_string() const override;
-
-    void setToLastValue() override;
-    void reset() override;
-    void increment() override;
-    void change(const std::string& newValue) override; // can throw std::runtime_error
-    void changeValue(long newValue) override;          // can throw std::runtime_error
-    void set_value(long newValue) override;            // will NOT throw, allows any value
-
-    void write(std::string&) const override;
-
-    std::string dump() const override;
-    bool isDate() const override { return true; }
-
-    /// Simulator functions:
-    bool isInfinite() const override { return false; }
-
-private:
-    long valid_value(long value) const;
-
-    RepeatDate(const std::string& name, int start, int end, int delta, long value)
-        : RepeatBase(name),
-          start_(start),
-          end_(end),
-          delta_(delta),
-          value_(value) {}
-
-    void update_repeat_genvar_value() const;
-
-private:
-    int start_{0};
-    int end_{0};
-    int delta_{0};
-    long value_{0};
-
-    mutable Variable yyyy_;   // *not* persisted
-    mutable Variable mm_;     // *not* persisted
-    mutable Variable dom_;    // *not* persisted
-    mutable Variable dow_;    // *not* persisted
-    mutable Variable julian_; // *not* persisted
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class RepeatDateTime final : public RepeatBase {
-public:
-    RepeatDateTime(const std::string& variable,
-                   const std::string& start,
-                   const std::string& end,
-                   const std::string& delta = "24:00:00");
-    RepeatDateTime(const std::string& variable, ecf::Instant start, ecf::Instant end, ecf::Duration delta);
-    RepeatDateTime() = default;
-
-    void gen_variables(std::vector<Variable>& vec) const override;
-    const Variable& find_gen_variable(const std::string& name) const override;
-    void update_repeat_genvar() const override;
-
-    const ecf::Instant& start_instant() const { return start_; }
-    const ecf::Instant& end_instant() const { return end_; }
-    const ecf::Duration& step_duration() const { return delta_; }
-    const ecf::Instant& value_instant() const { return value_; }
-
-    int start() const override { return coerce_from_instant(start_); }
-    int end() const override { return coerce_from_instant(end_); }
-    int step() const override { return delta_.as_seconds().count(); }
-    long value() const override { return coerce_from_instant(value_); }
-    long index_or_value() const override { return coerce_from_instant(value_); }
-    long last_valid_value() const override;
-    long last_valid_value_minus(int value) const override;
-    long last_valid_value_plus(int value) const override;
-
-    void delta(const ecf::Duration& d) { delta_ = d; }
-    bool operator==(const RepeatDateTime& rhs) const;
-    bool operator<(const RepeatDateTime& rhs) const { return name() < rhs.name(); }
-
-    RepeatDateTime* clone() const override { return new RepeatDateTime(name_, start_, end_, delta_, value_); }
-    bool compare(RepeatBase*) const override;
-    bool valid() const override {
-        return (delta_ > ecf::Duration{std::chrono::seconds{0}}) ? (value_ <= end_) : (value_ >= end_);
-    }
-    std::string valueAsString() const override;
-    std::string value_as_string(int index) const override;
-    std::string next_value_as_string() const override;
-    std::string prev_value_as_string() const override;
-
-    void setToLastValue() override;
-    void reset() override;
-    void increment() override;
-    void change(const std::string& newValue) override; // can throw std::runtime_error
-    void changeValue(long newValue) override;          // can throw std::runtime_error
-    void set_value(long newValue) override;            // will NOT throw, allows any value
-
-    void write(std::string&) const override;
-
-    std::string dump() const override;
-    bool isDateTime() const override { return true; }
-
-    /// Simulator functions:
-    bool isInfinite() const override { return false; }
-
-private:
-    ecf::Instant valid_value(const ecf::Instant& value) const;
-
-    RepeatDateTime(const std::string& name,
-                   ecf::Instant start,
-                   ecf::Instant end,
-                   ecf::Duration delta,
-                   ecf::Instant value)
-        : RepeatBase(name),
-          start_(start),
-          end_(end),
-          delta_(delta),
-          value_(value) {}
-
-    void update_repeat_genvar_value() const;
-
-private:
-    ecf::Instant start_;
-    ecf::Instant end_;
-    ecf::Duration delta_;
-    ecf::Instant value_;
-
-    // *not* persisted
-    mutable VariableMap generated_{
-        // clang-format off
-        // Date
-        Variable(name_ + "_DATE", "<invalid>"),
-        // Date Components
-        Variable(name_ + "_YYYY", "<invalid>"),
-        Variable(name_ + "_MM", "<invalid>"),
-        Variable(name_ + "_DD", "<invalid>"),
-        Variable(name_ + "_JULIAN", "<invalid>"),
-        // Time
-        Variable(name_ + "_TIME", "<invalid>"),
-        // Time Components4
-        Variable(name_ + "_HOURS", "<invalid>"),
-        Variable(name_ + "_MINUTES", "<invalid>"),
-        Variable(name_ + "_SECONDS", "<invalid>")
-        // clang-format on
-    };
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class RepeatDateList final : public RepeatBase {
-public:
-    RepeatDateList(const std::string& variable, const std::vector<int>&); // will throw for empty list
-    RepeatDateList() = default;
-
-    void gen_variables(std::vector<Variable>& vec) const override;
-    const Variable& find_gen_variable(const std::string& name) const override;
-    void update_repeat_genvar() const override;
-
-    bool operator==(const RepeatDateList& rhs) const;
-    bool operator<(const RepeatDateList& rhs) const { return name() < rhs.name(); }
-
-    int start() const override;
-    int end() const override;
-    int step() const override { return 1; }
-    long value() const override; // return value at index   otherwise return 0
-    long index_or_value() const override { return currentIndex_; }
-    long last_valid_value() const override;
-    long last_valid_value_minus(int value) const override;
-    long last_valid_value_plus(int value) const override;
-
-    RepeatBase* clone() const override { return new RepeatDateList(name_, list_, currentIndex_); }
-    bool compare(RepeatBase*) const override;
-    bool valid() const override { return (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(list_.size())); }
-    std::string valueAsString() const override;
-    std::string value_as_string(int index) const override;
-    std::string next_value_as_string() const override;
-    std::string prev_value_as_string() const override;
-
-    void setToLastValue() override;
-    void reset() override;
-    void increment() override;
-    void change(const std::string& newValue) override; // can throw std::runtime_error
-    void changeValue(long newValue) override;          // can throw std::runtime_error
-    void set_value(long newValue) override;            // will NOT throw, allows any value
-    void write(std::string&) const override;
-    std::string dump() const override;
-    bool isDateList() const override { return true; }
-    int indexNum() const { return static_cast<int>(list_.size()); }
-
-    /// Simulator functions:
-    bool isInfinite() const override { return false; }
-
-private:
-    RepeatDateList(const std::string& variable, const std::vector<int>& l, int index)
-        : RepeatBase(variable),
-          currentIndex_(index),
-          list_(l) {}
-
-    void update_repeat_genvar_value() const;
-
-private:
-    int currentIndex_{0};
-    std::vector<int> list_;
-
-    mutable Variable yyyy_;   // *not* persisted
-    mutable Variable mm_;     // *not* persisted
-    mutable Variable dom_;    // *not* persisted
-    mutable Variable dow_;    // *not* persisted
-    mutable Variable julian_; // *not* persisted
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class RepeatInteger final : public RepeatBase {
-public:
-    RepeatInteger(const std::string& variable, int start, int end, int delta = 1);
-    RepeatInteger();
-
-    bool operator==(const RepeatInteger& rhs) const;
-    bool operator<(const RepeatInteger& rhs) const { return name() < rhs.name(); }
-
-    int start() const override { return start_; }
-    int end() const override { return end_; }
-    int step() const override { return delta_; }
-    long value() const override { return value_; }
-    long index_or_value() const override { return value_; }
-    long last_valid_value() const override;
-
-    RepeatInteger* clone() const override { return new RepeatInteger(name_, start_, end_, delta_, value_); }
-    bool compare(RepeatBase*) const override;
-    bool valid() const override { return (delta_ > 0) ? (value_ <= end_) : (value_ >= end_); }
-    std::string valueAsString() const override;
-    std::string value_as_string(int index) const override;
-    std::string next_value_as_string() const override;
-    std::string prev_value_as_string() const override;
-    void setToLastValue() override;
-    void reset() override;
-    void increment() override;
-    void change(const std::string& newValue) override; // can throw std::runtime_error
-    void changeValue(long newValue) override;          // can throw std::runtime_error
-    void set_value(long newValue) override;            // will NOT throw, allows any value
-    void write(std::string&) const override;
-    std::string dump() const override;
-    bool isInteger() const override { return true; }
-
-    /// Simulator functions:
-    bool isInfinite() const override { return false; }
-
-private:
-    long valid_value(long value) const;
-
-    RepeatInteger(const std::string& name, int start, int end, int delta, long value)
-        : RepeatBase(name),
-          start_(start),
-          end_(end),
-          delta_(delta),
-          value_(value) {}
-
-private:
-    int start_{0};
-    int end_{0};
-    int delta_{0};
-    long value_{0};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-// Note:: Difference between RepeatEnumerated and  RepeatString, is that
-// RepeatEnumerated::value() will return the value at the index if cast-able to integer,
-// whereas RepeatString::value() will always return the index.
-class RepeatEnumerated final : public RepeatBase {
-public:
-    RepeatEnumerated(const std::string& variable, const std::vector<std::string>& theEnums);
-    RepeatEnumerated() = default;
-
-    bool operator==(const RepeatEnumerated& rhs) const;
-    bool operator<(const RepeatEnumerated& rhs) const { return name() < rhs.name(); }
-
-    int start() const override { return 0; }
-    int end() const override;
-    int step() const override { return 1; }
-    long value() const override; // return value at index if cast-able to integer, otherwise return index
-    long index_or_value() const override { return currentIndex_; }
-    long last_valid_value() const override;
-
-    RepeatBase* clone() const override { return new RepeatEnumerated(name_, theEnums_, currentIndex_); }
-    bool compare(RepeatBase*) const override;
-    bool valid() const override { return (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theEnums_.size())); }
-    std::string valueAsString() const override;
-    std::string value_as_string(int index) const override;
-    std::string next_value_as_string() const override;
-    std::string prev_value_as_string() const override;
-
-    void setToLastValue() override;
-    void reset() override;
-    void increment() override;
-    void change(const std::string& newValue) override; // can throw std::runtime_error
-    void changeValue(long newValue) override;          // can throw std::runtime_error
-    void set_value(long newValue) override;            // will NOT throw, allows any value
-    void write(std::string&) const override;
-    std::string dump() const override;
-    bool isEnumerated() const override { return true; }
-    int indexNum() const { return static_cast<int>(theEnums_.size()); }
-
-    /// Simulator functions:
-    bool isInfinite() const override { return false; }
-
-private:
-    RepeatEnumerated(const std::string& variable, const std::vector<std::string>& theEnums, int index)
-        : RepeatBase(variable),
-          currentIndex_(index),
-          theEnums_(theEnums) {}
-
-private:
-    int currentIndex_{0};
-    std::vector<std::string> theEnums_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class RepeatString final : public RepeatBase {
-public:
-    RepeatString(const std::string& variable, const std::vector<std::string>& theEnums);
-    RepeatString() = default;
-
-    bool operator==(const RepeatString& rhs) const;
-    bool operator<(const RepeatString& rhs) const { return name() < rhs.name(); }
-
-    int start() const override { return 0; }
-    int end() const override;
-    int step() const override { return 1; }
-    long value() const override { return currentIndex_; }
-    long index_or_value() const override { return currentIndex_; }
-    long last_valid_value() const override; // returns the index
-
-    RepeatBase* clone() const override { return new RepeatString(name_, theStrings_, currentIndex_); }
-    bool compare(RepeatBase*) const override;
-    bool valid() const override { return (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theStrings_.size())); }
-    std::string valueAsString() const override;
-    std::string value_as_string(int index) const override;
-    std::string next_value_as_string() const override;
-    std::string prev_value_as_string() const override;
-
-    void setToLastValue() override;
-    void reset() override;
-    void increment() override;
-    void change(const std::string& newValue) override; // can throw std::runtime_error
-    void changeValue(long newValue) override;          // can throw std::runtime_error
-    void set_value(long newValue) override;            // will NOT throw, allows any value
-    void write(std::string&) const override;
-    std::string dump() const override;
-    bool isString() const override { return true; }
-    int indexNum() const { return static_cast<int>(theStrings_.size()); }
-
-    /// Simulator functions:
-    bool isInfinite() const override { return false; }
-
-private:
-    RepeatString(const std::string& variable, const std::vector<std::string>& theEnums, int index)
-        : RepeatBase(variable),
-          currentIndex_(index),
-          theStrings_(theEnums) {}
-
-private:
-    int currentIndex_{0};
-    std::vector<std::string> theStrings_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-/// The current repeat day is not that well defined or deterministic.
-///  **** Currently I have not come across any suites that use an end-date ****
-///   o If the suite has defined a real clock
-///     then number of repeats is deterministic
-///     However if the end-date is less than suite clock this should be reported as error
-///   o Currently under the hybrid clock the date is not updated, this raises
-///     a whole lot of issues. (We don't wont a separate calendar, just for this).
-///   o If there is _no_ suite clock, then we must use the current day
-///     now the number of repeats  varies, and if end-date is less than the current
-///     day we need to report an error
-///  Its not clear what behaviour is required here, hence I will not implement
-///  the end-date functionality. Until there is clear requirement is this area.
-///  end-date will be treated as a parser error.
-///  The minimum deterministic functionality here is to implement the infinite
-///  repeat that has no end date
-///
-/// RepeatDay do not really have a name: However we need maintain invariant that all NON-empty repeats
-/// have a name. Hence the name will be as day
-/// Note: this applies to the clone as well
-class RepeatDay final : public RepeatBase {
-public:
-    RepeatDay() : RepeatBase("day") {}
-
-    // Enable implicit conversion from integer
-    RepeatDay(int step) : RepeatBase("day"), step_(step) {}
-
-    bool operator==(const RepeatDay& rhs) const;
-    bool operator<(const RepeatDay& rhs) const { return step_ < rhs.step(); }
-
-    int start() const override { return 0; }
-    int end() const override { return 0; }
-    int step() const override { return step_; }
-    void increment() override { /* do nothing */
-    }
-    long value() const override { return step_; }
-    long index_or_value() const override { return step_; }
-    long last_valid_value() const override { return step_; }
-
-    RepeatBase* clone() const override { return new RepeatDay(step_, valid_); }
-    bool compare(RepeatBase*) const override;
-    bool valid() const override { return valid_; }
-    std::string valueAsString() const override { return std::string(); };
-    std::string value_as_string(int) const override { return std::string(); }
-    std::string next_value_as_string() const override { return std::string(); }
-    std::string prev_value_as_string() const override { return std::string(); }
-
-    void setToLastValue() override { /* do nothing  ?? */
-    }
-    void reset() override { valid_ = true; }
-    void change(const std::string& /*newValue*/) override { /* do nothing */
-    }
-    void changeValue(long /*newValue*/) override { /* do nothing */
-    }
-    void set_value(long /*newValue*/) override { /* do nothing */
-    }
-    void write(std::string&) const override;
-    std::string dump() const override;
-    bool isDay() const override { return true; }
-
-    /// Simulator functions:
-    bool isInfinite() const override { return true; }
-
-    bool is_repeat_day() const override { return true; }
-
-private:
-    RepeatDay(int step, bool valid) : RepeatBase("day"), step_(step), valid_(valid) {}
-
-private:
-    int step_{1};
-    bool valid_{true}; // not persisted since only used in simulator
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class Repeat {
-public:
-    Repeat(); // for serialisation
-
-    // Enable implicit conversion to Repeat
-    Repeat(const RepeatDate&);
-    Repeat(const RepeatDateTime&);
-    Repeat(const RepeatDateList&);
-    Repeat(const RepeatInteger&);
-    Repeat(const RepeatEnumerated&);
-    Repeat(const RepeatString&);
-    Repeat(const RepeatDay&);
-
-    // Enable copy semantics
-    Repeat(const Repeat&);
-    Repeat& operator=(const Repeat& rhs);
-
-    // Enable move semantics
-    Repeat(Repeat&& rhs) : type_(std::move(rhs.type_)) {}
-    Repeat& operator=(Repeat&& rhs);
-
-    ~Repeat();
-
-    bool operator==(const Repeat& rhs) const;
-    bool operator<(const Repeat& rhs) const { return name() < rhs.name(); }
-
-    bool empty() const { return (type_) ? false : true; }
-    void clear() { type_.reset(nullptr); }
-
-    const std::string& name() const;
-
-    void gen_variables(std::vector<Variable>& vec) const {
-        if (type_)
-            type_->gen_variables(vec);
-    }
-    const Variable& find_gen_variable(const std::string& name) const {
-        return (type_) ? type_->find_gen_variable(name) : Variable::EMPTY();
-    }
-    void update_repeat_genvar() const {
-        if (type_)
-            type_->update_repeat_genvar();
-    }
-
-    int start() const { return (type_) ? type_->start() : 0; }
-    int end() const { return (type_) ? type_->end() : 0; }
-    int step() const { return (type_) ? type_->step() : 0; }
-    long value() const { return (type_) ? type_->value() : 0; }
-    long index_or_value() const { return (type_) ? type_->index_or_value() : 0; }
-    long last_valid_value() const { return (type_) ? type_->last_valid_value() : 0; }
-    long last_valid_value_minus(int val) const { return (type_) ? type_->last_valid_value_minus(val) : -val; }
-    long last_valid_value_plus(int val) const { return (type_) ? type_->last_valid_value_plus(val) : val; }
-
-    void print(std::string& os) const;
-    bool valid() const { return (type_) ? type_->valid() : false; }
-    void setToLastValue() {
-        if (type_)
-            type_->setToLastValue();
-    }
-    std::string valueAsString() const { return (type_) ? type_->valueAsString() : std::string(); }
-    std::string value_as_string(int index) const { return (type_) ? type_->value_as_string(index) : std::string(); }
-    std::string next_value_as_string() const { return (type_) ? type_->next_value_as_string() : std::string(); }
-    std::string prev_value_as_string() const { return (type_) ? type_->prev_value_as_string() : std::string(); }
-
-    void reset() {
-        if (type_)
-            type_->reset();
-    }
-    void increment() {
-        if (type_)
-            type_->increment();
-    }
-    void change(const std::string& newValue) {
-        if (type_)
-            type_->change(newValue);
-    }
-    void changeValue(long newValue) {
-        if (type_)
-            type_->changeValue(newValue);
-    }
-    void set_value(long newValue) {
-        if (type_)
-            type_->set_value(newValue);
-    }
-    std::string toString() const { return (type_) ? type_->toString() : std::string(); }
-    std::string dump() const { return (type_) ? type_->dump() : std::string(); } // additional state
-    unsigned int state_change_no() const { return (type_) ? type_->state_change_no() : 0; }
-
-    /// simulator functions:
-    bool isInfinite() const { return (type_) ? type_->isInfinite() : false; }
-
-    // Allows Repeat's to be returned by reference
-    static const Repeat& EMPTY();
-
-    bool is_repeat_day() const { return (type_) ? type_->is_repeat_day() : false; }
-
-    /// Expose base for the GUI only, use with caution
-    RepeatBase* repeatBase() const { return type_.get(); }
-
-private:
-    void write(std::string& ret) const {
-        if (type_)
-            type_->write(ret);
-    }
-
-private:
-    std::unique_ptr<RepeatBase> type_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_attribute_RepeatAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/TimeAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/TimeAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/TimeAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/TimeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,253 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/TimeAttr.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/attribute/DateAttr.hpp" // Used in Why
-#include "ecflow/attribute/DayAttr.hpp"  // Used in Why
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-namespace ecf {
-
-TimeAttr::TimeAttr(const std::string& str) : state_change_no_(0) {
-    if (str.empty())
-        throw std::runtime_error("Time::Time: empty string passed");
-    std::vector<std::string> tokens;
-    Str::split(str, tokens);
-    if (tokens.empty())
-        throw std::runtime_error("Time::Time: incorrect time string ?");
-
-    size_t index = 0;
-    ts_          = TimeSeries::create(index, tokens, false /*parse_state*/);
-}
-
-void TimeAttr::calendarChanged(const ecf::Calendar& c) {
-    // ensure this called first , since we need always update for relative duration. ECFLOW-1648
-    if (ts_.calendarChanged(c)) {
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-    //   log(Log::DBG,"TimeAttr::calendarChanged(1) " + dump()); // ECFLOW-1648
-
-    if (free_) {
-        return;
-    }
-
-    // For a time series, we rely on the re queue to reset makeFree
-    if (isFree(c)) {
-        setFree();
-    }
-    //   log(Log::DBG,"TimeAttr::calendarChanged(2) " + dump()); // ECFLOW-1648
-}
-
-void TimeAttr::resetRelativeDuration() {
-    if (ts_.resetRelativeDuration()) {
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-}
-
-void TimeAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        ts_.write_state(os, free_);
-    }
-    os += "\n";
-}
-
-std::string TimeAttr::name() const {
-    std::string ret;
-    write(ret);
-    ts_.write_state_for_gui(ret, free_);
-    return ret;
-}
-
-std::string TimeAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void TimeAttr::write(std::string& ret) const {
-    ret += "time ";
-    ts_.write(ret);
-}
-
-std::string TimeAttr::dump() const {
-    std::stringstream ss;
-    ss << "time ";
-
-    if (free_)
-        ss << "(free) ";
-    else
-        ss << "(holding) ";
-
-    ss << ts_.dump();
-
-    return ss.str();
-}
-
-bool TimeAttr::operator==(const TimeAttr& rhs) const {
-    if (free_ != rhs.free_) {
-        return false;
-    }
-    return ts_.operator==(rhs.ts_);
-}
-
-bool TimeAttr::structureEquals(const TimeAttr& rhs) const {
-    return ts_.structureEquals(rhs.ts_);
-}
-
-bool TimeAttr::isFree(const ecf::Calendar& calendar) const {
-    // The FreeDepCmd can be used to free the time,
-    if (free_) {
-        return true;
-    }
-    return is_free(calendar);
-}
-
-bool TimeAttr::is_free(const ecf::Calendar& calendar) const {
-    return ts_.isFree(calendar);
-}
-
-void TimeAttr::setFree() {
-    free_            = true;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "TimeAttr::setFree()\n";
-#endif
-}
-
-void TimeAttr::clearFree() {
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "TimeAttr::clearFree()\n";
-#endif
-}
-
-void TimeAttr::miss_next_time_slot() {
-    ts_.miss_next_time_slot();
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-bool TimeAttr::why(const ecf::Calendar& c,
-                   const std::vector<DayAttr>& days,
-                   const std::vector<DateAttr>& dates,
-                   std::string& theReasonWhy) const {
-    if (isFree(c))
-        return false;
-    theReasonWhy += "is time ";
-    if (!days.empty())
-        theReasonWhy += "and day ";
-    if (!dates.empty())
-        theReasonWhy += "and date ";
-    theReasonWhy += "dependent";
-
-    // Check to see if time has expired, if has not, then report why
-    if (ts_.is_valid()) {
-        // This can apply to single and series
-        boost::posix_time::time_duration calendar_time = ts_.duration(c);
-        if (calendar_time < ts_.start().duration()) {
-            ts_.why(c, theReasonWhy);
-            return true;
-        }
-
-        // calendar_time >= ts_.start().duration()
-        if (ts_.hasIncrement()) {
-            if (calendar_time < ts_.finish().duration()) {
-                ts_.why(c, theReasonWhy);
-                return true;
-            }
-        }
-        // calendar_time >= ts_.start().duration() && calendar_time >= ts_.finish().duration()
-        // past the end of time slot, hence this should not hold job generation,
-    }
-
-    // the time has expired
-    theReasonWhy += " ( '";
-    theReasonWhy += toString();
-    theReasonWhy += "' has expired,";
-
-    // take into account, user can use run/force complete to miss time slots
-    bool do_a_requeue = ts_.requeueable(c);
-    if (do_a_requeue) {
-        TimeSlot the_next_time_slot = ts_.compute_next_time_slot(c);
-        if (the_next_time_slot.isNULL() || !ts_.hasIncrement()) {
-            theReasonWhy += " *re-queue* to run at this time";
-        }
-        else {
-            theReasonWhy += " *re-queue* to run at ";
-            theReasonWhy += the_next_time_slot.toString();
-        }
-    }
-    else {
-        if (ts_.relative()) {
-            theReasonWhy += " please *re-queue*, to reset the relative duration";
-        }
-        else {
-            boost::gregorian::date the_min_next_date;
-
-            if (!days.empty() || !dates.empty()) {
-                for (const auto& day : days) {
-                    boost::gregorian::date the_next_matching_date = day.next_matching_date(c);
-                    if (the_min_next_date.is_special())
-                        the_min_next_date = the_next_matching_date;
-                    if (the_next_matching_date < the_min_next_date)
-                        the_min_next_date = the_next_matching_date;
-                }
-                for (const auto& date : dates) {
-                    boost::gregorian::date the_next_matching_date = date.next_matching_date(c);
-                    if (the_min_next_date.is_special())
-                        the_min_next_date = the_next_matching_date;
-                    if (the_next_matching_date < the_min_next_date)
-                        the_min_next_date = the_next_matching_date;
-                }
-
-                theReasonWhy += " next run at ";
-            }
-            else {
-                boost::gregorian::date_duration one_day(1);
-                the_min_next_date = c.date(); // todays date
-                the_min_next_date += one_day; // add one day, so its in the future
-                theReasonWhy += " next run tomorrow at ";
-            }
-
-            theReasonWhy += ts_.start().toString();
-            theReasonWhy += " ";
-            theReasonWhy += to_simple_string(the_min_next_date);
-        }
-    }
-    theReasonWhy += " )";
-
-    return true;
-}
-
-template <class Archive>
-void TimeAttr::serialize(Archive& ar) {
-    ar(CEREAL_NVP(ts_));
-
-    // Only persisted for testing, see usage of isSetFree()
-    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE(TimeAttr);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/TimeAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/TimeAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/TimeAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/TimeAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,142 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_TimeAttr_HPP
-#define ecflow_attribute_TimeAttr_HPP
-
-///
-/// \brief isFree is called when a node is queued. If it returns true, Task can be submitted
-/// checkForReque: is called when a node has completed, and need to determine if it should run again.
-/// These are different/orthogonal concerns.
-/// There is a *separate* issue of whether nodes should be queued when a node is *manually*
-///    a/ Set complete
-///    b/ Runs and then completes
-///
-/// For a *single* time slot we can't requeue.
-/// Hence we checkForReque that takes as parameters max/min time slots, so we **treat**
-/// Multiple single slot as a series.
-///
-///                                               isFree:hhhhhhhhhhhhhhhhh
-///                                               Begin:
-///                                               V
-/// checkForReque:rrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh   10:00
-/// checkForReque:rrrrrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhh   11:00
-/// checkForReque:rrrrrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhh   for both 10:00 and 11:000 together
-///       isFree:hhhhhhhhhhhhhhhhffffffffffffffffffffffffffffffffffff   *once* free we stay free (single slot *only*)
-///       begin :                |                           |
-///        V                     |                           |
-/// Time   ======================0============0==============0=============
-///                            10:00        11:00              Midnight
-///
-///                                                     isFree:hhhhhhhhhhhhhhhhhh
-///                                                      V
-///   CheckForReque:rrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
-///          isFree:hhhhhhhFhhhhFhhhhFhhhhFhhhhFhhhhFhhhhhhhhhhhhhhhhhhhhhhhhhhhh
-///            V           |    |    |    |    |    |        |
-/// Time   ================o====|====|====|====|====0========0====================
-///                      10:00  1    2    3    4  15:00    Midnight
-///
-/// If the job starts at 10:00 but takes more than 1 hour, then it will miss the 11:00 slot
-/// and will have to start at 12:00
-///
-
-#include "ecflow/core/TimeSeries.hpp"
-
-class DateAttr; // Used in Why
-class DayAttr;  // Used in Why
-
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-namespace ecf {
-
-// Use compiler ,  destructor, assignment, copy constructor,
-class TimeAttr {
-public:
-    explicit TimeAttr(const std::string&);
-    TimeAttr() = default;
-    TimeAttr(int hour, int minute, bool relative = false) : ts_(hour, minute, relative) {}
-    explicit TimeAttr(const TimeSlot& t, bool relative = false) : ts_(t, relative) {}
-    explicit TimeAttr(const TimeSeries& ts) : ts_(ts) {}
-    TimeAttr(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative = false)
-        : ts_(start, finish, incr, relative) {}
-
-    void print(std::string&) const;
-    bool operator==(const TimeAttr& rhs) const;
-    bool operator<(const TimeAttr& rhs) const { return ts_ < rhs.ts_; }
-    bool structureEquals(const TimeAttr& rhs) const;
-
-    /// This can set attribute as free, once free its stays free, until re-queue/reset
-    void calendarChanged(const ecf::Calendar& c); // can set attribute free
-    void resetRelativeDuration();
-
-    void reset_only() {
-        clearFree();
-        ts_.reset_only();
-    }
-    void reset(const ecf::Calendar& c) {
-        clearFree();
-        ts_.reset(c);
-    } // updates state_change_no_
-    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true) {
-        clearFree();
-        ts_.requeue(c, reset_next_time_slot);
-    } // updates state_change_no_
-
-    void miss_next_time_slot(); // updates state_change_no_
-    void setFree();             // ensures that isFree() always returns true, updates state_change_no_
-    bool isSetFree() const { return free_; }
-    bool isFree(const ecf::Calendar&) const;
-    bool checkForRequeue(const ecf::Calendar& c,
-                         const TimeSlot& the_min,
-                         const TimeSlot& the_max,
-                         bool cmd_context = false) const {
-        return ts_.checkForRequeue(c, the_min, the_max, cmd_context);
-    }
-    void min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const { ts_.min_max_time_slots(the_min, the_max); }
-    bool why(const ecf::Calendar&,
-             const std::vector<DayAttr>&,
-             const std::vector<DateAttr>&,
-             std::string& theReasonWhy) const;
-
-    bool checkInvariants(std::string& errormsg) const { return ts_.checkInvariants(errormsg); }
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    // Note: changes in state of ts_, i.e affect the equality operator (used in test)
-    //       must be captured. i.e things like relative duration & next_time_slot are
-    //       reported by the Why command, & hence need to be synced.
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    std::string name() const; // for display/gui
-    std::string toString() const;
-    void write(std::string&) const;
-    std::string dump() const;
-
-    // access
-    const TimeSeries& time_series() const { return ts_; }
-
-private:
-    void clearFree();                         // resets the free flag, updates state_change_no_
-    bool is_free(const ecf::Calendar&) const; // ignores free_
-
-private:
-    TimeSeries ts_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool free_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_attribute_TimeAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/TodayAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/TodayAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/TodayAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/TodayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,252 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/TodayAttr.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/attribute/DateAttr.hpp" // Used in Why
-#include "ecflow/attribute/DayAttr.hpp"  // Used in Why
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-TodayAttr::TodayAttr(const std::string& str) {
-    if (str.empty())
-        throw std::runtime_error("Today::Today: empty string passed");
-    std::vector<std::string> tokens;
-    Str::split(str, tokens);
-    if (tokens.empty())
-        throw std::runtime_error("Today::Today: incorrect time string ?");
-
-    size_t index = 0;
-    ts_          = TimeSeries::create(index, tokens, false /*parse_state*/);
-}
-
-void TodayAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        ts_.write_state(os, free_);
-    }
-    os += "\n";
-}
-
-std::string TodayAttr::name() const {
-    std::string ret;
-    write(ret);
-    ts_.write_state_for_gui(ret, free_);
-    return ret;
-}
-
-std::string TodayAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void TodayAttr::write(std::string& ret) const {
-    ret += "today ";
-    ts_.write(ret);
-}
-
-std::string TodayAttr::dump() const {
-    std::stringstream ss;
-    ss << "today ";
-
-    if (PrintStyle::getStyle() == PrintStyle::STATE) {
-        if (free_)
-            ss << "(free) ";
-        else
-            ss << "(holding) ";
-    }
-
-    ss << ts_.dump();
-
-    return ss.str();
-}
-
-bool TodayAttr::operator==(const TodayAttr& rhs) const {
-    if (free_ != rhs.free_) {
-        return false;
-    }
-    return ts_.operator==(rhs.ts_);
-}
-
-bool TodayAttr::structureEquals(const TodayAttr& rhs) const {
-    return ts_.structureEquals(rhs.ts_);
-}
-
-void TodayAttr::miss_next_time_slot() {
-    ts_.miss_next_time_slot();
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void TodayAttr::setFree() {
-    free_            = true;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void TodayAttr::clearFree() {
-    free_            = false;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void TodayAttr::calendarChanged(const ecf::Calendar& c) {
-    // ensure this called first , since we need always update for relative duration ECFLOW-1648
-    if (ts_.calendarChanged(c)) {
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-
-    if (free_) {
-        return;
-    }
-
-    // For a time series, we rely on the re queue to reset makeFree
-    if (isFree(c)) {
-        setFree();
-    }
-}
-
-void TodayAttr::resetRelativeDuration() {
-    if (ts_.resetRelativeDuration()) {
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-}
-
-bool TodayAttr::isFree(const ecf::Calendar& calendar) const {
-    // The FreeDepCmd can be used to free the today,
-    if (free_) {
-        return true;
-    }
-    return is_free(calendar);
-}
-
-bool TodayAttr::is_free(const ecf::Calendar& calendar) const {
-    if (!ts_.hasIncrement()) {
-        if (ts_.duration(calendar) > ts_.start().duration()) {
-            return true;
-        }
-    }
-
-    // For time series(/range), this  is already handle by ts_
-    // If timer expired return false. otherwise must match one time slot in the range/series
-    return ts_.isFree(calendar);
-}
-
-bool TodayAttr::why(const ecf::Calendar& c,
-                    const std::vector<DayAttr>& days,
-                    const std::vector<DateAttr>& dates,
-                    std::string& theReasonWhy) const {
-    if (isFree(c))
-        return false;
-    theReasonWhy += "is today ";
-    if (!days.empty())
-        theReasonWhy += "and day ";
-    if (!dates.empty())
-        theReasonWhy += "and date ";
-    theReasonWhy += "dependent";
-
-    // Check to see if time has expired, if has not, then report why
-    if (ts_.is_valid()) {
-        // This can apply to single and series
-        boost::posix_time::time_duration calendar_time = ts_.duration(c);
-        if (calendar_time < ts_.start().duration()) {
-            ts_.why(c, theReasonWhy);
-            return true;
-        }
-
-        // calendar_time >= ts_.start().duration()
-        if (ts_.hasIncrement()) {
-            if (calendar_time < ts_.finish().duration()) {
-                ts_.why(c, theReasonWhy);
-                return true;
-            }
-        }
-        // calendar_time >= ts_.start().duration() && calendar_time >= ts_.finish().duration()
-        // past the end of time slot, hence this should not hold job generation,
-    }
-
-    // the today has expired,
-    theReasonWhy += " ( '";
-    theReasonWhy += toString();
-    theReasonWhy += "' has expired,";
-
-    // take into account, user can use run/force complete to miss time slots
-    bool do_a_requeue = ts_.requeueable(c);
-    if (do_a_requeue) {
-        TimeSlot the_next_time_slot = ts_.compute_next_time_slot(c);
-        if (the_next_time_slot.isNULL() || !ts_.hasIncrement()) {
-            theReasonWhy += " *re-queue* to run at this time";
-        }
-        else {
-            theReasonWhy += " *re-queue* to run at";
-            theReasonWhy += the_next_time_slot.toString();
-        }
-    }
-    else {
-        if (ts_.relative()) {
-            theReasonWhy += " please *re-queue*, to reset the relative duration";
-        }
-        else {
-            boost::gregorian::date the_min_next_date;
-
-            if (!days.empty() || !dates.empty()) {
-                for (auto day : days) {
-                    boost::gregorian::date the_next_matching_date = day.next_matching_date(c);
-                    if (the_min_next_date.is_special())
-                        the_min_next_date = the_next_matching_date;
-                    if (the_next_matching_date < the_min_next_date)
-                        the_min_next_date = the_next_matching_date;
-                }
-                for (const auto& i : dates) {
-                    boost::gregorian::date the_next_matching_date = i.next_matching_date(c);
-                    if (the_min_next_date.is_special())
-                        the_min_next_date = the_next_matching_date;
-                    if (the_next_matching_date < the_min_next_date)
-                        the_min_next_date = the_next_matching_date;
-                }
-
-                theReasonWhy += " next run at ";
-            }
-            else {
-                boost::gregorian::date_duration one_day(1);
-                the_min_next_date = c.date(); // todays date
-                the_min_next_date += one_day; // add one day, so its in the future
-                theReasonWhy += " next run tomorrow at ";
-            }
-
-            theReasonWhy += ts_.start().toString();
-            theReasonWhy += " ";
-            theReasonWhy += to_simple_string(the_min_next_date);
-        }
-    }
-    theReasonWhy += " )";
-
-    return true;
-}
-
-template <class Archive>
-void TodayAttr::serialize(Archive& ar) {
-    ar(CEREAL_NVP(ts_));
-    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE(TodayAttr);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/TodayAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/TodayAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/TodayAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/TodayAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,192 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_TodayAttr_HPP
-#define ecflow_attribute_TodayAttr_HPP
-
-///
-/// \brief The Today attribute is heavily tied to the begin command
-///
-/// Real Clock:
-///   1/ Suite Begin time > Today time
-///      If the suite 'begin' time is past the time given for today
-///      the node is free to run.
-///   2/ Suite Begin time < Today Time
-///      The node will 'hold' until current time > today time
-///   3/ Suite time, has passed midnight(next day)
-///      then today command will permanently hold the node
-///   4/ Under Real/hybrid clocks today will hold node after
-///      current is past last today time.
-///
-/// Take the following example when we have a single time slot:
-///     today 10:00
-///                                                isFree:-----free-----
-///                                                 begin:
-///                                                 V
-/// checkForReque:rrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
-///         isFree:hhhhhhhhhhhhhhhh|fffffffffffffffffffffffffffffffffffffff  *once* free we stay free (single slot
-///         *only*) begin:
-///          V
-///   Today  ======================0=====================0=================
-///                               10:00              Midnight
-///
-///   Difference between time and today. If begin is started after the time slot
-///   then the node is free to re-run
-///
-/// When we have a today time series:
-///     today 10:00 20:00 01:00
-///
-///  *** If the begin time is past 10:00  in the case above then the
-///  *** node should is free to run once. However for a range its different
-///  *** if suite begin time is past 20:00 then the node is held.
-///
-///  At 10am the Node is free, when node completes, it is re-queued
-///  At 11am the Node is free, when node completes, it is re-queued
-///  ....
-///  At 20pm the Node is free, when node completes, it is *NOT* re-queued.
-///
-/// isFree is called when a node is queued. if it returns true, Task can be submitted
-/// checkForReque: is called when a node has completed, and need to determine if it should run again.
-/// These are different/orthogonal concerns.
-/// There is a *separate* issue of whether nodes should be queued when a node is *manually*
-///    a/ Set complete
-///    b/ Runs and then completes
-///
-/// For a *single* time slot we can't requeue.
-/// ****However we could have a set of time slots *****
-///
-///                                               isFree:ffffffffffffffff
-///                                               Begin:
-///                                               V
-/// checkForReque:hhhhhhhhhhhhhhhhhrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
-///       isFree:hhhhhhhhhhhhhhhh|fffffffffffffffffffffffffffffffffffffff
-///       begin :
-///        V
-/// Today  ======================0========0===========0====================
-///                            10:00    11:00      Midnight
-///                                                     isFree:hhhhhhhhhhhhhhhhhh
-///                                                      V
-///   CheckForReque:hhhhhhhrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
-///          isFree:hhhhhhhFhhhhFhhhhFhhhhFhhhhFhhhhFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
-///            V           |    |    |    |    |    |        |
-/// Today  ================o====|====|====|====|====0========0====================
-///                      10:00  1    2    3    4  15:00    Midnight
-///
-/// If the job starts at 10:00 but takes more than 1 hour, then it will miss the 11:00 slot
-/// and will have to start at 12:00
-///
-
-#include "ecflow/core/TimeSeries.hpp"
-
-class DateAttr; // Used in Why
-class DayAttr;  // Used in Why
-namespace ecf {
-class Calendar;
-} // namespace ecf
-
-namespace ecf {
-
-// Use compiler ,  destructor, assignment, copy constructor
-class TodayAttr {
-public:
-    explicit TodayAttr(const std::string&);
-    TodayAttr() = default;
-    TodayAttr(int hour, int minute, bool relative = false) : ts_(hour, minute, relative) {}
-    explicit TodayAttr(const TimeSlot& t, bool relative = false) : ts_(t, relative) {}
-    explicit TodayAttr(const TimeSeries& ts) : ts_(ts) {}
-    TodayAttr(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative = false)
-        : ts_(start, finish, incr, relative) {}
-
-    void print(std::string&) const;
-    bool operator==(const TodayAttr& rhs) const;
-    bool operator<(const TodayAttr& rhs) const { return ts_ < rhs.ts_; }
-    bool structureEquals(const TodayAttr& rhs) const;
-
-    /// This can set attribute as free, once free its stays free, until re-queue/reset
-    void calendarChanged(const ecf::Calendar& c);
-    void resetRelativeDuration();
-
-    void reset_only() {
-        clearFree();
-        ts_.reset_only();
-    }
-    void reset(const ecf::Calendar& c) {
-        clearFree();
-        ts_.reset(c);
-    } // updates state_change_no_
-    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true) {
-        clearFree();
-        ts_.requeue(c, reset_next_time_slot);
-    } // updates state_change_no_
-
-    void miss_next_time_slot(); // updates state_change_no_
-    void setFree();             // ensures that isFree() always returns true, updates state_change_no_
-    bool isSetFree() const { return free_; }
-
-    // This is used when we have a *single* today attribute
-    //  single-slot   is free, if calendar time >= today_time
-    //  (range)       is free, if calendar time == (one of the time ranges)
-    bool isFree(const ecf::Calendar&) const;
-
-    // This is used when we have a *multiple* today attribute
-    // (single | range) is free, if calendar time == (one of the time ranges)
-    // if timer *expired* returns false
-    //     task t1
-    //        today 09:00
-    //        today 10:00
-    // If current times is 11:00, then we will return false.
-    // since both 09:00 and 10:00 have expired
-    // Multiple single today, should behave like a today with a range.
-    bool isFreeMultipleContext(const ecf::Calendar& c) const { return ts_.isFree(c); }
-
-    bool checkForRequeue(const ecf::Calendar& c,
-                         const TimeSlot& the_min,
-                         const TimeSlot& the_max,
-                         bool cmd_context = false) const {
-        return ts_.checkForRequeue(c, the_min, the_max, cmd_context);
-    }
-    void min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const { ts_.min_max_time_slots(the_min, the_max); }
-    bool why(const ecf::Calendar&,
-             const std::vector<DayAttr>&,
-             const std::vector<DateAttr>&,
-             std::string& theReasonWhy) const;
-    bool checkInvariants(std::string& errormsg) const { return ts_.checkInvariants(errormsg); }
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    // Note: changes in state of ts_, i.e affect the equality operator (used in test)
-    //       must be captured. i.e things like relative duration & next_time_slot are
-    //       reported by the Why command, & hence need to be synced.
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    std::string name() const; // for display/GUI
-    std::string toString() const;
-    void write(std::string&) const;
-    std::string dump() const;
-
-    // access
-    const TimeSeries& time_series() const { return ts_; }
-
-private:
-    void clearFree();                         // resets the free flag, updates state_change_no_
-    bool is_free(const ecf::Calendar&) const; // ignores free_
-
-private:
-    TimeSeries ts_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool free_{false};                // persisted for use by why() on client side && for state changes
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_attribute_TodayAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/Variable.cpp 5.13.0-1/ANattr/src/ecflow/attribute/Variable.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/Variable.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/Variable.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,138 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/Variable.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// init static's
-const Variable& Variable::EMPTY() {
-    static const Variable VARIABLE = Variable();
-    return VARIABLE;
-}
-
-////////////////////////////////////////////////////////////////////////////////////////////
-
-Variable::Variable(const std::string& name, const std::string& value) : n_(name), v_(value) {
-    std::string msg;
-    if (!Str::valid_name(name, msg)) {
-        throw std::runtime_error("Variable::Variable: Invalid Variable name: " + msg);
-    }
-}
-
-void Variable::set_name(const std::string& v) {
-    std::string msg;
-    if (!Str::valid_name(v, msg)) {
-        throw std::runtime_error("Variable::set_name: Invalid Variable name: " + msg);
-    }
-    n_ = v;
-}
-
-int Variable::value() const {
-    // see if the value is convertible to a integer
-    return Str::to_int(v_, 0 /* value to return if conversion fails*/);
-}
-
-bool Variable::operator==(const Variable& rhs) const {
-    if (v_ != rhs.v_)
-        return false;
-    if (n_ != rhs.n_)
-        return false;
-    return true;
-}
-
-void Variable::print(std::string& os) const {
-    // see notes in VariableParser.h
-    //               Hence we do the following:
-    //                  a/ On parsing always remove quotes ie single or double
-    //                  b/ On serialising always add single quotes
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += "\n";
-}
-
-void Variable::print_server_variable(std::string& os) const {
-    // see notes in VariableParser.h
-    //               Hence we do the following:
-    //                  a/ On parsing always remove quotes ie single or double
-    //                  b/ On serialising always add single quotes
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += " # server\n";
-}
-
-void Variable::print_generated(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    os += "# ";
-    write(os);
-    os += "\n";
-}
-
-std::string Variable::toString() const {
-    std::string ret;
-    ret.reserve(n_.size() + v_.size() + 8);
-    write(ret);
-    return ret;
-}
-
-void Variable::write(std::string& ret) const {
-    ret += "edit ";
-    ret += n_;
-    ret += " '";
-    if (v_.find("\n") == std::string::npos)
-        ret += v_;
-    else {
-        // replace \n, otherwise re-parse will fail
-        std::string value = v_;
-        Str::replaceall(value, "\n", "\\n");
-        ret += value;
-    }
-    ret += "'";
-}
-
-std::string Variable::dump() const {
-    std::stringstream ss;
-    ss << toString() << " value(" << value() << ")";
-    return ss.str();
-}
-
-template <class Archive>
-void Variable::serialize(Archive& ar) {
-    ar(CEREAL_NVP(n_), CEREAL_NVP(v_));
-}
-CEREAL_TEMPLATE_SPECIALIZE(Variable);
-
-/*
- * VariableMap
- * *********** */
-
-void VariableMap::set_value(const std::string& value) {
-    for (auto& variable : variables_) {
-        variable.set_value(value);
-    }
-}
-
-Variable& VariableMap::operator[](const std::string& name) {
-    if (auto found = index_.find(name); found != std::end(index_)) {
-        return variables_[found->second];
-    }
-    throw std::runtime_error("Variable not found in Map");
-}
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/Variable.hpp 5.13.0-1/ANattr/src/ecflow/attribute/Variable.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/Variable.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/Variable.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_Variable_HPP
-#define ecflow_attribute_Variable_HPP
-
-#include <string>
-#include <vector>
-
-#include <unordered_map>
-
-namespace cereal {
-class access;
-}
-
-////////////////////////////////////////////////////////////////////////////////////////
-// Class Variable:
-// Use compiler , generated destructor, assignment,  copy constructor
-class Variable {
-public:
-    // This constructor added as an optimisation to avoid, checking variable names.
-    // i.e the generated variables, and created by the default constructors of Suite/Family/Task etc
-    // These are called during serialisation, hence to avoid checking generated names, we know are valid
-    // use this constructor. The bool is used as a dummy argument, so that we call the right constructor
-    Variable(const std::string& name, const std::string& value, bool /*check_names_dummy*/) : n_(name), v_(value) {}
-    Variable(const std::string& name, const std::string& value);
-    Variable() = default;
-
-    const std::string& name() const { return n_; }
-    void print(std::string&) const;
-    void print_server_variable(std::string&) const;
-    void print_generated(std::string&) const;
-    bool empty() const { return n_.empty(); }
-
-    void set_value(const std::string& v) { v_ = v; }
-    const std::string& theValue() const { return v_; }
-    int value() const;
-
-    void set_name(const std::string& v);
-    std::string& value_by_ref() { return v_; }
-
-    bool operator==(const Variable& rhs) const;
-    bool operator<(const Variable& rhs) const { return n_ < rhs.name(); }
-    std::string toString() const;
-    std::string dump() const;
-
-    // Added to support return by reference
-    static const Variable& EMPTY();
-
-private:
-    void write(std::string&) const;
-
-private:
-    std::string n_;
-    std::string v_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-class VariableMap {
-public:
-    using storage_t = std::vector<Variable>;
-    using index_t   = std::unordered_map<std::string, size_t>;
-
-    template <typename... VARIABLES>
-    explicit VariableMap(const VARIABLES... variables) : variables_{variables...} {
-        // Fill index
-        for (size_t i = 0; i < variables_.size(); ++i) {
-            index_.insert(std::make_pair(variables_[i].name(), i));
-        }
-    }
-
-    [[nodiscard]] storage_t::iterator begin() { return variables_.begin(); }
-    [[nodiscard]] storage_t::const_iterator begin() const { return variables_.begin(); }
-    [[nodiscard]] storage_t::iterator end() { return variables_.end(); }
-    [[nodiscard]] storage_t::const_iterator end() const { return variables_.end(); }
-
-    [[nodiscard]] bool empty() const { return variables_.empty(); }
-    [[nodiscard]] size_t size() const { return variables_.size(); }
-
-    void set_value(const std::string& value);
-
-    [[nodiscard]] Variable& operator[](const std::string& name);
-
-private:
-    storage_t variables_;
-    index_t index_;
-};
-
-#endif /* ecflow_attribute_Variable_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/VerifyAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/VerifyAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/VerifyAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/VerifyAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,79 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/VerifyAttr.hpp"
-
-#include <sstream>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace ecf;
-
-bool VerifyAttr::operator==(const VerifyAttr& rhs) const {
-    if (state_ != rhs.state_)
-        return false;
-    if (expected_ != rhs.expected_)
-        return false;
-    return true;
-}
-
-void VerifyAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    os += toString();
-    if (!PrintStyle::defsStyle()) {
-        os += " # ";
-        os += ecf::convert_to<std::string>(actual_);
-    }
-    os += "\n";
-}
-
-void VerifyAttr::incrementActual() {
-    actual_++;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "VerifyAttr::incrementActual()\n";
-#endif
-}
-
-void VerifyAttr::reset() {
-    actual_          = 0;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "VerifyAttr::reset()\n";
-#endif
-}
-
-std::string VerifyAttr::toString() const {
-    std::stringstream ss;
-    ss << "verify " << NState::toString(state_) << Str::COLON() << expected_;
-    return ss.str();
-}
-
-std::string VerifyAttr::dump() const {
-    std::stringstream ss;
-    ss << "verify " << NState::toString(state_) << Str::COLON() << expected_;
-    ss << " actual(" << actual_ << ")";
-    return ss.str();
-}
-
-template <class Archive>
-void VerifyAttr::serialize(Archive& ar) {
-    ar(CEREAL_NVP(state_), CEREAL_NVP(expected_), CEREAL_NVP(actual_));
-}
-CEREAL_TEMPLATE_SPECIALIZE(VerifyAttr);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/VerifyAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/VerifyAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/VerifyAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/VerifyAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_VerifyAttr_HPP
-#define ecflow_attribute_VerifyAttr_HPP
-
-#include "ecflow/core/NState.hpp"
-
-// Class VerifyAttr:
-// This class is only used for testing/verification purposes. It allows us to
-// embed expected number of states, within the definition file and so
-// reduce the need for golden log files.
-// Use compiler , generated destructor, assignment, copy constructor
-class VerifyAttr {
-public:
-    VerifyAttr(NState::State state, int expected, int actual = 0)
-        : state_(state),
-          expected_(expected),
-          actual_(actual),
-          state_change_no_(0) {}
-    VerifyAttr() = default;
-
-    bool operator==(const VerifyAttr& rhs) const;
-    void print(std::string&) const;
-
-    NState::State state() const { return state_; }
-    int expected() const { return expected_; }
-    int actual() const { return actual_; }
-    void incrementActual();
-    void reset();
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    std::string toString() const;
-    std::string dump() const;
-
-private:
-    NState::State state_{NState::UNKNOWN};
-    int expected_{0};
-    int actual_{0};
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_attribute_VerifyAttr_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/Zombie.cpp 5.13.0-1/ANattr/src/ecflow/attribute/Zombie.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/Zombie.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/Zombie.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,383 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/Zombie.hpp"
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// support return by reference
-const Zombie& Zombie::EMPTY() {
-    static const Zombie ZOMBIE = Zombie();
-    return ZOMBIE;
-}
-Zombie& Zombie::EMPTY_() {
-    static Zombie ZOMBIE = Zombie();
-    return ZOMBIE;
-}
-
-Zombie::Zombie(ecf::Child::ZombieType zombie_type,
-               ecf::Child::CmdType cmd,
-               const ZombieAttr& attr,
-               const std::string& pathToTask,
-               const std::string& jobsPassword,
-               const std::string& process_or_remote_id,
-               int try_no,
-               const std::string& host,
-               const std::string& user_cmd)
-    : try_no_(try_no),
-      zombie_type_(zombie_type),
-      last_child_cmd_(cmd),
-      path_to_task_(pathToTask),
-      jobs_password_(jobsPassword),
-      process_or_remote_id_(process_or_remote_id),
-      user_cmd_(user_cmd),
-      host_(host),
-      attr_(attr),
-      creation_time_(Calendar::second_clock_time()) {
-}
-
-Zombie::Zombie() = default;
-
-bool Zombie::operator==(const Zombie& rhs) const { // for python interface only
-    if (zombie_type_ != rhs.zombie_type_)
-        return false;
-    if (user_action_ != rhs.user_action_)
-        return false;
-    if (try_no_ != rhs.try_no_)
-        return false;
-    if (duration_ != rhs.duration_)
-        return false;
-    if (calls_ != rhs.calls_)
-        return false;
-    if (last_child_cmd_ != rhs.last_child_cmd_)
-        return false;
-    if (path_to_task_ != rhs.path_to_task_)
-        return false;
-    if (jobs_password_ != rhs.jobs_password_)
-        return false;
-    if (process_or_remote_id_ != rhs.process_or_remote_id_)
-        return false;
-    if (user_cmd_ != rhs.user_cmd_)
-        return false;
-    if (host_ != rhs.host_)
-        return false;
-    if (user_action_set_ != rhs.user_action_set_)
-        return false;
-    if (!(attr_ == rhs.attr_))
-        return false;
-    return true;
-}
-
-std::string Zombie::to_string() const { // for python interface only
-    std::vector<Zombie> vec;
-    vec.push_back(*this);
-    return Zombie::pretty_print(vec, 1);
-}
-
-std::string Zombie::type_str() const {
-    return Child::to_string(zombie_type_);
-}
-
-ecf::User::Action Zombie::user_action() const {
-    // User action needs to take into account, last child command and setting on attr_
-    if (fob())
-        return User::FOB;
-    else if (block())
-        return User::BLOCK;
-    else if (fail())
-        return User::FAIL;
-    else if (remove())
-        return User::REMOVE;
-    else if (kill())
-        return User::KILL;
-    else if (adopt())
-        return User::ADOPT;
-
-    return User::BLOCK; // the default action
-}
-
-std::string Zombie::user_action_str() const {
-    std::string ret;
-    if (manual_user_action())
-        ret = "manual-";
-    else
-        ret = "auto-";
-    ret += User::to_string(user_action());
-    return ret;
-}
-
-/// accessors
-bool Zombie::fob() const {
-    if (user_action_set_)
-        return user_action_ == User::FOB;
-    return attr_.fob(last_child_cmd_);
-}
-bool Zombie::fail() const {
-    if (user_action_set_)
-        return user_action_ == User::FAIL;
-    return attr_.fail(last_child_cmd_);
-}
-bool Zombie::adopt() const {
-    if (user_action_set_)
-        return user_action_ == User::ADOPT;
-    return attr_.adopt(last_child_cmd_);
-}
-bool Zombie::block() const {
-    if (user_action_set_)
-        return user_action_ == User::BLOCK;
-    return attr_.block(last_child_cmd_);
-}
-bool Zombie::remove() const {
-    if (user_action_set_)
-        return user_action_ == User::REMOVE;
-    return attr_.remove(last_child_cmd_);
-}
-bool Zombie::kill() const {
-    if (user_action_set_)
-        return user_action_ == User::KILL;
-    return attr_.kill(last_child_cmd_);
-}
-
-int Zombie::allowed_age() const {
-    return attr_.zombie_lifetime();
-}
-
-void Zombie::set_fob() {
-    user_action_     = User::FOB;
-    user_action_set_ = true;
-}
-void Zombie::set_fail() {
-    user_action_     = User::FAIL;
-    user_action_set_ = true;
-}
-void Zombie::set_adopt() {
-    user_action_     = User::ADOPT;
-    user_action_set_ = true;
-}
-void Zombie::set_block() {
-    user_action_     = User::BLOCK;
-    user_action_set_ = true;
-}
-void Zombie::set_kill() {
-    user_action_     = User::KILL;
-    user_action_set_ = true;
-}
-
-std::ostream& operator<<(std::ostream& os, const Zombie& z) {
-    os << z.path_to_task() << " ";
-    os << z.type_str() << " ";
-    os << z.duration() << " ";
-    os << z.jobs_password() << " ";
-    os << z.process_or_remote_id() << "<pid> ";
-    os << z.try_no() << " ";
-    os << "calls(" << z.calls() << ") ";
-    os << z.user_action_str();
-    os << " ";
-    os << Child::to_string(z.last_child_cmd());
-    return os;
-}
-
-std::string Zombie::explanation() const {
-    std::string ecf_pid_expl        = "PID miss-match, password matches. Job scheduled twice. Check submitter";
-    std::string ecf_pid_passwd_expl = "Both PID and password miss-match. Re-queue & submit of active job?";
-    std::string ecf_passwd_expl     = "Password miss-match, PID matches, system has re-cycled PID or hacked job file?";
-    std::string ecf_expl            = "Two init commands or task complete or aborted but receives another child cmd";
-    std::string ecf_user            = "Created by user action(";
-    std::string ecf_path            = "Task not found. Nodes replaced whilst jobs were running";
-    std::string exp;
-
-    switch (zombie_type_) {
-        case Child::USER:
-            exp = ecf_user;
-            exp += user_cmd_;
-            exp += ")";
-            break;
-        case Child::PATH:
-            exp = ecf_path;
-            break;
-        case Child::ECF:
-            exp = ecf_expl;
-            break;
-        case Child::ECF_PID:
-            exp = ecf_pid_expl;
-            break;
-        case Child::ECF_PID_PASSWD:
-            exp = ecf_pid_passwd_expl;
-            break;
-        case Child::ECF_PASSWD:
-            exp = ecf_passwd_expl;
-            break;
-        case Child::NOT_SET:
-            break;
-    }
-
-    return exp;
-}
-
-std::string Zombie::pretty_print(const std::vector<Zombie>& zombies, int indent) {
-    std::stringstream ss;
-    std::vector<std::string> list;
-    pretty_print(zombies, list, indent);
-    for (const auto& i : list) {
-        ss << i << "\n";
-    }
-    return ss.str();
-}
-
-void Zombie::pretty_print(const std::vector<Zombie>& zombies, std::vector<std::string>& list, int indent) {
-    string path("task-path");
-    string type("type");
-    string password("password");
-    string rid("pid");
-    string duration("age(s)");
-    string calls("calls");
-    string try_no("try_no");
-    string user_action("action");
-    string child_type("child");
-    string host("host");
-    string explanation("explanation");
-
-    size_t path_width        = path.size();
-    size_t type_width        = type.size();
-    size_t duration_width    = duration.size();
-    size_t password_width    = password.size();
-    size_t tryno_width       = try_no.size();
-    size_t rid_width         = rid.size();
-    size_t user_action_width = user_action.size(); // max of FOB,FAIL,ADOPT,BLOCK,REMOVE + (manual- | auto- )
-    size_t child_type_width  = child_type.size();
-    size_t calls_width       = calls.size();
-    size_t host_width        = host.size();
-    size_t explanation_width = explanation.size();
-
-    std::string ecf_pid_expl        = "PID miss-match, password matches. Job scheduled twice. Check submitter";
-    std::string ecf_pid_passwd_expl = "Both PID and password miss-match. Re-queue & submit of active job?";
-    std::string ecf_passwd_expl     = "Password miss-match, PID matches, system has re-cycled PID or hacked job file?";
-    std::string ecf_expl            = "Two init commands or task complete or aborted but receives another child cmd";
-    std::string ecf_user            = "Created by user action(";
-    std::string ecf_path            = "Task not found. Nodes replaced whilst jobs were running";
-    std::string exp;
-
-    for (const Zombie& z : zombies) {
-        path_width              = std::max(path_width, z.path_to_task().size());
-        type_width              = std::max(type_width, z.type_str().size());
-        password_width          = std::max(password_width, z.jobs_password().size());
-        rid_width               = std::max(rid_width, z.process_or_remote_id().size());
-        std::string no_of_calls = ecf::convert_to<std::string>(z.calls());
-        calls_width             = std::max(calls_width, no_of_calls.size());
-        host_width              = std::max(host_width, z.host().size());
-
-        std::string try_no_int = ecf::convert_to<std::string>(z.try_no());
-        tryno_width            = std::max(tryno_width, try_no_int.size());
-        child_type_width       = std::max(child_type_width, Child::to_string(z.last_child_cmd()).size());
-        user_action_width      = std::max(user_action_width, z.user_action_str().size());
-
-        switch (z.type()) {
-            case Child::USER:
-                exp = ecf_user;
-                exp += z.user_cmd();
-                exp += ")";
-                break;
-            case Child::PATH:
-                exp = ecf_path;
-                break;
-            case Child::ECF:
-                exp = ecf_expl;
-                break;
-            case Child::ECF_PID:
-                exp = ecf_pid_expl;
-                break;
-            case Child::ECF_PID_PASSWD:
-                exp = ecf_pid_passwd_expl;
-                break;
-            case Child::ECF_PASSWD:
-                exp = ecf_passwd_expl;
-                break;
-            case Child::NOT_SET:
-                break;
-        }
-        explanation_width = std::max(explanation_width, exp.size());
-    }
-
-    {
-        std::stringstream ss;
-        if (indent != 0)
-            for (int i = 0; i < indent; i++)
-                ss << " ";
-        ss << left << setw(path_width) << path << " " << setw(type_width) << type << " " << setw(duration_width)
-           << duration << " " << setw(password_width) << password << " " << setw(rid_width) << rid << " "
-           << setw(tryno_width) << try_no << " " << setw(user_action_width) << user_action << " "
-           << setw(child_type_width) << child_type << " " << setw(calls_width) << calls << " " << setw(host_width)
-           << host << " " << setw(explanation_width) << explanation;
-        list.push_back(ss.str());
-    }
-
-    for (const Zombie& z : zombies) {
-        std::stringstream ss;
-        if (indent != 0)
-            for (int i = 0; i < indent; i++)
-                ss << " ";
-
-        switch (z.type()) {
-            case Child::USER:
-                exp = ecf_user;
-                exp += z.user_cmd();
-                exp += ")";
-                break;
-            case Child::PATH:
-                exp = ecf_path;
-                break;
-            case Child::ECF:
-                exp = ecf_expl;
-                break;
-            case Child::ECF_PID:
-                exp = ecf_pid_expl;
-                break;
-            case Child::ECF_PID_PASSWD:
-                exp = ecf_pid_passwd_expl;
-                break;
-            case Child::ECF_PASSWD:
-                exp = ecf_passwd_expl;
-                break;
-            case Child::NOT_SET:
-                break;
-        }
-
-        ss << left << setw(path_width) << z.path_to_task() << " " << setw(type_width) << z.type_str() << " "
-           << setw(duration_width) << z.duration() << " " << setw(password_width) << z.jobs_password() << " "
-           << setw(rid_width) << z.process_or_remote_id() << " " << setw(tryno_width) << z.try_no() << " "
-           << setw(user_action_width) << z.user_action_str() << " " << setw(child_type_width)
-           << Child::to_string(z.last_child_cmd()) << " " << setw(calls_width) << z.calls() << " " << setw(host_width)
-           << z.host() << " " << setw(explanation_width) << exp;
-        list.push_back(ss.str());
-    }
-}
-
-template <class Archive>
-void Zombie::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(user_action_),
-       CEREAL_NVP(try_no_),
-       CEREAL_NVP(duration_),
-       CEREAL_NVP(calls_),
-       CEREAL_NVP(zombie_type_),
-       CEREAL_NVP(last_child_cmd_),
-       CEREAL_NVP(path_to_task_),
-       CEREAL_NVP(jobs_password_),
-       CEREAL_NVP(process_or_remote_id_),
-       CEREAL_NVP(user_cmd_),
-       CEREAL_NVP(host_),
-       CEREAL_NVP(attr_),
-       CEREAL_NVP(user_action_set_));
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(Zombie);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/Zombie.hpp 5.13.0-1/ANattr/src/ecflow/attribute/Zombie.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/Zombie.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/Zombie.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,157 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_Zombie_HPP
-#define ecflow_attribute_Zombie_HPP
-
-///
-/// \brief Holds the zombie structure
-///
-/// WE have 3 structures:
-///      Jobs(path,password,process_id)
-///      Complications ONLY init command provides process_id.
-///      Task(path,password,process_id)
-///      Zombie(path,password,process_id)
-/// Issues:
-///   At the extreme we can have *2* Jobs running at one go. Typically user commands
-///   that have a force parameter, will create 'user' zombies.
-///   ** the command can be invoked at any time, i.e we could invoke
-///   ** the user command, whilst the task is in SUBMITTED state
-///   ** This will go through and create user zombie. However at this stage we have *NO* process_id
-///   ** since the job has not started. Zombie(path,password)
-///   When the Task init command is called, we get given a process_id.
-///   ** HOWEVER ** need to determine if this is from the real child cmd or from the zombie
-///   ** We search zombie list, and compare zombies, by path and password
-///   ** if a match is found, we update the zombie id.
-///
-///   IMPORTANT:: Automated test:
-///               If a child command provides just path and password, this is *NOT*
-///               enough information to disambiguate a zombie from a real job.
-///               To work around this the job file has been updated to add ECF_RID=$$
-///
-///   IMPORTANT:: For command line interface we just have the task path.
-///               i,e we don't want to expose password, and user will not easily
-///               know the process or remote id. Hence we will make do with the
-///               task path. We just find the first zombie, and act up on it
-///
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/core/Child.hpp"
-
-/// Use default copy constructor ,assignment operator and destructor
-class Zombie {
-public:
-    Zombie(ecf::Child::ZombieType zombie_type,      // The kind of zombie
-           ecf::Child::CmdType child_cmd,           // The Child command, that lead to this zombie
-           const ZombieAttr& attr,                  // will hold Action if set on node tree
-           const std::string& pathToTask,           // from child ipc
-           const std::string& jobsPassword,         // from child ipc
-           const std::string& process_or_remote_id, // from child ipc
-           int try_no,
-           const std::string& host,         // The host where the client was invoked
-           const std::string& user_cmd = "" // user cmd that created this zombie
-    );
-    Zombie();
-
-    bool operator==(const Zombie& rhs) const; // for python only
-    std::string to_string() const;            // for python only
-
-    /// accessors
-    // distinguish between manual and automatic user action. manual take precedence
-    bool manual_user_action() const { return user_action_set_; }
-    bool fob() const;
-    bool fail() const;
-    bool adopt() const;
-    bool block() const;
-    bool remove() const;
-    bool kill() const;
-
-    ecf::Child::ZombieType type() const { return zombie_type_; }
-    ecf::Child::CmdType last_child_cmd() const { return last_child_cmd_; }
-    const ZombieAttr& attr() const { return attr_; }
-    int calls() const { return calls_; }
-
-    std::string type_str() const;
-    const std::string& jobs_password() const { return jobs_password_; }
-    const std::string& path_to_task() const { return path_to_task_; }
-    const std::string& process_or_remote_id() const { return process_or_remote_id_; }
-    const std::string& user_cmd() const { return user_cmd_; }
-    const std::string& host() const { return host_; }
-    int try_no() const { return try_no_; }
-    int duration() const { return duration_; }
-    ecf::User::Action user_action() const;
-    std::string user_action_str() const;
-    std::string explanation() const;
-
-    const boost::posix_time::ptime& creation_time() const { return creation_time_; }
-
-    bool empty() const { return path_to_task_.empty(); }
-
-    /// returns in seconds the age the zombie is allowed to live
-    /// Server typically checks every 60 seconds, hence this is lowest valid value that has effect
-    int allowed_age() const;
-
-    /// mutators
-    void set_attr(const ZombieAttr& attr) { attr_ = attr; }
-    void set_process_or_remote_id(const std::string& s) { process_or_remote_id_ = s; }
-    void set_last_child_cmd(ecf::Child::CmdType c) { last_child_cmd_ = c; } // user cmd that created this zombie
-    void set_host(const std::string& h) { host_ = h; }                      // The host where client/zombie was created
-    void set_type(ecf::Child::ZombieType zt) { zombie_type_ = zt; }
-
-    /// User action must take precedence over Zombie attribute settings on node tree
-    ///
-    /// Note: user_action to remove zombie is immediate hence no need to for set_remove()
-    ///       Whereas for the other we want to store the action so that when next child
-    ///       command communicate with the server, the action is applied.
-    void set_duration(int d) { duration_ = d; }
-    void set_fob();
-    void set_fail();
-    void set_adopt();
-    void set_block();
-    void set_kill();
-
-    void increment_calls() { calls_++; }
-
-    // write to standard out a title and list of zombies
-    static std::string pretty_print(const std::vector<Zombie>& zombies, int indent = 0);
-    static void pretty_print(const std::vector<Zombie>& zombies, std::vector<std::string>& list, int indent = 0);
-
-    // MISC:
-    // Added to support return by reference
-    static const Zombie& EMPTY();
-    static Zombie& EMPTY_();
-
-private:
-    ecf::User::Action user_action_{ecf::User::BLOCK};      // [ fob, fail, remove, adopt, block, kill ]
-    int try_no_{0};                                        // task try number, set on construction
-    int duration_{0};                                      // How long zombie been alive
-    int calls_{0};                                         // Number of times we have communicated with server.
-    ecf::Child::ZombieType zombie_type_{ecf::Child::USER}; // [ ecf, ecf_pid, ecf_pid_passwd, ecf_passwd, path, user ]
-    ecf::Child::CmdType last_child_cmd_{
-        ecf::Child::INIT};                   // [ init | event | meter | label | wait | queue | abort | complete ]
-    std::string path_to_task_;               // set on construction
-    std::string jobs_password_;              // set on construction
-    std::string process_or_remote_id_;       // set on construction
-    std::string user_cmd_;                   // user cmd that created this zombie, empty otherwise
-    std::string host_;                       // The client host name
-    ZombieAttr attr_;                        // Default or attribute obtained from node tree.
-    boost::posix_time::ptime creation_time_; // When zombie was created. Needed to control lifetime
-    bool user_action_set_{false};            // Differentiate manual from automated, response, manual take precedence
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-std::ostream& operator<<(std::ostream& os, const Zombie&);
-
-#endif /* ecflow_attribute_Zombie_HPP */
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/ZombieAttr.cpp 5.13.0-1/ANattr/src/ecflow/attribute/ZombieAttr.cpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/ZombieAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/ZombieAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,311 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/attribute/ZombieAttr.hpp"
-
-#include <cassert>
-#include <stdexcept>
-
-#include <boost/tokenizer.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace ecf;
-using namespace boost;
-using namespace std;
-
-const ZombieAttr& ZombieAttr::EMPTY() {
-    static const ZombieAttr ZOMBIEATTR = ZombieAttr();
-    return ZOMBIEATTR;
-}
-
-// Constructor ==============================================================================
-ZombieAttr::ZombieAttr(ecf::Child::ZombieType t,
-                       const std::vector<ecf::Child::CmdType>& c,
-                       ecf::User::Action a,
-                       int zombie_lifetime)
-    : child_cmds_(c),
-      zombie_type_(t),
-      action_(a),
-      zombie_lifetime_(zombie_lifetime) {
-    /// Server typically checks every 60 seconds, hence this is lowest valid value for
-    if (zombie_lifetime_ <= 0) {
-        // default constructor. Set defaults
-        switch (zombie_type_) {
-            case Child::USER:
-                zombie_lifetime_ = default_user_zombie_life_time();
-                break;
-            case Child::PATH:
-                zombie_lifetime_ = default_path_zombie_life_time();
-                break;
-            case Child::ECF:
-                zombie_lifetime_ = default_ecf_zombie_life_time();
-                break;
-            case Child::ECF_PID:
-                zombie_lifetime_ = default_ecf_zombie_life_time();
-                break;
-            case Child::ECF_PID_PASSWD:
-                zombie_lifetime_ = default_ecf_zombie_life_time();
-                break;
-            case Child::ECF_PASSWD:
-                zombie_lifetime_ = default_ecf_zombie_life_time();
-                break;
-            case Child::NOT_SET:
-                assert(false);
-                break;
-        }
-    }
-    else if (zombie_lifetime_ < minimum_zombie_life_time()) {
-        zombie_lifetime_ = minimum_zombie_life_time();
-    }
-}
-
-bool ZombieAttr::operator==(const ZombieAttr& rhs) const {
-    if (child_cmds_ != rhs.child_cmds_)
-        return false;
-    if (zombie_type_ != rhs.zombie_type_)
-        return false;
-    if (action_ != rhs.action_)
-        return false;
-    if (zombie_lifetime_ != rhs.zombie_lifetime_)
-        return false;
-    return true;
-}
-
-void ZombieAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += "\n";
-}
-
-std::string ZombieAttr::toString() const {
-    /// format is  zombie_type : child_cmds(optional) : action : zombie_lifetime_(optional)
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void ZombieAttr::write(std::string& ret) const {
-    /// format is  zombie_type : child_cmds(optional) : action : zombie_lifetime_(optional)
-    ret += "zombie ";
-    ret += Child::to_string(zombie_type_);
-    ret += Str::COLON();
-    ret += User::to_string(action_);
-    ret += Str::COLON();
-    ret += Child::to_string(child_cmds_);
-    ret += Str::COLON();
-    ret += ecf::convert_to<std::string>(zombie_lifetime_);
-}
-
-bool ZombieAttr::fob(ecf::Child::CmdType child_cmd) const {
-    if (action_ != User::FOB)
-        return false;
-    if (child_cmds_.empty())
-        return true;
-
-    // If we have child commands specified, then the action is only applicable for that child cmd
-    // for all other child cmds we block
-    for (auto i : child_cmds_) {
-        if (i == child_cmd) {
-            return true;
-        }
-    }
-    return false;
-}
-
-bool ZombieAttr::fail(ecf::Child::CmdType child_cmd) const {
-    if (action_ != User::FAIL)
-        return false;
-    if (child_cmds_.empty())
-        return true;
-
-    // If we have child commands specified, then the action is only applicable for that child cmd
-    // for all other child cmds we block
-    for (auto i : child_cmds_) {
-        if (i == child_cmd) {
-            return true;
-        }
-    }
-    return false;
-}
-
-bool ZombieAttr::adopt(ecf::Child::CmdType child_cmd) const {
-    if (action_ != User::ADOPT)
-        return false;
-    if (child_cmds_.empty())
-        return true;
-
-    // If we have child commands specified, then the action is only applicable for that child cmd
-    // for all other child cmds we block
-    for (auto i : child_cmds_) {
-        if (i == child_cmd) {
-            return true;
-        }
-    }
-    return false;
-}
-
-bool ZombieAttr::remove(ecf::Child::CmdType child_cmd) const {
-    if (action_ != User::REMOVE)
-        return false;
-    if (child_cmds_.empty())
-        return true;
-
-    // If we have child commands specified, then the action is only applicable for that child cmd
-    // for all other child cmds we block
-    for (auto i : child_cmds_) {
-        if (i == child_cmd) {
-            return true;
-        }
-    }
-    return false;
-}
-
-bool ZombieAttr::block(ecf::Child::CmdType child_cmd) const {
-    if (action_ != User::BLOCK)
-        return false;
-    if (child_cmds_.empty())
-        return true;
-
-    // If we have child commands specified, then the action is only applicable for that child cmd
-    // for all other child cmds we block
-    for (auto i : child_cmds_) {
-        if (i == child_cmd) {
-            return true;
-        }
-    }
-    return false;
-}
-
-bool ZombieAttr::kill(ecf::Child::CmdType child_cmd) const {
-    if (action_ != User::KILL)
-        return false;
-    if (child_cmds_.empty())
-        return true;
-
-    // If we have child commands specified, then the action is only applicable for that child cmd
-    // for all other child cmds we block
-    for (auto i : child_cmds_) {
-        if (i == child_cmd) {
-            return true;
-        }
-    }
-    return false;
-}
-
-ZombieAttr ZombieAttr::create(const std::string& string_to_parse) {
-    /// Use boost tokenizer instead of Str::split, as it allows preservation of empty tokens
-    char_separator<char> sep(":", "", boost::keep_empty_tokens);
-    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
-    tokenizer tokenise(string_to_parse, sep);
-    std::vector<std::string> tokens;
-    std::copy(tokenise.begin(), tokenise.end(), back_inserter(tokens));
-    if (tokens.size() < 2)
-        throw std::runtime_error("ZombieAttr::create failed: Invalid zombie type " + string_to_parse);
-
-    /// expects <zombie_type>:<user_action>:child_cmds:zombie_lifetime
-    string str_zombie_type;
-    string action_str;
-    string child_cmds;
-    string lifetime;
-    size_t tokens_size = tokens.size();
-    for (size_t i = 0; i < tokens_size; i++) {
-        // cout << "   token " << i << ": '" << tokens[i] << "'\n";
-        if (i == 0) {
-            str_zombie_type = tokens[i];
-            continue;
-        }
-        if (i == 1) {
-            action_str = tokens[i];
-            continue;
-        }
-        if (i == 2) {
-            child_cmds = tokens[i];
-            continue;
-        }
-        if (i == 3) {
-            lifetime = tokens[i];
-            continue;
-        }
-        throw std::runtime_error("ZombieAttr::create failed: Invalid zombie tokens " + string_to_parse);
-    }
-    // std::cout << "   zombie_type = " << str_zombie_type << "   user_action = " << action_str <<  "   child_cmds = "
-    // << child_cmds<< "   zombie_lifetime = " << lifetime << "\n";
-
-    if (!Child::valid_zombie_type(str_zombie_type))
-        throw std::runtime_error("ZombieAttr::create failed: Invalid zombie type, expected one of [ user | ecf | "
-                                 "ecf_pid | ecf_pid_passed | ecf_passwd | path ] but found " +
-                                 str_zombie_type + string(":") + string_to_parse);
-
-    if (!action_str.empty() && !User::valid_user_action(action_str)) {
-        throw std::runtime_error("ZombieAttr::create failed: Invalid user action, expected one of [ fob | fail | "
-                                 "remove | block | adopt | kill ] but found " +
-                                 action_str + string(":") + string_to_parse);
-    }
-
-    if (!child_cmds.empty() && !Child::valid_child_cmds(child_cmds)) {
-        throw std::runtime_error("ZombieAttr::create failed: Invalid child type, expected one or more of [ "
-                                 "init,event,meter,label,wait,queue,abort,complete] but found " +
-                                 tokens[2] + string(":") + string_to_parse);
-    }
-
-    int zombie_lifetime = -1;
-    if (!lifetime.empty()) {
-        try {
-            zombie_lifetime = ecf::convert_to<int>(lifetime);
-        }
-        catch (const ecf::bad_conversion&) {
-            throw std::runtime_error("ZombieAttr::create failed: Zombie life time must be convertible to an integer " +
-                                     lifetime + string(":") + string_to_parse);
-        }
-    }
-
-    if (action_str.empty() && zombie_lifetime == -1)
-        throw std::runtime_error(
-            "ZombieAttr::create failed: User Action(fob,fail,remove,adopt,block) or lifetime must be specified: " +
-            string_to_parse);
-
-    Child::ZombieType zombie_type   = Child::zombie_type(str_zombie_type);
-    User::Action action             = User::user_action(action_str);
-    vector<Child::CmdType> childVec = Child::child_cmds(child_cmds);
-
-    /// If zombie_lifetime is still -1 constructor will reset to standard defaults
-    return ZombieAttr(zombie_type, childVec, action, zombie_lifetime);
-}
-
-ZombieAttr ZombieAttr::get_default_attr(ecf::Child::ZombieType zt) {
-    switch (zt) {
-        case Child::USER:
-            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_user_zombie_life_time());
-        case Child::PATH:
-            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_path_zombie_life_time());
-        case Child::ECF:
-            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
-        case Child::ECF_PID:
-            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
-        case Child::ECF_PID_PASSWD:
-            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
-        case Child::ECF_PASSWD:
-            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
-        case Child::NOT_SET:
-            break;
-    }
-    return ZombieAttr(Child::ECF, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
-}
-
-template <class Archive>
-void ZombieAttr::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(child_cmds_), CEREAL_NVP(zombie_type_), CEREAL_NVP(action_), CEREAL_NVP(zombie_lifetime_));
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(ZombieAttr);
diff -pruN 5.12.4-1/ANattr/src/ecflow/attribute/ZombieAttr.hpp 5.13.0-1/ANattr/src/ecflow/attribute/ZombieAttr.hpp
--- 5.12.4-1/ANattr/src/ecflow/attribute/ZombieAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/src/ecflow/attribute/ZombieAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_attribute_ZombieAttr_HPP
-#define ecflow_attribute_ZombieAttr_HPP
-
-#include <cstdint>
-
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/User.hpp"
-
-namespace cereal {
-class access;
-}
-
-// Class ZombieAttr:
-// Use compiler , generated destructor, assignment, copy constructor
-// ZombieAttr does *not* have any changeable state
-class ZombieAttr {
-public:
-    ZombieAttr(ecf::Child::ZombieType t,
-               const std::vector<ecf::Child::CmdType>& c,
-               ecf::User::Action a,
-               int zombie_lifetime = 0);
-    ZombieAttr() = default;
-
-    bool operator==(const ZombieAttr& rhs) const;
-    void print(std::string&) const;
-    bool empty() const { return zombie_type_ == ecf::Child::NOT_SET; }
-
-    ecf::Child::ZombieType zombie_type() const { return zombie_type_; }
-    ecf::User::Action action() const { return action_; }
-    int zombie_lifetime() const { return zombie_lifetime_; }
-    const std::vector<ecf::Child::CmdType>& child_cmds() const { return child_cmds_; }
-
-    std::vector<ecf::Child::CmdType>::const_iterator child_begin() const { return child_cmds_.begin(); } // for python
-    std::vector<ecf::Child::CmdType>::const_iterator child_end() const { return child_cmds_.end(); }     // for python
-
-    std::string toString() const;
-
-    bool fob(ecf::Child::CmdType) const;
-    bool fail(ecf::Child::CmdType) const;
-    bool adopt(ecf::Child::CmdType) const;
-    bool block(ecf::Child::CmdType) const;
-    bool remove(ecf::Child::CmdType) const;
-    bool kill(ecf::Child::CmdType) const;
-
-    /// Create from a string. Will throw std::runtime_error of parse errors
-    /// expects <zombie_type>:<user_action>:child_cmds:zombie_lifetime
-    static ZombieAttr create(const std::string& str);
-
-    // Added to support return by reference
-    static const ZombieAttr& EMPTY();
-
-    // Provide the default behaviour
-    static ZombieAttr get_default_attr(ecf::Child::ZombieType);
-
-    static int default_ecf_zombie_life_time() { return 3600; }
-    static int default_user_zombie_life_time() { return 300; }
-    static int default_path_zombie_life_time() { return 900; }
-    static int minimum_zombie_life_time() { return 60; }
-
-private:
-    void write(std::string&) const;
-
-private:
-    std::vector<ecf::Child::CmdType> child_cmds_;             // init, event, meter,label, complete
-    ecf::Child::ZombieType zombie_type_{ecf::Child::NOT_SET}; // User,path or ecf
-    ecf::User::Action action_{ecf::User::BLOCK};              // fob, fail,remove, adopt, block, kill
-    int zombie_lifetime_{0};                                  // How long zombie lives in server
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_attribute_ZombieAttr_HPP */
diff -pruN 5.12.4-1/ANattr/test/TestAttrSerialization.cpp 5.13.0-1/ANattr/test/TestAttrSerialization.cpp
--- 5.12.4-1/ANattr/test/TestAttrSerialization.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestAttrSerialization.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,339 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestSerialisation.hpp"
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/ClockAttr.hpp"
-#include "ecflow/attribute/CronAttr.hpp"
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/attribute/RepeatAttr.hpp"
-#include "ecflow/attribute/TimeAttr.hpp"
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/core/Calendar.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-// Globals used throughout the test
-static std::string fileName = "test.txt";
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_AttrSerialization)
-
-BOOST_AUTO_TEST_CASE(test_AttrDefaultConstructor_serialisation) {
-    cout << "ANattr:: ...test_AttrDefaultConstructor_serialisation \n";
-
-    doSaveAndRestore<VerifyAttr>(fileName);
-    doSaveAndRestore<TodayAttr>(fileName);
-    doSaveAndRestore<TimeAttr>(fileName);
-    doSaveAndRestore<RepeatDate>(fileName);
-    doSaveAndRestore<RepeatDateList>(fileName);
-    doSaveAndRestore<RepeatInteger>(fileName);
-    doSaveAndRestore<RepeatEnumerated>(fileName);
-    doSaveAndRestore<RepeatString>(fileName);
-    doSaveAndRestore<LateAttr>(fileName);
-    doSaveAndRestore<DayAttr>(fileName);
-    doSaveAndRestore<DateAttr>(fileName);
-    doSaveAndRestore<CronAttr>(fileName);
-    doSaveAndRestore<ClockAttr>(fileName);
-    doSaveAndRestore<AutoCancelAttr>(fileName);
-    doSaveAndRestore<AutoArchiveAttr>(fileName);
-    doSaveAndRestore<Label>(fileName);
-    doSaveAndRestore<Variable>(fileName);
-    doSaveAndRestore<Event>(fileName);
-    doSaveAndRestore<Meter>(fileName);
-    doSaveAndRestore<ZombieAttr>(fileName);
-    doSaveAndRestore<QueueAttr>(fileName);
-    doSaveAndRestore<GenericAttr>(fileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_VerifyAttr_serialisation) {
-    cout << "ANattr:: ...test_VerifyAttr_serialisation \n";
-    VerifyAttr saved(NState::COMPLETE, 10);
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_TodayAttr_serialisation) {
-    cout << "ANattr:: ...test_TodayAttr_serialisation \n";
-    {
-        TodayAttr saved(TimeSlot(10, 12));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        TodayAttr saved(TimeSlot(0, 0), TimeSlot(10, 12), TimeSlot(1, 0));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        TodayAttr saved(TimeSeries(TimeSlot(10, 12)));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        TodayAttr saved(TimeSeries(TimeSlot(10, 12)));
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_TimeAttr_serialisation) {
-    cout << "ANattr:: ...test_TimeAttr_serialisation \n";
-    {
-        TimeAttr saved(TimeSlot(10, 12));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        TimeAttr saved(TimeSlot(0, 0), TimeSlot(10, 12), TimeSlot(1, 0));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        TimeAttr saved(TimeSeries(TimeSlot(10, 12)));
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_RepeatAttr_serialisation) {
-    cout << "ANattr:: ...test_RepeatAttr_serialisation \n";
-    {
-        RepeatDate saved("varname", 20101210, 20101230, 3);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        RepeatDateList saved("varname", {19990101, 19990103});
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        RepeatInteger saved("varname", 0, 10, 1);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        std::vector<std::string> theVec;
-        theVec.emplace_back("a");
-        theVec.emplace_back("b");
-        RepeatEnumerated saved = RepeatEnumerated("varname", theVec);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        std::vector<std::string> theVec;
-        theVec.emplace_back("a");
-        RepeatString saved = RepeatString("varname", theVec);
-        doSaveAndRestore(fileName, saved);
-    }
-
-    {
-        Repeat saved(RepeatDate("varname", 20101210, 20101230, 3));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        Repeat saved(RepeatDateList("varname", {19990101, 19990103}));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        Repeat saved(RepeatInteger("varname", 0, 10, 1));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        std::vector<std::string> theVec;
-        theVec.emplace_back("a");
-        theVec.emplace_back("b");
-        Repeat saved(RepeatEnumerated("varname", theVec));
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        std::vector<std::string> theVec;
-        theVec.emplace_back("a");
-        Repeat saved(RepeatString("varname", theVec));
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_LateAttr_serialisation) {
-    cout << "ANattr:: ...test_LateAttr_serialisation \n";
-    LateAttr saved;
-    saved.addSubmitted(TimeSlot(10, 12));
-    saved.addActive(TimeSlot(10, 12));
-    saved.addComplete(TimeSlot(10, 12), true);
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_DayAttr_serialisation) {
-    cout << "ANattr:: ...test_DayAttr_serialisation\n";
-    std::vector<DayAttr::Day_t> dvec;
-    dvec.push_back(DayAttr::SUNDAY);
-    dvec.push_back(DayAttr::MONDAY);
-    dvec.push_back(DayAttr::TUESDAY);
-    dvec.push_back(DayAttr::WEDNESDAY);
-    dvec.push_back(DayAttr::THURSDAY);
-    dvec.push_back(DayAttr::FRIDAY);
-    dvec.push_back(DayAttr::SATURDAY);
-    for (auto& d : dvec) {
-        DayAttr saved(d);
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_DateAttr_serialisation) {
-    cout << "ANattr:: ...test_DateAttr_serialisation\n";
-    DateAttr saved(1, 1, 2010);
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_CronAttr_serialisation) {
-    cout << "ANattr:: ...test_CronAttr_serialisation\n";
-    CronAttr saved;
-    std::vector<int> weekDays;
-    weekDays.push_back(1);
-    weekDays.push_back(2);
-    std::vector<int> daysOfMonth;
-    daysOfMonth.push_back(1);
-    daysOfMonth.push_back(2);
-    std::vector<int> months;
-    months.push_back(1);
-    months.push_back(2);
-    saved.addWeekDays(weekDays);
-    saved.addDaysOfMonth(daysOfMonth);
-    saved.addMonths(months);
-    saved.addTimeSeries(TimeSlot(0, 0), TimeSlot(20, 0), TimeSlot(0, 1));
-
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_ClockAttr_serialisation) {
-    cout << "ANattr:: ...test_ClockAttr_serialisation\n";
-    {
-        ClockAttr saved(false);
-        saved.date(1, 1, 2009);
-        saved.set_gain_in_seconds(3600);
-
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        ClockAttr saved(Calendar::second_clock_time());
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_AutoCancelAttr_serialisation) {
-    cout << "ANattr:: ...test_AutoCancelAttr_serialisation\n";
-    {
-        AutoCancelAttr saved(100);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        AutoCancelAttr saved(TimeSlot(12, 10), true);
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_AutoArchiveAttr_serialisation) {
-    cout << "ANattr:: ...test_AutoArchiveAttr_serialisation\n";
-    {
-        AutoArchiveAttr saved(100);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        AutoArchiveAttr saved(100, true /*idle*/);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        AutoArchiveAttr saved(TimeSlot(12, 10), true, false /*idle*/);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        AutoArchiveAttr saved(TimeSlot(12, 10), true, true /*idle*/);
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_Label_serialisation) {
-    cout << "ANattr:: ...test_Label_serialisation\n";
-    {
-        Label saved("labelName", "some text");
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_Variable_serialisation) {
-    cout << "ANattr:: ...test_Variable_serialisation\n";
-    Variable saved("varname", "var value 123 12 =");
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_Event_serialisation) {
-    cout << "ANattr:: ...test_Event_serialisation\n";
-    {
-        Event saved(3);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        Event saved(10 + 1, "event_name");
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        Event saved(12, "event_name", true /*init value*/);
-        doSaveAndRestore(fileName, saved);
-    }
-    {
-        Event saved(12, "event_name", false /*init value*/);
-        doSaveAndRestore(fileName, saved);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_Meter_serialisation) {
-    cout << "ANattr:: ...test_Meter_serialisation\n";
-    Meter saved("meter", 0, 20, 20);
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_queue_serialisation) {
-    cout << "ANattr:: ...test_queue_serialisation\n";
-    std::vector<std::string> queue_items;
-    queue_items.emplace_back("a");
-    queue_items.emplace_back("b");
-    QueueAttr saved("queue", queue_items);
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_generic_serialisation) {
-    cout << "ANattr:: ...test_generic_serialisation\n";
-    std::vector<std::string> queue_items;
-    queue_items.emplace_back("a");
-    queue_items.emplace_back("b");
-    GenericAttr saved("gen1", queue_items);
-    doSaveAndRestore(fileName, saved);
-}
-
-BOOST_AUTO_TEST_CASE(test_zombie_attr_serialisation) {
-    cout << "ANattr:: ...test_zombie_attr_serialisation\n";
-
-    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
-
-    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
-    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::FAIL, 10));
-    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::BLOCK, 10));
-    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::REMOVE, 10));
-    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::KILL, 10));
-    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::ADOPT, 10));
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestAttributes_main.cpp 5.13.0-1/ANattr/test/TestAttributes_main.cpp
--- 5.12.4-1/ANattr/test/TestAttributes_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestAttributes_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Attributes
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/ANattr/test/TestCron.cpp 5.13.0-1/ANattr/test/TestCron.cpp
--- 5.12.4-1/ANattr/test/TestCron.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestCron.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,623 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/CronAttr.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_Cron)
-
-BOOST_AUTO_TEST_CASE(test_cron_parsing) {
-    cout << "ANattr:: ...test_cron_parsing\n";
-    TimeSlot start(10, 10);
-    TimeSlot finish(23, 10);
-    TimeSlot incr(0, 1);
-
-    {
-        CronAttr cron;
-        CronAttr parsedCron;
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-    }
-    {
-        CronAttr cron;
-        cron.add_time_series(10, 10, false);
-        CronAttr cron1(10, 10, false);
-        CronAttr parsedCron = CronAttr::create("cron 10:10");
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
-                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
-    }
-    {
-        CronAttr cron;
-        cron.add_time_series(10, 10, true);
-        CronAttr cron1(10, 10, true);
-        CronAttr parsedCron = CronAttr::create("cron +10:10");
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
-                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
-    }
-    {
-        CronAttr cron;
-        cron.addTimeSeries(start, finish, incr);
-        CronAttr cron1(start, finish, incr);
-        CronAttr parsedCron = CronAttr::create("cron 10:10 23:10 00:01");
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
-                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
-    }
-
-    {
-        std::vector<int> week_days{0, 1, 2, 3, 4, 5, 6};
-        CronAttr cron;
-        cron.addWeekDays(week_days);
-        cron.add_time_series(10, 10, true);
-
-        CronAttr cron1(10, 10, true);
-        cron1.addWeekDays(week_days);
-
-        std::string cron_str = "cron -w 0,1,2,3,4,5,6 +10:10";
-        CronAttr parsedCron  = CronAttr::create(cron_str);
-        BOOST_CHECK_MESSAGE(parsedCron.toString() == cron_str,
-                            "Expected " << cron_str << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
-                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
-    }
-    {
-        std::vector<int> week_days{0, 1, 2, 3, 4, 5, 6};
-        CronAttr cron;
-        cron.add_last_week_days_of_month(week_days);
-        cron.add_time_series(10, 10, true);
-
-        std::string cron_str = "cron -w 0L,1L,2L,3L,4L,5L,6L +10:10";
-        CronAttr parsedCron  = CronAttr::create(cron_str);
-        BOOST_CHECK_MESSAGE(parsedCron.toString() == cron_str,
-                            "Expected " << cron_str << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-    }
-    {
-        std::vector<int> week_days{0, 1, 2};
-        std::vector<int> last_week_days_of_month{3, 4, 5, 6};
-        CronAttr cron;
-        cron.addWeekDays(week_days);
-        cron.add_last_week_days_of_month(last_week_days_of_month);
-        cron.add_time_series(10, 10, true);
-
-        std::string cron_str = "cron -w 0,1,2,3L,4L,5L,6L +10:10";
-        CronAttr parsedCron  = CronAttr::create(cron_str);
-        BOOST_CHECK_MESSAGE(parsedCron.toString() == cron_str,
-                            "Expected " << cron_str << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-    }
-    {
-        std::vector<int> week_days{0, 1, 2};
-        std::vector<int> last_week_days_of_month{3, 4};
-        CronAttr cron;
-        cron.addWeekDays(week_days);
-        cron.add_last_week_days_of_month(last_week_days_of_month);
-        cron.add_time_series(10, 10, true);
-
-        try {
-            CronAttr parsedCron = CronAttr::create("cron -w 0,1,2,0L,1L,2L +10:10");
-            BOOST_CHECK_MESSAGE(false,
-                                "Expected exception for " << parsedCron.toString() << " cron " << cron.toString());
-        }
-        catch (...) {
-        }
-    }
-
-    {
-        std::vector<int> days_of_month{1, 3, 4, 5, 6, 24, 25};
-        CronAttr cron;
-        cron.addDaysOfMonth(days_of_month);
-        cron.add_last_day_of_month();
-        cron.add_time_series(10, 10, true);
-
-        CronAttr cron1(10, 10, true);
-        cron1.addDaysOfMonth(days_of_month);
-        cron1.add_last_day_of_month();
-
-        CronAttr parsedCron  = CronAttr::create("cron -d L,1,3,4,5,6,24,25 +10:10");
-        CronAttr parsedCron2 = CronAttr::create("cron -d 1,3,4,5,6,24,25,L +10:10");
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron2.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron2.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
-                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
-    }
-
-    std::vector<int> months{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
-    {
-        CronAttr cron;
-        cron.addMonths(months);
-        cron.add_time_series(10, 10, true);
-
-        CronAttr cron1(10, 10, true);
-        cron1.addMonths(months);
-
-        CronAttr parsedCron = CronAttr::create("cron -m 1,2,3,4,5,6,7,8,9,10,11,12 +10:10");
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
-                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
-    }
-
-    {
-        std::vector<int> week_days{0, 1, 2};
-        std::vector<int> last_week_days_of_month{3, 4, 5, 6};
-        std::vector<int> days_of_month{1, 3, 4, 5, 6, 24, 25};
-
-        CronAttr cron;
-        cron.addWeekDays(week_days);
-        cron.add_last_week_days_of_month(last_week_days_of_month);
-        cron.addDaysOfMonth(days_of_month);
-        cron.addMonths(months);
-        cron.add_last_day_of_month();
-        cron.addTimeSeries(start, finish, incr);
-
-        CronAttr cron1(start, finish, incr);
-        cron1.addWeekDays(week_days);
-        cron1.add_last_week_days_of_month(last_week_days_of_month);
-        cron1.addDaysOfMonth(days_of_month);
-        cron1.addMonths(months);
-        cron1.add_last_day_of_month();
-
-        CronAttr parsedCron = CronAttr::create(
-            "cron -w 0,1,2,3L,4L,5L,6L -d 1,3,4,5,6,24,L,25 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:10 23:10 00:01");
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
-                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
-        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
-                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
-    }
-
-    {
-        std::vector<std::string> cron_vec{
-            "cron -w 0,1,2,3L,4L,5L,6L -d 1,3,4,5,6,24,L,25 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:10 23:10 00:01",
-            "cron -w 0L,1L,2L,3L,4L,5L,6L -d 1,L 23:00"};
-        for (const auto& cron : cron_vec) {
-            try {
-                CronAttr parsedCron = CronAttr::create(cron);
-            }
-            catch (...) {
-                BOOST_CHECK_MESSAGE(false, "Could not parse " << cron);
-            }
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_cron_state_parsing) {
-    cout << "ANattr:: ...test_cron_state_parsing\n";
-
-    size_t index = 1; // to get over the cron
-    {
-        std::string line = "cron 04:30 # isValid:false";
-        std::vector<std::string> lineTokens;
-        Str::split(line, lineTokens);
-        bool parse_state = true;
-        CronAttr parsed_cronAttr;
-        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
-
-        CronAttr expected;
-        TimeSeries series(4, 30);
-        series.set_isValid(false); // to match isValid:false
-        expected.addTimeSeries(series);
-        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
-                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
-                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
-    }
-
-    {
-        std::string line = "cron 04:30 # free isValid:false";
-        std::vector<std::string> lineTokens;
-        Str::split(line, lineTokens);
-        bool parse_state = true;
-        CronAttr parsed_cronAttr;
-        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
-
-        CronAttr expected;
-        TimeSeries series(4, 30);
-        series.set_isValid(false); // to match isValid:false
-        expected.addTimeSeries(series);
-        expected.setFree();
-        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
-                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
-                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
-    }
-
-    {
-        std::string line = "cron 00:01 23:59 01:00 # nextTimeSlot/12:01";
-        std::vector<std::string> lineTokens;
-        Str::split(line, lineTokens);
-        bool parse_state = true;
-        CronAttr parsed_cronAttr;
-        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
-
-        CronAttr expected;
-        TimeSlot start(0, 1);
-        TimeSlot finish(23, 59);
-        TimeSlot incr(1, 0);
-        TimeSeries series(start, finish, incr);
-        series.set_next_time_slot(TimeSlot(12, 1));
-        expected.addTimeSeries(series);
-        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
-                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
-                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
-    }
-
-    {
-        std::string line = "cron 00:01 23:59 01:00 # free nextTimeSlot/12:01";
-        std::vector<std::string> lineTokens;
-        Str::split(line, lineTokens);
-        bool parse_state = true;
-        CronAttr parsed_cronAttr;
-        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
-
-        CronAttr expected;
-        TimeSlot start(0, 1);
-        TimeSlot finish(23, 59);
-        TimeSlot incr(1, 0);
-        TimeSeries series(start, finish, incr);
-        series.set_next_time_slot(TimeSlot(12, 1));
-        expected.addTimeSeries(series);
-        expected.setFree();
-        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
-                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
-                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
-    }
-    {
-        std::string line = "cron 00:00 18:00 06:00 # isValid:false nextTimeSlot/24:00";
-        std::vector<std::string> lineTokens;
-        Str::split(line, lineTokens);
-        bool parse_state = true;
-        CronAttr parsed_cronAttr;
-        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
-
-        CronAttr expected;
-        TimeSlot start(0, 0);
-        TimeSlot finish(18, 0);
-        TimeSlot incr(6, 0);
-        TimeSeries series(start, finish, incr);
-        series.set_next_time_slot(TimeSlot(24, 0));
-        series.set_isValid(false); // to match isValid:false
-        expected.addTimeSeries(series);
-        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
-                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
-                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
-    }
-
-    {
-        // ECFLOW-1693
-        // Could not parse 'cron +00:00 23:59 00:01 # isValid:false nextTimeSlot/523:40' around line number 654
-        std::string line = "cron +00:00 23:59 00:01 # isValid:false nextTimeSlot/523:40";
-        std::vector<std::string> lineTokens;
-        Str::split(line, lineTokens);
-        bool parse_state = true;
-        CronAttr parsed_cronAttr;
-        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
-
-        CronAttr expected;
-        TimeSlot start(0, 0);
-        TimeSlot finish(23, 59);
-        TimeSlot incr(0, 1);
-        TimeSeries series(start, finish, incr, true);
-        series.set_next_time_slot(TimeSlot(523, 40));
-        series.set_isValid(false); // to match isValid:false
-        expected.addTimeSeries(series);
-        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
-                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
-                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_cron_once_free_stays_free) {
-    cout << "ANattr:: ...test_cron_once_free_stays_free\n";
-
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
-    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
-
-    CronAttr timeSeries;
-    timeSeries.addTimeSeries(timeSeriesX);
-    CronAttr timeSeries2;
-    timeSeries2.addTimeSeries(timeSeries2X);
-    CronAttr timeSeries3;
-    timeSeries3.addTimeSeries(timeSeries3X);
-    CronAttr timeSeries4;
-    timeSeries4.addTimeSeries(timeSeries4X);
-
-    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
-    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
-    timeSeries.time_series().free_slots(timeSeries_free_slots);
-    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
-    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
-                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
-                                                      << timeSeries_free_slots.size());
-    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
-                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
-                                                     << timeSeries_free_slots.size());
-
-    bool day_changed = false; // after midnight make sure we keep day_changed
-    for (int m = 1; m < 96; m++) {
-        calendar.update(time_duration(minutes(30)));
-        if (!day_changed) {
-            day_changed = calendar.dayChanged();
-        }
-        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
-        // cout << time << " day_changed(" << day_changed << ")\n";
-
-        timeSeries.calendarChanged(calendar);
-        timeSeries2.calendarChanged(calendar);
-        timeSeries3.calendarChanged(calendar);
-        timeSeries4.calendarChanged(calendar);
-
-        // cron should always reque regardless of time series
-        BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar),
-                            timeSeries.toString() << " checkForRequeue should be true at time " << time);
-        BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar),
-                            timeSeries2.toString() << " checkForRequeue should be true at time " << time);
-        BOOST_CHECK_MESSAGE(timeSeries3.checkForRequeue(calendar),
-                            timeSeries3.toString() << " checkForRequeue should be true at time " << time);
-        BOOST_CHECK_MESSAGE(timeSeries4.checkForRequeue(calendar),
-                            timeSeries4.toString() << " checkForRequeue should be true at time " << time);
-
-        // **********************************************************************************
-        // When a cron (regardless of whether its single slot or time series) is free, it stays free,
-        // until explicitly re-queued,
-        // ***********************************************************************************
-
-        if (time < timeSeries.time_series().start().duration()) {
-            if (!day_changed)
-                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should NOT be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be free at time " << time);
-        }
-        else if (time >= timeSeries.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                timeSeries.toString() << " should be free at time " << time);
-        }
-
-        if (time < timeSeries2.time_series().start().duration()) {
-            if (!day_changed)
-                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should NOT be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be free at time " << time);
-        }
-        else if (time >= timeSeries2.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                timeSeries2.toString() << " should be free at time " << time);
-        }
-
-        if (!day_changed) {
-            if (time == timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " should be free at time " << time);
-            }
-            else if (time > timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " isFree, once free should stay free at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                timeSeries3.toString() << " should be free at time after day change " << time);
-        }
-
-        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
-        // repeat/cron)
-        if (!day_changed) {
-            if (time == timeSeries4.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                    timeSeries4.toString() << " should be free at time " << time);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
-                                    timeSeries4.toString()
-                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                timeSeries4.toString()
-                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_cron_time_series) {
-    cout << "ANattr:: ...test_cron_time_series\n";
-
-    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
-    // test time attr isFree(), and checkForRequeue
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
-    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
-
-    CronAttr timeSeries;
-    timeSeries.addTimeSeries(timeSeriesX);
-    CronAttr timeSeries2;
-    timeSeries2.addTimeSeries(timeSeries2X);
-    CronAttr timeSeries3;
-    timeSeries3.addTimeSeries(timeSeries3X);
-    CronAttr timeSeries4;
-    timeSeries4.addTimeSeries(timeSeries4X);
-
-    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
-    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
-    timeSeries.time_series().free_slots(timeSeries_free_slots);
-    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
-    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
-                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
-                                                      << timeSeries_free_slots.size());
-    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
-                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
-                                                     << timeSeries_free_slots.size());
-
-    bool day_changed = false; // after midnight make sure we keep day_changed
-    for (int m = 1; m < 96; m++) {
-        calendar.update(time_duration(minutes(30)));
-        if (!day_changed) {
-            day_changed = calendar.dayChanged();
-        }
-        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
-        //      cout << time << " day_changed(" << day_changed << ")\n";
-
-        timeSeries.calendarChanged(calendar);
-        timeSeries2.calendarChanged(calendar);
-        timeSeries3.calendarChanged(calendar);
-        timeSeries4.calendarChanged(calendar);
-
-        // cron should always reque regardless of time series
-        BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar),
-                            timeSeries.toString() << " checkForRequeue should be true at time " << time);
-        BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar),
-                            timeSeries2.toString() << " checkForRequeue should be true at time " << time);
-        BOOST_CHECK_MESSAGE(timeSeries3.checkForRequeue(calendar),
-                            timeSeries3.toString() << " checkForRequeue should be true at time " << time);
-        BOOST_CHECK_MESSAGE(timeSeries4.checkForRequeue(calendar),
-                            timeSeries4.toString() << " checkForRequeue should be true at time " << time);
-
-        // **********************************************************************************
-        // When a cron (regardless of whether its single slot or time series) is free, it stays free
-        // However in order to test crons with time series, we will re-queue ate the end of this loop
-        // ***********************************************************************************
-
-        if (time < timeSeries.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                timeSeries.toString() << " should NOT be free at time " << time);
-        }
-        else if (time >= timeSeries.time_series().start().duration() &&
-                 time <= timeSeries.time_series().finish().duration()) {
-
-            bool matches_free_slot = false;
-            for (const auto& timeSeries_free_slot : timeSeries_free_slots) {
-                if (time == timeSeries_free_slot) {
-                    matches_free_slot = true;
-                    break;
-                }
-            }
-            if (matches_free_slot)
-                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be fail at time " << time);
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                timeSeries.toString() << " should be holding at time " << time);
-        }
-
-        if (time < timeSeries2.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                timeSeries2.toString() << " should NOT be free at time " << time);
-        }
-        else if (time >= timeSeries2.time_series().start().duration() &&
-                 time <= timeSeries2.time_series().finish().duration()) {
-
-            bool matches_free_slot = false;
-            for (const auto& timeSeries2_free_slot : timeSeries2_free_slots) {
-                if (time == timeSeries2_free_slot) {
-                    matches_free_slot = true;
-                    break;
-                }
-            }
-            if (matches_free_slot)
-                BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should be fail at time " << time);
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                timeSeries2.toString() << " should be holding at time " << time);
-        }
-
-        // Single slot, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
-        // repeat/cron)
-        if (!day_changed) {
-            if (time == timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " should be free at time " << time);
-            }
-            else if (time > timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " isFree, once free should stay free at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                timeSeries3.toString() << " should be free at time after day change " << time);
-        }
-
-        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
-        // repeat/cron)
-        if (!day_changed) {
-            if (time == timeSeries4.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                    timeSeries4.toString() << " should be free at time " << time);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
-                                    timeSeries4.toString()
-                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                timeSeries4.toString()
-                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
-        }
-
-        // Typically when a cron is free, it stays free, until it is re-queued
-        // However in order to test isFree for cron with time inetrvals, we need to re-queue
-        timeSeries.requeue(calendar);
-        timeSeries2.requeue(calendar);
-
-        // Do not requeue cron 00, and cron 15, so that we can check for free
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestDateAttr.cpp 5.13.0-1/ANattr/test/TestDateAttr.cpp
--- 5.12.4-1/ANattr/test/TestDateAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestDateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,123 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_DateAttr)
-
-BOOST_AUTO_TEST_CASE(test_date) {
-    cout << "ANattr:: ...test_date\n";
-    {
-        DateAttr empty;
-        DateAttr empty2;
-        BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
-        BOOST_CHECK_MESSAGE(empty.day() == 0 && empty.month() == 0 && empty.year() == 0, "");
-    }
-    {
-        for (int day = 0; day < 28; day++) {
-            for (int month = 0; month < 13; month++) {
-                int year = 2017;
-                if (month == 0)
-                    year = 0;
-                std::stringstream ss;
-                if (day == 0)
-                    ss << "*";
-                else
-                    ss << day;
-                ss << ".";
-                if (month == 0)
-                    ss << "*";
-                else
-                    ss << month;
-                ss << ".";
-                if (year == 0)
-                    ss << "*";
-                else
-                    ss << year;
-
-                DateAttr date1(day, month, year);
-                DateAttr date2(ss.str());
-                BOOST_CHECK_MESSAGE(date1 == date2, "Equality failed");
-                BOOST_CHECK_MESSAGE(date1.name() == date2.name(), "name failed");
-            }
-        }
-    }
-}
-
-static DateAttr print_and_parse_attr(DateAttr& date) {
-
-    PrintStyle style(PrintStyle::MIGRATE);
-    std::string output;
-    date.print(output);
-    output.erase(output.begin() + output.size() - 1); // remove trailing newline
-
-    std::vector<std::string> tokens;
-    Str::split_orig(output, tokens);
-
-    return DateAttr::create(tokens, true /*read state*/);
-}
-
-BOOST_AUTO_TEST_CASE(test_date_parsing) {
-
-    cout << "ANattr:: ...test_date_parsing\n";
-    {
-        DateAttr date("12.12.2019");
-        date.setFree();
-        DateAttr parsed_date = print_and_parse_attr(date);
-
-        BOOST_CHECK_MESSAGE(date == parsed_date,
-                            "Parse failed expected " << date.dump() << " but found " << parsed_date.dump());
-    }
-    {
-        DateAttr date("12.12.2019");
-        date.setFree();
-        DateAttr parsed_date = print_and_parse_attr(date);
-
-        BOOST_CHECK_MESSAGE(date == parsed_date,
-                            "Parse failed expected " << date.dump() << " but found " << parsed_date.dump());
-    }
-    {
-        DateAttr date("12.12.2019");
-        DateAttr parsed_date = print_and_parse_attr(date);
-
-        BOOST_CHECK_MESSAGE(date == parsed_date,
-                            "Parse failed expected " << date.dump() << " but found " << parsed_date.dump());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_date_errors) {
-    cout << "ANattr:: ...test_date_errors\n";
-    {
-        BOOST_REQUIRE_THROW(DateAttr("-1.2.*"), std::runtime_error);
-        BOOST_REQUIRE_THROW(DateAttr("32.2.*"), std::runtime_error);
-        BOOST_REQUIRE_THROW(DateAttr("1.-1.*"), std::runtime_error);
-        BOOST_REQUIRE_THROW(DateAttr("1.13.*"), std::runtime_error);
-        BOOST_REQUIRE_THROW(DateAttr("1.13.-1"), std::runtime_error);
-        BOOST_REQUIRE_THROW(DateAttr("1.13.99999999"), std::runtime_error);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestDayAttr.cpp 5.13.0-1/ANattr/test/TestDayAttr.cpp
--- 5.12.4-1/ANattr/test/TestDayAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestDayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,171 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_DayAttr)
-
-BOOST_AUTO_TEST_CASE(test_day_attr) {
-    cout << "ANattr:: ...test_day_attr\n";
-
-    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
-    // test time attr isFree(), and checkForRequeue
-    Calendar calendar;
-    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
-
-    // Represent a day within a week (range 0==Sun to 6==Sat)
-    BOOST_CHECK_MESSAGE(calendar.day_of_week() == 2, " Expected tuesday(2) but found " << calendar.day_of_week());
-
-    DayAttr day(DayAttr::WEDNESDAY);
-    day.reset(calendar);
-
-    // int day_changed = 0; // after midnight make sure we keep day_changed
-    // day_changed = 0;  tuesday
-    // day_changed = 1;  wednesday
-    // day_changed = 3;  thursday
-    for (int m = 1; m < 96; m++) {
-        calendar.update(time_duration(hours(1)));
-        // if (calendar.dayChanged())
-        //     day_changed++;
-
-        // cout << " day_changed(" << day_changed << ") calendar.day_of_week() = " <<  calendar.day_of_week() << "\n";
-
-        day.calendarChanged(calendar);
-
-        if (day.date() < calendar.date()) {
-            BOOST_CHECK_MESSAGE(!day.isFree(calendar),
-                                day.toString() << " is free should fail at day " << calendar.day_of_week());
-            BOOST_CHECK_MESSAGE(!day.checkForRequeue(calendar),
-                                day.toString() << " checkForRequeue should return false for a single day "
-                                               << calendar.day_of_week());
-        }
-        else if (day.date() == calendar.date()) {
-            BOOST_CHECK_MESSAGE(day.isFree(calendar),
-                                day.toString() << " is free should pass at day " << calendar.day_of_week());
-            BOOST_CHECK_MESSAGE(!day.checkForRequeue(calendar),
-                                day.toString() << " checkForRequeue should fail at " << calendar.day_of_week());
-        }
-        else {
-            BOOST_CHECK_MESSAGE(day.date() > calendar.date(), "");
-            BOOST_CHECK_MESSAGE(!day.isFree(calendar),
-                                day.toString() << " is free should pass at day " << calendar.day_of_week());
-            BOOST_CHECK_MESSAGE(day.checkForRequeue(calendar),
-                                day.toString() << " checkForRequeue should fail at " << calendar.day_of_week());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_day_attr_constructor) {
-    cout << "ANattr:: ...test_day_attr_constructor \n";
-    {
-        DayAttr day;
-        BOOST_CHECK_MESSAGE(day.day() == DayAttr::SUNDAY, "");
-        BOOST_CHECK_MESSAGE(day.state_change_no() == 0, "");
-        BOOST_CHECK_MESSAGE(day.isSetFree() == false, "");
-    }
-    {
-        DayAttr day(DayAttr::WEDNESDAY);
-        BOOST_CHECK_MESSAGE(day.day() == DayAttr::WEDNESDAY, "");
-        BOOST_CHECK_MESSAGE(day.state_change_no() == 0, "");
-        BOOST_CHECK_MESSAGE(day.isSetFree() == false, "");
-    }
-    {
-        DayAttr day("monday");
-        BOOST_CHECK_MESSAGE(day.day() == DayAttr::MONDAY, "");
-        BOOST_CHECK_MESSAGE(day.state_change_no() == 0, "");
-        BOOST_CHECK_MESSAGE(day.isSetFree() == false, "");
-    }
-}
-
-static DayAttr print_and_parse_attr(DayAttr& day) {
-
-    PrintStyle style(PrintStyle::MIGRATE);
-    std::string output;
-    day.print(output);
-    output.erase(output.begin() + output.size() - 1); // remove trailing newline
-
-    std::vector<std::string> tokens;
-    Str::split_orig(output, tokens);
-
-    return DayAttr::create(tokens, true /*read state*/);
-}
-
-BOOST_AUTO_TEST_CASE(test_day_parsing) {
-
-    cout << "ANattr:: ...test_day_parsing\n";
-    {
-        DayAttr day(DayAttr::WEDNESDAY);
-        day.setFree();
-        DayAttr parsed_day = print_and_parse_attr(day);
-
-        BOOST_CHECK_MESSAGE(day == parsed_day,
-                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
-    }
-    {
-        DayAttr day(DayAttr::WEDNESDAY);
-        day.setFree();
-        DayAttr parsed_day = print_and_parse_attr(day);
-
-        BOOST_CHECK_MESSAGE(day == parsed_day,
-                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
-    }
-    {
-        DayAttr day(DayAttr::WEDNESDAY);
-        DayAttr parsed_day = print_and_parse_attr(day);
-
-        BOOST_CHECK_MESSAGE(day == parsed_day,
-                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
-    }
-    {
-        Calendar calendar;
-        calendar.init(ptime(date(2020, 6, 26), minutes(0)), Calendar::REAL); // friday
-
-        DayAttr day(calendar.date());
-
-        DayAttr parsed_day = print_and_parse_attr(day);
-        BOOST_CHECK_MESSAGE(day == parsed_day,
-                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
-    }
-    {
-        Calendar c;
-        c.init(ptime(date(2020, 6, 26), minutes(0)), Calendar::REAL); // friday
-
-        boost::gregorian::date_duration one_day(1);
-        boost::gregorian::date next_day = c.date(); // todays date
-
-        for (int i = 0; i < 7; i++) {
-            next_day += one_day;
-
-            DayAttr day(next_day);
-            DayAttr parsed_day = print_and_parse_attr(day);
-            BOOST_CHECK_MESSAGE(day == parsed_day,
-                                "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestLabel.cpp 5.13.0-1/ANattr/test/TestLabel.cpp
--- 5.12.4-1/ANattr/test/TestLabel.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestLabel.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_Label)
-
-BOOST_AUTO_TEST_CASE(test_label_parsing) {
-    cout << "ANattr:: ...test_label_parsing\n";
-    {
-        std::string line = "label name \"value\"";
-        std::vector<string> linetokens;
-        Str::split(line, linetokens);
-
-        Label label;
-        label.parse(line, linetokens, false);
-
-        Label expected("name", "value");
-        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
-        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
-                            "Expected " << expected.dump() << " but found " << label.dump());
-    }
-    {
-        std::string line = R"(label name "value\nvalue")";
-        std::vector<string> linetokens;
-        Str::split(line, linetokens);
-
-        Label label;
-        label.parse(line, linetokens, false);
-
-        Label expected("name", "value\nvalue");
-        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
-        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
-                            "Expected " << expected.dump() << " but found " << label.dump());
-    }
-    {
-        std::string line = "label name \"value that is multiple token !!!! 23445 !^ & * ( )\"";
-        std::vector<string> linetokens;
-        Str::split(line, linetokens);
-
-        Label label;
-        label.parse(line, linetokens, false);
-
-        Label expected("name", "value that is multiple token !!!! 23445 !^ & * ( )");
-        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
-        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
-                            "Expected " << expected.dump() << " but found " << label.dump());
-    }
-    {
-        std::string line = R"(label name "value\n that\n is\n multiple\n token\n and\n new\n \nlines")";
-        std::vector<string> linetokens;
-        Str::split(line, linetokens);
-
-        Label label;
-        label.parse(line, linetokens, false);
-
-        Label expected("name", "value\n that\n is\n multiple\n token\n and\n new\n \nlines");
-        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
-        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
-                            "Expected " << expected.dump() << " but found " << label.dump());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestLateAttr.cpp 5.13.0-1/ANattr/test/TestLateAttr.cpp
--- 5.12.4-1/ANattr/test/TestLateAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestLateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,312 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/date_time/posix_time/time_formatters.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/NState.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_LateAttr)
-
-BOOST_AUTO_TEST_CASE(test_late_attr_submitted) {
-    cout << "ANattr:: ...test_late_attr_submitted\n";
-
-    // REF: ECFLOW-322
-    Calendar calendar;
-    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
-
-    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
-    ///               relative, so + is simple ignored, if present. If the node stays submitted
-    ///               longer than the time specified, the late flag is set
-    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
-    ///               is still queued or submitted, the late flag is set
-    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
-    ///               taken from the time the node became active, otherwise node must be complete by
-    ///               the time given.
-    ecf::LateAttr lateAttr;
-    lateAttr.addSubmitted(ecf::TimeSlot(0, 4));
-
-    calendar.update(time_duration(minutes(1)));
-    calendar.update(time_duration(minutes(1)));
-    calendar.update(time_duration(minutes(1)));
-    calendar.update(time_duration(minutes(1)));
-    calendar.update(time_duration(minutes(1)));
-
-    // set submitted state at 00:05:00
-    // cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
-    std::pair<NState, boost::posix_time::time_duration> state =
-        std::make_pair(NState(NState::SUBMITTED), calendar.duration());
-
-    // after four minutes in submitted state, we should be late
-    for (int m = 1; m < 10; m++) {
-        calendar.update(time_duration(minutes(1)));
-        // cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-
-        lateAttr.checkForLateness(state, calendar);
-        // if (lateAttr.isLate()) {
-        //    cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-        // }
-
-        if (m >= 4) {
-            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
-                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_late_attr_active) {
-    cout << "ANattr:: ...test_late_attr_active\n";
-
-    Calendar calendar;
-    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
-
-    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
-    ///               relative, so + is simple ignored, if present. If the node stays submitted
-    ///               longer than the time specified, the late flag is set
-    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
-    ///               is still queued or submitted, the late flag is set
-    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
-    ///               taken from the time the node became active, otherwise node must be complete by
-    ///               the time given.
-
-    ecf::LateAttr lateAttr;
-    lateAttr.addActive(ecf::TimeSlot(10, 0));
-
-    // set submitted state at 00:00:00
-    // cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
-    std::pair<NState, boost::posix_time::time_duration> state =
-        std::make_pair(NState(NState::SUBMITTED), calendar.duration());
-
-    // after 10 hours we, if we are not active, we should be late
-    for (int m = 1; m < 23; m++) {
-        calendar.update(time_duration(hours(1)));
-        // cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-
-        lateAttr.checkForLateness(state, calendar);
-        //      if (lateAttr.isLate()) {
-        //         cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-        //      }
-
-        if (m >= 10) {
-            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
-                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_late_attr_complete_relative) {
-    cout << "ANattr:: ...test_late_attr_complete_relative\n";
-
-    Calendar calendar;
-    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
-
-    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
-    ///               relative, so + is simple ignored, if present. If the node stays submitted
-    ///               longer than the time specified, the late flag is set
-    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
-    ///               is still queued or submitted, the late flag is set
-    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
-    ///               taken from the time the node became active, otherwise node must be complete by
-    ///               the time given.
-
-    ecf::LateAttr lateAttr;
-    lateAttr.addComplete(ecf::TimeSlot(0, 15), true);
-
-    // set active state at 00:00:00
-    //   cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
-    std::pair<NState, boost::posix_time::time_duration> state =
-        std::make_pair(NState(NState::ACTIVE), calendar.duration());
-
-    // after 15 minutes relative, if we are not complete, we should be late
-    for (int m = 1; m < 23; m++) {
-        calendar.update(time_duration(minutes(1)));
-        //      cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-
-        lateAttr.checkForLateness(state, calendar);
-        //      if (lateAttr.isLate()) {
-        //         cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-        //      }
-
-        if (m >= 15) {
-            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
-                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_late_attr_complete_real) {
-    cout << "ANattr:: ...test_late_attr_complete_real\n";
-
-    Calendar calendar;
-    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
-
-    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
-    ///               relative, so + is simple ignored, if present. If the node stays submitted
-    ///               longer than the time specified, the late flag is set
-    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
-    ///               is still queued or submitted, the late flag is set
-    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
-    ///               taken from the time the node became active, otherwise node must be complete by
-    ///               the time given.
-
-    ecf::LateAttr lateAttr;
-    lateAttr.addComplete(ecf::TimeSlot(3, 0), false);
-
-    // set active state at 00:00:00
-    //   cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
-    std::pair<NState, boost::posix_time::time_duration> state =
-        std::make_pair(NState(NState::ACTIVE), calendar.duration());
-
-    // after 3 hours we, if we are not complete, we should be late
-    for (int m = 1; m < 7; m++) {
-
-        calendar.update(time_duration(hours(1)));
-        //      cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-
-        lateAttr.checkForLateness(state, calendar);
-        //      if (lateAttr.isLate()) {
-        //         cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
-        //      }
-
-        if (m >= 3) {
-            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
-                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_late_parsing) {
-    cout << "ANattr:: ...test_late_parsing\n";
-    TimeSlot start(10, 10);
-    TimeSlot finish(23, 10);
-    {
-        LateAttr late;
-        LateAttr parsedlate;
-        BOOST_CHECK_MESSAGE(late == parsedlate,
-                            "Expected " << late.toString() << " but found " << parsedlate.toString());
-    }
-    {
-        LateAttr late;
-        late.addSubmitted(start);
-        LateAttr parsedLate = LateAttr::create("late -s 10:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-        parsedLate = LateAttr::create("-s 10:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-    }
-    {
-        LateAttr late;
-        late.addActive(finish);
-        LateAttr parsedLate = LateAttr::create("late -a 23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-        parsedLate = LateAttr::create("-a 23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-    }
-    {
-        LateAttr late;
-        late.addComplete(finish, false);
-        LateAttr parsedLate = LateAttr::create("late -c 23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-        parsedLate = LateAttr::create("-c 23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-    }
-    {
-        LateAttr late;
-        late.addComplete(finish, true);
-        LateAttr parsedLate = LateAttr::create("late -c +23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-        parsedLate = LateAttr::create("-c +23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-    }
-    {
-        LateAttr late;
-        late.addComplete(finish, true);
-        LateAttr parsedLate = LateAttr::create("late -c +23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-        parsedLate = LateAttr::create("-c +23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-    }
-    {
-        LateAttr late;
-        late.addSubmitted(start);
-        late.addActive(finish);
-        late.addComplete(finish, true);
-        LateAttr parsedLate = LateAttr::create("late -s 10:10 -a 23:10 -c +23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-        parsedLate = LateAttr::create("-s 10:10 -a 23:10 -c +23:10");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-    }
-    {
-        LateAttr late;
-        late.addSubmitted(start);
-        late.addActive(finish);
-        late.addComplete(finish, true);
-        LateAttr parsedLate = LateAttr::create("late -c +23:10 -s 10:10 -a 23:10 ");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-        parsedLate = LateAttr::create("-c +23:10 -s 10:10 -a 23:10 ");
-        BOOST_CHECK_MESSAGE(late == parsedLate,
-                            "Expected " << late.toString() << " but found " << parsedLate.toString());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_late_parsing_errors) {
-    cout << "ANattr:: ...test_late_parsing_errors\n";
-    BOOST_REQUIRE_THROW((void)LateAttr::create(""), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late 10:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -s 100:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -s 10:107"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("10:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -a"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("-a"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("-c"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("-s"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c -s 10:10 -a 23:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -s -a 23:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:105 -s 10:10 -a 23:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -c +23:10 -s 10:10 -a 23:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -s 10:10 -a 23:10 -a 23:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -s 10:10  -s 10:10 -a 23:10"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c -s -a"), std::runtime_error);
-    BOOST_REQUIRE_THROW((void)LateAttr::create("late +23:10 10:10 23:10"), std::runtime_error);
-
-    BOOST_CHECK_THROW((void)LateAttr::create("late  -a 23:11 -c"), std::runtime_error);
-    BOOST_CHECK_THROW((void)LateAttr::create("late -c +23:10 -s 10:10 -a"), std::runtime_error);
-    BOOST_CHECK_THROW((void)LateAttr::create("late -c +23:10 -s 10:10 -a 11:11 -s"), std::runtime_error);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestMigration.cpp 5.13.0-1/ANattr/test/TestMigration.cpp
--- 5.12.4-1/ANattr/test/TestMigration.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,344 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestSerialisation.hpp"
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/ClockAttr.hpp"
-#include "ecflow/attribute/CronAttr.hpp"
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/attribute/RepeatAttr.hpp"
-#include "ecflow/attribute/TimeAttr.hpp"
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/TimeSlot.hpp"
-#include "ecflow/core/cereal_boost_time.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-// #define UPDATE_TESTS 1
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_Migration)
-
-// These test are used for future release. They help to ensure that we have
-// backward compatibility.i.e future release can open file, created by an earlier release
-//
-BOOST_AUTO_TEST_CASE(test_migration_restore_def_con) {
-    cout << "ANattr:: ...test_migration_restore_def_con\n";
-
-    std::string file_name = File::test_data("ANattr/test/data/migration/default_constructor_1_2_2/", "ANattr");
-    // BOOST_CHECK_MESSAGE(File::createDirectories(file_name ),"Could not create directory " << file_name);
-
-    // Create migration data
-#ifdef UPDATE_TESTS
-    doSave(file_name + "VerifyAttr", VerifyAttr());
-    doSave(file_name + "TodayAttr", TodayAttr());
-    doSave(file_name + "TimeAttr", TimeAttr());
-    doSave(file_name + "RepeatDate", RepeatDate());
-    doSave(file_name + "RepeatDateList", RepeatDateList());
-    doSave(file_name + "RepeatInteger", RepeatInteger());
-    doSave(file_name + "RepeatEnumerated", RepeatEnumerated());
-    doSave(file_name + "RepeatString", RepeatString());
-    doSave(file_name + "LateAttr", LateAttr());
-    doSave(file_name + "DayAttr", DayAttr());
-    doSave(file_name + "DateAttr", DateAttr());
-    doSave(file_name + "CronAttr", CronAttr());
-    doSave(file_name + "ClockAttr", ClockAttr());
-    doSave(file_name + "AutoCancelAttr", AutoCancelAttr());
-    doSave(file_name + "AutoArchiveAttr", AutoArchiveAttr());
-    doSave(file_name + "Label", Label());
-    doSave(file_name + "Variable", Variable());
-    doSave(file_name + "Event", Event());
-    doSave(file_name + "Meter", Meter());
-    doSave(file_name + "ZombieAttr", ZombieAttr());
-    doSave(file_name + "QueueAttr", QueueAttr());
-    doSave(file_name + "GenericAttr", GenericAttr());
-#endif
-
-    do_restore<VerifyAttr>(file_name + "VerifyAttr", VerifyAttr());
-    do_restore<TodayAttr>(file_name + "TodayAttr", TodayAttr());
-    do_restore<TimeAttr>(file_name + "TimeAttr", TimeAttr());
-    do_restore<RepeatDate>(file_name + "RepeatDate", RepeatDate());
-    do_restore<RepeatDateList>(file_name + "RepeatDateList", RepeatDateList());
-    do_restore<RepeatInteger>(file_name + "RepeatInteger", RepeatInteger());
-    do_restore<RepeatEnumerated>(file_name + "RepeatEnumerated", RepeatEnumerated());
-    do_restore<RepeatString>(file_name + "RepeatString", RepeatString());
-    do_restore<LateAttr>(file_name + "LateAttr", LateAttr());
-    do_restore<DayAttr>(file_name + "DayAttr", DayAttr());
-    do_restore<DateAttr>(file_name + "DateAttr", DateAttr());
-    do_restore<CronAttr>(file_name + "CronAttr", CronAttr());
-    do_restore<AutoCancelAttr>(file_name + "AutoCancelAttr", AutoCancelAttr());
-    do_restore<AutoArchiveAttr>(file_name + "AutoArchiveAttr", AutoArchiveAttr());
-    do_restore<Label>(file_name + "Label", Label());
-    do_restore<Variable>(file_name + "Variable", Variable());
-    do_restore<Event>(file_name + "Event", Event());
-    do_restore<Meter>(file_name + "Meter", Meter());
-    do_restore<ZombieAttr>(file_name + "ZombieAttr", ZombieAttr());
-    do_restore<QueueAttr>(file_name + "QueueAttr", QueueAttr());
-    do_restore<GenericAttr>(file_name + "GenericAttr", GenericAttr());
-}
-
-BOOST_AUTO_TEST_CASE(test_migration_restore) {
-    cout << "ANattr:: ...test_migration_restore\n";
-
-    std::string file_name = File::test_data("ANattr/test/data/migration/1_2_2/", "ANattr");
-    // BOOST_CHECK_MESSAGE(File::createDirectories(file_name ),"Could not create directory " << file_name);
-
-    std::vector<std::string> theVec;
-    theVec.emplace_back("a");
-    theVec.emplace_back("b");
-    LateAttr lateattr;
-    lateattr.addSubmitted(TimeSlot(10, 12));
-    lateattr.addActive(TimeSlot(10, 12));
-    lateattr.addComplete(TimeSlot(10, 12), true);
-
-    CronAttr cron_attr;
-    std::vector<int> weekDays;
-    weekDays.push_back(1);
-    weekDays.push_back(2);
-    std::vector<int> daysOfMonth;
-    daysOfMonth.push_back(1);
-    daysOfMonth.push_back(2);
-    std::vector<int> months;
-    months.push_back(1);
-    months.push_back(2);
-    cron_attr.addWeekDays(weekDays);
-    cron_attr.addDaysOfMonth(daysOfMonth);
-    cron_attr.addMonths(months);
-    cron_attr.addTimeSeries(TimeSlot(0, 0), TimeSlot(20, 0), TimeSlot(0, 1));
-
-    ClockAttr clock_attr(false);
-    clock_attr.date(1, 1, 2009);
-    clock_attr.set_gain_in_seconds(3600);
-
-    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
-
-    Label label("name", "value");
-    label.set_new_value("new_value");
-
-#ifdef UPDATE_TESTS
-    // Create migration data
-    doSave(file_name + "VerifyAttr", VerifyAttr(NState::COMPLETE, 3));
-    doSave(file_name + "TodayAttr", TodayAttr(10, 12));
-    doSave(file_name + "TimeAttr", TimeAttr(10, 12));
-    doSave(file_name + "RepeatDate", RepeatDate("date", 20110112, 20110115));
-    doSave(file_name + "RepeatDateList", RepeatDateList("datelist", {19990101, 19990102}));
-    doSave(file_name + "RepeatInteger", RepeatInteger("integer", 0, 100, 2));
-    doSave(file_name + "RepeatEnumerated", RepeatEnumerated("enum", theVec));
-    doSave(file_name + "RepeatString", RepeatString("string", theVec));
-    doSave(file_name + "LateAttr", lateattr);
-    doSave(file_name + "DayAttr", DayAttr(DayAttr::MONDAY));
-    doSave(file_name + "DateAttr", DateAttr(12, 12, 2012));
-    doSave(file_name + "CronAttr", cron_attr);
-    doSave(file_name + "ClockAttr", clock_attr);
-    doSave(file_name + "AutoCancelAttr", AutoCancelAttr(100));
-    doSave(file_name + "AutoCancelAttr_1", AutoCancelAttr(TimeSlot(10, 12), true));
-    doSave(file_name + "AutoArchiveAttr", AutoArchiveAttr(100));
-    doSave(file_name + "AutoArchiveAttr_1", AutoArchiveAttr(TimeSlot(10, 12), true));
-    doSave(file_name + "Label", label);
-    //   doSave(file_name + "Limit",limit);
-    doSave(file_name + "Variable", Variable("var_name", "var_value"));
-    doSave(file_name + "Event_1", Event(1));
-    doSave(file_name + "Event_2", Event("event"));
-    doSave(file_name + "Event_3", Event(1, "event", true));
-    doSave(file_name + "Meter", Meter("meter", 10, 100, 100));
-    doSave(file_name + "ZombieAttr", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB));
-    doSave(file_name + "ZombieAttr1", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 500));
-    doSave(file_name + "QueueAttr", QueueAttr("queue", theVec));
-    doSave(file_name + "GenericAttr", GenericAttr("gen1", theVec));
-#endif
-
-    do_restore<VerifyAttr>(file_name + "VerifyAttr", VerifyAttr(NState::COMPLETE, 3));
-    do_restore<TodayAttr>(file_name + "TodayAttr", TodayAttr(10, 12));
-    do_restore<TimeAttr>(file_name + "TimeAttr", TimeAttr(10, 12));
-    do_restore<RepeatDate>(file_name + "RepeatDate", RepeatDate("date", 20110112, 20110115));
-    do_restore<RepeatDateList>(file_name + "RepeatDateList", RepeatDateList("datelist", {19990101, 19990102}));
-    do_restore<RepeatInteger>(file_name + "RepeatInteger", RepeatInteger("integer", 0, 100, 2));
-    do_restore<RepeatEnumerated>(file_name + "RepeatEnumerated", RepeatEnumerated("enum", theVec));
-    do_restore<RepeatString>(file_name + "RepeatString", RepeatString("string", theVec));
-    do_restore<LateAttr>(file_name + "LateAttr", lateattr);
-    do_restore<DayAttr>(file_name + "DayAttr", DayAttr(DayAttr::MONDAY));
-    do_restore<DateAttr>(file_name + "DateAttr", DateAttr(12, 12, 2012));
-    do_restore<CronAttr>(file_name + "CronAttr", cron_attr);
-    do_restore<ClockAttr>(file_name + "ClockAttr", clock_attr);
-    do_restore<AutoCancelAttr>(file_name + "AutoCancelAttr", AutoCancelAttr(100));
-    do_restore<AutoCancelAttr>(file_name + "AutoCancelAttr_1", AutoCancelAttr(TimeSlot(10, 12), true));
-    do_restore<AutoArchiveAttr>(file_name + "AutoArchiveAttr", AutoArchiveAttr(100));
-    do_restore<AutoArchiveAttr>(file_name + "AutoArchiveAttr_1", AutoArchiveAttr(TimeSlot(10, 12), true));
-    do_restore<Label>(file_name + "Label", label);
-    do_restore<Variable>(file_name + "Variable", Variable("var_name", "var_value"));
-    do_restore<Event>(file_name + "Event_1", Event(1));
-    do_restore<Event>(file_name + "Event_2", Event(string("event")));
-    do_restore<Event>(file_name + "Event_3", Event(1, string("event"), true));
-    do_restore<Meter>(file_name + "Meter", Meter("meter", 10, 100, 100));
-    do_restore<ZombieAttr>(file_name + "ZombieAttr", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB));
-    do_restore<ZombieAttr>(file_name + "ZombieAttr1", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 500));
-    do_restore<QueueAttr>(file_name + "QueueAttr", QueueAttr("queue", theVec));
-    do_restore<GenericAttr>(file_name + "GenericAttr", GenericAttr("gen1", theVec));
-}
-
-// The following test shows that CEREAL ignores new data members it does not recognise.
-// This allows new data members, which will be ignored by the old client.
-// OLD server to NEW Client(GUI), will not be a problem, since the the new data members are conditional.
-// In ecflow 5.4.0/5.5.0 we added a new data members to the DayAttribute class.
-// This test shows that when NEW SERVER send DayAttr to OLD Client(GUI), this new data member is ignored.
-namespace version_old {
-class DayAttr {
-public:
-    enum Day_t { SUNDAY = 0, MONDAY = 1, TUESDAY = 2, WEDNESDAY = 3, THURSDAY = 4, FRIDAY = 5, SATURDAY = 6 };
-    DayAttr() = default;
-    explicit DayAttr(Day_t day) : day_(day) {}
-    bool operator==(const DayAttr& rhs) const { return day_ == rhs.day() && free_ == rhs.free(); }
-
-    DayAttr::Day_t day() const { return day_; }
-    bool free() const { return free_; }
-    void set_free() { free_ = true; }
-
-private:
-    DayAttr::Day_t day_{DayAttr::SUNDAY};
-    bool free_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar) {
-        ar(CEREAL_NVP(day_));
-        CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
-    }
-};
-} // namespace version_old
-
-namespace version_new_data_member {
-class DayAttr {
-public:
-    enum Day_t { SUNDAY = 0, MONDAY = 1, TUESDAY = 2, WEDNESDAY = 3, THURSDAY = 4, FRIDAY = 5, SATURDAY = 6 };
-    DayAttr() = default;
-    explicit DayAttr(Day_t day) : day_(day) {}
-    bool operator==(const DayAttr& rhs) const {
-        return day_ == rhs.day_ && expired_ == rhs.expired() && free_ == rhs.free() && date_ == rhs.date_;
-    }
-
-    DayAttr::Day_t day() const { return day_; }
-    bool expired() const { return expired_; }
-    bool free() const { return free_; }
-    boost::gregorian::date date() const { return date_; }
-
-    void set_free() { free_ = true; }
-    void set_expired() { expired_ = true; }
-    void set_date(boost::gregorian::date date) { date_ = std::move(date); }
-
-private:
-    DayAttr::Day_t day_{DayAttr::SUNDAY};
-    bool free_{false};
-    bool expired_{false};         // new data member 5.4.0
-    boost::gregorian::date date_; // new data member 5.5.0
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar) {
-        ar(CEREAL_NVP(day_));
-        CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; });       // conditionally save
-        CEREAL_OPTIONAL_NVP(ar, expired_, [this]() { return expired_; }); // conditionally save
-        CEREAL_OPTIONAL_NVP(
-            ar, date_, [this]() { return !date_.is_special(); }); // conditionally save, new to ecflow 5.5.0,
-    }
-};
-} // namespace version_new_data_member
-
-BOOST_AUTO_TEST_CASE(test_day_migration) {
-    cout << "ANattr:: ...test_day_migration\n";
-    // OLD -> NEW  i.e OLD SERVER --> NEW CLIENT
-    {
-        const version_old::DayAttr t = version_old::DayAttr();
-        ecf::save("test_day_migration", t);
-    }
-    {
-        version_new_data_member::DayAttr t;
-        ecf::restore("test_day_migration", t);
-        BOOST_CHECK_MESSAGE(t == version_new_data_member::DayAttr(), "Should be the same");
-    }
-
-    // NEW->OLD  i.e NEW SERVER --> OLD CLIENT
-    // IMPORTANT: This shows that CEREAL ignore data members is does NOT RECOGNIZE.
-    {
-        version_new_data_member::DayAttr def;
-        ecf::save("test_day_migration_def", def);
-
-        version_new_data_member::DayAttr def_free;
-        def_free.set_free();
-        ecf::save("test_day_migration_free", def_free);
-
-        version_new_data_member::DayAttr def_expired;
-        def_expired.set_expired();
-        ecf::save("test_day_migration_expired", def_expired);
-
-        version_new_data_member::DayAttr def_free_and_expired;
-        def_free_and_expired.set_expired();
-        def_free_and_expired.set_free();
-        ecf::save("test_day_migration_free_and_expired", def_free_and_expired);
-
-        version_new_data_member::DayAttr def_free_expired_date;
-        def_free_expired_date.set_expired();
-        def_free_expired_date.set_free();
-        def_free_expired_date.set_date(boost::gregorian::date(2020, 06, 28)); // sunday
-        ecf::save("test_day_migration_free_expired_date", def_free_expired_date);
-    }
-    {
-        version_old::DayAttr def = version_old::DayAttr();
-        ecf::restore("test_day_migration_def", def);
-        BOOST_CHECK_MESSAGE(def == version_old::DayAttr(), "Should be the same");
-
-        version_old::DayAttr def_free = version_old::DayAttr();
-        ecf::restore("test_day_migration_free", def_free);
-        version_old::DayAttr cdef_free;
-        cdef_free.set_free();
-        BOOST_CHECK_MESSAGE(def_free == cdef_free, "Should be the same");
-
-        version_old::DayAttr def_expired = version_old::DayAttr();
-        ecf::restore("test_day_migration_expired", def_expired);
-        BOOST_CHECK_MESSAGE(def_expired == version_old::DayAttr(), "No expired, should be same as default");
-
-        version_old::DayAttr def_free_and_expired = version_old::DayAttr();
-        ecf::restore("test_day_migration_free_and_expired", def_free_and_expired);
-        BOOST_CHECK_MESSAGE(def_free_and_expired == cdef_free, "No expired,But free should be set,Should be the same");
-
-        version_old::DayAttr def_free_expired_date = version_old::DayAttr();
-        ecf::restore("test_day_migration_free_expired_date", def_free_expired_date);
-        BOOST_CHECK_MESSAGE(def_free_and_expired == cdef_free,
-                            "No expired,No date,But free should be set,Should be the same");
-    }
-
-    // remove the generated filea, comment out to debug.
-    fs::remove("test_day_migration");
-    fs::remove("test_day_migration_def");
-    fs::remove("test_day_migration_free");
-    fs::remove("test_day_migration_expired");
-    fs::remove("test_day_migration_free_and_expired");
-    fs::remove("test_day_migration_free_expired_date");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestRepeat.cpp 5.13.0-1/ANattr/test/TestRepeat.cpp
--- 5.12.4-1/ANattr/test/TestRepeat.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestRepeat.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1220 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/RepeatAttr.hpp"
-#include "ecflow/core/Cal.hpp"
-#include "ecflow/core/Converter.hpp"
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-static const std::vector<std::string> stringList = {std::string("a"), std::string("b"), std::string("c")};
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_Repeat)
-
-/*
- * Test Suite: ::test_repeat
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat)
-
-BOOST_AUTO_TEST_CASE(invariants) {
-    cout << "ANattr:: ...TestRepeat::invariants\n";
-
-    // Test the invariant that non-empty repeat must have a name
-    Repeat empty;
-    Repeat empty2;
-    BOOST_CHECK_MESSAGE(empty.empty(), "Construction");
-    BOOST_CHECK_MESSAGE(empty.name().empty(), "Construction");
-    BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
-}
-
-BOOST_AUTO_TEST_CASE(construction) {
-    cout << "ANattr:: ...TestRepeat::construction\n";
-
-    Repeat empty;
-
-    Repeat another(empty);
-    BOOST_CHECK_MESSAGE(another == empty, "Copy construction failed");
-
-    BOOST_CHECK_MESSAGE(empty.name() == string(), " empty  failed");
-    BOOST_CHECK_MESSAGE(empty.valid() == false, " empty  failed");
-    BOOST_CHECK_MESSAGE(empty.value() == 0, " empty  failed");
-    empty.setToLastValue();
-    BOOST_CHECK_MESSAGE(empty.valueAsString() == string(), " empty  failed");
-    empty.reset();
-    empty.increment();
-    empty.change("fred");
-    BOOST_CHECK_MESSAGE(empty.valueAsString() == string(), " empty  failed");
-    empty.changeValue(10);
-    BOOST_CHECK_MESSAGE(empty.valueAsString() == string(), " empty  failed");
-    BOOST_CHECK_MESSAGE(empty.isInfinite() == false, " empty  failed");
-    BOOST_CHECK_MESSAGE(empty.toString() == string(), " empty  failed");
-    BOOST_CHECK_MESSAGE(empty.state_change_no() == 0, " empty  failed");
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat
-
-/*
- * Test Suite: ::test_repeat_datelist
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat_datelist)
-
-BOOST_AUTO_TEST_CASE(invariants) {
-    cout << "ANattr:: ...test_repeat_datelist::invariants\n";
-
-    {
-        Repeat rep(RepeatDateList("YMD", {20190929, 20190131}));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.start() == 20190929, "Start should be 20190929");
-        BOOST_CHECK_MESSAGE(rep.end() == 20190131, "end should be 20190131");
-        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
-        BOOST_CHECK_MESSAGE(rep.value() == 20190929, "value should be 20190929");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190929, "last_valid_value should be 20190929");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20190929", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20190131", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20190929", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value_minus(1) == 20190928,
-                            "expected 20190928 but found " << rep.last_valid_value_minus(1));
-        BOOST_CHECK_MESSAGE(rep.last_valid_value_plus(1) == 20190930,
-                            "expected 20190930 but found " << rep.last_valid_value_minus(1));
-        BOOST_CHECK_MESSAGE(rep.last_valid_value_plus(2) == 20191001,
-                            "expected 20191001 but found " << rep.last_valid_value_minus(1));
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(cloned.name() == "YMD", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.start() == 20190929, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.end() == 20190131, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.value() == 20190929, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "20190929", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 20190929, "last_valid_value should be 20190929");
-        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "20190131", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "20190929", "not as expected");
-
-        RepeatDateList empty;
-        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
-        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
-        BOOST_CHECK_MESSAGE(empty.step() == 1, "step should be 1");
-        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
-        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
-        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
-        BOOST_CHECK_MESSAGE(empty.valueAsString() == "0", "expected 0 but found " << empty.valueAsString());
-        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "0",
-                            "expected 0 but found " << empty.next_value_as_string());
-        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "0",
-                            "expected 0 but found " << empty.prev_value_as_string());
-    }
-    {
-        Repeat rep(RepeatDateList("YMD", {20190929, 20190131}));
-        BOOST_CHECK_MESSAGE(rep.start() == 20190929, "Start should be 20190929");
-        BOOST_CHECK_MESSAGE(rep.end() == 20190131, "end should be  20190131");
-        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
-        BOOST_CHECK_MESSAGE(rep.value() == 20190929, "value should be 20190929");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190929, "last valid value should be 20190929");
-        rep.increment();
-        BOOST_CHECK_MESSAGE(rep.valid(), "RepeatDateList should be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 20190131, "value should be 20190131 ");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190131, "last_valid_value should be 20190131 ");
-        rep.increment();
-        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDateList should not be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 0, "expected 0 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190131,
-                            "expected 20190131 but found " << rep.last_valid_value());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat_datelist
-
-/*
- * Test Suite: ::test_repeat_date
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat_date)
-
-BOOST_AUTO_TEST_CASE(invariants) {
-    cout << "ANattr:: ...test_repeat_date::invariants\n";
-
-    {
-        Repeat rep(RepeatDate("YMD", 20090916, 20090930, 1));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.end() == 20090930, "end should be 20090930");
-        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
-        BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090916", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090917", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090916", "not as expected");
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(cloned.name() == "YMD", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.start() == 20090916, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.end() == 20090930, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.value() == 20090916, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "20090916", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 20090916, "last_valid_value should be 20090916");
-        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "20090917", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "20090916", "not as expected");
-
-        RepeatDate empty;
-        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
-        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
-        BOOST_CHECK_MESSAGE(empty.step() == 0, "step should be 0");
-        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
-        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
-        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
-        BOOST_CHECK_MESSAGE(empty.valueAsString() == "0", "expected 0 but found " << empty.valueAsString());
-        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "0",
-                            "expected 0 but found " << empty.next_value_as_string());
-        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "0",
-                            "expected 0 but found " << empty.prev_value_as_string());
-    }
-    {
-        Repeat rep(RepeatDate("YMD", 20090930, 20090916, -1));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.start() == 20090930, "Start should be 20090930");
-        BOOST_CHECK_MESSAGE(rep.end() == 20090916, "end should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.step() == -1, "step should be -1");
-        BOOST_CHECK_MESSAGE(rep.value() == 20090930, "value should be 20090930");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090930, "last_valid_value should be 20090930");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090930", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090929",
-                            "expected 20090929 but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090930",
-                            "expected 20090930 but found " << rep.prev_value_as_string());
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(cloned.name() == "YMD", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.start() == 20090930, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.end() == 20090916, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.step() == -1, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.value() == 20090930, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "20090930", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 20090930, "last_valid_value should be 20090930");
-    }
-    {
-        Repeat rep(RepeatDate("YMD", 20090916, 20090916, 1));
-        BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.end() == 20090916, "end should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
-        BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "delta should be 20090916");
-        rep.increment();
-        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDate should not be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 20090917, "value should be 20090917");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
-    }
-    {
-        Repeat rep(RepeatDate("YMD", 20090916, 20090916, -1));
-        BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.end() == 20090916, "end should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.step() == -1, "step should be -1");
-        BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
-        rep.increment();
-        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDate should not be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 20090915, "value should be 20090915");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(construction) {
-    cout << "ANattr:: ...test_repeat_date::construction\n";
-
-    Repeat empty;
-    {
-        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
-        Repeat l2(RepeatDate("YMD", 20090916, 20090930, 1));
-        BOOST_CHECK_MESSAGE(!l1.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(!l2.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
-        BOOST_CHECK_MESSAGE(!(l1 == empty), "Equality failed");
-
-        Repeat l1a(RepeatDate("YMD", 20090930, 20090916, -1));
-        Repeat l2a(RepeatDate("YMD", 20090930, 20090916, -1));
-        BOOST_CHECK_MESSAGE(!l1a.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(!l2a.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(l1a == l2a, "Equality failed");
-        BOOST_CHECK_MESSAGE(!(l1a == empty), "Equality failed");
-
-        l1.clear();
-        l2.clear();
-
-        BOOST_CHECK_MESSAGE(l1 == empty, "Clear failed");
-        BOOST_CHECK_MESSAGE(l2 == empty, "Clear failed");
-    }
-
-    {
-        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
-        Repeat l2;
-        l2 = l1;
-        BOOST_CHECK_MESSAGE(l1 == l2, "Assignment failed");
-
-        l2 = empty;
-        BOOST_CHECK_MESSAGE(l2 == empty, "Assignment failed");
-    }
-
-    {
-        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
-        Repeat l2 = l1;
-        BOOST_CHECK_MESSAGE(l1 == l2, "Copy construction failed");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(move_semantics) {
-    cout << "ANattr:: ...test_repeat_date::move_semantics\n";
-
-    {
-        Repeat x;
-        BOOST_CHECK_MESSAGE(x.empty(), "Construction failed");
-
-        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
-        x = l1;
-        BOOST_CHECK_MESSAGE(!x.empty(), "copy assignment failed");
-        BOOST_CHECK_MESSAGE(x == l1, "Equality failed, after copy assignment");
-        x = std::move(l1);
-        BOOST_CHECK_MESSAGE(!x.empty(), "move assignment failed");
-        BOOST_CHECK_MESSAGE(l1.empty(), "move assignment failed");
-    }
-    {
-        Repeat r1(RepeatDate("YMD", 20090916, 20090930, 1));
-        Repeat r2 = Repeat(r1); // copy construction
-        BOOST_CHECK_MESSAGE(!r1.empty(), " copy construction failed");
-        BOOST_CHECK_MESSAGE(!r2.empty(), " copy construction failed");
-        BOOST_CHECK_MESSAGE(r1 == r2, "Equality failed, after copy construction");
-
-        Repeat r3 = Repeat(std::move(r1)); // move construction
-        BOOST_CHECK_MESSAGE(r1.empty(), "move construction failed");
-        BOOST_CHECK_MESSAGE(r2 == r3, "Equality failed, after move construction");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(last_value) {
-    cout << "ANattr:: ...test_repeat_date::last_value \n";
-
-    {
-        Repeat rep(RepeatDate("YMD", 20090916, 20090930, 1));
-        rep.update_repeat_genvar();
-        const Variable& gen_var = rep.find_gen_variable("YMD_JULIAN");
-        int old_value           = gen_var.value();
-        rep.setToLastValue();
-        int new_value = gen_var.value();
-
-        BOOST_CHECK_MESSAGE(rep.value() == 20090930,
-                            "Set to last value did not work, expected 20090930 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090930",
-                            "Set to last value did not work, expected '20090930' but found " << rep.valueAsString());
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090930",
-                            "next_value_as_string() did not work, expected 20090930 but found "
-                                << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090929",
-                            "prev_value_as_string() did not work, expected 20090929 but found "
-                                << rep.prev_value_as_string());
-        BOOST_CHECK_MESSAGE(old_value != new_value, "Expected to update the generated variables ");
-    }
-    {
-        Repeat rep(RepeatDate("YMD", 20090930, 20090916, -1));
-        rep.setToLastValue();
-        BOOST_CHECK_MESSAGE(rep.value() == 20090916,
-                            "Set to last value did not work, expected 20090916 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090916",
-                            "Set to last value did not work, expected '20090916' but found " << rep.valueAsString());
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090916",
-                            "next_value_as_string() did not work, expected 20090916 but found "
-                                << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090917",
-                            "prev_value_as_string() did not work, expected 20090917 but found "
-                                << rep.prev_value_as_string());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(increment) {
-    cout << "ANattr:: ...test_repeat_date::increment \n";
-
-    {
-        Repeat rep(RepeatDate("YMD", 20090916, 20090920, 1));
-        rep.update_repeat_genvar();
-        const Variable& gen_var  = rep.find_gen_variable("YMD_JULIAN");
-        const Variable& gen_var2 = rep.find_gen_variable("YMD_DOW");
-        int old_value            = gen_var.value();
-        int old_value2           = gen_var2.value();
-
-        while (rep.valid()) {
-            rep.increment();
-        }
-
-        BOOST_CHECK_MESSAGE(rep.value() == 20090921, "expected 20090921 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090920,
-                            "expected 20090920 but found " << rep.last_valid_value());
-        BOOST_CHECK_MESSAGE(old_value != gen_var.value(), "Expected generated variables to change on increment");
-        BOOST_CHECK_MESSAGE(old_value2 != gen_var2.value(), "Expected generated variables to change on increment");
-
-        rep.reset();
-        BOOST_CHECK_MESSAGE(old_value = gen_var.value(), "Expected generated variables to be the same after reset");
-        BOOST_CHECK_MESSAGE(old_value2 = gen_var2.value(), "Expected generated variables to be the same after reset");
-    }
-    {
-        Repeat rep(RepeatDate("YMD", 20090920, 20090916, -1));
-        while (rep.valid()) {
-            rep.increment();
-        }
-        BOOST_CHECK_MESSAGE(rep.value() == 20090915, "expected 20090915 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916,
-                            "expected 20090916 but found " << rep.last_valid_value());
-    }
-    {
-        Repeat rep(RepeatDate("YMD", 20150514, 20150730, 7));
-        while (rep.valid()) {
-            rep.increment();
-            // cout << "YMD: " << rep.value() << "\n";
-        }
-        BOOST_CHECK_MESSAGE(rep.value() == 20150806, "expected 20150806 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20150730,
-                            "expected 20150730 but found " << rep.last_valid_value());
-    }
-    {
-        Repeat rep(RepeatDate("YMD", 20150730, 20150514, -7));
-        while (rep.valid()) {
-            rep.increment();
-            // cout << "YMD: " << rep.value() << "\n";
-        }
-        BOOST_CHECK_MESSAGE(rep.value() == 20150507, "expected 20150507 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20150514,
-                            "expected 20150514 but found " << rep.last_valid_value());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(handling_errors) {
-    cout << "ANattr:: ...test_repeat_date:handling_errors \n";
-
-    BOOST_REQUIRE_THROW(RepeatDate("", 20090916, 20090920, 1), std::runtime_error);
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 200909161, 20090920, 1), std::runtime_error); // start > 8
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 200909201, 1), std::runtime_error); // end > 8
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090016, 200909201, 1), std::runtime_error); // invalid start month
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090900, 20090920, 1), std::runtime_error);  // invalid start day
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090020, 1), std::runtime_error);  // invalid end month
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090900, 1), std::runtime_error);  // invalid end day
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090920, 0), std::runtime_error);  // delta cannot be zero
-
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090920, 20090916, 1),
-                        std::runtime_error); //  start day > end day, and delta > 0
-    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090920, -1),
-                        std::runtime_error); //  start day < end day, and delta < 0
-
-    RepeatDate date("YMD", 20150514, 20150730, 7);
-    BOOST_REQUIRE_THROW(date.changeValue(20150513), std::runtime_error); // outside of range
-    BOOST_REQUIRE_THROW(date.changeValue(20150731), std::runtime_error); // outside of range
-    BOOST_REQUIRE_THROW(date.changeValue(20150801), std::runtime_error); // outside of range
-
-    BOOST_REQUIRE_THROW(date.changeValue(20150515), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150516), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150517), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150518), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150519), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150520), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150522), std::runtime_error); // not a valid step
-
-    RepeatDate date1("YMD", 20150730, 20150514, -7);
-    BOOST_REQUIRE_THROW(date1.changeValue(20150731), std::runtime_error); // outside of range
-    BOOST_REQUIRE_THROW(date1.changeValue(20150813), std::runtime_error); // outside of range
-    BOOST_REQUIRE_THROW(date1.changeValue(20150513), std::runtime_error); // outside of range
-    BOOST_REQUIRE_THROW(date1.changeValue(20150413), std::runtime_error); // outside of range
-
-    BOOST_REQUIRE_THROW(date.changeValue(20150729), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150728), std::runtime_error); // not a valid step
-    BOOST_REQUIRE_THROW(date.changeValue(20150515), std::runtime_error); // not a valid step
-}
-
-BOOST_AUTO_TEST_CASE(change_value) {
-    cout << "ANattr:: ...test_repeat_date::change_value \n";
-    {
-        Repeat rep2(RepeatDate("YMD", 20150514, 20150730, 7));
-        Repeat rep(RepeatDate("YMD", 20150514, 20150730, 7));
-        BOOST_CHECK_MESSAGE(rep.valid(), "expected valid at start ");
-
-        while (rep.valid()) {
-            rep2.change(boost::lexical_cast<std::string>(rep.value()));
-            BOOST_CHECK_MESSAGE(rep.value() == rep2.value(),
-                                "expected same value, but found " << rep.value() << "  " << rep2.value());
-            rep.increment();
-        }
-    }
-    {
-        Repeat rep2(RepeatDate("YMD", 20150730, 20150514, -7));
-        Repeat rep(RepeatDate("YMD", 20150730, 20150514, -7));
-        BOOST_CHECK_MESSAGE(rep.valid(), "expected valid at start ");
-
-        while (rep.valid()) {
-            rep2.change(boost::lexical_cast<std::string>(rep.value()));
-            BOOST_CHECK_MESSAGE(rep.value() == rep2.value(),
-                                "expected same value, but found " << rep.value() << "  " << rep2.value());
-            rep.increment();
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(generated_variables) {
-    cout << "ANattr:: ...test_repeat_date::generated_variables\n";
-
-    Repeat rep(RepeatDate("YMD", 20090916, 20090930, 1));
-    BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-    BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-    BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
-    BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
-    BOOST_CHECK_MESSAGE(rep.end() == 20090930, "end should be 20090930");
-    BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
-    BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
-    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
-    rep.update_repeat_genvar();
-    std::vector<Variable> vec;
-    rep.gen_variables(vec);
-    BOOST_CHECK_MESSAGE(vec.size() == 6, "expected 6 generated variables but found " << vec.size());
-
-    {
-        const Variable& var = rep.find_gen_variable("YMD");
-        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
-        BOOST_CHECK_MESSAGE(var.theValue() == "20090916", "expected year to be 20090916  but found " << var.theValue());
-    }
-
-    {
-        const Variable& var = rep.find_gen_variable("YMD_YYYY");
-        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
-        BOOST_CHECK_MESSAGE(var.theValue() == "2009", "expected year to be 2009  but found " << var.theValue());
-    }
-
-    {
-        const Variable& var = rep.find_gen_variable("YMD_MM");
-        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_MM");
-        BOOST_CHECK_MESSAGE(var.theValue() == "9", "expected month to be 9  but found " << var.theValue());
-    }
-
-    {
-        const Variable& var = rep.find_gen_variable("YMD_DD");
-        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DD");
-        BOOST_CHECK_MESSAGE(var.theValue() == "16", "expected day of month to be 16 but found " << var.theValue());
-    }
-
-    {
-        const Variable& var = rep.find_gen_variable("YMD_DOW");
-        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DOW");
-        BOOST_CHECK_MESSAGE(var.theValue() == "3", "expected day of week to be 3 but found " << var.theValue());
-    }
-
-    {
-        const Variable& var = rep.find_gen_variable("YMD_JULIAN");
-        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_JULIAN");
-        std::string expected = ecf::convert_to<std::string>(Cal::date_to_julian(20090916));
-        BOOST_CHECK_MESSAGE(var.theValue() == expected, "expected " << expected << " but found " << var.theValue());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(more_generated_variables) {
-    cout << "ANattr:: ...test_repeat_date::more_generated_variables\n";
-
-    int start = 20161231;
-    int end   = 20170106;
-    Repeat rep(RepeatDate("YMD", start, end, 1));
-    BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-    BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-    BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
-    BOOST_CHECK_MESSAGE(rep.start() == start, "Start should be " << start);
-    BOOST_CHECK_MESSAGE(rep.end() == end, "end should be " << end << " but found " << rep.end());
-    BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
-    BOOST_CHECK_MESSAGE(rep.value() == start, "value should be " << start << " but found " << rep.value());
-    BOOST_CHECK_MESSAGE(rep.last_valid_value() == start,
-                        "last_valid_value should be " << start << " but found " << rep.last_valid_value());
-
-    std::vector<std::string> expected_YMD;
-    expected_YMD.emplace_back("20161231");
-    expected_YMD.emplace_back("20170101");
-    expected_YMD.emplace_back("20170102");
-    expected_YMD.emplace_back("20170103");
-    expected_YMD.emplace_back("20170104");
-    expected_YMD.emplace_back("20170105");
-    expected_YMD.emplace_back("20170106");
-
-    std::vector<std::string> expected_year;
-    expected_year.emplace_back("2016");
-    expected_year.emplace_back("2017");
-    expected_year.emplace_back("2017");
-    expected_year.emplace_back("2017");
-    expected_year.emplace_back("2017");
-    expected_year.emplace_back("2017");
-    expected_year.emplace_back("2017");
-
-    std::vector<std::string> expected_MM;
-    expected_MM.emplace_back("12");
-    expected_MM.emplace_back("1");
-    expected_MM.emplace_back("1");
-    expected_MM.emplace_back("1");
-    expected_MM.emplace_back("1");
-    expected_MM.emplace_back("1");
-    expected_MM.emplace_back("1");
-
-    std::vector<std::string> expected_day_of_month;
-    expected_day_of_month.emplace_back("31");
-    expected_day_of_month.emplace_back("1");
-    expected_day_of_month.emplace_back("2");
-    expected_day_of_month.emplace_back("3");
-    expected_day_of_month.emplace_back("4");
-    expected_day_of_month.emplace_back("5");
-    expected_day_of_month.emplace_back("6");
-
-    std::vector<std::string> expected_day_of_week;
-    expected_day_of_week.emplace_back("6");
-    expected_day_of_week.emplace_back("0");
-    expected_day_of_week.emplace_back("1");
-    expected_day_of_week.emplace_back("2");
-    expected_day_of_week.emplace_back("3");
-    expected_day_of_week.emplace_back("4");
-    expected_day_of_week.emplace_back("5");
-
-    std::vector<std::string> expected_julian;
-    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20161231)));
-    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170101)));
-    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170102)));
-    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170103)));
-    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170104)));
-    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170105)));
-    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170106)));
-
-    for (int i = 0; i < 7; i++) {
-
-        rep.update_repeat_genvar();
-        std::vector<Variable> vec;
-        rep.gen_variables(vec);
-        BOOST_CHECK_MESSAGE(vec.size() == 6, "expected 6 generated variables but found " << vec.size());
-
-        {
-            const Variable& var = rep.find_gen_variable("YMD");
-            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
-            BOOST_CHECK_MESSAGE(var.theValue() == expected_YMD[i],
-                                "expected YMD " << expected_YMD[i] << " but found " << var.theValue());
-        }
-
-        {
-            const Variable& var = rep.find_gen_variable("YMD_YYYY");
-            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
-            BOOST_CHECK_MESSAGE(var.theValue() == expected_year[i],
-                                "expected year to be " << expected_year[i] << " but found " << var.theValue());
-        }
-
-        {
-            const Variable& var = rep.find_gen_variable("YMD_MM");
-            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_MM");
-            BOOST_CHECK_MESSAGE(var.theValue() == expected_MM[i],
-                                "expected month to be " << expected_MM[i] << " but found " << var.theValue());
-        }
-
-        {
-            const Variable& var = rep.find_gen_variable("YMD_DD");
-            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DD");
-            BOOST_CHECK_MESSAGE(var.theValue() == expected_day_of_month[i],
-                                "expected day of month to be " << expected_day_of_month[i] << " but found "
-                                                               << var.theValue());
-        }
-
-        {
-            const Variable& var = rep.find_gen_variable("YMD_DOW");
-            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DOW");
-            BOOST_CHECK_MESSAGE(var.theValue() == expected_day_of_week[i],
-                                "expected day of week to be " << expected_day_of_week[i] << " but found "
-                                                              << var.theValue());
-        }
-
-        {
-            const Variable& var = rep.find_gen_variable("YMD_JULIAN");
-            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_JULIAN");
-            BOOST_CHECK_MESSAGE(var.theValue() == expected_julian[i],
-                                "expected " << expected_julian[i] << " but found " << var.theValue());
-        }
-
-        rep.increment();
-    }
-}
-
-BOOST_AUTO_TEST_CASE(convert_xref_to_boost_date) {
-    cout << "ANattr:: ...test_repeat_date::convert_xref_to_boost_date \n";
-
-    auto check_date = [](int start, int end, int delta) {
-        boost::gregorian::date bdate(from_undelimited_string(boost::lexical_cast<std::string>(start)));
-
-        Repeat rep(RepeatDate("YMD", start, end, delta));
-        Repeat rep2(RepeatDate("YMD", start, end, delta));
-        while (rep.valid()) {
-
-            // xref repeat date with boost date, essentially checking bdate with rep
-            string str_value = boost::lexical_cast<std::string>(rep.value());
-            boost::gregorian::date date2(from_undelimited_string(str_value));
-            BOOST_CHECK_MESSAGE(bdate == date2, "expected same value, but found " << bdate << "  " << date2);
-
-            // check change value
-            rep2.change(str_value);
-            BOOST_CHECK_MESSAGE(rep.value() == rep2.value(),
-                                "expected same value, but found " << rep.value() << "  " << rep2.value());
-
-            // increment repeat and boost date
-            rep.increment();
-            bdate += days(delta);
-        }
-    };
-
-    check_date(19800101, 20621231, 1);
-    check_date(19800101, 20621231, 7);
-    check_date(20621231, 19800101, -7);
-    check_date(20150514, 20150730, 7);
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat_date
-
-/*
- * Test Suite: ::test_repeat_datetime
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat_datetime)
-
-BOOST_AUTO_TEST_CASE(invariants) {
-    cout << "ANattr:: ...test_repeat_datetime::invariants\n";
-
-    {
-        Repeat rep(RepeatDateTime("DT", "19700101T000001", "19700102T000001", "24:00:00"));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "DT", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.start() == 1, "Start should be 1");
-        BOOST_CHECK_MESSAGE(rep.end() == 86401, "end should be 86401");
-        BOOST_CHECK_MESSAGE(rep.step() == 86400, "step should be 1");
-        BOOST_CHECK_MESSAGE(rep.value() == 1, "value should be 1");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 1, "last_valid_value should be 1");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "19700101T000001", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "19700102T000001", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "19700101T000001", "not as expected");
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(cloned.name() == "DT", "name not as expected");
-        BOOST_CHECK_MESSAGE(cloned.start() == 1, "Start should be 1");
-        BOOST_CHECK_MESSAGE(cloned.end() == 86401, "end should be 86401");
-        BOOST_CHECK_MESSAGE(cloned.step() == 86400, "step should be 1");
-        BOOST_CHECK_MESSAGE(cloned.value() == 1, "value should be 1");
-        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 1, "last_valid_value should be 1");
-        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "19700101T000001", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "19700102T000001", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "19700101T000001", "not as expected");
-
-        RepeatDateTime empty;
-        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
-        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
-        BOOST_CHECK_MESSAGE(empty.step() == 0, "step should be 0");
-        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
-        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
-        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
-        BOOST_CHECK_MESSAGE(empty.valueAsString() == "19700101T000000",
-                            "expected 19700101T000000 but found " << empty.valueAsString());
-        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "19700101T000000",
-                            "expected 19700101T000000 but found " << empty.next_value_as_string());
-        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "19700101T000000",
-                            "expected 19700101T000000 but found " << empty.prev_value_as_string());
-    }
-    {
-        Repeat rep(RepeatDateTime("DT", "19700102T000001", "19700101T000000", "-24:00:00"));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "DT", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.start() == 86401, "Start should be 86401 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.end() == 0, "end should be 0 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.step() == -86400, "step should be -86400");
-        BOOST_CHECK_MESSAGE(rep.value() == 86401, "value should be 86401 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86401,
-                            "last_valid_value should be 86401 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "19700102T000001", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "19700101T000001",
-                            "expected 19700101T000001 but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "19700102T000001",
-                            "expected 19700102T000001 but found " << rep.prev_value_as_string());
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(rep.name() == "DT", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.start() == 86401, "Start should be 86401 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.end() == 0, "end should be 0 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.step() == -86400, "step should be -86400");
-        BOOST_CHECK_MESSAGE(rep.value() == 86401, "value should be 86401 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86401,
-                            "last_valid_value should be 86401 (seconds since 19700101T000000)");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "19700102T000001", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "19700101T000001",
-                            "expected 19700101T000001 but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "19700102T000001",
-                            "expected 19700102T000001 but found " << rep.prev_value_as_string());
-    }
-    {
-        Repeat rep(RepeatDateTime("DT", "19700101T000001", "19700102T000000", "24:00:00"));
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 1, "last_valid_value should be 1");
-        rep.increment();
-        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDateTime should not be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 86401, "value should be 86401");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86400, "last_valid_value should be 1");
-    }
-    {
-        Repeat rep(RepeatDateTime("DT", "19700102T000000", "19700101T000001", "-24:00:00"));
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86400, "last_valid_value should be 86400");
-        rep.increment();
-        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDateTime should not be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 0, "value should be 0");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 1, "last_valid_value should be 86400");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat_datetime
-
-/*
- * Test Suite: ::test_repeat_enumerated
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat_enumerated)
-
-BOOST_AUTO_TEST_CASE(invariants) {
-    cout << "ANattr:: ...test_repeat_enumerated::invariants\n";
-
-    const std::vector<std::string> stringList = {std::string("a"), std::string("b"), std::string("c")};
-
-    {
-        Repeat rep(RepeatEnumerated("AEnum", stringList));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "AEnum", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "a", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "b", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "a", "not as expected");
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(cloned.name() == "AEnum", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.start() == 0, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.value() == 0, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "a", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "b", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "a", "not as expected");
-
-        RepeatEnumerated empty;
-        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
-        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
-        BOOST_CHECK_MESSAGE(empty.step() == 1, "default step should be 1");
-        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
-        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
-        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
-        BOOST_CHECK_MESSAGE(empty.valueAsString() == "", "not as expected");
-        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "", "not as expected");
-        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "", "not as expected");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(construction) {
-    cout << "ANattr:: ...TestRepeatEnumerated::construction\n";
-
-    Repeat empty;
-    {
-        Repeat la(RepeatEnumerated("AEnum", stringList));
-        Repeat lb(RepeatEnumerated("AEnum", stringList));
-        BOOST_CHECK_MESSAGE(!la.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(!lb.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(la == lb, "Equality failed");
-        BOOST_CHECK_MESSAGE(!(la == empty), "Equality failed");
-
-        la.clear();
-        lb.clear();
-
-        BOOST_CHECK_MESSAGE(la == empty, "Clear failed");
-        BOOST_CHECK_MESSAGE(lb == empty, "Clear failed");
-    }
-    {
-        Repeat la(RepeatEnumerated("AEnum", stringList));
-        Repeat lb;
-        lb = la;
-        BOOST_CHECK_MESSAGE(la == lb, "Assignment failed");
-    }
-    {
-        Repeat la(RepeatEnumerated("AEnum", stringList));
-        Repeat lb = la;
-        BOOST_CHECK_MESSAGE(la == lb, "Copy construction failed");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(last_value) {
-    cout << "ANattr:: ...test_repeat_enumerated::last_value \n";
-
-    Repeat rep(RepeatEnumerated("AEnum", stringList));
-    rep.setToLastValue();
-    BOOST_CHECK_MESSAGE(rep.value() == 2, "Set to last value did not work, expected 2 but found " << rep.value());
-    BOOST_CHECK_MESSAGE(rep.valueAsString() == "c",
-                        "Set to last value did not work, expected 'c' but found " << rep.valueAsString());
-    BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "a", " Expected 'a' but found " << rep.value_as_string(0));
-    BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "b", " Expected 'b' but found " << rep.value_as_string(1));
-    BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "c", " Expected 'c' but found " << rep.value_as_string(2));
-    BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "c",
-                        "next_value_as_string() did not work, expected c but found " << rep.next_value_as_string());
-    BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "b",
-                        "prev_value_as_string() did not work, expected b but found " << rep.prev_value_as_string());
-}
-
-BOOST_AUTO_TEST_CASE(increment) {
-    cout << "ANattr:: ...test_repeat_enumerated::increment \n";
-
-    Repeat rep(RepeatEnumerated("AEnum", stringList));
-    while (rep.valid()) {
-        rep.increment();
-    }
-    BOOST_CHECK_MESSAGE(rep.value() == 3, " Expected 3 but found " << rep.value());
-    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 2, " Expected 2 but found " << rep.last_valid_value());
-}
-
-BOOST_AUTO_TEST_CASE(more_increment) {
-    cout << "ANattr:: ...test_repeat_enumerated::more_increment\n";
-
-    using namespace std::string_literals;
-
-    const std::vector<std::string> stringList = {"20130101"s, "20130102"s, "20130103"s};
-
-    {
-        Repeat rep(RepeatEnumerated("AEnum", stringList));
-        // Note: valueAsString should return string at the last valid index
-
-        BOOST_CHECK_MESSAGE(rep.valid(), "Expected rep to be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 20130101, " Expected 20130101 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130101,
-                            " Expected 20130101 but found " << rep.last_valid_value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130101",
-                            " Expected '20130101' but found " << rep.valueAsString());
-        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "20130101",
-                            " Expected '20130101' but found " << rep.value_as_string(0));
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20130102",
-                            " Expected '20130102' but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20130101",
-                            " Expected '20130101' but found " << rep.prev_value_as_string());
-
-        rep.increment();
-        BOOST_CHECK_MESSAGE(rep.valid(), "Expected rep to be valid");
-        BOOST_CHECK_MESSAGE(rep.value() == 20130102, " Expected 20130102 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130102,
-                            " Expected 20130102 but found " << rep.last_valid_value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130102",
-                            " Expected '20130102' but found " << rep.valueAsString());
-        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "20130102",
-                            " Expected '20130102' but found " << rep.value_as_string(1));
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20130103",
-                            " Expected '20130103' but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20130101",
-                            " Expected '20130101' but found " << rep.prev_value_as_string());
-
-        rep.increment();
-        BOOST_CHECK_MESSAGE(rep.value() == 20130103, " Expected 20130103 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130103,
-                            " Expected 20130103 but found " << rep.last_valid_value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130103",
-                            " Expected '20130103' but found " << rep.valueAsString());
-        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "20130103",
-                            " Expected '20130103' but found " << rep.value_as_string(2));
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20130103",
-                            " Expected '20130103' but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20130102",
-                            " Expected '20130102' but found " << rep.prev_value_as_string());
-
-        rep.increment();
-        BOOST_CHECK_MESSAGE(!rep.valid(), "Expected rep to be in-valid");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130103,
-                            " Expected 20130103 but found " << rep.last_valid_value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130103",
-                            " Expected '20130103' but found " << rep.valueAsString());
-
-        rep.increment();
-        BOOST_CHECK_MESSAGE(!rep.valid(), "Expected rep to be in-valid");
-        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130103,
-                            " Expected 20130103 but found " << rep.last_valid_value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130103",
-                            " Expected '20130103' but found " << rep.valueAsString());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(handling_errors) {
-    cout << "ANattr:: ...test_repeat_enumerated::handling_errors \n";
-
-    const std::vector<std::string> empty;
-    const std::vector<std::string> stringList = {"a", "b"};
-
-    BOOST_REQUIRE_THROW(RepeatEnumerated("", stringList), std::runtime_error);  // empty name
-    BOOST_REQUIRE_THROW(RepeatEnumerated(" ", stringList), std::runtime_error); // empty name
-    BOOST_REQUIRE_THROW(RepeatEnumerated("*", stringList), std::runtime_error); // illegal name
-    BOOST_REQUIRE_THROW(RepeatEnumerated("AEnum", empty), std::runtime_error);  // empty enumerations
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat_enumerated
-
-/*
- * Test Suite: ::test_repeat_integer
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat_integer)
-
-BOOST_AUTO_TEST_CASE(invariants) {
-    cout << "ANattr:: ...test_repeat_integer::invariants\n";
-
-    {
-        Repeat rep(RepeatInteger("rep", 0, 100, 1));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "rep", "name not as expected");
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "0", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "1", "not as expected");
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "0", "not as expected");
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(cloned.name() == "rep", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.start() == 0, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.end() == 100, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.value() == 0, "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "0", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "1", "not as expected");
-        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "0", "not as expected");
-
-        RepeatInteger empty;
-        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
-        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
-        BOOST_CHECK_MESSAGE(empty.step() == 0, "default step should be 0 but found" << empty.step());
-        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
-        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
-        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
-        BOOST_CHECK_MESSAGE(empty.valueAsString() == "0", "not as expected");
-        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "0", "not as expected");
-        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "0", "not as expected");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(construction) {
-    cout << "ANattr:: ...test_repeat_integer::construction\n";
-
-    Repeat empty;
-
-    {
-        Repeat l1(RepeatInteger("rep", 0, 100, 1));
-        Repeat l2(RepeatInteger("rep", 0, 100, 1));
-        BOOST_CHECK_MESSAGE(!l1.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(!l2.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
-        BOOST_CHECK_MESSAGE(!(l1 == empty), "Equality failed");
-
-        l1.clear();
-        l2.clear();
-
-        BOOST_CHECK_MESSAGE(l1 == empty, "Clear failed");
-        BOOST_CHECK_MESSAGE(l2 == empty, "Clear failed");
-    }
-
-    {
-        Repeat l1(RepeatInteger("rep", 0, 100, 1));
-        Repeat lf;
-        lf = l1;
-        BOOST_CHECK_MESSAGE(l1 == lf, "Assignment failed");
-    }
-
-    {
-        Repeat l1(RepeatInteger("rep", 0, 100, 1));
-        Repeat lf = l1;
-        BOOST_CHECK_MESSAGE(l1 == lf, "Copy construction failed");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(last_value) {
-    cout << "ANattr:: ...test_repeat_integer::last_value \n";
-
-    {
-        Repeat rep(RepeatInteger("integer", 0, 10, 1));
-        rep.setToLastValue();
-        BOOST_CHECK_MESSAGE(rep.value() == 10, "Set to last value did not work, expected 10 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "0", " Expected '0' but found " << rep.value_as_string(0));
-        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "1", " Expected '1' but found " << rep.value_as_string(1));
-        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "2", " Expected '2' but found " << rep.value_as_string(2));
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "10",
-                            "next_value_as_string() did not work, expected 10 but found "
-                                << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "9",
-                            "prev_value_as_string() did not work, expected 9 but found " << rep.prev_value_as_string());
-    }
-    {
-        Repeat rep(RepeatInteger("integer", 10, 0, -1));
-        rep.setToLastValue();
-        BOOST_CHECK_MESSAGE(rep.value() == 0, "Set to last value did not work, expected 0 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "0", " Expected '0' but found " << rep.value_as_string(0));
-        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "1", " Expected '1' but found " << rep.value_as_string(1));
-        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "2", " Expected '2' but found " << rep.value_as_string(2));
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "0",
-                            "next_value_as_string() did not work, expected 0 but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "1",
-                            "prev_value_as_string() did not work, expected 1 but found " << rep.prev_value_as_string());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(increment) {
-    cout << "ANattr:: ...test_repeat_integer::increment \n";
-
-    Repeat rep(RepeatInteger("integer", 0, 10, 1));
-    while (rep.valid()) {
-        rep.increment();
-    }
-    BOOST_CHECK_MESSAGE(rep.value() == 11, " Expected 11 but found " << rep.value());
-    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 10, " Expected 10 but found " << rep.last_valid_value());
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat_integer
-
-/*
- * Test Suite: ::test_repeat_day
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat_day)
-
-BOOST_AUTO_TEST_CASE(invariants) {
-    cout << "ANattr:: ...test_repeat_day::invariants\n";
-
-    {
-        Repeat rep(RepeatDay(2));
-        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
-        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
-        BOOST_CHECK_MESSAGE(rep.name() == "day", "name not as expected");
-
-        Repeat cloned = Repeat(rep);
-        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
-        BOOST_CHECK_MESSAGE(cloned.name() == "day", "name not as expected");
-        BOOST_CHECK_MESSAGE(cloned.step() == 2, "step not as expected");
-
-        RepeatDay empty;
-        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
-        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
-        BOOST_CHECK_MESSAGE(empty.step() == 1, "default step should be 0 but found " << empty.step());
-        BOOST_CHECK_MESSAGE(empty.value() == 1, "value should be 0 but found " << empty.value());
-        BOOST_CHECK_MESSAGE(empty.name() == "day", "name not as expected");
-        BOOST_CHECK_MESSAGE(empty.valueAsString() == "", "not as expected");
-        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "", "not as expected");
-        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "", "not as expected");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat_day
-
-/*
- * Test Suite: ::test_repeat_string
- * ************************************************************ */
-
-BOOST_AUTO_TEST_SUITE(test_repeat_string)
-
-BOOST_AUTO_TEST_CASE(construction) {
-    cout << "ANattr:: ...test_repeat_string::construction\n";
-
-    Repeat empty;
-
-    {
-        Repeat l1(RepeatString("RepeatString", stringList));
-        Repeat l2(RepeatString("RepeatString", stringList));
-        BOOST_CHECK_MESSAGE(!l1.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(!l2.empty(), "Construction failed");
-        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
-        BOOST_CHECK_MESSAGE(!(l2 == empty), "Equality failed");
-
-        l1.clear();
-        l2.clear();
-
-        BOOST_CHECK_MESSAGE(l1 == empty, "Clear failed");
-        BOOST_CHECK_MESSAGE(l2 == empty, "Clear failed");
-    }
-
-    {
-        Repeat l1(RepeatString("RepeatString", stringList));
-        Repeat l2;
-        l2 = l1;
-        BOOST_CHECK_MESSAGE(l1 == l2, "Assignment failed");
-    }
-
-    {
-        Repeat l1(RepeatString("RepeatString", stringList));
-        Repeat l2 = l1;
-        BOOST_CHECK_MESSAGE(l1 == l2, "Copy construction failed");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(last_value) {
-    cout << "ANattr:: ...test_repeat_string::last_value \n";
-
-    {
-        Repeat rep(RepeatString("Str", stringList));
-        rep.setToLastValue();
-        BOOST_CHECK_MESSAGE(rep.value() == 2, "Set to last value did not work, expected 2 but found " << rep.value());
-        BOOST_CHECK_MESSAGE(rep.valueAsString() == "c",
-                            "Set to last value did not work, expected 'c' but found " << rep.valueAsString());
-        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "a", " Expected 'a' but found " << rep.value_as_string(0));
-        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "b", " Expected 'b' but found " << rep.value_as_string(1));
-        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "c", " Expected 'c' but found " << rep.value_as_string(2));
-        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "c",
-                            "next_value_as_string() did not work, expected c but found " << rep.next_value_as_string());
-        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "b",
-                            "prev_value_as_string() did not work, expected b but found " << rep.prev_value_as_string());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(increment) {
-    cout << "ANattr:: ...test_repeat_string::increment \n";
-
-    Repeat rep(RepeatString("Str", stringList));
-    while (rep.valid()) {
-        rep.increment();
-    }
-    BOOST_CHECK_MESSAGE(rep.value() == 3, " Expected 3 but found " << rep.value());
-    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 2, " Expected 2 but found " << rep.last_valid_value());
-}
-
-BOOST_AUTO_TEST_CASE(handling_errors) {
-    cout << "ANattr:: ...test_repeat_string::handling_errors \n";
-
-    const std::vector<std::string> empty;
-    const std::vector<std::string> stringList = {"a", "b"};
-
-    BOOST_REQUIRE_THROW(RepeatString("", stringList), std::runtime_error);          // empty name
-    BOOST_REQUIRE_THROW(RepeatString(" ", stringList), std::runtime_error);         // empty name
-    BOOST_REQUIRE_THROW(RepeatString("!£$%^&*()", stringList), std::runtime_error); // illegal name
-    BOOST_REQUIRE_THROW(RepeatString("AEnum", empty), std::runtime_error);          // empty string list
-}
-
-BOOST_AUTO_TEST_SUITE_END() // test_repeat_string
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestSizeOf.cpp 5.13.0-1/ANattr/test/TestSizeOf.cpp
--- 5.12.4-1/ANattr/test/TestSizeOf.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestSizeOf.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace boost;
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_SizeOf)
-
-BOOST_AUTO_TEST_CASE(test_size_of) {
-    cout << "ACore:: ...test_size_of\n";
-    cout << "   sizeof(std::ofstream)      " << sizeof(std::ofstream) << "\n";
-    cout << "   sizeof(std::string)        " << sizeof(std::string) << "\n";
-    cout << "   sizeof(vector<int>)        " << sizeof(std::vector<int>) << "\n";
-    cout << "   sizeof(vector<string>)     " << sizeof(vector<string>) << "\n";
-    cout << "   sizeof(std::weak_ptr<int>) " << sizeof(std::weak_ptr<int>) << "\n";
-    cout << "   sizeof(nullptr)            " << sizeof(nullptr) << "\n";
-    cout << "   sizeof(unique_ptr)         " << sizeof(unique_ptr<int>) << "\n";
-    cout << "   sizeof(double)             " << sizeof(double) << "\n";
-    cout << "   sizeof(long)               " << sizeof(long) << "\n";
-    cout << "   sizeof(int)                " << sizeof(int) << "\n";
-    cout << "   sizeof(unsigned int)       " << sizeof(unsigned int) << "\n";
-    cout << "   sizeof(bool)               " << sizeof(bool) << "\n";
-    cout << "   sizeof(TimeSeries)         " << sizeof(ecf::TimeSeries) << "\n";
-    cout << "   sizeof(DayAttr)            " << sizeof(DayAttr) << "\n";
-
-    BOOST_CHECK_MESSAGE(true, "Dummy");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestTimeAttr.cpp 5.13.0-1/ANattr/test/TestTimeAttr.cpp
--- 5.12.4-1/ANattr/test/TestTimeAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestTimeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,450 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/date_time/posix_time/time_formatters.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/TimeAttr.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_TimeAttr)
-
-BOOST_AUTO_TEST_CASE(test_time_string_constrcutor) {
-    cout << "ANattr:: ...test_time_string_constrcutor\n";
-    {
-        TimeAttr time("+00:30");
-        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
-                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
-                                time.time_series().relative(),
-                            "Error in time constructor");
-    }
-    {
-        TimeAttr time("12:30");
-        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 12 && time.time_series().start().minute() == 30 &&
-                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
-                                !time.time_series().relative(),
-                            "Error in time constructor");
-    }
-    {
-        TimeAttr time("+00:30 11:30 00:01");
-        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
-                                time.time_series().finish().hour() == 11 &&
-                                time.time_series().finish().minute() == 30 && time.time_series().incr().hour() == 0 &&
-                                time.time_series().incr().minute() == 1 && time.time_series().relative(),
-                            "Error in time constructor");
-    }
-    {
-        BOOST_REQUIRE_THROW(TimeAttr(""), std::runtime_error);
-        BOOST_REQUIRE_THROW(TimeAttr(" "), std::runtime_error);
-        BOOST_REQUIRE_THROW(TimeAttr("sdsdsdsd"), std::runtime_error);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_attr) {
-    cout << "ANattr:: ...test_time_attr\n";
-
-    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
-    // test time attr isFree(), and checkForRequeue
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series. Need to sync hour with suite time
-    // at hour 1, suite time should also be 01:00, for test to work
-    //
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr    1:00
-    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
-    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
-
-    TimeSlot t1_min, t1_max, t2_min, t2_max, t3_min, t3_max, t4_min, t4_max;
-    timeSeriesX.min_max_time_slots(t1_min, t1_max);
-    timeSeries2X.min_max_time_slots(t2_min, t2_max);
-    timeSeries3X.min_max_time_slots(t3_min, t3_max);
-    timeSeries4X.min_max_time_slots(t4_min, t4_max);
-    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(20, 0), "Not as expected");
-    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(11, 0) && t2_max == TimeSlot(15, 0), "Not as expected");
-    BOOST_CHECK_MESSAGE(t3_min == TimeSlot(15, 0) && t3_max == TimeSlot(15, 0), "Not as expected");
-    BOOST_CHECK_MESSAGE(t4_min == TimeSlot(0, 0) && t4_max == TimeSlot(0, 0), "Not as expected");
-
-    TimeAttr timeSeries(timeSeriesX);
-    TimeAttr timeSeries2(timeSeries2X);
-    TimeAttr timeSeries3(timeSeries3X);
-    TimeAttr timeSeries4(timeSeries4X);
-
-    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
-    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
-    timeSeries.time_series().free_slots(timeSeries_free_slots);
-    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
-    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
-                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
-                                                      << timeSeries_free_slots.size());
-    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
-                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
-                                                     << timeSeries_free_slots.size());
-    //   cout << "time " << timeSeries.toString() << " free slots:";
-    //   for(size_t i = 0; i < timeSeries_free_slots.size(); i++)  cout << timeSeries_free_slots[i] << " ";
-    //   cout << "\n";
-
-    // follow normal process
-    timeSeries.reset(calendar);
-    timeSeries2.reset(calendar);
-    timeSeries3.reset(calendar);
-    timeSeries4.reset(calendar);
-
-    bool cmd_context = true;
-    bool day_changed = false; // after midnight make sure we keep day_changed
-    for (int m = 1; m < 96; m++) {
-        calendar.update(time_duration(minutes(30)));
-        if (!day_changed)
-            day_changed = calendar.dayChanged();
-
-        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
-        // cout << time << " day_changed(" << day_changed << ")\n";
-
-        timeSeries.calendarChanged(calendar);
-        timeSeries2.calendarChanged(calendar);
-        timeSeries3.calendarChanged(calendar);
-        timeSeries4.calendarChanged(calendar);
-
-        // cout << to_simple_string(calendar.suiteTime()) << "\n";
-
-        if (calendar.dayChanged()) {
-            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                " expected " << timeSeries.toString() << " checkForRequeue to fail at "
-                                             << to_simple_string(calendar.suiteTime()));
-            BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max, cmd_context),
-                                " expected " << timeSeries.toString() << " checkForRequeue to pass at "
-                                             << to_simple_string(calendar.suiteTime()));
-        }
-        else if (time < timeSeries.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                timeSeries.toString() << " should NOT be free at time " << time);
-            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                timeSeries.toString() << " checkForRequeue should fail at " << time);
-            BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max, cmd_context),
-                                timeSeries.toString() << " checkForRequeue should pass at " << time);
-        }
-        else if (time >= timeSeries.time_series().start().duration() &&
-                 time <= timeSeries.time_series().finish().duration()) {
-
-            bool matches_free_slot = false;
-            for (const auto& timeSeries_free_slot : timeSeries_free_slots) {
-                if (time == timeSeries_free_slot) {
-                    matches_free_slot = true;
-                    break;
-                }
-            }
-            if (matches_free_slot)
-                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be fail at time " << time);
-
-            /// At the last hour checkForRequeue should return false; This ensures that value will
-            /// not get incremented and so, should leave node in the complete state.
-            if (time < timeSeries.time_series().finish().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries.toString() << " checkForRequeue should be free at time " << time);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries.toString() << "checkForRequeue should Not free at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                timeSeries.toString() << " should be holding at time " << time);
-            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                timeSeries.toString() << " should fail at " << time);
-        }
-
-        if (calendar.dayChanged()) {
-            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
-                                             << to_simple_string(calendar.suiteTime()));
-        }
-        else if (time < timeSeries2.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                timeSeries2.toString() << " should NOT be free at time " << time);
-            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                timeSeries2.toString() << " checkForRequeue should pass at " << time);
-        }
-        else if (time >= timeSeries2.time_series().start().duration() &&
-                 time <= timeSeries2.time_series().finish().duration()) {
-
-            bool matches_free_slot = false;
-            for (const auto& timeSeries2_free_slot : timeSeries2_free_slots) {
-                if (time == timeSeries2_free_slot) {
-                    matches_free_slot = true;
-                    break;
-                }
-            }
-            if (matches_free_slot)
-                BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should be fail at time " << time);
-
-            /// At the last time checkForRequeue should return false; This ensures that value will
-            /// not get incremented and so, should leave node in the complete state.
-            if (time < timeSeries2.time_series().finish().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    timeSeries2.toString() << " checkForRequeue should be free at time " << time);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    timeSeries2.toString() << "checkForRequeue should Not free at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                timeSeries2.toString() << " should be holding at time " << time);
-            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                timeSeries2.toString() << " should fail at " << time);
-        }
-
-        // Single slot, Once a single slot is Free it *stays* free until explicitly requeued, (i.e by parent
-        // repeat/cron)
-        if (!day_changed) {
-            if (time < timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(!timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " should be fail at time " << time);
-            }
-            else if (time == timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " should be free at time " << time);
-            }
-            else if (time > timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " isFree should pass at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                timeSeries3.toString() << " should be free at time after day change" << time);
-        }
-        BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(calendar, t3_min, t3_max),
-                            timeSeries3.toString() << " checkForRequeue should fail at " << time);
-
-        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
-        // repeat/cron)
-        if (!day_changed) {
-            if (time == timeSeries4.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                    timeSeries4.toString() << " should be free at time " << time);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
-                                    timeSeries4.toString()
-                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                timeSeries4.toString()
-                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
-        }
-        BOOST_CHECK_MESSAGE(!timeSeries4.checkForRequeue(calendar, t4_min, t4_max),
-                            timeSeries4.toString() << " checkForRequeue should fail at " << time);
-
-        // Typically when a time is free, it stays free, until it is re-queued
-        // However in order to test isFree for time with time intervals, we need to re-queue
-        timeSeries.requeue(calendar);
-        timeSeries2.requeue(calendar);
-
-        // Do not requeue time 00, and time 15, so that we can check for free
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_once_free_stays_free) {
-    cout << "ANattr:: ...test_time_once_free_stays_free\n";
-
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
-    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
-
-    TimeAttr timeSeries(timeSeriesX);
-    TimeAttr timeSeries2(timeSeries2X);
-    TimeAttr timeSeries3(timeSeries3X);
-    TimeAttr timeSeries4(timeSeries4X);
-
-    bool day_changed = false; // after midnight make sure we keep day_changed
-    for (int m = 1; m < 96; m++) {
-        calendar.update(time_duration(minutes(30)));
-        if (!day_changed) {
-            day_changed = calendar.dayChanged();
-        }
-        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
-        // cout << time << " day_changed(" << day_changed << ")\n";
-
-        timeSeries.calendarChanged(calendar);
-        timeSeries2.calendarChanged(calendar);
-        timeSeries3.calendarChanged(calendar);
-        timeSeries4.calendarChanged(calendar);
-
-        // **********************************************************************************
-        // When a time (regardless of whether its single slot or time series) is free, it stays free,
-        // until explicitly re-queued,
-        // ***********************************************************************************
-
-        if (time < timeSeries.time_series().start().duration()) {
-            if (!day_changed)
-                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should NOT be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be free at time " << time);
-        }
-        else if (time >= timeSeries.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                timeSeries.toString() << " should be free at time " << time);
-        }
-
-        if (time < timeSeries2.time_series().start().duration()) {
-            if (!day_changed)
-                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should NOT be free at time " << time);
-            else
-                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be free at time " << time);
-        }
-        else if (time >= timeSeries2.time_series().start().duration()) {
-            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                timeSeries2.toString() << " should be free at time " << time);
-        }
-
-        if (!day_changed) {
-            if (time == timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " should be free at time " << time);
-            }
-            else if (time > timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " isFree, once free should stay free at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                timeSeries3.toString() << " should be free at time after day change " << time);
-        }
-
-        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
-        // repeat/cron)
-        if (!day_changed) {
-            if (time == timeSeries4.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                    timeSeries4.toString() << " should be free at time " << time);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
-                                    timeSeries4.toString()
-                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
-            }
-        }
-        else {
-            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
-                                timeSeries4.toString()
-                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_time_attr_multiples) {
-    cout << "ANattr:: ...test_time_attr_multiples\n";
-
-    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
-    // test time attr isFree(), and checkForRequeue
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    TimeSeries timeSeries1530(TimeSlot(15, 30), false /* relative */);
-    TimeSeries timeSeries1630(TimeSlot(16, 30), false /* relative */);
-    TimeSeries timeSeries2030(TimeSlot(20, 30), false /* relative */);
-
-    TimeSlot t1_min, t1_max;
-    timeSeries1530.min_max_time_slots(t1_min, t1_max);
-    timeSeries1630.min_max_time_slots(t1_min, t1_max);
-    timeSeries2030.min_max_time_slots(t1_min, t1_max);
-    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(15, 30) && t1_max == TimeSlot(20, 30), "Not as expected");
-
-    TimeAttr timeSeries(timeSeries1530);
-    TimeAttr timeSeries2(timeSeries1630);
-    TimeAttr timeSeries3(timeSeries2030);
-
-    bool day_changed = false; // after midnight make sure we keep day_changed
-    for (int m = 1; m < 96; m++) {
-        calendar.update(time_duration(minutes(30)));
-        if (!day_changed) {
-            day_changed = calendar.dayChanged();
-        }
-        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
-        //      cout << time << " day_changed(" << day_changed << ")\n";
-
-        timeSeries.calendarChanged(calendar);
-        timeSeries2.calendarChanged(calendar);
-        timeSeries3.calendarChanged(calendar);
-
-        if (!day_changed) {
-            if (time >= t1_min.duration() && time < t1_max.duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries.toString() << " checkForRequeue should pass at " << time);
-                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries2.toString() << " checkForRequeue should pass at " << time);
-                BOOST_CHECK_MESSAGE(timeSeries3.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries3.toString() << " checkForRequeue should pass at " << time);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries.toString() << " checkForRequeue should fail at " << time);
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries2.toString() << " checkForRequeue should fail at " << time);
-                BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries3.toString() << " checkForRequeue should fail at " << time);
-            }
-        }
-        else {
-            // Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent repeat/cron)
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                timeSeries.toString()
-                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
-            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                timeSeries2.toString()
-                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
-            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                timeSeries2.toString()
-                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestTodayAttr.cpp 5.13.0-1/ANattr/test/TestTodayAttr.cpp
--- 5.12.4-1/ANattr/test/TestTodayAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestTodayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,244 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_TodayAttr)
-
-BOOST_AUTO_TEST_CASE(test_today_string_constrcutor) {
-    cout << "ANattr:: ...test_today_string_constrcutor\n";
-    {
-        TodayAttr time("+00:30");
-        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
-                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
-                                time.time_series().relative(),
-                            "Error in today constructor");
-    }
-    {
-        TodayAttr time("12:30");
-        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 12 && time.time_series().start().minute() == 30 &&
-                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
-                                !time.time_series().relative(),
-                            "Error in today constructor");
-    }
-    {
-        TodayAttr time("+00:30 11:30 00:01");
-        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
-                                time.time_series().finish().hour() == 11 &&
-                                time.time_series().finish().minute() == 30 && time.time_series().incr().hour() == 0 &&
-                                time.time_series().incr().minute() == 1 && time.time_series().relative(),
-                            "Error in today constructor");
-    }
-    {
-        BOOST_REQUIRE_THROW(TodayAttr(""), std::runtime_error);
-        BOOST_REQUIRE_THROW(TodayAttr(" "), std::runtime_error);
-        BOOST_REQUIRE_THROW(TodayAttr("sdsdsdsd"), std::runtime_error);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_today_attr) {
-    cout << "ANattr:: ...test_today_attr\n";
-
-    // See TodayAttr.hpp for rules concerning isFree() and checkForReque()
-    // test today attr isFree(), and checkForRequeue
-    Calendar calendar;
-    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
-
-    // Create a test when we can match a time series. Need to sync hour with suite time
-    // at hour 1, suite time should also be 01:00, for test to work
-    //
-    // Create the time series: start  10:00
-    //                         finish 20:00
-    //                         incr    1:00
-    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
-    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
-
-    TimeSlot t1_min, t1_max, t2_min, t2_max, t3_min, t3_max;
-    timeSeriesX.min_max_time_slots(t1_min, t1_max);
-    timeSeries2X.min_max_time_slots(t2_min, t2_max);
-    timeSeries3X.min_max_time_slots(t3_min, t3_max);
-    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(20, 0), "Not as expected");
-    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(11, 0) && t2_max == TimeSlot(15, 0), "Not as expected");
-    BOOST_CHECK_MESSAGE(t3_min == TimeSlot(15, 0) && t3_max == TimeSlot(15, 0), "Not as expected");
-
-    TodayAttr timeSeries(timeSeriesX);
-    TodayAttr timeSeries2(timeSeries2X);
-    TodayAttr timeSeries3(timeSeries3X);
-
-    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
-    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
-    timeSeries.time_series().free_slots(timeSeries_free_slots);
-    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
-    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
-                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
-                                                      << timeSeries_free_slots.size());
-    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
-                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
-                                                     << timeSeries_free_slots.size());
-
-    // follow normal process
-    timeSeries.reset(calendar);
-    timeSeries2.reset(calendar);
-    timeSeries3.reset(calendar);
-
-    bool cmd_context = true;
-    bool day_changed = false; // after midnight make sure we keep day_changed
-    for (int m = 1; m < 96; m++) {
-        calendar.update(time_duration(minutes(30)));
-        if (!day_changed) {
-            day_changed = calendar.dayChanged();
-        }
-        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
-        //      cout << time << " day_changed(" << day_changed << ")\n";
-
-        timeSeries.calendarChanged(calendar);
-        timeSeries2.calendarChanged(calendar);
-        timeSeries3.calendarChanged(calendar);
-
-        if (!day_changed) {
-
-            if (time < timeSeries.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should NOT be free at time " << time);
-                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries.toString() << " should pass at " << time);
-                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max, cmd_context),
-                                    timeSeries.toString() << " should pass at " << time);
-            }
-            else if (time >= timeSeries.time_series().start().duration() &&
-                     time <= timeSeries.time_series().finish().duration()) {
-
-                bool matches_free_slot = false;
-                for (const auto& timeSeries_free_slot : timeSeries_free_slots) {
-                    if (time == timeSeries_free_slot) {
-                        matches_free_slot = true;
-                        break;
-                    }
-                }
-                // no else branch since once today is free it stays free, unti re-queue
-                if (matches_free_slot)
-                    BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                        timeSeries.toString() << " should be free at time " << time);
-
-                /// At the last time checkForRequeue should return false; This ensures that value will
-                /// not get incremented and so, should leave node in the complete state.
-                if (time < timeSeries.time_series().finish().duration()) {
-                    BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                        timeSeries.toString() << " checkForRequeue should be free at time " << time);
-                }
-                else {
-                    BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                        timeSeries.toString() << "checkForRequeue should Not free at time " << time);
-                }
-            }
-            else {
-                // After end time, a Today Attr should be free to run.
-                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                    timeSeries.toString() << " should be free at time " << time);
-                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
-                                    timeSeries.toString() << " should fail at " << time);
-            }
-        }
-        else {
-            // Once a today time series is free, it stays free
-            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
-                                timeSeries.toString() << " should be free at time " << time);
-        }
-
-        if (!day_changed) {
-            if (time < timeSeries2.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should NOT be free at time " << time);
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    timeSeries2.toString() << " should pass at " << time);
-            }
-            else if (time >= timeSeries2.time_series().start().duration() &&
-                     time <= timeSeries2.time_series().finish().duration()) {
-
-                bool matches_free_slot = false;
-                for (const auto& timeSeries2_free_slot : timeSeries2_free_slots) {
-                    if (time == timeSeries2_free_slot) {
-                        matches_free_slot = true;
-                        break;
-                    }
-                }
-                if (matches_free_slot)
-                    BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                        timeSeries2.toString() << " should be free at time " << time);
-
-                /// At the last time checkForRequeue should return false; This ensures that value will
-                /// not get incremented and so, should leave node in the complete state.
-                if (time < timeSeries2.time_series().finish().duration()) {
-                    BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                        timeSeries2.toString() << " checkForRequeue should be free at time " << time);
-                }
-                else {
-                    BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                        timeSeries2.toString() << "checkForRequeue should Not free at time " << time);
-                }
-            }
-            else {
-                // After end time, a Today Attr should be free to run.
-                BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                    timeSeries2.toString() << " should be holding at time " << time);
-                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
-                                    timeSeries2.toString() << " should fail at " << time);
-            }
-        }
-        else {
-            // Once a today time series is free, it stays free
-            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
-                                timeSeries2.toString() << " should be holding at time " << time);
-        }
-
-        // Single slot
-        if (!day_changed) {
-            if (time == timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " should be free at time " << time);
-            }
-            else if (time < timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(!timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " isFree should fail at time " << time);
-            }
-            else if (time > timeSeries3.time_series().start().duration()) {
-                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                    timeSeries3.toString() << " isFree should fail at time " << time);
-            }
-        }
-        else {
-            // Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent repeat/cron)
-            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
-                                timeSeries3.toString() << " isFree should fail at time " << time);
-        }
-        BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(calendar, t3_min, t3_max),
-                            timeSeries3.toString() << " checkForRequeue should fail at " << time);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestVariable.cpp 5.13.0-1/ANattr/test/TestVariable.cpp
--- 5.12.4-1/ANattr/test/TestVariable.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestVariable.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,103 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdio>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/Variable.hpp"
-
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_Variable)
-
-BOOST_AUTO_TEST_CASE(test_multi_line_variable_values) {
-    cout << "ANattr:: ...test_multi_line_variable_values\n";
-
-    {
-        Variable var("name", "value");
-        BOOST_CHECK_MESSAGE(var.name() == "name", "name not as expected");
-        BOOST_CHECK_MESSAGE(var.theValue() == "value", "value not as expected");
-
-        std::string expected = "edit name 'value'";
-        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
-    }
-    {
-        Variable var("name", "");
-        std::string expected = "edit name ''";
-        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
-    }
-    {
-        Variable var("name", "value\n");
-        std::string expected = "edit name 'value\\n'";
-        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
-    }
-    {
-        Variable var("name", "val1\nxxx\nval2");
-        std::string expected = "edit name 'val1\\nxxx\\nval2'";
-        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_variable_value) {
-    cout << "ANattr:: ...test_variable_value\n";
-
-    std::vector<std::string> values;
-    values.emplace_back("sdsd");
-    values.emplace_back("0fred0");
-    values.emplace_back("fted");
-    values.emplace_back("%value%");
-    values.emplace_back("a");
-    values.emplace_back("");
-    values.emplace_back("0");
-    values.emplace_back("00");
-    values.emplace_back("000");
-    values.emplace_back("0000");
-    values.emplace_back("0000000000000");
-    for (const auto& value : values) {
-        Variable var("name", "");
-        var.set_value(value);
-        BOOST_CHECK_MESSAGE(var.value() == 0, "expected 0 but found " << var.value() << " for " << value);
-    }
-
-    {
-        Variable var("name", "0100");
-        BOOST_CHECK_MESSAGE(var.value() == 100, "expected 100 but found " << var.value());
-    }
-    {
-        Variable var("name", "0001");
-        BOOST_CHECK_MESSAGE(var.value() == 1, "expected 1 but found " << var.value());
-    }
-    {
-        Variable var("name", "2359");
-        BOOST_CHECK_MESSAGE(var.value() == 2359, "expected 2359 but found " << var.value());
-    }
-
-    // make sure time is convertible to an integer
-    constexpr int buff_size = 255;
-    char smstime[buff_size];
-    for (int h = 0; h < 24; h++) {
-        for (int m = 1; m < 60; m++) {
-            int output_written = snprintf(smstime, buff_size, "%02d%02d", h, m);
-            BOOST_CHECK_MESSAGE(output_written == 4, " expected size 4 but found " << output_written);
-            Variable var("name", "");
-            var.set_value(smstime);
-            int value = stoi(string(smstime));
-            BOOST_CHECK_MESSAGE(var.value() == value, "expected " << value << " but found " << var.value());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestVariableMap.cpp 5.13.0-1/ANattr/test/TestVariableMap.cpp
--- 5.12.4-1/ANattr/test/TestVariableMap.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestVariableMap.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-/*
- * Copyright 2023- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/Variable.hpp"
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_VariableMap)
-
-BOOST_AUTO_TEST_CASE(test_variablemap_is_able_to_create_empty_variable_map) {
-    VariableMap empty;
-
-    BOOST_CHECK(empty.empty());
-    BOOST_CHECK(empty.size() == 0);
-}
-
-BOOST_AUTO_TEST_CASE(test_variablemap_is_able_to_create_variable_map) {
-    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
-
-    BOOST_CHECK(!variables.empty());
-    BOOST_CHECK(variables.size() == 3);
-}
-
-BOOST_AUTO_TEST_CASE(test_variablemap_is_able_set_value_to_all_variables_in_variable_map) {
-    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
-
-    std::string value = "some large value just for precaution!";
-    // set value of all variables
-    variables.set_value(value);
-
-    for (const auto& variable : variables) {
-        BOOST_CHECK(variable.theValue() == value);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_variablemap_is_able_to_access_variable_in_variable_map) {
-    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
-
-    const Variable& variable = variables["n1"];
-
-    BOOST_CHECK(variable.name() == "n1");
-    BOOST_CHECK(variable.theValue() == "v1");
-}
-
-BOOST_AUTO_TEST_CASE(test_variablemap_throws_when_accessing_inexistent_variable_in_variable_map) {
-    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
-
-    Variable found;
-    BOOST_CHECK_EXCEPTION(
-        found = variables["nX"], std::runtime_error, [](const std::runtime_error& e) { return true; });
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/TestZombieAttr.cpp 5.13.0-1/ANattr/test/TestZombieAttr.cpp
--- 5.12.4-1/ANattr/test/TestZombieAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/TestZombieAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,131 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/ZombieAttr.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Attributes)
-
-BOOST_AUTO_TEST_SUITE(T_ZombieAttr)
-
-BOOST_AUTO_TEST_CASE(test_zombie_attr) {
-    cout << "ANattr:: ...test_zombie_attr\n";
-    {
-        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL);
-        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
-                            "expected " << ZombieAttr::default_ecf_zombie_life_time() << " but got "
-                                        << ecf.zombie_lifetime());
-
-        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL);
-        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
-                            "Zombie life time not as expected");
-
-        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL);
-        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
-                            "Zombie life time not as expected");
-    }
-    {
-        int zombie_life_time = 0;
-        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
-                            "Zombie life time not as expected");
-
-        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
-                            "Zombie life time not as expected");
-
-        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
-                            "Zombie life time not as expected");
-    }
-    {
-        int zombie_life_time = -1;
-        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
-                            "Zombie life time not as expected");
-
-        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
-                            "Zombie life time not as expected");
-
-        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
-                            "Zombie life time not as expected");
-    }
-    {
-        int zombie_life_time = 29;
-        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
-                            "Zombie life time not as expected");
-
-        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
-                            "Zombie life time not as expected");
-
-        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
-        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
-                            "Zombie life time not as expected");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_zombie_attr_parsing) {
-    cout << "ANattr:: ...test_zombie_attr_parsing\n";
-    {
-        ZombieAttr zombie = ZombieAttr::create("user:fob::");
-        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::USER, "Type not as expected");
-        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FOB, "action not as expected");
-        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
-                            "Zombie life time not as expected");
-        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
-    }
-    {
-        ZombieAttr zombie = ZombieAttr::create("ecf:fail::");
-        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::ECF, "Type not as expected");
-        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FAIL, "action not as expected");
-        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
-                            "Zombie life time not as expected");
-        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
-    }
-    {
-        ZombieAttr zombie = ZombieAttr::create("path:fail::");
-        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::PATH, "Type not as expected");
-        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FAIL, "action not as expected");
-        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
-                            "Zombie life time not as expected");
-        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
-    }
-
-    {
-        ZombieAttr zombie = ZombieAttr::create("user:fob::29");
-        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::USER, "Type not as expected");
-        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FOB, "action not as expected");
-        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
-                            "Zombie life time < 60, should default to 60");
-        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
-    }
-    {
-        ZombieAttr zombie = ZombieAttr::create("user:fob:init:29");
-        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::USER, "Type not as expected");
-        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FOB, "action not as expected");
-        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
-                            "Zombie life time < 60, should default to 60");
-        BOOST_CHECK_MESSAGE(zombie.child_cmds().size() == 1, "Expected one child");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf15AutoArchiveAttrE":{"cereal_class_version":0,"time_":{"h_":2400,"m_":0},"days_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr_1 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr_1
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr_1	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoArchiveAttr_1	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf15AutoArchiveAttrE":{"cereal_class_version":0,"time_":{"h_":10,"m_":12}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf14AutoCancelAttrE":{"cereal_class_version":0,"time_":{"h_":2400,"m_":0},"days_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr_1 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr_1
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr_1	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/AutoCancelAttr_1	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf14AutoCancelAttrE":{"cereal_class_version":0,"time_":{"h_":10,"m_":12}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/ClockAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/ClockAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/ClockAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/ClockAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"9ClockAttr":{"cereal_class_version":0,"hybrid_":false,"positiveGain_":true,"gain_":3600,"day_":1,"month_":1,"year_":2009}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/CronAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/CronAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/CronAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/CronAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8CronAttrE":{"cereal_class_version":0,"timeSeries_":{"cereal_class_version":0,"start_":{"h_":0,"m_":0},"finish_":{"h_":20,"m_":0},"incr_":{"h_":0,"m_":1}},"weekDays_":[1,2],"daysOfMonth_":[1,2],"months_":[1,2]}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/DateAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/DateAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/DateAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/DateAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"8DateAttr":{"day_":12,"month_":12,"year_":2012}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/DayAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/DayAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/DayAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/DayAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"7DayAttr":{"day_":1}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/Event_1 5.13.0-1/ANattr/test/data/migration/1_2_2/Event_1
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/Event_1	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/Event_1	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Event":{"number_":1}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/Event_2 5.13.0-1/ANattr/test/data/migration/1_2_2/Event_2
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/Event_2	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/Event_2	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Event":{"n_":"event"}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/Event_3 5.13.0-1/ANattr/test/data/migration/1_2_2/Event_3
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/Event_3	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/Event_3	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Event":{"n_":"event","number_":1,"v_":true,"iv_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/GenericAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/GenericAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/GenericAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/GenericAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"11GenericAttr":{"name_":"gen1","values_":["a","b"]}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/Label 5.13.0-1/ANattr/test/data/migration/1_2_2/Label
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/Label	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/Label	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Label":{"n_":"name","v_":"value","new_v_":"new_value"}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/LateAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/LateAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/LateAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/LateAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8LateAttrE":{"s_":{"h_":10,"m_":12},"a_":{"h_":10,"m_":12},"c_":{"h_":10,"m_":12},"c_is_rel_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/Meter 5.13.0-1/ANattr/test/data/migration/1_2_2/Meter
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/Meter	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/Meter	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Meter":{"min_":10,"max_":100,"v_":10,"n_":"meter","cc_":100}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/QueueAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/QueueAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/QueueAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/QueueAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"9QueueAttr":{"cereal_class_version":0,"theQueue_":["a","b"],"state_vec_":[2,2],"name_":"queue","currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatDate 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatDate
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatDate	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatDate	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"10RepeatDate":{"cereal_class_version":0,"value0":{"name_":"date"},"start_":20110112,"end_":20110115,"delta_":1,"value_":20110112}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatDateList 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatDateList
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatDateList	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatDateList	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"14RepeatDateList":{"cereal_class_version":0,"value0":{"name_":"datelist"},"list_":[19990101,19990102],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatEnumerated 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatEnumerated
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatEnumerated	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatEnumerated	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"16RepeatEnumerated":{"cereal_class_version":0,"value0":{"name_":"enum"},"theEnums_":["a","b"],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatInteger 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatInteger
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatInteger	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatInteger	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"13RepeatInteger":{"cereal_class_version":0,"value0":{"name_":"integer"},"start_":0,"end_":100,"delta_":2,"value_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatString 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatString
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/RepeatString	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/RepeatString	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"12RepeatString":{"cereal_class_version":0,"value0":{"name_":"string"},"theStrings_":["a","b"],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/TimeAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/TimeAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/TimeAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/TimeAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8TimeAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":10,"m_":12}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/TodayAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/TodayAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/TodayAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/TodayAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf9TodayAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":10,"m_":12}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/Variable 5.13.0-1/ANattr/test/data/migration/1_2_2/Variable
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/Variable	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/Variable	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"8Variable":{"n_":"var_name","v_":"var_value"}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/VerifyAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/VerifyAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/VerifyAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/VerifyAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"10VerifyAttr":{"state_":1,"expected_":3,"actual_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/ZombieAttr 5.13.0-1/ANattr/test/data/migration/1_2_2/ZombieAttr
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/ZombieAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/ZombieAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"10ZombieAttr":{"cereal_class_version":0,"child_cmds_":[0,1,2,3,4,5,6,7],"zombie_type_":0,"action_":0,"zombie_lifetime_":300}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/1_2_2/ZombieAttr1 5.13.0-1/ANattr/test/data/migration/1_2_2/ZombieAttr1
--- 5.12.4-1/ANattr/test/data/migration/1_2_2/ZombieAttr1	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/1_2_2/ZombieAttr1	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"10ZombieAttr":{"cereal_class_version":0,"child_cmds_":[0,1,2,3,4,5,6,7],"zombie_type_":0,"action_":0,"zombie_lifetime_":500}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf15AutoArchiveAttrE":{"cereal_class_version":0,"time_":{"h_":-1,"m_":-1}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoCancelAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoCancelAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoCancelAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/AutoCancelAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf14AutoCancelAttrE":{"cereal_class_version":0,"time_":{"h_":-1,"m_":-1}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/ClockAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/ClockAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/ClockAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/ClockAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"9ClockAttr":{"cereal_class_version":0,"hybrid_":false}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/CronAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/CronAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/CronAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/CronAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8CronAttrE":{"cereal_class_version":0,"timeSeries_":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/DateAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/DateAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/DateAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/DateAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"8DateAttr":{"day_":0,"month_":0,"year_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/DayAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/DayAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/DayAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/DayAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"7DayAttr":{"day_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Event 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Event
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Event	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Event	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Event":{}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/GenericAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/GenericAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/GenericAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/GenericAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"11GenericAttr":{"name_":"","values_":[]}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Label 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Label
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Label	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Label	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Label":{"n_":""}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/LateAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/LateAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/LateAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/LateAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8LateAttrE":{}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Meter 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Meter
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Meter	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Meter	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Meter":{"min_":0,"max_":0,"v_":0,"n_":"","cc_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/QueueAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/QueueAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/QueueAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/QueueAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"9QueueAttr":{"cereal_class_version":0,"theQueue_":[],"state_vec_":[],"name_":"","currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDate 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDate
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDate	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDate	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"10RepeatDate":{"cereal_class_version":0,"value0":{"name_":""},"start_":0,"end_":0,"delta_":0,"value_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDateList 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDateList
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDateList	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatDateList	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"14RepeatDateList":{"cereal_class_version":0,"value0":{"name_":""},"list_":[],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatEnumerated 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatEnumerated
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatEnumerated	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatEnumerated	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"16RepeatEnumerated":{"cereal_class_version":0,"value0":{"name_":""},"theEnums_":[],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatInteger 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatInteger
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatInteger	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatInteger	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"13RepeatInteger":{"cereal_class_version":0,"value0":{"name_":""},"start_":0,"end_":0,"delta_":0,"value_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatString 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatString
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatString	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/RepeatString	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"12RepeatString":{"cereal_class_version":0,"value0":{"name_":""},"theStrings_":[],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/TimeAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/TimeAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/TimeAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/TimeAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf8TimeAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/TodayAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/TodayAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/TodayAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/TodayAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"N3ecf9TodayAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Variable 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Variable
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/Variable	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/Variable	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"8Variable":{"n_":"","v_":""}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/VerifyAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/VerifyAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/VerifyAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/VerifyAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"10VerifyAttr":{"state_":0,"expected_":0,"actual_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/ZombieAttr 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/ZombieAttr
--- 5.12.4-1/ANattr/test/data/migration/default_constructor_1_2_2/ZombieAttr	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANattr/test/data/migration/default_constructor_1_2_2/ZombieAttr	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"10ZombieAttr":{"cereal_class_version":0,"child_cmds_":[],"zombie_type_":6,"action_":4,"zombie_lifetime_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/CMakeLists.txt 5.13.0-1/ANode/CMakeLists.txt
--- 5.12.4-1/ANode/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,389 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-set(srcs
-  # Headers
-  src/ecflow/node/AbstractObserver.hpp
-  src/ecflow/node/Alias.hpp
-  src/ecflow/node/Aspect.hpp
-  src/ecflow/node/Attr.hpp
-  src/ecflow/node/AutoRestoreAttr.hpp
-  src/ecflow/node/ClientSuiteMgr.hpp
-  src/ecflow/node/ClientSuites.hpp
-  src/ecflow/node/CmdContext.hpp
-  src/ecflow/node/Defs.hpp
-  src/ecflow/node/DefsDelta.hpp
-  src/ecflow/node/DefsTreeVisitor.hpp
-  src/ecflow/node/EcfFile.hpp
-  src/ecflow/node/ExprAst.hpp
-  src/ecflow/node/ExprAstVisitor.hpp
-  src/ecflow/node/ExprDuplicate.hpp
-  src/ecflow/node/ExprParser.hpp
-  src/ecflow/node/Expression.hpp
-  src/ecflow/node/Family.hpp
-  src/ecflow/node/Flag.hpp
-  src/ecflow/node/InLimit.hpp
-  src/ecflow/node/InLimitMgr.hpp
-  src/ecflow/node/JobCreationCtrl.hpp
-  src/ecflow/node/JobProfiler.hpp
-  src/ecflow/node/Jobs.hpp
-  src/ecflow/node/JobsParam.hpp
-  src/ecflow/node/Limit.hpp
-  src/ecflow/node/LimitFwd.hpp
-  src/ecflow/node/Memento.hpp
-  src/ecflow/node/MiscAttrs.hpp
-  src/ecflow/node/Node.hpp
-  src/ecflow/node/NodeContainer.hpp
-  src/ecflow/node/NodeFwd.hpp
-  src/ecflow/node/NodeState.hpp
-  src/ecflow/node/NodeStats.hpp
-  src/ecflow/node/NodeTreeVisitor.hpp
-  src/ecflow/node/ResolveExternsVisitor.hpp
-  src/ecflow/node/ServerState.hpp
-  src/ecflow/node/Signal.hpp
-  src/ecflow/node/Submittable.hpp
-  src/ecflow/node/Suite.hpp
-  src/ecflow/node/SuiteChanged.hpp
-  src/ecflow/node/System.hpp
-  src/ecflow/node/Task.hpp
-  src/ecflow/node/TaskScriptGenerator.hpp
-  src/ecflow/node/move_peer.hpp
-  src/ecflow/node/parser/AutoArchiveParser.hpp
-  src/ecflow/node/parser/AutoCancelParser.hpp
-  src/ecflow/node/parser/AutoRestoreParser.hpp
-  src/ecflow/node/parser/CalendarParser.hpp
-  src/ecflow/node/parser/ClockParser.hpp
-  src/ecflow/node/parser/CronParser.hpp
-  src/ecflow/node/parser/DateParser.hpp
-  src/ecflow/node/parser/DayParser.hpp
-  src/ecflow/node/parser/DefsParser.hpp
-  src/ecflow/node/parser/DefsStateParser.hpp
-  src/ecflow/node/parser/DefsStatusParser.hpp
-  src/ecflow/node/parser/DefsStructureParser.hpp
-  src/ecflow/node/parser/EventParser.hpp
-  src/ecflow/node/parser/ExternParser.hpp
-  src/ecflow/node/parser/GenericParser.hpp
-  src/ecflow/node/parser/InlimitParser.hpp
-  src/ecflow/node/parser/LabelParser.hpp
-  src/ecflow/node/parser/LateParser.hpp
-  src/ecflow/node/parser/LimitParser.hpp
-  src/ecflow/node/parser/MeterParser.hpp
-  src/ecflow/node/parser/Parser.hpp
-  src/ecflow/node/parser/QueueParser.hpp
-  src/ecflow/node/parser/RepeatParser.hpp
-  src/ecflow/node/parser/TimeParser.hpp
-  src/ecflow/node/parser/TodayParser.hpp
-  src/ecflow/node/parser/TriggerParser.hpp
-  src/ecflow/node/parser/VariableParser.hpp
-  src/ecflow/node/parser/VerifyParser.hpp
-  src/ecflow/node/parser/ZombieAttrParser.hpp
-  # Sources
-  src/ecflow/node/Alias.cpp
-  src/ecflow/node/Attr.cpp
-  src/ecflow/node/AutoRestoreAttr.cpp
-  src/ecflow/node/ClientSuiteMgr.cpp
-  src/ecflow/node/ClientSuites.cpp
-  src/ecflow/node/CmdContext.cpp
-  src/ecflow/node/Defs.cpp
-  src/ecflow/node/DefsDelta.cpp
-  src/ecflow/node/EcfFile.cpp
-  src/ecflow/node/ExprAst.cpp
-  src/ecflow/node/ExprAstVisitor.cpp
-  src/ecflow/node/ExprDuplicate.cpp
-  src/ecflow/node/ExprParser.cpp
-  src/ecflow/node/Expression.cpp
-  src/ecflow/node/Family.cpp
-  src/ecflow/node/Flag.cpp
-  src/ecflow/node/InLimit.cpp
-  src/ecflow/node/InLimitMgr.cpp
-  src/ecflow/node/JobCreationCtrl.cpp
-  src/ecflow/node/JobProfiler.cpp
-  src/ecflow/node/Jobs.cpp
-  src/ecflow/node/JobsParam.cpp
-  src/ecflow/node/Limit.cpp
-  src/ecflow/node/Memento.cpp
-  src/ecflow/node/MiscAttrs.cpp
-  src/ecflow/node/Node.cpp
-  src/ecflow/node/NodeAdd.cpp
-  src/ecflow/node/NodeChange.cpp
-  src/ecflow/node/NodeContainer.cpp
-  src/ecflow/node/NodeDelete.cpp
-  src/ecflow/node/NodeFind.cpp
-  src/ecflow/node/NodeMemento.cpp
-  src/ecflow/node/NodeStats.cpp
-  src/ecflow/node/NodeTime.cpp
-  src/ecflow/node/NodeTreeVisitor.cpp
-  src/ecflow/node/ResolveExternsVisitor.cpp
-  src/ecflow/node/ServerState.cpp
-  src/ecflow/node/Signal.cpp
-  src/ecflow/node/Submittable.cpp
-  src/ecflow/node/Suite.cpp
-  src/ecflow/node/SuiteChanged.cpp
-  src/ecflow/node/System.cpp
-  src/ecflow/node/Task.cpp
-  src/ecflow/node/TaskScriptGenerator.cpp
-  src/ecflow/node/parser/AutoArchiveParser.cpp
-  src/ecflow/node/parser/AutoCancelParser.cpp
-  src/ecflow/node/parser/AutoRestoreParser.cpp
-  src/ecflow/node/parser/CalendarParser.cpp
-  src/ecflow/node/parser/ClockParser.cpp
-  src/ecflow/node/parser/CronParser.cpp
-  src/ecflow/node/parser/DateParser.cpp
-  src/ecflow/node/parser/DayParser.cpp
-  src/ecflow/node/parser/DefsParser.cpp
-  src/ecflow/node/parser/DefsStateParser.cpp
-  src/ecflow/node/parser/DefsStatusParser.cpp
-  src/ecflow/node/parser/DefsStructureParser.cpp
-  src/ecflow/node/parser/EventParser.cpp
-  src/ecflow/node/parser/ExternParser.cpp
-  src/ecflow/node/parser/GenericParser.cpp
-  src/ecflow/node/parser/InlimitParser.cpp
-  src/ecflow/node/parser/LabelParser.cpp
-  src/ecflow/node/parser/LateParser.cpp
-  src/ecflow/node/parser/LimitParser.cpp
-  src/ecflow/node/parser/MeterParser.cpp
-  src/ecflow/node/parser/Parser.cpp
-  src/ecflow/node/parser/QueueParser.cpp
-  src/ecflow/node/parser/RepeatParser.cpp
-  src/ecflow/node/parser/TimeParser.cpp
-  src/ecflow/node/parser/TodayParser.cpp
-  src/ecflow/node/parser/TriggerParser.cpp
-  src/ecflow/node/parser/VariableParser.cpp
-  src/ecflow/node/parser/VerifyParser.cpp
-  src/ecflow/node/parser/ZombieAttrParser.cpp
-)
-
-ecbuild_add_library(
-  TARGET
-    node
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-  PUBLIC_LIBS
-    attributes
-)
-target_clangformat(node)
-
-
-set(test_srcs
-  # Headers
-  test/MyDefsFixture.hpp
-  # Sources
-  test/TestAdd.cpp
-  test/TestAlias.cpp
-  test/TestAssignmentOperator.cpp
-  test/TestChangeMgrSingleton.cpp
-  test/TestClientSuiteMgr.cpp
-  test/TestCopyConstructor.cpp
-  test/TestDefStatus.cpp
-  test/TestDefs.cpp
-  test/TestEcfFile.cpp
-  test/TestEcfFileLocator.cpp
-  test/TestEnviromentSubstitution.cpp
-  test/TestExprParser.cpp
-  test/TestExprRepeatDateArithmetic.cpp
-  test/TestExprRepeatDateListArithmetic.cpp
-  test/TestFindAbsNodePath.cpp
-  test/TestFlag.cpp
-  test/TestHistoryParser.cpp
-  test/TestInLimit.cpp
-  test/TestJobCreator.cpp
-  test/TestJobProfiler.cpp
-  test/TestLimit.cpp
-  test/TestMigration.cpp
-  test/TestMissNextTimeSlot.cpp
-  test/TestMovePeer.cpp
-  test/TestNodeBeginRequeue.cpp
-  test/TestNodeState.cpp
-  test/TestNode_main.cpp # test entry point
-  test/TestOrder.cpp
-  test/TestPersistence.cpp
-  test/TestPreProcessing.cpp
-  test/TestRepeatWithTimeDependencies.cpp
-  test/TestReplace.cpp
-  test/TestSetState.cpp
-  test/TestSpecificIssues.cpp
-  test/TestSystem.cpp
-  test/TestTaskScriptGenerator.cpp
-  test/TestTimeDependencies.cpp
-  test/TestVariableGeneration.cpp
-  test/TestVariableInheritance.cpp
-  test/TestVariableSubstitution.cpp
-  test/TestVariableSubstitutionDefs.cpp
-  test/TestZombies.cpp
-)
-
-ecbuild_add_test(
-  TARGET
-    u_node
-  LABELS
-    unit
-    nightly
-  SOURCES
-    ${test_srcs}
-  LIBS
-    test_support
-    node
-    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-  TEST_DEPENDS
-    u_attributes
-)
-target_clangformat(u_node
-  CONDITION ENABLE_TESTS)
-
-
-set(test_srcs
-  # Headers
-  test/parser/PersistHelper.hpp
-  test/parser/TemporaryFile.hpp
-  # Sources
-  test/parser/PersistHelper.cpp
-  test/parser/TemporaryFile.cpp
-  test/parser/TestAutoAddExterns.cpp
-  test/parser/TestDefsStructurePersistAndReload.cpp
-  test/parser/TestMementoPersistAndReload.cpp
-  test/parser/TestMigration.cpp
-  test/parser/TestParser.cpp
-  test/parser/TestParser_main.cpp # test entry point
-  test/parser/TestVariableParsing.cpp
-)
-ecbuild_add_test(
-  TARGET
-    u_parser
-  LABELS
-    unit
-    nightly
-  SOURCES
-    ${test_srcs}
-  INCLUDES
-    test
-    test/parser
-  LIBS
-    node
-    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-  TEST_DEPENDS
-    u_node
-)
-target_clangformat(u_parser
-  CONDITION ENABLE_TESTS
-)
-
-if (ENABLE_ALL_TESTS)
-  set(test_srcs
-    test/TestSingleExprParse.cpp
-    test/TestSingleExprParse_main.cpp # test entry point
-  )
-
-  ecbuild_add_test(
-    TARGET
-      u_node_single
-    LABELS
-      unit
-      nightly
-    SOURCES
-      ${test_srcs}
-    LIBS
-      node
-      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-    TEST_DEPENDS
-      u_anattr
-  )
-  target_clangformat(u_node_single
-    CONDITION ENABLE_TESTS
-  )
-
-
-  set(test_srcs
-    # Headers
-    test/parser/PersistHelper.hpp
-    test/parser/TemporaryFile.hpp
-    # Sources
-    test/parser/PersistHelper.cpp
-    test/parser/TemporaryFile.cpp
-    test/parser/TestParserPerformance_main.cpp # test entry point
-    test/parser/TestSingleDefsFile.cpp
-  )
-
-  ecbuild_add_test(
-    TARGET
-      p_parser
-    LABELS
-      performance
-      nightly
-    SOURCES
-      ${test_srcs}
-    LIBS
-      node
-      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-      Boost::timer
-  )
-  target_clangformat(p_parser
-    CONDITION ENABLE_TESTS
-  )
-
-
-  set(test_srcs
-    # Headers
-    test/parser/PersistHelper.hpp
-    test/parser/TemporaryFile.hpp
-    # Sources
-    test/parser/ParseTimer.cpp
-    test/parser/PersistHelper.cpp
-    test/parser/TemporaryFile.cpp
-  )
-
-  # The following is not technically a test (as it makes no checks),
-  # but a tool to measure the time it takes to parse 'mega.def' file
-  ecbuild_add_test(
-    TARGET
-      p_parser_timer
-    LABELS
-      performance
-      nightly
-    ARGS
-      ${CMAKE_CURRENT_SOURCE_DIR}/test/parser/data/single_defs/mega.def
-    SOURCES
-      ${test_srcs}
-    LIBS
-      node
-      Boost::boost # Boost header-only libraries must be available
-      Boost::timer
-  )
-  target_clangformat(p_parser_timer
-    CONDITION ENABLE_TESTS
-  )
-
-  # The following is not technically a test (as it makes no checks),
-  # but a tool to parse 'mega.def' file
-  set(test_srcs
-    test/parser/ParseOnly.cpp
-  )
-  ecbuild_add_test(
-    TARGET
-      p_parser_only
-    LABELS
-      performance
-      nightly
-    ARGS
-      ${CMAKE_CURRENT_SOURCE_DIR}/test/parser/data/single_defs/mega.def
-    SOURCES
-      ${test_srcs}
-    LIBS
-      node
-      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-  )
-  target_clangformat(p_parser_only
-    CONDITION ENABLE_TESTS
-  )
-
-endif()
diff -pruN 5.12.4-1/ANode/src/ecflow/node/AbstractObserver.hpp 5.13.0-1/ANode/src/ecflow/node/AbstractObserver.hpp
--- 5.12.4-1/ANode/src/ecflow/node/AbstractObserver.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/AbstractObserver.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,36 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_core_AbstractObserver_HPP
-#define ecflow_core_AbstractObserver_HPP
-
-#include <vector>
-
-#include "ecflow/node/Aspect.hpp"
-
-class Node;
-class Defs;
-
-class AbstractObserver {
-public:
-    virtual ~AbstractObserver() = default;
-
-    virtual void update_start(const Node*, const std::vector<ecf::Aspect::Type>&) = 0;
-    virtual void update_start(const Defs*, const std::vector<ecf::Aspect::Type>&) = 0;
-
-    virtual void update(const Node*, const std::vector<ecf::Aspect::Type>&) = 0;
-    virtual void update(const Defs*, const std::vector<ecf::Aspect::Type>&) = 0;
-
-    /// After this call, the node will be deleted, hence observers must *NOT* use the pointers
-    virtual void update_delete(const Node*) {}
-    virtual void update_delete(const Defs*) {}
-};
-
-#endif /* ecflow_core_AbstractObserver_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Alias.cpp 5.13.0-1/ANode/src/ecflow/node/Alias.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Alias.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Alias.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,165 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Alias.hpp"
-
-#include <limits>
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-//==================================================================================
-Alias::Alias(const std::string& name, bool check) : Submittable(name, check) {
-    set_state_only(NState::QUEUED);
-}
-
-Alias::Alias(const Alias& rhs) = default;
-
-Alias::Alias() {
-    set_state_only(NState::QUEUED);
-}
-
-node_ptr Alias::clone() const {
-    return std::make_shared<Alias>(*this);
-}
-
-Alias::~Alias() {
-    if (!Ecf::server()) {
-        notify_delete();
-    }
-}
-
-Alias& Alias::operator=(const Alias& rhs) {
-    if (this != &rhs) {
-        Submittable::operator=(rhs);
-    }
-    return *this;
-}
-
-alias_ptr Alias::create(const std::string& name, bool check) {
-    return std::make_shared<Alias>(name, check);
-}
-
-bool Alias::operator==(const Alias& rhs) const {
-    return Submittable::operator==(rhs);
-}
-
-void Alias::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    os += "alias ";
-    os += name();
-    if (!PrintStyle::defsStyle()) {
-        bool added_comment_char = false;
-        write_state(os, added_comment_char);
-    }
-    os += "\n";
-
-    Node::print(os);
-
-    // Generated variable are not persisted since they are created on demand
-    // There *NO* point in printing them they will always be empty
-}
-std::ostream& operator<<(std::ostream& os, const Alias& d) {
-    std::string s;
-    d.print(s);
-    os << s;
-    return os;
-}
-
-void Alias::begin() {
-    Submittable::begin();
-}
-
-void Alias::requeue(Requeue_args& args) {
-    Submittable::requeue(args);
-}
-
-const std::string& Alias::debugType() const {
-    return ecf::Str::ALIAS();
-}
-
-node_ptr Alias::removeChild(Node*) {
-    LOG_ASSERT(false, "");
-    return node_ptr();
-}
-
-bool Alias::addChild(const node_ptr&, size_t) {
-    LOG_ASSERT(false, "");
-    return false;
-}
-
-size_t Alias::child_position(const Node*) const {
-    return std::numeric_limits<std::size_t>::max();
-}
-
-bool Alias::isAddChildOk(Node* alias, std::string& errorMsg) const {
-    errorMsg += "Cannot add children to a Alias";
-    return false;
-}
-
-void Alias::handleStateChange() {
-    Node::handleStateChange();
-
-    /// Increment/decrement limits based on the current state
-    update_limits();
-
-    // Aliases are stand alone, they do no requeue or bubble up/down state changes
-    // i.e no requeue since they have no time dependencies, or repeat
-}
-
-const std::string& Alias::script_extension() const {
-    return File::USR_EXTN();
-}
-
-void Alias::collateChanges(DefsDelta& changes) const {
-    /// All changes to Alias should be on ONE compound_memento_ptr
-    compound_memento_ptr comp;
-    Submittable::incremental_changes(changes, comp);
-}
-
-void Alias::get_all_nodes(std::vector<node_ptr>& nodes) const {
-    nodes.push_back(non_const_this());
-}
-
-// Functions unique to aliases
-void Alias::add_alias_variable(const std::string& name, const std::string& value) {
-    if (name.empty()) {
-        throw std::runtime_error("Alias::add_alias_variable: Variable with empty name");
-    }
-
-    // The bool argument to variable, allows addition of Variable without name checking
-    addVariable(Variable(name, value, false));
-}
-
-node_ptr Alias::find_node_up_the_tree(const std::string& name) const {
-    Node* the_parent = parent();
-    if (the_parent)
-        return the_parent->find_node_up_the_tree(name);
-    return node_ptr();
-}
-
-template <class Archive>
-void Alias::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Submittable>(this));
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(Alias);
-CEREAL_REGISTER_TYPE(Alias)
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Alias.hpp 5.13.0-1/ANode/src/ecflow/node/Alias.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Alias.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Alias.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,97 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Alias_HPP
-#define ecflow_node_Alias_HPP
-
-#include "ecflow/node/Submittable.hpp"
-
-class Alias final : public Submittable {
-public:
-    explicit Alias(const std::string& name, bool check = true);
-    Alias();
-    Alias(const Alias&);
-    Alias& operator=(const Alias&);
-    node_ptr clone() const override;
-
-    ~Alias() override;
-
-    static alias_ptr create(const std::string& name, bool check = true);
-
-    void print(std::string&) const override;
-    bool operator==(const Alias& rhs) const;
-
-    /// Overridden to reset the try number
-    /// The tasks job can be invoked multiple times. For each invocation we want to preserve
-    /// the output. The try number is used in SMSJOB/SMSJOBOUT to preserve the output when
-    /// there are multiple runs.  re-queue/begin() resets the try Number
-    void begin() override;
-    void requeue(Requeue_args&) override;
-
-    Suite* suite() const override { return parent()->suite(); }
-    Defs* defs() const override {
-        return (parent()) ? parent()->defs() : nullptr;
-    } // exposed to python hence check for NULL first
-    Alias* isAlias() const override { return const_cast<Alias*>(this); }
-    Submittable* isSubmittable() const override { return const_cast<Alias*>(this); }
-
-    const std::string& debugType() const override;
-
-    node_ptr removeChild(Node* child) override;
-    bool addChild(const node_ptr& child, size_t position = std::numeric_limits<std::size_t>::max()) override;
-    bool isAddChildOk(Node* child, std::string& errorMsg) const override;
-
-    const std::string& script_extension() const override;
-
-    void collateChanges(DefsDelta&) const override;
-    void set_memento(const SubmittableMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
-        Submittable::set_memento(m, aspects, f);
-    }
-
-    node_ptr find_node_up_the_tree(const std::string& name) const override;
-
-    // Pure node Functions that are not implemented for aliases
-    node_ptr find_relative_node(const std::vector<std::string>&) override { return node_ptr(); }
-
-    void get_all_nodes(std::vector<node_ptr>& nodes) const override;
-
-    // Functions unique to aliases
-    // Alias variable names by pass checking of valid names, allowing anything
-    void add_alias_variable(const std::string& name, const std::string& value);
-
-private:
-    size_t child_position(const Node*) const override;
-
-    /// Job creation checking is typically called from python API
-    /// This has been disabled for Aliases
-    void check_job_creation(job_creation_ctrl_ptr) override {}
-
-    // Overridden from Node to increment/decrement limits only
-    // i.e we do not update parent computed states for aliases
-    void handleStateChange() override;
-
-    // Pure node Functions that are not implemented for aliases
-    void accept(ecf::NodeTreeVisitor&) override {}
-    void acceptVisitTraversor(ecf::NodeTreeVisitor&) override {}
-    void get_all_tasks(std::vector<task_ptr>&) const override {}
-    void get_all_aliases(std::vector<alias_ptr>&) const override {}
-    void getAllNodes(std::vector<Node*>&) const override {}
-    void getAllTasks(std::vector<Task*>&) const override {}
-    void getAllSubmittables(std::vector<Submittable*>&) const override {}
-    void get_all_active_submittables(std::vector<Submittable*>&) const override {}
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-std::ostream& operator<<(std::ostream& os, const Alias&);
-
-#endif /* ecflow_node_Alias_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Aspect.hpp 5.13.0-1/ANode/src/ecflow/node/Aspect.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Aspect.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Aspect.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Aspect_HPP
-#define ecflow_node_Aspect_HPP
-
-///
-/// \brief This class is used to provide observers with more info regarding
-/// whats changed. used as a part of the observer pattern
-/// s
-
-namespace ecf {
-
-class Aspect {
-public:
-    enum Type {
-        NOT_DEFINED,
-        ORDER,
-        ADD_REMOVE_NODE,
-        ADD_REMOVE_ATTR,
-        METER,
-        EVENT,
-        LABEL,
-        LIMIT,
-        STATE,
-        DEFSTATUS,
-        SUSPENDED,
-        SERVER_STATE,
-        SERVER_VARIABLE,
-        EXPR_TRIGGER,
-        EXPR_COMPLETE,
-        REPEAT,
-        REPEAT_INDEX,
-        NODE_VARIABLE,
-        LATE,
-        TODAY,
-        TIME,
-        DAY,
-        CRON,
-        DATE,
-        FLAG,
-        SUBMITTABLE,
-        SUITE_CLOCK,
-        SUITE_BEGIN,
-        SUITE_CALENDAR,
-        ALIAS_NUMBER,
-        QUEUE,
-        QUEUE_INDEX,
-        GENERIC
-    };
-
-    // Disable default construction
-    Aspect() = delete;
-    // Disable copy (and move) semantics
-    Aspect(const Aspect&)                  = delete;
-    const Aspect& operator=(const Aspect&) = delete;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_Aspect_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Attr.cpp 5.13.0-1/ANode/src/ecflow/node/Attr.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Attr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Attr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Attr.hpp"
-
-#include <cassert>
-
-namespace ecf {
-
-const char* Attr::to_string(Attr::Type s) {
-    switch (s) {
-        case Attr::EVENT:
-            return "event";
-        case Attr::METER:
-            return "meter";
-        case Attr::LABEL:
-            return "label";
-        case Attr::LIMIT:
-            return "limit";
-        case Attr::VARIABLE:
-            return "variable";
-        case Attr::ALL:
-            return "all";
-        case Attr::UNKNOWN:
-            return "unknown";
-        default:
-            assert(false);
-            break;
-    }
-    assert(false);
-    return nullptr;
-}
-
-Attr::Type Attr::to_attr(const std::string& str) {
-    if (str == "event")
-        return Attr::EVENT;
-    if (str == "meter")
-        return Attr::METER;
-    if (str == "label")
-        return Attr::LABEL;
-    if (str == "limit")
-        return Attr::LIMIT;
-    if (str == "variable")
-        return Attr::VARIABLE;
-    if (str == "all")
-        return Attr::ALL;
-    return Attr::UNKNOWN;
-}
-
-bool Attr::is_valid(const std::string& str) {
-    return (to_attr(str) == Attr::UNKNOWN) ? false : true;
-}
-
-std::vector<std::string> Attr::all_attrs() {
-    std::vector<std::string> vec;
-    vec.reserve(6);
-    vec.emplace_back("event");
-    vec.emplace_back("meter");
-    vec.emplace_back("label");
-    vec.emplace_back("limit");
-    vec.emplace_back("variable");
-    vec.emplace_back("all");
-    return vec;
-}
-
-std::vector<Attr::Type> Attr::attrs() {
-    std::vector<Attr::Type> vec;
-    vec.reserve(6);
-    vec.push_back(Attr::UNKNOWN);
-    vec.push_back(Attr::EVENT);
-    vec.push_back(Attr::METER);
-    vec.push_back(Attr::LABEL);
-    vec.push_back(Attr::LIMIT);
-    vec.push_back(Attr::VARIABLE);
-    vec.push_back(Attr::ALL);
-    return vec;
-}
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Attr.hpp 5.13.0-1/ANode/src/ecflow/node/Attr.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Attr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Attr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Attr_HPP
-#define ecflow_node_Attr_HPP
-
-#include <string>
-#include <vector>
-
-namespace ecf {
-class Attr {
-public:
-    enum Type { UNKNOWN = 0, EVENT = 1, METER = 2, LABEL = 3, LIMIT = 4, VARIABLE = 5, ALL = 6 };
-
-    // Disable default construction
-    Attr() = delete;
-    // Disable copy (and move) semantics
-    Attr(const Attr&)                  = delete;
-    const Attr& operator=(const Attr&) = delete;
-
-    static const char* to_string(Attr::Type s);
-    static Attr::Type to_attr(const std::string& attr);
-    static bool is_valid(const std::string& state);
-    static std::vector<std::string> all_attrs();
-    static std::vector<Attr::Type> attrs();
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_Attr_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/AutoRestoreAttr.cpp 5.13.0-1/ANode/src/ecflow/node/AutoRestoreAttr.cpp
--- 5.12.4-1/ANode/src/ecflow/node/AutoRestoreAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/AutoRestoreAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,149 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/AutoRestoreAttr.hpp"
-
-#include <sstream>
-
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/NodeContainer.hpp"
-
-#ifdef DEBUG
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-using namespace std;
-
-namespace ecf {
-
-void AutoRestoreAttr::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    os += "\n";
-}
-
-std::string AutoRestoreAttr::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void AutoRestoreAttr::write(std::string& ret) const {
-    ret += "autorestore";
-    for (const auto& i : nodes_to_restore_) {
-        ret += " ";
-        ret += i;
-    }
-}
-
-bool AutoRestoreAttr::operator==(const AutoRestoreAttr& rhs) const {
-    if (nodes_to_restore_ == rhs.nodes_to_restore_)
-        return true;
-
-#ifdef DEBUG
-    if (Ecf::debug_equality()) {
-        std::cout << "AutoRestoreAttr::operator== nodes_to_restore_ == rhs.nodes_to_restore_\n";
-    }
-#endif
-
-    return false;
-}
-
-void AutoRestoreAttr::do_autorestore() {
-    string warning_message;
-    for (const auto& i : nodes_to_restore_) {
-
-        warning_message.clear();
-        node_ptr referenceNode = node_->findReferencedNode(i, warning_message);
-        if (!referenceNode.get()) {
-            /// Could not find the references node
-            std::stringstream ss;
-            ss << "AutoRestoreAttr::do_auto_restore: " << node_->debugType() << " references a path '" << i
-               << "' which cannot be found\n";
-            log(Log::ERR, ss.str());
-            continue;
-        }
-
-        NodeContainer* nc = referenceNode->isNodeContainer();
-        if (nc) {
-            try {
-                nc->restore();
-            }
-            catch (std::exception& e) {
-                std::stringstream ss;
-                ss << "AutoRestoreAttr::do_auto_restore: could not autorestore : because : " << e.what();
-                log(Log::ERR, ss.str());
-            }
-        }
-        else {
-            std::stringstream ss;
-            ss << "AutoRestoreAttr::do_auto_restore: " << node_->debugType() << " references a node '" << i
-               << "' which cannot be restored. Only family and suite nodes can be restored";
-            log(Log::ERR, ss.str());
-        }
-    }
-}
-
-void AutoRestoreAttr::check(std::string& errorMsg) const {
-    std::vector<NodeContainer*> vec;
-    string warning_message;
-    for (const auto& i : nodes_to_restore_) {
-
-        warning_message.clear();
-        node_ptr referenceNode = node_->findReferencedNode(i, warning_message);
-        if (!referenceNode.get()) {
-            /// Could not find the references node
-
-            // OK a little bit of duplication, since findReferencedNode, will also look for externs
-            // See if the Path:name is defined as an extern, in which case *DONT* error:
-            // This is client side specific, since server does not have externs.
-            if (node_->defs()->find_extern(i, Str::EMPTY())) {
-                continue;
-            }
-
-            std::stringstream ss;
-            ss << "Error: autorestore on node " << node_->debugType() << " references a path '" << i
-               << "' which cannot be found\n";
-            errorMsg += ss.str();
-            continue;
-        }
-
-        // reference node found, make sure it not a task
-        NodeContainer* nc = referenceNode->isNodeContainer();
-        if (!nc) {
-            std::stringstream ss;
-            ss << "Error: autorestore on node " << node_->debugType() << " references a node '" << i
-               << "' which is a task. restore only works with suites or family nodes";
-            errorMsg += ss.str();
-        }
-
-        // Check for duplicate references
-        if (find(vec.begin(), vec.end(), nc) == vec.end())
-            vec.push_back(nc);
-        else {
-            std::stringstream ss;
-            ss << "Error: autorestore on node " << node_->debugType() << ", duplicate references to node '" << i << "'";
-            errorMsg += ss.str();
-        }
-    }
-}
-
-template <class Archive>
-void AutoRestoreAttr::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(nodes_to_restore_));
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(AutoRestoreAttr);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/AutoRestoreAttr.hpp 5.13.0-1/ANode/src/ecflow/node/AutoRestoreAttr.hpp
--- 5.12.4-1/ANode/src/ecflow/node/AutoRestoreAttr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/AutoRestoreAttr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_AutoRestoreAttr_HPP
-#define ecflow_node_AutoRestoreAttr_HPP
-
-#include <cstdint>
-#include <string>
-#include <vector>
-
-namespace cereal {
-class access;
-}
-
-class Node;
-
-namespace ecf {
-
-// Use compiler, destructor
-class AutoRestoreAttr {
-public:
-    AutoRestoreAttr(const AutoRestoreAttr& rhs) : node_(nullptr), nodes_to_restore_(rhs.nodes_to_restore_) {}
-    explicit AutoRestoreAttr(const std::vector<std::string>& nodes_to_restore)
-        : node_(nullptr),
-          nodes_to_restore_(nodes_to_restore) {}
-    AutoRestoreAttr() = default;
-
-    // needed by node copy constructor and persistence
-    void set_node(Node* n) { node_ = n; }
-
-    void print(std::string&) const;
-    bool operator==(const AutoRestoreAttr& rhs) const;
-    std::string toString() const;
-
-    void do_autorestore();
-    const std::vector<std::string>& nodes_to_restore() const { return nodes_to_restore_; }
-    void check(std::string& errorMsg) const; // check auto restore can reference the nodes
-
-private:
-    void write(std::string&) const;
-
-private:
-    Node* node_{nullptr};                       // Not persisted, constructor will always set this up.
-    std::vector<std::string> nodes_to_restore_; // must be suite or family
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_AutoRestoreAttr_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ClientSuiteMgr.cpp 5.13.0-1/ANode/src/ecflow/node/ClientSuiteMgr.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ClientSuiteMgr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ClientSuiteMgr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,275 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/ClientSuiteMgr.hpp"
-
-#include <algorithm> // for sort, remove_if
-#include <sstream>   // for std::stringstream
-#include <stdexcept>
-
-#include "ecflow/core/Ecf.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// #define DEBUG_HANDLE 1
-
-ClientSuiteMgr::ClientSuiteMgr(Defs* defs) : defs_(defs) {
-}
-
-unsigned int ClientSuiteMgr::create_client_suite(bool auto_add_new_suites,
-                                                 const std::vector<std::string>& suites,
-                                                 const std::string& the_user) {
-    // The handle must be unique. If there are holes, re-use them, i.e
-    //     1,2,3,4,5     user deletes handle 3 ===>  1,2,4,5
-    // Hence re-use handle 3
-    bool found_hole         = false;
-    unsigned int new_handle = 1;
-    for (auto& clientSuite : clientSuites_) {
-        if (clientSuite.handle() == new_handle) {
-            new_handle++;
-        }
-        else {
-            found_hole = true;
-            break;
-        }
-    }
-    if (!found_hole)
-        new_handle = clientSuites_.size() + 1;
-
-    clientSuites_.emplace_back(defs_, new_handle, auto_add_new_suites, suites, the_user);
-
-    // aesthetics only
-    std::sort(clientSuites_.begin(), clientSuites_.end(), [](const ecf::ClientSuites& a, const ecf::ClientSuites& b) {
-        return a.handle() < b.handle();
-    });
-
-    // make sure all suites in ClientSuites are in same order as  Defs suites
-    update_suite_order();
-
-#ifdef DEBUG_HANDLE
-    std::cout << "ClientSuiteMgr::create_client_suite: " << dump() << "\n";
-#endif
-    return new_handle;
-}
-
-void ClientSuiteMgr::remove_client_suite(unsigned int client_handle) {
-    size_t before = clientSuites_.size();
-    clientSuites_.erase(
-        std::remove_if(clientSuites_.begin(),
-                       clientSuites_.end(),
-                       [client_handle](const ecf::ClientSuites& cs) { return cs.handle() == client_handle; }),
-        clientSuites_.end());
-
-    if (before == clientSuites_.size()) {
-        std::stringstream ss;
-        ss << "ClientSuiteMgr::remove_client_suite: handle(" << client_handle
-           << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
-        throw std::runtime_error(ss.str());
-    }
-#ifdef DEBUG_HANDLE
-    std::cout << "ClientSuiteMgr::remove_client_suite: handle(" << client_handle << ") " << dump() << "\n";
-#endif
-}
-
-void ClientSuiteMgr::remove_client_suites(const std::string& user_to_drop) {
-    size_t before = clientSuites_.size();
-    clientSuites_.erase(
-        std::remove_if(clientSuites_.begin(),
-                       clientSuites_.end(),
-                       [&user_to_drop](const ecf::ClientSuites& cs) { return cs.user() == user_to_drop; }),
-        clientSuites_.end());
-
-    if (before == clientSuites_.size()) {
-        std::stringstream ss;
-        ss << "ClientSuiteMgr::remove_client_suites: user(" << user_to_drop
-           << ") has no registered handles. User dropped? Please refresh GUI/re-register suites";
-        throw std::runtime_error(ss.str());
-    }
-
-#ifdef DEBUG_HANDLE
-    std::cout << "ClientSuiteMgr::remove_client_suites: user_to_drop(" << user_to_drop << ") " << dump() << "\n";
-#endif
-}
-
-void ClientSuiteMgr::add_suites(unsigned int client_handle, const std::vector<std::string>& suites) {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            for (const auto& suite : suites) {
-                clientSuites_[i].add_suite(suite);
-            }
-#ifdef DEBUG_HANDLE
-            std::cout << "ClientSuiteMgr::add_suites: client_handle(" << client_handle << ") " << dump() << "\n";
-#endif
-            update_suite_order();
-            return;
-        }
-    }
-    std::stringstream ss;
-    ss << "ClientSuiteMgr::add_suites: handle(" << client_handle
-       << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
-    throw std::runtime_error(ss.str());
-}
-
-void ClientSuiteMgr::remove_suites(unsigned int client_handle, const std::vector<std::string>& suites) {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            for (const auto& suite : suites) {
-                clientSuites_[i].remove_suite(suite);
-            }
-#ifdef DEBUG_HANDLE
-            std::cout << "ClientSuiteMgr::remove_suites: client_handle(" << client_handle << ") " << dump() << "\n";
-#endif
-            return;
-        }
-    }
-    std::stringstream ss;
-    ss << "ClientSuiteMgr::remove_suites: handle(" << client_handle
-       << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
-    throw std::runtime_error(ss.str());
-}
-
-void ClientSuiteMgr::auto_add_new_suites(unsigned int client_handle, bool auto_add_new_suites) {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            clientSuites_[i].add_new_suite(auto_add_new_suites);
-
-#ifdef DEBUG_HANDLE
-            std::cout << "ClientSuiteMgr::auto_add_new_suites: client_handle(" << client_handle
-                      << ") auto_add_new_suites(" << auto_add_new_suites << ") " << dump() << "\n";
-#endif
-            return;
-        }
-    }
-    std::stringstream ss;
-    ss << "ClientSuiteMgr::auto_add_new_suites: handle(" << client_handle
-       << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
-    throw std::runtime_error(ss.str());
-}
-
-bool ClientSuiteMgr::valid_handle(unsigned int client_handle) const {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            return true;
-        }
-    }
-    return false;
-}
-
-/// returns true if the handle was created, or suites added or removed from it
-bool ClientSuiteMgr::handle_changed(unsigned int client_handle) {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            return clientSuites_[i].handle_changed();
-        }
-    }
-    return false;
-}
-
-void ClientSuiteMgr::collateChanges(unsigned int client_handle, DefsDelta& changes) const {
-    // collate changes over the suites that match the client handle
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            clientSuites_[i].collateChanges(changes);
-            return;
-        }
-    }
-}
-
-void ClientSuiteMgr::suites(unsigned int client_handle, std::vector<std::string>& names) const {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            clientSuites_[i].suites(names);
-            return;
-        }
-    }
-}
-
-defs_ptr ClientSuiteMgr::create_defs(unsigned int client_handle, defs_ptr server_defs) const {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            return clientSuites_[i].create_defs(server_defs);
-        }
-    }
-    return defs_ptr();
-}
-
-void ClientSuiteMgr::max_change_no(unsigned int client_handle,
-                                   unsigned int& max_state_change_no,
-                                   unsigned int& max_modify_change_no) {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        if (clientSuites_[i].handle() == client_handle) {
-            clientSuites_[i].max_change_no(max_state_change_no, max_modify_change_no);
-            return;
-        }
-    }
-    std::stringstream ss;
-    ss << "ClientSuiteMgr::max_change_no: handle(" << client_handle
-       << ") does not exist in server. Handle dropped or Server may have died? Please refresh GUI/re-register suites";
-    throw std::runtime_error(ss.str());
-}
-
-void ClientSuiteMgr::suite_added_in_defs(suite_ptr suite) {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        clientSuites_[i].suite_added_in_defs(suite);
-        clientSuites_[i].update_suite_order();
-    }
-}
-
-void ClientSuiteMgr::suite_deleted_in_defs(suite_ptr suite) {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        clientSuites_[i].suite_deleted_in_defs(suite);
-    }
-}
-
-void ClientSuiteMgr::update_suite_order() {
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        clientSuites_[i].update_suite_order();
-    }
-}
-
-std::string ClientSuiteMgr::dump_max_change_no() const {
-    std::stringstream ss;
-    ss << "ClientSuiteMgr::dump_max_change_no: ECF:(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-       << ")\n";
-    size_t client_suites_size = clientSuites_.size();
-    for (size_t i = 0; i < client_suites_size; i++) {
-        unsigned int max_state_change_no  = 0;
-        unsigned int max_modify_change_no = 0;
-        clientSuites_[i].max_change_no(max_state_change_no, max_modify_change_no);
-        ss << "handle: " << clientSuites_[i].handle() << " max(" << max_state_change_no << "," << max_modify_change_no
-           << ")\n";
-    }
-    return ss.str();
-}
-
-/// For debug dumps
-std::string ClientSuiteMgr::dump() const {
-    size_t client_suites_size = clientSuites_.size();
-    std::stringstream ss;
-    ss << "ECF:(" << Ecf::state_change_no() << "," << Ecf::modify_change_no() << ") clientSuites_.size("
-       << client_suites_size << ")\n";
-    for (size_t i = 0; i < client_suites_size; i++) {
-        ss << clientSuites_[i].dump() << "\n";
-    }
-    return ss.str();
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ClientSuiteMgr.hpp 5.13.0-1/ANode/src/ecflow/node/ClientSuiteMgr.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ClientSuiteMgr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ClientSuiteMgr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,118 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ClientSuiteMgr_HPP
-#define ecflow_node_ClientSuiteMgr_HPP
-
-///
-/// \brief The client may only want to view a small subset of the suites available
-/// in a defs file. This class manages the client handles
-///
-/// Users are allowed to register interest in suite that have not yet been added
-/// This will only work provided we have a definition
-///
-/// Only handle with value > 0 are valid. This is because sync() and news() command
-/// take a client_handle. By reserving a client handle of zero, we can sync with the
-/// full defs.
-///
-///
-/// \note Change of suite order is handled by OrderMemento
-///       and *NOT* by the ClientSuiteMgr, however whenever suites are
-///       registered and added/deleted:
-///       then:
-///           defs_ptr create_defs(unsigned int client_handle) const;
-///
-///       Will return the suites in the same order as the defs
-///
-
-#include "ecflow/node/ClientSuites.hpp"
-class DefsDelta;
-class Defs;
-
-class ClientSuiteMgr {
-public:
-    explicit ClientSuiteMgr(Defs*);
-    // Disable copy (and move) semantics
-    ClientSuiteMgr(const ClientSuiteMgr&)                  = delete;
-    const ClientSuiteMgr& operator=(const ClientSuiteMgr&) = delete;
-
-    /// Create a client suite, and return the handle associated with the created object
-    unsigned int
-    create_client_suite(bool auto_add_new_suites, const std::vector<std::string>& suites, const std::string& user);
-
-    /// These function can throw std::runtime_error if the handle cannot be found
-    void remove_client_suite(unsigned int client_handle);
-    void remove_client_suites(const std::string& user_to_drop);
-    void add_suites(unsigned int client_handle, const std::vector<std::string>& suites);
-    void remove_suites(unsigned int client_handle, const std::vector<std::string>& suites);
-    void auto_add_new_suites(unsigned int client_handle, bool auto_add_new_suites);
-
-    /// Return true if the input handle is valid
-    bool valid_handle(unsigned int client_handle) const;
-
-    /// returns true if the handle was created, or suites added or removed from it
-    /// The handle change flag is reset when create_defs is called
-    bool handle_changed(unsigned int client_handle);
-
-    /// Collect all the state changes, so that only small subset is returned to client
-    /// When nodes are added/deleted we use the modify_change_no_, in this case
-    /// the whole defs is returned. Both integers are returned back to the client
-    /// so that, the client then sends the integers back to server, so we can determine
-    /// what's changed.
-    void collateChanges(unsigned int client_handle, DefsDelta&) const;
-
-    // Only return the defs state and suites that the client has registered in the client handle
-    // *HOWEVER* if the client has registered all the suites, just return the server defs
-    //           *with* the updated change numbers
-    // *OTHERWISE*
-    /// This will also compute the **maximum** state and modify change numbers over
-    /// the suites managed by the client handle.
-    /// and then set it on the newly created defs.
-    /// It also takes special precaution *NOT* to change Ecf::state_change_no() and Ecf::modify_change_no()
-    /// This will clear the handle_changed flag
-    defs_ptr create_defs(unsigned int client_handle, defs_ptr server_defs) const;
-
-    /// Used to determine the change, will throw if handle not found
-    void
-    max_change_no(unsigned int client_handle, unsigned int& max_state_change_no, unsigned int& max_modify_change_no);
-
-    /// Accessor
-    const std::vector<ecf::ClientSuites>& clientSuites() const { return clientSuites_; }
-
-    /// returns the list of suites associated with a handle, Used by ecFlowview
-    void suites(unsigned int client_handle, std::vector<std::string>& names) const;
-
-    /// A suite is being added in the definition.
-    /// If the suite was previously registered *UPDATE* its suite_ptr
-    /// Otherwise if any ClientSuites registered for automatic inclusion of new suite, add them in
-    void suite_added_in_defs(suite_ptr);
-
-    /// The suite is being deleted in the definition, reset the suite_ptr
-    /// Deleted suites STAY registered, until explicitly dropped.
-    void suite_deleted_in_defs(suite_ptr);
-
-    /// Update suites to be in same order as Defs.
-    void update_suite_order();
-
-    /// remove all client Suites
-    void clear() { clientSuites_.clear(); }
-
-    /// Returns a string which has the max state change and modify numbers for each handle
-    std::string dump_max_change_no() const;
-
-    /// For debug dumps
-    std::string dump() const;
-
-private:
-    std::vector<ecf::ClientSuites> clientSuites_;
-    Defs* defs_;
-};
-
-#endif /* ecflow_node_ClientSuiteMgr_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ClientSuites.cpp 5.13.0-1/ANode/src/ecflow/node/ClientSuites.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ClientSuites.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ClientSuites.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,296 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/ClientSuites.hpp"
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/DefsDelta.hpp"
-#include "ecflow/node/Suite.hpp"
-
-// #define DEBUG_ME 1
-
-namespace ecf {
-
-ClientSuites::ClientSuites(Defs* defs,
-                           unsigned int handle,
-                           bool auto_add_new_suites,
-                           const std::vector<std::string>& suites,
-                           const std::string& user)
-    : defs_(defs),
-      user_(user),
-      handle_(handle),
-      auto_add_new_suites_(auto_add_new_suites) {
-    for (const std::string& s : suites) {
-        add_suite(s);
-    }
-}
-
-void ClientSuites::add_suite(const std::string& s) {
-    suite_ptr suite = defs_->findSuite(s);
-    if (suite.get()) {
-        add_suite(suite);
-    }
-    else {
-        auto i = find_suite(s);
-        if (i != suites_.end()) {
-            (*i).weak_suite_ptr_ = weak_suite_ptr();
-        }
-        else {
-            suites_.emplace_back(s);
-        }
-    }
-}
-
-void ClientSuites::add_suite(suite_ptr suite) {
-    if (suite.get()) {
-
-        // *IMPORTANT* update weak_suite_ptr_
-        auto i = find_suite(suite->name());
-        if (i != suites_.end()) {
-            (*i).weak_suite_ptr_ = weak_suite_ptr(suite);
-        }
-        else {
-            suites_.emplace_back(suite->name(), weak_suite_ptr(suite));
-        }
-        handle_changed_ = true;
-
-#ifdef DEBUG_ME
-        i = suites_.find_suite(suite->name());
-        assert(i != suites_.end());
-        assert((*i).weak_suite_ptr_.lock().get());
-#endif
-    }
-}
-
-void ClientSuites::remove_suite(const std::string& s) {
-    auto i = find_suite(s);
-    if (i != suites_.end()) {
-        if ((*i).weak_suite_ptr_.lock().get()) {
-            handle_changed_ = true;
-        }
-        suites_.erase(i);
-    }
-}
-
-bool ClientSuites::remove_suite(suite_ptr suite) {
-    if (suite.get()) {
-        auto i = find_suite(suite->name());
-        if (i != suites_.end()) {
-            handle_changed_ = true;
-            suites_.erase(i);
-            return true;
-        }
-    }
-    return false;
-}
-
-void ClientSuites::suite_added_in_defs(suite_ptr suite) {
-    if (auto_add_new_suites_)
-        add_suite(suite);
-    else {
-        // *IF* and *ONLY IF* the suite was previously registered added, *UPDATE* its suite_ptr
-        auto i = find_suite(suite->name());
-        if (i != suites_.end()) {
-            // previously registered suite, update
-            add_suite(suite);
-        }
-    }
-}
-
-void ClientSuites::suite_deleted_in_defs(suite_ptr suite) {
-    // Deleted suites are *NOT* automatically removed
-    // They have to be moved explicitly by the user. Reset to weak ptr
-    if (suite.get()) {
-        auto i = find_suite(suite->name());
-        if (i != suites_.end()) {
-            handle_changed_      = true;
-            modify_change_no_    = Ecf::modify_change_no(); // need to pass back to client
-            (*i).weak_suite_ptr_ = weak_suite_ptr();        // reset suite ptr, not strictly necessary
-        }
-    }
-}
-
-void ClientSuites::collateChanges(DefsDelta& changes) const {
-    for (const HSuite& s : suites_) {
-        suite_ptr suite = s.weak_suite_ptr_.lock();
-        if (suite.get()) {
-            suite->collateChanges(changes);
-        }
-    }
-}
-
-defs_ptr ClientSuites::create_defs(defs_ptr server_defs) const {
-    /// Clear handle changed, so we can detect suites added or removed for this handle
-    handle_changed_ = false;
-
-    // If the user has registered *ALL* the suites just return the server defs
-    auto suites_end = suites_.end();
-    if (suites_.size() == server_defs->suiteVec().size()) {
-        size_t real_suite_count = 0;
-        for (auto i = suites_.begin(); i != suites_end; ++i) {
-            suite_ptr suite = (*i).weak_suite_ptr_.lock();
-            if (suite.get())
-                real_suite_count++;
-        }
-        if (real_suite_count == server_defs->suiteVec().size()) {
-
-            server_defs->set_state_change_no(Ecf::state_change_no());
-            server_defs->set_modify_change_no(Ecf::modify_change_no());
-
-            // Update local modify_change_no_ *AND* state_change_no_
-            // ***** Note: Otherwise NewsCmd which computes change numbers over
-            // ***** registered suites will not be correct. causing unnecessary sync's
-            modify_change_no_ = Ecf::modify_change_no();
-            state_change_no_  = Ecf::state_change_no();
-            return server_defs;
-        }
-    }
-
-    // CREATE NEW DEFS, using the registered suites
-    //
-    // *** We do not use local state_change_no_. That is used ONLY when all suites ***
-    // *** are registered.                                                         ***
-    //
-    // add_suite() below will incremented the modify_change_no.
-    // We don't want to do this, as change for suites *not in* the our handle will get skewed
-    // This class ensure that any changes made are reset to their original values
-    EcfPreserveChangeNo preserveChangeNo;
-
-    // Create defs to be sent to the client, with the registered suites.
-    defs_ptr newly_created_defs = Defs::create();
-    newly_created_defs->copy_defs_state_only(server_defs);
-
-    // Store the state/modify change number to the newly created defs *over* the objects that have changed
-    unsigned int the_max_state_change_no  = server_defs->defs_only_max_state_change_no();
-    unsigned int the_max_modify_change_no = 0;
-
-    // Handle suites that get deleted. Need a full sync
-    the_max_modify_change_no = std::max(the_max_modify_change_no, modify_change_no_);
-
-    // Suites should already be in order
-    for (auto i = suites_.begin(); i != suites_end; ++i) {
-        suite_ptr suite = (*i).weak_suite_ptr_.lock();
-        if (suite.get()) {
-
-            // Preserve the change/modify numbers, as these will updated on the suite, by addSuite() below
-            unsigned int suite_state_change_no  = suite->state_change_no();
-            unsigned int suite_modify_change_no = suite->modify_change_no();
-
-            the_max_state_change_no  = std::max(the_max_state_change_no, suite_state_change_no);
-            the_max_modify_change_no = std::max(the_max_modify_change_no, suite_modify_change_no);
-
-            // To avoid copying the suites, we will just add the suites, to the newly created defs
-            // However this presents a problem with the suites defs pointer. To avoid corrupting
-            // the server, we must reset the defs pointer.
-            // The newly_created_defs/Defs serialisation will re-adjust the suites defs pointer
-            Defs* old_defs = suite->defs();
-
-            // This will end up setting the suite's defs pointer to 'newly_created_defs'.
-            // This is wrong, since we only have a single suite
-            suite->set_defs(nullptr);            // otherwise addSuite, will complain
-            newly_created_defs->addSuite(suite); // will update modify_change_no, see comment at top
-
-            suite->set_defs(old_defs);                           // reset the defs, since addSuite() changed defs ptr
-            suite->set_state_change_no(suite_state_change_no);   // reset in case addSuite() changed this
-            suite->set_modify_change_no(suite_modify_change_no); // reset in case addSuite() changed this
-        }
-    }
-
-    // Store the max in the defs, for transmission to client. The client uses this for syncing
-    newly_created_defs->set_state_change_no(the_max_state_change_no);
-    newly_created_defs->set_modify_change_no(the_max_modify_change_no);
-    return newly_created_defs;
-}
-
-void ClientSuites::max_change_no(unsigned int& the_max_state_change_no, unsigned int& the_max_modify_change_no) const {
-    /// get the max state change_no due to:
-    ///   o Defs state changed
-    ///   o Suite order changed
-    ///   o Defs flag changed
-    ///   o Defs server state changed.
-    ///   o Defs server variables changed
-    the_max_state_change_no = defs_->defs_only_max_state_change_no();
-
-    // Take into account case where all suites are registered
-    the_max_state_change_no = std::max(the_max_state_change_no, state_change_no_);
-
-    // Take into account registered suites that get deleted, and where all suites registered
-    the_max_modify_change_no = 0;
-    the_max_modify_change_no = std::max(the_max_modify_change_no, modify_change_no_);
-
-    for (const HSuite& p : suites_) {
-        suite_ptr suite = p.weak_suite_ptr_.lock();
-        if (suite.get()) {
-            the_max_modify_change_no = std::max(the_max_modify_change_no, suite->modify_change_no());
-            the_max_state_change_no  = std::max(the_max_state_change_no, suite->state_change_no());
-        }
-    }
-}
-
-void ClientSuites::suites(std::vector<std::string>& names) const {
-    names.reserve(suites_.size());
-    auto suites_end = suites_.end();
-    for (auto i = suites_.begin(); i != suites_end; ++i) {
-        names.push_back((*i).name_);
-    }
-}
-
-std::string ClientSuites::dump() const {
-    unsigned int maxstatechangeno  = 0;
-    unsigned int maxmodifychangeno = 0;
-    max_change_no(maxstatechangeno, maxmodifychangeno);
-
-    std::stringstream ss;
-    ss << "  handle(" << handle() << ") user(" << user_ << ") auto_add_new_suites(" << auto_add_new_suites_
-       << ") suites_.size(" << suites_.size() << ") suites(";
-
-    auto suites_end = suites_.end();
-    for (auto i = suites_.begin(); i != suites_end; ++i) {
-        suite_ptr suite = (*i).weak_suite_ptr_.lock();
-        if (suite.get()) {
-            ss << " " << suite->name();
-        }
-        else {
-            ss << " " << (*i).name_ << ":NULL";
-        }
-    }
-    ss << ") max(" << maxstatechangeno << "," << maxmodifychangeno << ")";
-    return ss.str();
-}
-
-void ClientSuites::update_suite_order() {
-    const std::vector<suite_ptr>& server_suite_vec = defs_->suiteVec();
-    size_t server_suite_vec_size                   = server_suite_vec.size();
-
-    auto suites_end = suites_.end();
-    for (auto i = suites_.begin(); i != suites_end; ++i) {
-        for (size_t s = 0; s < server_suite_vec_size; s++) {
-            if ((*i).name_ == server_suite_vec[s]->name()) {
-                (*i).index_ = static_cast<int>(s);
-                break;
-            }
-        }
-    }
-
-    std::sort(suites_.begin(), suites_.end(), [](const HSuite& a, const HSuite& b) { return a.index_ < b.index_; });
-}
-
-std::vector<HSuite>::iterator ClientSuites::find_suite(const std::string& name) {
-    auto suites_end = suites_.end();
-    for (auto i = suites_.begin(); i != suites_end; ++i) {
-        if ((*i).name_ == name) {
-            return i;
-        }
-    }
-    return suites_end;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ClientSuites.hpp 5.13.0-1/ANode/src/ecflow/node/ClientSuites.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ClientSuites.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ClientSuites.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ClientSuites_HPP
-#define ecflow_node_ClientSuites_HPP
-
-///
-/// \brief The definition file could hold hundreds of suites, however the client
-/// may only be interested in a small subset. By allowing the client to register
-/// the suites they are interested in, we can reduce the network traffic
-/// when they ask for updates.(ie via sync or news)
-/// When the Client registers an interest in suites it is returned a handle,
-/// this handle must is passed back to the server as a reference, with the sync'ing commands
-///
-/// Users are allowed to register interest in suite that have not yet been added
-/// This will only work provided we have a definition
-///
-///
-/// \note Change of suite order is handled by OrderMemento
-///       and *NOT* by the ClientSuites, however whenever suites are:
-///       registered and added/deleted:
-///       then:
-///           defs_ptr create_defs(Defs* server_defs) const;
-///
-///       Will return the suites in the same order as the defs
-///
-
-#include <limits>
-#include <string>
-#include <vector>
-
-#include "ecflow/node/NodeFwd.hpp"
-
-namespace ecf {
-
-struct HSuite
-{
-    HSuite(const std::string& name, weak_suite_ptr p, int index = std::numeric_limits<int>::max())
-        : name_(name),
-          weak_suite_ptr_(p),
-          index_(index) {}
-
-    explicit HSuite(const std::string& name) : name_(name), index_(std::numeric_limits<int>::max()) {}
-
-    std::string name_;              // suite name
-    weak_suite_ptr weak_suite_ptr_; // does suite exist in defs, need to lock, to find out
-    int index_;                     // suites in handles must be in same order as defs
-};
-
-class ClientSuites {
-public:
-    /// Will automatically create a unique handle
-    ClientSuites(Defs*,
-                 unsigned int handle,
-                 bool auto_add_new_suites,
-                 const std::vector<std::string>& suites,
-                 const std::string& user);
-
-    /// Return the handle, returned to the client, and required for all correspondence
-    /// between client server. This value is always > 0
-    unsigned int handle() const { return handle_; }
-
-    /// return the user who requested this handle
-    const std::string& user() const { return user_; }
-
-    /// The handle changed flag is set to true whenever a ClinetSuites is created
-    /// or when suites are added/removed from it. The alternative way would have
-    /// been to update the modify change number, but this would have affected all handles
-    bool handle_changed() const { return handle_changed_; }
-
-    /// Add an interest to this suite
-    void add_suite(const std::string&);
-    void add_suite(suite_ptr);
-
-    /// no longer interested in this suite. Explicit remove
-    void remove_suite(const std::string&);
-    bool remove_suite(suite_ptr);
-
-    /// A new suite is being added in the definition.
-    /// If it was already registered update the suite ptr
-    /// If auto add new suite enabled,register it
-    void suite_added_in_defs(suite_ptr);
-
-    /// The suite is being deleted, update modify_change_no. So we do a full sync
-    /// RESETs suite ptr. Deleted suites are *NOT* automatically removed
-    void suite_deleted_in_defs(suite_ptr);
-
-    /// Collate the incremental changes, made to my suites
-    void collateChanges(DefsDelta& changes) const;
-
-    // Only return the defs state and suites that the client has registered in this suite
-    // *HOWEVER* if the client has registered all the suites, just return the server defs
-    //           *with* the updated change numbers
-    // *OTHERWISE*
-    /// Creates a new defs, by adding the suites to the defs
-    /// The defs is to be transferred to the client
-    /// Suites are returned in the same order as the defs
-    /// We avoid copying, but need to adjust suites defs pointer
-    /// This will clear the handle_changed_  flag
-    defs_ptr create_defs(defs_ptr server_defs) const;
-
-    // iterates overs its suites and return max state and modify change numbers
-    void max_change_no(unsigned int& state_change_no, unsigned int& modify_change_no) const;
-
-    /// Enable/disable interest in new suites.
-    /// if the flag is true, when ever new suites are added to the defs
-    /// The internal list is updated.
-    void add_new_suite(bool flag) { auto_add_new_suites_ = flag; }
-    bool auto_add_new_suites() const { return auto_add_new_suites_; }
-
-    /// returns the list of suites
-    void suites(std::vector<std::string>& names) const;
-
-    /// Update suites to be in same order as Defs.
-    /// This should be done externally to avoid update after individual add
-    void update_suite_order();
-
-    /// For debug dumps
-    std::string dump() const;
-
-private:
-    std::vector<HSuite>::iterator find_suite(const std::string& name);
-
-private:
-    Defs* defs_;
-
-    std::string user_; // user who create this handle
-    std::vector<HSuite> suites_;
-
-    unsigned int handle_; // This must be unique
-
-    // The modify_change_no_ is required specifically when a registered suite is deleted
-    // Both modify_change_no_ & state_change_no_ are required when user has registered
-    // with *ALL* the suites. In this case we need to ensure that after a SYNC/create_defs
-    // the NewsCmd call to max_change_no() is in sync with global change numbers.
-    mutable unsigned int state_change_no_{0};
-    mutable unsigned int modify_change_no_{0};
-
-    bool auto_add_new_suites_;
-    mutable bool handle_changed_{false}; // set when handle created, or when suites added/removed
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_ClientSuites_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/CmdContext.cpp 5.13.0-1/ANode/src/ecflow/node/CmdContext.cpp
--- 5.12.4-1/ANode/src/ecflow/node/CmdContext.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/CmdContext.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/CmdContext.hpp"
-
-namespace ecf {
-bool CmdContext::in_command_ = false;
-
-CmdContext::CmdContext() {
-    in_command_ = true;
-}
-
-CmdContext::~CmdContext() {
-    in_command_ = false;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/CmdContext.hpp 5.13.0-1/ANode/src/ecflow/node/CmdContext.hpp
--- 5.12.4-1/ANode/src/ecflow/node/CmdContext.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/CmdContext.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,36 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_CmdContext_HPP
-#define ecflow_node_CmdContext_HPP
-
-///
-/// \brief This class allow client to determine whether they are in a middle of a command.
-///
-
-namespace ecf {
-
-class CmdContext {
-public:
-    CmdContext();
-    // Disable copy (and move) semantics
-    CmdContext(const CmdContext&)                  = delete;
-    const CmdContext& operator=(const CmdContext&) = delete;
-
-    ~CmdContext();
-
-    static bool in_command() { return in_command_; }
-
-private:
-    static bool in_command_;
-};
-} // namespace ecf
-
-#endif /* ecflow_node_CmdContext_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Defs.cpp 5.13.0-1/ANode/src/ecflow/node/Defs.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Defs.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Defs.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,2156 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Defs.hpp"
-
-#include <cassert>
-#include <limits>
-#include <stdexcept>
-
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/NodePath.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/StringSplitter.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/node/AbstractObserver.hpp"
-#include "ecflow/node/DefsDelta.hpp"
-#include "ecflow/node/ExprDuplicate.hpp"
-#include "ecflow/node/JobCreationCtrl.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/NodeState.hpp"
-#include "ecflow/node/NodeStats.hpp"
-#include "ecflow/node/NodeTreeVisitor.hpp"
-#include "ecflow/node/ResolveExternsVisitor.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/node/move_peer.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp" /// The reason why Parser code moved into Defs, avoid cyclic dependency
-
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-using namespace ecf;
-using namespace std;
-
-// #define DEBUG_JOB_SUBMISSION 1
-// #define DEBUG_MEMENTO 1
-
-Defs::Defs() = default;
-
-Defs::Defs(const std::string& port) : server_(port) {
-}
-
-Defs::Defs(const Defs& rhs) : state_(rhs.state_), server_(rhs.server_), flag_(rhs.flag_), client_suite_mgr_(this) {
-    size_t theSize = rhs.suiteVec_.size();
-    for (size_t s = 0; s < theSize; s++) {
-        suite_ptr suite_copy = std::make_shared<Suite>(*rhs.suiteVec_[s]);
-        suite_copy->set_defs(this);
-        suiteVec_.push_back(suite_copy);
-    }
-
-    // edit history is not copied
-    // externs not copied
-    // observers not copied
-}
-
-void Defs::copy_defs_state_only(const defs_ptr& server_defs) {
-    if (!server_defs)
-        return;
-
-    // Initialise the defs state. We need to reflect the real state.
-    set_state(server_defs->state());
-
-    // initialise flag
-    flag_ = server_defs->get_flag();
-
-    // Initialise the server state
-    set_server().set_state(server_defs->server().get_state());
-    set_server().set_user_variables(server_defs->server().user_variables());
-    set_server().set_server_variables(server_defs->server().server_variables());
-}
-
-Defs& Defs::operator=(const Defs& rhs) {
-    if (this != &rhs) {
-        Defs tmp(rhs); // does *NOT* use Suite::operator=(const Suite& rhs), we use copy/swap
-
-        std::swap(state_, tmp.state_);
-        std::swap(server_, tmp.server_);
-        std::swap(suiteVec_, tmp.suiteVec_);
-        std::swap(flag_, tmp.flag_);
-
-        // edit history is not copied
-        // externs not copied
-        // observers not copied
-
-        size_t vec_size = suiteVec_.size();
-        for (size_t i = 0; i < vec_size; i++) {
-            suiteVec_[i]->set_defs(this);
-        }
-
-        modify_change_no_ = Ecf::incr_modify_change_no();
-    }
-    return *this;
-}
-
-defs_ptr Defs::create() {
-    return std::make_shared<Defs>();
-}
-defs_ptr Defs::create(const std::string& port) {
-    return std::make_shared<Defs>(port);
-} // Defs::create(port)
-
-Defs::~Defs() {
-    //    cout << "   Deleting defs "\n";
-    if (!Ecf::server()) {
-        notify_delete();
-    }
-
-    // Duplicate AST are held in a static map. Delete them, to avoid valgrind complaining
-    ExprDuplicate reclaim_cloned_ast_memory;
-}
-
-void Defs::handle_migration() {
-    // Fix up any migration issues. Remove when in Bolgna, and ecflow4 no longer used
-    for (const auto& s : suiteVec_) {
-        s->handle_migration(s->calendar());
-    }
-
-    // remove any edit history that is no longer referenced. Ignore root, which will not be found
-    auto it = edit_history_.begin();
-    while (it != edit_history_.end()) {
-
-        if ((*it).first == Str::ROOT_PATH()) {
-            it++;
-            continue; // root path is defs, which is not a node, hence ignore
-        }
-
-        node_ptr node = findAbsNode((*it).first);
-        if (!node.get()) {
-            it = edit_history_.erase(it);
-        }
-        else
-            it++;
-    }
-}
-
-///// State relation functions: ==================================================
-NState::State Defs::state() const {
-    return state_.state();
-}
-
-void Defs::set_state_only(NState::State the_new_state) {
-    state_.setState(the_new_state); // this will update state_change_no
-}
-
-void Defs::set_state(NState::State the_new_state) {
-    set_state_only(the_new_state); // this will update state_change_no
-
-    // Log the state change
-    //           " " +  submitted(max) + ": /"
-    // reserve : 1   +  9              + 3      = 13
-    std::string log_state_change;
-    log_state_change.reserve(13);
-    log_state_change += " ";
-    log_state_change += NState::toString(the_new_state);
-    log_state_change += ": /";
-    ecf::log(Log::LOG, log_state_change);
-}
-
-void Defs::set_most_significant_state() {
-    NState::State computedStateOfImmediateChildren =
-        ecf::theComputedNodeState(suiteVec_, true /* immediate children only */);
-    if (computedStateOfImmediateChildren != state_.state())
-        set_state(computedStateOfImmediateChildren);
-}
-
-/// Others ======================================================================
-void Defs::check_job_creation(job_creation_ctrl_ptr jobCtrl) {
-    /// Job generation checking. is done via the python API
-    /// As such it done directly on the Defs.
-    /// However Job generation checking will end up changing the states of the DEFS
-    /// If this defs is loaded into the server the state of each node may be surprising. (i.e submitted)
-    /// Hence we need to reset the state.
-    if (!jobCtrl.get())
-        throw std::runtime_error("Defs::check_job_creation: NULL JobCreationCtrl passed");
-
-    if (jobCtrl->verbose())
-        cout << "Defs::check_job_creation(verbose):\n";
-
-    // This function should NOT really change the data model
-    // The changed state is reset, hence we need to preserve change and modify numbers
-    EcfPreserveChangeNo preserveChangeNo;
-
-    if (jobCtrl->node_path().empty()) {
-
-        size_t theSize = suiteVec_.size();
-        for (size_t s = 0; s < theSize; s++) {
-            /// begin will cause creation of generated variables. The generated variables
-            /// are use in client scripts and used to locate the ecf files
-            suiteVec_[s]->begin();
-            suiteVec_[s]->check_job_creation(jobCtrl);
-
-            /// reset the state
-            suiteVec_[s]->reset(); // will reset begin
-            suiteVec_[s]->setStateOnlyHierarchically(NState::UNKNOWN);
-            set_most_significant_state();
-        }
-    }
-    else {
-
-        node_ptr node = findAbsNode(jobCtrl->node_path());
-        if (node.get()) {
-            /// begin will cause creation of generated variables. The generated variables
-            /// are use in client scripts and used to locate the ecf files
-            node->suite()->begin();
-            node->check_job_creation(jobCtrl);
-
-            /// reset the state
-            node->reset();
-            node->suite()->reset_begin();
-            node->setStateOnlyHierarchically(NState::UNKNOWN);
-        }
-        else {
-            std::stringstream ss;
-            ss << "Defs::check_job_creation: failed as node path '" << jobCtrl->node_path() << "' does not exist.\n";
-            jobCtrl->error_msg() = ss.str();
-        }
-    }
-}
-
-void Defs::do_generate_scripts(const std::map<std::string, std::string>& override) const {
-    size_t theSize = suiteVec_.size();
-    for (size_t s = 0; s < theSize; s++) {
-        suiteVec_[s]->generate_scripts(override);
-    }
-}
-void Defs::generate_scripts() const {
-    std::map<std::string, std::string> override;
-    do_generate_scripts(override);
-}
-
-static void remove_autocancelled(const std::vector<node_ptr>& auto_cancelled_nodes) {
-    // Permanently remove any auto-cancelled nodes.
-    if (!auto_cancelled_nodes.empty()) {
-        auto theNodeEnd = auto_cancelled_nodes.end();
-        string msg;
-        for (auto n = auto_cancelled_nodes.begin(); n != theNodeEnd; ++n) {
-            // If we have two autocancel in the hierarchy, with same attributes. Then
-            // (*n)->remove() on the second will fail( with a crash, SuiteChanged0 destructor,  no suite pointer)
-            // since it would already be detached. See ECFLOW-556
-            // By checking we can still reach the Defs we know we are not detached
-            if ((*n)->defs()) {
-                msg.clear();
-                msg = "autocancel ";
-                msg += (*n)->debugNodePath();
-                ecf::log(Log::MSG, msg);
-                (*n)->remove();
-            }
-        }
-    }
-}
-
-static void auto_archive(const std::vector<node_ptr>& auto_archive_nodes) {
-    if (!auto_archive_nodes.empty()) {
-        auto theNodeEnd = auto_archive_nodes.end();
-        for (auto n = auto_archive_nodes.begin(); n != theNodeEnd; ++n) {
-            // If we have two auto archive in the hierarchy, with same attributes. Then
-            // By checking we can still reach the Defs we know we are not detached
-            NodeContainer* nc = (*n)->isNodeContainer();
-            if (nc && nc->defs()) {
-                nc->archive();
-            }
-        }
-    }
-}
-
-void Defs::updateCalendar(const ecf::CalendarUpdateParams& calUpdateParams) {
-    // Collate any auto cancelled nodes as a result of calendar update
-    // Collate any auto archive nodes as a result of calendar update
-    Node::Calendar_args cal_args;
-
-    // updateCalendarCount_ is only used in *test*
-    updateCalendarCount_++;
-
-    size_t theSize = suiteVec_.size();
-    for (size_t s = 0; s < theSize; s++) {
-        suiteVec_[s]->updateCalendar(calUpdateParams, cal_args);
-    }
-
-    // Permanently remove any auto-cancelled nodes.
-    remove_autocancelled(cal_args.auto_cancelled_nodes_);
-
-    // Archive any nodes with auto archive attribute, Must be suite/family
-    auto_archive(cal_args.auto_archive_nodes_);
-}
-
-void Defs::update_calendar(Suite* suite, const ecf::CalendarUpdateParams& cal_update_params) {
-    // Collate any auto cancelled nodes as a result of calendar update
-    // Collate any auto archive nodes as a result of calendar update
-    Node::Calendar_args cal_args;
-
-    suite->updateCalendar(cal_update_params, cal_args);
-
-    // Permanently remove any auto-cancelled nodes.
-    remove_autocancelled(cal_args.auto_cancelled_nodes_);
-
-    // Archive any nodes with auto archive attribute, Must be suite/family
-    auto_archive(cal_args.auto_archive_nodes_);
-}
-
-bool Defs::catch_up_to_real_time() {
-    auto time_now = Calendar::second_clock_time();
-
-    //   cout << "Time Now: " << to_simple_string(time_now) << "\n";
-    //   for(const auto& suite : suiteVec_)  cout << suite->calendar().toString() << "\n";
-    //   cout << "===================================================================\n";
-    bool updated = false;
-    time_duration schedule_increment(0, 0, server_.jobSubmissionInterval(), 0);
-    for (const auto& suite : suiteVec_) {
-        // Check if suite has time,today,date,day,cron,late,autocancel,autoarchive attributes
-        if (suite->has_time_based_attributes()) {
-            auto suite_time = suite->calendar().suiteTime();
-            if (time_now - suite_time <= hours(1)) {
-                suite_time += schedule_increment;
-                while (suite_time <= time_now) {
-
-                    update_calendar(suite.get(), ecf::CalendarUpdateParams(suite_time, schedule_increment, true));
-
-                    // cout << suite->name() << " : " << suite->calendar().toString() << "\n";
-                    suite_time += schedule_increment;
-                    updated = true;
-                }
-            }
-        }
-    }
-    //   cout << "===================================================================\n";
-    //   for(const auto& suite : suiteVec_)  cout << suite->calendar().toString() << "\n";
-    return updated;
-}
-
-void Defs::absorb(Defs* input_defs, bool force) {
-    // Dont absorb myself.
-    if (input_defs == this) {
-        return;
-    }
-
-    // updateCalendarCount_ is *only* used in test, reset whenever a new defs is loaded
-    updateCalendarCount_ = 0;
-
-    // We must make a copy, otherwise we are iterating over a vector that is being deleted
-    std::vector<suite_ptr> suiteVecCopy = input_defs->suiteVec();
-    size_t theSize                      = suiteVecCopy.size();
-    for (size_t s = 0; s < theSize; s++) {
-
-        /// regardless remove the suite from the input defs
-        suite_ptr the_input_suite = input_defs->removeSuite(suiteVecCopy[s]);
-
-        if (force) {
-            /// The suite of the same name exists. remove it from *existing* defs
-            suite_ptr existing_suite = findSuite(the_input_suite->name());
-            if (existing_suite.get()) {
-                removeSuite(existing_suite);
-            }
-        }
-
-        /// Add the suite. Will throw if suite of same name already exists.
-        /// This stops accidental overwrite
-        addSuite(the_input_suite);
-    }
-    LOG_ASSERT(input_defs->suiteVec().empty(), "Defs::absorb");
-
-    // Copy over server user variables
-    set_server().add_or_update_user_variables(input_defs->server().user_variables());
-
-    // This only works on the client side. since server does not store externs
-    const set<string>& ex = input_defs->externs();
-    for (const auto& i : ex) {
-        add_extern(i);
-    }
-}
-
-void Defs::accept(ecf::NodeTreeVisitor& v) {
-    v.visitDefs(this);
-    size_t theSuiteVecSize = suiteVec_.size();
-    for (size_t i = 0; i < theSuiteVecSize; i++) {
-        suiteVec_[i]->accept(v);
-    }
-}
-
-void Defs::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
-    LOG_ASSERT(v.traverseObjectStructureViaVisitors(), "");
-    v.visitDefs(this);
-}
-
-bool Defs::verification(std::string& errorMsg) const {
-    size_t theSuiteVecSize = suiteVec_.size();
-    for (size_t i = 0; i < theSuiteVecSize; i++) {
-        suiteVec_[i]->verification(errorMsg);
-    }
-    return errorMsg.empty();
-}
-
-suite_ptr Defs::add_suite(const std::string& name) {
-    if (findSuite(name).get()) {
-        std::stringstream ss;
-        ss << "Add Suite failed: A Suite of name '" << name << "' already exist";
-        throw std::runtime_error(ss.str());
-    }
-    suite_ptr the_suite = Suite::create(name);
-    add_suite_only(the_suite, std::numeric_limits<std::size_t>::max());
-    return the_suite;
-}
-
-void Defs::addSuite(const suite_ptr& s, size_t position) {
-    if (findSuite(s->name()).get()) {
-        std::stringstream ss;
-        ss << "Add Suite failed: A Suite of name '" << s->name() << "' already exist";
-        throw std::runtime_error(ss.str());
-    }
-    add_suite_only(s, position);
-}
-
-void Defs::add_suite_only(const suite_ptr& s, size_t position) {
-    if (s->defs()) {
-        std::stringstream ss;
-        ss << "Add Suite failed: The suite of name '" << s->name() << "' already owned by another Defs ";
-        throw std::runtime_error(ss.str());
-    }
-
-    s->set_defs(this);
-    if (position >= suiteVec_.size()) {
-        suiteVec_.push_back(s);
-    }
-    else {
-        suiteVec_.insert(suiteVec_.begin() + position, s);
-    }
-    Ecf::incr_modify_change_no();
-    client_suite_mgr_.suite_added_in_defs(s);
-}
-
-suite_ptr Defs::removeSuite(suite_ptr s) {
-    auto i = std::find(suiteVec_.begin(), suiteVec_.end(), s);
-    if (i != suiteVec_.end()) {
-        s->set_defs(nullptr); // allows suite to added to different defs
-        suiteVec_.erase(i);   // iterator invalidated
-        Ecf::incr_modify_change_no();
-        client_suite_mgr_.suite_deleted_in_defs(s); // must be after Ecf::incr_modify_change_no();
-        return s;                                   // transfer ownership of suite
-    }
-
-    // Something serious has gone wrong. Cannot find the suite
-    cout << "Defs::removeSuite: assert failure:  suite '" << s->name() << "' suiteVec_.size() = " << suiteVec_.size()
-         << "\n";
-    for (unsigned si = 0; si < suiteVec_.size(); ++si) {
-        cout << si << " " << suiteVec_[si]->name() << "\n";
-    }
-    LOG_ASSERT(false, "Defs::removeSuite the suite not found");
-    return suite_ptr();
-}
-
-size_t Defs::child_position(const Node* child) const {
-    size_t vecSize = suiteVec_.size();
-    for (size_t t = 0; t < vecSize; t++) {
-        if (suiteVec_[t].get() == child) {
-            return t;
-        }
-    }
-    return std::numeric_limits<std::size_t>::max();
-}
-
-node_ptr Defs::removeChild(Node* child) {
-    size_t vecSize = suiteVec_.size();
-    for (size_t t = 0; t < vecSize; t++) {
-        if (suiteVec_[t].get() == child) {
-            Ecf::incr_modify_change_no();
-            suiteVec_[t]->set_defs(nullptr); // Must be set to NULL, allows suite to be added to different defs
-            client_suite_mgr_.suite_deleted_in_defs(suiteVec_[t]); // must be after Ecf::incr_modify_change_no();
-            node_ptr node = std::dynamic_pointer_cast<Node>(suiteVec_[t]);
-            suiteVec_.erase(suiteVec_.begin() + t);
-            return node;
-        }
-    }
-
-    // Something has gone wrong.
-    cout << "Defs::removeChild: assert failed:  suite '" << child->name() << "' suiteVec_.size() = " << suiteVec_.size()
-         << "\n";
-    for (unsigned i = 0; i < suiteVec_.size(); ++i) {
-        cout << i << " " << suiteVec_[i]->name() << "\n";
-    }
-    LOG_ASSERT(false, "Defs::removeChild,the suite not found");
-    return node_ptr();
-}
-
-bool Defs::addChild(const node_ptr& child, size_t position) {
-    LOG_ASSERT(child.get(), "");
-    LOG_ASSERT(child->isSuite(), "");
-
-    // *** CANT construct shared_ptr from a raw pointer, must use dynamic_pointer_cast,
-    // *** otherwise the reference counts will get messed up.
-    // If the suite of the same exists, it is deleted first
-    addSuite(std::dynamic_pointer_cast<Suite>(child), position);
-    return true;
-}
-
-void Defs::add_extern(const std::string& ex) {
-    if (ex.empty()) {
-        throw std::runtime_error("Defs::add_extern: Cannot add empty extern");
-    }
-    externs_.insert(ex);
-    // auto result = externs_.insert(ex);
-    // cout << "Defs::add_extern " << ex << " result " << result.second << "\n";
-}
-
-void Defs::auto_add_externs(bool remove_existing_externs_first) {
-    // cout << "\nDefs::auto_add_externs START EXTERNS size: " << externs_.size() << "
-    // ==================================================== \n";
-    if (remove_existing_externs_first) {
-        externs_.clear();
-    }
-    /// Automatically add externs
-    ResolveExternsVisitor visitor(this);
-    acceptVisitTraversor(visitor);
-    // cout << "Defs::auto_add_externs END EXTERNS size : " << externs_.size() << "
-    // ==================================================== \n";
-}
-
-void Defs::beginSuite(const suite_ptr& suite) {
-    if (!suite.get())
-        throw std::runtime_error("Defs::beginSuite: Begin failed as suite is not loaded");
-
-    if (!suite->begun()) {
-        // Hierarchical set the state. Handle case where we have children that are all defstatus complete
-        // and hence needs parent set to complete. See Simulator/good_defs/operations/naw.def
-        //	  family naw
-        //	    family general
-        //	      time 06:00
-        //	      task metgrams
-        //	        defstatus complete
-        //	      task equipot
-        //	        defstatus complete
-        //	    endfamily
-        suite->begin();
-
-        set_most_significant_state();
-    }
-    else {
-        LOG(Log::WAR, "Suite " << suite->name() << " has already begun");
-    }
-}
-
-void Defs::beginAll() {
-    bool at_least_one_suite_begun = false;
-    size_t theSuiteVecSize        = suiteVec_.size();
-    for (size_t s = 0; s < theSuiteVecSize; s++) {
-        if (!suiteVec_[s]->begun()) {
-            suiteVec_[s]->begin();
-            at_least_one_suite_begun = true;
-        }
-    }
-
-    if (at_least_one_suite_begun) {
-        set_most_significant_state();
-    }
-}
-
-void Defs::reset_begin() {
-    std::for_each(suiteVec_.begin(), suiteVec_.end(), [](suite_ptr s) { s->reset_begin(); });
-}
-
-void Defs::requeue() {
-    bool edit_history_set = flag().is_set(ecf::Flag::MESSAGE);
-    flag_.reset();
-    if (edit_history_set)
-        flag().set(ecf::Flag::MESSAGE);
-
-    Node::Requeue_args args;
-    size_t theSuiteVecSize = suiteVec_.size();
-    for (size_t s = 0; s < theSuiteVecSize; s++) {
-        suiteVec_[s]->requeue(args);
-    }
-
-    set_most_significant_state();
-}
-
-void Defs::sort_attributes(ecf::Attr::Type attr, bool recursive, const std::vector<std::string>& no_sort) {
-    if (attr == ecf::Attr::VARIABLE || attr == ecf::Attr::ALL)
-        server_.sort_variables();
-
-    if (recursive) {
-        size_t theSuiteVecSize = suiteVec_.size();
-        for (size_t s = 0; s < theSuiteVecSize; s++) {
-            SuiteChanged changed(suiteVec_[s]);
-            suiteVec_[s]->sort_attributes(attr, recursive, no_sort);
-        }
-    }
-}
-
-void Defs::check_suite_can_begin(const suite_ptr& suite) const {
-    NState::State suiteState = suite->state();
-    if (!suite->begun() && suiteState != NState::UNKNOWN && suiteState != NState::COMPLETE) {
-        int count = 0;
-        std::vector<Task*> tasks;
-        getAllTasks(tasks);
-        std::stringstream ts;
-        for (auto& task : tasks) {
-            if (task->state() == NState::ACTIVE || task->state() == NState::SUBMITTED) {
-                ts << "   " << task->absNodePath() << "\n";
-                count++;
-            }
-        }
-        /// allow suite to begin even its aborted provide no tasks in active or submitted states
-        if (count > 0) {
-            std::stringstream ss;
-            ss << "Begin failed as suite " << suite->name() << "(computed state=" << NState::toString(suiteState)
-               << ") can only begin if its in UNKNOWN or COMPLETE state\n";
-            ss << "Found " << count << " tasks with state 'active' or 'submitted'\n";
-            ss << ts.str();
-            ss << "Use the force argument to bypass this check, at the risk of creating zombies\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-}
-
-bool Defs::hasTimeDependencies() const {
-    size_t theSuiteVecSize = suiteVec_.size();
-    for (size_t s = 0; s < theSuiteVecSize; s++) {
-        if (suiteVec_[s]->hasTimeDependencies())
-            return true;
-    }
-    return false;
-}
-
-std::string Defs::print(PrintStyle::Type_t t) const {
-    PrintStyle style(t);
-    std::string s;
-    print(s);
-    return s;
-}
-
-void Defs::print(std::string& os) const {
-    // cout << "Defs::print(start) print_cache_ " << print_cache_ << "\n";
-    os.clear();
-    if (print_cache_ != 0)
-        os.reserve(print_cache_);
-    else
-        os.reserve(4096);
-    os += "#";
-    os += ecf::Version::raw();
-    os += "\n";
-
-    if (!PrintStyle::defsStyle())
-        write_state(os);
-
-    if (PrintStyle::getStyle() == PrintStyle::STATE) {
-        os += "# server state: ";
-        os += SState::to_string(server().get_state());
-        os += "\n";
-    }
-
-    // In PrintStyle::MIGRATE we do NOT persist the externs. (+matches boost serialisation)
-    if (!PrintStyle::persist_style()) {
-        auto extern_end = externs_.end();
-        for (auto i = externs_.begin(); i != extern_end; ++i) {
-            os += "extern ";
-            os += *i;
-            os += "\n";
-        }
-    }
-
-    for (const auto& s : suiteVec_) {
-        s->print(os);
-    }
-
-    os += "# enddef\n"; // ECFLOW-1227 so user knows there was no truncation
-    print_cache_ = os.size();
-    // cout << "Defs::print print_cache_ " << print_cache_ << "\n";
-}
-
-void Defs::write_state(std::string& os) const {
-    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e.
-    //                 task a; task b;
-    // *IMPORTANT* make sure name are unique, i.e can't have state: and server_state:
-    // Otherwise read_state() will mess up
-    os += "defs_state ";
-    os += PrintStyle::to_string();
-
-    if (state_ != NState::UNKNOWN) {
-        os += " state>:";
-        os += NState::toString(state_);
-    } // make <state> is unique
-    if (flag_.flag() != 0) {
-        os += " flag:";
-        flag_.write(os);
-    }
-    if (state_change_no_ != 0) {
-        os += " state_change:";
-        os += ecf::convert_to<std::string>(state_change_no_);
-    }
-    if (modify_change_no_ != 0) {
-        os += " modify_change:";
-        os += ecf::convert_to<std::string>(modify_change_no_);
-    }
-    if (server().get_state() != ServerState::default_state()) {
-        os += " server_state:";
-        os += SState::to_string(server().get_state());
-    }
-
-    // This only works when the full defs is requested, otherwise zero as defs is fabricated for handles
-    os += " cal_count:";
-    os += ecf::convert_to<std::string>(updateCalendarCount_);
-    os += "\n";
-
-    // This read by the DefsParser
-    const std::vector<Variable>& server_user_variables = server().user_variables();
-    size_t the_size                                    = server_user_variables.size();
-    for (size_t i = 0; i < the_size; ++i)
-        server_user_variables[i].print(os);
-
-    const std::vector<Variable>& server_variables = server().server_variables();
-    the_size                                      = server_variables.size();
-    for (size_t i = 0; i < the_size; ++i)
-        server_variables[i].print_server_variable(os); // edit var value # server
-
-    // READ by Defs::read_history()
-    // We need to define a separator for the message, will to allow it to be re-read
-    // This separator cannot be :
-    // ' ' space, used in the messages
-    // %  Used in job submission
-    // :  Used in time, and name (:ma0)
-    // [] Used in time
-    // integers used in the time.
-    // -  Used in commands
-    if (save_edit_history_) {
-        Indentor in;
-        for (const auto& i : edit_history_) {
-            Indentor::indent(os);
-            os += "history ";
-            os += i.first;
-            os += " ";                                      // node path
-            const std::vector<std::string>& vec = i.second; // list of requests
-            for (const auto& c : vec) {
-
-                // We expect to output a single newline, hence if there are additional new lines
-                // It can mess  up, re-parse. i.e during alter change label/value, user could have added newlines
-                if (c.find("\n") == std::string::npos) {
-                    os += "\b";
-                    os += c;
-                }
-                else {
-                    std::string h = c;
-                    Str::replaceall(h, "\n", "\\n");
-                    os += "\b";
-                    os += h;
-                }
-            }
-            os += "\n";
-        }
-        save_edit_history_ = false;
-    }
-}
-
-std::string Defs::dump_edit_history() const {
-    std::stringstream os;
-    for (const auto& i : edit_history_) {
-        os << "history ";
-        os << i.first;
-        os << "  ";                                     // node path
-        const std::vector<std::string>& vec = i.second; // list of requests
-        for (const auto& c : vec) {
-
-            // We expect to output a single newline, hence if there are additional new lines
-            // It can mess  up, re-parse. i.e during alter change label/value, user could have added newlines
-            if (c.find("\n") == std::string::npos) {
-                os << " ";
-                os << c;
-            }
-            else {
-                std::string h = c;
-                Str::replaceall(h, "\n", "\\n");
-                os << " ";
-                os << h;
-            }
-        }
-        os << "\n";
-    }
-    return os.str();
-}
-
-void Defs::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
-    //   cout << "line = " << line << "\n";
-    std::string token;
-    size_t line_tokens_size = lineTokens.size();
-    for (size_t i = 2; i < line_tokens_size; i++) {
-        token.clear();
-        const std::string& line_token_i = lineTokens[i];
-        if (line_token_i.find("state>:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Defs::read_state: state extraction failed : " + line_token_i);
-            std::pair<NState::State, bool> state_pair = NState::to_state(token);
-            if (!state_pair.second)
-                throw std::runtime_error("Defs::read_state: Invalid state specified : " + token);
-            set_state_only(state_pair.first);
-        }
-        else if (line_token_i.find("flag:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Defs::read_state: Invalid flag specified : " + line);
-            flag().set_flag(token); // this can throw
-        }
-        else if (line_token_i.find("state_change:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Defs::read_state: Invalid state_change specified : " + line);
-            int sc = Extract::theInt(token, "Defs::read_state: invalid state_change specified : " + line);
-            set_state_change_no(sc);
-        }
-        else if (line_token_i.find("modify_change:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Defs::read_state: Invalid modify_change specified : " + line);
-            int mc = Extract::theInt(token, "Defs::read_state: invalid state_change specified : " + line);
-            set_modify_change_no(mc);
-        }
-        else if (line_token_i.find("server_state:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Defs::read_state: Invalid server_state specified : " + line);
-            if (!SState::isValid(token))
-                throw std::runtime_error("Defs::read_state: Invalid server_state specified : " + line);
-            set_server().set_state(SState::toState(token));
-        }
-        else if (line_token_i.find("cal_count:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Defs::read_state: Invalid cal_count specified : " + line);
-            updateCalendarCount_ = Extract::theInt(token, "Defs::read_state: invalid cal_count specified : " + line);
-        }
-    }
-}
-
-void Defs::read_history(const std::string& line, const std::vector<std::string>& lineTokens) {
-    // expect:
-    // history <node_path> \bmsg1\bmsg2
-    // The message can contain spaces,
-    // Multiple spaces will be lost !!
-    // Edit history older than ecf_prune_node_log_ days, will be pruned.
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("Defs::read_history: Invalid history " + line);
-
-    DefsHistoryParser parser;
-    parser.parse(line);
-
-    const std::vector<std::string>& parsed_messages = parser.parsed_messages();
-    if (ecf_prune_node_log_ == 0) {
-        for (const auto& parsed_message : parsed_messages) {
-            add_edit_history(lineTokens[1], parsed_message);
-        }
-    }
-    else {
-        std::vector<std::string> vec;
-        date todays_date_in_utc = day_clock::universal_day();
-
-        for (const auto& parsed_message : parsed_messages) {
-            // extract the date, expecting MSG:[HH:MM:SS D.M.YYYY]
-            if (parsed_message.find("MSG:[") == 0) {
-
-                size_t space_pos = parsed_message.find(" ");
-                size_t close_p   = parsed_message.find("]");
-                std::string date = parsed_message.substr(space_pos + 1, close_p - space_pos - 1);
-                vec.clear();
-                Str::split(date, vec, ".");
-                if (vec.size() == 3) {
-                    try {
-                        int day   = ecf::convert_to<int>(vec[0]);
-                        int month = ecf::convert_to<int>(vec[1]);
-                        int year  = ecf::convert_to<int>(vec[2]);
-
-                        boost::gregorian::date node_log_date(year, month, day);
-                        boost::gregorian::date_duration duration = todays_date_in_utc - node_log_date;
-                        if (duration.days() > ecf_prune_node_log_) {
-                            continue;
-                        }
-                    }
-                    catch (...) {
-                    }
-                }
-            }
-            add_edit_history(lineTokens[1], parsed_message);
-        }
-    }
-}
-
-bool Defs::compare_edit_history(const Defs& rhs) const {
-    if (edit_history_ != rhs.edit_history_)
-        return false;
-    return true;
-}
-
-bool Defs::compare_change_no(const Defs& rhs) const {
-    if (state_change_no_ != rhs.state_change_no_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Defs::compare_change_no: state_change_no_(" << state_change_no_
-                      << ") != rhs.state_change_no_(" << rhs.state_change_no_ << ")\n";
-        }
-#endif
-        return false;
-    }
-    if (modify_change_no_ != rhs.modify_change_no_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Defs::compare_change_no: modify_change_no_(" << modify_change_no_
-                      << ") != rhs.modify_change_no_(" << rhs.modify_change_no_ << ")\n";
-        }
-#endif
-        return false;
-    }
-    return true;
-}
-
-bool Defs::operator==(const Defs& rhs) const {
-    if (state() != rhs.state()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Defs::operator==  state(" << NState::toString(state()) << ") != rhs.state("
-                      << NState::toString(rhs.state()) << ")) \n";
-        }
-#endif
-        return false;
-    }
-
-    if (server_ != rhs.server()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Defs::operator== server_ != rhs.server())\n";
-        }
-#endif
-        return false;
-    }
-
-    if (flag_ != rhs.flag_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Defs::operator== ( flag_ != rhs.flag_) : '" << flag_.to_string() << "' != '"
-                      << rhs.flag_.to_string() << "'\n";
-        }
-#endif
-        return false;
-    }
-
-    /// Note:: WE specifically exclude testing of externs.
-    /// Externs are not persisted, hence cannot take part in comparison
-    /// Externs only live on the client side.
-
-    if (suiteVec_.size() != rhs.suiteVec_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Defs::operator==    suiteVec_.size(" << suiteVec_.size() << ") != rhs.suiteVec_.size( "
-                      << rhs.suiteVec_.size() << ") \n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < suiteVec_.size(); ++i) {
-        if (!(*(suiteVec_[i]) == *(rhs.suiteVec_[i]))) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Defs::operator==    !( *(suiteVec_[i]) == *(rhs.suiteVec_[i]) )\n";
-            }
-#endif
-            return false;
-        }
-    }
-    return true;
-}
-
-node_ptr Defs::findAbsNode(const std::string& pathToNode) const {
-    //	std::cout << "Defs::findAbsNode " << pathToNode << "\n";
-    // The pathToNode is of the form:
-    //     /suite
-    //     /suite/family
-    //     /suite/family/task
-    //     /suite/family/family/family/task
-    // This is 14% quicker than the previous algorithm, that split 'pathToNode' into a vector of strings first.
-    node_ptr ret;
-    bool first = false;
-    StringSplitter string_splitter(pathToNode, Str::PATH_SEPERATOR());
-    while (!string_splitter.finished()) {
-        std::string_view path_token = string_splitter.next();
-        // std::cout << "path_token:'" << path_token << "'  last = " << string_splitter.last() << "\n";
-        if (!first) {
-            for (const auto& suite : suiteVec_) {
-                if (path_token == suite->name()) {
-                    ret = suite;
-                    if (string_splitter.last()) {
-                        // cout << "finished returning " << ret->absNodePath() << " *last* suite found\n";
-                        return ret;
-                    }
-                    break;
-                }
-            }
-            if (!ret) {
-                // cout << "finished returning suite not found\n";
-                return node_ptr();
-            }
-            first = true;
-        }
-        else {
-            // cout << "seraching from " << ret->absNodePath() << " for " << ref << "\n";
-            ret = ret->find_immediate_child(path_token);
-            if (ret) {
-                if (string_splitter.last()) {
-                    // cout << "finished returning " << ret->absNodePath() << " *last* \n";
-                    return ret;
-                }
-                continue;
-            }
-            // cout << "finished returning node not found\n";
-            return node_ptr();
-        }
-    }
-    // cout << "finished returning node not found, end of loop\n";
-    return node_ptr();
-
-    // OLD code, slower. Since we are creating a vector of strings
-    //	std::vector<std::string> theNodeNames; theNodeNames.reserve(4);
-    //	NodePath::split(pathToNode,theNodeNames);
-    //	if ( theNodeNames.empty() ) {
-    //		return node_ptr();
-    //	}
-    //	size_t child_pos = 0 ; // unused
-    //	size_t pathSize = theNodeNames.size();
-    //	size_t theSuiteVecSize = suiteVec_.size();
-    //	for(size_t s = 0; s < theSuiteVecSize; s++)  {
-    //		size_t index = 0;
-    //		if (theNodeNames[index] == suiteVec_[s]->name()) {
-    //			node_ptr the_node = suiteVec_[s];
-    //			if (pathSize == 1) return the_node;
-    //			index++; // skip over suite,
-    //			while (index < pathSize) {
-    //				the_node = the_node->findImmediateChild(theNodeNames[index],child_pos);
-    //				if (the_node) {
-    //					if (index == pathSize - 1) return the_node;
-    //					index++;
-    //				}
-    //				else {
-    //					return node_ptr();
-    //				}
-    //			}
-    //			return node_ptr();
-    //		}
-    //	}
-    //	return node_ptr();
-}
-
-node_ptr Defs::find_closest_matching_node(const std::string& pathToNode) const {
-    std::vector<std::string> theNodeNames;
-    NodePath::split(pathToNode, theNodeNames);
-    if (theNodeNames.empty())
-        return node_ptr();
-
-    node_ptr closest_matching_node;
-    int index              = 0;
-    size_t theSuiteVecSize = suiteVec_.size();
-    for (size_t s = 0; s < theSuiteVecSize; s++) {
-        suiteVec_[s]->find_closest_matching_node(theNodeNames, index, closest_matching_node);
-        if (closest_matching_node.get())
-            return closest_matching_node;
-    }
-    return node_ptr();
-}
-
-bool Defs::find_extern(const std::string& pathToNode, const std::string& node_attr_name) const {
-    if (externs_.empty()) {
-        return false;
-    }
-
-    if (node_attr_name.empty()) {
-        if (externs_.find(pathToNode) != externs_.end()) {
-            return true;
-        }
-        return false;
-    }
-
-    std::string extern_path = pathToNode;
-    extern_path += Str::COLON();
-    extern_path += node_attr_name;
-
-    if (externs_.find(extern_path) != externs_.end()) {
-        return true;
-    }
-    return false;
-}
-
-suite_ptr Defs::findSuite(const std::string& name) const {
-    for (const auto& s : suiteVec_) {
-        if (s->name() == name) {
-            return s;
-        }
-    }
-    return suite_ptr();
-}
-
-std::string Defs::find_node_path(const std::string& type, const std::string& name) const {
-    for (const auto& s : suiteVec_) {
-        std::string res = s->find_node_path(type, name);
-        if (!res.empty())
-            return res;
-    }
-    return string();
-}
-
-node_ptr Defs::find_node(const std::string& type, const std::string& pathToNode) const {
-    // std::cout << "Defs::find_node  type:" << type << " path: " << pathToNode << "\n";
-    node_ptr node_p = findAbsNode(pathToNode);
-    if (!node_p) {
-        // std::cout << " node not found\n";
-        return node_p;
-    }
-
-    if (Str::caseInsCompare(type, "task")) {
-        if (node_p->isTask())
-            return node_p;
-        return node_ptr();
-    }
-    if (Str::caseInsCompare(type, "family")) {
-        if (node_p->isFamily())
-            return node_p;
-        return node_ptr();
-    }
-    if (Str::caseInsCompare(type, "suite")) {
-        if (node_p->suite())
-            return node_p;
-        return node_ptr();
-    }
-
-    throw std::runtime_error("Defs::find_node: Node of type can't be found " + type);
-    return node_ptr();
-}
-
-bool Defs::check(std::string& errorMsg, std::string& warningMsg) const {
-    for (const auto& s : suiteVec_) {
-        s->check(errorMsg, warningMsg);
-    }
-    return errorMsg.empty();
-}
-
-void Defs::getAllTasks(std::vector<Task*>& tasks) const {
-    for (const auto& s : suiteVec_) {
-        s->getAllTasks(tasks);
-    }
-}
-
-void Defs::getAllSubmittables(std::vector<Submittable*>& tasks) const {
-    for (const auto& s : suiteVec_) {
-        s->getAllSubmittables(tasks);
-    }
-}
-
-void Defs::get_all_active_submittables(std::vector<Submittable*>& tasks) const {
-    for (const auto& s : suiteVec_) {
-        s->get_all_active_submittables(tasks);
-    }
-}
-
-void Defs::get_all_tasks(std::vector<task_ptr>& tasks) const {
-    for (const auto& s : suiteVec_) {
-        s->get_all_tasks(tasks);
-    }
-}
-
-void Defs::get_all_nodes(std::vector<node_ptr>& nodes) const {
-    for (const auto& s : suiteVec_) {
-        s->get_all_nodes(nodes);
-    }
-}
-
-void Defs::get_all_aliases(std::vector<alias_ptr>& aliases) const {
-    for (const auto& s : suiteVec_) {
-        s->get_all_aliases(aliases);
-    }
-}
-
-void Defs::getAllFamilies(std::vector<Family*>& vec) const {
-    for (const auto& s : suiteVec_) {
-        s->getAllFamilies(vec);
-    }
-}
-
-void Defs::getAllNodes(std::vector<Node*>& vec) const {
-    vec.reserve(vec.size() + suiteVec_.size());
-    for (const auto& s : suiteVec_) {
-        vec.push_back(s.get());
-        s->getAllNodes(vec);
-    }
-}
-
-void Defs::getAllAstNodes(std::set<Node*>& theSet) const {
-    for (const auto& s : suiteVec_) {
-        s->getAllAstNodes(theSet);
-    }
-}
-
-bool Defs::deleteChild(Node* nodeToBeDeleted) {
-    // Find node and children of the node to be deleted and remove them from node history
-    remove_edit_history(nodeToBeDeleted);
-
-    Node* parent = nodeToBeDeleted->parent();
-    if (parent)
-        return parent->doDeleteChild(nodeToBeDeleted);
-    return doDeleteChild(nodeToBeDeleted);
-}
-
-bool Defs::doDeleteChild(Node* nodeToBeDeleted) {
-    //	std::cout << "Defs::doDeleteChild nodeToBeDeleted   = " << nodeToBeDeleted->debugNodePath() << "\n";
-
-    auto theSuiteEnd = suiteVec_.end();
-    for (auto s = suiteVec_.begin(); s != theSuiteEnd; ++s) {
-        if ((*s).get() == nodeToBeDeleted) {
-            Ecf::incr_modify_change_no();
-
-            // Remove any child archived file
-            (*s)->remove_archived_files();
-
-            client_suite_mgr_.suite_deleted_in_defs(*s); // must be after Ecf::incr_modify_change_no();
-            (*s)->set_defs(nullptr);                     // Must be set to NULL, allows re-added to a different defs
-            suiteVec_.erase(s);
-            set_most_significant_state(); // must be after suiteVec_.erase(s);
-            return true;
-        }
-    }
-
-    // recurse down only if we did not remove the suite
-    for (auto s = suiteVec_.begin(); s != theSuiteEnd; ++s) {
-        // SuiteChanged is called within doDeleteChild
-        if ((*s)->doDeleteChild(nodeToBeDeleted)) {
-            return true;
-        }
-    }
-    return false;
-}
-
-void Defs::invalidate_trigger_references() const {
-    for (const auto& s : suiteVec_) {
-        s->invalidate_trigger_references();
-    }
-}
-
-node_ptr Defs::replaceChild(const std::string& path,
-                            const defs_ptr& clientDefs,
-                            bool createNodesAsNeeded,
-                            bool force,
-                            std::string& errorMsg) {
-    node_ptr clientNode = clientDefs->findAbsNode(path);
-    if (!clientNode.get()) {
-        errorMsg = "Cannot replace node since path ";
-        errorMsg += path;
-        errorMsg += " does not exist on the client definition";
-        return node_ptr();
-    }
-
-    node_ptr serverNode = findAbsNode(path);
-    if (!force && serverNode.get()) {
-        // Check if serverNode has child tasks in submitted or active states
-        vector<Task*> taskVec;
-        serverNode->getAllTasks(taskVec); // taskVec will be empty if serverNode is a task
-        int count = 0;
-        for (Task* t : taskVec) {
-            if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED)
-                count++;
-        }
-        if (count != 0) {
-            std::stringstream ss;
-            ss << "Cannot replace node " << serverNode->debugNodePath() << " because it has " << count
-               << " tasks which are active or submitted\n";
-            ss << "Please use the 'force' option to bypass this check, at the expense of creating zombies\n";
-            errorMsg = ss.str();
-            return node_ptr();
-        }
-    }
-
-    /// REPLACE ===========================================================
-    if (!createNodesAsNeeded || serverNode.get()) {
-        // Then the child must exist in the server defs (i.e. this)
-        if (!serverNode.get()) {
-            errorMsg = "Cannot replace child since path ";
-            errorMsg += path;
-            errorMsg += " does not exist on the server definition. Please use <parent> option";
-            return node_ptr();
-        }
-
-        invalidate_trigger_references();
-
-        // HAVE a FULL match in the server
-
-        // Take a note of begun status, in case the suite is being replaced.
-        bool begin_node = serverNode->suite()->begun();
-
-        // Preserver suspended states, otherwise preserve state of client node
-        if (serverNode->isSuspended())
-            clientNode->suspend();
-
-        std::vector<node_ptr> all_server_node_children;
-        serverNode->allChildren(all_server_node_children);
-        for (auto& i : all_server_node_children) {
-            if (i->isSuspended()) {
-                node_ptr client_node = clientDefs->findAbsNode(i->absNodePath());
-                if (client_node)
-                    client_node->suspend();
-            }
-        }
-
-        // Find the position of the server node relative to its peers
-        // We use this to re-add client node at the same position
-        size_t child_pos = serverNode->position();
-
-        // Delete node on the server, Must recurse down
-        Node* parentNodeOnServer = serverNode->parent();
-        deleteChild(serverNode.get());
-
-        // Remove reference in the client defs to clientNode and detach from its parent
-        // transfer ownership to the server
-        bool addOk                  = false;
-        node_ptr client_node_to_add = clientNode->remove();
-        if (parentNodeOnServer)
-            addOk = parentNodeOnServer->addChild(client_node_to_add, child_pos);
-        else
-            addOk = addChild(client_node_to_add, child_pos);
-        LOG_ASSERT(addOk, "");
-
-        // preserve begun status. Note: we should't call begin() on the client side. As the suites will not have been
-        // begun. This can cause assert, because begin time attributes assumes that calendar has been initialised. This
-        // is not the case for client ASSERT failure: !c.suiteTime().is_special() at ../ACore/src/TimeSeries.cpp:526
-        // init has not been called on calendar. TimeSeries::duration ECFLOW-1612
-        if (begin_node)
-            client_node_to_add->begin();
-
-        client_node_to_add->set_most_significant_state_up_node_tree();
-        return client_node_to_add;
-    }
-
-    invalidate_trigger_references();
-
-    // ADD ======================================================================
-    // Create/Add nodes as needed for a *PARTIAL* match
-    // If the path is /a/b/c/d/e/f it may be that path /a/b already exists
-    // hence we need only create the missing nodes   c, d, e, f
-    LOG_ASSERT(serverNode == nullptr, "");
-    node_ptr server_parent;
-    Node* last_client_child = clientNode.get(); // remember the last child
-    Node* client_parent     = clientNode->parent();
-    while (client_parent) {
-        server_parent = findAbsNode(client_parent->absNodePath());
-        if (server_parent) {
-            break;
-        }
-        last_client_child = client_parent;
-        client_parent     = client_parent->parent();
-    }
-    if (server_parent.get() == nullptr) {
-        // NOT EVEN A PARTIAL path match, hence move over WHOLE suite, detach from client and add to server
-        node_ptr client_suite_to_add = clientNode->suite()->remove();
-        bool addOk                   = addChild(client_suite_to_add);
-        LOG_ASSERT(addOk, "");
-
-        client_suite_to_add->set_most_significant_state_up_node_tree();
-        return client_suite_to_add;
-    }
-    if (server_parent->isTask()) {
-        errorMsg = "Cannot replace child '";
-        errorMsg += path;
-        errorMsg += "' since path (";
-        errorMsg += server_parent->absNodePath();
-        errorMsg += ") in the server is a task.";
-        return node_ptr();
-    }
-
-    // PARTIAL PATH MATCH,
-    LOG_ASSERT(last_client_child, "");
-    LOG_ASSERT(client_parent, "");
-    LOG_ASSERT(last_client_child->parent() == client_parent, "");
-    LOG_ASSERT(client_parent->absNodePath() == server_parent->absNodePath(), "");
-
-    /// If the child of same name exist we *replace* at the same position otherwise we *add* it to the end
-    size_t client_child_pos = last_client_child->position();
-
-    size_t server_child_pos; // will be set to  std::numeric_limits<std::size_t>::max(), if child not found
-    node_ptr server_child = server_parent->findImmediateChild(last_client_child->name(), server_child_pos);
-    if (server_child.get()) {
-
-        // Copy over suspended state
-        if (server_child->isSuspended()) {
-            last_client_child->suspend();
-        }
-
-        // Child of same name exist on the server, hence remove it
-        deleteChild(server_child.get());
-    }
-
-    // Take a note of begun status, in case the suite is being replaced.
-    bool begin_node = server_parent->suite()->begun();
-
-    node_ptr client_node_to_add = last_client_child->remove();
-    bool addOk                  = server_parent->addChild(client_node_to_add, client_child_pos);
-    LOG_ASSERT(addOk, "");
-
-    // preserve begun status. Note: we should't call begin() on the client side. As the suites will not have been begun.
-    // This can cause assert, because begin time attributes assumes that calendar has been initialised. This is not the
-    // case for client ASSERT failure: !c.suiteTime().is_special() at ../ACore/src/TimeSeries.cpp:526 init has not been
-    // called on calendar. TimeSeries::duration ECFLOW-1612
-    if (begin_node)
-        client_node_to_add->begin();
-
-    client_node_to_add->set_most_significant_state_up_node_tree();
-
-    return client_node_to_add;
-}
-
-void Defs::cereal_save_as_checkpt(const std::string& the_fileName) const {
-    // only_save_edit_history_when_check_pointing or if explicitly requested
-    save_edit_history_ = true; // this is reset after edit_history is saved
-
-    /// Can throw archive exception
-    ecf::save(the_fileName, *this);
-}
-
-void Defs::cereal_restore_from_checkpt(const std::string& the_fileName) {
-    //	cout << "Defs::cereal_restore_from_checkpt " << the_fileName << "\n";
-
-    if (the_fileName.empty())
-        return;
-
-    // deleting existing content first. *** Note: Server environment left as is ****
-    clear();
-
-    ecf::restore(the_fileName, (*this));
-
-    //	cout << "Restored: " << suiteVec_.size() << " suites\n";
-}
-
-void Defs::save_as_checkpt(const std::string& the_fileName) const {
-    // Save as defs will always save children, hence no need for CheckPtContext
-
-    // only_save_edit_history_when_check_pointing or if explicitly requested
-    save_edit_history_ = true; // this is reset after edit_history is saved
-
-    // Speed up check-pointing by avoiding indentation. i.e run_time and disk space
-    // to view indented code use 'ecflow_client --load=checkpt_file check_only print'
-    ecf::DisableIndentor disable_indentation;
-    save_as_filename(the_fileName, PrintStyle::MIGRATE);
-}
-
-void Defs::save_as_filename(const std::string& the_fileName, PrintStyle::Type_t p_style) const {
-    PrintStyle printStyle(p_style);
-
-    std::ofstream ofs(the_fileName.c_str());
-    std::string s;
-    print(s);
-    ofs << s;
-
-    if (!ofs.good()) {
-        std::string err = "Defs::save_as_filename: path(";
-        err += the_fileName;
-        err += ") failed: ";
-        err += File::stream_error_condition(ofs);
-        throw std::runtime_error(err);
-    }
-}
-
-void Defs::save_as_string(std::string& the_string, PrintStyle::Type_t p_style) const {
-    PrintStyle printStyle(p_style);
-
-    // Speed up check-pointing by avoiding indentation. i.e run_time and disk space
-    // to view indented code use 'ecflow_client --load=checkpt_file check_only print'
-    ecf::DisableIndentor disable_indentation;
-    print(the_string);
-}
-
-void Defs::restore(const std::string& the_fileName) {
-    if (the_fileName.empty())
-        return;
-
-    /// *************************************************************************
-    /// The reason why Parser code moved to ANode directory. Avoid cyclic loop
-    /// *************************************************************************
-    std::string errorMsg, warningMsg;
-    if (!restore(the_fileName, errorMsg, warningMsg)) {
-        std::stringstream e;
-        e << "Defs::defs_restore_from_checkpt: " << errorMsg;
-        throw std::runtime_error(e.str());
-    }
-}
-
-bool Defs::restore(const std::string& the_fileName, std::string& errorMsg, std::string& warningMsg) {
-    if (the_fileName.empty()) {
-        errorMsg = "Defs::restore: the filename string is empty";
-        return false;
-    }
-
-    // deleting existing content first. *** Note: Server environment left as is ****
-    clear();
-
-    DefsStructureParser parser(this, the_fileName);
-    bool ret = parser.doParse(errorMsg, warningMsg);
-    return ret;
-}
-
-void Defs::restore_from_string(const std::string& str) {
-    /// *************************************************************************
-    /// The reason why Parser code moved to ANode directory. Avoid cyclic loop
-    /// *************************************************************************
-    std::string errorMsg, warningMsg;
-    if (!restore_from_string(str, errorMsg, warningMsg)) {
-        std::stringstream e;
-        e << "Defs::defs_restore_from_string: " << errorMsg;
-        throw std::runtime_error(e.str());
-    }
-}
-
-bool Defs::restore_from_string(const std::string& str, std::string& errorMsg, std::string& warningMsg) {
-    if (str.empty()) {
-        errorMsg = "Defs::restore_from_string: the string is empty";
-        return false;
-    }
-
-    // deleting existing content first. *** Note: Server environment left as is ****
-    clear();
-
-    // Do *NOT* Reset the state and modify numbers
-    // As we we need this numbers for Syncing between client<->Server
-    DefsStructureParser parser(this, str, false /* not used*/);
-    bool ret = parser.doParse(errorMsg, warningMsg);
-    return ret;
-}
-
-void Defs::clear() {
-    // Duplicate AST are held in a static map.
-    ExprDuplicate reclaim_cloned_ast_memory;
-
-    // *** Note: Server environment left as is ****
-    suiteVec_.clear();
-    externs_.clear();
-    client_suite_mgr_.clear();
-    state_.setState(NState::UNKNOWN);
-    edit_history_.clear();
-    save_edit_history_ = false;
-    Ecf::incr_modify_change_no();
-}
-
-bool Defs::checkInvariants(std::string& errorMsg) const {
-    for (const auto& s : suiteVec_) {
-        if (s->defs() != this) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants suite->defs() function not correct. Child suite parent ptr not correct\n";
-            ss << "For suite " << s->name();
-            errorMsg += ss.str();
-            return false;
-        }
-        if (!s->isSuite()) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants suite isSuite() return NULL ? for suite " << s->name();
-            errorMsg += ss.str();
-            return false;
-        }
-        if (s->isSuite() != s->suite()) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants  s->isSuite(" << s->isSuite() << ") != s->suite(" << s->suite() << ") ";
-            ss << "for suite " << s->name();
-            errorMsg += ss.str();
-            return false;
-        }
-        if (!s->checkInvariants(errorMsg)) {
-            return false;
-        }
-    }
-
-    if (Ecf::server()) {
-        /// The change no should NOT be greater than Ecf::state_change_no()
-
-        if (state_change_no_ > Ecf::state_change_no()) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants: state_change_no(" << state_.state_change_no() << ") > Ecf::state_change_no("
-               << Ecf::state_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-        if (modify_change_no_ > Ecf::modify_change_no()) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants: modify_change_no_(" << modify_change_no_ << ") > Ecf::modify_change_no("
-               << Ecf::modify_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-
-        if (flag_.state_change_no() > Ecf::state_change_no()) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants: flag.state_change_no()(" << flag_.state_change_no()
-               << ") > Ecf::state_change_no(" << Ecf::state_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-
-        if (state_.state_change_no() > Ecf::state_change_no()) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants: state_.state_change_no()(" << state_.state_change_no()
-               << ") > Ecf::state_change_no(" << Ecf::state_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-
-        if (server_.state_change_no() > Ecf::state_change_no()) {
-            std::stringstream ss;
-            ss << "Defs::checkInvariants: server_.state_change_no()(" << server_.state_change_no()
-               << ") > Ecf::state_change_no(" << Ecf::state_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-    }
-    return true;
-}
-
-void Defs::order(Node* immediateChild, NOrder::Order ord) {
-    switch (ord) {
-        case NOrder::TOP: {
-            for (auto i = suiteVec_.begin(); i != suiteVec_.end(); ++i) {
-                suite_ptr s = (*i);
-                if (s.get() == immediateChild) {
-                    suiteVec_.erase(i);
-                    suiteVec_.insert(suiteVec_.begin(), s);
-                    client_suite_mgr_.update_suite_order();
-                    order_state_change_no_ = Ecf::incr_state_change_no();
-                    return;
-                }
-            }
-            throw std::runtime_error("Defs::order: TOP, immediate child suite not found");
-        }
-        case NOrder::BOTTOM: {
-            for (auto i = suiteVec_.begin(); i != suiteVec_.end(); ++i) {
-                suite_ptr s = (*i);
-                if (s.get() == immediateChild) {
-                    suiteVec_.erase(i);
-                    suiteVec_.push_back(s);
-                    order_state_change_no_ = Ecf::incr_state_change_no();
-                    client_suite_mgr_.update_suite_order();
-                    return;
-                }
-            }
-            throw std::runtime_error("Defs::order: BOTTOM, immediate child suite not found");
-        }
-        case NOrder::ALPHA: {
-            std::sort(suiteVec_.begin(), suiteVec_.end(), [](const suite_ptr& a, const suite_ptr& b) {
-                try {
-                    int a_as_int = ecf::convert_to<int>(a->name());
-                    int b_as_int = ecf::convert_to<int>(b->name());
-                    return a_as_int < b_as_int;
-                }
-                catch (const ecf::bad_conversion&) {
-                }
-
-                return Str::caseInsLess(a->name(), b->name());
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            client_suite_mgr_.update_suite_order();
-            break;
-        }
-        case NOrder::ORDER: {
-            std::sort(suiteVec_.begin(), suiteVec_.end(), [](const suite_ptr& a, const suite_ptr& b) {
-                return Str::caseInsGreater(a->name(), b->name());
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            client_suite_mgr_.update_suite_order();
-            break;
-        }
-        case NOrder::UP: {
-            for (size_t t = 0; t < suiteVec_.size(); t++) {
-                if (suiteVec_[t].get() == immediateChild) {
-                    if (t != 0) {
-                        suite_ptr s = suiteVec_[t];
-                        suiteVec_.erase(suiteVec_.begin() + t);
-                        t--;
-                        suiteVec_.insert(suiteVec_.begin() + t, s);
-                        order_state_change_no_ = Ecf::incr_state_change_no();
-                    }
-                    client_suite_mgr_.update_suite_order();
-                    return;
-                }
-            }
-            throw std::runtime_error("Defs::order: UP, immediate child suite not found");
-        }
-        case NOrder::DOWN: {
-            for (size_t t = 0; t < suiteVec_.size(); t++) {
-                if (suiteVec_[t].get() == immediateChild) {
-                    if (t != suiteVec_.size() - 1) {
-                        suite_ptr s = suiteVec_[t];
-                        suiteVec_.erase(suiteVec_.begin() + t);
-                        t++;
-                        suiteVec_.insert(suiteVec_.begin() + t, s);
-                        order_state_change_no_ = Ecf::incr_state_change_no();
-                    }
-                    client_suite_mgr_.update_suite_order();
-                    return;
-                }
-            }
-            throw std::runtime_error("Defs::order: DOWN, immediate child suite not found");
-        }
-        case NOrder::RUNTIME: {
-            for (suite_ptr suite : suiteVec_) {
-                if (suite->state() != NState::COMPLETE) {
-                    throw std::runtime_error("Defs::order: To order by RUNTIME All suites must be complete");
-                }
-            }
-            for (suite_ptr suite : suiteVec_)
-                (void)suite->sum_runtime();
-            std::sort(suiteVec_.begin(), suiteVec_.end(), [](const suite_ptr& a, const suite_ptr& b) {
-                return a->state_change_runtime() > b->state_change_runtime();
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            client_suite_mgr_.update_suite_order();
-            break;
-        }
-    }
-}
-
-void Defs::move_peer(Node* source, Node* dest) {
-    move_peer_node(suiteVec_, source, dest, "Defs");
-    order_state_change_no_ = Ecf::incr_state_change_no();
-    client_suite_mgr_.update_suite_order();
-}
-
-void Defs::top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
-    bool why_found = why(theReasonWhy, html_tags);
-    if (!why_found) {
-        for (const auto& s : suiteVec_) {
-            (void)s->top_down_why(theReasonWhy, html_tags);
-        }
-    }
-}
-
-bool Defs::why(std::vector<std::string>& theReasonWhy, bool html) const {
-    if (isSuspended()) {
-        std::string the_reason = "The server is *not* RUNNING.";
-        theReasonWhy.push_back(the_reason);
-        return true;
-    }
-    else if (state() != NState::QUEUED && state() != NState::ABORTED) {
-        std::stringstream ss;
-        if (html)
-            ss << "The definition state(" << NState::to_html(state()) << ") is not queued or aborted.";
-        else
-            ss << "The definition state(" << NState::toString(state()) << ") is not queued or aborted.";
-        theReasonWhy.push_back(ss.str());
-    }
-    return server_.why(theReasonWhy);
-}
-
-std::string Defs::toString() const {
-    // Let the Client control the print style
-    std::stringstream ss;
-    ss << this;
-    return ss.str();
-}
-
-// Memento functions
-void Defs::collateChanges(unsigned int client_handle, DefsDelta& incremental_changes) const {
-    // Collate any small scale changes to the defs
-    collate_defs_changes_only(incremental_changes);
-
-    if (0 == client_handle) {
-        // small scale changes. Collate changes over all suites.
-        // Suite stores the maximum state change, over *all* its children, this is used by client handle mechanism
-        // and here to avoid traversing down the hierarchy.
-        // ******** We must trap all child changes under the suite. See class SuiteChanged
-        // ******** otherwise some attribute sync's will be missed
-        for (const auto& s : suiteVec_) {
-            //   *IF* node/attribute change no > client_state_change_no
-            //   *THEN*
-            //       Create a memento, and store in incremental_changes_
-            s->collateChanges(incremental_changes);
-        }
-    }
-    else {
-
-        // small scale changes over the suites in our handle, determine what's changed,
-        // relative to each node and attributes client_state_change_no.
-        //   *IF* node/attribute change no > client_state_change_no
-        //   *THEN*
-        //       Create a memento, and store in incremental_changes_
-        client_suite_mgr_.collateChanges(client_handle, incremental_changes);
-    }
-}
-
-void Defs::collate_defs_changes_only(DefsDelta& incremental_changes) const {
-    // ************************************************************************************************
-    // determine if defs state changed. make sure this is in sync with defs_only_max_state_change_no()
-    // ************************************************************************************************
-    compound_memento_ptr comp;
-    if (state_.state_change_no() > incremental_changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
-        comp->add(std::make_shared<StateMemento>(state_.state()));
-    }
-    if (order_state_change_no_ > incremental_changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
-        std::vector<std::string> order;
-        order.reserve(suiteVec_.size());
-        for (const auto& i : suiteVec_)
-            order.push_back(i->name());
-        comp->add(std::make_shared<OrderMemento>(order));
-    }
-
-    // Determine if the flag changed
-    if (flag_.state_change_no() > incremental_changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
-        comp->add(std::make_shared<FlagMemento>(flag_));
-    }
-
-    // determine if defs server state, currently only watch server state. i.e HALTED, SHUTDOWN, RUNNING
-    if (server_.state_change_no() > incremental_changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
-        comp->add(std::make_shared<ServerStateMemento>(server_.get_state()));
-    }
-    if (server_.variable_state_change_no() > incremental_changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
-        comp->add(std::make_shared<ServerVariableMemento>(server_.user_variables()));
-    }
-
-    if (comp.get()) {
-        incremental_changes.add(comp);
-    }
-}
-
-unsigned int Defs::defs_only_max_state_change_no() const {
-    // ************************************************************************************************
-    // make sure this is in sync with collate_defs_changes_only()
-    // ************************************************************************************************
-    unsigned int max_change_no = 0;
-    max_change_no              = std::max(max_change_no, state_.state_change_no());
-    max_change_no              = std::max(max_change_no, order_state_change_no_);
-    max_change_no              = std::max(max_change_no, flag_.state_change_no());
-    max_change_no              = std::max(max_change_no, server_.state_change_no());
-    max_change_no              = std::max(max_change_no, server_.variable_state_change_no());
-    return max_change_no;
-}
-
-void Defs::set_memento(const StateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Defs::set_memento(const StateMemento* memento)\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::STATE);
-    else
-        set_state(memento->state_);
-}
-
-void Defs::set_memento(const ServerStateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Defs::set_memento(const ServerStateMemento* memento)\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::SERVER_STATE);
-    else
-        server_.set_state(memento->state_);
-}
-
-void Defs::set_memento(const ServerVariableMemento* memento,
-                       std::vector<ecf::Aspect::Type>& aspects,
-                       bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Defs::set_memento(const ServerVariableMemento* memento)\n";
-#endif
-
-    if (aspect_only) {
-        if (server_.user_variables().size() != memento->serverEnv_.size()) {
-            aspects.push_back(ecf::Aspect::ADD_REMOVE_ATTR);
-        }
-        aspects.push_back(ecf::Aspect::SERVER_VARIABLE);
-        return;
-    }
-
-    server_.set_user_variables(memento->serverEnv_);
-}
-
-void Defs::set_memento(const OrderMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Defs::set_memento(const OrderMemento* memento)\n";
-#endif
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::ORDER);
-        return;
-    }
-
-    // Order the suites
-
-    // Order nodes according to memento ordering
-    const std::vector<std::string>& order = memento->order_;
-
-    // NOTE: When we have handles only a small subset of the suites, are returned
-    //       Whereas order will always contain all the suites.
-    //       Hence we need to handle the case where: order.size() != suiteVec_.size()
-
-    std::vector<suite_ptr> vec;
-    vec.reserve(suiteVec_.size());
-    size_t node_vec_size = suiteVec_.size();
-    for (const auto& i : order) {
-        for (size_t t = 0; t < node_vec_size; t++) {
-            if (i == suiteVec_[t]->name()) {
-                vec.push_back(suiteVec_[t]);
-                break;
-            }
-        }
-    }
-    if (vec.size() != suiteVec_.size()) {
-        std::cout << "Defs::set_memento could not find all the names\n";
-        return;
-    }
-    suiteVec_ = vec;
-}
-
-void Defs::set_memento(const FlagMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Defs::set_memento(const FlagMemento* memento)\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::FLAG);
-    else
-        flag_.set_flag(memento->flag_.flag());
-}
-
-// =====================================================================
-
-void Defs::add_edit_history(const std::string& path, const std::string& request) {
-    auto i = edit_history_.find(path);
-    if (i == edit_history_.end()) {
-        edit_history_.insert(std::make_pair(path, std::vector<std::string>(1, request)));
-    }
-    else {
-        (*i).second.push_back(request);
-        if ((*i).second.size() > Defs::max_edit_history_size_per_node()) {
-            (*i).second.erase((*i).second.begin());
-        }
-    }
-}
-
-void Defs::remove_edit_history(Node* node) {
-    if (!node)
-        return;
-
-    // When removing a node *it* and all its children also need to be removed.
-    std::vector<node_ptr> node_children;
-    node->get_all_nodes(node_children);
-    for (const auto& c : node_children) {
-
-        auto it = edit_history_.find(c->absNodePath());
-        if (it != edit_history_.end()) {
-            edit_history_.erase(it);
-        }
-    }
-}
-
-void Defs::clear_edit_history() {
-    edit_history_.clear();
-}
-
-const std::vector<std::string>& Defs::get_edit_history(const std::string& path) const {
-    auto i = edit_history_.find(path);
-    if (i != edit_history_.end()) {
-        return (*i).second;
-    }
-    return empty_edit_history();
-}
-
-const std::vector<std::string>& Defs::empty_edit_history() {
-    static std::vector<std::string> static_edit_history;
-    return static_edit_history;
-}
-
-// =====================================================================================
-
-void Defs::notify_delete() {
-    // make a copy, to avoid iterating over observer list that is being changed
-    std::vector<AbstractObserver*> copy_of_observers = observers_;
-    for (auto& copy_of_observer : copy_of_observers) {
-        copy_of_observer->update_delete(this);
-    }
-
-    /// Check to make sure that the Observer called detach
-    /// We cannot call detach ourselves, since the the client needs to
-    /// call detach in the case where the graphical tree is destroyed by user
-    /// In this case the Subject/Node is being deleted.
-    assert(observers_.empty());
-}
-
-void Defs::notify_start(const std::vector<ecf::Aspect::Type>& aspects) {
-    for (auto& observer : observers_) {
-        observer->update_start(this, aspects);
-    }
-}
-
-void Defs::notify(const std::vector<ecf::Aspect::Type>& aspects) {
-    for (auto& observer : observers_) {
-        observer->update(this, aspects);
-    }
-}
-
-void Defs::attach(AbstractObserver* obs) {
-    observers_.push_back(obs);
-}
-
-void Defs::detach(AbstractObserver* obs) {
-    for (size_t i = 0; i < observers_.size(); i++) {
-        if (observers_[i] == obs) {
-            observers_.erase(observers_.begin() + i);
-            return;
-        }
-    }
-}
-
-bool Defs::is_observed(AbstractObserver* obs) const {
-    for (auto observer : observers_) {
-        if (observer == obs) {
-            return true;
-        }
-    }
-    return false;
-}
-// =====================================================================================
-
-std::ostream& operator<<(std::ostream& os, const Defs* d) {
-    if (d) {
-        std::string s;
-        d->print(s);
-        os << s;
-        return os;
-    }
-    return os << "DEFS == NULL\n";
-}
-std::ostream& operator<<(std::ostream& os, const Defs& d) {
-    std::string s;
-    d.print(s);
-    os << s;
-    return os;
-}
-
-// =========================================================================
-
-DefsHistoryParser::DefsHistoryParser() = default;
-
-void DefsHistoryParser::parse(const std::string& line) {
-    size_t pos = line.find("\b");
-    if (pos != std::string::npos) {
-        // keep compatibility with current way of writing history
-        std::string requests = line.substr(pos);
-        Str::split(requests, parsed_messages_, "\b");
-        return;
-    }
-
-    // fallback, split line based on looking for logType like 'MSG:[' | 'LOG:['
-    string::size_type first = find_log(line, 0);
-    if (first == std::string::npos)
-        return;
-
-    string::size_type next = find_log(line, first + 4);
-    if (next == std::string::npos) {
-        parsed_messages_.push_back(line.substr(first));
-        return;
-    }
-
-    while (next != std::string::npos) {
-        parsed_messages_.push_back(line.substr(first, next - first));
-        first = next;
-        next  = find_log(line, first + 4);
-
-        if (next == std::string::npos) {
-            parsed_messages_.push_back(line.substr(first));
-            return;
-        }
-    }
-}
-
-string::size_type DefsHistoryParser::find_log(const std::string& line, string::size_type pos) const {
-    std::vector<std::string> log_types;
-    Log::get_log_types(log_types);
-
-    for (auto log_type : log_types) {
-        log_type += ":[";
-        string::size_type log_type_pos = line.find(log_type, pos);
-        if (log_type_pos != std::string::npos) {
-            return log_type_pos;
-        }
-    }
-    return std::string::npos;
-}
-
-std::string Defs::stats() const {
-    std::vector<node_ptr> node_vec;
-    get_all_nodes(node_vec);
-
-    std::vector<Family*> family_vec;
-    getAllFamilies(family_vec);
-
-    std::vector<task_ptr> task_vec;
-    get_all_tasks(task_vec);
-
-    size_t alias = 0;
-    for (auto task : task_vec)
-        alias += task->aliases().size();
-
-    NodeStats stats;
-    stats.suites_ = suiteVec_.size();
-    stats.family_ = family_vec.size();
-    stats.task_   = task_vec.size();
-    stats.alias_  = alias;
-    stats.nodes_  = node_vec.size();
-
-    stats.edit_history_nodes_ = edit_history_.size();
-    for (const auto& i : edit_history_) {
-        const std::vector<std::string>& vec = i.second; // list of requests
-        stats.edit_history_paths_ += vec.size();
-    }
-
-    for (auto node : node_vec)
-        node->stats(stats);
-    return stats.print();
-}
-
-template <class Archive>
-void Defs::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(state_change_no_),
-       CEREAL_NVP(modify_change_no_),
-       CEREAL_NVP(updateCalendarCount_),
-       CEREAL_NVP(state_),
-       CEREAL_NVP(server_),
-       CEREAL_NVP(suiteVec_));
-
-    CEREAL_OPTIONAL_NVP(ar, flag_, [this]() { return flag_.flag() != 0; }); // conditionally save
-
-    // only save the edit history when check pointing.
-    CEREAL_OPTIONAL_NVP(
-        ar, edit_history_, [this]() { return save_edit_history_ && !edit_history_.empty(); }); // conditionally save
-
-    if (Archive::is_loading::value) {
-        size_t vec_size = suiteVec_.size();
-        for (size_t i = 0; i < vec_size; i++) {
-            suiteVec_[i]->set_defs(this);
-        }
-    }
-}
-
-CEREAL_TEMPLATE_SPECIALIZE_V(Defs);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Defs.hpp 5.13.0-1/ANode/src/ecflow/node/Defs.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Defs.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Defs.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,454 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Defs_HPP
-#define ecflow_node_Defs_HPP
-
-///
-/// \brief class defs: The root of the node tree. Holds all the suites:
-/// Externs are not persisted, why ?:
-///   o Externs are un-resolved references to node paths in trigger expressions and inlimits
-///     These references can be dynamically generated.
-///   o Saves on network bandwidth and checkpoint file size
-///
-/// Hence externs are *ONLY* used on the client side.
-///
-
-#include <cstdint>
-#include <iosfwd>
-#include <set>
-#include <unordered_map>
-#include <vector>
-
-#include "ecflow/core/NOrder.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Aspect.hpp"
-#include "ecflow/node/Attr.hpp"
-#include "ecflow/node/ClientSuiteMgr.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-#include "ecflow/node/ServerState.hpp"
-
-namespace cereal {
-class access;
-}
-namespace ecf {
-class NodeTreeVisitor;
-class CalendarUpdateParams;
-} // namespace ecf
-
-class Defs {
-public:
-    static defs_ptr create();
-    static defs_ptr create(const std::string& port);
-    Defs();
-    explicit Defs(const std::string& port); // used in test, to initialise server variables
-    Defs(const Defs&);
-    Defs& operator=(const Defs&);
-
-    ~Defs();
-
-    void copy_defs_state_only(const defs_ptr& defs); // needed when creating defs for client handles
-    bool operator==(const Defs& rhs) const;
-    void print(std::string&) const;
-    std::string print(PrintStyle::Type_t t = PrintStyle::MIGRATE) const;
-
-    /// Handle migration of checkpoint 4->5, and 5.0-5.4.0 -> 5.5
-    /// This essentially update date data member of the Day attribute
-    /// Can be removed when ecflow 5 is used everywhere.
-    void handle_migration();
-
-    /// State related functions:
-    /// Defs acts like the root node.
-    void set_state(NState::State);
-    void set_state_only(NState::State);
-    NState::State state() const;
-    void set_most_significant_state();
-
-    // The defs does not need suspend()/resume() as this is controlled by the server states
-    // The defs cannot schedule jobs when HALTED or SHUTDOWN, i.e. not RUNNING, this is same as suspended
-    bool isSuspended() const { return (server().get_state() != SState::RUNNING); }
-
-    /// Python based checking
-    /// Will create a temporary variable ECF_JOB so the job generation is done to a temporary directory
-    /// For TEST ONLY. Will generated jobs from the given node path
-    /// if the no path defined will generate jobs for all tasks
-    /// Job generation here is INDEPENDENT of the dependencies
-    /// Will call begin(). this updated generated variables which are used
-    /// **during variable substitution in job generation.
-    /// Note: All Tasks that fail to create jobs are returned in jobCtrl
-    /// This is because some Tasks are dummy, they have no associated ecf.
-    /// since they will never be run. This can be determined if they have
-    /// trigger expression like "1 == 0"
-    void check_job_creation(job_creation_ctrl_ptr jobCtrl);
-
-    /// Automatically generated '.ecf' scripts for this definition
-    /// It uses the contents of the definition to parameterise what gets
-    /// generated, and the location of the files. Will throw std::runtime_error for errors
-    /// Assumes: ECF_HOME specified and accessible for all Tasks, otherwise std::runtime_error is raised
-    /// If ECF_FILES is specified, then scripts are generated under this directory
-    /// otherwise ECF_HOME is used. The missing directories are automatically added.
-    /// IF ECF_INCLUDE must be specified.The head.h and tail.h includes will
-    /// use angle brackets, i.e %include <head.h>.
-    /// If ECF_CLIENT_EXE_PATH variable is added, child command will use this, otherwise
-    /// will use ecflow_client, and assume this accessible on the path.
-    /// Will not generated scripts for tasks with ECF_DUMMY_TASK specified.
-    void generate_scripts() const;
-
-    /// Update calendar and time dependent variables. This must be called by the polling mechanism,
-    /// This will *ONLY* have an effect after begin() command has been called
-    ///
-    /// Some suites can elect to ignore calendar updates when the server is not running
-    /// This allows normal and relative time dependencies to be honoured, even if the
-    /// server is started/stopped many times.
-    /// Updating the calendar can lead to state changes in the server. i.e when time related
-    /// dependencies are free'd
-    void updateCalendar(const ecf::CalendarUpdateParams&);
-
-    /// Used by simulator & catch_up_to_real_time
-    void update_calendar(Suite* suite, const ecf::CalendarUpdateParams& cal_update_params); // used by simulator
-
-    /// returns the number of times the calendar has been updated. For DEBUG
-    unsigned int updateCalendarCount() const { return updateCalendarCount_; }
-
-    /// When the server is terminated and then restarted, Allow time attributes to catch up.
-    /// This may expire time attributes allowing the task to run
-    /// We only update suite that have time attributes and where the calendars that are 1 hour out of sync with real
-    /// time. It can be quite expensive to update time attributes 1 minute at a time, hence we chose 1 hour. Return true
-    /// if any suite where updated
-    bool catch_up_to_real_time();
-
-    // Implements visitor pattern
-    void accept(ecf::NodeTreeVisitor&);                 // Node Tree structure does the traversal
-    void acceptVisitTraversor(ecf::NodeTreeVisitor& v); // visitor does traversal
-
-    /// Moves all the data from input defs into this definition. By default
-    /// suite of the same name, are left alone, unless the force option is used.
-    /// i.e with force any suites of the same name will overwrite the suite of
-    /// the same name in this definition.
-    /// externs and server user variables are appended to.
-    /// The input defs will be left with NO suites
-    void absorb(Defs*, bool force);
-
-    std::string name() const { return "/"; } /* ABO */
-
-    /// Add a suite to the definition, will throw std::runtime_error if duplicate
-    suite_ptr add_suite(const std::string& name);
-    void addSuite(const suite_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
-    size_t child_position(const Node*) const;
-
-    /// Externs refer to Nodes or, variable, events, meter, repeat, or generated variable
-    /// not currently defined. If the object(variable, event,meter, repeat, or generate variable name)
-    /// is empty the path can refer to a Task, Family of Suite
-    /// extern can have absolute and relative paths
-    /// Typically used in a trigger or complete expression
-    /// Path can be off the form:
-    ///  extern /suite/family
-    ///  extern /suite/family:repeat_name
-    ///  extern ../family:repeat_name
-    void add_extern(const std::string& nodePath);
-    void clear_externs() { externs_.clear(); }
-
-    /// Scan the trigger and complete expressions, and automatically add extern's
-    /// i.e where the node paths, and references, to event, meters, edit and repeat variables,
-    /// don't exist, in this defs.
-    void auto_add_externs(bool remove_existing_externs_first = true);
-
-    /// Flag the chosen suite, so that it can resolve dependencies. This also
-    /// changes the state of all children to QUEUED/defstatus and initialise the node attributes
-    /// Once a suite is begun, it stays in that state
-    void beginSuite(const suite_ptr&);
-
-    /// Enables all suites to resolve dependencies
-    /// Once a suite is begun, it stays in that state
-    void beginAll();
-
-    /// Reset the begin state. **** ONLY to be used for test ********
-    void reset_begin();
-
-    /// throws runtime_error if suite cant begin
-    void check_suite_can_begin(const suite_ptr&) const;
-
-    /// Will requeue all suites. Current used in test only
-    void requeue();
-
-    /// returns true if defs has cron,time,day,date or today time dependencies
-    bool hasTimeDependencies() const;
-
-    /// recursively sort the attributes
-    // expect one attr to be [ event | meter | label | limits | variable ]
-    // if recursive is true, ignore nodes on no_sort list
-    void sort_attributes(ecf::Attr::Type attr,
-                         bool recursive                          = true,
-                         const std::vector<std::string>& no_sort = std::vector<std::string>());
-
-    /// This function is called when ALL definition has been parsed successfully
-    /// Client Side:: The client side has externs, hence any references to node paths
-    ///               in the triggers expression, that are un-resolved and not in
-    ///               the extern;s are reported as errors/warnings
-    ///               Likewise for inlimit references to Limits
-    /// Server Side:: There are no externs hence, check will report all unresolved
-    ///               references as errors.
-    /// Note the AST will be demand loaded in the server. Since they are not persisted.
-    /// we will also resolve inLimit references to Limits. Note inlimit may also
-    /// reference paths, which are externs::
-    // ****** Spirit based AST construction is very expensive  ********
-    // ****** Need to replace at some point in future          ********
-    bool check(std::string& errorMsg, std::string& warningMsg) const;
-
-    /// Assumes input argument is of the form /suite/family/task, /suite/family/family/task
-    node_ptr findAbsNode(const std::string& pathToNode) const;
-    bool find_extern(const std::string& pathToNode, const std::string& node_attr_name) const;
-    suite_ptr findSuite(const std::string& name) const;
-    std::string find_node_path(const std::string& type, const std::string& name) const;
-    node_ptr find_node(const std::string& type, const std::string& pathToNode) const;
-
-    const std::vector<suite_ptr>& suiteVec() const { return suiteVec_; }
-
-    /// Given a path, /suite/family/task, find node which is the closest
-    node_ptr find_closest_matching_node(const std::string& pathToNode) const;
-
-    void getAllFamilies(std::vector<Family*>&) const;
-    void getAllNodes(std::vector<Node*>&) const;
-    void getAllTasks(std::vector<Task*>&) const;
-    void getAllSubmittables(std::vector<Submittable*>&) const;
-    void get_all_active_submittables(std::vector<Submittable*>&) const;
-    void get_all_nodes(std::vector<node_ptr>&) const;
-    void get_all_tasks(std::vector<task_ptr>&) const;
-    void get_all_aliases(std::vector<alias_ptr>&) const;
-    void getAllAstNodes(std::set<Node*>&) const;
-    const std::set<std::string>& externs() const { return externs_; }
-
-    /// Get/set for server state.
-    const ServerState& server() const { return server_; }
-    ServerState& set_server() { return server_; }
-
-    /// find all %VAR% and replaces with variable values, returns false on the
-    /// first variable that can't be found, cmd will be left half processed.
-    /// Will search for ECF_MICRO, if not found assumes % as the micro char
-    bool variableSubsitution(std::string& cmd) const { return server_.variableSubsitution(cmd); }
-
-    /// returns true if definition file passes its verification
-    /// If the definition file contains verify attribute, this function will check
-    /// expected number of state changes corresponds to the actual number of state changes
-    bool verification(std::string& errorMsg) const;
-
-    /// generic way of deleting a Node.
-    /// This should always succeed else something is seriously wrong
-    bool deleteChild(Node*);
-
-    /// This called during replace. If the trigger expression(AST) has been created,  then
-    /// the references to the nodes, will be invalidated.
-    /// These get generated on the fly, when referenced.
-    void invalidate_trigger_references() const;
-
-    /// Adopt the child specified by 'path' from the clientDef.
-    /// If node at path already exists in this instance, it is replaced.
-    /// if  createNodesAsNeeded = false,  then the path must exist on this defs
-    /// otherwise an error message is issued.
-    /// if  createNodesAsNeeded = true, and the path does not exist on this defs
-    /// then the missing path nodes are created.
-    /// In both the client and this defs the trigger references and cleared first.
-    /// Returns the changed node, or NULL and error message set.
-    node_ptr replaceChild(const std::string& path,
-                          const defs_ptr& clientDef,
-                          bool createNodesAsNeeded,
-                          bool force,
-                          std::string& errormsg);
-
-    // Order the suite
-    void order(Node* immediateChild, NOrder::Order);
-    void move_peer(Node* src, Node* dest);
-
-    /// determines why the node is not running.
-    void top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
-    bool why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const; // return true if why found
-
-    /// Function to save/restore the defs as a checkpoint file. Can throw exception
-    /// If the Defs file has content, this is deleted first, i.e. suites, externs, Can throw an exception
-    void cereal_save_as_checkpt(const std::string& fileName) const;
-    void cereal_restore_from_checkpt(const std::string& fileName);
-
-    // defs format
-    void save_as_checkpt(const std::string& fileName) const;
-    void save_as_filename(const std::string& fileName,
-                          PrintStyle::Type_t = PrintStyle::MIGRATE) const; // used in test only
-    void save_as_string(std::string& str, PrintStyle::Type_t = PrintStyle::MIGRATE) const;
-    void restore(const std::string& fileName); // will throw
-    bool restore(const std::string& fileName, std::string& errorMsg, std::string& warningMsg);
-    void restore_from_string(const std::string& str); // will throw
-    bool restore_from_string(const std::string& str, std::string& errorMsg, std::string& warningMsg);
-
-    /// Delete suites, externs, client handles, reset suspended, and locate state
-    /// etc but Server environment left as is:
-    void clear();
-
-    ecf::Flag& flag() { return flag_; }
-    const ecf::Flag& get_flag() const { return flag_; }
-
-    void add_edit_history(const std::string& path, const std::string& request);
-    void remove_edit_history(Node*);
-    void clear_edit_history();
-    std::string dump_edit_history() const;
-    const std::vector<std::string>& get_edit_history(const std::string& path) const;
-    const std::unordered_map<std::string, std::vector<std::string>>& get_edit_history() const { return edit_history_; }
-    void save_edit_history(bool f) const { save_edit_history_ = f; }
-    static const std::vector<std::string>& empty_edit_history();
-    constexpr static size_t max_edit_history_size_per_node() { return 10; }
-
-    /// Memento functions:
-    void collateChanges(unsigned int client_handle, DefsDelta&) const;
-    void set_memento(const StateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const ServerStateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const ServerVariableMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const OrderMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const FlagMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-
-    /// Find the max state change number for defs only. This includes:
-    ///   o the Defs state.
-    ///   o the Defs suspend state
-    ///   o the Defs server state.
-    unsigned int defs_only_max_state_change_no() const;
-
-    /// Change functions, used for *transferring* change number, from server to client
-    void set_state_change_no(unsigned int x) { state_change_no_ = x; }
-    unsigned int state_change_no() const { return state_change_no_; }
-    void set_modify_change_no(unsigned int x) { modify_change_no_ = x; }
-    unsigned int modify_change_no() const { return modify_change_no_; }
-
-    ClientSuiteMgr& client_suite_mgr() { return client_suite_mgr_; }
-
-    // Provided for python interface
-    std::string toString() const;
-
-    // Will recurse down.
-    bool doDeleteChild(Node* nodeToBeDeleted);
-
-    bool checkInvariants(std::string& errorMsg) const;
-
-    void read_state(const std::string& line, const std::vector<std::string>& lineTokens);
-    void read_history(const std::string& line, const std::vector<std::string>& lineTokens);
-    bool compare_edit_history(const Defs&) const;
-    bool compare_change_no(const Defs&) const;
-
-    std::string stats() const; // dump out definition stats
-
-    void ecf_prune_node_log(int v) { ecf_prune_node_log_ = v; }
-
-private:
-    void do_generate_scripts(const std::map<std::string, std::string>& override) const;
-    void write_state(std::string&) const;
-    void collate_defs_changes_only(DefsDelta&) const;
-    void setupDefaultEnv();
-    void add_suite_only(const suite_ptr&, size_t position);
-
-    /// Removes the suite, from defs returned as suite_ptr, asserts if suite does not exist
-    suite_ptr removeSuite(suite_ptr);
-    node_ptr removeChild(Node*);
-    bool addChild(const node_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
-    friend class Node;
-
-    /// For use by python interface,
-    std::vector<suite_ptr>::const_iterator suite_begin() const { return suiteVec_.begin(); }
-    std::vector<suite_ptr>::const_iterator suite_end() const { return suiteVec_.end(); }
-    std::set<std::string>::const_iterator extern_begin() const { return externs_.begin(); }
-    std::set<std::string>::const_iterator extern_end() const { return externs_.end(); }
-    std::vector<Variable>::const_iterator user_variables_begin() const { return server_.user_variables().begin(); }
-    std::vector<Variable>::const_iterator user_variables_end() const { return server_.user_variables().end(); }
-    std::vector<Variable>::const_iterator server_variables_begin() const { return server_.server_variables().begin(); }
-    std::vector<Variable>::const_iterator server_variables_end() const { return server_.server_variables().end(); }
-
-    friend void export_Defs();
-
-private:
-    /// Note: restoring from a check point file will reset, defs state and modify numbers
-    mutable size_t print_cache_{0}; // NOT persisted
-    unsigned int state_change_no_{
-        0}; // persisted since passed to client, however side effect, is it will be in checkpoint file
-    unsigned int modify_change_no_{
-        0}; // persisted since passed to client, however side effect, is it will be in checkpoint file
-    unsigned int updateCalendarCount_{0};
-    unsigned int order_state_change_no_{0}; // *NOT* persisted
-    unsigned int ecf_prune_node_log_{0};    // *NOT* persisted, only used on the server side
-    NState state_;                          // state & change_no, i,e attribute changed
-    ServerState server_;
-    std::vector<suite_ptr> suiteVec_;
-    std::unordered_map<std::string, std::vector<std::string>> edit_history_; // path,request
-    ecf::Flag flag_;
-
-    ClientSuiteMgr client_suite_mgr_{this}; // NOT persisted
-
-    /// Externs are *NEVER* loaded in the server, since they can be computed and
-    /// save on network band with, and check point file size.
-    std::set<std::string> externs_; // NOT persisted
-
-    friend class SaveEditHistoryWhenCheckPointing;
-
-private:
-    /// Observer notifications Start. Allow client to query if they are in syncing with server
-    void notify_start() { in_notification_ = true; }
-    void notify_end() { in_notification_ = false; }
-    std::vector<AbstractObserver*> observers_;
-    mutable bool save_edit_history_{false}; // NOT persisted
-    bool in_notification_{false};
-
-    friend class ChangeStartNotification;
-    void notify_delete();
-
-public:
-    void notify_start(const std::vector<ecf::Aspect::Type>& aspects);
-    void notify(const std::vector<ecf::Aspect::Type>& aspects);
-    void attach(AbstractObserver*);
-    void detach(AbstractObserver*);
-    bool is_observed(AbstractObserver*) const; // return true if we have this observer in our list
-    bool in_notification() const { return in_notification_; }
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-std::ostream& operator<<(std::ostream& os, const Defs*);
-std::ostream& operator<<(std::ostream& os, const Defs&);
-
-// =====================================================================
-// This class is used to read the History
-class DefsHistoryParser {
-public:
-    DefsHistoryParser();
-    // Disable copy (and move) semantics
-    DefsHistoryParser(const DefsHistoryParser&)                  = delete;
-    const DefsHistoryParser& operator=(const DefsHistoryParser&) = delete;
-
-    void parse(const std::string& line);
-    const std::vector<std::string>& parsed_messages() const { return parsed_messages_; }
-
-private:
-    std::string::size_type find_log(const std::string& line, std::string::size_type pos) const;
-    std::vector<std::string> parsed_messages_;
-};
-
-// Start notification. End notification automatically signalled, Even if exception raised.
-class ChangeStartNotification {
-public:
-    explicit ChangeStartNotification(defs_ptr defs) : defs_ptr_(defs) { defs_ptr_->notify_start(); }
-    // Disable copy (and move) semantics
-    ChangeStartNotification(const ChangeStartNotification&)                  = delete;
-    const ChangeStartNotification& operator=(const ChangeStartNotification&) = delete;
-
-    ~ChangeStartNotification() { defs_ptr_->notify_end(); }
-
-private:
-    defs_ptr defs_ptr_;
-};
-
-#endif /* ecflow_node_Defs_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/DefsDelta.cpp 5.13.0-1/ANode/src/ecflow/node/DefsDelta.cpp
--- 5.12.4-1/ANode/src/ecflow/node/DefsDelta.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/DefsDelta.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,86 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/DefsDelta.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/node/Memento.hpp"
-
-using namespace std;
-
-// #define DEBUG_MEMENTO 1
-
-//===============================================================
-// DefsDelta
-
-/// Defs delta can be re-used. reset all data members
-void DefsDelta::init(unsigned int client_state_change_no, bool sync_suite_clock) {
-    sync_suite_clock_       = sync_suite_clock;
-    client_state_change_no_ = client_state_change_no;
-
-    server_state_change_no_  = 0;
-    server_modify_change_no_ = 0;
-    compound_mementos_.clear();
-}
-
-bool DefsDelta::incremental_sync(defs_ptr client_def,
-                                 std::vector<std::string>& changed_nodes,
-                                 int client_handle) const {
-    // ****************************************************
-    // On the client side
-    // ****************************************************
-    if (!client_def.get())
-        return false;
-
-    // Clear the changed nodes since we want it to match number of changed memento's
-    // This should have been clear anyway in ServerReply::clear_for_invoke
-    changed_nodes.clear();
-
-    // Update the client defs with latest server *handle* based state change/modify number
-    // to keep pace with the state changes. Passed back later on, to get further changes
-    client_def->set_state_change_no(server_state_change_no_);
-    client_def->set_modify_change_no(server_modify_change_no_);
-
-    try {
-#ifdef DEBUG_MEMENTO
-        std::cout << "DefsDelta::incremental_sync compound_mementos_.size() = " << compound_mementos_.size() << "\n";
-#endif
-
-        // For each compound memento, we should have a changed node,
-        for (compound_memento_ptr m : compound_mementos_) {
-            changed_nodes.push_back(m->abs_node_path()); // Record changed nodes for the Python interface
-            m->incremental_sync(client_def);
-        }
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "Could not apply incremental server changes to client defs( with client handle: " << client_handle
-           << "), because: " << e.what();
-        throw std::runtime_error(ss.str());
-    }
-
-    // For each compound memento, we should have a changed node.(for use with python interface)
-    assert(compound_mementos_.size() == changed_nodes.size());
-
-    // return true if there were any changes made
-    return !compound_mementos_.empty();
-}
-
-void DefsDelta::add(compound_memento_ptr memento) {
-    compound_mementos_.push_back(memento);
-}
-
-template <class Archive>
-void DefsDelta::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(server_state_change_no_), CEREAL_NVP(server_modify_change_no_), CEREAL_NVP(compound_mementos_));
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(DefsDelta);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/DefsDelta.hpp 5.13.0-1/ANode/src/ecflow/node/DefsDelta.hpp
--- 5.12.4-1/ANode/src/ecflow/node/DefsDelta.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/DefsDelta.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,90 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_DefsDelta_HPP
-#define ecflow_node_DefsDelta_HPP
-
-///
-///
-/// \brief class DefsDelta: holds a list of incremental changes made in the server.
-///                  This class is created in the server, and transferred to the client
-///                  The client use it to syncronize with the server, without the need
-///                  for asking for the full defs.
-///
-/// When the client request the incremental changes, it also passes its client_state_change_no.
-/// The client_state_change number is used in the server side to determine what's changed.
-/// These changes are collated with add()  and transferred to the client.
-/// The client then calls  incremental_sync() which will apply the changes to the client defs
-/// so bringing it in sync with the server defs.
-///
-/// Note:: updating state_change_no() on the *client side*  a no-op() it has no effect
-///
-
-#include <cstdint>
-
-#include "ecflow/node/NodeFwd.hpp"
-namespace cereal {
-class access;
-}
-
-class DefsDelta {
-public:
-    ///=========================================================================
-    /// *Server side*
-    explicit DefsDelta(unsigned int client_state_change_no) : client_state_change_no_(client_state_change_no) {}
-    // Disable copy (and move) semantics
-    DefsDelta(const DefsDelta&)                  = delete;
-    const DefsDelta& operator=(const DefsDelta&) = delete;
-
-    /// This class can be re-used hence init() should reset all data members
-    void init(unsigned int client_state_change_no, bool sync_suite_clock);
-
-    /// reclaim memory
-    void cleanup() { std::vector<compound_memento_ptr>().swap(compound_mementos_); }
-
-    // ECFLOW-631, allow the suite calendar to be sync'ed, even if there are no other changes
-    bool sync_suite_clock() const { return sync_suite_clock_; }
-
-    /// Add the compound memento, ie. store all memento's for a *given* node.
-    void add(compound_memento_ptr);
-
-    void set_server_state_change_no(unsigned int s) { server_state_change_no_ = s; }
-    void set_server_modify_change_no(unsigned int s) { server_modify_change_no_ = s; }
-    unsigned int get_server_state_change_no() const { return server_state_change_no_; }
-    unsigned int get_server_modify_change_no() const { return server_modify_change_no_; }
-
-    ///=========================================================================
-    /// *Client side*
-    /// Applies the mementos to the client defs and record all changed nodes.
-    /// Can raise std::runtime_error.
-    /// Note:: updating state_change_no() on the *client side*  has *no effect*
-    bool incremental_sync(defs_ptr client_def, std::vector<std::string>& changed_nodes, int client_handle) const;
-
-    /// =========================================================================
-    // The client state change number. Used to determine what's changed
-    unsigned int client_state_change_no() const { return client_state_change_no_; }
-
-    /// return the number of compound mementos
-    size_t size() const { return compound_mementos_.size(); }
-
-private:
-    bool sync_suite_clock_{false};        // *no* need to persist since only used on server side
-    unsigned int client_state_change_no_; // *no* need to persist since only used on server side
-
-    unsigned int server_state_change_no_{0};
-    unsigned int server_modify_change_no_{0};
-    std::vector<compound_memento_ptr> compound_mementos_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_node_DefsDelta_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/DefsTreeVisitor.hpp 5.13.0-1/ANode/src/ecflow/node/DefsTreeVisitor.hpp
--- 5.12.4-1/ANode/src/ecflow/node/DefsTreeVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/DefsTreeVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,132 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_DefsTreeVisitor_HPP
-#define ecflow_node_DefsTreeVisitor_HPP
-
-#include <string>
-#include <vector>
-
-#include <ecflow/node/Alias.hpp>
-#include <ecflow/node/Defs.hpp>
-#include <ecflow/node/Family.hpp>
-#include <ecflow/node/Node.hpp>
-#include <ecflow/node/Suite.hpp>
-#include <ecflow/node/Task.hpp>
-
-namespace ecf {
-
-struct NodeNotFound : public std::runtime_error
-{
-    using std::runtime_error::runtime_error;
-};
-
-template <typename V>
-struct DefsTreeVisitor
-{
-    using path_t  = std::string;
-    using nodes_t = std::vector<const Node*>;
-
-    DefsTreeVisitor(const defs_ptr& defs, V& v) : defs_{*defs}, v_{v} {}
-
-    DefsTreeVisitor(const Defs& defs, V& v) : defs_{defs}, v_{v} {}
-
-    void visit_at(const path_t& path) {
-        nodes_t nodes = nodes_at(path);
-        for (auto node : nodes) {
-            visit(*node);
-        }
-    }
-
-private:
-    const Defs& defs_;
-    V& v_;
-
-private:
-    nodes_t nodes_at(const path_t& path) const {
-        nodes_t nodes;
-        if (path == "/") {
-            std::vector<suite_ptr> suites = defs_.suiteVec();
-            std::transform(std::begin(suites), std::end(suites), std::back_inserter(nodes), [](const suite_ptr& ptr) {
-                return static_cast<Node*>(ptr.get());
-            });
-        }
-        else {
-            nodes = nodes_t{get_node(path).get()};
-        }
-        return nodes;
-    }
-
-    node_ptr get_node(const std::string& path) const {
-        if (node_ptr node = defs_.findAbsNode(path); node) {
-            return node;
-        }
-
-        throw NodeNotFound(std::string{"Unable to find node: "} + path);
-    }
-
-    void visit(const Node& node) {
-
-        if (auto found = dynamic_cast<const Suite*>(&node); found) {
-            // Visit suite itself
-            v_.begin_visit(*found);
-            // Visit suite children
-            for (auto&& entry : found->nodeVec()) {
-                visit(*entry.get());
-            }
-            v_.end_visit(*found);
-            return;
-        }
-
-        if (auto found = dynamic_cast<const Family*>(&node); found) {
-            // Visit family itself
-            v_.begin_visit(*found);
-            // Visit family children
-            for (auto&& entry : found->nodeVec()) {
-                visit(*entry.get());
-            }
-            v_.end_visit(*found);
-            return;
-        }
-
-        if (auto found = dynamic_cast<const Task*>(&node); found) {
-            // Visit task itself
-            v_.begin_visit(*found);
-            // Visit task children (i.e. aliases)
-            std::vector<alias_ptr> aliases;
-            found->get_all_aliases(aliases);
-            for (const auto& entry : aliases) {
-                visit(*entry.get());
-            }
-            v_.end_visit(*found);
-            return;
-        }
-
-        if (auto found = dynamic_cast<const Alias*>(&node); found) {
-            // Visit alias itself
-            v_.begin_visit(*found);
-            v_.end_visit(*found);
-            return;
-        }
-
-        // Important!
-        // If this point is reached, then some kind of Node isn't being properly handled.
-        panic();
-    }
-
-    static void panic() {
-        assert(false);
-        std::terminate();
-    }
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_DefsTreeVisitor_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/EcfFile.cpp 5.13.0-1/ANode/src/ecflow/node/EcfFile.cpp
--- 5.12.4-1/ANode/src/ecflow/node/EcfFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/EcfFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1875 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/EcfFile.hpp"
-
-#include <cerrno>
-#include <memory>
-#include <sstream>
-#include <stdexcept>
-
-#include <sys/stat.h>
-#include <sys/wait.h> // for waitpid
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Submittable.hpp"
-
-// #define DEBUG_ECF_ 1
-// #define DEBUG_PRE_PROCESS 1
-// #define DEBUG_PRE_PROCESS_INCLUDES 1    // be careful with this as it will skew  the diffs in test code
-// #define DEBUG_MIGRATE 1                 // for TEST ONLY
-
-// #define DEBUG_PRE_PROCESS_OUTPUT 1
-// #define DEBUG_VAR_SUB_OUTPUT 1
-// #define DEBUG_MAN_FILE 1
-
-#ifdef DEBUG_ECF_
-    #include <iostream>
-#endif
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-
-static const char* T_NOPP        = "nopp";
-static const char* T_COMMENT     = "comment";
-static const char* T_MANUAL      = "manual";
-static const char* T_END         = "end";
-static const char* T_ECFMICRO    = "ecfmicro";
-static const char* T_INCLUDE     = "include ";
-static const char* T_INCLUDENOPP = "includenopp ";
-static const char* T_INCLUDEONCE = "includeonce ";
-
-static void vector_to_string(const std::vector<std::string>& vec, std::string& str) {
-    // Determine size of string, to avoid reallocation
-    size_t the_string_size = 0;
-    size_t theSize         = vec.size();
-    for (size_t i = 0; i < theSize; i++) {
-        the_string_size += vec[i].size() + 1;
-    } // +1 is for "\n";
-    str.reserve(str.size() + the_string_size);
-
-    // populate string using the vector
-    for (size_t i = 0; i < theSize; i++) {
-        str += vec[i];
-        str += "\n";
-    }
-}
-
-EcfFile::EcfFile() = default;
-
-EcfFile& EcfFile::operator=(const EcfFile& rhs) {
-    /// This preserves the caches, used to avoid opening/stat of include file more than once.
-    // assign in order or declaration
-    node_               = rhs.node_;
-    ecfMicroCache_      = rhs.ecfMicroCache_;
-    script_path_or_cmd_ = rhs.script_path_or_cmd_;
-    jobLines_.resize(0); // the most expensive
-    job_size_.clear();
-    script_origin_             = rhs.script_origin_;
-    ecf_file_search_algorithm_ = rhs.ecf_file_search_algorithm_;
-    return *this;
-}
-
-// ==================================================================================
-// Avoid making any data model/defs state changes. Changes like:
-//       node_->flag().set(ecf::Flag::NO_SCRIPT);
-// Which will cause a state change.
-// If the script fails then it is up to the calling Task to set this flag
-// This class is also used to extract the scripts/manual, etc form
-// a read only command. hence this class cannot make state changes
-// ===================================================================================
-EcfFile::EcfFile(Node* t,
-                 const std::string& pathToEcfFileOrCommand,
-                 EcfFile::Origin script_origin,
-                 EcfFile::EcfFileSearchAlgorithm search_algo)
-    : node_(t),
-      script_path_or_cmd_(pathToEcfFileOrCommand),
-      script_origin_(script_origin),
-      ecf_file_search_algorithm_(search_algo) {
-    node_->findParentUserVariableValue(Str::ECF_MICRO(), ecfMicroCache_);
-    if (ecfMicroCache_.empty() || ecfMicroCache_.size() != 1) {
-        std::stringstream ss;
-        ss << "EcfFile::EcfFile: Node " << t->absNodePath() << " is referencing a invalid ECF_MICRO variable(' "
-           << ecfMicroCache_ << "). ECF_MICRO when overridden, must be a single character.";
-        throw std::runtime_error(ss.str());
-    }
-
-#ifdef DEBUG_ECF_
-    cout << "   EcfFile::EcfFile pathToEcfFileOrCommand = " << script_path_or_cmd_ << " script_type = " << script_type
-         << "\n";
-#endif
-}
-
-void EcfFile::manual(std::string& theManual) {
-    /// Pre-process the file accessible from the server
-    std::vector<std::string> lines;
-    std::string error_msg;
-    EcfFile::Type file_type = (node_->isSubmittable()) ? EcfFile::SCRIPT : EcfFile::MANUAL;
-    if (!open_script_file(script_path_or_cmd_, file_type, lines, error_msg)) {
-        std::stringstream ss;
-        ss << "EcfFile::manual: For node " << node_->debugNodePath() << ", failed to open file " << script_path_or_cmd_
-           << " : " << error_msg;
-        throw std::runtime_error(ss.str());
-    }
-
-    // expand all %includes this will expand %includenopp by enclosing in %nopp %end, will populate jobLines_
-    PreProcessor data(this, "EcfFile::manual:");
-    data.preProcess(lines);
-
-    // perform variable sub's but don't error if failure
-    try {
-        JobsParam dummy; // create jobs = false, spawn jobs =  false
-        variableSubstitution(dummy);
-    }
-    catch (...) {
-    }
-
-    vector<string> theManualLines;
-    if (!extractManual(jobLines_, theManualLines, error_msg)) {
-        std::stringstream ss;
-        ss << "EcfFile::manual: extraction failed for task " << node_->absNodePath() << " " << error_msg;
-        throw std::runtime_error(ss.str());
-    }
-
-    if (theManualLines.empty()) {
-        // There is no %manual -> %end in the file. However this may be .man file for Suites/Family
-        // For this case just include the pre-processed contents as is, ie since the whole file
-        // is the manual
-        if (node_->isNodeContainer()) {
-            vector_to_string(jobLines_, theManual);
-            return;
-        }
-    }
-
-    vector_to_string(theManualLines, theManual);
-}
-
-std::string EcfFile::origin_str(EcfFile::Origin origin) {
-    string ret;
-    switch (origin) {
-        case ECF_FILES:
-            ret = "ECF_FILES";
-            break;
-        case ECF_HOME:
-            ret = "ECF_HOME";
-            break;
-        case ECF_SCRIPT:
-            ret = "ECF_SCRIPT";
-            break;
-        case ECF_FETCH_CMD:
-            ret = "ECF_FETCH";
-            break;
-        case ECF_SCRIPT_CMD:
-            ret = "ECF_SCRIPT_CMD";
-            break;
-    }
-    return ret;
-}
-
-std::string EcfFile::search_algorithm_str(EcfFile::EcfFileSearchAlgorithm sa) {
-    string ret;
-    switch (sa) {
-        case PRUNE_ROOT:
-            ret = "PRUNE_ROOT";
-            break;
-        case PRUNE_LEAF:
-            ret = "PRUNE_LEAF";
-            break;
-    }
-    return ret;
-}
-
-std::string EcfFile::ecf_file_origin_dump() const {
-    string origin = "# ecf_script_origin :";
-    switch (script_origin_) {
-        case ECF_FILES: {
-            origin += " ECF_FILES(";
-            if (ecf_file_search_algorithm_ == EcfFile::PRUNE_ROOT)
-                origin += "PRUNE_ROOT) : ";
-            else
-                origin += "PRUNE_LEAF) : ";
-            break;
-        }
-        case ECF_HOME: {
-            origin += " ECF_HOME(";
-            if (ecf_file_search_algorithm_ == EcfFile::PRUNE_ROOT)
-                origin += "PRUNE_ROOT) : ";
-            else
-                origin += "PRUNE_LEAF) : ";
-            break;
-        }
-        case ECF_SCRIPT:
-            origin += " ECF_SCRIPT : ";
-            break;
-        case ECF_FETCH_CMD:
-            origin += " ECF_FETCH : ";
-            break;
-        case ECF_SCRIPT_CMD:
-            origin += " ECF_SCRIPT_CMD : ";
-            break;
-    }
-    origin += script_path_or_cmd_;
-    return origin;
-}
-
-void EcfFile::script(std::string& theScript) const {
-    if (script_origin_ == EcfFile::ECF_SCRIPT) {
-        if (!File::open(script_path_or_cmd_, theScript)) {
-            std::stringstream ss;
-            ss << "EcfFile::script: Could not open script for task/alias " << node_->absNodePath() << " at path "
-               << script_path_or_cmd_ << " (" << strerror(errno) << ")";
-            throw std::runtime_error(ss.str());
-        }
-        return;
-    }
-
-    // record script origin, as a comment on the first line
-    std::vector<std::string> lines;
-    lines.push_back(ecf_file_origin_dump());
-    std::string error_msg;
-    if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, error_msg)) {
-        std::stringstream ss;
-        ss << "EcfFile::script: Could not open script for task/alias " << node_->absNodePath() << " using command "
-           << script_path_or_cmd_;
-        throw std::runtime_error(ss.str());
-    }
-    vector_to_string(lines, theScript);
-}
-
-void EcfFile::pre_process_user_file(std::vector<std::string>& user_edit_file, std::string& pre_processed_file) {
-    // expand all %includes this will expand %includenopp by enclosing in %nopp %end, will populate jobLines_
-    PreProcessor data(this, "EcfFile::pre_process_user_file");
-    data.preProcess(user_edit_file);
-
-    remove_comment_manual_and_nopp_tokens();
-
-    JobsParam dummy;
-    variableSubstitution(dummy);
-
-    vector_to_string(jobLines_, pre_processed_file);
-}
-
-void EcfFile::pre_process(std::string& pre_processed_file) {
-    /// Pre-process the ECF file accessible from the server
-    std::vector<std::string> lines;
-    std::string error_msg;
-    if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, error_msg)) {
-        std::stringstream ss;
-        ss << "EcfFile::pre_process: Failed to open file " << script_path_or_cmd_ << " : " << error_msg;
-        throw std::runtime_error(ss.str());
-    }
-
-    // expand all %includes this will expand %includenopp by enclosing in %nopp %end, will populate jobLines_
-    PreProcessor data(this, "EcfFile::pre_process");
-    data.preProcess(lines);
-
-    /// Find Used variables, *after* all %includes expanded, can throw std::runtime_error
-    get_used_variables(pre_processed_file);
-
-    /// Add pre-processed content
-    vector_to_string(jobLines_, pre_processed_file);
-}
-
-void EcfFile::edit_used_variables(std::string& return_script_with_used_variables) {
-    std::string errorMsg;
-    std::vector<std::string> lines;
-    if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, errorMsg)) {
-        throw std::runtime_error("EcfFile::edit_used_variables: Open script failed : " + errorMsg);
-    }
-
-    // Copy the script file, *BEFORE* expanding the includes
-    std::string script;
-    vector_to_string(lines, script);
-
-    // expand all %includes
-    PreProcessor data(this, "EcfFile::edit_used_variables");
-    data.preProcess(lines);
-
-    /// Find Used variables, *after* all %includes expanded, Can throw std::runtime_error
-    get_used_variables(return_script_with_used_variables);
-
-    /// Return Used variables and SCRIPT before pre-processing
-    return_script_with_used_variables += script;
-}
-
-const std::string& EcfFile::create_job(JobsParam& jobsParam) {
-#ifdef DEBUG_ECF_
-    cout << "EcfFile::createJob task " << node_->absNodePath() << " script_path_or_cmd_ = " << script_path_or_cmd_
-         << "\n";
-#endif
-
-    // NOTE: When editing pure python jobs, we may have *NO* variable specified, but only user_edit_file
-    //       hence whenever we have user_edit_file, we should follow the else part below
-    std::string error_msg;
-    { // add scope to limit lifetime of lines variable
-        std::vector<std::string> lines;
-        if (jobsParam.user_edit_variables().empty() && jobsParam.user_edit_file().empty()) {
-            /// The typical *NORMAL* path
-            if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, error_msg)) {
-                throw std::runtime_error("EcfFile::create_job: failed " + error_msg);
-            }
-        }
-        else {
-            // *USER* edit, two kinds
-            if (jobsParam.user_edit_file().empty()) {
-                // *USE* user variables, but ECF file accessible from the server
-                if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, jobsParam.errorMsg())) {
-                    throw std::runtime_error("EcfFile::create_job: User variables, Could not open script: " +
-                                             error_msg);
-                }
-            }
-            else {
-                // *USE* the user supplied ECF file *AND* user variables
-                lines = jobsParam.user_edit_file();
-            }
-        }
-
-        // expand all %includes this will expand %includenopp by enclosing in %nopp %end
-
-        PreProcessor data(this, "EcfFile::create_job");
-        data.preProcess(lines);
-    }
-
-#ifdef DEBUG_PRE_PROCESS_OUTPUT
-    std::string err;
-    File::create("preProcess" + get_extn(), jobLines_, err);
-#endif
-
-    // _IF_ ECF_CLIENT is specified provide Special support for migration.
-    // The variable ECF_CLIENT is used to specify the path to client exe.
-    // This is then used to replace smsinit,smscomplete, smsevent,smsmeter.smslabel,smsabort
-    std::string clientPath;
-    if (node_->findParentUserVariableValue("ECF_CLIENT", clientPath)) {
-        if (!replaceSmsChildCmdsWithEcf(clientPath, error_msg)) {
-            throw std::runtime_error("EcfFile::create_job: ECF_CLIENT replacement failed " + error_msg);
-        }
-#ifdef DEBUG_MIGRATE
-        std::string err;
-        File::create("migrate" + get_extn(), jobLines_, err);
-#endif
-    }
-
-    /// Will use *USER* supplied edit variables in preference to node tree variable *IF* supplied
-    /// expand %VAR% or %VAR:sub% & replace %% with %
-    // Allow variable substitution in comment and manual blocks. But if it fails, don't report as an error
-    variableSubstitution(jobsParam);
-
-#ifdef DEBUG_VAR_SUB_OUTPUT
-    std::string err1;
-    File::create("variableSub" + get_extn(), jobLines_, err1);
-#endif
-
-#ifdef DEBUG_MAN_FILE
-    if (!doCreateManFile(error_msg)) {
-        throw std::runtime_error("EcfFile::create_job: manual file creation failed " + error_msg);
-    }
-#endif
-
-    /// Create the user file for tasks, when submitting without aliases,  before removing comments
-    if (node_->isTask() && !jobsParam.user_edit_variables().empty()) {
-        doCreateUsrFile();
-    }
-
-    remove_comment_manual_and_nopp_tokens();
-
-    return doCreateJobFile(jobsParam /* this is only past in for profiling */); // create job on disk
-}
-
-void EcfFile::extract_used_variables(NameValueMap& used_variables_as_map,
-                                     const std::vector<std::string>& script_lines) {
-    // we only process the contents of the FIRST %comment  %end
-    bool comment   = false;
-    size_t theSize = script_lines.size();
-    for (size_t i = 0; i < theSize; ++i) {
-
-        // std::cout << "EcfFile::extract_used_variables found:'" << script_lines[i] << "\n";
-        if (script_lines[i].empty())
-            continue;
-
-        // take into account micro char during variable substitution
-        string::size_type ecfmicro_pos = script_lines[i].find(Ecf::MICRO());
-        if (ecfmicro_pos == 0) {
-
-            // We cannot do variable substitution between %nopp/%end
-            if (script_lines[i].find(T_COMMENT) == 1) {
-                comment = true;
-                continue;
-            }
-            if (script_lines[i].find(T_NOPP) == 1) {
-                return;
-            }
-            if (script_lines[i].find(T_MANUAL) == 1) {
-                return;
-            }
-            if (script_lines[i].find(T_END) == 1) {
-                return;
-            }
-        }
-
-        if (comment) {
-
-            // expect  name =  value
-            string::size_type equal_pos = script_lines[i].find("=");
-            if (equal_pos == string::npos)
-                continue;
-            string name  = script_lines[i].substr(0, equal_pos);
-            string value = script_lines[i].substr(equal_pos + 1);
-            ecf::algorithm::trim(name);
-            ecf::algorithm::trim(value);
-
-            // std::cout << "   extracted as '" << name << "' = '" << value << "'\n";
-            used_variables_as_map.insert(std::make_pair(name, value));
-        }
-    }
-}
-
-/**
- * Retrieve the set of paths defined by ECF_INCLUDE.
- *
- * ECF_INCLUDE is either a single path, or a list of paths (separated by ':').
- * The content of ECF_INCLUDE can reference ecFlow variables, which are replaced in the result.
- *
- * @param ecf
- *   The ECF file to consider (the Node directly related with the file determines which ECF_INCLUDE value is used)
- *
- * @return
- *   An empty set if ECF_INCLUDE is not defined; otherwise, the set of paths defined by ECF_INCLUDE, after resolving
- *   all ecFlow variables.
- */
-std::vector<std::string> EcfFile::get_ecf_include_paths(const EcfFile& ecf) {
-    assert(ecf.node_);
-    const Node& node = *ecf.node_;
-
-    std::string ecf_include;
-    node.findParentUserVariableValue(Str::ECF_INCLUDE(), ecf_include);
-
-    std::vector<std::string> paths;
-    if (!ecf_include.empty()) {
-
-        // if ECF_INCLUDE is a set a paths, search in order. i.e., like $PATH
-        if (ecf_include.find(':') != std::string::npos) {
-            Str::split(ecf_include, paths, ":");
-        }
-        else {
-            paths = {ecf_include};
-        }
-
-        // Don't rely on hard coded paths. Added for testing, but could be generally useful
-        // since in test scenario ECF_INCLUDE is defined relative to $ECF_HOME
-        for (std::string& path : paths) {
-            node.variable_dollar_substitution(path);
-            node.variableSubstitution(path);
-        }
-    }
-
-    return paths;
-}
-
-bool EcfFile::open_script_file(const std::string& file_or_cmd,
-                               EcfFile::Type type,
-                               std::vector<std::string>& lines,
-                               std::string& errormsg) const {
-#ifdef DEBUG_ECF_
-    std::cout << "EcfFile::open_script_file file(" << file_or_cmd << ") type(" << fileType(type) << ")\n";
-#endif
-    if (file_or_cmd.empty()) {
-        std::stringstream ss;
-        ss << "EcfFile::open_script_file: Could not open ecf " << fileType(type)
-           << " file. Input File/cmd string is empty.";
-        errormsg += ss.str();
-        return false;
-    }
-
-    switch (script_origin_) {
-        case ECF_FILES:
-        case ECF_HOME:
-        case ECF_SCRIPT: {
-            if (type == EcfFile::INCLUDE) {
-                return open_include_file(file_or_cmd, lines, errormsg);
-            }
-            if (!File::splitFileIntoLines(file_or_cmd, lines)) {
-                std::stringstream ss;
-                ss << "Could not open " << fileType(type) << " file:" << file_or_cmd << " (" << strerror(errno) << ")";
-                errormsg += ss.str();
-                return false;
-            }
-            break;
-        }
-
-        case ECF_FETCH_CMD: {
-            // Not tested.
-            string theFile;
-            string theCommand = file_or_cmd; // variables have already been substituted
-            switch (type) {
-                case EcfFile::SCRIPT: {
-                    theCommand += " -s ";
-                    theFile = node_->name() + get_extn();
-                    break;
-                }
-                case EcfFile::INCLUDE:
-                    theCommand += " -i ";
-                    break;
-                case EcfFile::MANUAL: {
-                    theCommand += " -m ";
-                    theFile = node_->name() + get_extn();
-                    break;
-                }
-                case EcfFile::COMMENT: {
-                    theCommand += " -c ";
-                    theFile = node_->name() + get_extn();
-                    break;
-                }
-            }
-            theCommand += theFile;
-            if (!do_popen(theCommand, type, lines, errormsg))
-                return false;
-            break;
-        }
-
-        case ECF_SCRIPT_CMD: {
-            switch (type) {
-                case EcfFile::SCRIPT: {
-                    if (!do_popen(file_or_cmd, type, lines, errormsg))
-                        return false;
-                    break;
-                }
-                case EcfFile::INCLUDE:
-                    return open_include_file(file_or_cmd, lines, errormsg);
-                    break;
-                case EcfFile::MANUAL:
-                case EcfFile::COMMENT:
-                    if (!File::splitFileIntoLines(file_or_cmd, lines)) {
-                        std::stringstream ss;
-                        ss << "Could not open " << fileType(type) << " file:" << file_or_cmd << " (" << strerror(errno)
-                           << ")";
-                        errormsg += ss.str();
-                        return false;
-                    }
-                    break;
-            }
-            break;
-        }
-    }
-    return true;
-}
-
-#define USE_INCLUDE_CACHE 1
-//  ulimit -Hn            # hard limit, of number of open files allowed
-//  ulimit -Sn            # soft limit
-//  ulimit -n <new-limit> # takes affect on current shell only
-//
-//  Check limit of running process:
-//     ps aux | grep process-name
-//     cat /proc/XXX/limits
-//  max open files allowed is:
-//     VM:       cat /proc/sys/fs/file-max:  188086
-//     Desk top: cat /proc/sys/fs/file-max: 3270058
-//  Desktop:
-//     Without cache: real:10.15  user: 5.58  sys: 1.62                                     # opensuse131
-//     With cache:    real: 4.46  user: 3.72  sys: 0.74  Only open/close include file once. # opensuse131
-//     With cache:    real: 3.82  user: 3.22  sys: 0.59  Only open/close include file once. # leap42
-//
-bool EcfFile::open_include_file(const std::string& file, std::vector<std::string>& lines, std::string& errormsg) const {
-#ifdef USE_INCLUDE_CACHE
-    // SEARCH THE CACHE
-    size_t include_file_cache_size = include_file_cache_.size();
-    for (size_t i = 0; i < include_file_cache_size; i++) {
-        if (include_file_cache_[i]->path() == file) {
-            // cout << "found " << file << " in cache, cache size = " << include_file_cache_.size() << "\n";
-            if (!include_file_cache_[i]->lines(lines)) {
-                std::stringstream ss;
-                ss << "Could not open include file: " << file << " (" << strerror(errno)
-                   << ") : include file cache size:" << include_file_cache_.size();
-                errormsg += ss.str();
-                return false;
-            }
-            return true;
-        }
-    }
-
-    // cout << "NOT found " << file << " in cache, cache size = " << include_file_cache_.size() << "\n";
-
-    if (include_file_cache_size > 1000) {
-        // avoid hitting limit for open file descriptors ~1024, valgrind(takes 10 fd). clear cache
-        include_file_cache_.clear();
-    }
-
-    // ADD to cache
-    std::shared_ptr<IncludeFileCache> ptr = std::make_shared<IncludeFileCache>(file);
-    include_file_cache_.push_back(ptr);
-
-    if (!ptr->lines(lines)) {
-        if (errno == EMFILE /*Too many open files*/) {
-
-            log(Log::WAR,
-                "EcfFile::open_include_file: Too many files open(errno=EMFILE), Clearing cache, and trying again. "
-                "Check limits with ulimit -Sn");
-            include_file_cache_.clear();
-
-            std::shared_ptr<IncludeFileCache> a_ptr = std::make_shared<IncludeFileCache>(file);
-            include_file_cache_.push_back(a_ptr);
-            if (!a_ptr->lines(lines)) {
-                std::stringstream ss;
-                ss << "Could not open include file: " << file << " (" << strerror(errno)
-                   << ") include file cache size:" << include_file_cache_.size();
-                errormsg += ss.str();
-                return false;
-            }
-        }
-        else {
-            std::stringstream ss;
-            ss << "Could not open include file: " << file << " (" << strerror(errno)
-               << ") include file cache size:" << include_file_cache_.size();
-            errormsg += ss.str();
-            return false;
-        }
-    }
-#else
-    if (!File::splitFileIntoLines(file, lines)) {
-        std::stringstream ss;
-        ss << "Could not open include file:" << file << " (" << strerror(errno) << ")";
-        errormsg += ss.str();
-        return false;
-    }
-#endif
-    return true;
-}
-
-bool EcfFile::do_popen(const std::string& the_cmd,
-                       EcfFile::Type type,
-                       std::vector<std::string>& lines,
-                       std::string& errormsg) const {
-    FILE* fp = popen(the_cmd.c_str(), "r");
-    if (!fp) {
-        std::stringstream ss;
-        ss << "EcfFile::do_popen:: Could not open " << fileType(type) << " via cmd " << the_cmd << " for task "
-           << node_->absNodePath() << " (" << strerror(errno) << ") ";
-        errormsg += ss.str();
-        return false;
-    }
-    char line[LINE_MAX];
-    while (fgets(line, LINE_MAX, fp)) {
-        lines.emplace_back(line);
-        // remove any trailing new lines
-        std::string& the_line = lines.back();
-        if (!the_line.empty() && the_line[the_line.size() - 1] == '\n') {
-            the_line.erase(the_line.begin() + the_line.size() - 1);
-        }
-    }
-    int status = pclose(fp);
-    if (status == -1) {
-        std::stringstream ss;
-        ss << "EcfFile::do_popen: error on pclose for " << fileType(type) << " via cmd " << the_cmd << " for task "
-           << node_->absNodePath() << " (" << strerror(errno) << ") ";
-        errormsg += ss.str();
-        return false;
-    }
-
-    if (WIFEXITED(status)) {
-        // *Normal* termination via exit
-        if (WEXITSTATUS(status)) {
-            std::stringstream ss;
-            ss << "EcfFile::do_popen: non-zero exit : " << fileType(type) << " via cmd " << the_cmd << " for task "
-               << node_->absNodePath() << " (" << strerror(errno) << ") ";
-            errormsg += ss.str();
-            return false;
-        }
-        else {
-            // exit(0) child terminated normally
-            return true;
-        }
-    }
-    if (WIFSIGNALED(status)) {
-        std::stringstream ss;
-        ss << "EcfFile::do_popen: child process terminated by a signal  : " << fileType(type) << " via cmd " << the_cmd
-           << " for task " << node_->absNodePath() << " (" << strerror(errno) << ") ";
-        errormsg += ss.str();
-        return false;
-    }
-
-    return true;
-}
-
-std::string EcfFile::fileType(EcfFile::Type t) {
-    switch (t) {
-        case EcfFile::SCRIPT:
-            return "script";
-            break;
-        case EcfFile::INCLUDE:
-            return "include";
-            break;
-        case EcfFile::MANUAL:
-            return "manual";
-            break;
-        case EcfFile::COMMENT:
-            return "comment";
-            break;
-    }
-    assert(false);
-    return string();
-}
-
-static void replace(string::size_type commentPos,
-                    std::string& jobLine,
-                    const std::string& smsChildCmd,
-                    const std::string& ecfEquiv,
-                    const std::string& clientPath) {
-    string::size_type childPos = jobLine.find(smsChildCmd);
-    if (childPos != std::string::npos) {
-        if (commentPos == std::string::npos) {
-            std::string replace1 = clientPath;
-            replace1 += ecfEquiv;
-            Str::replace(jobLine, smsChildCmd, replace1);
-        }
-        else if (childPos < commentPos) {
-            std::string replace2 = clientPath;
-            replace2 += ecfEquiv;
-            Str::replace(jobLine, smsChildCmd, replace2);
-        }
-    }
-}
-
-bool EcfFile::replaceSmsChildCmdsWithEcf(const std::string& clientPath, std::string& errormsg) {
-    //   smsinit $$          	   ---> ECF_CLIENT(value) --init=$$
-    //   smscomplete         	   ---> ECF_CLIENT(value)
-    //   smsevent eventname       ---> ECF_CLIENT(value) --event=eventname
-    //   smsmeter metername value ---> ECF_CLIENT(value) --meter=metername value
-    //   smslabel value           ---> ECF_CLIENT(value) --label=value
-    //   smswait expr             ---> ECF_CLIENT(value) --wait=expr
-    //   smsabort                 ---> ECF_CLIENT(value) --abort
-    size_t jobLines_size = jobLines_.size();
-    for (size_t i = 0; i < jobLines_size; ++i) {
-
-        // ONLY do the replacement if there is no leading comment
-        string::size_type commentPos = jobLines_[i].find("#");
-        replace(commentPos, jobLines_[i], "smsinit", " --init ", clientPath);
-        replace(commentPos, jobLines_[i], "smscomplete", " --complete ", clientPath);
-        replace(commentPos, jobLines_[i], "smsabort", " --abort ", clientPath);
-        replace(commentPos, jobLines_[i], "smsevent", " --event ", clientPath);
-        replace(commentPos, jobLines_[i], "smsmeter", " --meter ", clientPath);
-        replace(commentPos, jobLines_[i], "smslabel", " --label ", clientPath);
-        replace(commentPos, jobLines_[i], "smswait", " --wait ", clientPath);
-    }
-    return true;
-}
-
-bool EcfFile::extract_ecfmicro(const std::string& line, std::string& ecfmicro, std::string& error_msg) const {
-    if (!Str::get_token(line, 1, ecfmicro)) {
-        std::stringstream ss;
-        ss << "ecfmicro does not have a replacement character, in " << script_path_or_cmd_;
-        error_msg += ss.str();
-        return false;
-    }
-    // This is typically a single character, however $/£ will be multi-character i.e. size 2
-    if (ecfmicro.size() > 2) {
-        std::stringstream ss;
-        ss << "Expected ecfmicro replacement to be a single character, but found '" << ecfmicro << "' "
-           << ecfmicro.size() << " in file : " << script_path_or_cmd_;
-        error_msg += ss.str();
-        return false;
-    }
-    return true;
-}
-
-void EcfFile::variableSubstitution(const JobsParam& jobsParam) {
-    // Allow variable substitution in comment and manual blocks.
-    // But if it fails, don't report as an error
-
-    // get the cached ECF_MICRO variable, typically its one char.
-    string ecfMicro = ecfMicroCache_;
-    char microChar  = ecfMicro[0];
-
-    // We need a stack to properly implement nopp. This is required since we need to pair
-    // the %end, with nopp. i.e. need to handle
-    // %nopp
-    // %comment
-    // %end      // this is paired with comment
-    // %end      // This is paired with nopp
-    const int NOPP    = 0;
-    const int COMMENT = 1;
-    const int MANUAL  = 2;
-    std::vector<int> pp_stack;
-
-    bool nopp            = false;
-    size_t jobLines_size = jobLines_.size();
-    for (size_t i = 0; i < jobLines_size; ++i) {
-
-        // take into account micro char during variable substitution
-        string::size_type ecfmicro_pos = jobLines_[i].find(ecfMicro);
-        if (ecfmicro_pos == 0) {
-
-            // We cannot do variable substitution between %nopp/%end
-            if (jobLines_[i].find(T_MANUAL) == 1) {
-                pp_stack.push_back(MANUAL);
-                continue;
-            }
-            if (jobLines_[i].find(T_COMMENT) == 1) {
-                pp_stack.push_back(COMMENT);
-                continue;
-            }
-            if (jobLines_[i].find(T_NOPP) == 1) {
-                pp_stack.push_back(NOPP);
-                nopp = true;
-                continue;
-            }
-            if (jobLines_[i].find(T_END) == 1) {
-                if (pp_stack.empty())
-                    throw std::runtime_error("EcfFile::variableSubstitution: failed unpaired %end");
-                int last_directive = pp_stack.back();
-                pp_stack.pop_back();
-                if (last_directive == NOPP)
-                    nopp = false;
-                continue;
-            }
-
-            if (jobLines_[i].find(T_ECFMICRO) == 1) { // %ecfmicro #
-                // override ecfMicro char
-                std::string error_msg;
-                if (!extract_ecfmicro(jobLines_[i], ecfMicro, error_msg)) {
-                    throw std::runtime_error("EcfFile::variableSubstitution: failed : " + error_msg);
-                }
-                microChar = ecfMicro[0];
-                continue; // no point in doing variable subs on %ecfmicro ^
-            }
-        }
-        if (nopp)
-            continue;
-
-        /// For variable substitution % can occur anywhere on the line
-        if (ecfmicro_pos != string::npos) {
-
-            /// In the *NORMAL* flow jobsParam.user_edit_variables() will be EMPTY
-            if (!node_->variable_substitution(jobLines_[i], jobsParam.user_edit_variables(), microChar)) {
-
-                // Allow variable substitution in comment and manual blocks.
-                // But if it fails, don't report as an error
-                int last_directive = -1;
-                if (!pp_stack.empty())
-                    last_directive = pp_stack.back();
-                if (last_directive == COMMENT || last_directive == MANUAL)
-                    continue;
-
-                std::stringstream ss;
-                ss << "EcfFile::variableSubstitution: failed : '" << jobLines_[i] << "'";
-                dump_expanded_script_file(jobLines_);
-                throw std::runtime_error(ss.str());
-            }
-        }
-    }
-}
-
-void EcfFile::get_used_variables(std::string& used_variables) const {
-    /// Find Used variables, *after* all %includes expanded
-    NameValueMap used_variables_map;
-    std::string errorMsg;
-    if (!get_used_variables(used_variables_map, errorMsg)) {
-        throw std::runtime_error("EcfFile::get_used_variables: Extract used variables failed : " + errorMsg);
-    }
-
-    if (!used_variables_map.empty()) {
-
-        // add %comment - edit user variable, %end - ecf user variable
-        used_variables = ecfMicroCache_;
-        used_variables += "comment - ecf user variables\n";
-
-        // ***************************************************************************************
-        // Custom handling of dynamic variables, i.e. ECF_TRYNO, ECF_PASS and
-        // any variable that embeds a try number, i.e. ECF_JOB, ECF_JOBOUT
-        // This is required since the try number is *always* incremented *before* job submission,
-        // hence the value extracted from the job file will *not* be accurate, hence we exclude it.
-        // This way at job submission we use the latest/correct value, which is in-sync with JOB OUTPUT
-        // Note: Otherwise the job output will not be in sync
-        //
-        // Custom handling of ECF_PORT,ECF_HOST,ECF_NAME do not show these variables, these variables
-        // including ECF_PASS appear in the script. If the user accidentally edits them,
-        // Child communication with the server will be broken. Hence, not shown.
-        //
-        // All the above are examples of generated variables, which should not really be edited
-        // The used variables are typically *user* variable *in* the scripts, that user may need
-        // to modify. Hence, we have also excluded generated variables SUITE, FAMILY, TASK
-        // ****************************************************************************************
-        for (std::pair<std::string, std::string> item : used_variables_map) {
-            if (item.first.find(Str::ECF_TRYNO()) != std::string::npos)
-                continue;
-            if (item.first.find(Str::ECF_JOB()) != std::string::npos)
-                continue;
-            if (item.first.find(Str::ECF_JOBOUT()) != std::string::npos)
-                continue;
-            if (item.first.find(Str::ECF_PASS()) != std::string::npos)
-                continue;
-            if (item.first.find(Str::ECF_PORT()) != std::string::npos)
-                continue;
-            if (item.first.find(Str::ECF_HOST()) != std::string::npos)
-                continue;
-            if (item.first.find(Str::ECF_NAME()) != std::string::npos)
-                continue;
-
-            // We must use exact match, to avoid user variables like ESUITE,EFAMILY,ETASK
-            if (item.first == Str::TASK())
-                continue;
-            if (item.first == Str::FAMILY())
-                continue;
-            if (item.first == "FAMILY1")
-                continue;
-            if (item.first == Str::SUITE())
-                continue;
-            used_variables += item.first;
-            used_variables += " = ";
-            used_variables += item.second;
-            used_variables += "\n";
-        }
-
-        used_variables += ecfMicroCache_;
-        used_variables += "end - ecf user variables\n";
-    }
-}
-
-bool EcfFile::get_used_variables(NameValueMap& used_variables, std::string& errormsg) const {
-    // get the cached ECF_MICRO variable, typically its one char.
-    string ecfMicro = ecfMicroCache_;
-
-    char microChar = ecfMicro[0];
-
-    // We need a stack to properly implement nopp. This is required since we need to pair
-    // the %end, with nopp. i.e. need to handle
-    // %nopp
-    // %comment
-    // %end      // this is paired with comment
-    // %end      // This is paired with nopp
-    const int NOPP    = 0;
-    const int COMMENT = 1;
-    const int MANUAL  = 2;
-    std::vector<int> pp_stack;
-
-    bool nopp = false;
-    std::stringstream ss;
-
-    size_t job_lines_size = jobLines_.size();
-    for (size_t i = 0; i < job_lines_size; ++i) {
-
-        if (jobLines_[i].empty())
-            continue;
-
-        // take into account micro char during variable substitution
-        string::size_type ecfmicro_pos = jobLines_[i].find(ecfMicro);
-        if (ecfmicro_pos == 0) {
-
-            // We cannot do variable substitution between %nopp/%end
-            if (jobLines_[i].find(T_MANUAL) == 1) {
-                pp_stack.push_back(MANUAL);
-                continue;
-            }
-            if (jobLines_[i].find(T_COMMENT) == 1) {
-                pp_stack.push_back(COMMENT);
-                continue;
-            }
-            if (jobLines_[i].find(T_NOPP) == 1) {
-                pp_stack.push_back(NOPP);
-                nopp = true;
-                continue;
-            }
-            if (jobLines_[i].find(T_END) == 1) {
-                if (pp_stack.empty())
-                    throw std::runtime_error("EcfFile::get_used_variables: failed  unpaired %end");
-                int last_directive = pp_stack.back();
-                pp_stack.pop_back();
-                if (last_directive == NOPP)
-                    nopp = false;
-                continue;
-            }
-
-            if (!nopp && jobLines_[i].find(T_ECFMICRO) == 1) { // %ecfmicro #
-                // override ecfMicro char
-                std::string error_msg;
-                if (!extract_ecfmicro(jobLines_[i], ecfMicro, error_msg)) {
-                    throw std::runtime_error("EcfFile::get_used_variables: failed : " + error_msg);
-                }
-                microChar = ecfMicro[0];
-                continue;
-            }
-        }
-        if (nopp)
-            continue;
-
-        if (ecfmicro_pos != string::npos) {
-
-            /// *Note:* currently this modifies jobLines_[i]
-            std::string line_copy = jobLines_[i]; // avoid modifying the jobs Lines, end up doing  variable substitution
-            if (!node_->find_all_used_variables(line_copy, used_variables, microChar)) {
-
-                // Allow variable substitution in comment and manual blocks.
-                // But if it fails, dont report as an error
-                int last_directive = -1;
-                if (!pp_stack.empty())
-                    last_directive = pp_stack.back();
-                if (last_directive == COMMENT || last_directive == MANUAL)
-                    continue;
-
-                ss << "Variable find failed for '" << jobLines_[i] << "'  microChar='" << microChar << "' ";
-                dump_expanded_script_file(jobLines_);
-            }
-        }
-    }
-
-    // Append to error message if any
-    errormsg += ss.str();
-
-    return errormsg.empty();
-}
-
-const std::string& EcfFile::doCreateJobFile(JobsParam& jobsParam) const {
-    if (!jobLines_.empty()) {
-        // Guard against ecf file that exist's but is empty,
-        // no point in creating empty job files for them
-
-        // ECF_JOB is used with ECF_JOB_CMD when submitting a job.
-        // First look for a user variable of name ECF_JOB, otherwise look for
-        // the generated variable, hence this should never fail.
-        // *This* assumes that:
-        //   a/ if the user has overridden ECF_JOB then it has been specified at the task level
-        //      Otherwise findParentVariableValue will find the generated ECF_JOB on the task
-        //   b/ The value of the user variable has a valid directory paths and job file name
-        //   c/ The user will lose the try number.
-        std::string ecf_job;
-        if (!node_->findParentVariableValue(Str::ECF_JOB(), ecf_job)) {
-            LOG_ASSERT(!ecf_job.empty(), "EcfFile::doCreateJobFile: ECF_JOB should have been generated, program error");
-        }
-
-        // *** The location of the ECF_ file may not always be the same as the location
-        // *** of the job file. Job file location is specified by ECF_JOB
-        // cout << "EcfFile::createJob ecf " << script_path_or_cmd_ << " ECF_JOB(" << ecf_job << ")\n";
-
-        if (!File::createMissingDirectories(ecf_job)) {
-            std::stringstream ss;
-            ss << "EcfFile::doCreateJobFile: Could not create missing directories for ECF_JOB " << ecf_job << " ("
-               << strerror(errno) << ")";
-            throw std::runtime_error(ss.str());
-        }
-
-        // Create the jobs file.
-        std::string error_msg;
-        if (!File::create(ecf_job, jobLines_, error_msg)) {
-            std::stringstream ss;
-            if (errno == EMFILE /*Too many open files*/) {
-                // CLEAR cache and try again. Can test with ulimit -n 60, (Base/bin/gcc-5.3.0/release/perf_job_gen
-                // ./metabuilder.def)
-                LogToCout log_to_cout;
-                ss << "EcfFile::doCreateJobFile: Too many files open(errno=EMFILE), include file cache size("
-                   << include_file_cache_.size() << ") Clearing cache. Check limits with ulimit -Sn";
-                log(Log::WAR, ss.str());
-
-                include_file_cache_.clear();
-
-                error_msg.clear();
-                if (!File::create(ecf_job, jobLines_, error_msg)) {
-                    ss << "EcfFile::doCreateJobFile: Could not create job file, even after clearing include cache: "
-                       << error_msg; // error_msg includes strerror(errno)
-                    throw std::runtime_error(ss.str());
-                }
-            }
-            else {
-                ss << "EcfFile::doCreateJobFile: Could not create job file : "
-                   << error_msg; // error_msg includes strerror(errno)
-                throw std::runtime_error(ss.str());
-            }
-        }
-
-        // make the job file executable
-        if (chmod(ecf_job.c_str(), 0755) != 0) {
-            std::stringstream ss;
-            ss << "EcfFile::doCreateJobFile: Could not make job file " << ecf_job << "  executable by using chmod ("
-               << strerror(errno) << ")";
-            throw std::runtime_error(ss.str());
-        }
-
-        // record job size, for placement into log files
-        size_t job_output_size = 0;
-        size_t jobLines_size   = jobLines_.size();
-        // cout << " jobLines_.size() " << jobLines_size << " jobLines_.capacity() " << jobLines_.capacity() << "\n";
-        for (size_t i = 0; i < jobLines_size; ++i)
-            job_output_size += jobLines_[i].size();
-        job_output_size += jobLines_size; // take into account new lines for each line of output
-        job_size_ = "job_size:";
-        job_size_ += ecf::convert_to<std::string>(job_output_size);
-        return job_size_;
-    }
-
-    std::stringstream ss;
-    ss << "EcfFile::doCreateJobFile: The ecf file '" << script_path_or_cmd_ << "' that is associated with task '"
-       << node_->absNodePath() << "' is empty";
-    throw std::runtime_error(ss.str());
-}
-
-fs::path EcfFile::file_creation_path() const {
-    return fs::path(script_or_job_path());
-}
-
-std::string EcfFile::script_or_job_path() const {
-    if (script_origin_ == ECF_SCRIPT)
-        return script_path_or_cmd_;
-
-    // ECF_FETCH or ECF_SCRIPT_CMD
-    std::string ecf_job;
-    (void)node_->findParentVariableValue(Str::ECF_JOB(), ecf_job);
-    return ecf_job;
-}
-
-bool EcfFile::doCreateManFile(std::string& errormsg) {
-    vector<string> manFile;
-    if (!extractManual(jobLines_, manFile, errormsg)) {
-        return false;
-    }
-    if (!manFile.empty()) {
-
-        // find the directory associated with job file and place Man file there.
-        fs::path script_file_path = file_creation_path();
-        fs::path parent_path      = script_file_path.parent_path();
-        if (fs::is_directory(parent_path)) {
-
-            fs::path theManFilePath(parent_path.string() + '/' + node_->name() + File::MAN_EXTN());
-
-            // cout << "EcfFile::doCreateManFile job " << manFile.string() << "\n";
-            if (!File::create(theManFilePath.string(), manFile, errormsg))
-                return false;
-        }
-        else {
-            std::stringstream ss;
-            ss << "man file creation failed. The path '" << script_file_path.parent_path() << "' is not a directory";
-            errormsg += ss.str();
-            return false;
-        }
-    }
-    return true;
-}
-
-void EcfFile::doCreateUsrFile() const {
-    // find the directory associated with ecf file and place .usr file there.
-    fs::path script_file_path = file_creation_path();
-    fs::path parent_path      = script_file_path.parent_path();
-    if (fs::is_directory(parent_path)) {
-
-        fs::path theUsrFilePath(parent_path.string() + '/' + node_->name() + File::USR_EXTN());
-
-        // cout << "EcfFile::doCreateUsrFile job " << theUsrFilePath.string() << "\n";
-        std::string error_msg;
-        if (!File::create(theUsrFilePath.string(), jobLines_, error_msg)) {
-            throw std::runtime_error("EcfFile::doCreateUsrFile: file creation failed : " + error_msg);
-        }
-    }
-    else {
-        std::stringstream ss;
-        ss << "EcfFile::doCreateUsrFile: file creation failed. The path '" << script_file_path.parent_path()
-           << "' is not a directory";
-        throw std::runtime_error(ss.str());
-    }
-}
-
-bool EcfFile::extractManual(const std::vector<std::string>& lines,
-                            std::vector<std::string>& theManualLines,
-                            std::string& errormsg) const {
-    // Note: we have already done pre-processing, ie since the manual is obtained after
-    // all the includes have been pre-procssed, hence most errors should have been caught
-    // get the cached ECF_MICRO variable, typically its one char.
-    string ecfMicro = ecfMicroCache_;
-
-    bool add = false;
-    for (const auto& line : lines) {
-        if (line.find(ecfMicro) == 0) {
-            if (line.find(T_MANUAL) == 1) {
-                add = true;
-                continue;
-            }
-            if (add && line.find(T_END) == 1) {
-                add = false;
-                continue;
-            }
-
-            if (line.find(T_ECFMICRO) == 1) { // %ecfmicro #
-
-                if (!extract_ecfmicro(line, ecfMicro, errormsg)) {
-                    return false;
-                }
-
-                continue;
-            }
-        }
-        if (add) {
-            theManualLines.push_back(line);
-        }
-    }
-    if (add) {
-        std::stringstream ss;
-        ss << "Unterminated manual. Matching 'end' is missing, for " << script_path_or_cmd_;
-        errormsg += ss.str();
-        dump_expanded_script_file(lines);
-        return false;
-    }
-    return true;
-}
-
-void EcfFile::remove_comment_manual_and_nopp_tokens() {
-    // preserve *all* lines between %nopp and %end
-    // remove all line between %comment and %end | %manual and %end, *provided* they are not embedded in %nopp/%end
-    // remove tokens %nopp,%end,%ecfmicro and only remove %comment,%manual if they not embedded in %nopp/%end
-
-    // get the cached ECF_MICRO variable, typically its one char.
-    string ecfMicro = ecfMicroCache_;
-
-    // We need a stack to properly implement nopp. This is required since we need to pair
-    // the %end, with nopp. i.e. need to handle
-    // %nopp       // delete this line
-    // %comment    // preserve
-    // -- comment  // preserve
-    // %end        // preserve , this is paired with comment
-    // blah %blah% // preserve, i.e. don't preprocess
-    // %end        // delete this line, This is paired with nopp
-    //
-    // For the following
-    // %comment    // delete this line
-    // -- comment  // delete this line
-    // %end        // delete this line
-
-    const int NOPP    = 0;
-    const int COMMENT = 1;
-    const int MANUAL  = 2;
-    std::vector<int> pp_stack;
-    bool nopp          = false;
-    bool manual_erase  = false;
-    bool comment_erase = false;
-
-    for (auto i = jobLines_.begin(); i != jobLines_.end(); ++i) {
-
-        string::size_type ecfmicro_pos = (*i).find(ecfMicro);
-        if (ecfmicro_pos == 0) {
-            if ((*i).find(T_MANUAL) == 1) {
-                if (manual_erase) {
-                    std::stringstream ss;
-                    ss << "EcfFile::remove_comment_manual_and_nopp_tokens: Embedded manuals are not allowed in "
-                       << script_path_or_cmd_;
-                    throw std::runtime_error(ss.str());
-                }
-
-                pp_stack.push_back(MANUAL);
-                if (nopp)
-                    continue;         // preserve
-                jobLines_.erase(i--); // remove  %manual
-                manual_erase = true;
-                continue;
-            }
-            if ((*i).find(T_COMMENT) == 1) {
-                if (comment_erase) {
-                    std::stringstream ss;
-                    ss << "EcfFile::remove_comment_manual_and_nopp_tokens: Embedded comments are not allowed in "
-                       << script_path_or_cmd_;
-                    throw std::runtime_error(ss.str());
-                }
-
-                pp_stack.push_back(COMMENT);
-                if (nopp)
-                    continue;         // preserve
-                jobLines_.erase(i--); // remove %comment
-                comment_erase = true;
-                continue;
-            }
-            if ((*i).find(T_NOPP) == 1) {
-                if (nopp) {
-                    std::stringstream ss;
-                    ss << "Embedded nopp are not allowed " << script_path_or_cmd_;
-                    throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
-                }
-
-                pp_stack.push_back(NOPP);
-                nopp = true;
-                jobLines_.erase(i--); // remove %nopp
-                continue;
-            }
-            if ((*i).find(T_END) == 1) {
-                if (pp_stack.empty())
-                    throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed unpaired %end");
-                int last_directive = pp_stack.back();
-                pp_stack.pop_back();
-                if (last_directive == NOPP) {
-                    nopp = false;
-                    jobLines_.erase(i--); // remove %end associated with %nopp
-                    continue;
-                }
-                else if (last_directive == MANUAL) {
-                    manual_erase = false;
-                    if (nopp)
-                        continue;         // preserve
-                    jobLines_.erase(i--); // remove %end associated with %manual
-                    continue;
-                }
-                else if (last_directive == COMMENT) {
-                    comment_erase = false;
-                    if (nopp)
-                        continue;         // preserve
-                    jobLines_.erase(i--); // remove %end associated with %comment
-                    continue;
-                }
-                throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed unpaired %end does "
-                                         "not match nopp,comment or manual");
-            }
-            if (!nopp && (*i).find(T_ECFMICRO) == 1) { // %ecfmicro #
-
-                std::string error_msg;
-                if (!extract_ecfmicro((*i), ecfMicro, error_msg)) {
-                    throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed : " + error_msg);
-                }
-                jobLines_.erase(i--); // remove %ecfmicro &
-                continue;
-            }
-        }
-
-        // *** For No-preprocessor (nopp), we only remove the tokens(%nopp,%end) *NOT* the lines between.
-        // *noop* means skip pre-processing, and keep the lines untouched.
-        if (nopp)
-            continue;
-
-        if (manual_erase || comment_erase) {
-            // remove all line between %comment and %end | %manual and %end
-            jobLines_.erase(i--);
-        }
-    }
-
-    if (nopp) {
-        std::stringstream ss;
-        ss << "Unterminated nopp. Matching 'end' is missing, in " << script_path_or_cmd_;
-        throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
-    }
-    if (manual_erase) {
-        std::stringstream ss;
-        ss << "Unterminated manual. Matching 'end' is missing, in " << script_path_or_cmd_;
-        throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
-    }
-    if (comment_erase) {
-        std::stringstream ss;
-        ss << "Unterminated comment. Matching 'end' is missing, in " << script_path_or_cmd_;
-        throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
-    }
-}
-
-int EcfFile::countEcfMicro(const std::string& line, const std::string& ecfMicro) {
-    // ignore ecfmicro character in comments
-    // However pay special attenstion to:
-    // var="%VAR: # fred%  # %fred
-    if (ecfMicro.empty()) {
-        return 0;
-    }
-
-    int count          = 0;
-    const char theChar = ecfMicro[0];
-    size_t end         = line.size();
-    size_t comment_pos = 0;
-    for (size_t i = 0; i < end; ++i) {
-        if (line[i] == theChar) {
-            count++;
-        }
-        if (line[i] == '#') {
-            if (i == 0)
-                return 0;    // very first character is comment
-            comment_pos = i; // remember *last* comment pos
-        }
-    }
-
-    if (count % 2 != 0 && comment_pos != 0) {
-        // could have:
-        // var="%VAR: # fred%  # %fred
-        // discount trailing #
-        count = 0;
-        for (size_t i = 0; i < comment_pos; ++i) {
-            if (line[i] == theChar) {
-                count++;
-            }
-        }
-    }
-    //	cerr << "line " << line << " count = " << count << "\n";
-    return count;
-}
-
-void EcfFile::dump_expanded_script_file(const std::vector<std::string>& lines) {
-#ifdef DEBUG_PRE_PROCESS
-    std::string err;
-    if (!File::create("tmp" + get_extn(), lines, err))
-        std::cout << "Could not create file tmp.ecf\n";
-#endif
-}
-
-/// returns the extension, i.e. for task->.ecf for alias->.usr
-const std::string& EcfFile::get_extn() const {
-    Submittable* task_or_alias = node_->isSubmittable();
-    if (task_or_alias)
-        return task_or_alias->script_extension();
-    else {
-        std::stringstream ss;
-        ss << "EcfFile::get_extn(): Can only return extension for task/alias but found " << node_->debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    return Str::EMPTY();
-}
-
-// =======================================================================================
-
-PreProcessor::PreProcessor(EcfFile* ecfile, const char* error_context)
-    : ecfile_(ecfile),
-      error_context_(error_context),
-      ecf_micro_(ecfile->ecfMicroCache_),
-      jobLines_(ecfile->jobLines_) {
-    pp_nopp_ = ecf_micro_;
-    pp_nopp_ += T_NOPP;
-    pp_comment_ = ecf_micro_;
-    pp_comment_ += T_COMMENT;
-    pp_manual_ = ecf_micro_;
-    pp_manual_ += T_MANUAL;
-    pp_end_ = ecf_micro_;
-    pp_end_ += T_END;
-
-    /// Clear existing jobLines, pre-processing will populate jobLines_
-    jobLines_.clear();
-    jobLines_.reserve(512); // estimate for includes
-}
-
-PreProcessor::~PreProcessor() = default;
-
-void PreProcessor::preProcess(std::vector<std::string>& script_lines) {
-    bool ignore_end_check = false;
-    if (manual_ || comment_)
-        ignore_end_check = true; // %include inside a %manual || %comment, ignore end check in preProcess
-
-    // preProcess is called recursively, i.e. for processing includes
-    // Uses a Depth first traversal
-    for (auto& line : script_lines) {
-        jobLines_.emplace_back(std::move(line));
-        preProcess_line();
-    }
-
-    if (nopp_)
-        throw std::runtime_error(error_context() + "Unterminated nopp, matching 'end' is missing");
-    if (comment_ && !ignore_end_check)
-        throw std::runtime_error(error_context() + "Unterminated comment, matching 'end' is missing");
-    if (manual_ && !ignore_end_check)
-        throw std::runtime_error(error_context() + "Unterminated manual, matching 'end' is missing");
-}
-
-void PreProcessor::preProcess_line() {
-    const std::string& script_line = jobLines_.back();
-
-    // For variable substitution % can occur anywhere on the line, for pre -processing of
-    // %ecfmicro,%manual,%comment,%end,%include,%includenopp it must be the very *first* character
-    string::size_type ecfmicro_pos = script_line.find(ecf_micro_);
-    if (ecfmicro_pos == string::npos)
-        return;
-
-    // Check for Mismatched micro i.e. %FRED or %FRED%%
-    if (ecfmicro_pos != 0 && !nopp_ && !comment_ && !manual_) {
-        // For variable substitution '%' can occur anywhere on the line.
-        int ecfMicroCount = EcfFile::countEcfMicro(script_line, ecf_micro_);
-        if (ecfMicroCount % 2 != 0) {
-            ecfile_->dump_expanded_script_file(jobLines_);
-            std::stringstream ss;
-            ss << "Mismatched ecfmicro(" << ecf_micro_ << ") count(" << ecfMicroCount << ")  at : " << script_line;
-            throw std::runtime_error(error_context() + ss.str());
-        }
-    }
-
-    // %ecfmicro,%manual,%comment,%end,%include,%includenopp,%includeonce it must be the very *first* character
-    if (ecfmicro_pos != 0)
-        return; // handle 'garbage%include'
-
-#ifdef DEBUG_PRE_PROCESS
-    std::cout << i << ": " << script_line << "\n";
-#endif
-    if (script_line.find(pp_manual_) == 0) {
-        if (comment_ || manual_) {
-            ecfile_->dump_expanded_script_file(jobLines_);
-            std::stringstream ss;
-            ss << "Embedded comments/manuals not supported : '" << script_line << "'";
-            throw std::runtime_error(error_context() + ss.str());
-        }
-        manual_ = true;
-        return;
-    }
-    if (script_line.find(pp_comment_) == 0) {
-        if (comment_ || manual_) {
-            ecfile_->dump_expanded_script_file(jobLines_);
-            std::stringstream ss;
-            ss << "Embedded comments/manuals not supported : '" << script_line << "'";
-            throw std::runtime_error(error_context() + ss.str());
-        }
-        comment_ = true;
-        return;
-    }
-    if (script_line.find(pp_nopp_) == 0) {
-        if (nopp_) {
-            ecfile_->dump_expanded_script_file(jobLines_);
-            std::stringstream ss;
-            ss << "Embedded nopp not supported : '" << script_line << "'";
-            throw std::runtime_error(error_context() + ss.str());
-        }
-        nopp_ = true;
-        return;
-    }
-    if (script_line.find(pp_end_) == 0) {
-        if (comment_) {
-            comment_ = false;
-            return;
-        }
-        if (manual_) {
-            manual_ = false;
-            return;
-        }
-        if (nopp_) {
-            nopp_ = false;
-            return;
-        }
-
-        ecfile_->dump_expanded_script_file(jobLines_);
-        std::stringstream ss;
-        ss << pp_end_ << " found with no matching %comment | %manual | %nopp  : '" << script_line << "'";
-        throw std::runtime_error(error_context() + ss.str());
-    }
-    if (nopp_)
-        return;
-
-    // =================================================================================
-    // Handle ecfmicro replacement
-    // =================================================================================
-    if (script_line.find(T_ECFMICRO) == 1) { // %ecfmicro #
-
-        // keep %ecfmicro in jobs file later processing, i.e. for comments/manuals
-        std::string err;
-        if (!ecfile_->extract_ecfmicro(script_line, ecf_micro_, err)) {
-            throw std::runtime_error(error_context() + err);
-        }
-
-        pp_nopp_ = ecf_micro_;
-        pp_nopp_ += T_NOPP;
-        pp_comment_ = ecf_micro_;
-        pp_comment_ += T_COMMENT;
-        pp_manual_ = ecf_micro_;
-        pp_manual_ += T_MANUAL;
-        pp_end_ = ecf_micro_;
-        pp_end_ += T_END;
-
-        return;
-    }
-    else {
-        if (script_line.find("ecf_micro") == 1) { //  Mistyped ecfmicro
-            throw std::runtime_error(error_context() + "Replace with 'ecf_micro' with 'ecfmicro' at line: '" +
-                                     script_line + "'");
-        }
-    }
-
-    // If there's no second token, when what kind of directive is it ?
-    // allow   : %FRED:val%
-    // disallow: %FRED
-    std::string the_include_token;
-    if (!Str::get_token(script_line, 1, the_include_token)) {
-        int ecfMicroCount = EcfFile::countEcfMicro(script_line, ecf_micro_);
-        if (ecfMicroCount % 2 != 0) {
-            throw std::runtime_error(error_context() + " unrecognised pre-processing directive at: '" + script_line +
-                                     "'");
-        }
-        return;
-    }
-
-    // we only end up here if we have includes
-    preProcess_includes();
-}
-
-void PreProcessor::preProcess_includes() {
-    std::string includedFile;
-    bool fnd_includenopp = false;
-    {
-        // Take note: when we call jobLines_.pop_back() below, script_line will be invalidated
-        const std::string& script_line = jobLines_.back();
-
-        // =================================================================================
-        // order is *IMPORTANT*, hence search for includenopp, includeonce, include
-        // Otherwise string::find() of include will match includenopp and includeonce
-        // =================================================================================
-        bool fnd_includeonce = false;
-        bool fnd_include     = false;
-        fnd_includenopp      = (script_line.find(T_INCLUDENOPP) == 1);
-        if (!fnd_includenopp) {
-            fnd_includeonce = (script_line.find(T_INCLUDEONCE) == 1);
-            if (!fnd_includeonce)
-                fnd_include = (script_line.find(T_INCLUDE) == 1);
-        }
-        if (!fnd_include && !fnd_includenopp && !fnd_includeonce) {
-            if (script_line.find("include") == 1) {
-                throw std::runtime_error(error_context() + ", unrecognised or miss-spelled include at: '" +
-                                         script_line + "'");
-            }
-            return;
-        }
-
-        std::string the_include_token;
-        if (!Str::get_token(script_line, 1, the_include_token)) {
-            throw std::runtime_error(error_context() + "Could not extract include token at : " + script_line);
-        }
-
-#ifdef DEBUG_PRE_PROCESS_INCLUDES
-        // Output the includes for debug purposes. Will appear in preProcess.ecf
-        // Note: Will interfere with diff
-        jobLines_.push_back("========== include of " + the_include_token + " ===========================");
-#endif
-
-        includedFile = getIncludedFilePath(the_include_token, script_line);
-
-        // remove %include from the job lines, since were going to expand or ignore it.
-        // **** input script_line life_time is tied, jobLines_.back(), hence jobLines_.pop_back() will invalidate
-        // script_lines
-        // **** Hence don't use script_line after this point.
-        jobLines_.pop_back();
-
-        // handle %includeonce
-        if (fnd_includeonce) {
-            if (std::find(include_once_set_.begin(), include_once_set_.end(), includedFile) !=
-                include_once_set_.end()) {
-                return; // Already processed once ignore
-            }
-            include_once_set_.push_back(includedFile);
-        }
-    }
-
-#ifdef DEBUG_PRE_PROCESS
-    cout << "EcfFile::preProcess processing " << includedFile << "\n";
-#endif
-
-    // Check for recursive includes. some includes like %include <endt.h>
-    // are included many times, but the include is not recursive.
-    // To get round this will use a simple count.
-    // replace map with vector
-    bool fnd = false;
-    for (auto& p : globalIncludedFileSet_) {
-        if (p.first == includedFile) {
-            fnd = true;
-            if (p.second > 100) {
-                std::stringstream ss;
-                ss << " Recursive include of file " << includedFile << " for " << ecfile_->script_path_or_cmd_;
-                throw std::runtime_error(error_context() + ss.str());
-            }
-            p.second++;
-            break;
-        }
-    }
-    if (!fnd) {
-        globalIncludedFileSet_.emplace_back(includedFile, 0);
-    }
-
-    std::vector<std::string> include_lines;
-    if (fnd_includenopp)
-        include_lines.push_back(ecf_micro_ + T_NOPP);
-    std::string err;
-    if (!ecfile_->open_script_file(includedFile, EcfFile::INCLUDE, include_lines, err)) {
-        throw std::runtime_error(error_context() + err);
-    }
-    if (fnd_includenopp)
-        include_lines.push_back(ecf_micro_ + T_END);
-
-    preProcess(include_lines);
-}
-
-std::string PreProcessor::getIncludedFilePath(const std::string& includedFile1, const std::string& line) {
-    // Include can have following format: [ %include | %includeonce | %includenopp ]
-    //   %include /tmp/file.name   -> /tmp/filename
-    //   %include file.name        -> file.name
-    //   %include "../file.name"   -> script_file_location/../file.name
-    //   %include "./file.name"    -> script_file_location/./file.name
-    //   %include "file.name"      -> %ECF_HOME%/%SUITE%/%FAMILY%/filename
-    //   %include <file.name>      -> %ECF_INCLUDE%/filename || %ECF_HOME%/filename # note: ECF_HOME is always a single
-    //   path
-    //
-    //   %include <%file%.name>        -> %ECF_INCLUDE%/filename || %ECF_HOME%/filename
-    //   %include "%file%.name"        -> %ECF_HOME%/%SUITE%/%FAMILY%/filename
-    //   %include "./%file%.name"      -> script_file_location/./file.name
-    //   %include "/%tmp%/%file%.name" -> /%tmp%/%file%.name
-    //   %include %INCLUDE%            -> any of the above
-    //
-    // When ECF_INCLUDE           -> path1:path2:path3
-    //   %include <filename>      -> path1/filename || path2/filename || path3/filename || ECF_HOME/filename
-
-    // the included file could have variables,(ECFLOW-765), check for miss-matched ecf_micro
-    std::string includedFile = includedFile1;
-    if (includedFile.find(ecf_micro_) != std::string::npos) {
-        int ecfMicroCount = EcfFile::countEcfMicro(includedFile, ecf_micro_);
-        if (ecfMicroCount % 2 != 0) {
-            std::stringstream ss;
-            ss << "Mismatched ecfmicro(" << ecf_micro_ << ") count(" << ecfMicroCount << ") at : " << line;
-            throw std::runtime_error(error_context() + ss.str());
-        }
-        NameValueMap user_edit_variables;
-        ecfile_->node_->variable_substitution(includedFile, user_edit_variables, ecf_micro_[0]);
-    }
-
-    std::string the_include_file = includedFile.substr(1, includedFile.size() - 2);
-    if (includedFile.size() >= 2 && includedFile[1] == '/') {
-        // filename starts with '/' no interpretation return as in
-        // %include </home/ecf/fred.ecf>
-        // %include "/home/ecf/fred.ecf"
-        return the_include_file;
-    }
-
-    Node* node = ecfile_->node_;
-    if (includedFile[0] == '<') {
-
-        auto ecf_include_paths = EcfFile::get_ecf_include_paths(*ecfile_);
-        for (const auto& ecf_include_path : ecf_include_paths) {
-            auto include_path_plus_file = ecf_include_path;
-            include_path_plus_file += '/';
-            include_path_plus_file += the_include_file;
-
-            if (ecfile_->file_exists(include_path_plus_file))
-                return include_path_plus_file;
-        }
-
-        // WE get HERE *if* ECF_INCLUDE not specified, or if specified but file *not found*
-        std::string ecf_include;
-        node->findParentVariableValue(Str::ECF_HOME(), ecf_include);
-        if (ecf_include.empty()) {
-            std::stringstream ss;
-            ss << "ECF_INCLUDE/ECF_HOME not specified, at : " << line;
-            throw std::runtime_error(error_context() + ss.str());
-        }
-
-        ecf_include += '/';
-        ecf_include += the_include_file;
-
-        return ecf_include;
-    }
-    else if (includedFile[0] == '"') {
-
-        // we have two forms: "head.h" & "../head.h"
-
-        //  ECFLOW-274 need to allow:
-        //     - %include "../fred.h"     # this is one directory up
-        //     - %include "./fred.h"      # this is at the same level as script
-        std::string path;
-        if (includedFile.find("./") == 1 || includedFile.find("../") == 1) {
-            // remove the leading and trailing '"'
-            std::string the_included_file = includedFile;
-            Str::removeQuotes(the_included_file);
-
-            // Get the root path, i.e. script_or_job_path() is of the form:
-            //    "/user/home/ma/mao/course/t1.ecf || /user/home/ma/mao/course/t1.job"
-            // we need "/user/home/ma/mao/course/"
-            std::string the_script_or_job_path = ecfile_->script_or_job_path();
-            std::string::size_type last_slash  = the_script_or_job_path.rfind("/");
-            if (last_slash != std::string::npos) {
-                path = the_script_or_job_path.substr(0, last_slash + 1);
-                path += the_included_file;
-                // std::cout << "path == " << path << "\n";
-                return path;
-            }
-        }
-
-        // include contents of %ECF_HOME%/%SUITE%/%FAMILY%/filename
-        node->findParentUserVariableValue(Str::ECF_HOME(), path);
-        if (path.empty()) {
-            std::stringstream ss;
-            ss << "ECF_HOME not specified, at : " << line;
-            throw std::runtime_error(error_context() + ss.str());
-        }
-        path += '/';
-        std::string suite;
-        node->findParentVariableValue("SUITE", suite); // SUITE is a generated variable
-        if (suite.empty()) {
-            std::stringstream ss;
-            ss << "SUITE not specified, at : " << line;
-            throw std::runtime_error(error_context() + ss.str());
-        }
-        path += suite;
-        path += '/';
-        std::string family;
-        node->findParentVariableValue("FAMILY", family); // FAMILY is a generated variable
-        if (family.empty()) {
-            std::stringstream ss;
-            ss << "FAMILY not specified, at : " << line;
-            throw std::runtime_error(error_context() + ss.str());
-        }
-        path += family;
-        path += '/';
-        path += the_include_file; // "filename"
-        return path;
-    }
-
-    // File either has an absolute pathname or is in the current working dir.
-    // include file name as is, from current working directory
-    return includedFile;
-}
-
-std::string PreProcessor::error_context() const {
-    std::string ret(error_context_);
-    ret += ": Failed preprocessing : ";
-    ret += ecfile_->node_->debugNodePath();
-    ret += " : path/cmd(";
-    ret += ecfile_->script_path_or_cmd_;
-    ret += ")\n: ";
-    return ret;
-}
-
-bool EcfFile::file_exists(const std::string& ecf_include) const {
-    //   return fs::exists(ecf_include);
-    size_t file_stat_cache_size = file_stat_cache_.size();
-    for (size_t i = 0; i < file_stat_cache_size; i++) {
-        if (file_stat_cache_[i].first == ecf_include) {
-            // cout << "EcfFile::file_exists " << ecf_include << " found in cache " << file_stat_cache_[i].second <<
-            // "\n";
-            return file_stat_cache_[i].second;
-        }
-    }
-    if (fs::exists(ecf_include)) {
-        // cout << "EcfFile::file_exists " << ecf_include << " exists add to cache\n";
-        file_stat_cache_.emplace_back(ecf_include, true);
-        return true;
-    }
-    // cout << "EcfFile::file_exists " << ecf_include << " does NOT exist add to cache\n";
-    file_stat_cache_.emplace_back(ecf_include, false);
-    return false;
-}
-
-// **********************************************************************************
-
-IncludeFileCache::IncludeFileCache(const std::string& path)
-    : path_(path),
-      fp_(path.c_str(), std::ios_base::in),
-      no_of_lines_(0) {
-}
-
-IncludeFileCache::~IncludeFileCache() {
-    fp_.close();
-}
-
-bool IncludeFileCache::lines(std::vector<std::string>& lns) {
-    if (!fp_)
-        return false;
-
-    if (no_of_lines_ != 0) {
-        lns.reserve(no_of_lines_);
-        fp_.seekg(0); // Using cache, reset pos back to 0
-    }
-
-    // Note if we use: while( getline( theEcfFile, line)), then we will miss the *last* *empty* line
-    string line;
-    while (std::getline(fp_, line)) {
-        lns.push_back(line);
-    }                          // c++11
-    fp_.clear();               // eol fp_ will be in bad state reset. So we can re-use
-    no_of_lines_ = lns.size(); // cache for next time
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/EcfFile.hpp 5.13.0-1/ANode/src/ecflow/node/EcfFile.hpp
--- 5.12.4-1/ANode/src/ecflow/node/EcfFile.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/EcfFile.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,234 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_EcfFile_HPP
-#define ecflow_node_EcfFile_HPP
-
-#include <fstream>
-#include <memory>
-
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-// This class is used to minimise file I/0.
-// When job processing the same include file can be opened and closed many time
-// This cache serves to open the include file only once. It halves the job processing time.
-class IncludeFileCache {
-public:
-    explicit IncludeFileCache(const std::string& path);
-    // Disable copy (and move) semantics
-    IncludeFileCache(const IncludeFileCache&)                  = delete;
-    const IncludeFileCache& operator=(const IncludeFileCache&) = delete;
-
-    ~IncludeFileCache();
-
-    const std::string& path() const { return path_; }
-    bool lines(std::vector<std::string>&);
-
-private:
-    std::string path_;
-    std::ifstream fp_; // is not copy constructable
-    size_t no_of_lines_;
-};
-
-/// This class is used in the pre-processing of files( .ecf or .usr or .man typically)
-/// It is used to to create the job file.
-///
-///
-/// Please note the %manual is only created on request from the file cmd.
-/// Even then it is extracted as a string. i.e. no .man file is
-/// created. This is left to the client.
-/// When returning the manual we pre-process the files first
-///
-/// However for testing purpose this capability may be retained.
-
-class EcfFile {
-public:
-    enum Origin {
-        ECF_SCRIPT,    // Look for .ecf file, uses default algorithm to find %includes
-        ECF_HOME,      // default directory for scripts
-        ECF_FILES,     // User specified directory
-        ECF_FETCH_CMD, // pre-process output of ECF_FETCH,     all %includes use same command
-        ECF_SCRIPT_CMD // pre-process output of ECF_SCRIPT_CMD, uses default algorithm to find %includes
-    };
-
-    // Use to record how the ecf_file was located from ECF_FILES and ECF_HOME directories. Default is PRUNE_ROOT
-    enum EcfFileSearchAlgorithm { PRUNE_ROOT, PRUNE_LEAF };
-
-    EcfFile();
-
-    /// This preserves the caches, used to avoid opening/stat of include file more than once.
-    EcfFile& operator=(const EcfFile& rhs);
-
-    /// use default copy constructor, assignment, destructor
-    /// ECF_FETCH  is used obtain the script from running a command  i.e.
-    /// from the version control system.
-    EcfFile(Node*,
-            const std::string& path_to_script_or_fetch_cmd,
-            EcfFile::Origin                 = ECF_SCRIPT,
-            EcfFile::EcfFileSearchAlgorithm = PRUNE_ROOT);
-
-    // The path to the ecf file, empty path means that ecf file could not be located
-    bool valid() const { return !script_path_or_cmd_.empty(); }
-
-    /// This function will return the contents of %manual -> %end for the input file
-    /// It will pre-process the file, then extract the manual form all the pre-processed files
-    /// Will throw std::runtime_error for errors
-    void manual(std::string& theManual);
-
-    /// returns the script, The first line contains the origin of the file/cmd.
-    /// Will throw std::runtime_error for errors
-    void script(std::string& theScript) const;
-
-    const std::string& script_path_or_cmd() const { return script_path_or_cmd_; }
-
-    /// What is the origin of this ecf_file
-    std::string ecf_file_origin_dump() const;
-
-    /// simple accessors
-    Origin ecf_file_origin() const { return script_origin_; }
-    EcfFileSearchAlgorithm ecf_file_search_algorithm() const { return ecf_file_search_algorithm_; }
-    static std::string origin_str(Origin);
-    static std::string search_algorithm_str(EcfFileSearchAlgorithm);
-
-    /// Create the job file from with script of a task or alias.
-    /// Note: the location of the ecf file may not be the same as the job file
-    ///       For creating the job we must use ECF_JOB
-    ///
-    /// _IF_ ECF_CLIENT is specified provide Special support for migration. TEST ONLY
-    /// The variable ECF_CLIENT is used to specify the path to client exe.
-    /// This is then used to replace smsinit,smscomplete, smsevent,smsmeter.smslabel,smsabort
-    /// This function will start the pre processing
-    /// Will throw std::runtime_error for errors
-    const std::string& create_job(JobsParam&);
-
-    /// Process the script file, to add all the used variables, add the start of the file
-    /// between %comment %end, The augmented script is returned in file_with_used_variables
-    /// Will throw std::runtime_error for errors
-    void edit_used_variables(std::string& file_with_used_variables);
-
-    /// Pre-processing involves include expansion and variable substitution
-    /// Will throw std::runtime_error if pre processing fails
-    void pre_process(std::string& pre_processed_file);
-
-    /// Does full pre-processing:
-    ///   - include pre-processing
-    ///   - variable substitution
-    ///   - remove comment and manual sections
-    ///   - ignore %nopp
-    void pre_process_user_file(std::vector<std::string>& user_edit_file, std::string& pre_processed_file);
-
-    /// Searches for the first %comment, then extracts all variables of the form
-    ///   <name>  =  <value>
-    /// and places into map
-    static void extract_used_variables(NameValueMap& used_variables_as_map,
-                                       const std::vector<std::string>& script_lines);
-
-    static std::vector<std::string> get_ecf_include_paths(const EcfFile& ecf);
-
-private:
-    friend class PreProcessor;
-    enum Type { SCRIPT, INCLUDE, MANUAL, COMMENT };
-    static std::string fileType(EcfFile::Type);
-
-    bool open_script_file(const std::string& file,
-                          EcfFile::Type,
-                          std::vector<std::string>& lines,
-                          std::string& errormsg) const;
-    bool open_include_file(const std::string& file, std::vector<std::string>& lines, std::string& errormsg) const;
-
-    bool replaceSmsChildCmdsWithEcf(const std::string& clientPath, std::string& errormsg);
-    void variableSubstitution(const JobsParam&);
-    const std::string& doCreateJobFile(JobsParam&) const;
-    bool doCreateManFile(std::string& errormsg);
-    bool extractManual(const std::vector<std::string>& lines,
-                       std::vector<std::string>& theManualLines,
-                       std::string& errormsg) const;
-
-    void remove_comment_manual_and_nopp_tokens();
-
-    static int countEcfMicro(const std::string& line, const std::string& ecfMicro);
-    static void dump_expanded_script_file(const std::vector<std::string>& lines); // for DEBUG
-
-    /// returns the extension, i.e for task->.ecf for alias->.usr, will throw if node_ is not task or alias
-    const std::string& get_extn() const;
-
-    bool
-    do_popen(const std::string& the_cmd, EcfFile::Type, std::vector<std::string>& lines, std::string& errormsg) const;
-
-    fs::path file_creation_path() const;
-    std::string script_or_job_path() const;
-
-    bool extract_ecfmicro(const std::string& line, std::string& ecfmicro, std::string& error_msg) const;
-
-    /// User edit functions:
-    void get_used_variables(std::string& used_variables) const;
-    bool get_used_variables(NameValueMap& used_variables, std::string& errorMsg) const;
-    void doCreateUsrFile() const;
-    bool file_exists(const std::string& file_path) const;
-
-    Node* node_{nullptr};               // Task or Alias or Container when pre-processing the man files
-    std::string ecfMicroCache_;         // cache value of ECF_MICRO
-    std::string script_path_or_cmd_;    // path to .ecf, .usr file or command
-    std::vector<std::string> jobLines_; // Lines that will form the job file.
-
-    mutable std::vector<std::shared_ptr<IncludeFileCache>> include_file_cache_; // only open include file once
-    mutable std::vector<std::pair<std::string, bool>> file_stat_cache_;         // Minimise calls to stat/kernel calls
-    mutable std::string job_size_;                       // to be placed in log file during job submission
-    EcfFile::Origin script_origin_{EcfFile::ECF_SCRIPT}; // get script from a file, or from running a command
-    EcfFile::EcfFileSearchAlgorithm ecf_file_search_algorithm_{
-        EcfFile::PRUNE_ROOT}; // only used for ECF_FILES and ECF_HOME
-};
-
-// This class is used in expanding(pre-processing) the includes.
-// The pre-processing is done in a depth first fashion (ECFLOW-673)
-class PreProcessor {
-public:
-    explicit PreProcessor(EcfFile*, const char* error_context);
-    // Disable copy (and move) semantics
-    PreProcessor(const PreProcessor&)                  = delete;
-    const PreProcessor& operator=(const PreProcessor&) = delete;
-
-    ~PreProcessor();
-
-    void preProcess(std::vector<std::string>& script_lines);
-
-private:
-    std::string error_context() const;
-
-    // include pre-processing on the included file.
-    // Note: include directives _in_ manual/comment should he handled.
-    //       only include directives in %nopp/%end are ignored
-    void preProcess_line();
-    void preProcess_includes();
-    std::string getIncludedFilePath(const std::string& include, const std::string& line);
-
-private:
-    EcfFile* ecfile_;
-    const char* error_context_;
-
-    std::string pp_nopp_;
-    std::string pp_comment_;
-    std::string pp_manual_;
-    std::string pp_end_;
-    std::string ecf_micro_; // constant until ecfmicro changes, then reset
-
-    std::vector<std::string>& jobLines_;
-
-    std::vector<std::pair<std::string, int>>
-        globalIncludedFileSet_; // test for recursive includes, <no _of times it was included>
-    std::vector<std::string> include_once_set_;
-
-    bool nopp_{false};
-    bool comment_{false};
-    bool manual_{false};
-};
-
-#endif /* ecflow_node_EcfFile_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprAst.cpp 5.13.0-1/ANode/src/ecflow/node/ExprAst.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprAst.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprAst.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,2045 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/ExprAst.hpp"
-
-#include <iostream>
-
-#include "ecflow/core/Cal.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAstVisitor.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-////////////////////////////////////////////////////////////////////////////////////
-
-Ast::~Ast() = default;
-
-// #define DEBUG_WHY 1
-
-bool Ast::why(std::string& theReasonWhy, bool html) const {
-    if (evaluate()) {
-#ifdef DEBUG_WHY
-        std::cout << "   Ast::why evaluates returning\n";
-#endif
-        return false;
-    }
-
-    theReasonWhy = "expression ";
-    theReasonWhy += why_expression(html); // provide additional state
-    theReasonWhy += " is false";
-#ifdef DEBUG_WHY
-    std::cout << "    Ast::why  reason = " << theReasonWhy << "\n";
-#endif
-    return true;
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-AstTop::~AstTop() {
-    delete root_;
-}
-
-void AstTop::accept(ExprAstVisitor& v) {
-    v.visitTop(this);
-    root_->accept(v);
-}
-
-AstTop* AstTop::clone() const {
-    auto* top = new AstTop();
-    top->addChild(root_->clone());
-    return top;
-}
-
-bool AstTop::evaluate() const {
-    if (root_) {
-        return root_->evaluate();
-    }
-
-    LOG_ASSERT(false, "AstTop::evaluate(): assert failed, AST top has no root/children");
-    return false;
-}
-
-bool AstTop::check(std::string& error_msg) const {
-    if (root_) {
-        return root_->check(error_msg);
-    }
-    return true;
-}
-
-std::ostream& AstTop::print(std::ostream& os) const {
-    Indentor in;
-    Indentor::indent(os) << "# Trigger Evaluation Tree\n";
-    if (root_) {
-        Indentor in2;
-        return root_->print(os);
-    }
-    return os;
-}
-
-void AstTop::print_flat(std::ostream& os, bool add_bracket) const {
-    if (root_) {
-        root_->print_flat(os, add_bracket);
-    }
-}
-
-bool AstTop::is_valid_ast(std::string& error_msg) const {
-    if (root_) {
-        return root_->is_valid_ast(error_msg);
-    }
-    error_msg = "AstTop: Abstract syntax tree creation failed";
-    return false;
-}
-
-bool AstTop::why(std::string& theReasonWhy, bool html) const {
-    if (evaluate()) {
-#ifdef DEBUG_WHY
-        std::cout << "   AstTop::why evaluates returning\n";
-#endif
-        return false;
-    }
-    return root_->why(theReasonWhy, html);
-}
-
-std::string AstTop::expression() const {
-    std::string ret = exprType_;
-    if (root_) {
-        ret += " ";
-        ret += root_->expression();
-    }
-    return ret;
-}
-
-std::string AstTop::why_expression(bool html) const {
-    std::string ret = exprType_;
-    if (root_) {
-        ret += " ";
-        ret += root_->why_expression(html);
-    }
-    return ret;
-}
-
-void AstTop::setParentNode(Node* p) {
-    if (root_)
-        root_->setParentNode(p);
-}
-
-void AstTop::invalidate_trigger_references() const {
-    if (root_)
-        root_->invalidate_trigger_references();
-}
-
-//////////////////////////////////////////////////////////////////////////////////////
-
-AstRoot::~AstRoot() {
-    delete left_;
-    delete right_;
-    left_  = nullptr;
-    right_ = nullptr;
-}
-
-void AstRoot::accept(ExprAstVisitor& v) {
-    v.visitRoot(this);
-    left_->accept(v);
-    if (right_)
-        right_->accept(v); // right_ is empty for Not
-}
-
-bool AstRoot::check(std::string& error_msg) const {
-    if (left_ && !left_->check(error_msg))
-        return false;
-    if (right_ && !right_->check(error_msg))
-        return false;
-    return true;
-}
-
-void AstRoot::addChild(Ast* n) {
-    LOG_ASSERT(n, "");
-
-    if (!left_) {
-        left_ = n;
-        return;
-    }
-    if (!right_) {
-        right_ = n;
-        return;
-    }
-
-    LOG_ASSERT(false, "AstRoot::addChild: assert failed: root already has left and right children\n");
-}
-
-std::ostream& AstRoot::print(std::ostream& os) const {
-    // left_ should not be NULL, but keep clang static analyser happy
-    if (left_) {
-        if (left_->isRoot()) {
-            Indentor in;
-            left_->print(os);
-        }
-        else
-            left_->print(os);
-    }
-
-    if (right_) { // right_ is empty for Not
-        if (right_->isRoot()) {
-            Indentor in;
-            right_->print(os);
-        }
-        else
-            right_->print(os);
-        ;
-    }
-    return os;
-}
-
-std::string AstRoot::do_why_expression(const std::string& root, bool html) const {
-    std::string ret;
-    if (left_)
-        ret += left_->why_expression(html);
-    ret += root;
-    if (right_)
-        ret += right_->why_expression(html);
-    return ret;
-}
-
-std::string AstRoot::do_bracket_why_expression(const std::string& root, bool html) const {
-    std::string ret = "(";
-    ret += do_why_expression(root, html);
-    ret += ")";
-    return ret;
-}
-
-std::string AstRoot::do_false_bracket_why_expression(const std::string& root, bool html) const {
-    std::string ret;
-    if (html)
-        ret += "<false>"; // still need guard with html for ecflowview ?
-    ret += do_bracket_why_expression(root, html);
-    if (html)
-        ret += "</false>";
-    return ret;
-}
-
-std::string AstRoot::do_expression(const std::string& root) const {
-    std::string ret;
-    if (left_)
-        ret += left_->expression();
-    ret += root;
-    if (right_)
-        ret += right_->expression();
-    return ret;
-}
-
-std::string AstRoot::do_bracket_expression(const std::string& root) const {
-    std::string ret = "(";
-    ret += do_expression(root);
-    ret += ")";
-    return ret;
-}
-
-void AstRoot::setParentNode(Node* p) {
-    if (left_)
-        left_->setParentNode(p);
-    if (right_)
-        right_->setParentNode(p);
-}
-
-void AstRoot::invalidate_trigger_references() const {
-    if (left_)
-        left_->invalidate_trigger_references();
-    if (right_)
-        right_->invalidate_trigger_references();
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstNot::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitNot(this);
-}
-
-AstNot* AstNot::clone() const {
-    auto* ast = new AstNot();
-    if (left_)
-        ast->addChild(left_->clone());
-    return ast;
-}
-
-std::ostream& AstNot::print(std::ostream& os) const {
-    Indentor::indent(os) << "# NOT (" << evaluate_str() << ")";
-    if (right_)
-        os << " # ERROR has right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstNot::is_valid_ast(std::string& error_msg) const {
-    if (right_) {
-        error_msg = "AstNot: should only have a single root";
-        return false;
-    }
-    if (!left_) {
-        error_msg = "AstNot: Does not have root";
-        return false;
-    }
-    return left_->is_valid_ast(error_msg);
-}
-
-void AstNot::print_flat(std::ostream& os, bool add_bracket) const {
-    os << name_;
-    if (left_) {
-        if (add_bracket)
-            os << "(";
-        left_->print_flat(os, add_bracket);
-        if (add_bracket)
-            os << ")";
-    }
-}
-
-std::string AstNot::expression() const {
-    std::string ret = "NOT ";
-    ret += left_->expression();
-    return ret;
-}
-
-std::string AstNot::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-
-    std::string ret;
-    if (html)
-        ret += "<false>";
-    ret += "not ";
-    ret += left_->why_expression(html);
-    if (html)
-        ret += "</false>";
-    return ret;
-}
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstPlus::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitPlus(this);
-}
-
-AstPlus* AstPlus::clone() const {
-    auto* ast = new AstPlus();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstPlus::print(std::ostream& os) const {
-    Indentor::indent(os) << "# PLUS value(" << value() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstPlus::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstPlus: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstPlus: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstPlus::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " + ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstPlus::expression() const {
-    return do_expression(" + ");
-}
-
-std::string AstPlus::why_expression(bool html) const {
-    return do_why_expression(" + ", html);
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstMinus::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitMinus(this);
-}
-
-AstMinus* AstMinus::clone() const {
-    auto* ast = new AstMinus();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstMinus::print(std::ostream& os) const {
-    Indentor::indent(os) << "# MINUS value(" << value() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstMinus::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstMinus: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstMinus: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstMinus::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " - ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstMinus::expression() const {
-    return do_expression(" - ");
-}
-
-std::string AstMinus::why_expression(bool html) const {
-    return do_why_expression(" - ", html);
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstDivide::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitDivide(this);
-}
-
-AstDivide* AstDivide::clone() const {
-    auto* ast = new AstDivide();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-bool AstDivide::check(std::string& error_msg) const {
-    if (right_ && right_->value() == 0) {
-        error_msg += " Error: Divide by zero in trigger expression";
-        return false;
-    }
-    return true;
-}
-
-int AstDivide::value() const {
-    if (right_->value() == 0) {
-        log(Log::ERR, "Divide by zero in trigger/complete expression");
-        return 0;
-    }
-    return (left_->value() / right_->value());
-}
-
-std::ostream& AstDivide::print(std::ostream& os) const {
-    Indentor::indent(os) << "# DIVIDE value(" << value() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstDivide::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstDivide: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstDivide: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstDivide::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " / ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstDivide::expression() const {
-    return do_expression(" / ");
-}
-
-std::string AstDivide::why_expression(bool html) const {
-    return do_why_expression(" / ", html);
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstMultiply::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitMultiply(this);
-}
-
-AstMultiply* AstMultiply::clone() const {
-    auto* ast = new AstMultiply();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstMultiply::print(std::ostream& os) const {
-    Indentor::indent(os) << "# MULTIPLY value(" << value() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstMultiply::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstMultiply: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstMultiply: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstMultiply::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " * ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstMultiply::expression() const {
-    return do_expression(" * ");
-}
-
-std::string AstMultiply::why_expression(bool html) const {
-    return do_why_expression(" * ", html);
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstModulo::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitModulo(this);
-}
-
-AstModulo* AstModulo::clone() const {
-    auto* ast = new AstModulo();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-bool AstModulo::check(std::string& error_msg) const {
-    if (right_ && right_->value() == 0) {
-        error_msg += " Error: Modulo by zero in trigger expression";
-        return false;
-    }
-    return true;
-}
-
-int AstModulo::value() const {
-    if (right_->value() == 0) {
-        log(Log::ERR, "Modulo by zero in trigger/complete expression");
-        return 0;
-    }
-    return (left_->value() % right_->value());
-}
-
-std::ostream& AstModulo::print(std::ostream& os) const {
-    Indentor::indent(os) << "# Modulo value(" << value() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstModulo::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstModulo: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstModulo: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstModulo::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " % ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstModulo::expression() const {
-    return do_expression(" % ");
-}
-
-std::string AstModulo::why_expression(bool html) const {
-    return do_why_expression(" % ", html);
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstAnd::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitAnd(this);
-}
-
-AstAnd* AstAnd::clone() const {
-    auto* ast = new AstAnd();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstAnd::print(std::ostream& os) const {
-    Indentor::indent(os) << "# AND (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstAnd::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstAnd: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstAnd: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstAnd::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " and ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstAnd::expression() const {
-    return do_bracket_expression(" AND ");
-}
-
-std::string AstAnd::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    return do_false_bracket_why_expression(" and ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstOr::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitOr(this);
-}
-
-AstOr* AstOr::clone() const {
-    auto* ast = new AstOr();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstOr::print(std::ostream& os) const {
-    Indentor::indent(os) << "# OR (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstOr::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstOr: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstOr: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstOr::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " or ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstOr::expression() const {
-    return do_bracket_expression(" OR ");
-}
-
-std::string AstOr::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    return do_false_bracket_why_expression(" or ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstEqual::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitEqual(this);
-}
-
-AstEqual* AstEqual::clone() const {
-    auto* ast = new AstEqual();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstEqual::print(std::ostream& os) const {
-    Indentor::indent(os) << "# EQUAL (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstEqual::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstEqual: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstEqual: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstEqual::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " == ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstEqual::expression() const {
-    return do_bracket_expression(" == ");
-}
-
-std::string AstEqual::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    return do_false_bracket_why_expression(" == ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstNotEqual::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitNotEqual(this);
-}
-AstNotEqual* AstNotEqual::clone() const {
-    auto* ast = new AstNotEqual();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstNotEqual::print(std::ostream& os) const {
-    Indentor::indent(os) << "# NOT_EQUAL (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstNotEqual::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstNotEqual: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstNotEqual: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstNotEqual::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " != ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstNotEqual::expression() const {
-    return do_bracket_expression(" != ");
-}
-
-std::string AstNotEqual::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    return do_false_bracket_why_expression(" != ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstLessEqual::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitLessEqual(this);
-}
-AstLessEqual* AstLessEqual::clone() const {
-    auto* ast = new AstLessEqual();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstLessEqual::print(std::ostream& os) const {
-    Indentor::indent(os) << "# LESS_EQUAL (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstLessEqual::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstLessEqual: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstLessEqual: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstLessEqual::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " <= ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstLessEqual::expression() const {
-    return do_bracket_expression(" <= ");
-}
-
-std::string AstLessEqual::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    return do_false_bracket_why_expression(" <= ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstGreaterEqual::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitGreaterEqual(this);
-}
-AstGreaterEqual* AstGreaterEqual::clone() const {
-    auto* ast = new AstGreaterEqual();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstGreaterEqual::print(std::ostream& os) const {
-    Indentor::indent(os) << "# GREATER_EQUAL (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstGreaterEqual::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstGreaterEqual: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstGreaterEqual: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstGreaterEqual::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " >= ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstGreaterEqual::expression() const {
-    return do_bracket_expression(" >= ");
-}
-
-std::string AstGreaterEqual::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    return do_false_bracket_why_expression(" >= ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstGreaterThan::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitGreaterThan(this);
-}
-AstGreaterThan* AstGreaterThan::clone() const {
-    auto* ast = new AstGreaterThan();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstGreaterThan::print(std::ostream& os) const {
-    Indentor::indent(os) << "# GREATER_THAN (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstGreaterThan::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstGreaterThan: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstGreaterThan: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstGreaterThan::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " > ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstGreaterThan::expression() const {
-    return do_bracket_expression(" > ");
-}
-
-std::string AstGreaterThan::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    return do_false_bracket_why_expression(" > ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstLessThan::accept(ExprAstVisitor& v) {
-    AstRoot::accept(v);
-    v.visitLessThan(this);
-}
-
-AstLessThan* AstLessThan::clone() const {
-    auto* ast = new AstLessThan();
-    if (left_)
-        ast->addChild(left_->clone());
-    if (right_)
-        ast->addChild(right_->clone());
-    return ast;
-}
-
-std::ostream& AstLessThan::print(std::ostream& os) const {
-    Indentor::indent(os) << "# LESS_THAN (" << evaluate_str() << ")";
-    if (!left_)
-        os << " # ERROR has no left_";
-    if (!right_)
-        os << " # ERROR has no right_";
-    os << "\n";
-    return AstRoot::print(os);
-}
-
-bool AstLessThan::is_valid_ast(std::string& error_msg) const {
-    if (!left_) {
-        error_msg = "AstLessThan: has no left part";
-        return false;
-    }
-    if (!right_) {
-        error_msg = "AstLessThan: has no right part";
-        return false;
-    }
-    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
-        return true;
-    }
-    return false;
-}
-
-void AstLessThan::print_flat(std::ostream& os, bool add_bracket) const {
-    if (add_bracket)
-        os << "(";
-    if (left_)
-        left_->print_flat(os, add_bracket);
-    os << " < ";
-    if (right_)
-        right_->print_flat(os, add_bracket);
-    if (add_bracket)
-        os << ")";
-}
-
-std::string AstLessThan::expression() const {
-    return do_bracket_expression(" < ");
-}
-
-std::string AstLessThan::why_expression(bool html) const {
-    if (evaluate())
-        return "true";
-    // Using ' < ' seems to mess up html
-    return do_false_bracket_why_expression(" lt ", html); // false - allows GUI to colour the false expression part
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstLeaf::accept(ExprAstVisitor& v) {
-    v.visitLeaf(this);
-}
-
-///////////////////////////////////////////////////////////////////////////////////
-
-void AstFunction::accept(ecf::ExprAstVisitor& v) {
-    v.visitFunction(this); // Not calling base
-}
-
-AstFunction* AstFunction::clone() const {
-    return new AstFunction(ft_, arg()->clone());
-}
-
-static int digits_in_integer(int number) {
-    int digits = 0;
-    if (number < 0)
-        digits = 1; // remove this line if '-' counts as a digit
-    while (number) {
-        number /= 10;
-        digits++;
-    }
-    return digits;
-}
-
-int AstFunction::value() const {
-    int arg_eval = arg_->value();
-
-    switch (ft_) {
-        case AstFunction::DATE_TO_JULIAN: {
-            // cope with 8 digit, yyyymmdd and 10 digit yyyymmddhh
-            int integer_digits = digits_in_integer(arg_eval);
-            if (integer_digits == 10)
-                arg_eval = arg_eval / 100;
-            else if (integer_digits != 8)
-                return 0;
-            return Cal::date_to_julian(arg_eval);
-        }
-        case AstFunction::JULIAN_TO_DATE:
-            return Cal::julian_to_date(arg_eval);
-        default:
-            assert(false);
-    }
-    return 0;
-}
-
-std::ostream& AstFunction::print(std::ostream& os) const {
-    Indentor in;
-    switch (ft_) {
-        case AstFunction::DATE_TO_JULIAN:
-            return Indentor::indent(os) << "# DATE_TO_JULIAN " << value() << "\n";
-        case AstFunction::JULIAN_TO_DATE:
-            return Indentor::indent(os) << "# JULIAN_TO_DATE " << value() << "\n";
-        default:
-            assert(false);
-    }
-    return os;
-}
-
-void AstFunction::print_flat(std::ostream& os, bool add_brackets) const {
-    switch (ft_) {
-        case AstFunction::DATE_TO_JULIAN:
-            os << "date_to_julian(arg:" << arg_->value() << ") = " << value();
-            break;
-        case AstFunction::JULIAN_TO_DATE:
-            os << "julian_to_date(arg:" << arg_->value() << ") = " << value();
-            break;
-        default:
-            assert(false);
-    }
-}
-
-std::string AstFunction::expression() const {
-    std::stringstream ss;
-    switch (ft_) {
-        case AstFunction::DATE_TO_JULIAN:
-            ss << "date_to_julian( arg:" << arg_->expression() << ") = " << value();
-            break;
-        case AstFunction::JULIAN_TO_DATE:
-            ss << "julian_to_date( arg:" << arg_->expression() << ") = " << value();
-            break;
-        default:
-            assert(false);
-    }
-    return ss.str();
-}
-
-std::string AstFunction::why_expression(bool html) const {
-    std::stringstream ss;
-    switch (ft_) {
-        case AstFunction::DATE_TO_JULIAN:
-            ss << "date_to_julian( arg:" << arg_->why_expression(html) << ") = " << value();
-            break;
-        case AstFunction::JULIAN_TO_DATE:
-            ss << "julian_to_date( arg:" << arg_->why_expression(html) << ") = " << value();
-            break;
-        default:
-            assert(false);
-    }
-    return ss.str();
-}
-
-void AstFunction::setParentNode(Node* n) {
-    if (arg_)
-        arg_->setParentNode(n);
-}
-
-///////////////////////////////////////////////////////////////////////////////////
-void AstInteger::accept(ExprAstVisitor& v) {
-    v.visitInteger(this); // Not calling base
-}
-
-AstInteger* AstInteger::clone() const {
-    auto* ast = new AstInteger(value_);
-    return ast;
-}
-
-std::ostream& AstInteger::print(std::ostream& os) const {
-    Indentor in;
-    return Indentor::indent(os) << "# INTEGER " << value() << "\n";
-}
-
-void AstInteger::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    os << value_;
-}
-
-std::string AstInteger::expression() const {
-    std::stringstream ss;
-    ss << value();
-    return ss.str();
-}
-
-std::string AstInteger::why_expression(bool /*html*/) const {
-    return expression();
-}
-
-///////////////////////////////////////////////////////////////////////////////////
-
-void AstInstant::accept(ExprAstVisitor& v) {
-    v.visitInstant(this); // Not calling base
-}
-
-AstInstant* AstInstant::clone() const {
-    auto* ast = new AstInstant(value_);
-    return ast;
-}
-
-std::ostream& AstInstant::print(std::ostream& os) const {
-    Indentor in;
-    return Indentor::indent(os) << "# Instant " << value_ << "\n";
-}
-
-void AstInstant::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    os << value_;
-}
-
-std::string AstInstant::expression() const {
-    std::stringstream ss;
-    ss << value_;
-    return ss.str();
-}
-
-std::string AstInstant::why_expression(bool /*html*/) const {
-    return expression();
-}
-
-//////////////////////////////////////////////////////////////////////////////////
-
-void AstNodeState::accept(ExprAstVisitor& v) {
-    v.visitNodeState(this); // Not calling base
-}
-
-AstNodeState* AstNodeState::clone() const {
-    return new AstNodeState(state_);
-}
-
-std::ostream& AstNodeState::print(std::ostream& os) const {
-    Indentor in;
-    return Indentor::indent(os) << "# NODE_STATE " << DState::toString(state_) << "(" << value() << ")\n";
-}
-
-void AstNodeState::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    os << DState::toString(state_);
-}
-
-std::string AstNodeState::expression() const {
-    return DState::toString(state_);
-}
-
-std::string AstNodeState::why_expression(bool html) const {
-    if (html)
-        return DState::to_html(state_);
-    return DState::toString(state_);
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstEventState::accept(ExprAstVisitor& v) {
-    v.visitEventState(this); // Not calling base
-}
-
-AstEventState* AstEventState::clone() const {
-    return new AstEventState(state_);
-}
-
-std::ostream& AstEventState::print(std::ostream& os) const {
-    Indentor in;
-    return Indentor::indent(os) << "# EVENT_STATE " << state_ << "\n";
-}
-
-void AstEventState::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    if (state_)
-        os << Event::SET();
-    else
-        os << Event::CLEAR();
-}
-
-std::string AstEventState::expression() const {
-    if (state_)
-        return Event::SET();
-    return Event::CLEAR();
-}
-
-std::string AstEventState::why_expression(bool /*html*/) const {
-    return expression();
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstNode::accept(ExprAstVisitor& v) {
-    v.visitNode(this); // Not calling base
-}
-
-AstNode* AstNode::clone() const {
-    return new AstNode(nodePath_);
-}
-
-DState::State AstNode::state() const {
-    // This function is called hundreds of millions of times
-    Node* refNode = referencedNode(); // call once, could be expensive
-    if (refNode)
-        return refNode->dstate();
-    return DState::UNKNOWN;
-}
-
-Node* AstNode::referencedNode() const {
-    // This function is called hundreds of millions of times
-    // One of the server CPU **bottleneck's** is weak ptr locking
-    // Note: gprof does not report on in-lined functions ?
-    Node* ref = get_ref_node();
-    if (ref) {
-        return ref;
-    }
-    if (parentNode_) {
-        std::string errorMsg;
-        ref_node_ = parentNode_->findReferencedNode(nodePath_, errorMsg);
-        return get_ref_node(); // can be NULL
-    }
-    return nullptr;
-}
-
-Node* AstNode::referencedNode(std::string& errorMsg) const {
-    Node* ref = get_ref_node();
-    if (ref) {
-        return ref;
-    }
-    if (parentNode_) {
-        ref_node_ = parentNode_->findReferencedNode(nodePath_, errorMsg);
-        return get_ref_node(); // can be NULL
-    }
-    return nullptr;
-}
-
-std::ostream& AstNode::print(std::ostream& os) const {
-
-    Node* refNode = referencedNode(); // Only call once
-    Indentor in;
-
-    if (refNode) {
-        Indentor::indent(os) << "# NODE " << nodePath_ << " ";
-        os << DState::toString(refNode->dstate()) << "(" << static_cast<int>(refNode->dstate()) << ")\n";
-    }
-    else {
-        Indentor::indent(os) << "# NODE node(?not-found?) " << nodePath_ << " ";
-        os << DState::toString(DState::UNKNOWN) << "(" << static_cast<int>(DState::UNKNOWN)
-           << ") # check suite filter\n";
-    }
-    return os;
-}
-
-void AstNode::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    os << nodePath_;
-}
-
-std::string AstNode::expression() const {
-    return nodePath_;
-}
-
-std::string AstNode::why_expression(bool html) const {
-    Node* refNode = referencedNode(); // Only call once
-    std::string ret;
-    if (html) {
-        if (refNode)
-            ret = Node::path_href_attribute(refNode->absNodePath(), nodePath_);
-        else
-            ret = Node::path_href_attribute(nodePath_);
-    }
-    else
-        ret = nodePath_;
-
-    if (refNode) {
-        ret += "(";
-        if (html)
-            ret += DState::to_html(refNode->dstate());
-        else
-            ret += DState::toString(refNode->dstate());
-        ret += ")";
-        return ret;
-    }
-    else {
-        ret += "?(";
-        if (html)
-            ret += DState::to_html(DState::UNKNOWN);
-        else
-            ret += DState::toString(DState::UNKNOWN);
-        ret += ")";
-    }
-    return ret;
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-std::string AstFlag::name() const {
-    return ecf::Flag::enum_to_string(flag_);
-}
-
-void AstFlag::accept(ExprAstVisitor& v) {
-    v.visitFlag(this); // Not calling base
-}
-
-AstFlag* AstFlag::clone() const {
-    return new AstFlag(nodePath_, flag_);
-}
-
-int AstFlag::value() const {
-    Node* node = referencedNode();
-    if (node && node->flag().is_set(flag_))
-        return 1;
-    if (parentNode_ && nodePath_ == "/") {
-        Defs* the_defs = parentNode_->defs();
-        if (the_defs && the_defs->flag().is_set(flag_))
-            return 1;
-    }
-    return 0;
-}
-
-Node* AstFlag::referencedNode() const {
-    Node* ref = get_ref_node();
-    if (ref) {
-        return ref;
-    }
-    if (parentNode_) {
-        if (nodePath_ == "/")
-            return nullptr; // reference to defs
-        std::string errorMsg;
-        ref_node_ = parentNode_->findReferencedNode(nodePath_, errorMsg);
-        return get_ref_node(); // can be NULL
-    }
-    return nullptr;
-}
-
-Node* AstFlag::referencedNode(std::string& errorMsg) const {
-    Node* ref = get_ref_node();
-    if (ref) {
-        return ref;
-    }
-    if (parentNode_) {
-        if (nodePath_ == "/")
-            return nullptr; // reference to defs
-        ref_node_ = parentNode_->findReferencedNode(nodePath_, ecf::Flag::enum_to_string(flag_), errorMsg);
-        return get_ref_node(); // can be NULL
-    }
-    return nullptr;
-}
-
-std::ostream& AstFlag::print(std::ostream& os) const {
-
-    Node* refNode = referencedNode(); // Only call once
-    Indentor in;
-
-    if (refNode) {
-        Indentor::indent(os) << "# FLAG_NODE " << nodePath_ << " ";
-        os << ecf::Flag::enum_to_string(flag_) << "(" << static_cast<int>(refNode->flag().is_set(flag_)) << ")\n";
-    }
-    else {
-        Indentor::indent(os) << "# FLAG_NODE node(?not-found?) " << nodePath_ << " ";
-        os << ecf::Flag::enum_to_string(flag_) << "(0) # check suite filter\n";
-    }
-    return os;
-}
-
-void AstFlag::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    os << expression();
-}
-
-std::string AstFlag::expression() const {
-    string ret = nodePath_;
-    ret += "<flag>";
-    ret += ecf::Flag::enum_to_string(flag_);
-    return ret;
-}
-
-std::string AstFlag::why_expression(bool html) const {
-    if (evaluate()) {
-#ifdef DEBUG_WHY
-        cout << " AstFlag::why_expression evaluates returning\n";
-#endif
-        return "true";
-    }
-
-#ifdef DEBUG_WHY
-    cout << " AstFlag::why_expression html " << html << "\n";
-#endif
-
-    Node* ref_node = referencedNode(); // Only call once
-    std::string ret;
-    if (html) {
-        // ecflow_ui expects: [attribute_type]attribute_path:attribute_name(value)
-        // i.e                [limit]/suite/family/task:my_limit(value)
-        // i.e                [flag]/suite/family/task:late(value)
-        std::stringstream display_ss;
-        display_ss << "[flag:" << ecf::Flag::enum_to_string(flag_) << "]" << nodePath_;
-        std::string display_str = display_ss.str();
-
-        std::string ref_str;
-        if (ref_node) {
-            std::stringstream ref_ss;
-            ref_ss << "[flag:" << ecf::Flag::enum_to_string(flag_) << "]" << ref_node->absNodePath();
-            ref_str = ref_ss.str();
-        }
-        else
-            ref_str = display_str;
-
-        ret = Node::path_href_attribute(ref_str, display_str);
-        if (!ref_node)
-            ret += "(?)";
-        else {
-            ret += "(";
-            ret += ecf::convert_to<std::string>(ref_node->flag().is_set(flag_));
-            ret += ")";
-        }
-    }
-    else {
-        ret = nodePath_;
-        if (!ref_node)
-            ret += "(?)";
-        ret += "<flag>";
-        ret += ecf::Flag::enum_to_string(flag_);
-        if (!ref_node)
-            ret += "(?)";
-        else {
-            ret += "(";
-            std::stringstream ss;
-            ss << ref_node->flag().is_set(flag_);
-            ret += ss.str();
-            ret += ")";
-        }
-    }
-    return ret;
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-void AstVariable::accept(ExprAstVisitor& v) {
-    v.visitVariable(this); // Not calling base
-}
-
-AstVariable* AstVariable::clone() const {
-    return new AstVariable(nodePath_, name_);
-}
-
-int AstVariable::value() const {
-    VariableHelper varHelper(this);
-    return varHelper.value();
-}
-
-int AstVariable::minus(Ast* right) const {
-    VariableHelper varHelper(this);
-    return varHelper.minus(right->value());
-}
-
-int AstVariable::plus(Ast* right) const {
-    VariableHelper varHelper(this);
-    return varHelper.plus(right->value());
-}
-
-std::ostream& AstVariable::print(std::ostream& os) const {
-    VariableHelper varHelper(this);
-    return varHelper.print(os);
-}
-
-void AstVariable::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    os << nodePath_ << Str::COLON() << name_;
-}
-
-std::string AstVariable::expression() const {
-    return nodePath_ + Str::COLON() + name_;
-}
-
-std::string AstVariable::why_expression(bool html) const {
-    VariableHelper varHelper(this);
-    std::string ret;
-    std::string varType;
-    int theValue = 0;
-    varHelper.varTypeAndValue(varType, theValue);
-    Node* ref_node = varHelper.theReferenceNode();
-
-    if (html) {
-        // ecflow_ui expects: [attribute_type]attribute_path:attribute_name
-        // i.e                [limit]/suite/family/task:my_limit
-        std::stringstream display_ss;
-        display_ss << "[" << varType << "]" << nodePath_ << ":" << name_;
-        std::string display_str = display_ss.str();
-        std::string ref_str;
-        if (ref_node) {
-            std::stringstream ref_ss;
-            ref_ss << "[" << varType << "]" << ref_node->absNodePath() << ":" << name_;
-            ref_str = ref_ss.str();
-        }
-        else
-            ref_str = display_str;
-
-        ret = Node::path_href_attribute(ref_str, display_str);
-        if (!ref_node)
-            ret += "(?)";
-        ret += "(";
-        ret += ecf::convert_to<std::string>(theValue);
-        ret += ")";
-    }
-    else {
-        ret = nodePath_;
-        if (!ref_node)
-            ret += "(?)";
-        ret += Str::COLON();
-        ret += name_;
-        ret += "(";
-        std::stringstream ss;
-        ss << "type:" << varType << " value:" << theValue;
-        ret += ss.str();
-        ret += ")";
-    }
-    return ret;
-}
-
-Node* AstVariable::referencedNode() const {
-    Node* ref = get_ref_node();
-    if (ref) {
-        return ref;
-    }
-    if (parentNode_) {
-        std::string ignoredErrorMsg;
-        ref_node_ = parentNode_->findReferencedNode(nodePath_, name_, ignoredErrorMsg);
-        return get_ref_node(); // can be NULL
-    }
-    return nullptr;
-}
-
-Node* AstVariable::referencedNode(std::string& errorMsg) const {
-    Node* ref = get_ref_node();
-    if (ref) {
-        return ref;
-    }
-    if (parentNode_) {
-        ref_node_ = parentNode_->findReferencedNode(nodePath_, name_, errorMsg);
-        return get_ref_node(); // can be NULL
-    }
-    return nullptr;
-}
-
-////////////////////////////////////////////////////////////////////////////////////
-
-Node* AstParentVariable::find_node_which_references_variable() const {
-    Node* parent = parentNode_;
-    while (parent) {
-        if (parent->findExprVariable(name_))
-            return parent;
-        parent = parent->parent();
-    }
-    return nullptr;
-}
-
-void AstParentVariable::accept(ExprAstVisitor& v) {
-    v.visitParentVariable(this); // Not calling base
-}
-
-AstParentVariable* AstParentVariable::clone() const {
-    return new AstParentVariable(name_);
-}
-
-int AstParentVariable::value() const {
-    Node* ref_node = find_node_which_references_variable();
-    if (ref_node) {
-        return ref_node->findExprVariableValue(name_);
-    }
-    return 0;
-}
-
-int AstParentVariable::minus(Ast* right) const {
-    Node* ref_node = find_node_which_references_variable();
-    if (ref_node) {
-        return ref_node->findExprVariableValueAndMinus(name_, right->value());
-    }
-    return right->value();
-}
-
-int AstParentVariable::plus(Ast* right) const {
-    Node* ref_node = find_node_which_references_variable();
-    if (ref_node) {
-        return ref_node->findExprVariableValueAndPlus(name_, right->value());
-    }
-    return right->value();
-}
-
-std::ostream& AstParentVariable::print(std::ostream& os) const {
-    Indentor in;
-    Indentor::indent(os) << "# " << Str::COLON() << name_;
-
-    Node* ref_node = find_node_which_references_variable();
-    if (ref_node) {
-        os << " node(" << ref_node->name() << ") ";
-        ref_node->findExprVariableAndPrint(name_, os);
-        os << "\n";
-        return os;
-    }
-    os << " node(?not-found?) value(0)";
-    os << " # check suite filter\n";
-    return os;
-}
-
-void AstParentVariable::print_flat(std::ostream& os, bool /*add_bracket*/) const {
-    os << Str::COLON() << name_;
-}
-
-std::string AstParentVariable::expression() const {
-    return Str::COLON() + name_;
-}
-
-std::string AstParentVariable::why_expression(bool html) const {
-    std::string varType = "variable-not-found";
-    int theValue        = 0;
-    std::string ret;
-    Node* ref_node = find_node_which_references_variable();
-    if (ref_node) {
-        theValue = ref_node->findExprVariableValueAndType(name_, varType);
-    }
-    if (html) {
-        // ecflow_ui expects: [attribute_type]attribute_path:attribute_name
-        // i.e                [limit]/suite/family/task:my_limit
-        std::stringstream display_ss;
-        display_ss << "[" << varType << "]"
-                   << ":" << name_;
-        std::string display_str = display_ss.str();
-        std::string ref_str;
-        if (ref_node) {
-            std::stringstream ref_ss;
-            ref_ss << "[" << varType << "]" << ref_node->absNodePath() << ":" << name_;
-            ref_str = ref_ss.str();
-        }
-        else
-            ref_str = display_str;
-
-        ret = Node::path_href_attribute(ref_str, display_str);
-        if (!ref_node)
-            ret += "(?)";
-        ret += "(";
-        ret += ecf::convert_to<std::string>(theValue);
-        ret += ")";
-    }
-    else {
-        if (!ref_node)
-            ret += "(?)";
-        ret += Str::COLON();
-        ret += name_;
-        ret += "(";
-        std::stringstream ss;
-        ss << "type:" << varType << " value:" << theValue;
-        ret += ss.str();
-        ret += ")";
-    }
-    return ret;
-}
-
-// ===============================================================================
-// class VariableHelper:
-// ===============================================================================
-VariableHelper::VariableHelper(const AstVariable* astVariable) : astVariable_(astVariable), theReferenceNode_(nullptr) {
-    // For *this* constructor we don't care about errors'
-    std::string errorMsg;
-    theReferenceNode_ = astVariable_->referencedNode(errorMsg);
-    if (!theReferenceNode_) {
-        // A node can be NULL  if :
-        // 1/ parentNode is NOT set
-        // 2/ when its a extern path. i.e corresponding suite not loaded yet
-        return;
-    }
-    LOG_ASSERT(errorMsg.empty(), ""); // when a reference node is found, the error msg should be empty
-}
-
-// ***NOTE*** This constructor is called during AST construction***. i.e AstResolveVisitor
-// ********** It is used to report errors and to Flag whether meter or event is used
-// ********** in a trigger expression for the simulator
-VariableHelper::VariableHelper(const AstVariable* astVariable, std::string& errorMsg)
-    : astVariable_(astVariable),
-      theReferenceNode_(nullptr) {
-    // for *this* constructor we want to report errors
-    theReferenceNode_ = astVariable_->referencedNode(errorMsg);
-    if (!theReferenceNode_) {
-        // A node can be NULL  if :
-        // 1/ parentNode is NOT set
-        // 2/ when its a extern path. i.e corresponding suite not loaded yet
-        return;
-    }
-    LOG_ASSERT(errorMsg.empty(), ""); // when a reference node is found, the error msg should be empty
-
-    // Find in order, event, meter, user variable, repeat, generated variable, limit
-    // ALSO: if meter or event mark as used in trigger, for simulator
-    if (theReferenceNode_->findExprVariable(astVariable_->name())) {
-        return;
-    }
-
-    // Check externs if possible
-    Defs* defs = theReferenceNode_->defs();
-    if (defs) {
-        if (defs->find_extern(astVariable_->nodePath(), astVariable_->name())) {
-            return;
-        }
-        if (defs->find_extern(theReferenceNode_->absNodePath(), astVariable_->name())) {
-            return;
-        }
-    }
-
-    std::stringstream ss;
-    ss << "From expression Variable " << astVariable_->nodePath() << Str::COLON() << astVariable_->name();
-    ss << " the referenced node is " << theReferenceNode_->debugNodePath() << "\n";
-    errorMsg += ss.str();
-    errorMsg += "Could not find event, meter, variable, repeat, generated variable, limit or queue of name('";
-    errorMsg += astVariable_->name();
-    errorMsg += "') on node ";
-    errorMsg += theReferenceNode_->debugNodePath();
-    errorMsg += "\n";
-
-    // FAILED to find astVar->name(), for node theReferenceNode on event, meter,
-    // user variable, repeat, generated variable
-    // SET theReferenceNode_ to NULL, since it does nor reference the Expression variable
-    theReferenceNode_ = nullptr;
-}
-
-int VariableHelper::value() const {
-    if (theReferenceNode_) {
-        return theReferenceNode_->findExprVariableValue(astVariable_->name());
-    }
-    return 0;
-}
-
-int VariableHelper::plus(int val) const {
-    if (theReferenceNode_) {
-        return theReferenceNode_->findExprVariableValueAndPlus(astVariable_->name(), val);
-    }
-    return val;
-}
-
-int VariableHelper::minus(int val) const {
-    if (theReferenceNode_) {
-        return theReferenceNode_->findExprVariableValueAndMinus(astVariable_->name(), val);
-    }
-    return -val;
-}
-
-void VariableHelper::varTypeAndValue(std::string& varType, int& theValue) const {
-    if (theReferenceNode_) {
-        theValue = theReferenceNode_->findExprVariableValueAndType(astVariable_->name(), varType);
-        return;
-    }
-    varType  = "variable-not-found";
-    theValue = 0;
-}
-
-std::ostream& VariableHelper::print(std::ostream& os) const {
-    Indentor in;
-    Indentor::indent(os) << "# " << astVariable_->nodePath() << Str::COLON() << astVariable_->name();
-
-    if (theReferenceNode_) {
-        os << " node(" << theReferenceNode_->name() << ") ";
-        theReferenceNode_->findExprVariableAndPrint(astVariable_->name(), os);
-    }
-    else {
-        os << " node(?not-found?) " << astVariable_->nodePath() << " value(0) # check suite filter";
-    }
-    os << "\n";
-    return os;
-}
-
-std::ostream& operator<<(std::ostream& os, const Ast& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstTop& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstRoot& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstNot& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstPlus& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstMinus& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstDivide& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstMultiply& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstModulo& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstAnd& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstOr& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstEqual& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstNotEqual& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstLessEqual& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstGreaterEqual& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstGreaterThan& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstLessThan& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstLeaf& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstInteger& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstInstant& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstNodeState& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstEventState& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstNode& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstVariable& d) {
-    return d.print(os);
-}
-std::ostream& operator<<(std::ostream& os, const AstFlag& d) {
-    return d.print(os);
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprAst.hpp 5.13.0-1/ANode/src/ecflow/node/ExprAst.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprAst.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprAst.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,726 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ExprAst_HPP
-#define ecflow_node_ExprAst_HPP
-
-// The AST is now demand created, and hence we no longer need to persist it
-
-#include <cassert>
-#include <iosfwd>
-
-#include "ecflow/core/Chrono.hpp"
-#include "ecflow/core/DState.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-namespace ecf {
-class ExprAstVisitor;
-} // namespace ecf
-
-//////////////////////////////////////////////////////////////////////////////////
-class Ast {
-public:
-    Ast() = default;
-    virtual ~Ast();
-
-    std::string evaluate_str() const { return evaluate() ? "true" : "false"; }
-
-    virtual void accept(ecf::ExprAstVisitor&) = 0;
-    virtual Ast* clone() const                = 0;
-    virtual bool is_attribute() const { return false; }
-    virtual bool is_not() const { return false; }
-    virtual bool isleaf() const { return false; }
-    virtual bool isRoot() const { return false; }
-    virtual AstTop* isTop() const { return nullptr; }
-    virtual bool is_evaluateable() const { return false; }
-
-    virtual void addChild(Ast*) {}
-    virtual Ast* left() const { return nullptr; }
-    virtual Ast* right() const { return nullptr; }
-    virtual bool evaluate() const {
-        assert(false);
-        return false;
-    }
-    virtual bool empty() const { return true; }
-    virtual int value() const {
-        assert(false);
-        return 0;
-    }                                                       // only valid for leaf or operators
-    virtual bool check(std::string&) const { return true; } // check divide or modulo by zero
-
-    virtual bool is_valid_ast(std::string& error_msg) const                 = 0;
-    virtual std::ostream& print(std::ostream&) const                        = 0;
-    virtual void print_flat(std::ostream&, bool add_brackets = false) const = 0; // used for test
-    virtual std::string type() const                                        = 0;
-    virtual void exprType(const std::string&) {}
-    virtual std::string name() const { return expression(); } /* ABO */
-    virtual std::string expression() const = 0;               // recreate expression from AST
-    virtual bool why(std::string& /*theReasonWhy*/, bool html = false) const;
-    virtual std::string why_expression(bool html = false) const = 0; // recreate expression from AST for why command
-
-    // Use for data arithmetic for REPEAT Date, Use default implementation for others
-    // Currently *ONLY* works if repeat variable in on LHS
-    virtual int minus(Ast* right) const { return (value() - right->value()); }
-    virtual int plus(Ast* right) const { return (value() + right->value()); }
-
-    virtual void setParentNode(Node*) {} // traverse and set for interested nodes
-    virtual void invalidate_trigger_references() const {}
-};
-
-class AstTop : public Ast {
-public:
-    AstTop() = default;
-    ~AstTop() override;
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstTop* clone() const override;
-
-    Ast* left() const override { return root_; }
-    void addChild(Ast* r) override { root_ = r; }
-    AstTop* isTop() const override { return const_cast<AstTop*>(this); }
-    bool evaluate() const override;
-    bool check(std::string& error_msg) const override;
-
-    bool empty() const override { return (root_) ? false : true; }
-    std::ostream& print(std::ostream&) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-
-    bool why(std::string& theReasonWhy, bool html = false) const override;
-    std::string type() const override { return stype(); }
-    void exprType(const std::string& s) override { exprType_ = s; }
-    static std::string stype() { return "top"; }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    void setParentNode(Node*) override;
-    void invalidate_trigger_references() const override;
-
-private:
-    Ast* root_{nullptr};
-    std::string exprType_; // trigger or complete
-};
-
-// This if one of AND, OR, == != <= >= +, -,*,!,%,/
-class AstRoot : public Ast {
-public:
-    AstRoot() = default;
-    ~AstRoot() override;
-
-    bool isRoot() const override { return true; }
-    bool is_evaluateable() const override { return true; }
-
-    bool check(std::string& error_msg) const override;
-    void accept(ecf::ExprAstVisitor&) override;
-    void addChild(Ast* n) override;
-    Ast* left() const override { return left_; }
-    Ast* right() const override { return right_; }
-    std::ostream& print(std::ostream& os) const override;
-    bool empty() const override { return (left_ && right_) ? false : true; }
-    void setParentNode(Node*) override;
-
-    virtual void set_root_name(const std::string&) {}
-    void invalidate_trigger_references() const override;
-
-protected:
-    std::string do_why_expression(const std::string& root, bool html) const;
-    std::string do_bracket_why_expression(const std::string& root, bool html) const;
-    std::string do_false_bracket_why_expression(const std::string& root, bool html) const;
-
-    std::string do_expression(const std::string& root) const;
-    std::string do_bracket_expression(const std::string& root) const;
-
-protected:
-    Ast* left_{nullptr};
-    Ast* right_{nullptr};
-};
-
-class AstNot : public AstRoot {
-public:
-    AstNot() : name_("! ") {}
-    void accept(ecf::ExprAstVisitor&) override;
-    AstNot* clone() const override;
-    bool is_not() const override { return true; }
-
-    bool evaluate() const override {
-        assert(!right_);
-        return !left_->evaluate();
-    }
-    int value() const override {
-        assert(!right_);
-        return !left_->value();
-    }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "not"; }
-    void set_root_name(const std::string& n) override { name_ = n; }
-
-private:
-    std::string name_;
-};
-
-class AstPlus : public AstRoot {
-public:
-    AstPlus() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstPlus* clone() const override;
-
-    bool evaluate() const override { return true; }
-    int value() const override { return left_->plus(right_); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "plus"; }
-};
-
-class AstMinus : public AstRoot {
-public:
-    AstMinus() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstMinus* clone() const override;
-
-    bool evaluate() const override { return true; }
-    int value() const override { return left_->minus(right_); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "minus"; }
-};
-
-class AstDivide : public AstRoot {
-public:
-    AstDivide() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstDivide* clone() const override;
-    bool evaluate() const override { return true; }
-    bool check(std::string& error_msg) const override;
-    int value() const override; // Log error if right hand side has value of zero
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "divide"; }
-};
-
-class AstMultiply : public AstRoot {
-public:
-    AstMultiply() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstMultiply* clone() const override;
-    bool evaluate() const override { return true; }
-    int value() const override { return (left_->value() * right_->value()); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "multiply"; }
-};
-
-class AstModulo : public AstRoot {
-public:
-    AstModulo() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstModulo* clone() const override;
-    bool check(std::string& error_msg) const override;
-    bool evaluate() const override { return true; }
-    int value() const override; // Log error if right hand side has value of zero
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "modulo"; }
-};
-
-class AstAnd : public AstRoot {
-public:
-    AstAnd() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstAnd* clone() const override;
-    bool evaluate() const override { return (left_->evaluate() && right_->evaluate()); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "and"; }
-};
-
-class AstOr : public AstRoot {
-public:
-    AstOr() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstOr* clone() const override;
-    bool evaluate() const override { return (left_->evaluate() || right_->evaluate()); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "or"; }
-};
-
-class AstEqual : public AstRoot {
-public:
-    AstEqual() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstEqual* clone() const override;
-    bool evaluate() const override { return (left_->value() == right_->value()); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "equal"; }
-};
-
-class AstNotEqual : public AstRoot {
-public:
-    AstNotEqual() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstNotEqual* clone() const override;
-    bool evaluate() const override { return (left_->value() != right_->value()); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "not-equal"; }
-};
-
-class AstLessEqual : public AstRoot {
-public:
-    AstLessEqual() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    AstLessEqual* clone() const override;
-    bool evaluate() const override { return (left_->value() <= right_->value()); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "less-equal"; }
-};
-
-class AstGreaterEqual : public AstRoot {
-public:
-    AstGreaterEqual() = default;
-    bool evaluate() const override { return (left_->value() >= right_->value()); }
-    void accept(ecf::ExprAstVisitor&) override;
-    AstGreaterEqual* clone() const override;
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "greater-equal"; }
-};
-
-class AstGreaterThan : public AstRoot {
-public:
-    AstGreaterThan() = default;
-
-    bool evaluate() const override { return (left_->value() > right_->value()); }
-    void accept(ecf::ExprAstVisitor&) override;
-    AstGreaterThan* clone() const override;
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "greater-than"; }
-};
-
-class AstLessThan : public AstRoot {
-public:
-    AstLessThan() = default;
-
-    bool evaluate() const override { return (left_->value() < right_->value()); }
-    void accept(ecf::ExprAstVisitor&) override;
-    AstLessThan* clone() const override;
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    bool is_valid_ast(std::string& error_msg) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "less-than"; }
-};
-
-//=============================================================================================
-/// class AstLeaf
-/// represents Integer, String, Node State, event State, Node, variable
-/// These always represent the right side of the tree
-class AstLeaf : public Ast {
-public:
-    AstLeaf() = default;
-    void accept(ecf::ExprAstVisitor&) override;
-    bool isleaf() const override { return true; }
-    bool is_valid_ast(std::string&) const override { return true; }
-};
-
-class AstFunction : public AstLeaf {
-public:
-    enum FuncType { DATE_TO_JULIAN, JULIAN_TO_DATE };
-    AstFunction(FuncType ft, Ast* arg) : arg_(arg), ft_(ft) { assert(arg_); }
-    ~AstFunction() override { delete arg_; }
-
-    bool is_evaluateable() const override { return true; }
-    bool evaluate() const override { return value() != 0 ? true : false; }
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstFunction* clone() const override;
-    int value() const override;
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "AstFunction"; }
-    void setParentNode(Node* n) override;
-
-    Ast* arg() const { return arg_; }
-    FuncType ft() const { return ft_; }
-
-private:
-    Ast* arg_;
-    FuncType ft_;
-};
-
-class AstInteger : public AstLeaf {
-public:
-    explicit AstInteger(int value) : value_(value) {}
-
-    bool is_evaluateable() const override { return true; }
-    bool evaluate() const override { return value_; } // -1 -2 1 2 3 evaluates to true, 0 returns false
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstInteger* clone() const override;
-    int value() const override { return value_; }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "integer"; }
-
-private:
-    int value_;
-};
-
-class AstInstant : public AstLeaf {
-public:
-    explicit AstInstant(int value) : value_(ecf::coerce_to_instant(value)) {}
-    explicit AstInstant(ecf::Instant value) : value_(std::move(value)) {}
-
-    bool is_evaluateable() const override { return true; }
-    bool evaluate() const override { return value(); } // -1 -2 1 2 3 evaluates to true, 0 returns false
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstInstant* clone() const override;
-    int value() const override { return ecf::coerce_from_instant(value_); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "integer"; }
-
-private:
-    ecf::Instant value_;
-};
-
-class AstNodeState : public AstLeaf {
-public:
-    explicit AstNodeState(DState::State s) : state_(s) {}
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstNodeState* clone() const override;
-    int value() const override { return static_cast<int>(state_); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "node-state"; }
-
-private:
-    DState::State state_;
-};
-
-class AstEventState : public AstLeaf {
-public:
-    explicit AstEventState(bool b) : state_(b) {}
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstEventState* clone() const override;
-    int value() const override { return state_; }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    static std::string stype() { return "event-state"; }
-
-private:
-    bool state_;
-};
-
-/// This class will need to determine the corresponding node pointer
-/// This is required so that during evaluation we don't need to search for the Node.
-/// represent nodeName(a), dotPath(./a), dot dot path(../a/b)
-///
-/// A Node without a corresponding Node* will return the integer value of
-/// DState::UNKNOWN for the value() function. This will allow for trigger
-/// of the form:  trigger a == complete or a == unknown
-/// to be evaluated.
-
-class AstNode : public AstLeaf {
-public:
-    explicit AstNode(const std::string& n) : parentNode_(nullptr), nodePath_(n) {}
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstNode* clone() const override;
-    int value() const override { return static_cast<int>(state()); }
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    void setParentNode(Node* n) override { parentNode_ = n; }
-    void invalidate_trigger_references() const override { ref_node_.reset(); }
-    static std::string stype() { return "node"; }
-
-    const std::string& nodePath() const { return nodePath_; }
-    Node* referencedNode() const;
-    Node* referencedNode(std::string& errorMsg) const;
-    Node* parentNode() const { return parentNode_; }
-    DState::State state() const;
-
-private:
-    Node* get_ref_node() const { return ref_node_.lock().get(); }
-    Node* parentNode_; // should always be non null, before evaluate.
-    std::string nodePath_;
-    mutable weak_node_ptr ref_node_;
-};
-
-class AstFlag : public AstLeaf {
-public:
-    AstFlag(const std::string& n, ecf::Flag::Type ft) : nodePath_(n), flag_(ft) {}
-
-    std::string name() const override;
-
-    bool is_attribute() const override { return true; }
-    // although AstFlag is leaf, However allow to evaluate to cope with
-    //     ( ../family1/<flag>:late != 0 and ../family1/a:myEvent)
-    // Treat this like an integer
-    bool is_evaluateable() const override { return true; }
-    bool evaluate() const override { return value() != 0 ? true : false; }
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstFlag* clone() const override;
-    int value() const override;
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    void setParentNode(Node* n) override { parentNode_ = n; }
-    void invalidate_trigger_references() const override { ref_node_.reset(); }
-    static std::string stype() { return "flag"; }
-
-    const std::string& nodePath() const { return nodePath_; }
-    Node* referencedNode() const;
-    Node* referencedNode(std::string& errorMsg) const;
-    Node* parentNode() const { return parentNode_; }
-
-private:
-    Node* get_ref_node() const { return ref_node_.lock().get(); }
-
-    std::string nodePath_;
-    Node* parentNode_{nullptr}; // should always be non null, before evaluate.
-    mutable weak_node_ptr ref_node_;
-    ecf::Flag::Type flag_;
-};
-
-/// A variable: This can reference in the CURRENT order:
-///     event,
-///     meter,
-///     user variable,
-///     repeat  variable, for enumerated/string we use the positional value
-///     generated variable
-/// ** IT is treated in a same as an integer, and can appear in that context
-//  ** i.e  "2 == (((/seasplots/lag:YMD / 100 ) % 100) % 3"
-class AstVariable : public AstLeaf {
-public:
-    AstVariable(const std::string& nodePath, const std::string& variablename)
-        : parentNode_(nullptr),
-          nodePath_(nodePath),
-          name_(variablename) {}
-
-    std::string name() const override { return name_; }
-    bool is_attribute() const override { return true; }
-
-    // although AstVariable is leaf, However allow to evaluate to cope with
-    //     ( ../family1/a:myMeter >= 20 and ../family1/a:myEvent)
-    // Treat this like an integer
-    bool is_evaluateable() const override { return true; }
-    bool evaluate() const override { return value() != 0 ? true : false; }
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstVariable* clone() const override;
-    int value() const override;
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    void setParentNode(Node* n) override { parentNode_ = n; }
-    void invalidate_trigger_references() const override { ref_node_.reset(); }
-
-    int minus(Ast* right) const override;
-    int plus(Ast* right) const override;
-
-    Node* parentNode() const { return parentNode_; }
-    Node* referencedNode() const;
-    Node* referencedNode(std::string& errorMsg) const;
-
-    static std::string stype() { return "variable"; }
-    const std::string& nodePath() const { return nodePath_; }
-
-private:
-    Node* get_ref_node() const { return ref_node_.lock().get(); }
-
-    Node* parentNode_;
-    std::string nodePath_;
-    std::string name_;
-    mutable weak_node_ptr ref_node_;
-};
-
-/// A variable: This can reference in the CURRENT order:
-///     event,
-///     meter,
-///     user variable,
-///     repeat  variable, for enumerated/string we use the positional value
-///     generated variable
-/// ** IT is treated in a same as an integer, and can appear in that context
-//  ** i.e  "2 == (((:YMD / 100 ) % 100) % 3"
-class AstParentVariable : public AstLeaf {
-public:
-    explicit AstParentVariable(const std::string& variablename) : parentNode_(nullptr), name_(variablename) {}
-
-    std::string name() const override { return name_; }
-    bool is_attribute() const override { return true; }
-
-    // although  AstParentVariable is leaf, However allow to evaluate to cope with
-    //     ( :myMeter >= 20 and :myEvent)
-    // Treat this like an integer
-    bool is_evaluateable() const override { return true; }
-    bool evaluate() const override { return value() != 0 ? true : false; }
-
-    void accept(ecf::ExprAstVisitor&) override;
-    AstParentVariable* clone() const override;
-    int value() const override;
-    std::ostream& print(std::ostream& os) const override;
-    void print_flat(std::ostream&, bool add_brackets = false) const override;
-    std::string type() const override { return stype(); }
-    std::string expression() const override;
-    std::string why_expression(bool html = false) const override;
-    void setParentNode(Node* n) override { parentNode_ = n; }
-    void invalidate_trigger_references() const override { ref_node_.reset(); }
-
-    int minus(Ast* right) const override;
-    int plus(Ast* right) const override;
-
-    Node* parentNode() const { return parentNode_; }
-    static std::string stype() { return "parent_variable"; }
-
-    Node* find_node_which_references_variable() const;
-    Node* referencedNode() const { return find_node_which_references_variable(); }
-
-private:
-    Node* parentNode_;
-    std::string name_;
-    mutable weak_node_ptr ref_node_;
-};
-
-// Helper class
-class VariableHelper {
-public:
-    explicit VariableHelper(const AstVariable* astVariable);
-    VariableHelper(const AstVariable* astVariable, std::string& errorMsg);
-    // Disable copy (and move) semantics
-    VariableHelper(const VariableHelper&)                  = delete;
-    const VariableHelper& operator=(const VariableHelper&) = delete;
-
-    int value() const;
-    int plus(int) const;
-    int minus(int) const;
-
-    std::ostream& print(std::ostream& os) const;
-    Node* theReferenceNode() const { return theReferenceNode_; }
-
-    void varTypeAndValue(std::string& varType, int& value) const;
-
-private:
-    const AstVariable* astVariable_;
-    Node* theReferenceNode_;
-};
-
-// 17
-std::ostream& operator<<(std::ostream& os, const Ast&);
-std::ostream& operator<<(std::ostream& os, const AstTop&);
-std::ostream& operator<<(std::ostream& os, const AstRoot&);
-std::ostream& operator<<(std::ostream& os, const AstNot&);
-std::ostream& operator<<(std::ostream& os, const AstPlus&);
-std::ostream& operator<<(std::ostream& os, const AstMinus&);
-std::ostream& operator<<(std::ostream& os, const AstMultiply&);
-std::ostream& operator<<(std::ostream& os, const AstDivide&);
-std::ostream& operator<<(std::ostream& os, const AstModulo&);
-std::ostream& operator<<(std::ostream& os, const AstAnd&);
-std::ostream& operator<<(std::ostream& os, const AstOr&);
-std::ostream& operator<<(std::ostream& os, const AstEqual&);
-std::ostream& operator<<(std::ostream& os, const AstNotEqual&);
-std::ostream& operator<<(std::ostream& os, const AstLessEqual&);
-std::ostream& operator<<(std::ostream& os, const AstGreaterEqual&);
-std::ostream& operator<<(std::ostream& os, const AstGreaterThan&);
-std::ostream& operator<<(std::ostream& os, const AstLessThan&);
-std::ostream& operator<<(std::ostream& os, const AstLeaf&);
-std::ostream& operator<<(std::ostream& os, const AstInteger&);
-std::ostream& operator<<(std::ostream& os, const AstInstant&);
-std::ostream& operator<<(std::ostream& os, const AstNodeState&);
-std::ostream& operator<<(std::ostream& os, const AstEventState&);
-std::ostream& operator<<(std::ostream& os, const AstNode&);
-std::ostream& operator<<(std::ostream& os, const AstVariable&);
-std::ostream& operator<<(std::ostream& os, const AstFlag&);
-
-#endif /* ecflow_node_ExprAst_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprAstVisitor.cpp 5.13.0-1/ANode/src/ecflow/node/ExprAstVisitor.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprAstVisitor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprAstVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,119 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/ExprAstVisitor.hpp"
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Node.hpp"
-
-namespace ecf {
-
-//======================================================================================
-
-ExprAstVisitor::~ExprAstVisitor() = default;
-
-//======================================================================================
-AstResolveVisitor::AstResolveVisitor(const Node* node) : triggerNode_(node) {
-}
-AstResolveVisitor::~AstResolveVisitor() = default;
-
-void AstResolveVisitor::visitNode(AstNode* astNode) {
-    // std::cout << "AstResolveVisitor::visitNode errorMsg = " << errorMsg_ << "\n";
-    if (errorMsg_.empty()) {
-
-        astNode->setParentNode(const_cast<Node*>(triggerNode_));
-        Node* node = astNode->referencedNode(errorMsg_);
-        if (!node) {
-            // A node can be NULL when its a extern path. In this case errorMsg should be empty
-            return;
-        }
-        LOG_ASSERT(errorMsg_.empty(), ""); // found Node, make sure errorMsg is empty
-    }
-}
-
-void AstResolveVisitor::visitVariable(AstVariable* astVar) {
-    if (errorMsg_.empty()) {
-
-        astVar->setParentNode(const_cast<Node*>(triggerNode_));
-
-        /// Use VariableHelper to populate errorMsg_
-        VariableHelper varHelper(astVar, errorMsg_);
-    }
-}
-
-void AstResolveVisitor::visitParentVariable(AstParentVariable* astvar) {
-    if (errorMsg_.empty()) {
-
-        astvar->setParentNode(const_cast<Node*>(triggerNode_));
-
-        if (!astvar->find_node_which_references_variable()) {
-
-            // Check externs if possible
-            Defs* defs = triggerNode_->defs();
-            if (defs) {
-                if (defs->find_extern(triggerNode_->absNodePath(), astvar->name())) {
-                    return;
-                }
-            }
-
-            std::stringstream ss;
-            ss << " Could not find variable " << astvar->name() << " on node " << triggerNode_->debugNodePath()
-               << " OR any of its parent nodes";
-            errorMsg_ += ss.str();
-        }
-    }
-}
-
-void AstResolveVisitor::visitFlag(AstFlag* ast) {
-    if (errorMsg_.empty()) {
-
-        ast->setParentNode(const_cast<Node*>(triggerNode_));
-        Node* node = ast->referencedNode(errorMsg_);
-        if (!node) {
-            // A node can be NULL when its a extern path. In this case errorMsg should be empty
-            return;
-        }
-        LOG_ASSERT(errorMsg_.empty(), ""); // found Node, make sure errorMsg is empty
-    }
-}
-
-//===========================================================================================================
-
-AstCollateNodesVisitor::AstCollateNodesVisitor(std::set<Node*>& s) : theSet_(s) {
-}
-AstCollateNodesVisitor::~AstCollateNodesVisitor() = default;
-
-void AstCollateNodesVisitor::visitNode(AstNode* astNode) {
-    Node* referencedNode = astNode->referencedNode(); // could be expensive, hence don't call twice
-    if (referencedNode)
-        theSet_.insert(referencedNode);
-}
-
-void AstCollateNodesVisitor::visitVariable(AstVariable* astVar) {
-    Node* referencedNode = astVar->referencedNode(); // could be expensive, hence don't call twice
-    if (referencedNode)
-        theSet_.insert(referencedNode);
-}
-
-void AstCollateNodesVisitor::visitParentVariable(AstParentVariable* astvar) {
-    Node* referencedNode = astvar->referencedNode(); // could be expensive, hence don't call twice
-    if (referencedNode)
-        theSet_.insert(referencedNode);
-}
-
-void AstCollateNodesVisitor::visitFlag(AstFlag* ast) {
-    Node* referencedNode = ast->referencedNode(); // could be expensive, hence don't call twice
-    if (referencedNode)
-        theSet_.insert(referencedNode);
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprAstVisitor.hpp 5.13.0-1/ANode/src/ecflow/node/ExprAstVisitor.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprAstVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprAstVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,156 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ExprAstVisitor_HPP
-#define ecflow_node_ExprAstVisitor_HPP
-
-#include <set>
-#include <string>
-
-class Node;
-class AstTop;
-class AstRoot;
-class AstAnd;
-class AstNot;
-class AstPlus;
-class AstMinus;
-class AstDivide;
-class AstMultiply;
-class AstModulo;
-class AstOr;
-class AstEqual;
-class AstNotEqual;
-class AstLessEqual;
-class AstGreaterEqual;
-class AstLessThan;
-class AstGreaterThan;
-class AstLeaf;
-class AstInteger;
-class AstInstant;
-class AstFunction;
-class AstNodeState;
-class AstEventState;
-class AstNode;
-class AstVariable;
-class AstParentVariable;
-class AstFlag;
-
-namespace ecf {
-
-class ExprAstVisitor {
-public:
-    virtual ~ExprAstVisitor();
-
-    virtual void visitTop(AstTop*)                       = 0;
-    virtual void visitRoot(AstRoot*)                     = 0;
-    virtual void visitAnd(AstAnd*)                       = 0;
-    virtual void visitNot(AstNot*)                       = 0;
-    virtual void visitPlus(AstPlus*)                     = 0;
-    virtual void visitMinus(AstMinus*)                   = 0;
-    virtual void visitDivide(AstDivide*)                 = 0;
-    virtual void visitMultiply(AstMultiply*)             = 0;
-    virtual void visitModulo(AstModulo*)                 = 0;
-    virtual void visitOr(AstOr*)                         = 0;
-    virtual void visitEqual(AstEqual*)                   = 0;
-    virtual void visitNotEqual(AstNotEqual*)             = 0;
-    virtual void visitLessEqual(AstLessEqual*)           = 0;
-    virtual void visitGreaterEqual(AstGreaterEqual*)     = 0;
-    virtual void visitGreaterThan(AstGreaterThan*)       = 0;
-    virtual void visitLessThan(AstLessThan*)             = 0;
-    virtual void visitLeaf(AstLeaf*)                     = 0;
-    virtual void visitInteger(AstInteger*)               = 0;
-    virtual void visitInstant(AstInstant*)               = 0;
-    virtual void visitFunction(AstFunction*)             = 0;
-    virtual void visitNodeState(AstNodeState*)           = 0;
-    virtual void visitEventState(AstEventState*)         = 0;
-    virtual void visitNode(AstNode*)                     = 0;
-    virtual void visitVariable(AstVariable*)             = 0;
-    virtual void visitParentVariable(AstParentVariable*) = 0;
-    virtual void visitFlag(AstFlag*)                     = 0;
-};
-
-class AstResolveVisitor : public ExprAstVisitor {
-public:
-    explicit AstResolveVisitor(const Node*);
-    ~AstResolveVisitor() override;
-
-    const std::string& errorMsg() const { return errorMsg_; }
-
-    void visitTop(AstTop*) override {}
-    void visitRoot(AstRoot*) override {}
-    void visitAnd(AstAnd*) override {}
-    void visitNot(AstNot*) override {}
-    void visitPlus(AstPlus*) override {}
-    void visitMinus(AstMinus*) override {}
-    void visitDivide(AstDivide*) override {}
-    void visitMultiply(AstMultiply*) override {}
-    void visitModulo(AstModulo*) override {}
-    void visitOr(AstOr*) override {}
-    void visitEqual(AstEqual*) override {}
-    void visitNotEqual(AstNotEqual*) override {}
-    void visitLessEqual(AstLessEqual*) override {}
-    void visitGreaterEqual(AstGreaterEqual*) override {}
-    void visitGreaterThan(AstGreaterThan*) override {}
-    void visitLessThan(AstLessThan*) override {}
-    void visitLeaf(AstLeaf*) override {}
-    void visitInteger(AstInteger*) override {}
-    void visitInstant(AstInstant*) override {}
-    void visitFunction(AstFunction*) override {}
-    void visitNodeState(AstNodeState*) override {}
-    void visitEventState(AstEventState*) override {}
-    void visitNode(AstNode*) override;
-    void visitVariable(AstVariable*) override;
-    void visitParentVariable(AstParentVariable*) override;
-    void visitFlag(AstFlag*) override;
-
-private:
-    const Node* triggerNode_;
-    std::string errorMsg_;
-};
-
-class AstCollateNodesVisitor : public ExprAstVisitor {
-public:
-    explicit AstCollateNodesVisitor(std::set<Node*>&);
-    ~AstCollateNodesVisitor() override;
-
-    void visitTop(AstTop*) override {}
-    void visitRoot(AstRoot*) override {}
-    void visitAnd(AstAnd*) override {}
-    void visitNot(AstNot*) override {}
-    void visitPlus(AstPlus*) override {}
-    void visitMinus(AstMinus*) override {}
-    void visitDivide(AstDivide*) override {}
-    void visitMultiply(AstMultiply*) override {}
-    void visitModulo(AstModulo*) override {}
-    void visitOr(AstOr*) override {}
-    void visitEqual(AstEqual*) override {}
-    void visitNotEqual(AstNotEqual*) override {}
-    void visitLessEqual(AstLessEqual*) override {}
-    void visitGreaterEqual(AstGreaterEqual*) override {}
-    void visitGreaterThan(AstGreaterThan*) override {}
-    void visitLessThan(AstLessThan*) override {}
-    void visitLeaf(AstLeaf*) override {}
-    void visitInteger(AstInteger*) override {}
-    void visitInstant(AstInstant*) override {}
-    void visitFunction(AstFunction*) override {}
-    void visitNodeState(AstNodeState*) override {}
-    void visitEventState(AstEventState*) override {}
-    void visitNode(AstNode*) override;
-    void visitVariable(AstVariable*) override;
-    void visitParentVariable(AstParentVariable*) override;
-    void visitFlag(AstFlag*) override;
-
-private:
-    std::set<Node*>& theSet_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_ExprAstVisitor_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprDuplicate.cpp 5.13.0-1/ANode/src/ecflow/node/ExprDuplicate.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprDuplicate.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprDuplicate.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/ExprDuplicate.hpp"
-
-#include <iostream>
-#include <unordered_map>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/ExprAst.hpp"
-
-using namespace std;
-
-static std::unordered_map<std::string, AstTop*> duplicate_expr;
-typedef std::unordered_map<std::string, AstTop*> my_map;
-
-ExprDuplicate::~ExprDuplicate() {
-    // cout << "ExprDuplicate::~ExprDuplicate: server(" << Ecf::server() << ") " << duplicate_expr.size() << "
-    // *****************************************************************\n";
-    for (my_map::value_type i : duplicate_expr) {
-        // cout << " deleting: " << i.first << " :" << i.second << "\n";
-        delete i.second;
-        i.second = NULL;
-    }
-    duplicate_expr.clear();
-}
-
-void ExprDuplicate::dump(const std::string& msg) {
-    cout << "ExprDuplicate::dump server(" << Ecf::server() << ") " << msg << "\n";
-    for (const my_map::value_type& i : duplicate_expr) {
-        cout << "   " << i.first << " :" << i.second << "\n";
-    }
-}
-
-std::unique_ptr<AstTop> ExprDuplicate::find(const std::string& expr) {
-    my_map::const_iterator it = duplicate_expr.find(expr);
-    if (it != duplicate_expr.end()) {
-        return std::unique_ptr<AstTop>((*it).second->clone());
-    }
-    return std::unique_ptr<AstTop>();
-}
-
-void ExprDuplicate::add(const std::string& expr, AstTop* ast) {
-    assert(!expr.empty() && ast);
-    AstTop* clone = ast->clone();
-    duplicate_expr.insert(std::make_pair(expr, clone));
-
-    // cout << "ExprDuplicate::add: server(" << Ecf::server() << ") " << expr << " :" << clone << "   " <<
-    // duplicate_expr.size() << "\n";
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprDuplicate.hpp 5.13.0-1/ANode/src/ecflow/node/ExprDuplicate.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprDuplicate.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprDuplicate.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ExprDuplicate_HPP
-#define ecflow_node_ExprDuplicate_HPP
-
-///
-/// \brief For large designs > 90% of triggers are identical.
-/// We take advantage of this by using a map to store a *CLONED* ast
-/// This saves a huge amount on re-parsing using spirit classic.
-///
-/// This cloned  AST is maintained in a static map, hence we need to
-/// manage the lifetime, to avoid valgrind complaining.
-///
-
-#include <memory> // for unique_ptr
-#include <string>
-class AstTop;
-
-// reclaim memory allocated in map, Avoid valgrind errors
-class ExprDuplicate {
-private:
-public:
-    ExprDuplicate() = default;
-    // Disable copy (and move) semantics
-    ExprDuplicate(const ExprDuplicate&)                  = delete;
-    const ExprDuplicate& operator=(const ExprDuplicate&) = delete;
-
-    ~ExprDuplicate();
-
-    // for debug only
-    static void dump(const std::string& msg);
-
-    // Find the expr in the map, if found returns a CLONED ast, else NULL
-    static std::unique_ptr<AstTop> find(const std::string& expr);
-
-    // Add the expr to the map, the ast is cloned.
-    static void add(const std::string& expr, AstTop*);
-};
-
-#endif /* ecflow_node_ExprDuplicate_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprParser.cpp 5.13.0-1/ANode/src/ecflow/node/ExprParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1188 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-// Un-comment these for selective for debugging. At the moment because we have added
-//            ast generation BOOST_SPIRIT_DEBUG is to verbose, making debugging a pain.
-// Typically, I will comment out ONLY BOOST_SPIRIT_DEBUG and enable all the others
-// #define BOOST_SPIRIT_DEBUG
-// #define BOOST_SPIRIT_DUMP_PARSETREE_AS_XML
-// #define PRINT_TREE
-// #define PRINT_AST_TRAVERSAL
-// #define PRINT_AST
-
-#include "ecflow/node/ExprParser.hpp"
-
-#include <iostream>
-#include <map>
-#include <memory>
-#include <sstream>
-#include <stack>
-#include <string>
-
-#include <boost/spirit/include/classic.hpp>
-#include <boost/spirit/include/classic_actor.hpp>
-#include <boost/spirit/include/classic_ast.hpp>
-#include <boost/spirit/include/classic_attribute.hpp>
-#include <boost/spirit/include/classic_confix.hpp>
-#include <boost/spirit/include/classic_core.hpp>
-#include <boost/spirit/include/classic_tree_to_xml.hpp>
-#include <boost/spirit/include/phoenix1_binders.hpp>
-
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/ExprDuplicate.hpp"
-
-// Reference
-// ‘*’   Zero or more
-// ‘!’   Zero or one
-// ‘+’   One or more
-// ‘>>’  Sequence/concatenation
-// ‘|’   alternate
-// ‘-‘   not
-
-////////////////////////////////////////////////////////////////////////////
-using namespace ecf;
-using namespace std;
-using namespace boost::spirit;
-using namespace phoenix;
-using namespace BOOST_SPIRIT_CLASSIC_NS;
-
-/////////////////////////////////////////////////////////////////////////////
-typedef tree_match<const char*> treematch_t;
-typedef treematch_t::tree_iterator tree_iter_t;
-
-//////////////////////////////////////////////////////////////////////////////
-
-struct ExpressionGrammer : public grammar<ExpressionGrammer>
-{
-    // The parser object is copied a lot, so only use reference/pointer variables as data members
-    ExpressionGrammer()  = default;
-    ~ExpressionGrammer() = default;
-
-    static const int integer_ID            = 1;
-    static const int dot_path_ID           = 2;
-    static const int equal_1_ID            = 3;
-    static const int equal_2_ID            = 4;
-    static const int not_equal_1_ID        = 5;
-    static const int not_equal_2_ID        = 6;
-    static const int node_name_ID          = 7;
-    static const int greater_equals_1_ID   = 8;
-    static const int greater_equals_2_ID   = 9;
-    static const int less_equals_1_ID      = 10;
-    static const int less_equals_2_ID      = 11;
-    static const int less_than_1_ID        = 12;
-    static const int less_than_2_ID        = 13;
-    static const int greater_than_1_ID     = 14;
-    static const int greater_than_2_ID     = 15;
-    static const int node_state_unknown_ID = 16;
-
-    static const int node_state_complete_ID  = 18;
-    static const int node_state_queued_ID    = 19;
-    static const int node_state_submitted_ID = 20;
-    static const int node_state_active_ID    = 21;
-    static const int node_state_aborted_ID   = 22;
-
-    static const int not1_ID                = 23;
-    static const int not2_ID                = 24;
-    static const int not3_ID                = 25;
-    static const int and_ID                 = 26;
-    static const int or_ID                  = 27;
-    static const int dot_dot_path_ID        = 29;
-    static const int base_trigger_ID        = 31;
-    static const int sub_expression_ID      = 32;
-    static const int node_path_state_ID     = 34;
-    static const int absolute_path_ID       = 35;
-    static const int event_state_ID         = 36;
-    static const int variable_ID            = 37;
-    static const int plus_ID                = 42;
-    static const int minus_ID               = 43;
-    static const int multiply_ID            = 44;
-    static const int divide_ID              = 45;
-    static const int modulo_ID              = 46;
-    static const int calc_expression_ID     = 47;
-    static const int calc_factor_ID         = 48;
-    static const int calc_term_ID           = 49;
-    static const int calc_grouping_ID       = 50;
-    static const int calc_subexpression_ID  = 51;
-    static const int basic_variable_path_ID = 52;
-    static const int compare_expression_ID  = 53;
-
-    static const int cal_date_to_julian_ID = 54;
-    static const int cal_julian_to_date_ID = 55;
-    static const int cal_argument_ID       = 56;
-
-    static const int flag_path_ID       = 57;
-    static const int flag_late_ID       = 58;
-    static const int flag_zombie_ID     = 59;
-    static const int flag_archived_ID   = 60;
-    static const int flag_ID            = 61;
-    static const int root_path_ID       = 62;
-    static const int parent_variable_ID = 63;
-
-    static const int datetime_ID = 64;
-
-    template <typename ScannerT>
-    struct definition
-    {
-        rule<ScannerT, parser_tag<cal_date_to_julian_ID>> cal_date_to_julian;
-        rule<ScannerT, parser_tag<cal_julian_to_date_ID>> cal_julian_to_date;
-        rule<ScannerT, parser_tag<cal_argument_ID>> cal_argument;
-
-        rule<ScannerT, parser_tag<integer_ID>> integer;
-        rule<ScannerT, parser_tag<plus_ID>> plus;
-        rule<ScannerT, parser_tag<minus_ID>> minus;
-        rule<ScannerT, parser_tag<multiply_ID>> multiply;
-        rule<ScannerT, parser_tag<divide_ID>> divide;
-        rule<ScannerT, parser_tag<modulo_ID>> modulo;
-
-        rule<ScannerT, parser_tag<equal_1_ID>> equal_1;
-        rule<ScannerT, parser_tag<equal_2_ID>> equal_2;
-        rule<ScannerT, parser_tag<not_equal_1_ID>> not_equal_1;
-        rule<ScannerT, parser_tag<not_equal_2_ID>> not_equal_2;
-        rule<ScannerT, parser_tag<node_name_ID>> nodename;
-
-        rule<ScannerT, parser_tag<greater_equals_1_ID>> greater_equals_1;
-        rule<ScannerT, parser_tag<greater_equals_2_ID>> greater_equals_2;
-        rule<ScannerT, parser_tag<less_equals_1_ID>> less_equals_1;
-        rule<ScannerT, parser_tag<less_equals_2_ID>> less_equals_2;
-
-        rule<ScannerT, parser_tag<less_than_1_ID>> less_than_1;
-        rule<ScannerT, parser_tag<less_than_2_ID>> less_than_2;
-        rule<ScannerT, parser_tag<greater_than_1_ID>> greater_than_1;
-        rule<ScannerT, parser_tag<greater_than_2_ID>> greater_than_2;
-
-        rule<ScannerT, parser_tag<node_state_unknown_ID>> node_state_unknown;
-        rule<ScannerT, parser_tag<node_state_complete_ID>> node_state_complete;
-        rule<ScannerT, parser_tag<node_state_queued_ID>> node_state_queued;
-        rule<ScannerT, parser_tag<node_state_submitted_ID>> node_state_submitted;
-        rule<ScannerT, parser_tag<node_state_active_ID>> node_state_active;
-        rule<ScannerT, parser_tag<node_state_aborted_ID>> node_state_aborted;
-
-        rule<ScannerT, parser_tag<not1_ID>> not1_r;
-        rule<ScannerT, parser_tag<not2_ID>> not2_r;
-        rule<ScannerT, parser_tag<not3_ID>> not3_r;
-        rule<ScannerT, parser_tag<and_ID>> and_r;
-        rule<ScannerT, parser_tag<or_ID>> or_r;
-
-        rule<ScannerT, parser_tag<dot_path_ID>> dotpath;
-        rule<ScannerT, parser_tag<dot_dot_path_ID>> dotdotpath;
-        rule<ScannerT, parser_tag<absolute_path_ID>> absolutepath;
-        rule<ScannerT, parser_tag<root_path_ID>> root_path;
-
-        rule<ScannerT, parser_tag<node_path_state_ID>> nodepathstate;
-
-        rule<ScannerT, parser_tag<event_state_ID>> event_state;
-        rule<ScannerT, parser_tag<variable_ID>> variable;
-
-        rule<ScannerT, parser_tag<calc_expression_ID>> calc_expression;
-        rule<ScannerT, parser_tag<calc_factor_ID>> calc_factor;
-        rule<ScannerT, parser_tag<calc_term_ID>> calc_term;
-        rule<ScannerT, parser_tag<calc_grouping_ID>> calc_grouping;
-        rule<ScannerT, parser_tag<calc_subexpression_ID>> calc_subexpression;
-        rule<ScannerT, parser_tag<basic_variable_path_ID>> basic_variable_path;
-        rule<ScannerT, parser_tag<parent_variable_ID>> parent_variable;
-        rule<ScannerT, parser_tag<compare_expression_ID>> compare_expression;
-
-        rule<ScannerT, parser_tag<flag_path_ID>> flag_path;
-        rule<ScannerT, parser_tag<flag_late_ID>> flag_late;
-        rule<ScannerT, parser_tag<flag_zombie_ID>> flag_zombie;
-        rule<ScannerT, parser_tag<flag_archived_ID>> flag_archived;
-        rule<ScannerT, parser_tag<flag_ID>> flag;
-
-        rule<ScannerT> not_r, less_than_comparable, expression, andExpr, operators;
-        rule<ScannerT> nodestate, equality_comparible, and_or, nodepath;
-
-        rule<ScannerT, parser_tag<datetime_ID>> datetime;
-
-        //        ‘*’   Zero or more
-        //        ‘!’   Zero or one
-        //        ‘+’   One or more
-        //        ‘>>’  Sequence/concatenation
-        //        ‘|’   alternate
-        //        ‘-‘   not
-        explicit definition(ExpressionGrammer const& /*self*/) {
-            nodename = leaf_node_d[lexeme_d[(alnum_p || ch_p('_')) >> *(alnum_p || ch_p('_') || ch_p('.'))]];
-
-            // Can be /suite/family/task ||  family/task ||   family
-
-            absolutepath = leaf_node_d[!(str_p("/")) >> nodename >> *(+str_p("/") >> nodename)];
-            dotdotpath // a kind of relative path
-                = leaf_node_d[str_p("..") >> *(+str_p("/") >> str_p("..")) >> +(+str_p("/") >> nodename)];
-
-            dotpath  = leaf_node_d[str_p(".") >> +(str_p("/") >> nodename)];
-            nodepath = absolutepath | dotdotpath | dotpath;
-
-            // Integer is distinct from task/family names that are integers, since nodes with integer
-            // names that occur in trigger/complete expression must have path ./0 ./1
-            integer   = leaf_node_d[uint_p];
-            plus      = root_node_d[str_p("+")];
-            minus     = root_node_d[str_p("-")];
-            divide    = root_node_d[str_p("/")];
-            multiply  = root_node_d[str_p("*")];
-            modulo    = root_node_d[str_p("%")];
-            operators = plus | minus | divide | multiply | modulo;
-
-            equal_1             = root_node_d[str_p("==")];
-            equal_2             = root_node_d[str_p("eq")];
-            not_equal_1         = root_node_d[str_p("!=")];
-            not_equal_2         = root_node_d[str_p("ne")];
-            equality_comparible = equal_1 | equal_2 | not_equal_2 | not_equal_1;
-
-            greater_equals_1 = root_node_d[str_p(">=")];
-            greater_equals_2 = root_node_d[str_p("ge")];
-            less_equals_1    = root_node_d[str_p("<=")];
-            less_equals_2    = root_node_d[str_p("le")];
-            less_than_1      = root_node_d[str_p("<")];
-            less_than_2      = root_node_d[str_p("lt")];
-            greater_than_1   = root_node_d[str_p(">")];
-            greater_than_2   = root_node_d[str_p("gt")];
-            // Prioritise to most common first, to speed up parsing
-            less_than_comparable = greater_equals_2 | less_equals_2 | greater_than_2 | less_than_2 | greater_equals_1 |
-                                   less_equals_1 | less_than_1 | greater_than_1;
-
-            not1_r = root_node_d[str_p("not ")];
-            not2_r = root_node_d[str_p("~")];
-            not3_r = root_node_d[str_p("!")];
-            not_r  = not1_r | not3_r | not2_r;
-
-            and_r  = root_node_d[str_p("and")] || root_node_d[str_p("&&")] || root_node_d[str_p("AND")];
-            or_r   = root_node_d[str_p("or")] || root_node_d[str_p("||")] || root_node_d[str_p("OR")];
-            and_or = and_r | or_r;
-
-            event_state = leaf_node_d[str_p("set")] || leaf_node_d[str_p("clear")];
-
-            node_state_unknown   = root_node_d[str_p("unknown")];
-            node_state_complete  = root_node_d[str_p("complete")];
-            node_state_queued    = root_node_d[str_p("queued")];
-            node_state_submitted = root_node_d[str_p("submitted")];
-            node_state_active    = root_node_d[str_p("active")];
-            node_state_aborted   = root_node_d[str_p("aborted")];
-            nodestate            = node_state_complete | node_state_aborted | node_state_queued | node_state_active |
-                        node_state_submitted | node_state_unknown;
-
-            flag_late     = root_node_d[str_p("late")];
-            flag_zombie   = root_node_d[str_p("zombie")];
-            flag_archived = root_node_d[str_p("archived")];
-            flag          = flag_late | flag_zombie | flag_archived;
-
-            variable            = leaf_node_d[nodename];
-            basic_variable_path = nodepath >> discard_node_d[ch_p(':')] >> variable;
-            parent_variable =
-                ch_p(':') >> variable; // if we discard_node, then we get just 'variable' and NOT parent_variable
-
-            root_path = leaf_node_d[(str_p("/"))];
-            flag_path = (nodepath | root_path) >> discard_node_d[str_p("<flag>")] >> flag;
-
-            cal_argument = basic_variable_path | integer;
-            cal_date_to_julian =
-                str_p("cal::date_to_julian") >> discard_node_d[ch_p('(')] >> cal_argument >> discard_node_d[ch_p(')')];
-            cal_julian_to_date =
-                str_p("cal::julian_to_date") >> discard_node_d[ch_p('(')] >> cal_argument >> discard_node_d[ch_p(')')];
-            datetime = leaf_node_d[lexeme_d[repeat_p(8)[digit_p] >> 'T' >> repeat_p(6)[digit_p]]];
-
-            calc_factor = datetime | integer | basic_variable_path |
-                          discard_node_d[ch_p('(')] >> calc_expression >> discard_node_d[ch_p(')')] | flag_path |
-                          parent_variable | root_node_d[operators] >> calc_factor | cal_date_to_julian |
-                          cal_julian_to_date;
-            calc_term       = calc_factor >> *(root_node_d[operators] >> calc_factor);
-            calc_expression = calc_term >> *(root_node_d[operators] >> calc_term);
-
-            nodepathstate = nodepath >> equality_comparible >> nodestate;
-
-            compare_expression = nodepathstate | basic_variable_path >> equality_comparible >> event_state |
-                                 root_node_d[calc_expression >> *((equality_comparible | less_than_comparable) >>
-                                                                  (!not_r >> calc_expression))];
-
-            // We need to take special care so that 'and' has a higher priority than 'or'
-            // (( This is done by have a custom rule for the and
-            andExpr = !not_r >> compare_expression >> *(and_r >> !not_r >> compare_expression);
-
-            calc_grouping = !not_r >> discard_node_d[ch_p('(')] >> calc_subexpression >> discard_node_d[ch_p(')')];
-
-            calc_subexpression = (andExpr | calc_grouping) >> *((and_r | or_r) >> calc_subexpression);
-
-            expression = calc_subexpression >> end_p;
-
-            BOOST_SPIRIT_DEBUG_NODE(cal_argument);
-            BOOST_SPIRIT_DEBUG_NODE(cal_date_to_julian);
-            BOOST_SPIRIT_DEBUG_NODE(andExpr);
-            BOOST_SPIRIT_DEBUG_NODE(not_r);
-            BOOST_SPIRIT_DEBUG_NODE(not1_r);
-            BOOST_SPIRIT_DEBUG_NODE(not2_r);
-            BOOST_SPIRIT_DEBUG_NODE(expression);
-            BOOST_SPIRIT_DEBUG_NODE(nodename);
-            BOOST_SPIRIT_DEBUG_NODE(nodepath);
-            BOOST_SPIRIT_DEBUG_NODE(dotdotpath);
-            BOOST_SPIRIT_DEBUG_NODE(dotpath);
-            BOOST_SPIRIT_DEBUG_NODE(absolutepath);
-            BOOST_SPIRIT_DEBUG_NODE(less_than_comparable);
-            BOOST_SPIRIT_DEBUG_NODE(nodestate);
-            BOOST_SPIRIT_DEBUG_NODE(equality_comparible);
-            BOOST_SPIRIT_DEBUG_NODE(equal_1);
-            BOOST_SPIRIT_DEBUG_NODE(equal_2);
-            BOOST_SPIRIT_DEBUG_NODE(not_equal_1);
-            BOOST_SPIRIT_DEBUG_NODE(not_equal_2);
-            BOOST_SPIRIT_DEBUG_NODE(and_or);
-            BOOST_SPIRIT_DEBUG_NODE(plus);
-            BOOST_SPIRIT_DEBUG_NODE(minus);
-            BOOST_SPIRIT_DEBUG_NODE(divide);
-            BOOST_SPIRIT_DEBUG_NODE(multiply);
-            BOOST_SPIRIT_DEBUG_NODE(modulo);
-            BOOST_SPIRIT_DEBUG_NODE(nodepathstate);
-            BOOST_SPIRIT_DEBUG_NODE(integer);
-            BOOST_SPIRIT_DEBUG_NODE(event_state);
-            BOOST_SPIRIT_DEBUG_NODE(variable);
-            BOOST_SPIRIT_DEBUG_NODE(basic_variable_path);
-            BOOST_SPIRIT_DEBUG_NODE(parent_variable);
-            BOOST_SPIRIT_DEBUG_NODE(flag_path);
-            BOOST_SPIRIT_DEBUG_NODE(calc_factor);
-            BOOST_SPIRIT_DEBUG_NODE(calc_expression);
-            BOOST_SPIRIT_DEBUG_NODE(calc_term);
-            BOOST_SPIRIT_DEBUG_NODE(compare_expression);
-            BOOST_SPIRIT_DEBUG_NODE(datetime);
-        };
-
-        rule<ScannerT> const& start() const { return expression; }
-    };
-};
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
-void print(tree_parse_info<> info, const std::string& expr, const std::map<parser_id, std::string>& rule_names);
-
-AstTop* createTopAst(tree_parse_info<> info,
-                     const std::string& expr,
-                     const std::map<parser_id, std::string>& rule_names,
-                     std::string& error_msg);
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
-ExprParser::ExprParser(const std::string& expression) : expr_(expression) {
-}
-
-static std::map<parser_id, std::string> rule_names;
-static void populate_rule_names() {
-    if (rule_names.empty()) {
-        rule_names[ExpressionGrammer::cal_date_to_julian_ID]   = "cal_date_to_julian";
-        rule_names[ExpressionGrammer::cal_julian_to_date_ID]   = "cal_julian_to_date";
-        rule_names[ExpressionGrammer::cal_argument_ID]         = "cal_argument";
-        rule_names[ExpressionGrammer::modulo_ID]               = "MODULO";
-        rule_names[ExpressionGrammer::equal_1_ID]              = "EQUALS";
-        rule_names[ExpressionGrammer::equal_2_ID]              = "EQUALS";
-        rule_names[ExpressionGrammer::not_equal_1_ID]          = "NOT_EQUAL";
-        rule_names[ExpressionGrammer::not_equal_2_ID]          = "NOT_EQUAL";
-        rule_names[ExpressionGrammer::greater_equals_1_ID]     = "GREATER_THAN_OR_EQUALS";
-        rule_names[ExpressionGrammer::greater_equals_2_ID]     = "GREATER_THAN_OR_EQUALS";
-        rule_names[ExpressionGrammer::less_equals_1_ID]        = "LESS_THAN_OR_EQUALS";
-        rule_names[ExpressionGrammer::less_equals_2_ID]        = "LESS_THAN_OR_EQUALS";
-        rule_names[ExpressionGrammer::less_than_1_ID]          = "LESS_THAN";
-        rule_names[ExpressionGrammer::less_than_2_ID]          = "LESS_THAN";
-        rule_names[ExpressionGrammer::greater_than_1_ID]       = "GREATER_THAN";
-        rule_names[ExpressionGrammer::greater_than_2_ID]       = "GREATER_THAN";
-        rule_names[ExpressionGrammer::not1_ID]                 = "NOT";
-        rule_names[ExpressionGrammer::not2_ID]                 = "NOT";
-        rule_names[ExpressionGrammer::not3_ID]                 = "NOT";
-        rule_names[ExpressionGrammer::and_ID]                  = "AND";
-        rule_names[ExpressionGrammer::or_ID]                   = "OR";
-        rule_names[ExpressionGrammer::node_name_ID]            = "NODE_NAME";
-        rule_names[ExpressionGrammer::node_state_unknown_ID]   = "UNKNOWN";
-        rule_names[ExpressionGrammer::node_state_complete_ID]  = "COMPLETE";
-        rule_names[ExpressionGrammer::node_state_queued_ID]    = "QUEUED";
-        rule_names[ExpressionGrammer::node_state_submitted_ID] = "SUBMITTED";
-        rule_names[ExpressionGrammer::node_state_active_ID]    = "ACTIVE";
-        rule_names[ExpressionGrammer::node_state_aborted_ID]   = "ABORTED";
-        rule_names[ExpressionGrammer::integer_ID]              = "INTEGER";
-        rule_names[ExpressionGrammer::dot_path_ID]             = "DOT_PATH";
-        rule_names[ExpressionGrammer::dot_dot_path_ID]         = "DOT_DOT_PATH";
-        rule_names[ExpressionGrammer::absolute_path_ID]        = "ABSOLUTE_PATH";
-
-        rule_names[ExpressionGrammer::base_trigger_ID]    = "BASE_TRIGGER";
-        rule_names[ExpressionGrammer::sub_expression_ID]  = "SUB_EXPRESSION";
-        rule_names[ExpressionGrammer::node_path_state_ID] = "NODE_PATH_STATE";
-        rule_names[ExpressionGrammer::flag_path_ID]       = "FLAG_PATH";
-
-        rule_names[ExpressionGrammer::event_state_ID] = "STRING";
-        rule_names[ExpressionGrammer::variable_ID]    = "VARIABLE";
-
-        rule_names[ExpressionGrammer::calc_expression_ID]     = "calc_expression_ID";
-        rule_names[ExpressionGrammer::calc_factor_ID]         = "calc_factor_ID";
-        rule_names[ExpressionGrammer::calc_term_ID]           = "calc_term_ID";
-        rule_names[ExpressionGrammer::calc_grouping_ID]       = "calc_grouping_ID";
-        rule_names[ExpressionGrammer::calc_subexpression_ID]  = "calc_subexpression_ID";
-        rule_names[ExpressionGrammer::basic_variable_path_ID] = "basic_variable_path_ID";
-        rule_names[ExpressionGrammer::parent_variable_ID]     = "parent_variable_ID";
-        rule_names[ExpressionGrammer::compare_expression_ID]  = "compare_expression_ID";
-
-        rule_names[ExpressionGrammer::datetime_ID] = "datetime";
-    }
-}
-
-bool ExprParser::doParse(std::string& errorMsg) {
-    if (expr_.empty()) {
-        errorMsg = "Expression is empty";
-        return false;
-    }
-
-    // =========================================================================
-    // For large designs > 90% of triggers are identical.
-    // We take advantage of this by only parsing the expression once
-    // and storing then Abstract Syntax tree( via cloning ) using a map
-    // This saves a huge amount of CPU time in re-parsing using spirit classic.
-    // =========================================================================
-    ast_ = ExprDuplicate::find(expr_);
-    if (ast_.get()) {
-        return true;
-    }
-
-    SimpleExprParser simpleParser(expr_);
-    if (simpleParser.doParse()) {
-        ast_ = simpleParser.ast();
-        ExprDuplicate::add(expr_, ast_.get()); // bypass spirit if same expression used
-        return true;
-    }
-
-    // SPIRIT CLASSIC parsing: very slooooow....
-    ExpressionGrammer grammer;
-    BOOST_SPIRIT_DEBUG_NODE(grammer);
-
-    // Use parser to generates a Boost.Spirit Abstract Syntax Tree (AST)
-    tree_parse_info<> info = ast_parse(expr_.c_str(), grammer, space_p);
-    if (info.full) {
-
-        populate_rule_names();
-
-#if defined(BOOST_SPIRIT_DUMP_PARSETREE_AS_XML)
-        tree_to_xml(cout, info.trees, expr_.c_str(), rule_names);
-#endif
-#if defined(PRINT_TREE)
-        print(info, expr_, rule_names);
-#endif
-        // Boost.Spirit has created an AST for us.
-        // However, it is not usable as is, so we will traverse the AST and create our OWN `Ast*` classes.
-        ast_.reset(createTopAst(info, expr_, rule_names, errorMsg));
-        if (ast_.get() && errorMsg.empty()) {
-            ExprDuplicate::add(expr_, ast_.get());
-        }
-        return errorMsg.empty();
-    }
-    else {
-        std::stringstream ss;
-        ss << "Parsing failed\n";
-        ss << "length = " << std::dec << info.length << "\n";
-        ss << "stopped at: \": " << info.stop << "\"\n";
-        errorMsg = ss.str();
-    }
-    return false;
-}
-
-// The evaluation function for the AST
-void do_print(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names) {
-    Indentor in;
-    auto iter = rule_names.find(i->value.id());
-    if (iter != rule_names.end()) {
-        Indentor::indent(cout) << "Rule " << (*iter).second << "(size:" << i->children.size() << ")"
-                               << "  " << string(i->value.begin(), i->value.end()) << endl;
-    }
-    else {
-        Indentor::indent(cout) << "Unknown rule(id:" << i->value.id().to_long() << ")"
-                               << "(size:" << i->children.size() << ")"
-                               << "  " << string(i->value.begin(), i->value.end()) << endl;
-    }
-
-    Indentor in2;
-    for (auto t = i->children.begin(); t != i->children.end(); ++t) {
-        do_print(t, rule_names);
-    }
-}
-
-void print(tree_parse_info<> info, const std::string& expr, const std::map<parser_id, std::string>& rule_names) {
-    std::cout << "\nPRINT_TREE  " << expr << "\n";
-    do_print(info.trees.begin(), rule_names);
-}
-
-////////////////////////////////////////////////////////////////////////////////////////////////
-
-AstRoot* createRootNode(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names) {
-#if defined(PRINT_AST_TRAVERSAL)
-    Indentor in;
-    std::map<parser_id, std::string>::const_iterator iter = rule_names.find(i->value.id());
-    if (iter != rule_names.end()) {
-        Indentor::indent(cout) << "Root Rule " << (*iter).second << "(" << i->children.size() << ")"
-                               << "  " << string(i->value.begin(), i->value.end()) << endl;
-    }
-    else {
-        Indentor::indent(cout) << "Unknown root rule "
-                               << "(" << i->children.size() << ")"
-                               << "  " << string(i->value.begin(), i->value.end()) << endl;
-    }
-#endif
-
-    if (i->value.id() == ExpressionGrammer::equal_1_ID)
-        return new AstEqual();
-    if (i->value.id() == ExpressionGrammer::equal_2_ID)
-        return new AstEqual();
-    if (i->value.id() == ExpressionGrammer::and_ID)
-        return new AstAnd();
-    if (i->value.id() == ExpressionGrammer::or_ID)
-        return new AstOr();
-    // Needed so that testing , when recreating expression uses same name for not.
-    if (i->value.id() == ExpressionGrammer::not1_ID) {
-        auto* astnot = new AstNot();
-        astnot->set_root_name("not ");
-        return astnot;
-    }
-    if (i->value.id() == ExpressionGrammer::not2_ID) {
-        auto* astnot = new AstNot();
-        astnot->set_root_name("~ ");
-        return astnot;
-    }
-    if (i->value.id() == ExpressionGrammer::not3_ID) {
-        auto* astnot = new AstNot();
-        astnot->set_root_name("! ");
-        return astnot;
-    }
-    if (i->value.id() == ExpressionGrammer::plus_ID)
-        return new AstPlus();
-
-    if (i->value.id() == ExpressionGrammer::not_equal_1_ID)
-        return new AstNotEqual();
-    if (i->value.id() == ExpressionGrammer::not_equal_2_ID)
-        return new AstNotEqual();
-    if (i->value.id() == ExpressionGrammer::greater_equals_1_ID)
-        return new AstGreaterEqual();
-    if (i->value.id() == ExpressionGrammer::greater_equals_2_ID)
-        return new AstGreaterEqual();
-    if (i->value.id() == ExpressionGrammer::less_equals_1_ID)
-        return new AstLessEqual();
-    if (i->value.id() == ExpressionGrammer::less_equals_2_ID)
-        return new AstLessEqual();
-    if (i->value.id() == ExpressionGrammer::less_than_1_ID)
-        return new AstLessThan();
-    if (i->value.id() == ExpressionGrammer::less_than_2_ID)
-        return new AstLessThan();
-    if (i->value.id() == ExpressionGrammer::greater_than_1_ID)
-        return new AstGreaterThan();
-    if (i->value.id() == ExpressionGrammer::greater_than_2_ID)
-        return new AstGreaterThan();
-
-    if (i->value.id() == ExpressionGrammer::minus_ID)
-        return new AstMinus();
-    if (i->value.id() == ExpressionGrammer::multiply_ID)
-        return new AstMultiply();
-    if (i->value.id() == ExpressionGrammer::divide_ID)
-        return new AstDivide();
-    if (i->value.id() == ExpressionGrammer::modulo_ID)
-        return new AstModulo();
-    LOG_ASSERT(false, "");
-    return nullptr;
-}
-
-// static bool is_node_state(const tree_iter_t& i) {
-//    if ( i->value.id() == ExpressionGrammer::node_state_unknown_ID  ) return true;
-//    if ( i->value.id() == ExpressionGrammer::node_state_complete_ID  ) return true;
-//    if ( i->value.id() == ExpressionGrammer::node_state_queued_ID  ) return true;
-//    if ( i->value.id() == ExpressionGrammer::node_state_submitted_ID  ) return true;
-//    if ( i->value.id() == ExpressionGrammer::node_state_active_ID  ) return true;
-//    if ( i->value.id() == ExpressionGrammer::node_state_aborted_ID  ) return true;
-//    return false;
-// }
-// static bool has_child_node_state(const tree_iter_t& i) {
-//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
-//       if (is_node_state(t)) return true;
-//    }
-//    return false;
-// }
-// static bool has_child_event_state(const tree_iter_t& i) {
-//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
-//       if ( t->value.id() == ExpressionGrammer::event_state_ID) return true;
-//    }
-//    return false;
-// }
-// static bool child_has_path(const tree_iter_t& i) {
-//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
-//       if ( t->value.id() == ExpressionGrammer::dot_path_ID ) return true;
-//       if ( t->value.id() == ExpressionGrammer::dot_dot_path_ID ) return true;
-//       if ( t->value.id() == ExpressionGrammer::absolute_path_ID ) return true;
-//    }
-//    return false;
-// }
-// static bool is_comparable(const tree_iter_t& i) {
-//    if ( i->value.id() == ExpressionGrammer::equal_1_ID ) return true;
-//    if ( i->value.id() == ExpressionGrammer::equal_2_ID ) return true;
-//    if ( i->value.id() == ExpressionGrammer::not_equal_1_ID ) return true;
-//    if ( i->value.id() == ExpressionGrammer::not_equal_2_ID ) return true;
-//    return false;
-// }
-// static bool has_child_not(const tree_iter_t& i) {
-//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
-//       if (is_not(t)) return true;
-//    }
-//    return false;
-// }
-
-static bool is_not(const tree_iter_t& i) {
-    if (i->value.id() == ExpressionGrammer::not1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::not2_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::not3_ID)
-        return true;
-    return false;
-}
-static bool child_has(const tree_iter_t& i, int id) {
-    for (auto& t : i->children) {
-        if (t.value.id() == id)
-            return true;
-    }
-    return false;
-}
-static bool is_root_node(const tree_iter_t& i) {
-    if (i->value.id() == ExpressionGrammer::equal_1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::equal_2_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::and_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::or_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::not1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::not2_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::not3_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::plus_ID)
-        return true;
-
-    if (i->value.id() == ExpressionGrammer::not_equal_1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::not_equal_2_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::greater_equals_1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::greater_equals_2_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::less_equals_1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::less_equals_2_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::less_than_1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::less_than_2_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::greater_than_1_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::greater_than_2_ID)
-        return true;
-
-    if (i->value.id() == ExpressionGrammer::minus_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::multiply_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::divide_ID)
-        return true;
-    if (i->value.id() == ExpressionGrammer::modulo_ID)
-        return true;
-    return false;
-}
-
-Ast* createAst(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names) {
-#if defined(PRINT_AST_TRAVERSAL)
-    Indentor in;
-    std::map<parser_id, std::string>::const_iterator iter = rule_names.find(i->value.id());
-    if (iter != rule_names.end()) {
-        Indentor::indent(cout) << "Create AST Rule " << (*iter).second << "(" << i->children.size() << ")"
-                               << "  '" << string(i->value.begin(), i->value.end()) << "'\n";
-    }
-    else {
-        Indentor::indent(cout) << "Create AST Unknown rule "
-                               << "(" << i->children.size() << ")"
-                               << "  '" << string(i->value.begin(), i->value.end()) << "'\n";
-    }
-#endif
-
-    if (i->value.id() == ExpressionGrammer::node_name_ID) {
-
-        string thevalue(i->value.begin(), i->value.end());
-        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
-        LOG_ASSERT(!thevalue.empty(), "");
-        return new AstNode(thevalue);
-    }
-    else if (i->value.id() == ExpressionGrammer::node_state_complete_ID) {
-
-        return new AstNodeState(DState::COMPLETE);
-    }
-    else if (i->value.id() == ExpressionGrammer::basic_variable_path_ID) {
-        LOG_ASSERT((i->children.size() == 2), "");
-        auto theNodePathIter = i->children.begin();
-        auto theNameIter     = i->children.begin() + 1;
-
-        string nodePath(theNodePathIter->value.begin(), theNodePathIter->value.end());
-        string name(theNameIter->value.begin(), theNameIter->value.end());
-        ecf::algorithm::trim(nodePath); // don't know why we get leading/trailing spaces
-        ecf::algorithm::trim(name);     // don't know why we get leading/trailing spaces
-        return new AstVariable(nodePath, name);
-    }
-    else if (i->value.id() == ExpressionGrammer::parent_variable_ID) {
-
-        // tree_iter_t the_colon = i->children.begin(); ignore
-        auto the_variable_t = i->children.begin() + 1;
-
-        string the_variable(the_variable_t->value.begin(), the_variable_t->value.end());
-        ecf::algorithm::trim(the_variable); // don't know why we get leading/trailing spaces
-        LOG_ASSERT(!the_variable.empty(), "");
-        return new AstParentVariable(the_variable);
-    }
-    else if (i->value.id() == ExpressionGrammer::dot_dot_path_ID) {
-
-        string thevalue(i->value.begin(), i->value.end());
-        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
-        LOG_ASSERT(!thevalue.empty(), "");
-        return new AstNode(thevalue);
-    }
-    if (i->value.id() == ExpressionGrammer::absolute_path_ID) {
-
-        string thevalue(i->value.begin(), i->value.end());
-        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
-        LOG_ASSERT(!thevalue.empty(), "");
-        return new AstNode(thevalue);
-    }
-    else if (i->value.id() == ExpressionGrammer::dot_path_ID) {
-
-        string thevalue(i->value.begin(), i->value.end());
-        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
-        LOG_ASSERT(!thevalue.empty(), "");
-        return new AstNode(thevalue);
-    }
-    else if (i->value.id() == ExpressionGrammer::event_state_ID) {
-
-        string thevalue(i->value.begin(), i->value.end());
-        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
-        if (thevalue == Event::SET())
-            return new AstEventState(true);
-        assert(thevalue == Event::CLEAR());
-        return new AstEventState(false);
-    }
-    else if (i->value.id() == ExpressionGrammer::datetime_ID) {
-
-        string thevalue(std::begin(i->value), std::end(i->value));
-        ecf::Instant instant = Instant::parse(thevalue);
-        return new AstInstant(instant);
-    }
-    else if (i->value.id() == ExpressionGrammer::integer_ID) {
-
-        string thevalue(i->value.begin(), i->value.end());
-        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
-        auto theInt = ecf::convert_to<int>(thevalue);
-        return new AstInteger(theInt);
-    }
-    else if (i->value.id() == ExpressionGrammer::node_state_aborted_ID) {
-
-        return new AstNodeState(DState::ABORTED);
-    }
-    else if (i->value.id() == ExpressionGrammer::node_state_active_ID) {
-
-        return new AstNodeState(DState::ACTIVE);
-    }
-    else if (i->value.id() == ExpressionGrammer::node_state_queued_ID) {
-
-        return new AstNodeState(DState::QUEUED);
-    }
-    else if (i->value.id() == ExpressionGrammer::node_state_submitted_ID) {
-
-        return new AstNodeState(DState::SUBMITTED);
-    }
-    else if (i->value.id() == ExpressionGrammer::node_state_unknown_ID) {
-
-        return new AstNodeState(DState::UNKNOWN);
-    }
-    else if (i->value.id() == ExpressionGrammer::cal_date_to_julian_ID) {
-
-        LOG_ASSERT((i->children.size() == 2), ""); // 1st is function, 2nd is arg(integer | basic variable path)
-
-        return new AstFunction(AstFunction::DATE_TO_JULIAN, createAst(i->children.begin() + 1, rule_names));
-    }
-    else if (i->value.id() == ExpressionGrammer::cal_julian_to_date_ID) {
-
-        LOG_ASSERT((i->children.size() == 2), ""); // 1st is function, 2nd is arg(integer | basic variable path)
-
-        return new AstFunction(AstFunction::JULIAN_TO_DATE, createAst(i->children.begin() + 1, rule_names));
-    }
-    else if (i->value.id() == ExpressionGrammer::flag_path_ID) {
-
-        LOG_ASSERT((i->children.size() == 2), "");
-        auto theNodePathIter = i->children.begin();
-        auto theFlagIter     = i->children.begin() + 1;
-
-        string nodePath(theNodePathIter->value.begin(), theNodePathIter->value.end());
-        string flag(theFlagIter->value.begin(), theFlagIter->value.end());
-        ecf::algorithm::trim(nodePath); // don't know why we get leading/trailing spaces
-        ecf::algorithm::trim(flag);     // don't know why we get leading/trailing spaces
-
-        return new AstFlag(nodePath, ecf::Flag::string_to_flag_type(flag));
-    }
-    return nullptr;
-}
-
-// The evaluation function for the AST
-Ast* doCreateAst(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names, Ast* top) {
-#if defined(PRINT_AST_TRAVERSAL)
-    Indentor in;
-    std::map<parser_id, std::string>::const_iterator iter = rule_names.find(i->value.id());
-    if (iter != rule_names.end()) {
-        Indentor::indent(cout) << "Rule " << (*iter).second << " (" << i->children.size() << ")"
-                               << "  " << string(i->value.begin(), i->value.end()) << endl;
-    }
-    else {
-        Indentor::indent(cout) << "Unknown rule "
-                               << "(" << i->children.size() << ")"
-                               << "  " << string(i->value.begin(), i->value.end()) << endl;
-    }
-#endif
-
-    Indentor in2;
-    if (i->children.size() == 3) {
-        // child 1: left                0
-        // child 2: root(i.e ==,!=)    +1
-        // child 3: right              +2
-
-        // cout << "i->children.size() == 3 ======================== \n";
-        AstRoot* someRoot = createRootNode(i->children.begin() + 1, rule_names);
-        if (someRoot) {
-            Ast* left = doCreateAst(i->children.begin(), rule_names, someRoot);
-            if (left)
-                someRoot->addChild(left);
-            Ast* right = doCreateAst(i->children.begin() + 2, rule_names, someRoot);
-            if (right)
-                someRoot->addChild(right);
-
-            if (top)
-                top->addChild(someRoot);
-            else
-                return someRoot;
-        }
-    }
-    else if (is_root_node(i) && i->children.size() == 2) {
-
-        // cout << "is_root_node(i) && i->children.size() == 2\n";
-        AstRoot* someRoot = createRootNode(i, rule_names);
-
-        Ast* left = doCreateAst(i->children.begin(), rule_names, someRoot);
-        if (left)
-            someRoot->addChild(left);
-        Ast* right = doCreateAst(i->children.begin() + 1, rule_names, someRoot);
-        if (right)
-            someRoot->addChild(right);
-
-        if (top)
-            top->addChild(someRoot);
-        else
-            return someRoot;
-    }
-    else if (i->children.size() == 4 && is_not(i->children.begin())) {
-        // child 0: notRoot                 0
-        // child 1: notChild               +1
-        // child 2: someRoot(i.e ==,!=)    +2
-        // child 3: right                  +3
-        // Create as:         someRoot
-        //              notRoot          right
-        //      notChild
-        // cout << "(i->children.size() == 4 && is_not(i->children.begin()))\n";
-
-        LOG_ASSERT(is_not(i->children.begin()), "");
-        AstRoot* notRoot = createRootNode(i->children.begin(), rule_names);
-
-        Ast* notChild = doCreateAst(i->children.begin() + 1, rule_names, notRoot /*top*/);
-        if (notChild)
-            notRoot->addChild(notChild);
-
-        AstRoot* someRoot = createRootNode(i->children.begin() + 2, rule_names);
-        someRoot->addChild(notRoot); // left
-
-        Ast* right = doCreateAst(i->children.begin() + 3, rule_names, someRoot /* top*/);
-        if (right)
-            someRoot->addChild(right);
-        if (top)
-            top->addChild(someRoot);
-        else
-            return someRoot;
-    }
-    else if (i->children.size() == 4 && is_root_node(i->children.begin() + 1) && is_not(i->children.begin() + 2)) {
-        // child 0: child                   0
-        // child 1: someRoot(i.e ==,!=)    +1
-        // child 2: NOT                    +2
-        // child 3: integer | variable     +3
-        //
-        // Create as:         someRoot
-        //              child          notRoot
-        //                                    notChild
-        // cout << "(i->children.size() == 4 && is_root_node(i->children.begin()+1) && is_not(i->children.begin()+2)
-        // )\n";
-        AstRoot* someRoot = createRootNode(i->children.begin() + 1, rule_names);
-        Ast* varPath      = doCreateAst(i->children.begin(), rule_names, someRoot /*top*/);
-        if (varPath)
-            someRoot->addChild(varPath); // left
-
-        AstRoot* notRoot = createRootNode(i->children.begin() + 2, rule_names);
-        someRoot->addChild(notRoot); // right
-
-        Ast* notChild = doCreateAst(i->children.begin() + 3, rule_names, notRoot /*top*/);
-        if (notChild)
-            notRoot->addChild(notChild);
-
-        if (top)
-            top->addChild(someRoot);
-        else
-            return someRoot;
-    }
-    else if (i->children.size() == 2 && is_not(i->children.begin())) {
-        // child 1: not     0
-        // child 2: left   +1
-        // cout << "(i->children.size() == 2 && is_not(i->children.begin()) )\n";
-
-        AstRoot* notRoot = createRootNode(i->children.begin(), rule_names);
-
-        if (child_has(i, ExpressionGrammer::basic_variable_path_ID)) {
-            // special case where we treat as a event i.e ! ../../../prod2diss/operation_is_late:yes
-            notRoot->addChild(createAst(i->children.begin() + 1, rule_names));
-        }
-        else {
-            Ast* left = doCreateAst(i->children.begin() + 1, rule_names, notRoot);
-            if (left)
-                notRoot->addChild(left);
-        }
-
-        if (top)
-            top->addChild(notRoot);
-        else
-            return notRoot;
-    }
-    else if (i->children.size() >= 5) {
-        // Must be multiple and's could have nots  Could have:
-        //     !a and b
-        //      a and !b
-        // We always treat the not as *child*
-        // cout << "(i->children.size() >=5 ) \n";
-        stack<Ast*> childs;
-        stack<Ast*> parents;
-        Ast* not_ast = nullptr;
-        for (auto t = i->children.begin(); t != i->children.end(); ++t) {
-            if (is_root_node(t) && !is_not(t)) {
-                Ast* and_ast = createRootNode(t, rule_names);
-                assert(and_ast);
-                assert(parents.empty());
-                parents.push(and_ast);
-            }
-            else {
-                if (is_not(t)) {
-                    assert(!not_ast);
-                    not_ast = createRootNode(t, rule_names);
-                    assert(not_ast);
-                    childs.push(not_ast);
-                }
-                else {
-                    Ast* child_ast = doCreateAst(t, rule_names, /*Top*/ nullptr);
-                    assert(child_ast);
-                    if (not_ast) {
-                        not_ast->addChild(child_ast);
-                        not_ast = nullptr;
-                    }
-                    else {
-                        childs.push(child_ast);
-                    }
-                }
-            }
-
-            if (parents.size() == 1 && childs.size() == 2) {
-                Ast* parent = parents.top();
-                parents.pop();
-                Ast* child1 = childs.top();
-                childs.pop();
-                Ast* child2 = childs.top();
-                childs.pop();
-                parent->addChild(child2);
-                parent->addChild(child1);
-                assert(parents.empty() && childs.empty());
-                childs.push(parent);
-            }
-        }
-        assert(top);
-        assert(childs.size() == 1);
-        if (top)
-            top->addChild(childs.top());
-    }
-    else {
-        // cout <<
-        // "JJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJ\n";
-        Ast* child = createAst(i, rule_names);
-        if (top && child)
-            top->addChild(child);
-        else
-            return child;
-    }
-    return nullptr;
-}
-
-AstTop* createTopAst(tree_parse_info<> info,
-                     const std::string& expr,
-                     const std::map<parser_id, std::string>& rule_names,
-                     std::string& error_msg) {
-#if defined(PRINT_AST_TRAVERSAL)
-    std::cout << "\nPRINT_AST_TRAVERSAL  " << expr << "\n";
-#endif
-
-    std::unique_ptr<AstTop> ast = std::make_unique<AstTop>();
-    try {
-        (void)doCreateAst(info.trees.begin(), rule_names, ast.get());
-    }
-    catch (std::runtime_error& error) {
-        error_msg = error.what();
-        return nullptr;
-    }
-
-    if (!ast->is_valid_ast(error_msg)) {
-        return nullptr;
-    }
-
-#if defined(PRINT_AST)
-    if (ast.get()) {
-        std::stringstream s2;
-        ast->print_flat(s2, true /*add_brackets*/);
-        std::cout << "\nPRINT_AST  " << s2.str() << "\n";
-        std::cout << "PRINT_AST  " << expr << "\n";
-        std::cout << *ast.get();
-    }
-#endif
-    return ast.release();
-}
-
-///////////////////////////////////////////////////////////////////////////
-// SimpleExprParser
-//////////////////////////////////////////////////////////////////////////
-
-bool has_complex_expressions(const std::string& expr) {
-    // we allow . and /
-    if (expr.find('(') != string::npos)
-        return true;
-    if (expr.find(':') != string::npos)
-        return true;
-    if (expr.find('.') != string::npos)
-        return true;
-    if (expr.find('/') != string::npos)
-        return true;
-    if (expr.find(" not ") != string::npos)
-        return true;
-    if (expr.find(" and ") != string::npos)
-        return true;
-    if (expr.find(" or ") != string::npos)
-        return true;
-    if (expr.find('!') != string::npos)
-        return true;
-    if (expr.find("&&") != string::npos)
-        return true;
-    if (expr.find("||") != string::npos)
-        return true;
-    if (expr.find('<') != string::npos)
-        return true;
-    if (expr.find('>') != string::npos)
-        return true;
-    if (expr.find('+') != string::npos)
-        return true;
-    if (expr.find('-') != string::npos)
-        return true;
-    if (expr.find('*') != string::npos)
-        return true;
-    if (expr.find('~') != string::npos)
-        return true;
-    if (expr.find(" ne ") != string::npos)
-        return true;
-    if (expr.find(" ge ") != string::npos)
-        return true;
-    if (expr.find("<=") != string::npos)
-        return true;
-    if (expr.find(">=") != string::npos)
-        return true;
-    if (expr.find(" le ") != string::npos)
-        return true;
-    if (expr.find(" gt ") != string::npos)
-        return true;
-    if (expr.find(" lt ") != string::npos)
-        return true;
-    return false;
-}
-
-bool SimpleExprParser::doParse() {
-    // 3199.def 57Mg
-    // a == b, || a eq b i.e simple  76940
-    // complex                       39240
-    if (has_complex_expressions(expr_)) {
-        return false;
-    }
-
-    // look for path == <state> || path eq state
-    // This gets round issue with Str::split:
-    //   "a = complete" will be split
-    // since will split on *ANY* of character, and hence this would not be reported as an error
-    std::vector<std::string> tokens;
-    if (expr_.find("==") != string::npos) {
-        Str::split(expr_, tokens, "==");
-    }
-    else if (expr_.find(" eq ") != string::npos) {
-        Str::split(expr_, tokens, " eq ");
-    }
-    else {
-        return false;
-    }
-
-    if (tokens.size() == 2) {
-
-        ecf::algorithm::trim(tokens[0]);
-        ecf::algorithm::trim(tokens[1]);
-
-        if (tokens[0].find(' ') != string::npos) {
-            //         cout << "Found space " << expr_ << "\n";
-            return false;
-        }
-
-        if (DState::isValid(tokens[1])) {
-
-            ast_          = std::make_unique<AstTop>();
-            Ast* someRoot = new AstEqual();
-            someRoot->addChild(new AstNode(tokens[0]));
-            someRoot->addChild(new AstNodeState(DState::toState(tokens[1])));
-            ast_->addChild(someRoot);
-            //       cout << "simple expr : " << expr_ << " `" << tokens[0] << "' = '" << tokens[1] << "'\n";
-            return true;
-        }
-        else {
-            try {
-                auto left     = ecf::convert_to<int>(tokens[0]);
-                auto right    = ecf::convert_to<int>(tokens[1]);
-                ast_          = std::make_unique<AstTop>();
-                Ast* someRoot = new AstEqual();
-                someRoot->addChild(new AstInteger(left));
-                someRoot->addChild(new AstInteger(right));
-                ast_->addChild(someRoot);
-                //               cout << "simple INT expr : " << expr_ << " `" << tokens[0] << "' = '" << tokens[1] <<
-                //               "'\n";
-                return true;
-            }
-            catch (const ecf::bad_conversion&) {
-                //            cout << "simple INT FAILED expr : " << expr_ << " `" << tokens[0] << "' = '"
-                //                     << tokens[1] << "'\n";
-            }
-        }
-    }
-    return false;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ExprParser.hpp 5.13.0-1/ANode/src/ecflow/node/ExprParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ExprParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ExprParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ExprParser_HPP
-#define ecflow_node_ExprParser_HPP
-
-#include <memory> // for unique_ptr
-#include <string>
-
-#include "ecflow/node/ExprAst.hpp"
-
-/// This class will parse a expression and create the abstract syntax tree
-/// It will own the AST unless specifically released calling ast();
-class ExprParser {
-public:
-    explicit ExprParser(const std::string& expression);
-    // Disable copy (and move) semantics
-    ExprParser(const ExprParser&)                  = delete;
-    const ExprParser& operator=(const ExprParser&) = delete;
-
-    /// Parse the expression, return true if parse OK false otherwise
-    /// if false is returned, and error message is returned
-    bool doParse(std::string& errorMsg);
-
-    /// return the Abstract syntax tree, and release memory
-    std::unique_ptr<AstTop> ast() { return std::move(ast_); }
-
-    /// return the Abstract syntax tree, without release memory
-    AstTop* getAst() const { return ast_.get(); }
-
-private:
-    std::unique_ptr<AstTop> ast_;
-    std::string expr_;
-};
-
-// This class was added to mitigate the slowness of the boost classic spirit parser
-// we will recognise very simple expression, and bypass spirit. Very limited
-// But the simple expression do form a very large subset
-class SimpleExprParser {
-public:
-    explicit SimpleExprParser(const std::string& expression) : expr_(expression) {}
-    // Disable copy (and move) semantics
-    SimpleExprParser(const SimpleExprParser&)                  = delete;
-    const SimpleExprParser& operator=(const SimpleExprParser&) = delete;
-
-    /// Parse the expression, return true if parse OK false otherwise
-    bool doParse();
-
-    /// return the Abstract syntax tree, and release memory
-    std::unique_ptr<AstTop> ast() { return std::move(ast_); }
-
-private:
-    const std::string& expr_;
-    std::unique_ptr<AstTop> ast_;
-};
-
-#endif /* ecflow_node_ExprParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Expression.cpp 5.13.0-1/ANode/src/ecflow/node/Expression.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Expression.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Expression.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,293 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Expression.hpp"
-
-#include <cassert>
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/node/ExprParser.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace std;
-using namespace ecf;
-
-///////////////////////////////////////////////////////////////////////////////////////////
-
-std::string PartExpression::toString(const std::string& exprType) const {
-    std::stringstream ss;
-    ss << exprType; // trigger or complete
-    switch (type_) {
-        case PartExpression::FIRST:
-            ss << " ";
-            break;
-        case PartExpression::AND:
-            ss << " -a ";
-            break;
-        case PartExpression::OR:
-            ss << " -o ";
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    ss << exp_ << "\n";
-    return ss.str();
-}
-
-void PartExpression::print(std::string& os, const std::string& exprType, bool isFree) const {
-    Indentor in;
-    Indentor::indent(os);
-    os += exprType;
-    switch (type_) {
-        case PartExpression::FIRST:
-            os += " ";
-            break;
-        case PartExpression::AND:
-            os += " -a ";
-            break;
-        case PartExpression::OR:
-            os += " -o ";
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    os += exp_;
-
-    if (!PrintStyle::defsStyle()) {
-        if (type_ == PartExpression::FIRST) {
-            if (isFree)
-                os += " # free";
-        }
-    }
-    os += "\n";
-}
-
-std::unique_ptr<AstTop> PartExpression::parseExpressions(std::string& errorMsg) const {
-    // #ifdef DEBUG
-    //	cout << "PartExpression::parseExpressions '" << exp_ << "'\n";
-    // #endif
-    if (!exp_.empty()) {
-        ExprParser expressionParser(exp_);
-        if (expressionParser.doParse(errorMsg)) {
-
-            // returns new allocated memory, if no errors
-            std::unique_ptr<AstTop> ast = expressionParser.ast();
-
-            if (errorMsg.empty())
-                LOG_ASSERT(ast.get(), "");
-            else
-                LOG_ASSERT(!ast.get(), "");
-
-            return ast;
-        }
-    }
-    return std::unique_ptr<AstTop>();
-}
-
-//===========================================================================
-
-Expression::Expression(const std::string& expression) {
-    add(PartExpression(expression));
-}
-
-Expression::Expression(const PartExpression& exp) {
-    add(exp);
-}
-
-Expression::Expression() = default;
-
-Expression::Expression(const Expression& rhs) : vec_(rhs.vec_), free_(rhs.free_) {
-}
-
-std::unique_ptr<AstTop> Expression::parse(const std::string& expression_to_parse,
-                                          const std::string& error_msg_context) {
-    PartExpression exp(expression_to_parse);
-    string parseErrorMsg;
-    std::unique_ptr<AstTop> ast = exp.parseExpressions(parseErrorMsg);
-    if (!ast.get()) {
-        std::stringstream ss;
-        ss << error_msg_context << " Failed to parse expression '" << expression_to_parse << "'.  " << parseErrorMsg;
-        throw std::runtime_error(ss.str());
-    }
-    return ast;
-}
-
-std::unique_ptr<AstTop> Expression::parse_no_throw(const std::string& expression_to_parse,
-                                                   std::string& error_msg_context) {
-    PartExpression exp(expression_to_parse);
-    string parseErrorMsg;
-    std::unique_ptr<AstTop> ast = exp.parseExpressions(parseErrorMsg);
-    if (!ast.get()) {
-        std::stringstream ss;
-        ss << error_msg_context << " Failed to parse expression '" << expression_to_parse << "'.  " << parseErrorMsg;
-        error_msg_context = ss.str();
-    }
-    return ast;
-}
-
-void Expression::print(std::string& os, const std::string& exprType) const {
-    for (const PartExpression& expr : vec_) {
-        expr.print(os, exprType, free_);
-    }
-}
-
-std::string Expression::compose_expression(const std::vector<PartExpression>& vec) {
-    string ret;
-    auto theEnd = vec.end();
-    for (auto expr = vec.begin(); expr != theEnd; ++expr) {
-        if ((*expr).andExpr())
-            ret += " AND ";
-        else if ((*expr).orExpr())
-            ret += " OR ";
-        ret += (*expr).expression();
-    }
-    return ret;
-}
-
-void Expression::add(const PartExpression& t) {
-    if (vec_.empty()) {
-        // The first expression should not have AND or OR
-        if (t.andExpr() || t.orExpr()) {
-            std::stringstream ss;
-            ss << "Expression::add: expression " << t.expression()
-               << " failed: The first expression should not have AND or OR set";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else {
-        // Subsequent expression must be AND or OR expressions
-        if (!t.andExpr() && !t.orExpr()) {
-            std::stringstream ss;
-            ss << "Expression::add: expression " << t.expression()
-               << " failed: Subsequent expression must have AND or OR set";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    vec_.push_back(t);
-    //	cout << "Expression::add " << expression() << "\n";
-}
-
-void Expression::add_expr(const std::vector<PartExpression>& vec) {
-    for (auto part : vec) {
-        if (!empty() && part.expr_type() == PartExpression::FIRST)
-            part.set_expr_type(PartExpression::AND);
-        add(part);
-    }
-}
-
-// ============================================================================
-// CREATE AST tree for each expression, and COMBINE AST for each expression into a single AST.
-// ============================================================================
-void Expression::createAST(Node* node, const std::string& exprType, std::string& errorMsg) const {
-    size_t theSize = vec_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        std::string localErrorMsg;
-        std::unique_ptr<AstTop> ast = vec_[i].parseExpressions(localErrorMsg);
-        if (ast.get()) {
-
-            // We can have multiple trigger/complete expression, combine to a single AST tree
-            if (theCombinedAst_.get()) {
-                // Must be trigger with -a(and) or -o(or) option's
-                LOG_ASSERT(theCombinedAst_->isTop(), "");
-                LOG_ASSERT(ast->isTop(), "");
-                /* Combine AST tree
-                                          top     top2 (this top needs to be deleted)       top            top2
-                                           |        |                                ===>    |              |
-                                          root1    root2                                   newRoot         NULL;
-                                                                                            / \
-                                                                                        root1  root2
-                 */
-                Ast* newRoot = nullptr;
-                if (vec_[i].andExpr())
-                    newRoot = new AstAnd();
-                else if (vec_[i].orExpr())
-                    newRoot = new AstOr();
-                else
-                    LOG_ASSERT(false, ""); // what else can it be.
-
-                if (newRoot) {
-                    newRoot->addChild(theCombinedAst_->left());
-                    newRoot->addChild(ast->left());
-                    theCombinedAst_->addChild(newRoot); // will overwrite
-
-                    // Since we have transferred over root2 it must be set to NULL for top2,
-                    // to avoid its child destruction
-                    ast->addChild(nullptr); // since its an unique_ptr, no need for explicit delete
-                }
-            }
-            else {
-                // The very first expression should _NOT_ be AND/OR trigger. (i.e no -o | -a)
-                LOG_ASSERT((!vec_[i].andExpr()) && (!vec_[i].orExpr()), "");
-                theCombinedAst_ = std::move(ast); // transfer ownership
-                theCombinedAst_->exprType(exprType);
-            }
-            //			cout << "****************************************************************\n";
-            //			cout << theCombinedAst->expression() << "\n";
-            //			cout << *theCombinedAst << "\n";
-        }
-        else {
-            std::stringstream ss;
-            ss << "Failed to parse " << vec_[i].toString(exprType) << " at " << node->debugNodePath() << " because "
-               << localErrorMsg << "\n\n";
-            errorMsg += ss.str();
-            break;
-        }
-    }
-
-    if (theCombinedAst_.get()) {
-        theCombinedAst_->setParentNode(node);
-    }
-}
-
-void Expression::setFree() {
-    // Only update for a real change
-    if (!free_) {
-        state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Expression::setFree()\n";
-#endif
-    }
-    free_ = true;
-}
-
-void Expression::clearFree() {
-    // Only update for a real change
-    if (free_) {
-        state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Expression::clearFree()\n";
-#endif
-    }
-    free_ = false;
-}
-
-template <class Archive>
-void PartExpression::serialize(Archive& ar) {
-    ar(CEREAL_NVP(exp_));
-    CEREAL_OPTIONAL_NVP(ar, type_, [this]() { return type_ != default_expr_type(); }); // conditionally save
-}
-
-template <class Archive>
-void Expression::serialize(Archive& ar) {
-    ar(CEREAL_NVP(vec_));
-    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
-}
-
-CEREAL_TEMPLATE_SPECIALIZE(PartExpression);
-CEREAL_TEMPLATE_SPECIALIZE(Expression);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Expression.hpp 5.13.0-1/ANode/src/ecflow/node/Expression.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Expression.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Expression.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Expression_HPP
-#define ecflow_node_Expression_HPP
-
-#include <memory> // for unique_ptr
-
-#include "ecflow/node/ExprAst.hpp"
-
-class Node;
-
-namespace cereal {
-class access;
-}
-
-/// class PartExpression:
-///  Hold a single expression, optional can specify whether it is to be And' or
-///  'Ored' when used as a part of a larger expression.
-///  Uses compiler , generated destructor, assignment,  copy constructor
-class PartExpression {
-public:
-    enum ExprType { FIRST, AND, OR };
-
-    PartExpression() : type_(default_expr_type()) {}
-    explicit PartExpression(const std::string& expression) : exp_(expression), type_(default_expr_type()) {}
-    explicit PartExpression(std::string&& expression) : exp_(std::move(expression)), type_(default_expr_type()) {}
-    PartExpression(const std::string& expression, bool and_type) : exp_(expression), type_((and_type) ? AND : OR) {}
-    PartExpression(std::string&& expression, bool and_type)
-        : exp_(std::move(expression)),
-          type_((and_type) ? AND : OR) {}
-
-    static ExprType default_expr_type() { return FIRST; } // NEVER change
-
-    const std::string& expression() const { return exp_; }
-    bool andExpr() const { return (type_ == AND) ? true : false; }
-    bool orExpr() const { return (type_ == OR) ? true : false; }
-
-    std::string toString(const std::string& exprType) const;
-    void print(std::string&, const std::string& exprType, bool isFree) const;
-
-    bool operator==(const PartExpression& rhs) const { return type_ == rhs.type_ && exp_ == rhs.exp_; }
-    bool operator!=(const PartExpression& rhs) const { return !operator==(rhs); }
-
-    /// Parse the expression and create the abstract syntax tree
-    std::unique_ptr<AstTop> parseExpressions(std::string& errorMsg) const;
-
-    void set_expr_type(ExprType t) { type_ = t; }
-    ExprType expr_type() const { return type_; }
-
-private:
-    std::string exp_;
-    ExprType type_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-////////////////////////////////////////////////////////////////////////////////////////
-// Class Expression:
-//       A Expression occur in a Trigger or Complete statement
-//       This class hold a number of part expression.
-//       It can also create a  single AST from the part expressions
-// NOTE: Distinguish between parser errors, and node path resolution
-//       Here we are only concerned with parser errors.
-// Use compiler , generated destructor, assignment,  copy constructor
-class Expression {
-public:
-    Expression();
-    explicit Expression(const std::string& expression);
-    explicit Expression(const PartExpression&);
-
-    Expression(const Expression& rhs);
-    // prevent assignment since we have an unique_ptr
-    Expression& operator=(Expression const& f) = delete;
-
-    bool operator==(const Expression& rhs) const {
-        if (free_ != rhs.free_)
-            return false;
-        return vec_ == rhs.vec_;
-    }
-    bool operator!=(const Expression& rhs) const { return !operator==(rhs); }
-
-    /// Helper function, will parse the expression and return the abstract syntax tree
-
-    static std::unique_ptr<AstTop> parse(const std::string& expression_to_parse,
-                                         const std::string& error_msg_context); // Will throw for parse errors
-    static std::unique_ptr<AstTop> parse_no_throw(const std::string& expression_to_parse,
-                                                  std::string& error_msg_context);
-
-    /// User should add "trigger" or "complete" at the start.
-    /// The part expression's are combined and returned as a single string
-    std::string expression() const { return compose_expression(vec_); }
-    static std::string compose_expression(const std::vector<PartExpression>& vec);
-
-    /// Need to pass in trigger tag, since expression may be split over multiple lines
-    /// trigger    "a == complete"
-    /// trigger -a "b == complete"
-    void print(std::string&, const std::string& exprType) const;
-
-    /// Use when we want to add compose a large expression form a set of smaller ones
-    void add(const PartExpression& t);
-    void add_expr(const std::vector<PartExpression>& vec);
-
-    // ==============================================================================================
-    // CREATE AST tree for each expression and COMBINE AST for each expression into a single AST.
-    // ==============================================================================================
-    void createAST(Node* parent_node, const std::string& exprType, std::string& errorMsg) const;
-    AstTop* get_ast() const { return theCombinedAst_.get(); } // can return NULL
-
-    /// Placed here rather than the expression tree. Since the expression
-    /// tree is created on demand, and is not persisted
-    void setFree();   // hence must be used before evaluate
-    void clearFree(); // resets the free flag
-    bool isFree() const { return free_; }
-    bool empty() const { return vec_.empty(); }
-    const std::vector<PartExpression>& expr() const { return vec_; }
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-private: /// For use by python interface,
-    friend void export_NodeAttr();
-    friend class Trigger;
-    friend class Complete;
-    std::vector<PartExpression>::const_iterator part_begin() const { return vec_.begin(); }
-    std::vector<PartExpression>::const_iterator part_end() const { return vec_.end(); }
-
-private:
-    // They are created on demand. reasons:
-    // 1/ Help with AIX serialisation
-    // 2/ Help to reduce network traffic
-    mutable std::unique_ptr<AstTop> theCombinedAst_; // *not* persisted, demand created
-    std::vector<PartExpression> vec_;
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    bool free_{false};
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_node_Expression_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Family.cpp 5.13.0-1/ANode/src/ecflow/node/Family.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Family.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Family.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,228 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Family.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/NodeTreeVisitor.hpp"
-
-using namespace ecf;
-using namespace std;
-
-/////////////////////////////////////////////////////////////////////////////////////////
-// The false below is used as a dummy argument to call the Variable constructor that does not
-// Check the variable names. i.e we know they are valid
-
-Family& Family::operator=(const Family& rhs) {
-    if (this != &rhs) {
-        NodeContainer::operator=(rhs);
-        delete fam_gen_variables_;
-        fam_gen_variables_ = nullptr;
-    }
-    return *this;
-}
-
-node_ptr Family::clone() const {
-    return std::make_shared<Family>(*this);
-}
-
-Family::~Family() {
-    if (!Ecf::server()) {
-        notify_delete();
-    }
-
-    delete fam_gen_variables_;
-}
-
-family_ptr Family::create(const std::string& name, bool check) {
-    return std::make_shared<Family>(name, check);
-}
-
-family_ptr Family::create_me(const std::string& name) {
-    return std::make_shared<Family>(name, true);
-}
-
-bool Family::check_defaults() const {
-    if (fam_gen_variables_ != nullptr)
-        throw std::runtime_error("Family ::check_defaults():  fam_gen_variables_ != nullptr");
-    return NodeContainer::check_defaults();
-}
-
-void Family::accept(ecf::NodeTreeVisitor& v) {
-    v.visitFamily(this);
-    NodeContainer::accept(v);
-}
-
-void Family::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
-    v.visitFamily(this);
-}
-
-void Family::begin() {
-    NodeContainer::begin();
-    update_generated_variables();
-}
-
-bool Family::resolveDependencies(JobsParam& jobsParam) {
-    if (jobsParam.check_for_job_generation_timeout())
-        return false;
-
-    return NodeContainer::resolveDependencies(jobsParam);
-}
-
-void Family::requeue(Requeue_args& args) {
-    NodeContainer::requeue(args);
-    update_generated_variables();
-}
-
-bool Family::operator==(const Family& rhs) const {
-    return NodeContainer::operator==(rhs);
-}
-
-void Family::print(std::string& os) const {
-    // Generated variable are not persisted since they are created on demand
-    // There *NO* point in printing them they will always be empty
-
-    Indentor in;
-    Indentor::indent(os);
-    os += "family ";
-    os += name();
-    if (!PrintStyle::defsStyle()) {
-        bool added_comment_char = false;
-        write_state(os, added_comment_char);
-    }
-    os += "\n";
-
-    Node::print(os);
-    NodeContainer::print(os);
-    Indentor::indent(os);
-    os += "endfamily\n";
-}
-
-void Family::write_state(std::string& ret, bool& added_comment_char) const {
-    NodeContainer::write_state(ret, added_comment_char);
-}
-void Family::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
-    NodeContainer::read_state(line, lineTokens);
-}
-
-const std::string& Family::debugType() const {
-    return ecf::Str::FAMILY();
-}
-
-std::ostream& operator<<(std::ostream& os, const Family& d) {
-    std::string s;
-    d.print(s);
-    os << s;
-    return os;
-}
-
-void Family::collateChanges(DefsDelta& changes) const {
-    /// All changes to family should be on ONE compound_memento_ptr
-    compound_memento_ptr compound;
-    NodeContainer::incremental_changes(changes, compound);
-
-    // Traversal
-    NodeContainer::collateChanges(changes);
-}
-
-// generated variables --------------------------------------------------------------------------
-
-void Family::update_generated_variables() const {
-    if (!fam_gen_variables_)
-        fam_gen_variables_ = new FamGenVariables(this);
-    fam_gen_variables_->update_generated_variables();
-    update_repeat_genvar();
-}
-
-const Variable& Family::findGenVariable(const std::string& name) const {
-    // Generally it should be never the case that the values are empty
-    // Since the user is assumed to have called begin(), which force
-    // the generation of generated variables
-
-    // AST can reference generated variables. Currently integer based values
-    // The family names can be integers
-
-    if (!fam_gen_variables_)
-        update_generated_variables();
-    const Variable& gen_var = fam_gen_variables_->findGenVariable(name);
-    if (!gen_var.empty())
-        return gen_var;
-
-    return NodeContainer::findGenVariable(name);
-}
-
-void Family::gen_variables(std::vector<Variable>& vec) const {
-    if (!fam_gen_variables_)
-        update_generated_variables();
-
-    vec.reserve(vec.size() + 3);
-    fam_gen_variables_->gen_variables(vec);
-    NodeContainer::gen_variables(vec);
-}
-
-std::string Family::find_node_path(const std::string& type, const std::string& node_name) const {
-    if (Str::caseInsCompare(type, "family")) {
-        if (node_name == name()) {
-            return absNodePath();
-        }
-    }
-    return NodeContainer::find_node_path(type, node_name);
-}
-
-// ================================================================
-
-FamGenVariables::FamGenVariables(const Family* f)
-    : family_(f),
-      genvar_family_("FAMILY", "", false),
-      genvar_family1_("FAMILY1", "", false) {
-}
-
-void FamGenVariables::update_generated_variables() const {
-    // This function is called during:
-    //   o begin()
-    //   o requeue()
-    // Since family generated not persisted, allow for demand creation by client
-    genvar_family1_.set_value(family_->name());
-
-    // FAMILY is the full path excluding the suite, there is *NO* leading slash
-    std::string path              = family_->absNodePath();
-    string::size_type secondSlash = path.find('/', 1);
-    path.erase(0, secondSlash + 1);
-    genvar_family_.set_value(path);
-}
-
-const Variable& FamGenVariables::findGenVariable(const std::string& name) const {
-    if (genvar_family_.name() == name)
-        return genvar_family_;
-    if (genvar_family1_.name() == name)
-        return genvar_family1_;
-    return Variable::EMPTY();
-}
-
-void FamGenVariables::gen_variables(std::vector<Variable>& vec) const {
-    vec.push_back(genvar_family_);
-    vec.push_back(genvar_family1_);
-}
-
-template <class Archive>
-void Family::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<NodeContainer>(this));
-}
-
-CEREAL_TEMPLATE_SPECIALIZE_V(Family);
-CEREAL_REGISTER_TYPE(Family)
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Family.hpp 5.13.0-1/ANode/src/ecflow/node/Family.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Family.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Family.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,98 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Family_HPP
-#define ecflow_node_Family_HPP
-
-#include "ecflow/node/NodeContainer.hpp"
-
-class FamGenVariables;
-
-class Family final : public NodeContainer {
-public:
-    explicit Family(const std::string& name, bool check = true) : NodeContainer(name, check) {}
-    Family() = default;
-    Family(const Family& rhs) : NodeContainer(rhs) {}
-    Family& operator=(const Family&);
-    node_ptr clone() const override;
-
-    ~Family() override;
-
-    static family_ptr create(const std::string& name, bool check = true);
-    static family_ptr create_me(const std::string& name); // python api, to pick correct init function
-
-    bool check_defaults() const override;
-
-    Suite* suite() const override { return parent()->suite(); }
-    Defs* defs() const override {
-        return (parent()) ? parent()->defs() : nullptr;
-    } // exposed to python hence check for NULL first
-    Family* isFamily() const override { return const_cast<Family*>(this); }
-    NodeContainer* isNodeContainer() const override { return const_cast<Family*>(this); }
-
-    void begin() override;
-    bool resolveDependencies(JobsParam&) override; // overriden to speicy family for job profiler
-    void requeue(Requeue_args&) override;
-    void accept(ecf::NodeTreeVisitor&) override;
-    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
-    void update_generated_variables() const override;
-    const Variable& findGenVariable(const std::string& name) const override;
-    void gen_variables(std::vector<Variable>&) const override;
-    std::string find_node_path(const std::string& type, const std::string& name) const override;
-
-    const std::string& debugType() const override;
-
-    void print(std::string&) const override;
-    bool operator==(const Family& rhs) const;
-
-    void collateChanges(DefsDelta&) const override;
-    void set_memento(const OrderMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
-        NodeContainer::set_memento(m, aspects, f);
-    }
-    void set_memento(const ChildrenMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
-        NodeContainer::set_memento(m, aspects, f);
-    }
-
-    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
-
-private:
-    void write_state(std::string&, bool&) const override;
-
-    mutable FamGenVariables* fam_gen_variables_{nullptr};
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-std::ostream& operator<<(std::ostream& os, const Family&);
-
-// We can have several thousands Families. This class helps in avoiding
-// the creation of generated variables until required.
-// This improves client->server download times by avoiding thousands of string constructions
-class FamGenVariables {
-public:
-    explicit FamGenVariables(const Family*);
-    // Disable copy (and move) semantics
-    FamGenVariables(const FamGenVariables&)                  = delete;
-    const FamGenVariables& operator=(const FamGenVariables&) = delete;
-
-    void update_generated_variables() const;
-    const Variable& findGenVariable(const std::string& name) const;
-    void gen_variables(std::vector<Variable>& vec) const;
-
-private:
-    const Family* family_;
-    mutable Variable genvar_family_;
-    mutable Variable genvar_family1_;
-};
-
-#endif /* ecflow_node_Family_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Flag.cpp 5.13.0-1/ANode/src/ecflow/node/Flag.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Flag.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Flag.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,372 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Flag.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-
-namespace ecf {
-
-void Flag::set(Flag::Type flag) {
-    if (!is_set(flag)) {
-        // minimize changes to state_change_no_
-        flag_ |= (1 << flag);
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-}
-
-void Flag::clear(Flag::Type flag) {
-    if (is_set(flag)) {
-        // minimize changes to state_change_no_
-        flag_ &= ~(1 << flag);
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-}
-
-void Flag::reset() {
-    flag_            = 0;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-std::vector<Flag::Type> Flag::list() {
-    std::vector<Flag::Type> ret;
-    ret.reserve(24);
-    ret.push_back(Flag::FORCE_ABORT);
-    ret.push_back(Flag::USER_EDIT);
-    ret.push_back(Flag::TASK_ABORTED);
-    ret.push_back(Flag::EDIT_FAILED);
-    ret.push_back(Flag::JOBCMD_FAILED);
-    ret.push_back(Flag::KILLCMD_FAILED);
-    ret.push_back(Flag::STATUSCMD_FAILED);
-    ret.push_back(Flag::NO_SCRIPT);
-    ret.push_back(Flag::KILLED);
-    ret.push_back(Flag::STATUS);
-    ret.push_back(Flag::LATE);
-    ret.push_back(Flag::MESSAGE);
-    ret.push_back(Flag::BYRULE);
-    ret.push_back(Flag::QUEUELIMIT);
-    ret.push_back(Flag::WAIT);
-    ret.push_back(Flag::LOCKED);
-    ret.push_back(Flag::ZOMBIE);
-    ret.push_back(Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
-    ret.push_back(Flag::ARCHIVED);
-    ret.push_back(Flag::RESTORED);
-    ret.push_back(Flag::THRESHOLD);
-    ret.push_back(Flag::ECF_SIGTERM);
-    ret.push_back(Flag::LOG_ERROR);
-    ret.push_back(Flag::CHECKPT_ERROR);
-    return ret;
-}
-
-constexpr std::array<Flag::Type, 24> Flag::array() {
-    return std::array<Flag::Type, 24>{Flag::FORCE_ABORT,      Flag::USER_EDIT,     Flag::TASK_ABORTED,
-                                      Flag::EDIT_FAILED,      Flag::JOBCMD_FAILED, Flag::KILLCMD_FAILED,
-                                      Flag::STATUSCMD_FAILED, Flag::NO_SCRIPT,     Flag::KILLED,
-                                      Flag::STATUS,           Flag::LATE,          Flag::MESSAGE,
-                                      Flag::BYRULE,           Flag::QUEUELIMIT,    Flag::WAIT,
-                                      Flag::LOCKED,           Flag::ZOMBIE,        Flag::NO_REQUE_IF_SINGLE_TIME_DEP,
-                                      Flag::ARCHIVED,         Flag::RESTORED,      Flag::THRESHOLD,
-                                      Flag::ECF_SIGTERM,      Flag::LOG_ERROR,     Flag::CHECKPT_ERROR};
-}
-
-std::string Flag::enum_to_string(Flag::Type flag) {
-
-    switch (flag) {
-        case Flag::FORCE_ABORT:
-            return "force_aborted";
-            break;
-        case Flag::USER_EDIT:
-            return "user_edit";
-            break;
-        case Flag::TASK_ABORTED:
-            return "task_aborted";
-            break;
-        case Flag::EDIT_FAILED:
-            return "edit_failed";
-            break;
-        case Flag::JOBCMD_FAILED:
-            return "ecfcmd_failed";
-            break;
-        case Flag::NO_SCRIPT:
-            return "no_script";
-            break;
-        case Flag::KILLED:
-            return "killed";
-            break;
-        case Flag::LATE:
-            return "late";
-            break;
-        case Flag::MESSAGE:
-            return "message";
-            break;
-        case Flag::BYRULE:
-            return "by_rule";
-            break;
-        case Flag::QUEUELIMIT:
-            return "queue_limit";
-            break;
-        case Flag::WAIT:
-            return "task_waiting";
-            break;
-        case Flag::LOCKED:
-            return "locked";
-            break;
-        case Flag::ZOMBIE:
-            return "zombie";
-            break;
-        case Flag::NO_REQUE_IF_SINGLE_TIME_DEP:
-            return "no_reque";
-            break;
-        case Flag::ARCHIVED:
-            return "archived";
-            break;
-        case Flag::RESTORED:
-            return "restored";
-            break;
-        case Flag::THRESHOLD:
-            return "threshold";
-            break;
-        case Flag::ECF_SIGTERM:
-            return "sigterm";
-            break;
-        case Flag::LOG_ERROR:
-            return "log_error";
-            break;
-        case Flag::CHECKPT_ERROR:
-            return "checkpt_error";
-            break;
-        case Flag::KILLCMD_FAILED:
-            return "killcmd_failed";
-            break;
-        case Flag::STATUSCMD_FAILED:
-            return "statuscmd_failed";
-            break;
-        case Flag::STATUS:
-            return "status";
-            break;
-        case Flag::NOT_SET:
-            return "not_set";
-            break;
-        default:
-            break;
-    };
-    return std::string();
-}
-
-const char* Flag::enum_to_char_star(Flag::Type flag) {
-    switch (flag) {
-        case Flag::FORCE_ABORT:
-            return "force_aborted";
-            break;
-        case Flag::USER_EDIT:
-            return "user_edit";
-            break;
-        case Flag::TASK_ABORTED:
-            return "task_aborted";
-            break;
-        case Flag::EDIT_FAILED:
-            return "edit_failed";
-            break;
-        case Flag::JOBCMD_FAILED:
-            return "ecfcmd_failed";
-            break;
-        case Flag::KILLCMD_FAILED:
-            return "killcmd_failed";
-            break;
-        case Flag::STATUSCMD_FAILED:
-            return "statuscmd_failed";
-            break;
-        case Flag::STATUS:
-            return "status";
-            break;
-        case Flag::NO_SCRIPT:
-            return "no_script";
-            break;
-        case Flag::KILLED:
-            return "killed";
-            break;
-        case Flag::LATE:
-            return "late";
-            break;
-        case Flag::MESSAGE:
-            return "message";
-            break;
-        case Flag::BYRULE:
-            return "by_rule";
-            break;
-        case Flag::QUEUELIMIT:
-            return "queue_limit";
-            break;
-        case Flag::WAIT:
-            return "task_waiting";
-            break;
-        case Flag::LOCKED:
-            return "locked";
-            break;
-        case Flag::ZOMBIE:
-            return "zombie";
-            break;
-        case Flag::NO_REQUE_IF_SINGLE_TIME_DEP:
-            return "no_reque";
-            break;
-        case Flag::ARCHIVED:
-            return "archived";
-            break;
-        case Flag::RESTORED:
-            return "restored";
-            break;
-        case Flag::THRESHOLD:
-            return "threshold";
-            break;
-        case Flag::ECF_SIGTERM:
-            return "sigterm";
-            break;
-        case Flag::LOG_ERROR:
-            return "log_error";
-            break;
-        case Flag::CHECKPT_ERROR:
-            return "checkpt_error";
-            break;
-        case Flag::NOT_SET:
-            return "not_set";
-            break;
-        default:
-            break;
-    };
-    assert(false);
-    return nullptr;
-}
-
-Flag::Type Flag::string_to_flag_type(const std::string& s) {
-    if (s == "force_aborted")
-        return Flag::FORCE_ABORT;
-    if (s == "user_edit")
-        return Flag::USER_EDIT;
-    if (s == "task_aborted")
-        return Flag::TASK_ABORTED;
-    if (s == "edit_failed")
-        return Flag::EDIT_FAILED;
-    if (s == "ecfcmd_failed")
-        return Flag::JOBCMD_FAILED;
-    if (s == "killcmd_failed")
-        return Flag::KILLCMD_FAILED;
-    if (s == "statuscmd_failed")
-        return Flag::STATUSCMD_FAILED;
-    if (s == "status")
-        return Flag::STATUS;
-    if (s == "no_script")
-        return Flag::NO_SCRIPT;
-    if (s == "killed")
-        return Flag::KILLED;
-    if (s == "late")
-        return Flag::LATE;
-    if (s == "message")
-        return Flag::MESSAGE;
-    if (s == "by_rule")
-        return Flag::BYRULE;
-    if (s == "queue_limit")
-        return Flag::QUEUELIMIT;
-    if (s == "task_waiting")
-        return Flag::WAIT;
-    if (s == "locked")
-        return Flag::LOCKED;
-    if (s == "zombie")
-        return Flag::ZOMBIE;
-    if (s == "no_reque")
-        return Flag::NO_REQUE_IF_SINGLE_TIME_DEP;
-    if (s == "archived")
-        return Flag::ARCHIVED;
-    if (s == "restored")
-        return Flag::RESTORED;
-    if (s == "threshold")
-        return Flag::THRESHOLD;
-    if (s == "sigterm")
-        return Flag::ECF_SIGTERM;
-    if (s == "log_error")
-        return Flag::LOG_ERROR;
-    if (s == "checkpt_error")
-        return Flag::CHECKPT_ERROR;
-    return Flag::NOT_SET;
-}
-
-void Flag::valid_flag_type(std::vector<std::string>& vec) {
-    vec.reserve(24);
-    vec.emplace_back("force_aborted");
-    vec.emplace_back("user_edit");
-    vec.emplace_back("task_aborted");
-    vec.emplace_back("edit_failed");
-    vec.emplace_back("ecfcmd_failed");
-    vec.emplace_back("statuscmd_failed");
-    vec.emplace_back("killcmd_failed");
-    vec.emplace_back("no_script");
-    vec.emplace_back("killed");
-    vec.emplace_back("status");
-    vec.emplace_back("late");
-    vec.emplace_back("message");
-    vec.emplace_back("by_rule");
-    vec.emplace_back("queue_limit");
-    vec.emplace_back("task_waiting");
-    vec.emplace_back("locked");
-    vec.emplace_back("zombie");
-    vec.emplace_back("no_reque");
-    vec.emplace_back("archived");
-    vec.emplace_back("restored");
-    vec.emplace_back("threshold");
-    vec.emplace_back("sigterm");
-    vec.emplace_back("log_error");
-    vec.emplace_back("checkpt_error");
-}
-
-std::string Flag::to_string() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void Flag::write(std::string& ret) const {
-    bool added                           = false;
-    std::array<Flag::Type, 24> flag_list = Flag::array();
-    for (auto& i : flag_list) {
-        if (is_set(i)) {
-            if (added)
-                ret += ',';
-            ret += enum_to_char_star(i);
-            added = true;
-        }
-    }
-}
-
-void Flag::set_flag(const std::string& flags) {
-    std::vector<std::string> the_flags_vec;
-    Str::split(flags, the_flags_vec, ",");
-
-    for (const auto& i : the_flags_vec) {
-        if (i == "migrated")
-            continue; // 4.4.x release had migrated ignore. REMOVE when 5.0.0 is default
-
-        Flag::Type ft = string_to_flag_type(i);
-        if (ft == Flag::NOT_SET) {
-            throw std::runtime_error("Flag::set_flag: Unknown flag types found: " + i);
-        }
-        set(ft);
-    }
-}
-
-template <class Archive>
-void Flag::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(flag_));
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(Flag);
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Flag.hpp 5.13.0-1/ANode/src/ecflow/node/Flag.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Flag.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Flag.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,122 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Flag_HPP
-#define ecflow_node_Flag_HPP
-
-#include <array>
-#include <cstdint>
-#include <string>
-#include <vector>
-
-namespace cereal {
-class access;
-}
-
-namespace ecf {
-
-/// Flag are used store what has happened to a node. These are shown as icon in ecFlowview
-/// Uses compiler generated copy constructor, assignment operator and destructor
-
-/// During interactive use. A Node can be *forced to complete*, or forced to *run*
-/// Typically the user may want to force a node to complete, if they are trying
-/// to update the repeat variable.
-///
-/// In either case  we need to miss a time slot, this is done by setting the
-/// NO_REQUE_IF_SINGLE_TIME_DEP, then at REQUE time we query the flag, if it was set
-/// we avoid resetting the time slots. effectively missing the next time slot.
-///
-/// This functionality is only required during interactive force or run
-/// However if the job aborted, we need to clear NO_REQUE_IF_SINGLE_TIME_DEP, i.e
-///     time 10:00
-///     time 11:00
-/// If at 9.00am use the run command, we want to miss the 10:00 time slot.
-/// However if the run at 9.00 fails, and we run again, we also miss 11:00 time slot
-/// to avoid this if the job aborts, we clear NO_REQUE_IF_SINGLE_TIME_DEP flag.
-
-class Flag {
-public:
-    Flag() = default;
-
-    /// The BYRULE is used to distinguish between tasks that have RUN and completed
-    /// and those that have completed by complete expression.
-    enum Type {
-        FORCE_ABORT                 = 0,  // Node* do not run when try_no > ECF_TRIES, and task aborted by user
-        USER_EDIT                   = 1,  // task
-        TASK_ABORTED                = 2,  // task*
-        EDIT_FAILED                 = 3,  // task*
-        JOBCMD_FAILED               = 4,  // task*
-        NO_SCRIPT                   = 5,  // task*
-        KILLED                      = 6,  // task* do not run when try_no > ECF_TRIES, and task killed by user
-        LATE                        = 7,  // Node attribute,
-        MESSAGE                     = 8,  // Node
-        BYRULE                      = 9,  // Node*, set if node is set to complete by complete trigger expression
-        QUEUELIMIT                  = 10, // Node                                   ( NOT USED currently)
-        WAIT                        = 11, // task*  set when waiting for trigger expression in client command
-        LOCKED                      = 12, // Server                                 ( NOT USED currently)
-        ZOMBIE                      = 13, // task*  Set/cleared but never queried by GUI
-        NO_REQUE_IF_SINGLE_TIME_DEP = 14, //
-        ARCHIVED                    = 15, // Container*
-        RESTORED       = 16, // Container*, Avoid re-archiving node that is restored, until it is re-queued again
-        THRESHOLD      = 17, // Job threshold exceeded.(slow disk,large includes/huge scripts,overloaded machine,server)
-        ECF_SIGTERM    = 18, // Record on defs that server received SIGTERM signal, main used in test
-        NOT_SET        = 19,
-        LOG_ERROR      = 20,   // Error in opening or writing to the log file
-        CHECKPT_ERROR  = 21,   // Error in saving checkpoint file
-        KILLCMD_FAILED = 22,   // task*
-        STATUSCMD_FAILED = 23, // task*
-        STATUS           = 24  // task*
-    };
-
-    bool operator==(const Flag& rhs) const { return flag_ == rhs.flag_; }
-    bool operator!=(const Flag& rhs) const { return !operator==(rhs); }
-
-    // Flag functions:
-    void set(Type flag);
-    void clear(Type flag);
-    bool is_set(Type flag) const { return (flag_ & (1 << flag)); }
-
-    void reset();
-    int flag() const { return flag_; }
-    void set_flag(int f) { flag_ = f; }
-    void set_flag(const std::string& flags); // these are comma separated
-
-    /// returns a comma separated list of all flags set
-    std::string to_string() const;
-    void write(std::string&) const;
-
-    /// returns the string equivalent
-    static std::string enum_to_string(Flag::Type flag);
-    static const char* enum_to_char_star(Flag::Type flag);
-
-    /// Used to determine change in state relative to client
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    /// returns the list of all flag types
-    static std::vector<Flag::Type> list();
-    static constexpr std::array<Flag::Type, 24> array();
-
-    /// Converts from string to flag types.
-    static Flag::Type string_to_flag_type(const std::string& s);
-
-    /// valid flag types, than can be used in AlterCmd
-    static void valid_flag_type(std::vector<std::string>& vec);
-
-private:
-    int flag_{0};
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-} // namespace ecf
-
-#endif /* ecflow_node_Flag_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/InLimit.cpp 5.13.0-1/ANode/src/ecflow/node/InLimit.cpp
--- 5.12.4-1/ANode/src/ecflow/node/InLimit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/InLimit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,164 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/InLimit.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Limit.hpp"
-#ifdef DEBUG
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-using namespace std;
-using namespace ecf;
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
-InLimit::InLimit(const std::string& name,
-                 const std::string& pathToNode,
-                 int tokens,
-                 bool limit_this_node_only,
-                 bool limit_submission,
-                 bool check)
-    : n_(name),
-      path_(pathToNode),
-      tokens_(tokens),
-      limit_this_node_only_(limit_this_node_only),
-      limit_submission_(limit_submission) {
-    if (check && !Str::valid_name(name)) {
-        throw std::runtime_error("InLimit::InLimit: Invalid InLimit name: " + name);
-    }
-    if (limit_this_node_only_ && limit_submission_) {
-        throw std::runtime_error(
-            "InLimit::InLimit: can't limit family only(-n) and limit submission(-s) at the same time");
-    }
-}
-
-bool InLimit::operator==(const InLimit& rhs) const {
-    if (path_ != rhs.path_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "InLimit::operator==   path_ != rhs.path_\n";
-#endif
-        return false;
-    }
-    if (n_ != rhs.n_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "InLimit::operator==     n_ != rhs.n_\n";
-#endif
-        return false;
-    }
-    if (tokens_ != rhs.tokens_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "InLimit::operator==    tokens_(" << tokens_ << ") != rhs.tokens_(" << rhs.tokens_ << ")\n";
-#endif
-        return false;
-    }
-
-    if (limit_this_node_only_ != rhs.limit_this_node_only_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "InLimit::operator==    limit_this_node_only_(" << limit_this_node_only_
-                      << ") != rhs.limit_this_node_only_(" << rhs.limit_this_node_only_ << ")\n";
-#endif
-        return false;
-    }
-    if (limit_submission_ != rhs.limit_submission_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "InLimit::operator==     limit_submission_(" << limit_submission_
-                      << ") != rhs.limit_submission_ (" << rhs.limit_submission_ << ")\n";
-#endif
-        return false;
-    }
-    if (incremented_ != rhs.incremented_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality())
-            std::cout << "InLimit::operator==    incremented_(" << incremented_ << ") != rhs.incremented_("
-                      << rhs.incremented_ << ")\n";
-#endif
-        return false;
-    }
-
-    // Note: comparison does not look at Limit pointers
-    return true;
-}
-
-void InLimit::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-
-    if (!PrintStyle::defsStyle()) {
-
-        // write state; See InlimitParser::doParse for read state part
-        if (incremented_)
-            os += " # incremented:1";
-
-        if (PrintStyle::getStyle() == PrintStyle::STATE) {
-            Limit* the_limit = limit();
-            if (the_limit) {
-                os += " # referenced limit(value) ";
-                os += ecf::convert_to<std::string>(the_limit->theLimit());
-                os += "(";
-                os += ecf::convert_to<std::string>(the_limit->value());
-                os += ")";
-            }
-        }
-    }
-
-    os += "\n";
-}
-
-std::string InLimit::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void InLimit::write(std::string& ret) const {
-    ret += "inlimit ";
-    if (limit_this_node_only_)
-        ret += "-n ";
-    if (limit_submission_)
-        ret += "-s ";
-    if (path_.empty())
-        ret += n_;
-    else {
-        ret += path_;
-        ret += Str::COLON();
-        ret += n_;
-    }
-    if (tokens_ != 1) {
-        ret += " ";
-        ret += ecf::convert_to<std::string>(tokens_);
-    }
-}
-
-template <class Archive>
-void InLimit::serialize(Archive& ar) {
-    ar(CEREAL_NVP(n_));
-    CEREAL_OPTIONAL_NVP(ar, path_, [this]() { return !path_.empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, tokens_, [this]() { return tokens_ != 1; }); // conditionally save
-    CEREAL_OPTIONAL_NVP(
-        ar, limit_this_node_only_, [this]() { return limit_this_node_only_; }); // conditionally save new to 5.0.0
-    CEREAL_OPTIONAL_NVP(
-        ar, limit_submission_, [this]() { return limit_submission_; });       // conditionally save new to 5.0.0
-    CEREAL_OPTIONAL_NVP(ar, incremented_, [this]() { return incremented_; }); // conditionally save new to 5.0.0
-}
-CEREAL_TEMPLATE_SPECIALIZE(InLimit);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/InLimit.hpp 5.13.0-1/ANode/src/ecflow/node/InLimit.hpp
--- 5.12.4-1/ANode/src/ecflow/node/InLimit.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/InLimit.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_InLimit_HPP
-#define ecflow_node_InLimit_HPP
-
-#include <string>
-
-#include "ecflow/node/LimitFwd.hpp"
-
-namespace cereal {
-class access;
-}
-
-// Inlimit. Multiple inlimits on same Node are logically ANDED
-//    inlimit    limitName     // This will consume one token in the limit <limitName>
-//    inlimit    limitName 10  // This will consume 10 tokens in the limit <limitName>
-//    inlimit -s limitName     // Limit submission, consume one token in the limit <limitName>
-//    inlimit -s limitName 10  // Limit submission, consume consume 10 tokens in the limit <limitName>
-//    inlimit -n limitName     // Only applicable to a Suite/family, does not matter how many tasks
-//                             // the family has, will only consume one token in the family
-//                             // Can control number of active families.
-//
-// Inlimit of the same name specified on a task take priority over the family
-class InLimit {
-public:
-    explicit InLimit(const std::string& limit_name, // referenced limit
-                     const std::string& path_to_node_with_referenced_limit =
-                         std::string(),                 // if empty, search for limit up parent hierarchy
-                     int tokens                = 1,     // tokens to consume in the Limit
-                     bool limit_this_node_only = false, // if true limit this node only
-                     bool limit_submission     = false, // limit submission only
-                     bool check                = true   // disable name checking
-    );
-    InLimit() = default;
-
-    void print(std::string&) const;
-    bool operator==(const InLimit& rhs) const;
-    bool operator<(const InLimit& rhs) const { return n_ < rhs.name(); }
-
-    const std::string& name() const { return n_; } // must be defined
-    const std::string& pathToNode() const {
-        return path_;
-    } // can be empty,the node referenced by the In-Limit, this should hold the Limit.
-    int tokens() const { return tokens_; }
-
-    bool limit_submission() const { return limit_submission_; }
-    bool limit_this_node_only() const { return limit_this_node_only_; }
-    bool incremented() const { return incremented_; } // only used with limit_this_node_only
-    void set_incremented(bool f) { incremented_ = f; }
-
-    std::string toString() const;
-
-private:
-    void write(std::string&) const;
-
-    void limit(limit_ptr l) { limit_ = std::weak_ptr<Limit>(l); }
-    Limit* limit() const { return limit_.lock().get(); } // can return NULL
-    friend class InLimitMgr;
-
-private:
-    std::weak_ptr<Limit> limit_; // NOT persisted since computed on the fly
-    std::string n_;
-    std::string path_;
-    int tokens_{1};
-    bool limit_this_node_only_{
-        false}; // default is false,if True, will consume one token(s) only, regardless of number of children
-    bool limit_submission_{false}; // limit submission only
-    bool incremented_{false};      // state
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_node_InLimit_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/InLimitMgr.cpp 5.13.0-1/ANode/src/ecflow/node/InLimitMgr.cpp
--- 5.12.4-1/ANode/src/ecflow/node/InLimitMgr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/InLimitMgr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,520 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/InLimitMgr.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/Node.hpp"
-
-#ifdef DEBUG
-    #include <ostream>
-
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-using namespace ecf;
-using namespace std;
-
-void InLimitMgr::reset() {
-    for (auto& i : vec_) {
-        i.set_incremented(false);
-    }
-}
-
-///////////////////////////////////////////////////////////////////////////////////////////
-
-InLimitMgr& InLimitMgr::operator=(const InLimitMgr& rhs) {
-    if (this != &rhs) {
-        vec_  = rhs.vec_;
-        node_ = nullptr;
-    }
-    return *this;
-}
-
-void InLimitMgr::print(std::string& os) const {
-    for (const InLimit& i : vec_) {
-        i.print(os);
-    }
-}
-
-bool InLimitMgr::operator==(const InLimitMgr& rhs) const {
-    if (vec_.size() != rhs.vec_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "InLimitMgr::operator==  vec_.size() != rhs.vec_.size() " << node_->debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (size_t i = 0; i < vec_.size(); ++i) {
-        if (!(vec_[i] == rhs.vec_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "InLimitMgr::operator==  (!(vec_[i] == rhs.vec_[i] )) " << node_->debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-    return true;
-}
-
-void InLimitMgr::addInLimit(const InLimit& l, bool check) {
-    if (check && findInLimitByNameAndPath(l)) {
-        throw std::runtime_error("Add InLimit failed: Duplicate InLimit see node " + node_->debugNodePath());
-    }
-    vec_.push_back(l);
-}
-
-bool InLimitMgr::deleteInlimit(const std::string& name) {
-    // cout << "InLimitMgr::deleteInlimit: " << name << "\n";
-    if (name.empty()) {
-        vec_.clear();
-        return true;
-    }
-
-    string path_to_limit; // This can be empty
-    string limit_name;
-    (void)Extract::pathAndName(name, path_to_limit, limit_name); // already checked for empty name
-    // cout << "   path_to_limit:" << path_to_limit << "\n";
-    // cout << "   limit_name:" <<  limit_name << "\n";
-
-    for (size_t i = 0; i < vec_.size(); i++) {
-        // cout << "   " << i << ": " << vec_[i].pathToNode() << "  :  " << vec_[i].name() << "\n";
-        if (path_to_limit.empty()) {
-            if (vec_[i].name() == limit_name) {
-                vec_.erase(vec_.begin() + i);
-                return true;
-            }
-        }
-        else {
-            if (vec_[i].name() == limit_name && vec_[i].pathToNode() == path_to_limit) {
-                vec_.erase(vec_.begin() + i);
-                return true;
-            }
-        }
-    }
-    throw std::runtime_error("InLimitMgr::deleteInlimit: Cannot find inlimit: " + name);
-}
-
-Limit* InLimitMgr::findLimitViaInLimit(const InLimit& theInLimit) const {
-    // Use in *test* only
-    size_t theSize = vec_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vec_[i].name() == theInLimit.name() && vec_[i].pathToNode() == theInLimit.pathToNode()) {
-            resolveInLimit(vec_[i]);
-            return vec_[i].limit();
-        }
-    }
-    return nullptr;
-}
-
-bool InLimitMgr::findInLimitByNameAndPath(const InLimit& theInLimit) const {
-    size_t theSize = vec_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vec_[i].name() == theInLimit.name() && vec_[i].pathToNode() == theInLimit.pathToNode()) {
-            return true;
-        }
-    }
-    return false;
-}
-
-void InLimitMgr::get_memento(compound_memento_ptr& comp) const {
-#ifdef DEBUG_MEMENTO
-    std::cout << "InLimitMgr::get_memento " << node_->debugNodePath() << "\n";
-#endif
-
-    for (const InLimit& l : vec_) {
-        comp->add(std::make_shared<NodeInLimitMemento>(l));
-    }
-}
-
-bool InLimitMgr::inLimit() const {
-    // Check in we are in limit.
-    // ** WE need to do a lookahead. hence we pass down inlimit tokens **
-    // In the case we have multiple inlimits then we are only in limit if _ALL_ are in limit.
-    // This is like a logical AND.
-
-    if (vec_.empty())
-        return true;
-
-    resolveInLimitReferences();
-
-    int inlimitsWithLimits = 0;
-    int inlimitCount       = 0;
-    size_t theSize         = vec_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vec_[i].limit_this_node_only()) {
-            if (vec_[i].incremented()) {
-                continue; // Effectively, this inlimit no longer constrains any tasks, allowing them to run.
-            }
-        }
-        Limit* limit = vec_[i].limit();
-        if (limit) {
-            inlimitsWithLimits++;
-            if (limit->inLimit(vec_[i].tokens())) {
-                inlimitCount++;
-            }
-        }
-    }
-
-    return (inlimitsWithLimits == inlimitCount);
-}
-
-void InLimitMgr::incrementInLimit(std::set<Limit*>& limitSet, const std::string& task_path) {
-    // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << endl;
-
-    // *NOTE* each limit is incremented if within LIMIT, and that
-    //        has not previously been updated.
-    //  we could have the same in limit at the task and family level.
-    //  in this case the task takes priority.
-    //  suite suite
-    //    family family
-    //       inlimit limitname 12
-    //       task t1
-    //          inlimit limitname 4
-    //    endfamily
-    //  endsuite
-    //
-    // In this case the limit <limitname> is incremented by 4 _only_
-    //
-    // Note: It is illegal for a node to have the same inlimit but with
-    //       different tokens:
-    //
-    //       task t1
-    //          inlimit limitname 4
-    //          inlimit limitname 2    // illegal and trapped by parser
-
-    if (vec_.empty())
-        return;
-
-    resolveInLimitReferences();
-
-    for (InLimit& inlimit : vec_) {
-        Limit* limit = inlimit.limit();
-        if (limit && limitSet.find(limit) == limitSet.end()) {
-            limitSet.insert(limit);
-
-            // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << " LIMIT incremented " << endl;
-            if (inlimit.limit_this_node_only()) {
-                if (!inlimit.incremented()) {
-                    // Can only increment this once, Notice we pass down this node path, i.e since this node is being
-                    // limited
-                    limit->increment(inlimit.tokens(), node_->absNodePath()); // node could suite || family || task
-                    inlimit.set_incremented(true);
-                }
-            }
-            else {
-                limit->increment(inlimit.tokens(), task_path);
-            }
-        }
-    }
-}
-
-void InLimitMgr::decrementInLimit(std::set<Limit*>& limitSet, const std::string& task_path) {
-    // *NOTE* each limit is incremented if within LIMIT, and that has not previously been updated.
-    //  we could have the same in limit at the task and family level.
-    //  in this case the task takes priority.
-    //  suite suite
-    //    family family
-    //       inlimit limitname 12
-    //       task t1
-    //          inlimit limitname 4
-    //    endfamily
-    //  endsuite
-    //
-    // In this case the limit <limitname> is incremented by 4 _only_
-    //
-    // Note: It is illegal for a node to have the same inlimit but with different tokens:
-    //       task t1
-    //          inlimit limitname 4
-    //          inlimit limitname 2    // illegal and trapped by parser
-
-    if (vec_.empty())
-        return;
-
-    resolveInLimitReferences();
-
-    std::vector<task_ptr> task_vec;
-    for (InLimit& inlimit : vec_) {
-        Limit* limit = inlimit.limit();
-        if (limit && limitSet.find(limit) == limitSet.end()) {
-            limitSet.insert(limit);
-            // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << " LIMIT decremented " << endl;
-
-            if (inlimit.limit_this_node_only()) {
-                if (inlimit.incremented()) {
-
-                    // Can only decrement this once, i.e when all child tasks are completed or aborted or queued or
-                    // unknown
-                    bool at_least_one_active = false;
-                    if (task_vec.empty())
-                        node_->get_all_tasks(task_vec); // Get tasks once, inside for loop
-                    for (task_ptr task : task_vec) {
-                        if (task->state() == NState::ACTIVE || task->state() == NState::SUBMITTED) {
-                            at_least_one_active = true;
-                            break;
-                        }
-                    }
-                    if (at_least_one_active)
-                        continue;
-
-                    limit->decrement(inlimit.tokens(), node_->absNodePath());
-                    inlimit.set_incremented(false);
-                }
-            }
-            else {
-                limit->decrement(inlimit.tokens(), task_path);
-            }
-        }
-    }
-}
-
-void InLimitMgr::decrementInLimitForSubmission(std::set<Limit*>& limitSet, const std::string& task_path) {
-    if (vec_.empty())
-        return;
-
-    resolveInLimitReferences();
-
-    for (InLimit& inlimit : vec_) {
-        Limit* limit = inlimit.limit();
-        if (limit && limitSet.find(limit) == limitSet.end()) {
-            limitSet.insert(limit);
-            // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << " LIMIT decremented " << endl;
-
-            if (inlimit.limit_submission()) {
-                limit->decrement(inlimit.tokens(), task_path);
-            }
-        }
-    }
-}
-
-// #define DEBUG_WHY 1
-
-static void add_consumed_paths(Limit* limit, std::stringstream& ss) {
-    ss << "(";
-    const std::set<std::string>& consumed_paths = limit->paths();
-    int count                                   = 0;
-    for (const auto& consumed_path : consumed_paths) {
-        if (4 == count) {
-            ss << "...";
-            break;
-        }
-        ss << consumed_path << ",";
-        count++;
-    }
-    ss << ")";
-}
-
-bool InLimitMgr::why(std::vector<std::string>& vec, bool html) const {
-    // Note: if this correspond to a leaf node, like a task. Then it may not be
-    // sufficient to just check in limits at this level  *BUT*
-    // Node::top_down_why() and Node::bottom_up_why() will traverse the hierarchy
-    // so we don't need to replicate it here.
-
-#ifdef DEBUG_WHY
-    std::cout << "InLimitMgr::why " << node_->debugNodePath() << " top_down:" << top_down << "\n";
-#endif
-    bool why_found = false;
-    if (!inLimit()) {
-#ifdef DEBUG_WHY
-        std::cout << "   InLimitMgr::why " << node_->debugNodePath() << " NOT in limit\n";
-#endif
-        for (auto& i : vec_) {
-            Limit* limit = i.limit();
-            if (limit && !limit->inLimit(i.tokens())) {
-                std::stringstream ss;
-                if (i.pathToNode().empty()) {
-                    ss << "limit " << limit->name() << " is full";
-                }
-                else {
-                    if (html) {
-                        std::stringstream s;
-                        s << "[limit]" << i.pathToNode() << Str::COLON() << limit->name();
-                        ss << Node::path_href_attribute(s.str()) << " is full";
-                    }
-                    else
-                        ss << "limit " << i.pathToNode() << Str::COLON() << limit->name() << " is full";
-                }
-
-                // show node paths that have consumed a limit, Only show first 5, Otherwise string may be too long
-                add_consumed_paths(limit, ss);
-
-                vec.push_back(ss.str());
-                why_found = true;
-            }
-        }
-    }
-    return why_found;
-}
-
-void InLimitMgr::check(std::string& errorMsg, std::string& warningMsg, bool reportErrors, bool reportWarnings) const {
-    size_t theSize = vec_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        (void)find_limit(vec_[i], errorMsg, warningMsg, reportErrors, reportWarnings);
-    }
-}
-
-void InLimitMgr::resolveInLimit(InLimit& inLimit,
-                                std::string& errorMsg,
-                                std::string& warningMsg,
-                                bool reportErrors,
-                                bool reportWarnings) const {
-    //		cout << "Inlimit " << inLimit.toString() << "\n";
-
-    /// if limit pointer already setup use them. These are shared ptr backed, Hence if deleted beneath use should return
-    /// 0;
-    if (inLimit.limit()) {
-        //		cout << "InLimitMgr::resolveInLimit " << inLimit.toString() << " Reusing limit ptr \n";
-        return;
-    }
-
-    /// Find the limit referenced by the InLimit. i.e. Link inLimit to its LIMIT
-    /// The return value can be NULL
-    limit_ptr referencedLimit = find_limit(inLimit, errorMsg, warningMsg, reportErrors, reportWarnings);
-    inLimit.limit(referencedLimit);
-}
-
-void InLimitMgr::auto_add_inlimit_externs(Defs* defs) const {
-    std::string errorMsg;
-    std::string warningMsg;
-    size_t theSize = vec_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        limit_ptr referencedLimit = find_limit(vec_[i], errorMsg, warningMsg, false, false);
-        if (!referencedLimit.get()) {
-            if (vec_[i].pathToNode().empty())
-                defs->add_extern(vec_[i].name());
-            else
-                defs->add_extern(vec_[i].pathToNode() + ":" + vec_[i].name());
-        }
-    }
-}
-
-limit_ptr InLimitMgr::find_limit(const InLimit& inLimit,
-                                 std::string& errorMsg,
-                                 std::string& warningMsg,
-                                 bool reportErrors,
-                                 bool reportWarnings) const {
-    if (inLimit.pathToNode().empty()) {
-
-        // cout << "inLimit.pathToNode().empty() search " << debugType() << " " << node_->absNodePath() << "\n";
-        limit_ptr referencedLimit = node_->findLimitUpNodeTree(inLimit.name());
-        if (referencedLimit.get())
-            return referencedLimit;
-
-        if (reportWarnings) {
-
-            // See if the name is defined, as an extern, in which case *DONT* warn:
-            // This is client side specific, since server does not have externs.
-            if (node_->defs()->find_extern(inLimit.name(), Str::EMPTY())) {
-                return referencedLimit; // this is empty/NULL
-            }
-
-            std::stringstream ss;
-            ss << "Warning: ";
-            ss << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString()
-               << ", which cannot be found on the parent nodes\n";
-            warningMsg += ss.str();
-        }
-        return referencedLimit; // this is empty/NULL
-    }
-
-    // *FIND* the node referenced by the In-Limit, this should hold the Limit.
-    // cout << "Inlimit path not empty \n";
-    string warning_message;
-    node_ptr referenceNode = node_->findReferencedNode(inLimit.pathToNode(), inLimit.name(), warning_message);
-    if (!referenceNode.get()) {
-        /// Could not find the node which *HOLDS* the limit
-        if (reportWarnings) {
-
-            // OK a little bit of duplication, since findReferencedNode, will also look for externs
-            // See if the Path:name is defined as an extern, in which case *DONT* warn:
-            // This is client side specific, since server does not have externs.
-            if (node_->defs()->find_extern(inLimit.pathToNode(), inLimit.name())) {
-                return limit_ptr();
-            }
-
-            std::stringstream ss;
-            ss << "Warning: " << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString()
-               << ", which cannot be found\n";
-            warningMsg += ss.str();
-        }
-        return limit_ptr();
-    }
-
-    // *FOUND* the node which should hold the Limit.
-    limit_ptr referencedLimit = referenceNode->find_limit(inLimit.name());
-    if (!referencedLimit.get()) {
-
-        // See if the name is defined, as an extern, in which case *DONT* warn:
-        // This is client side specific, since server does not have externs.
-        if (node_->defs()->find_extern(inLimit.pathToNode(), inLimit.name())) {
-            return limit_ptr();
-        }
-
-        if (reportWarnings) {
-            std::stringstream ss;
-            ss << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString() << " :";
-            ss << "The referenced " << referenceNode->debugType() << " '" << referenceNode->absNodePath()
-               << "' does not define the limit " << inLimit.name() << "\n";
-            warning_message += ss.str();
-            warningMsg += "Warning: ";
-            warningMsg += warning_message;
-            warningMsg += "\n";
-        }
-        return referencedLimit; // this is empty/NULL
-    }
-
-    // *FOUND* the referenced LIMIT. inlimit tokens must be less than limit.
-    // ECFLOW-713 make this a warning and not error, it allows job control over multiple suites, at load/begin time
-    if (inLimit.tokens() > referencedLimit->theLimit()) {
-        if (reportWarnings) {
-            // in limit exceeds the LIMIT value
-            std::stringstream ss;
-            ss << "Warning: ";
-            ss << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString()
-               << " reference\n";
-            ss << " with value '" << inLimit.tokens() << "' which exceeds '" << referencedLimit->theLimit()
-               << "' defined on the Limit\n";
-            warningMsg += ss.str();
-        }
-    }
-    return referencedLimit;
-}
-
-void InLimitMgr::resolveInLimit(InLimit& inLimit) const {
-    // Used in *test* only
-    std::string errorMsg;
-    std::string warningMsg;
-    resolveInLimit(inLimit, errorMsg, warningMsg, false, false);
-}
-
-void InLimitMgr::resolveInLimitReferences() const {
-    size_t theSize = vec_.size();
-    if (theSize > 0) {
-        std::string warningMsg;
-        std::string errorMsg;
-        for (size_t i = 0; i < theSize; i++) {
-            resolveInLimit(vec_[i], errorMsg, warningMsg, false, false);
-        }
-    }
-}
-
-template <class Archive>
-void InLimitMgr::serialize(Archive& ar) {
-    ar(CEREAL_NVP(vec_));
-}
-CEREAL_TEMPLATE_SPECIALIZE(InLimitMgr);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/InLimitMgr.hpp 5.13.0-1/ANode/src/ecflow/node/InLimitMgr.hpp
--- 5.12.4-1/ANode/src/ecflow/node/InLimitMgr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/InLimitMgr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,140 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_InLimitMgr_HPP
-#define ecflow_node_InLimitMgr_HPP
-
-#include <memory>
-#include <set>
-#include <string>
-
-#include "ecflow/node/InLimit.hpp"
-#include "ecflow/node/LimitFwd.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-namespace cereal {
-class access;
-}
-
-// class InLimitMgr:
-// Design notes:
-// Please note: when ever we want access the inlimits, limit ptrs we
-// must resolve(/compute them first). This save on client code which
-// modifies the node tree from having handle it.
-// If this proves to be a bottle next. We could add a caching mechanism
-// base on the Ecf class,so that we need only update the pointers
-// when a structural modification is made.
-//
-class InLimitMgr {
-public:
-    explicit InLimitMgr(Node* n) : node_(n) {}
-    InLimitMgr(const InLimitMgr& rhs) : vec_(rhs.vec_) {}
-    InLimitMgr() = default;
-
-    // needed by node copy constructor
-    void set_node(Node* n) { node_ = n; }
-
-    // Used by begin/re-queue
-    void reset(); // clear incremented flag, for family limited nodes.
-
-    // standard functions: ==============================================
-    InLimitMgr& operator=(const InLimitMgr&);
-    void print(std::string&) const;
-    bool operator==(const InLimitMgr& rhs) const;
-    void clear() { vec_.clear(); }
-
-    // Access functions: ======================================================
-    const std::vector<InLimit>& inlimits() const { return vec_; }
-
-    // Add functions: ===============================================================
-    void addInLimit(const InLimit&, bool check = true); // will throw std::runtime_error if duplicate
-
-    // Delete functions: can throw std::runtime_error ===================================
-    // if name argument is empty, delete all attributes of that type
-    // if delete was successful return true, else return false.
-    // Can throw std::runtime_error if the attribute cannot be found
-    bool deleteInlimit(const std::string& name);
-
-    // mementos functions:
-    void get_memento(compound_memento_ptr& comp) const;
-
-    // Find functions: ============================================================
-    /// *** This will resolve the in limits first ***
-    /// Used in *test* only
-    Limit* findLimitViaInLimit(const InLimit&) const;
-
-    bool findInLimitByNameAndPath(const InLimit&) const; // use name,path,token,
-
-    // Why:
-    bool why(std::vector<std::string>& vec, bool html = false) const; // return true if why found
-
-    // Limit functions:
-
-    /// Are the in limits pointers to the Limits in limit.
-    /// This is a very heavily used function. *******
-    /// *** This will resolve the in limits first ***
-    bool inLimit() const;
-
-    /// After job submission we need to increment the in limit, to indicate that a
-    /// resource is consumed.
-    /// *** This will resolve the in limits first ***
-    void
-    incrementInLimit(std::set<Limit*>& limitSet,  // The set ensure we only update once
-                     const std::string& task_path // The task that was submitted, and hence caused Limit to increment
-    );
-
-    /// After job aborts or completes we need to decrement the in limit, to indicate that
-    /// additional resource is available.
-    /// *** This will resolve the in limits first ***
-    void decrementInLimit(std::set<Limit*>& limitSet,  // The set ensure we only update once
-                          const std::string& task_path // The task that completed or aborted. Gives up the token
-    );
-    void
-    decrementInLimitForSubmission(std::set<Limit*>& limitSet,  // The set ensure we only update once
-                                  const std::string& task_path // The task that completed or aborted. Gives up the token
-    );
-
-    /// Check to see if inlimit's can reference their Limits
-    void check(std::string& errorMsg, std::string& warningMsg, bool reportErrors, bool reportWarnings) const;
-
-    /// Add externs where the inlimit reference to limits cannot be resolved
-    void auto_add_inlimit_externs(Defs*) const;
-
-    /// Needed by python interface
-    std::vector<InLimit>::const_iterator inlimit_begin() const { return vec_.begin(); }
-    std::vector<InLimit>::const_iterator inlimit_end() const { return vec_.end(); }
-
-private:
-    /// Setup in-limits, to point to their limits,
-    void resolveInLimitReferences() const;
-    void resolveInLimit(InLimit&,
-                        std::string& errorMsg,
-                        std::string& warningMsg,
-                        bool reportErrors,
-                        bool reportWarnings) const;
-    void resolveInLimit(InLimit&) const;
-
-    limit_ptr find_limit(const InLimit&,
-                         std::string& errorMsg,
-                         std::string& warningMsg,
-                         bool reportErrors,
-                         bool reportWarnings) const;
-
-private:
-    Node* node_{nullptr}; // Not persisted, constructor will always set this up.
-
-    mutable std::vector<InLimit> vec_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_node_InLimitMgr_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/JobCreationCtrl.cpp 5.13.0-1/ANode/src/ecflow/node/JobCreationCtrl.cpp
--- 5.12.4-1/ANode/src/ecflow/node/JobCreationCtrl.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/JobCreationCtrl.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/JobCreationCtrl.hpp"
-
-#include <cstdlib> // for getenv()
-#include <iostream>
-#include <stdexcept>
-
-void JobCreationCtrl::generate_temp_dir() {
-    if (!getenv("TMPDIR"))
-        throw std::runtime_error(
-            "JobCreationCtrl::generate_temp_dir(), The environment variable TMPDIR is not defined");
-    tempDirForJobGeneration_ = getenv("TMPDIR");
-    tempDirForJobGeneration_ += "/ecf_check_job_creation";
-    if (fs::exists(tempDirForJobGeneration_))
-        fs::remove_all(tempDirForJobGeneration_);
-    std::cout << "JobCreationCtrl::generate_temp_dir()  " << tempDirForJobGeneration_ << "\n";
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/JobCreationCtrl.hpp 5.13.0-1/ANode/src/ecflow/node/JobCreationCtrl.hpp
--- 5.12.4-1/ANode/src/ecflow/node/JobCreationCtrl.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/JobCreationCtrl.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_JobCreationCtrl_HPP
-#define ecflow_node_JobCreationCtrl_HPP
-
-#include <string>
-#include <vector>
-
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-// Used as a utility class for testing Job creation
-// Collates data during the node tree traversal
-// Note: For testing purposes we do not always want to create jobs
-class JobCreationCtrl : public std::enable_shared_from_this<JobCreationCtrl> {
-public:
-    JobCreationCtrl()                       = default;
-    JobCreationCtrl(const JobCreationCtrl&) = delete;
-    ~JobCreationCtrl()                      = default;
-
-    JobCreationCtrl& operator=(const JobCreationCtrl&) = delete;
-
-    void set_node_path(const std::string& absNodePath) { absNodePath_ = absNodePath; }
-    const std::string& node_path() const { return absNodePath_; }
-
-    void generate_temp_dir();
-    void set_dir_for_job_creation(const std::string& tempDirForJobGeneration) {
-        tempDirForJobGeneration_ = tempDirForJobGeneration;
-    }
-    const std::string& dir_for_job_creation() { return tempDirForJobGeneration_; }
-
-    std::string& error_msg() { return errorMsg_; }
-    const std::string& get_error_msg() const { return errorMsg_; }
-
-    void push_back_failing_submittable(submittable_ptr t) { fail_submittables_.push_back(t); }
-    const std::vector<weak_submittable_ptr>& fail_submittables() const { return fail_submittables_; }
-
-    void set_verbose(bool verbose) { verbose_ = verbose; }
-    bool verbose() const { return verbose_; }
-
-    // Used in job creation checking. Holds EcfFile, which has a CACHE of included files.
-    // Use to minimise file opening of included files
-    // Since we hold a only a single JobsParam over ALL job creation testing. See ECFLOW-1210
-    JobsParam& jobsParam() { return jobsParam_; }
-
-private:
-    bool verbose_{false};
-    std::string absNodePath_;
-    std::string tempDirForJobGeneration_;
-    std::string errorMsg_;
-    std::vector<weak_submittable_ptr> fail_submittables_;
-    JobsParam jobsParam_; // create jobs = false, spawn jobs = false used as a cache
-};
-
-#endif /* ecflow_node_JobCreationCtrl_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/JobProfiler.cpp 5.13.0-1/ANode/src/ecflow/node/JobProfiler.cpp
--- 5.12.4-1/ANode/src/ecflow/node/JobProfiler.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/JobProfiler.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/JobProfiler.hpp"
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// Connection and client timeout issues can be replicated  by adding
-//   - sleep(1) in EcfFile , i.e when creating the job output
-//
-
-static size_t task_threshold_ = 4000;
-
-namespace ecf {
-
-int JobProfiler::task_threshold_default() {
-    return 4000;
-}
-
-// =================================================================================
-JobProfiler::JobProfiler(Task* node, JobsParam& jobsParam, size_t threshold)
-    : node_(node),
-      jobsParam_(jobsParam),
-      start_time_(boost::posix_time::microsec_clock::universal_time()),
-      threshold_(threshold) {
-    // If job generation takes longer than the time to *reach* next_poll_time_, then time out.
-    // Hence we start out with 60 seconds, and time for job generation should decrease. Until reset back to 60
-    // Should allow greater child/user command communication.
-    if (!jobsParam_.next_poll_time().is_special() && start_time_ >= jobsParam_.next_poll_time()) {
-        jobsParam_.set_timed_out_of_job_generation(start_time_);
-    }
-}
-
-JobProfiler::~JobProfiler() {
-    if (node_) {
-        boost::posix_time::time_duration duration = boost::posix_time::microsec_clock::universal_time() - start_time_;
-        size_t time_taken                         = duration.total_milliseconds();
-
-        // When testing we set submitJobsInterval to < 0
-        if (jobsParam_.submitJobsInterval() < 0) {
-            time_taken = threshold_ + 1;
-        }
-
-        if (time_taken > threshold_) {
-            std::stringstream ss;
-            ss << "Job generation for task " << node_->absNodePath() << " took " << time_taken
-               << "ms, Exceeds ECF_TASK_THRESHOLD(" << threshold_ << "ms)";
-            log(Log::WAR, ss.str());
-            node_->flag().set(ecf::Flag::THRESHOLD);
-        }
-    }
-}
-
-void JobProfiler::set_task_threshold(size_t threshold) {
-    task_threshold_ = threshold;
-}
-size_t JobProfiler::task_threshold() {
-    return task_threshold_;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/JobProfiler.hpp 5.13.0-1/ANode/src/ecflow/node/JobProfiler.hpp
--- 5.12.4-1/ANode/src/ecflow/node/JobProfiler.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/JobProfiler.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_JobProfiler_HPP
-#define ecflow_node_JobProfiler_HPP
-
-///
-/// \brief This class is used to aid profiling of the job generation step.
-///
-/// This will be used to identify those suite/family/tasks that take the most
-/// amount of time, *when* we exceed the jobs generation interval.
-/// In particular if we have output that is many megabytes, it can affect
-/// the performance of the server, especially when the server is running
-/// on virtual machines
-///
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-class JobsParam;
-class Task;
-
-namespace ecf {
-
-class JobProfiler {
-private:
-public:
-    // Note: 1000 milliseconds = 1 second
-    JobProfiler(Task*, JobsParam&, size_t threshold /* expected to be milliseconds */);
-    // Disable copy (and move) semantics
-    JobProfiler(const JobProfiler&)                  = delete;
-    const JobProfiler& operator=(const JobProfiler&) = delete;
-
-    ~JobProfiler();
-
-    static void set_task_threshold(size_t threshold);
-    static size_t task_threshold();
-
-    static int task_threshold_default();
-
-private:
-    Task* node_;
-    JobsParam& jobsParam_;
-    boost::posix_time::ptime start_time_;
-    size_t threshold_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_JobProfiler_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Jobs.cpp 5.13.0-1/ANode/src/ecflow/node/Jobs.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Jobs.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Jobs.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,119 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Jobs.hpp"
-
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Signal.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// #define DEBUG_JOB_SUBMISSION 1
-
-bool Jobs::generate(JobsParam& jobsParam) const {
-#ifdef DEBUG_JOB_SUBMISSION
-    cout << "\n"
-         << "Jobs::generate (" << jobsParam.logDebugMessage() << ") create jobs(" << jobsParam.createJobs() << ")";
-    if (defs_)
-        cout << " server_state(" << SState::to_string(defs_->server().get_state()) << ")\n";
-#endif
-
-    // dependency resolving and job submission must be less than submitJobsInterval seconds
-    // Note: Duration timer makes a system call
-    DurationTimer durationTimer;
-
-#ifdef DEBUG_JOB_SUBMISSION
-    LogToCout toCoutAsWell;
-    LOG(Log::DBG, "-->Job submission start " << jobsParam.logDebugMessage());
-#endif
-    {
-        // Constructor does nothing, destructor will un-block SIGCHLD
-        // This allows the child process termination to be handled by the signal handler in System.
-        // The destructor will then re-block SIGCHLD
-        Signal unblock_on_desctruction_then_reblock;
-
-        // *******************************************************************
-        // **** JOB submission *MUST* be done sequentially, as each task could
-        // **** be affected by a resource/limit, and hence affect subsequent
-        // **** job submission
-        // *******************************************************************
-
-        if (defs_) {
-            if (defs_->server().get_state() == SState::RUNNING) {
-                const std::vector<suite_ptr>& suiteVec = defs_->suiteVec();
-                size_t theSize                         = suiteVec.size();
-                for (size_t i = 0; i < theSize; i++) {
-                    // SuiteChanged moved internal to Suite::resolveDependencies. i.e on fast path
-                    // and when suites not begun we save a constructor/destructor calls
-                    (void)suiteVec[i]->resolveDependencies(jobsParam);
-                }
-            }
-        }
-        else {
-            if (!node_->isParentSuspended()) {
-                // suite, family, task
-                SuiteChanged1 changed(node_->suite());
-                (void)node_->resolveDependencies(jobsParam);
-            }
-        }
-
-        // *****************************************************************
-        // Should end up calling signal handler here for any pending SIGCHLD
-        // *****************************************************************
-    }
-
-    // Process children that have terminated
-    System::instance()->processTerminatedChildren();
-
-#ifdef DEBUG_JOB_SUBMISSION
-    LOG(Log::DBG,
-        "-->Job submission finish interval = " << jobsParam.submitJobsInterval() << " time taken = "
-                                               << durationTimer.duration() << " Tasks/Aliases submitted "
-                                               << jobsParam.submitted().size() << " " << jobsParam.getErrorMsg());
-#endif
-
-    if (durationTimer.duration() > jobsParam.submitJobsInterval()) {
-        LOG(Log::ERR,
-            "Jobs::generate: job generation time(" << durationTimer.duration()
-                                                   << " seconds) is greater than job submission interval of "
-                                                   << jobsParam.submitJobsInterval() << " seconds!!");
-    }
-    return jobsParam.getErrorMsg().empty();
-}
-
-bool Jobs::generate() const {
-    Defs* defs = nullptr;
-    if (defs_) {
-        defs = defs_;
-        LOG_ASSERT(defs != nullptr, "defs_ == NULL");
-    }
-    else {
-        defs = node_->defs();
-        LOG_ASSERT(defs != nullptr, "node_->defs() == NULL");
-    }
-
-    if (defs && defs->server().get_state() == SState::RUNNING) {
-        LOG_ASSERT(defs->server().jobSubmissionInterval() != 0, "");
-        JobsParam jobsParam(defs->server().jobSubmissionInterval(), defs->server().jobGeneration());
-#ifdef DEBUG_JOB_SUBMISSION
-        jobsParam.logDebugMessage(" from Jobs::generate()/Server");
-#endif
-
-        return generate(jobsParam);
-    }
-    return false;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Jobs.hpp 5.13.0-1/ANode/src/ecflow/node/Jobs.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Jobs.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Jobs.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,82 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Jobs_HPP
-#define ecflow_node_Jobs_HPP
-
-#include "ecflow/node/NodeFwd.hpp"
-
-///
-/// Job generation implies the following activities:
-///
-/// 1/ Resolve dependencies.
-/// This implies inspecting day, date, time and triggers; and determine if
-/// each node is free or still holding.
-/// For task nodes that are free of its dependencies, a job can be created.
-/// Note: Job generation is not performed for Nodes that are suspended.
-///       In this case, time dependencies are still checked, and marked as
-///       free, accordingly. When the Nodes are later resumed, dependencies
-///       are (re)checked and job scripts are eventually created.
-///
-/// 2/ Create jobs scripts.
-/// Perform pre-processing of .ecf files including variable substitution.
-///
-/// 3/ Change state of task to submitted.
-///
-/// 4/ Increment the inlimit references (for successful job submissions).
-///
-/// 5/ Update limits according to Error/Complete
-///
-/// 6/ Set up signal handlers to monitor child jobs.
-/// This ensures that on failure the Task state is changed to ABORTED and
-/// related limit references are updated accordingly.
-///
-/// Important: Job submissions *MUST* be done sequentially, as each job
-/// submission can potentially consume a resource (e.g. a limit), which can
-/// affect the ability to perform subsequent job submissions.
-///
-/// The process of resolving dependencies (and submitting all the tasks), must
-/// take less than 60 seconds, as this is resolution of the clock.
-/// For testing purposes, this can be changed and we might not always want
-/// to actually create jobs.
-///
-/// @returns true, if job submission succeeds; false, otherwise (with error message in JobsParam)
-///
-/// The job files are shell scripts, which have IPC (child commands) which talk to
-/// to the server. Since the scripts are user created, they can include, errors:
-///   o multiple call to complete
-///     To guard against this, we should *not* clear/reset password in the complete.
-///     Otherwise, we will registered as a zombie.
-///   o Failure to call complete (maybe due to early exit in the job file).
-///     There is not much we can do here, the job will stay active.
-///   o Path do not match, since the node tree, in the server has been deleted
-///     Typically the job will hold on the child commands.
-///
-/// Note: in real life test 99% of job generation is done after child command.
-///
-
-class Jobs {
-public:
-    explicit Jobs(const defs_ptr& d) : defs_(d.get()) {}
-    explicit Jobs(Defs* d) : defs_(d) {}
-    explicit Jobs(Node* d) : node_(d) {}
-    // Disable copy (and move) semantics
-    Jobs(const Jobs&)                  = delete;
-    const Jobs& operator=(const Jobs&) = delete;
-
-    bool generate(JobsParam&) const;
-    bool generate() const;
-
-private:
-    Defs* defs_{nullptr};
-    Node* node_{nullptr};
-};
-
-#endif /* ecflow_node_Jobs_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/JobsParam.cpp 5.13.0-1/ANode/src/ecflow/node/JobsParam.cpp
--- 5.12.4-1/ANode/src/ecflow/node/JobsParam.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/JobsParam.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,36 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/JobsParam.hpp"
-
-bool JobsParam::check_for_job_generation_timeout() {
-    if (timed_out_of_job_generation_)
-        return true;
-    return check_for_job_generation_timeout(boost::posix_time::microsec_clock::universal_time());
-}
-
-bool JobsParam::check_for_job_generation_timeout(const boost::posix_time::ptime& start_time) {
-    if (timed_out_of_job_generation_) {
-        return true;
-    }
-    if (!next_poll_time_.is_special() && start_time >= next_poll_time_) {
-        set_timed_out_of_job_generation(start_time);
-        return true;
-    }
-    return false;
-}
-
-void JobsParam::clear() {
-    errorMsg_.clear();
-    debugMsg_.clear();
-    submitted_.clear();
-    user_edit_file_.clear();
-    user_edit_variables_.clear();
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/JobsParam.hpp 5.13.0-1/ANode/src/ecflow/node/JobsParam.hpp
--- 5.12.4-1/ANode/src/ecflow/node/JobsParam.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/JobsParam.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_JobsParam_HPP
-#define ecflow_node_JobsParam_HPP
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/node/EcfFile.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-// Used as a utility class for controlling job creation.
-// Collates data during the node tree traversal
-// Note: For testing purposes we do not always want to create jobs or spawn jobs
-class JobsParam {
-public:
-    // This constructor is used in test
-    explicit JobsParam(bool createJobs = false) : createJobs_(createJobs) {}
-
-    JobsParam(int submitJobsInterval, bool createJobs, bool spawn_jobs = true)
-        : createJobs_(createJobs),
-          spawnJobs_(spawn_jobs),
-          submitJobsInterval_(submitJobsInterval) {
-        if (!createJobs_)
-            spawnJobs_ = false;
-    }
-
-    // Disable copy (and move) semantics
-    JobsParam(const JobsParam&)                  = delete;
-    const JobsParam& operator=(const JobsParam&) = delete;
-
-    // Allow JobsParam to be re-used. Preserve cache in EcfFile. ECFLOW-1210
-    void clear();
-
-    std::string& errorMsg() { return errorMsg_; }
-    const std::string& getErrorMsg() const { return errorMsg_; }
-
-    void push_back_submittable(Submittable* t) { submitted_.push_back(t); }
-    const std::vector<Submittable*>& submitted() const { return submitted_; }
-
-    bool createJobs() const { return createJobs_; }
-    bool spawnJobs() const { return spawnJobs_; }
-
-    /// returns the number of seconds at which we should check time dependencies
-    /// this includes evaluating trigger dependencies and submit the corresponding jobs.
-    /// This is set at 60 seconds. But will vary for debug purposes only.
-    int submitJobsInterval() const { return submitJobsInterval_; }
-
-    /// Allow user to set the debug message that appears in log file when job submission starts
-    void logDebugMessage(const std::string& s) { debugMsg_ = s; }
-    const std::string& logDebugMessage() const { return debugMsg_; }
-
-    void set_user_edit_variables(const NameValueMap& v) { user_edit_variables_ = v; }
-    const NameValueMap& user_edit_variables() const { return user_edit_variables_; }
-
-    void set_user_edit_file(const std::vector<std::string>& file) { user_edit_file_ = file; }
-    const std::vector<std::string>& user_edit_file() const { return user_edit_file_; }
-
-    // Functions to aid timing of job generation
-    void set_next_poll_time(const boost::posix_time::ptime& next_poll_time) { next_poll_time_ = next_poll_time; }
-    const boost::posix_time::ptime& next_poll_time() const { return next_poll_time_; }
-    const boost::posix_time::ptime& time_out_time() const { return time_out_time_; }
-
-    // If job generation takes longer than the time to *reach* next_poll_time_, then time out.
-    // Hence we start out with 60 seconds, and time for job generation should decrease. Until reset back to 60
-    // Should allow greater child/user command communication.
-    void set_timed_out_of_job_generation(const boost::posix_time::ptime& t) {
-        time_out_time_               = t;
-        timed_out_of_job_generation_ = true;
-    }
-    bool timed_out_of_job_generation() const { return timed_out_of_job_generation_; }
-
-    // ensure that we avoid job generation close the server poll time.
-    bool check_for_job_generation_timeout();
-    bool check_for_job_generation_timeout(const boost::posix_time::ptime& time_now);
-
-    void set_ecf_file(const EcfFile& ecf_file) { ecf_file_ = ecf_file; }
-    EcfFile& ecf_file() { return ecf_file_; }
-
-private:
-    bool timed_out_of_job_generation_{false};
-    bool createJobs_;
-    bool spawnJobs_{false};
-    int submitJobsInterval_{60};
-    std::string errorMsg_;
-    std::string debugMsg_;
-    std::vector<Submittable*> submitted_;
-    std::vector<std::string> user_edit_file_;
-    NameValueMap user_edit_variables_;        // Used for User edit
-    boost::posix_time::ptime next_poll_time_; // Aid early exit from job generation, if it takes to long
-    boost::posix_time::ptime time_out_time_;  // When we actually timed out must >= next_poll_time_
-    EcfFile ecf_file_;                        // keep for lifetime, to optimise memory and cache include file
-};
-
-#endif /* ecflow_node_JobsParam_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Limit.cpp 5.13.0-1/ANode/src/ecflow/node/Limit.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Limit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Limit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,221 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Limit.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-/////////////////////////////////////////////////////////////////////////////////////////////
-
-Limit::Limit(const std::string& name, int limit) : n_(name), lim_(limit) {
-    if (!Str::valid_name(name)) {
-        throw std::runtime_error("Limit::Limit: Invalid Limit name: " + name);
-    }
-}
-
-Limit::Limit(const std::string& name, int limit, int value, const std::set<std::string>& paths, bool check)
-    : n_(name),
-      lim_(limit),
-      value_(value),
-      paths_(paths) {
-    if (check && !Str::valid_name(name)) {
-        throw std::runtime_error("Limit::Limit: Invalid Limit name: " + name);
-    }
-}
-
-Limit::Limit(const Limit& rhs) : n_(rhs.n_), lim_(rhs.lim_), value_(rhs.value_), paths_(rhs.paths_) {
-}
-
-bool Limit::operator==(const Limit& rhs) const {
-    if (value_ != rhs.value_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Limit::operator==value_(" << value_ << ") != rhs.value_(" << rhs.value_ << ") " << toString()
-                      << "   rhs(" << rhs.toString() << ")\n";
-        }
-#endif
-        return false;
-    }
-    if (lim_ != rhs.lim_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Limit::operator==( lim_ != rhs.lim_) " << toString() << "   rhs(" << rhs.toString() << ")\n";
-        }
-#endif
-        return false;
-    }
-    if (n_ != rhs.n_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Limit::operator==( n_ != rhs.n_ ) " << toString() << "   rhs(" << rhs.toString() << ")\n";
-        }
-#endif
-        return false;
-    }
-    if (paths_ != rhs.paths_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Limit::operator==( paths_ != rhs.paths_ ) " << toString() << "   rhs(" << rhs.toString()
-                      << ")\n";
-        }
-#endif
-        return false;
-    }
-    return true;
-}
-
-void Limit::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    write(os);
-    if (!PrintStyle::defsStyle()) {
-        if (value_ != 0) {
-            os += " # ";
-            os += ecf::convert_to<std::string>(value_);
-            for (const auto& path : paths_) {
-                os += " ";
-                os += path;
-            }
-        }
-    }
-    os += "\n";
-}
-
-std::string Limit::toString() const {
-    std::string ret;
-    write(ret);
-    return ret;
-}
-
-void Limit::write(std::string& ret) const {
-    ret += "limit ";
-    ret += n_;
-    ret += " ";
-    ret += ecf::convert_to<std::string>(lim_);
-}
-
-void Limit::decrement(int tokens, const std::string& abs_node_path) {
-
-    // cout << "Limit::decrement name = " << n_ << " current value_ = " << value_ << " limit = " <<  lim_ << " consume
-    // tokens = " << tokens << " path = " << abs_node_path << "\n"; Note: we previously had 'if (value_ > 0) {
-    //       However if the user had manually changed the value_, then we could be left with paths_,  that would never
-    //       have been cleared
-    if (delete_path(abs_node_path)) {
-        // delete_path() will increment state_change_no
-        value_ -= tokens;
-        if (value_ < 0) {
-            value_ = 0;
-            paths_.clear();
-        }
-    }
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Limit::decrement\n";
-#endif
-    // cout << "Limit::decrement name = " << n_ << " current value_ = " << value_ << "\n";
-}
-
-void Limit::increment(int tokens, const std::string& abs_node_path) {
-    // cout << "Limit::increment name = " << n_ << " current value_ = " << value_ << " limit = " <<  lim_ << " consume
-    // tokens = " << tokens << " path = " << abs_node_path << "\n";
-
-    // increment should keep increasing limit value, *EVEN* if over the limit. See ECFLOW-324
-    // Note: previously we had:
-    //     if ( value_ < lim_ ) {
-
-    auto result = paths_.insert(abs_node_path);
-    if (result.second) {
-        value_ += tokens;
-        update_change_no();
-    }
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Limit::increment\n";
-#endif
-    // cout << "Limit::increment name = " << n_ << " current value_ = " << value_ << "\n";
-}
-
-void Limit::setValue(int v) {
-    value_ = v;
-    if (value_ == 0)
-        paths_.clear();
-    update_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "   Limit::setValue() value_ = " << value_ << "\n";
-#endif
-}
-
-void Limit::setLimit(int v) {
-    lim_ = v;
-    update_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "   Limit::setLimit() lim_ = " << value_ << "\n";
-#endif
-}
-
-void Limit::set_paths(const std::set<std::string>& paths) {
-    paths_ = paths;
-    update_change_no();
-}
-
-void Limit::set_state(int limit, int value, const std::set<std::string>& paths) {
-    value_ = value;
-    lim_   = limit;
-    paths_ = paths;
-    update_change_no();
-}
-
-bool Limit::delete_path(const std::string& abs_node_path) {
-    auto i = paths_.find(abs_node_path);
-    if (i != paths_.end()) {
-        paths_.erase(i);
-        update_change_no();
-        return true;
-    }
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Limit::delete_path() \n";
-#endif
-    return false;
-}
-
-void Limit::reset() {
-    paths_.clear();
-    setValue(0); // will increment state_change_no_
-}
-
-void Limit::update_change_no() {
-    state_change_no_ = Ecf::incr_state_change_no();
-    if (node_) {
-        Suite* suite = node_->suite();
-        if (suite)
-            suite->set_state_change_no(state_change_no_);
-    }
-}
-
-template <class Archive>
-void Limit::serialize(Archive& ar) {
-    ar(CEREAL_NVP(n_), CEREAL_NVP(lim_));
-    CEREAL_OPTIONAL_NVP(ar, value_, [this]() { return value_ != 0; });     // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, paths_, [this]() { return !paths_.empty(); }); // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE(Limit);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Limit.hpp 5.13.0-1/ANode/src/ecflow/node/Limit.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Limit.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Limit.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,92 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Limit_HPP
-#define ecflow_node_Limit_HPP
-
-///
-/// \note Limit was placed in the ANode category because inlimit can reference
-/// Limit on *ANOTHER* suite. This presents a problem with incremental sync,
-/// since that requires access to a parent/suite, to mark the suite as changed.
-///
-/// To get round this issue the Node will set the parent pointer on the Limit
-/// this then makes it easy for incremental sync, since we directly access the
-/// parent suite
-///
-
-#include <set>
-#include <string>
-
-namespace cereal {
-class access;
-}
-class Node;
-
-// Class Limit: The limit is zero based, hence if limit is 10, increment must use < 10
-class Limit {
-public:
-    Limit(const std::string& name, int limit);
-    Limit(const std::string& name, int limit, int value, const std::set<std::string>& paths, bool check = true);
-    Limit() = default;
-    Limit(const Limit& rhs);
-
-    void print(std::string&) const;
-    bool operator==(const Limit& rhs) const;
-    bool operator<(const Limit& rhs) const { return n_ < rhs.name(); }
-    const std::string& name() const { return n_; }
-
-    Node* node() const { return node_; }
-    void set_node(Node* n) { node_ = n; }
-
-    void setValue(int v);
-    void setLimit(int v);
-    void set_state(int limit, int value, const std::set<std::string>& p); // for use by memento
-    void set_paths(const std::set<std::string>& p);
-
-    bool delete_path(const std::string& abs_node_path); // for use by AlterCmd
-    const std::set<std::string>& paths() const { return paths_; }
-
-    int value() const { return value_; }
-    bool inLimit(int inlimit_tokens) const { return ((value_ + inlimit_tokens) <= lim_); }
-    int theLimit() const { return lim_; }
-    void increment(int tokens, const std::string& abs_node_path);
-    void decrement(int tokens, const std::string& abs_node_path);
-    void reset();
-
-    // The state_change_no is never reset. Must be incremented if it can affect equality
-    unsigned int state_change_no() const { return state_change_no_; }
-
-    // for python interface
-    std::string toString() const;
-
-    // ECFLOW-518, we can't use:
-    //    std::set<std::string>::const_iterator paths_begin() const { return paths_.begin();}
-    //    std::set<std::string>::const_iterator paths_end() const { return paths_.end();}
-    // because boost python does not support std::set<std::string> out of the box
-    // we will wrap and return list instead. See ExportNodeAttr.cpp
-
-private:
-    void update_change_no();
-    void write(std::string&) const;
-
-private:
-    std::string n_;
-    Node* node_{nullptr};             // The parent NOT persisted
-    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
-    int lim_{0};
-    int value_{0};
-    std::set<std::string> paths_; // Updated via increment()/decrement()/reset(). Typically task paths
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar);
-};
-
-#endif /* ecflow_node_Limit_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/LimitFwd.hpp 5.13.0-1/ANode/src/ecflow/node/LimitFwd.hpp
--- 5.12.4-1/ANode/src/ecflow/node/LimitFwd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/LimitFwd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_LimitFwd_HPP
-#define ecflow_node_LimitFwd_HPP
-
-#include <memory>
-
-class Limit;
-typedef std::shared_ptr<Limit> limit_ptr;
-
-#endif /* ecflow_node_LimitFwd_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Memento.cpp 5.13.0-1/ANode/src/ecflow/node/Memento.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Memento.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Memento.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,401 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Memento.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/cereal_boost_time.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// #define DEBUG_MEMENTO 1
-
-// ===============================================================
-Memento::~Memento() = default;
-
-// ===============================================================
-void CompoundMemento::incremental_sync(defs_ptr client_def) const {
-    /// Clear out aspects, for this Memento.
-    ///   Aspects are added via do_incremental_* / set_mememto functions
-    ///   AND in *this* function when node attributes have been added or deleted.
-    aspects_.clear();
-
-    node_ptr node = client_def->findAbsNode(absNodePath_);
-    if (!node.get()) {
-        if (absNodePath_ != Str::ROOT_PATH()) {
-
-            // add more context, about what's suites are in the client defs.
-            std::string error_msg = "CompoundMemento::incremental_sync: could not find path ";
-            error_msg += absNodePath_;
-            error_msg += "\nClient has the following suites: ";
-            for (const auto& suite : client_def->suiteVec()) {
-                error_msg += suite->name();
-                error_msg += ",";
-            }
-            throw std::runtime_error(error_msg);
-        }
-
-#ifdef DEBUG_MEMENTO
-        cout << "CompoundMemento::incremental_sync: ROOT_PATH\n";
-#endif
-        //
-        // Notify observers what aspect is going to change, before make-ing data model changes
-        //
-        for (memento_ptr m : vec_) {
-            m->do_incremental_defs_sync(
-                client_def.get(), aspects_, true /* collect aspects only, don't make any changes*/);
-        }
-        size_t aspect_size = aspects_.size();
-        client_def->notify_start(aspects_);
-
-        /// make data model change.
-        /// Notify any interested parties incremental changes
-        /// Aspects records the kind of changes.
-        for (memento_ptr m : vec_) {
-#ifdef DEBUG_MEMENTO
-            cout << "   " << typeid(*(m.get())).name() << "\n";
-#endif
-            m->do_incremental_defs_sync(client_def.get(), aspects_, false /*Data model changes only*/);
-        }
-        if (aspect_size != aspects_.size()) {
-            assert(aspect_size == aspects_.size()); // aspect size should not change, when making data model changes
-        }
-        client_def->notify(aspects_);
-    }
-    else {
-
-#ifdef DEBUG_MEMENTO
-        cout << "CompoundMemento::incremental_sync: " << node->debugNodePath() << "\n";
-#endif
-        // Notify observers what aspect, is going to change.
-        Task* task     = node->isTask();
-        Alias* alias   = node->isAlias();
-        Suite* suite   = node->isSuite();
-        Family* family = node->isFamily();
-
-        if (clear_attributes_)
-            aspects_.push_back(ecf::Aspect::ADD_REMOVE_ATTR);
-
-        for (memento_ptr m : vec_) {
-#ifdef DEBUG_MEMENTO
-            cout << "   " << typeid(*(m.get())).name() << "\n";
-#endif
-            if (task)
-                m->do_incremental_task_sync(task, aspects_, true /* collect aspects only, don't make any changes*/);
-            else if (alias)
-                m->do_incremental_alias_sync(alias, aspects_, true /* collect aspects only, don't make any changes*/);
-            else if (suite)
-                m->do_incremental_suite_sync(suite, aspects_, true /* collect aspects only, don't make any changes*/);
-            else if (family)
-                m->do_incremental_family_sync(family, aspects_, true /* collect aspects only, don't make any changes*/);
-            m->do_incremental_node_sync(node.get(), aspects_, true /* collect aspects only, don't make any changes*/);
-        }
-        size_t aspect_size = aspects_.size();
-        node->notify_start(aspects_);
-
-        //
-        // data model changes only, aspects should not change
-        //
-        if (clear_attributes_)
-            node->clear();
-
-        for (memento_ptr m : vec_) {
-            if (task)
-                m->do_incremental_task_sync(task, aspects_, false /*Data model changes only*/);
-            else if (alias)
-                m->do_incremental_alias_sync(alias, aspects_, false /*Data model changes only*/);
-            else if (suite)
-                m->do_incremental_suite_sync(suite, aspects_, false /*Data model changes only*/);
-            else if (family)
-                m->do_incremental_family_sync(family, aspects_, false /*Data model changes only*/);
-            m->do_incremental_node_sync(node.get(), aspects_, false /*Data model changes only*/);
-        }
-        if (aspect_size != aspects_.size()) {
-            assert(aspect_size == aspects_.size()); // aspect size should not change, when making data model changes
-        }
-
-        /// Notify any interested parties that Node has made incremental changes
-        /// Aspects records the kind of changes.
-        node->notify(aspects_);
-    }
-}
-
-// ===================================================================================================
-
-template <class Archive>
-void Memento::serialize(Archive& ar, std::uint32_t const version) {
-}
-
-template <class Archive>
-void CompoundMemento::serialize(Archive& ar, std::uint32_t const version) {
-    CEREAL_OPTIONAL_NVP(ar, clear_attributes_, [this]() { return clear_attributes_; }); // conditionally save
-    ar(CEREAL_NVP(absNodePath_), CEREAL_NVP(vec_));
-}
-
-template <class Archive>
-void StateMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
-}
-
-template <class Archive>
-void NodeStateMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
-}
-
-template <class Archive>
-void OrderMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(order_));
-}
-
-template <class Archive>
-void ChildrenMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(children_));
-}
-
-template <class Archive>
-void AliasChildrenMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(children_));
-}
-
-template <class Archive>
-void AliasNumberMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(alias_no_));
-}
-
-template <class Archive>
-void SuspendedMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(suspended_));
-}
-
-template <class Archive>
-void ServerStateMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
-}
-
-template <class Archive>
-void ServerVariableMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(serverEnv_));
-}
-
-template <class Archive>
-void NodeDefStatusDeltaMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
-}
-
-template <class Archive>
-void NodeEventMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(event_));
-}
-
-template <class Archive>
-void NodeMeterMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(meter_));
-}
-
-template <class Archive>
-void NodeLabelMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(label_));
-}
-
-template <class Archive>
-void NodeQueueMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(queue_));
-}
-
-template <class Archive>
-void NodeGenericMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(generic_));
-}
-
-template <class Archive>
-void NodeQueueIndexMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(index_), CEREAL_NVP(name_), CEREAL_NVP(state_vec_));
-}
-
-template <class Archive>
-void NodeTriggerMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(exp_));
-}
-
-template <class Archive>
-void NodeCompleteMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(exp_));
-}
-
-template <class Archive>
-void NodeRepeatMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(repeat_));
-}
-
-template <class Archive>
-void NodeRepeatIndexMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(index_or_value_));
-}
-
-template <class Archive>
-void NodeLimitMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(limit_));
-}
-
-template <class Archive>
-void NodeInLimitMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(inlimit_));
-}
-
-template <class Archive>
-void NodeVariableMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(var_));
-}
-
-template <class Archive>
-void NodeLateMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(late_));
-}
-
-template <class Archive>
-void FlagMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(flag_));
-}
-
-template <class Archive>
-void NodeTodayMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
-}
-
-template <class Archive>
-void NodeTimeMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
-}
-
-template <class Archive>
-void NodeDayMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
-}
-
-template <class Archive>
-void NodeCronMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
-}
-
-template <class Archive>
-void NodeDateMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
-}
-
-template <class Archive>
-void NodeZombieMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
-}
-
-template <class Archive>
-void NodeVerifyMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(verifys_));
-}
-
-template <class Archive>
-void SubmittableMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(paswd_), CEREAL_NVP(rid_), CEREAL_NVP(abr_), CEREAL_NVP(tryNo_));
-}
-
-template <class Archive>
-void SuiteClockMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(clockAttr_));
-}
-
-template <class Archive>
-void SuiteBeginDeltaMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(begun_));
-}
-
-template <class Archive>
-void SuiteCalendarMemento::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Memento>(this), CEREAL_NVP(cal_));
-}
-
-CEREAL_TEMPLATE_SPECIALIZE_V(Memento);
-CEREAL_TEMPLATE_SPECIALIZE_V(CompoundMemento);
-
-CEREAL_TEMPLATE_SPECIALIZE_V(StateMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeStateMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeDefStatusDeltaMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(SuspendedMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(ServerStateMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(ServerVariableMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeEventMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeMeterMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeLabelMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeQueueMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeGenericMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeQueueIndexMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeTriggerMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeCompleteMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeRepeatMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeRepeatIndexMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeLimitMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeInLimitMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeVariableMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeLateMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeTodayMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeTimeMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeDayMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeCronMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeDateMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeZombieMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeVerifyMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(FlagMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(SubmittableMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(SuiteClockMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(SuiteBeginDeltaMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(SuiteCalendarMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(OrderMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(ChildrenMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(AliasChildrenMemento);
-CEREAL_TEMPLATE_SPECIALIZE_V(AliasNumberMemento);
-
-CEREAL_REGISTER_TYPE(StateMemento)
-CEREAL_REGISTER_TYPE(NodeStateMemento)
-CEREAL_REGISTER_TYPE(NodeDefStatusDeltaMemento)
-CEREAL_REGISTER_TYPE(SuspendedMemento)
-CEREAL_REGISTER_TYPE(ServerStateMemento)
-CEREAL_REGISTER_TYPE(ServerVariableMemento)
-CEREAL_REGISTER_TYPE(NodeEventMemento)
-CEREAL_REGISTER_TYPE(NodeMeterMemento)
-CEREAL_REGISTER_TYPE(NodeLabelMemento)
-CEREAL_REGISTER_TYPE(NodeQueueMemento)
-CEREAL_REGISTER_TYPE(NodeGenericMemento)
-CEREAL_REGISTER_TYPE(NodeQueueIndexMemento)
-CEREAL_REGISTER_TYPE(NodeTriggerMemento)
-CEREAL_REGISTER_TYPE(NodeCompleteMemento)
-CEREAL_REGISTER_TYPE(NodeRepeatMemento)
-CEREAL_REGISTER_TYPE(NodeRepeatIndexMemento)
-CEREAL_REGISTER_TYPE(NodeLimitMemento)
-CEREAL_REGISTER_TYPE(NodeInLimitMemento)
-CEREAL_REGISTER_TYPE(NodeVariableMemento)
-CEREAL_REGISTER_TYPE(NodeLateMemento)
-CEREAL_REGISTER_TYPE(NodeTodayMemento)
-CEREAL_REGISTER_TYPE(NodeTimeMemento)
-CEREAL_REGISTER_TYPE(NodeDayMemento)
-CEREAL_REGISTER_TYPE(NodeCronMemento)
-CEREAL_REGISTER_TYPE(NodeDateMemento)
-CEREAL_REGISTER_TYPE(NodeZombieMemento)
-CEREAL_REGISTER_TYPE(NodeVerifyMemento)
-CEREAL_REGISTER_TYPE(FlagMemento)
-CEREAL_REGISTER_TYPE(SubmittableMemento)
-CEREAL_REGISTER_TYPE(SuiteClockMemento)
-CEREAL_REGISTER_TYPE(SuiteBeginDeltaMemento)
-CEREAL_REGISTER_TYPE(SuiteCalendarMemento)
-CEREAL_REGISTER_TYPE(OrderMemento)
-CEREAL_REGISTER_TYPE(ChildrenMemento)
-CEREAL_REGISTER_TYPE(AliasChildrenMemento)
-CEREAL_REGISTER_TYPE(AliasNumberMemento)
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Memento.hpp 5.13.0-1/ANode/src/ecflow/node/Memento.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Memento.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Memento.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,794 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Memento_HPP
-#define ecflow_node_Memento_HPP
-
-///
-/// \note Classes derived from Memento are stored on DefsDelta.
-/// DefsDelta is transferred from Server to Client during a sync. See SSyncCmd.hpp
-///
-/// Are created in the server, but used by the client to sync.
-///
-/// Used to capture incremental change of state, to node, and node attributes
-/// Serve as a base class of all memento's
-/// Later on the client side, the changes can be applied. via incremental_sync()
-/// The are several kind of changes that we can capture:
-///   a/ simple state changes,
-///   b/ Change in attribute structure
-///   c/ Deletion of attribute
-///   d/ Addition of an attribute
-///   e/ Add/delete of a Family/task
-///   f/ Add/Delete of suite
-///
-/// The main emphasis here is to capture a,b,c,d,e. This is easily handled by state_change_no.
-/// option f/ is handled via a full update and hence does not use mementos
-///
-/// ISSUES: AIX has issues with TOC(table of contents) overflow. This is heavily
-/// influenced by the number of global symbols. Unfortunately each boost serializable
-/// type, greatly increases the number of globals.
-/// Hence, we need to ensure we use the minimum number of serializable types.
-///
-
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-// #define DEBUG_MEMENTO 1
-
-class Memento {
-public:
-    Memento()               = default;
-    Memento(const Memento&) = delete;
-    virtual ~Memento();
-
-    Memento& operator=(const Memento&) = delete;
-
-private:
-    /// Applies the mementos to the client side defs. Can raise std::runtime_error
-    virtual void do_incremental_node_sync(Node*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
-    virtual void do_incremental_task_sync(Task*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
-    virtual void do_incremental_alias_sync(Alias*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
-    virtual void do_incremental_suite_sync(Suite*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
-    virtual void do_incremental_family_sync(Family*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
-    virtual void do_incremental_defs_sync(Defs*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
-    friend class CompoundMemento;
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-// Used for storing all the memento's associated with a single node
-// This allows to make only *ONE* call to find the node.
-// The mementos are then applied to this single node.
-class CompoundMemento {
-public:
-    explicit CompoundMemento(const std::string& absNodePath) : absNodePath_(absNodePath) {}
-
-    CompoundMemento() = default; // for serialization
-
-    void incremental_sync(defs_ptr client_def) const;
-    void add(memento_ptr m) { vec_.push_back(m); }
-    void clear_attributes() { clear_attributes_ = true; }
-
-    const std::string& abs_node_path() const { return absNodePath_; }
-
-private:
-    std::string absNodePath_;
-    std::vector<memento_ptr> vec_;
-    mutable std::vector<ecf::Aspect::Type> aspects_; // not persisted only used on client side
-    bool clear_attributes_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class StateMemento : public Memento {
-public:
-    explicit StateMemento(NState::State state) : state_(state) {}
-    StateMemento() = default;
-
-private:
-    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        defs->set_memento(this, aspects, f);
-    }
-
-    NState::State state_{NState::UNKNOWN};
-    friend class Defs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeStateMemento : public Memento {
-public:
-    explicit NodeStateMemento(std::pair<NState::State, boost::posix_time::time_duration> state) : state_(state) {}
-    NodeStateMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    std::pair<NState::State, boost::posix_time::time_duration> state_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class OrderMemento : public Memento {
-public:
-    explicit OrderMemento(const std::vector<std::string>& order) : order_(order) {}
-    OrderMemento() = default;
-
-private:
-    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        defs->set_memento(this, aspects, f);
-    }
-    void do_incremental_suite_sync(Suite* s, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        s->set_memento(this, aspects, f);
-    }
-    void do_incremental_family_sync(Family* f, std::vector<ecf::Aspect::Type>& aspects, bool ff) const override {
-        f->set_memento(this, aspects, ff);
-    }
-    void do_incremental_task_sync(Task* t, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        t->set_memento(this, aspects, f);
-    }
-
-    std::vector<std::string> order_;
-    friend class NodeContainer;
-    friend class Task;
-    friend class Defs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class ChildrenMemento : public Memento {
-public:
-    explicit ChildrenMemento(const std::vector<node_ptr>& children) : children_(children) {}
-    ChildrenMemento() = default;
-
-private:
-    void do_incremental_suite_sync(Suite* s, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        s->set_memento(this, aspects, f);
-    }
-    void do_incremental_family_sync(Family* f, std::vector<ecf::Aspect::Type>& aspects, bool ff) const override {
-        f->set_memento(this, aspects, ff);
-    }
-
-    std::vector<node_ptr> children_;
-    friend class NodeContainer;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class AliasChildrenMemento : public Memento {
-public:
-    explicit AliasChildrenMemento(const std::vector<alias_ptr>& children) : children_(children) {}
-    AliasChildrenMemento() = default;
-
-private:
-    void do_incremental_task_sync(Task* t, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        t->set_memento(this, aspects, f);
-    }
-
-    std::vector<alias_ptr> children_;
-    friend class Task;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class AliasNumberMemento : public Memento {
-public:
-    explicit AliasNumberMemento(unsigned int alias_no) : alias_no_(alias_no) {}
-    AliasNumberMemento() = default;
-
-private:
-    void do_incremental_task_sync(Task* t, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        t->set_memento(this, aspects, f);
-    }
-
-    unsigned int alias_no_{0};
-    friend class Task;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class SuspendedMemento : public Memento {
-public:
-    explicit SuspendedMemento(bool suspended) : suspended_(suspended) {}
-    SuspendedMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    bool suspended_{false};
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class ServerStateMemento : public Memento {
-public:
-    explicit ServerStateMemento(SState::State s) : state_(s) {}
-    ServerStateMemento() = default;
-
-private:
-    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        defs->set_memento(this, aspects, f);
-    }
-
-    SState::State state_{SState::HALTED};
-    friend class Defs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class ServerVariableMemento : public Memento {
-public:
-    explicit ServerVariableMemento(const std::vector<Variable>& vec) : serverEnv_(vec) {}
-    ServerVariableMemento() = default;
-
-private:
-    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        defs->set_memento(this, aspects, f);
-    }
-
-    std::vector<Variable> serverEnv_;
-    friend class Defs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeDefStatusDeltaMemento : public Memento {
-public:
-    explicit NodeDefStatusDeltaMemento(DState::State state) : state_(state) {}
-    NodeDefStatusDeltaMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    DState::State state_{DState::UNKNOWN};
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeEventMemento : public Memento {
-public:
-    explicit NodeEventMemento(const Event& e) : event_(e) {}
-    NodeEventMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Event event_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeMeterMemento : public Memento {
-public:
-    explicit NodeMeterMemento(const Meter& e) : meter_(e) {}
-    NodeMeterMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Meter meter_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeLabelMemento : public Memento {
-public:
-    explicit NodeLabelMemento(const Label& e) : label_(e) {}
-    NodeLabelMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Label label_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeQueueMemento : public Memento {
-public:
-    explicit NodeQueueMemento(const QueueAttr& e) : queue_(e) {}
-    NodeQueueMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    QueueAttr queue_;
-    friend class Node;
-    friend class MiscAttrs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeGenericMemento : public Memento {
-public:
-    explicit NodeGenericMemento(const GenericAttr& e) : generic_(e) {}
-    NodeGenericMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    GenericAttr generic_;
-    friend class Node;
-    friend class MiscAttrs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeQueueIndexMemento : public Memento {
-public:
-    NodeQueueIndexMemento(const std::string& name, int index, const std::vector<NState::State>& state_vec)
-        : name_(name),
-          state_vec_(state_vec),
-          index_(index) {}
-    NodeQueueIndexMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    std::string name_;
-    std::vector<NState::State> state_vec_;
-    int index_{0};
-    friend class Node;
-    friend class MiscAttrs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeTriggerMemento : public Memento {
-public:
-    explicit NodeTriggerMemento(const Expression& e) : exp_(e) {}
-    NodeTriggerMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Expression exp_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeCompleteMemento : public Memento {
-public:
-    explicit NodeCompleteMemento(const Expression& e) : exp_(e) {}
-    NodeCompleteMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Expression exp_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeRepeatMemento : public Memento {
-public:
-    explicit NodeRepeatMemento(const Repeat& e) : repeat_(e) {}
-    NodeRepeatMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Repeat repeat_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeRepeatIndexMemento : public Memento {
-public:
-    explicit NodeRepeatIndexMemento(const Repeat& e) : index_or_value_(e.index_or_value()) {}
-    NodeRepeatIndexMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    long index_or_value_{0};
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeLimitMemento : public Memento {
-public:
-    explicit NodeLimitMemento(const Limit& e) : limit_(e) {}
-    NodeLimitMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Limit limit_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeInLimitMemento : public Memento {
-public:
-    explicit NodeInLimitMemento(const InLimit& e) : inlimit_(e) {}
-    NodeInLimitMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    InLimit inlimit_;
-    friend class Node;
-    friend class InLimitMgr;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeVariableMemento : public Memento {
-public:
-    explicit NodeVariableMemento(const Variable& e) : var_(e) {}
-    NodeVariableMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    Variable var_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeLateMemento : public Memento {
-public:
-    explicit NodeLateMemento(const ecf::LateAttr& e) : late_(e) {}
-    NodeLateMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    ecf::LateAttr late_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class FlagMemento : public Memento {
-public:
-    explicit FlagMemento(const ecf::Flag& e) : flag_(e) {}
-    FlagMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        defs->set_memento(this, aspects, f);
-    }
-
-    ecf::Flag flag_;
-    friend class Node;
-    friend class Defs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeTodayMemento : public Memento {
-public:
-    explicit NodeTodayMemento(const ecf::TodayAttr& attr) : attr_(attr) {}
-    NodeTodayMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    ecf::TodayAttr attr_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeTimeMemento : public Memento {
-public:
-    explicit NodeTimeMemento(const ecf::TimeAttr& attr) : attr_(attr) {}
-    NodeTimeMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    ecf::TimeAttr attr_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeDayMemento : public Memento {
-public:
-    explicit NodeDayMemento(const DayAttr& attr) : attr_(attr) {}
-    NodeDayMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    DayAttr attr_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeCronMemento : public Memento {
-public:
-    explicit NodeCronMemento(const ecf::CronAttr& attr) : attr_(attr) {}
-    NodeCronMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    ecf::CronAttr attr_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeDateMemento : public Memento {
-public:
-    explicit NodeDateMemento(const DateAttr& attr) : attr_(attr) {}
-    NodeDateMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    DateAttr attr_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeZombieMemento : public Memento {
-public:
-    explicit NodeZombieMemento(const ZombieAttr& attr) : attr_(attr) {}
-    NodeZombieMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    ZombieAttr attr_;
-    friend class Node;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class NodeVerifyMemento : public Memento {
-public:
-    explicit NodeVerifyMemento(const std::vector<VerifyAttr>& attr) : verifys_(attr) {}
-    NodeVerifyMemento() = default;
-
-private:
-    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    std::vector<VerifyAttr> verifys_;
-    friend class Node;
-    friend class MiscAttrs;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class SubmittableMemento : public Memento {
-public:
-    SubmittableMemento(const std::string& jobsPassword,
-                       const std::string& process_or_remote_id,
-                       const std::string& abortedReason,
-                       int tryNo)
-        : paswd_(jobsPassword),
-          rid_(process_or_remote_id),
-          abr_(abortedReason),
-          tryNo_(tryNo) {}
-    SubmittableMemento() = default;
-
-private:
-    void do_incremental_task_sync(Task* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-    void do_incremental_alias_sync(Alias* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    std::string paswd_;
-    std::string rid_;
-    std::string abr_;
-    int tryNo_{0};
-    friend class Submittable;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class SuiteClockMemento : public Memento {
-public:
-    explicit SuiteClockMemento(const ClockAttr& c) : clockAttr_(c) {}
-    SuiteClockMemento() = default;
-
-private:
-    void do_incremental_suite_sync(Suite* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    ClockAttr clockAttr_;
-    friend class Suite;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class SuiteBeginDeltaMemento : public Memento {
-public:
-    explicit SuiteBeginDeltaMemento(bool begun) : begun_(begun) {}
-    SuiteBeginDeltaMemento() = default;
-
-private:
-    void do_incremental_suite_sync(Suite* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    bool begun_{false};
-    friend class Suite;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-class SuiteCalendarMemento : public Memento {
-public:
-    explicit SuiteCalendarMemento(const ecf::Calendar& cal) : cal_(cal) {}
-    SuiteCalendarMemento() = default;
-
-private:
-    void do_incremental_suite_sync(Suite* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
-        n->set_memento(this, aspects, f);
-    }
-
-    ecf::Calendar cal_; // *Only* persisted since used by the why() on client side
-    friend class Suite;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_node_Memento_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/MiscAttrs.cpp 5.13.0-1/ANode/src/ecflow/node/MiscAttrs.cpp
--- 5.12.4-1/ANode/src/ecflow/node/MiscAttrs.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/MiscAttrs.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,356 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/MiscAttrs.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/Node.hpp"
-
-#ifdef DEBUG
-    #include <iostream>
-#endif
-
-using namespace ecf;
-using namespace std;
-
-///////////////////////////////////////////////////////////////////////////////////////////
-
-MiscAttrs::MiscAttrs(const MiscAttrs& rhs)
-    : zombies_(rhs.zombies_),
-      verifys_(rhs.verifys_),
-      queues_(rhs.queues_),
-      generics_(rhs.generics_) {
-}
-
-MiscAttrs::~MiscAttrs() = default;
-
-// needed by node serialisation
-void MiscAttrs::set_node(Node* n) {
-    node_ = n;
-}
-
-bool MiscAttrs::checkInvariants(std::string& errorMsg) const {
-    if (!node_) {
-        errorMsg += "MiscAttrs::checkInvariants: failed node_ is NULL";
-        return false;
-    }
-    return true;
-}
-
-void MiscAttrs::begin() {
-    // reset verification
-    for (auto& verify : verifys_) {
-        verify.reset();
-    }
-    for (auto& queue : queues_) {
-        queue.requeue();
-    }
-}
-
-void MiscAttrs::requeue() {
-    for (auto& queue : queues_) {
-        queue.requeue();
-    }
-}
-
-void MiscAttrs::print(std::string& os) const {
-    for (const ZombieAttr& z : zombies_) {
-        z.print(os);
-    }
-    for (const VerifyAttr& v : verifys_) {
-        v.print(os);
-    }
-    for (const QueueAttr& q : queues_) {
-        q.print(os);
-    }
-    for (const GenericAttr& g : generics_) {
-        g.print(os);
-    }
-}
-
-bool MiscAttrs::operator==(const MiscAttrs& rhs) const {
-    if (zombies_.size() != rhs.zombies_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "MiscAttrs::operator==   (zombies_.size() != rhs.zombies_.size()) " << node_->debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < zombies_.size(); ++i) {
-        if (!(zombies_[i] == rhs.zombies_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "MiscAttrs::operator==   (!(zombies_[i] == rhs.zombies_[i]) " << node_->debugNodePath()
-                          << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (queues_.size() != rhs.queues_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "MiscAttrs::operator==   (queues_.size() != rhs.queues_.size()) " << node_->debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < queues_.size(); ++i) {
-        if (!(queues_[i] == rhs.queues_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "MiscAttrs::operator==   (!(queues_[i] == rhs.queues_[i]) " << node_->debugNodePath()
-                          << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (verifys_.size() != rhs.verifys_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "MiscAttrs::operator==  (verifys_.size() != rhs.verifys_.size()) " << node_->debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < verifys_.size(); ++i) {
-        if (!(verifys_[i] == rhs.verifys_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "MiscAttrs::operator==  (!(verifys_[i] == rhs.verifys_[i] ))  " << node_->debugNodePath()
-                          << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (generics_.size() != rhs.generics_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "MiscAttrs::operator==  (generics_.size() != rhs.generics_.size()) " << node_->debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < generics_.size(); ++i) {
-        if (!(generics_[i] == rhs.generics_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "MiscAttrs::operator==  (!(generics_ [i] == rhs.generics_[i] ))  "
-                          << node_->debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-    return true;
-}
-
-void MiscAttrs::verification(std::string& errorMsg) const {
-    for (const VerifyAttr& v : verifys_) {
-        if (v.expected() != v.actual()) {
-            std::stringstream ss;
-            ss << node_->debugNodePath() << " expected " << v.expected() << " " << NState::toString(v.state())
-               << " but found " << v.actual() << "\n";
-            errorMsg += ss.str();
-        }
-    }
-}
-
-void MiscAttrs::addZombie(const ZombieAttr& z) {
-    const ZombieAttr& theFndOne = findZombie(z.zombie_type());
-    if (!theFndOne.empty()) {
-        std::stringstream ss;
-        ss << "MiscAttrs::addZombie: Node " << node_->absNodePath() << " already has a zombie attribute of type "
-           << Child::to_string(theFndOne.zombie_type()) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-    zombies_.push_back(z);
-    node_->state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "MiscAttrs::addZombie()\n";
-#endif
-}
-
-void MiscAttrs::deleteZombie(const std::string& zombie_type) {
-    if (zombie_type.empty()) {
-        zombies_.clear();
-        node_->state_change_no_ = Ecf::incr_state_change_no();
-        return;
-    }
-
-    if (!Child::valid_zombie_type(zombie_type)) {
-        throw std::runtime_error(
-            "MiscAttrs::deleteZombie failed: Expected one of [ ecf | path | user ] or empty string but found " +
-            zombie_type);
-    }
-    delete_zombie(Child::zombie_type(zombie_type));
-}
-
-void MiscAttrs::delete_zombie(Child::ZombieType zt) {
-    for (size_t i = 0; i < zombies_.size(); ++i) {
-        if (zombies_[i].zombie_type() == zt) {
-            zombies_.erase(zombies_.begin() + i);
-            node_->state_change_no_ = Ecf::incr_state_change_no();
-            return;
-        }
-    }
-}
-
-const ZombieAttr& MiscAttrs::findZombie(ecf::Child::ZombieType zombie_type) const {
-    /// There should only be one of each type
-    for (const auto& zombie : zombies_) {
-        if (zombie.zombie_type() == zombie_type) {
-            return zombie;
-        }
-    }
-    return ZombieAttr::EMPTY();
-}
-
-void MiscAttrs::add_generic(const GenericAttr& z) {
-    const GenericAttr& theFndOne = find_generic(z.name());
-    if (!theFndOne.empty()) {
-        std::stringstream ss;
-        ss << "MiscAttrs::add_generic : Node " << node_->absNodePath() << " already has a generic attribute of name "
-           << z.name() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-    generics_.push_back(z);
-    node_->state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
-}
-
-void MiscAttrs::addVerify(const VerifyAttr& v) {
-    if (findVerify(v)) {
-        std::stringstream ss;
-        ss << "Add Verify failed: Duplicate '" << v.toString() << "' already exist for node " << node_->debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    verifys_.push_back(v);
-    node_->state_change_no_ = Ecf::incr_state_change_no();
-}
-
-bool MiscAttrs::findVerify(const VerifyAttr& v) const {
-    size_t theSize = verifys_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (verifys_[i].state() == v.state()) {
-            return true;
-        }
-    }
-    return false;
-}
-
-void MiscAttrs::add_queue(const QueueAttr& q) {
-    const QueueAttr& theFndOne = find_queue(q.name());
-    if (!theFndOne.empty()) {
-        std::stringstream ss;
-        ss << "MiscAttrs::add_queue: Node " << node_->absNodePath() << " already has a queue attribute of name "
-           << q.name() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-    queues_.push_back(q);
-    node_->state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
-}
-
-void MiscAttrs::delete_queue(const std::string& name) {
-    if (name.empty()) {
-        queues_.clear();
-        node_->state_change_no_ = Ecf::incr_state_change_no();
-        return;
-    }
-    for (size_t i = 0; i < queues_.size(); ++i) {
-        if (queues_[i].name() == name) {
-            queues_.erase(queues_.begin() + i);
-            node_->state_change_no_ = Ecf::incr_state_change_no();
-            return;
-        }
-    }
-}
-
-const QueueAttr& MiscAttrs::find_queue(const std::string& name) const {
-    for (const auto& queue : queues_) {
-        if (queue.name() == name) {
-            return queue;
-        }
-    }
-    return QueueAttr::EMPTY();
-}
-
-QueueAttr& MiscAttrs::findQueue(const std::string& name) {
-    for (auto& queue : queues_) {
-        if (queue.name() == name) {
-            return queue;
-        }
-    }
-    return QueueAttr::EMPTY1();
-}
-
-void MiscAttrs::delete_generic(const std::string& name) {
-    if (name.empty()) {
-        generics_.clear();
-        node_->state_change_no_ = Ecf::incr_state_change_no();
-        return;
-    }
-    for (size_t i = 0; i < generics_.size(); ++i) {
-        if (generics_[i].name() == name) {
-            generics_.erase(generics_.begin() + i);
-            node_->state_change_no_ = Ecf::incr_state_change_no();
-            return;
-        }
-    }
-}
-
-const GenericAttr& MiscAttrs::find_generic(const std::string& name) const {
-    for (const auto& generic : generics_) {
-        if (generic.name() == name) {
-            return generic;
-        }
-    }
-    return GenericAttr::EMPTY();
-}
-
-void MiscAttrs::set_memento(const NodeQueueMemento* m) {
-    add_queue(m->queue_);
-}
-
-void MiscAttrs::set_memento(const NodeGenericMemento* m) {
-    add_generic(m->generic_);
-}
-
-void MiscAttrs::set_memento(const NodeQueueIndexMemento* m) {
-    for (auto& queue : queues_) {
-        if (queue.name() == m->name_) {
-            queue.set_index(m->index_);
-            queue.set_state_vec(m->state_vec_);
-        }
-    }
-}
-
-template <class Archive>
-void MiscAttrs::serialize(Archive& ar, std::uint32_t const version) {
-    CEREAL_OPTIONAL_NVP(ar, zombies_, [this]() { return !zombies_.empty(); });   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, verifys_, [this]() { return !verifys_.empty(); });   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, queues_, [this]() { return !queues_.empty(); });     // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, generics_, [this]() { return !generics_.empty(); }); // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(MiscAttrs);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/MiscAttrs.hpp 5.13.0-1/ANode/src/ecflow/node/MiscAttrs.hpp
--- 5.12.4-1/ANode/src/ecflow/node/MiscAttrs.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/MiscAttrs.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,107 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_MiscAttrs_HPP
-#define ecflow_node_MiscAttrs_HPP
-
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/node/Node.hpp"
-
-class MiscAttrs {
-public:
-    MiscAttrs() = default;
-    MiscAttrs(const MiscAttrs& rhs);
-    explicit MiscAttrs(Node* node) : node_(node) {}
-    ~MiscAttrs();
-
-    MiscAttrs& operator=(const MiscAttrs&) = delete;
-
-    // needed by node serialisation
-    void set_node(Node* n);
-    bool checkInvariants(std::string& errorMsg) const;
-
-    void begin();
-    void requeue();
-
-    // standard functions: ==============================================
-    void print(std::string&) const;
-    bool operator==(const MiscAttrs&) const;
-
-    // Access functions: ======================================================
-    const std::vector<VerifyAttr>& verifys() const { return verifys_; }
-    const std::vector<ZombieAttr>& zombies() const { return zombies_; }
-    const std::vector<QueueAttr>& queues() const { return queues_; }
-    const std::vector<GenericAttr>& generics() const { return generics_; }
-    std::vector<QueueAttr>& ref_queues() { return queues_; } // allow simulator access
-
-    // Add functions: ===============================================================
-    void addVerify(const VerifyAttr&);    // for testing and verification Can throw std::runtime_error
-    void addZombie(const ZombieAttr&);    // will throw std::runtime_error if duplicate
-    void add_queue(const QueueAttr&);     // will throw std::runtime_error if duplicate
-    void add_generic(const GenericAttr&); // will throw std::runtime_error if duplicate, must be unique on the key
-
-    /// Check to see if auto_restore can reference the nodes
-    void check(std::string& errorMsg) const;
-
-    // Delete functions: can throw std::runtime_error ===================================
-    // if name argument is empty, delete all attributes of that type
-    // Can throw std::runtime_error of the attribute cannot be found
-    void delete_zombie(const ecf::Child::ZombieType);
-    void deleteZombie(const std::string& type);   // string must be one of [ user | ecf | path ]
-    void delete_queue(const std::string& name);   // empty string means delete all queue's
-    void delete_generic(const std::string& name); // empty string means delete all generics
-
-    // Find functions: ============================================================
-    bool findVerify(const VerifyAttr&) const;
-    const ZombieAttr& findZombie(ecf::Child::ZombieType) const;
-    const QueueAttr& find_queue(const std::string& name) const;
-    const GenericAttr& find_generic(const std::string& name) const;
-    QueueAttr& findQueue(const std::string& name);
-
-    void verification(std::string& errorMsg) const;
-
-    void set_memento(const NodeGenericMemento*);
-    void set_memento(const NodeQueueMemento*);
-    void set_memento(const NodeQueueIndexMemento*);
-
-    bool empty() const {
-        return (zombies_.empty() && verifys_.empty() && queues_.empty() && generics_.empty()) ? true : false;
-    }
-
-private:
-    std::vector<ZombieAttr>::const_iterator zombie_begin() const { return zombies_.begin(); }
-    std::vector<ZombieAttr>::const_iterator zombie_end() const { return zombies_.end(); }
-    std::vector<VerifyAttr>::const_iterator verify_begin() const { return verifys_.begin(); }
-    std::vector<VerifyAttr>::const_iterator verify_end() const { return verifys_.end(); }
-    std::vector<QueueAttr>::const_iterator queue_begin() const { return queues_.begin(); }
-    std::vector<QueueAttr>::const_iterator queue_end() const { return queues_.end(); }
-    std::vector<GenericAttr>::const_iterator generic_begin() const { return generics_.begin(); }
-    std::vector<GenericAttr>::const_iterator generic_end() const { return generics_.end(); }
-
-private:
-    Node* node_{nullptr}; // *NOT* persisted must be set by the parent class
-    friend class Node;
-
-private:
-    std::vector<ZombieAttr> zombies_;   // can be added/removed via AlterCmd
-    std::vector<VerifyAttr> verifys_;   // used for statistics and test verification
-    std::vector<QueueAttr> queues_;     // experimental
-    std::vector<GenericAttr> generics_; // experimental
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_node_MiscAttrs_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Node.cpp 5.13.0-1/ANode/src/ecflow/node/Node.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Node.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Node.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,2912 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cassert>
-#include <stdexcept>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/cereal_boost_time.hpp"
-#include "ecflow/node/AbstractObserver.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/CmdContext.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/ExprAstVisitor.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/MiscAttrs.hpp"
-#include "ecflow/node/NodeStats.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///////////////////////////////////////////////////////////////////////////////////////////
-// #define DEBUG_DEPENDENCIES 1
-// #define DEBUG_REQUEUE 1
-// #define DEBUG_FIND_REFERENCED_NODE 1
-
-Node::Node(const std::string& n, bool check) : n_(n) {
-    if (check) {
-        string msg;
-        if (!Str::valid_name(n, msg)) {
-            throw std::runtime_error("Invalid node name : " + msg);
-        }
-    }
-}
-
-Node::Node() = default;
-
-Node::Node(const Node& rhs)
-    : enable_shared_from_this(rhs),
-      parent_(nullptr),
-      n_(rhs.n_),
-      st_(rhs.st_),
-      d_st_(rhs.d_st_),
-      vars_(rhs.vars_),
-      c_expr_((rhs.c_expr_) ? new Expression(*rhs.c_expr_) : nullptr),
-      t_expr_((rhs.t_expr_) ? new Expression(*rhs.t_expr_) : nullptr),
-      meters_(rhs.meters_),
-      events_(rhs.events_),
-      labels_(rhs.labels_),
-      times_(rhs.times_),
-      todays_(rhs.todays_),
-      crons_(rhs.crons_),
-      dates_(rhs.dates_),
-      days_(rhs.days_),
-      late_((rhs.late_) ? new ecf::LateAttr(*rhs.late_) : nullptr),
-      misc_attrs_((rhs.misc_attrs_) ? new MiscAttrs(*rhs.misc_attrs_) : nullptr),
-      repeat_(rhs.repeat_),
-      inLimitMgr_(rhs.inLimitMgr_),
-      flag_(rhs.flag_),
-      auto_cancel_((rhs.auto_cancel_) ? new AutoCancelAttr(*rhs.auto_cancel_) : nullptr),
-      auto_archive_((rhs.auto_archive_) ? new AutoArchiveAttr(*rhs.auto_archive_) : nullptr),
-      auto_restore_((rhs.auto_restore_) ? new AutoRestoreAttr(*rhs.auto_restore_) : nullptr),
-      suspended_(rhs.suspended_) {
-    inLimitMgr_.set_node(this);
-    if (misc_attrs_)
-        misc_attrs_->set_node(this);
-
-    if (auto_restore_)
-        auto_restore_->set_node(this);
-
-    for (const auto& limit : rhs.limits_) {
-        limit_ptr the_limit = std::make_shared<Limit>(*limit);
-        the_limit->set_node(this);
-        limits_.push_back(the_limit);
-    }
-}
-
-bool Node::check_defaults() const {
-    if (parent_ != nullptr)
-        throw std::runtime_error("Node::check_defaults(): parent_ != nullptr");
-    if (graphic_ptr_ != nullptr)
-        throw std::runtime_error("Node::check_defaults(): graphic_ptr_  != nullptr");
-    if (suspended_ != false)
-        throw std::runtime_error("Node::check_defaults(): suspended_ != false");
-    if (state_change_no_ != 0)
-        throw std::runtime_error("Node::check_defaults(): state_change_no_ != 0");
-    if (variable_change_no_ != 0)
-        throw std::runtime_error("Node::check_defaults(): variable_change_no_  != 0");
-    if (suspended_change_no_ != 0)
-        throw std::runtime_error("Node::check_defaults():  suspended_change_no_ != 0");
-    if (d_st_.state() != DState::QUEUED)
-        throw std::runtime_error("Node::check_defaults(): d_st_.state() != DState::QUEUED");
-    return true;
-}
-
-void Node::delete_attributes() {
-    c_expr_.reset(nullptr);
-    t_expr_.reset(nullptr);
-    late_.reset(nullptr);
-    misc_attrs_.reset(nullptr);
-}
-
-node_ptr Node::create(const std::string& node_string) {
-    DefsStructureParser parser(node_string);
-    std::string errorMsg, warningMsg;
-    (void)parser.doParse(errorMsg, warningMsg);
-    return parser.the_node_ptr(); // can return NULL
-}
-
-node_ptr Node::create(const std::string& node_string, std::string& error_msg) {
-    DefsStructureParser parser(node_string);
-    std::string warningMsg;
-    if (!parser.doParse(error_msg, warningMsg))
-        return node_ptr();
-    return parser.the_node_ptr();
-}
-
-Node& Node::operator=(const Node& rhs) {
-    // Note:: Defs assignment operator use copy/swap, hence this assignment note used
-    // parent must set parent_
-    if (this != &rhs) {
-        n_         = rhs.n_;
-        suspended_ = rhs.suspended_;
-        st_        = rhs.st_;
-        d_st_      = rhs.d_st_;
-
-        vars_ = rhs.vars_;
-
-        delete_attributes();
-
-        meters_ = rhs.meters_;
-        events_ = rhs.events_;
-        labels_ = rhs.labels_;
-
-        times_  = rhs.times_;
-        todays_ = rhs.todays_;
-        crons_  = rhs.crons_;
-        dates_  = rhs.dates_;
-        days_   = rhs.days_;
-
-        if (rhs.c_expr_)
-            c_expr_ = std::make_unique<Expression>(*rhs.c_expr_);
-        if (rhs.t_expr_)
-            t_expr_ = std::make_unique<Expression>(*rhs.t_expr_);
-        if (rhs.late_)
-            late_ = std::make_unique<ecf::LateAttr>(*rhs.late_);
-        if (rhs.misc_attrs_)
-            misc_attrs_ = std::make_unique<MiscAttrs>(*rhs.misc_attrs_);
-
-        if (rhs.auto_cancel_)
-            auto_cancel_ = std::make_unique<AutoCancelAttr>(*rhs.auto_cancel_);
-        if (rhs.auto_archive_)
-            auto_archive_ = std::make_unique<AutoArchiveAttr>(*rhs.auto_archive_);
-        if (rhs.auto_restore_)
-            auto_restore_ = std::make_unique<AutoRestoreAttr>(*rhs.auto_restore_);
-
-        repeat_     = rhs.repeat_;
-        inLimitMgr_ = rhs.inLimitMgr_;
-        inLimitMgr_.set_node(this);
-        flag_ = rhs.flag_;
-
-        state_change_no_     = 0;
-        variable_change_no_  = 0;
-        suspended_change_no_ = 0;
-        graphic_ptr_         = nullptr;
-
-        if (misc_attrs_)
-            misc_attrs_->set_node(this);
-
-        if (auto_restore_)
-            auto_restore_->set_node(this);
-
-        limits_.clear();
-        for (const auto& limit : rhs.limits_) {
-            limit_ptr the_limit = std::make_shared<Limit>(*limit);
-            the_limit->set_node(this);
-            limits_.push_back(the_limit);
-        }
-    }
-    return *this;
-}
-
-Node::~Node() = default;
-
-bool Node::isParentSuspended() const {
-    Node* theParent = parent();
-    if (theParent) {
-        if (theParent->isSuspended())
-            return true;
-        return theParent->isParentSuspended();
-    }
-    return defs()->isSuspended(); // obtained from the server states
-}
-
-void Node::resume() {
-    /// Guard against unnecessary creation of memento's
-    if (suspended_) {
-        suspended_           = false;
-        suspended_change_no_ = Ecf::incr_state_change_no();
-    }
-}
-
-void Node::suspend() {
-    // Typically called via user action or via defstatus
-    suspended_           = true;
-    suspended_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::begin() {
-    // record effect of defstatus for node changes, for verify attributes
-    if (misc_attrs_)
-        misc_attrs_->begin();
-
-    // Set the state without causing any side effects
-    initState(0);
-
-    clearTrigger();
-    clearComplete();
-
-    flag_.reset();
-    repeat_.reset(); // if repeat is empty reset() does nothing
-
-    for (auto& meter : meters_) {
-        meter.reset();
-    }
-    for (auto& event : events_) {
-        event.reset();
-    }
-    for (auto& label : labels_) {
-        label.reset();
-    }
-
-    if (late_)
-        late_->reset();
-    for (auto& limit : limits_) {
-        limit->reset();
-    }
-
-    // Let time base attributes use, relative duration if applicable
-    {
-        const Calendar& calendar = suite()->calendar();
-        for (auto& today : todays_) {
-            today.reset(calendar);
-        }
-        for (auto& time : times_) {
-            time.reset(calendar);
-        }
-        for (auto& cron : crons_) {
-            cron.reset(calendar);
-        }
-
-        for (auto& day : days_) {
-            day.reset(calendar);
-        }
-        for (auto& date : dates_) {
-            date.reset();
-        }
-        markHybridTimeDependentsAsComplete();
-    }
-
-    inLimitMgr_.reset(); // new to 5.0.0 clear inlimit.incremented() flag
-
-    // DO *NOT* call update_generated_variables(). Called on a type specific bases, for begin
-    // Typically we need only call update_generated_variables() for a task, at job creation time.
-    // so that ECF_OUT, ECF_TRYNO, ECF_JOBOUT, ECF_PASS(paswd_) can be updated.
-    // However, the generated variables are used when within job generation and can be referenced by AST
-    // Hence to avoid excessive memory consumption, they are created on demand
-}
-
-void Node::requeue(Requeue_args& args) {
-#ifdef DEBUG_REQUEUE
-    LOG(Log::DBG, "      Node::requeue() " << absNodePath() << " resetRepeats = " << args.resetRepeats_);
-#endif
-    /// Note: we don't reset verify attributes as they record state stat's
-
-    // Set the state without causing any side effects
-    initState(args.clear_suspended_in_child_nodes_, args.log_state_changes_);
-
-    clearTrigger();
-    clearComplete();
-
-    if (args.resetRepeats_)
-        repeat_.reset(); // if repeat is empty reset() does nothing
-
-    /// If a job takes longer than it slots, then that slot is missed, and next slot is used
-    /// Note we do *NOT* reset for requeue as we want to advance the valid time slots.
-    /// *NOTE* Update calendar will *free* time dependencies *even* time series. They rely
-    /// on this function to clear the time dependencies so they *HOLD* the task.
-    if (has_time_dependencies()) {
-
-        /// Requeue has several contexts:
-        ///   1/ manual requeue
-        ///   2/ automated requeue due to repeats
-        ///   3/ automated requeue due to time dependencies
-        /// For manual and automated reueue due to repeat's we always clear Flag::NO_REQUE_IF_SINGLE_TIME_DEP
-        /// since in those context we do NOT want miss any time slots
-        bool reset_next_time_slot = true;
-        if (args.reset_next_time_slot_) {
-            reset_next_time_slot = true;
-        }
-        else {
-            if (flag().is_set(Flag::NO_REQUE_IF_SINGLE_TIME_DEP)) {
-                /// If we have done an interactive run or complete, *dont* increment next_time_slot_
-                /// allow next time on time based attributes to be incremented and *not* reset,
-                /// when force and run commands used
-                reset_next_time_slot = false;
-            }
-        }
-
-        // must be done before the re-queue
-        do_requeue_time_attrs(reset_next_time_slot, args.reset_relative_duration_, args.requeue_t);
-        markHybridTimeDependentsAsComplete();
-    }
-
-    // Should *NOT* clear, archived flag, as this is done via autorestore or --restore
-    // reset the flags, however remember if edit were made
-    bool edit_history_set = flag().is_set(ecf::Flag::MESSAGE);
-    bool archived_set     = flag().is_set(ecf::Flag::ARCHIVED);
-    flag_.reset(); // will CLEAR NO_REQUE_IF_SINGLE_TIME_DEP
-    if (edit_history_set)
-        flag().set(ecf::Flag::MESSAGE);
-    if (archived_set)
-        flag().set(ecf::Flag::ARCHIVED);
-
-    if (late_)
-        late_->reset();
-
-    for (auto& meter : meters_) {
-        meter.reset();
-    }
-    for (auto& event : events_) {
-        event.reset();
-    }
-    // ECFLOW-195, only clear labels, if they are on Suites/Family not tasks(typically only specified on tasks)
-    if (isNodeContainer()) {
-        for (auto& label : labels_) {
-            label.reset();
-        }
-    }
-
-    if (misc_attrs_)
-        misc_attrs_->requeue();
-
-    for (auto& limit : limits_) {
-        limit->reset();
-    }
-    inLimitMgr_.reset(); // new to 5.0.0 clear inlimit.incremented() flag
-
-    // ECFLOW-196, ensure the re-queue release tokens held by Limits higher up the tree.
-    // Note: Its safe to call decrementInLimit, even when no limit consumed
-    std::set<Limit*> limitSet;  // ensure local limit have preference over parent
-    decrementInLimit(limitSet); // will recurse up, expensive but needed
-}
-
-void Node::reset_late_event_meters() {
-    if (late_)
-        late_->reset();
-    for (auto& meter : meters_) {
-        meter.reset();
-    }
-    for (auto& event : events_) {
-        event.reset();
-    }
-}
-
-void Node::reset() {
-    // Set the state without causing any side effects
-    initState(1);
-
-    clearTrigger();
-    clearComplete();
-
-    repeat_.reset(); // if repeat is empty reset() does nothing
-
-    for (auto& today : todays_) {
-        today.resetRelativeDuration();
-        today.reset_only();
-    }
-    for (auto& time : times_) {
-        time.resetRelativeDuration();
-        time.reset_only();
-    }
-    for (auto& cron : crons_) {
-        cron.resetRelativeDuration();
-        cron.reset_only();
-    }
-    for (auto& date : dates_) {
-        date.reset();
-    }
-    for (auto& day : days_) {
-        day.reset();
-    }
-
-    flag_.reset();
-
-    if (late_)
-        late_->reset();
-
-    for (auto& meter : meters_) {
-        meter.reset();
-    }
-    for (auto& event : events_) {
-        event.reset();
-    }
-    if (isNodeContainer()) {
-        for (auto& label : labels_) {
-            label.reset();
-        }
-    }
-
-    for (auto& limit : limits_) {
-        limit->reset();
-    }
-}
-
-void Node::handle_migration(const ecf::Calendar& c) {
-    // called when defs created by reading from a file on disk. i.e. checkpoint
-    // handle any migration
-    for (auto& day : days_) {
-        day.handle_migration(c);
-    }
-}
-
-void Node::requeue_time_attrs() {
-    // Note: we *don't* mark hybrid time dependencies as complete.
-    //       i.e. since this is called during alter command, it could be that
-    //        the task is in a submitted or active state.
-    do_requeue_time_attrs(true /*reset_next_time_slot*/, true /*reset_relative_duration*/, Requeue_args::FULL);
-}
-
-void Node::requeue_labels() {
-    // ECFLOW-195, clear labels before a task is run.
-    for (auto& label : labels_) {
-        label.reset();
-    }
-}
-
-// #define DEBUG_DAYS 1
-bool Node::calendarChanged(const ecf::Calendar& c,
-                           Node::Calendar_args& cal_args,
-                           const ecf::LateAttr*,
-                           bool holding_parent_day_or_date) {
-    // cout << " Node:calendarChanged: " << debugNodePath() << " holding_parent_day_or_date " <<
-    // holding_parent_day_or_date << "\n";
-
-    if (!holding_parent_day_or_date) {
-        holding_parent_day_or_date = calendar_changed_timeattrs(c, cal_args);
-
-#ifdef DEBUG_DAYS
-        if (holding_parent_day_or_date) {
-            cout << " Node::calendarChanged: " << debugNodePath() << " SETTING holding_parent_day_or_date "
-                 << holding_parent_day_or_date << " ***********\n";
-        }
-#endif
-    }
-#ifdef DEBUG_DAYS
-    else {
-        cout << " Node::calendarChanged: " << debugNodePath()
-             << " IGNORING since holding_parent_day_or_date  <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n";
-    }
-#endif
-
-    if (checkForAutoCancel(c)) {
-        cal_args.auto_cancelled_nodes_.push_back(shared_from_this());
-    }
-
-    // Avoid automatically archiving a restored node. Wait till begin/re-queue
-    if (!flag().is_set(ecf::Flag::RESTORED) && check_for_auto_archive(c)) {
-        cal_args.auto_archive_nodes_.push_back(shared_from_this());
-    }
-    return holding_parent_day_or_date;
-}
-
-void Node::check_for_lateness(const ecf::Calendar& c, const ecf::LateAttr* inherited_late) {
-    // Late flag should ONLY be set on Submittable
-    if (late_) {
-        // Only check for lateness if we are not late.
-        if (!late_->isLate()) {
-            if (!inherited_late || inherited_late->isNull())
-                checkForLateness(c);
-            else {
-                LateAttr overridden_late = *inherited_late;
-                overridden_late.override_with(late_.get());
-                if (overridden_late.check_for_lateness(st_, c)) {
-                    late_->setLate(true);
-                    flag().set(ecf::Flag::LATE);
-                }
-            }
-        }
-    }
-    else {
-        // inherited late, we can only set late flag.
-        if (inherited_late && !flag().is_set(ecf::Flag::LATE) && inherited_late->check_for_lateness(st_, c)) {
-            flag().set(ecf::Flag::LATE);
-        }
-    }
-}
-
-void Node::checkForLateness(const ecf::Calendar& c) {
-    if (late_ && late_->check_for_lateness(st_, c)) {
-        late_->setLate(true);
-        flag().set(ecf::Flag::LATE);
-        // cout << "Node::checkForLateness late flag set on " << absNodePath() << "\n";
-    }
-}
-
-void Node::initState(int clear_suspended_in_child_nodes, bool log_state_changes) {
-    // The state duration is ONLY updated *IF* state has changed.
-    // However, on re-queue *ALWAYS* reset state time.
-    // Otherwise, we can end up showing time in the future. SEE ECFLOW-1215
-    Suite* theSuite = suite();
-    if (theSuite) {
-        const Calendar& calendar = theSuite->calendar();
-        st_.second               = calendar.duration();
-    }
-
-    if (d_st_ == DState::SUSPENDED) {
-        /// Note: DState::SUSPENDED is not a real state, its really a user interaction
-        /// Replace with suspend, and set underlying state as queued
-        suspend();
-        setStateOnly(NState::QUEUED, false /*force*/, Str::EMPTY() /* additional info to log */, log_state_changes);
-    }
-    else {
-
-        if (clear_suspended_in_child_nodes > 0) {
-            resume();
-        }
-
-        // convert DState --> NState.
-        // NOTE::  NState does *NOT* have SUSPENDED
-        setStateOnly(DState::convert(d_st_.state()),
-                     false /*force*/,
-                     Str::EMPTY() /* additional info to log */,
-                     log_state_changes);
-    }
-}
-
-void Node::requeueOrSetMostSignificantStateUpNodeTree() {
-    // Get the computed state of my immediate children
-    // *** A family can be marked as complete, via complete trigger when not all its children
-    // *** are complete, hence computedState() *MUST* first check the immediate state  ,
-    // *** before considering its immediate children
-    NState::State computedStateOfImmediateChildren = computedState(Node::IMMEDIATE_CHILDREN);
-
-#ifdef DEBUG_REQUEUE
-    LogToCout toCoutAsWell;
-    cout << "\n";
-    Indentor indent;
-    LOG(Log::DBG,
-        "requeueOrSetMostSignificantStateUpNodeTree() " << debugNodePath() << "(" << NState::toString(state())
-                                                        << ") computed("
-                                                        << NState::toString(computedStateOfImmediateChildren) << ")");
-#endif
-
-    if (computedStateOfImmediateChildren == NState::COMPLETE) {
-
-        // set most significant state of my immediate children
-        // Record: That Suite/Family completed.
-        if (computedStateOfImmediateChildren != state()) {
-            setStateOnly(computedStateOfImmediateChildren);
-        }
-
-        // For automated re-queue do *not* clear suspended state in *child* nodes
-        int clear_suspended_in_child_nodes = -1;
-
-        if (!repeat_.empty()) {
-
-            repeat_.increment();
-
-            // If the repeat is still valid, re-queue the node
-#ifdef DEBUG_REQUEUE
-            LOG(Log::DBG,
-                "requeueOrSetMostSignificantStateUpNodeTree " << debugNodePath() << " for repeat "
-                                                              << repeat_.toString());
-#endif
-            if (repeat_.valid()) {
-#ifdef DEBUG_REQUEUE
-                LOG(Log::DBG,
-                    "requeueOrSetMostSignificantStateUpNodeTree() VALID for requeue "
-                        << debugNodePath() << " for repeat at " << repeat_.toString());
-#endif
-
-                // Remove effects of RUN and Force complete interactive commands
-                // For automated re-queue *DUE* to Repeats, *CLEAR* any user interaction that would miss the next time
-                // slots. *Down* the hierarchy This handles the case where a user, has manually intervened (i.e. via run
-                // or complete) and we had a time attribute That time attribute will have expired, typically we show
-                // next day. In the case where we have a parent repeat we need to clear the flag, otherwise the
-                // task/family with time based attribute would wait for next day.
-                Node::Requeue_args args(Node::Requeue_args::REPEAT_INCREMENT,
-                                        false /* don't reset repeats */,
-                                        clear_suspended_in_child_nodes,
-                                        true /* reset_next_time_slot */,
-                                        true /* reset relative duration */);
-                requeue(args);
-                set_most_significant_state_up_node_tree();
-                return;
-            }
-        }
-
-        /// If user has *INTERACTIVLY* forced changed in state to complete *OR* run the job.
-        /// This would cause Node to miss the next time slot. i.e. expire the time slot
-        /// In which case testTimeDependenciesForRequeue should return false for a single time/today dependency
-        /// and not requeue the node.
-        if (has_time_dependencies() && testTimeDependenciesForRequeue()) {
-
-            // This is the only place we do not explicitly reset_next_time_slot
-            bool reset_next_time_slot = false;
-
-            // Remove effects of RUN and Force complete interactive commands, *BUT* only if *not* applied to this cron
-            if (!crons().empty()) {
-                if (!flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP)) {
-                    reset_next_time_slot = true;
-                }
-            }
-
-            Node::Requeue_args args(Node::Requeue_args::TIME,
-                                    false /* don't reset repeats */,
-                                    clear_suspended_in_child_nodes,
-                                    reset_next_time_slot,
-                                    false /*  don't reset relative duration */);
-            requeue(args); // time +00:01 00:07 00:03 # here task re-queued many times, relative time must be preserved.
-            set_most_significant_state_up_node_tree();
-            return;
-        }
-    }
-
-    // In case compute state is other that COMPLETE, update. i,e for Family/Suite
-    if (computedStateOfImmediateChildren != state()) {
-        setStateOnly(computedStateOfImmediateChildren);
-    }
-
-    // recurse up the node tree
-    Node* theParentNode = parent();
-    if (theParentNode) {
-        theParentNode->requeueOrSetMostSignificantStateUpNodeTree();
-    }
-    else {
-        // No parent, hence next level is the root, ie the Defs
-        // Reflect the status of all the suite's
-        // **** This should not recurse down, just reflect status of suites
-        defs()->set_most_significant_state();
-    }
-}
-
-void Node::set_most_significant_state_up_node_tree() {
-    if (isTask()) {
-        parent()->set_most_significant_state_up_node_tree();
-        return;
-    }
-
-    // set most significant state  of my immediate children
-    NState::State computedStateOfImmediateChildren = computedState(Node::IMMEDIATE_CHILDREN);
-    if (computedStateOfImmediateChildren != state()) {
-        setStateOnly(computedStateOfImmediateChildren);
-    }
-
-    // recurse up the node tree
-    Node* theParentNode = parent();
-    if (theParentNode) {
-        theParentNode->set_most_significant_state_up_node_tree();
-    }
-    else {
-        // No parent, hence next level is the root, ie the Defs
-        // Reflect the status of all the suite's
-        // **** This should not recurse down, just reflect status of suites
-        defs()->set_most_significant_state();
-    }
-}
-
-// Returning false, *STOPS* further traversal *DOWN* the node tree
-bool Node::resolveDependencies(JobsParam& jobsParam) {
-    // This function is called:
-    //    a/ Periodically by the server, i.e. every minute
-    //    b/ Asynchronously, after child command, via job submission
-#ifdef DEBUG_DEPENDENCIES
-    LogToCout toCoutAsWell;
-    cout << "\n";
-    LOG(Log::DBG,
-        "   " << debugNodePath() << "::resolveDependencies " << NState::toString(state()) << " AT "
-              << suite()->calendar().toString());
-#endif
-
-    // A node that is archived should not allow any change of state.
-    if (get_flag().is_set(ecf::Flag::ARCHIVED))
-        return false;
-
-    if (isSuspended()) {
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG,
-            "   Node::resolveDependencies() " << absNodePath() << " HOLDING as node state " << NState::toString(state())
-                                              << " is SUSPENDED ");
-#endif
-        return false;
-    }
-
-    if (state() == NState::COMPLETE) {
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG,
-            "   Node::resolveDependencies() " << absNodePath() << " HOLDING as node state " << NState::toString(state())
-                                              << " is not valid for job submission");
-#endif
-        return false;
-    }
-
-    if (!timeDependenciesFree()) {
-#ifdef DEBUG_DEPENDENCIES
-        const Calendar& calendar = suite()->calendar();
-        LOG(Log::DBG,
-            "   Node::resolveDependencies() " << absNodePath() << " HOLDING due to time dependencies at "
-                                              << calendar.toString());
-#endif
-        return false;
-    }
-
-    // Complete *MUST* be evaluated before trigger. As it can affect the other
-    // i.e. A state change to COMPLETE, in which case no need to submit tasks
-    // However if the complete does *not* evaluate it should *NOT* hold the node.
-    if (evaluateComplete()) {
-        if (completeAst()) {
-
-            flag().set(ecf::Flag::BYRULE);
-
-            // If we are a parent sets the state first. then set state on all the children
-            set_state_hierarchically(NState::COMPLETE,
-                                     false); // reset try no and decrement inlimit resources & update repeats
-
-#ifdef DEBUG_DEPENDENCIES
-            LOG(Log::DBG,
-                "   Node::resolveDependencies() " << absNodePath() << " HOLDING since evaluation of COMPLETE");
-#endif
-            // We have a complete By returning false here, we stop dependency evaluation for any children
-            return false;
-        }
-    }
-    // No complete, or we have a complete  that does not evaluate.(this should not hold the node)
-
-    if (evaluateTrigger()) {
-        // WE only get here **IF** :
-        // 1/ There is no trigger
-        // 2/ WE have a trigger, and it evaluates to true
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG, "   Node::resolveDependencies() " << absNodePath() << " FREE of TRIGGER");
-#endif
-        return true;
-    }
-
-    // We *have* a trigger, and it does not evaluate, hold the node
-#ifdef DEBUG_DEPENDENCIES
-    LOG(Log::DBG, "   Node::resolveDependencies() " << absNodePath() << " HOLDING due to TRIGGER");
-#endif
-    return false;
-}
-
-bool Node::has_time_based_attributes() const {
-    if (has_time_dependencies())
-        return true;
-    if (auto_cancel_)
-        return true;
-    if (auto_archive_)
-        return true;
-    if (late_)
-        return true;
-    return false;
-}
-
-void Node::freeTrigger() const {
-    if (t_expr_)
-        t_expr_->setFree();
-}
-
-void Node::clearTrigger() const {
-    if (t_expr_)
-        t_expr_->clearFree();
-}
-
-void Node::freeComplete() const {
-    if (c_expr_)
-        c_expr_->setFree();
-}
-
-void Node::clearComplete() const {
-    if (c_expr_)
-        c_expr_->clearFree();
-}
-
-bool Node::evaluateComplete() const {
-    // Complete *MUST* be evaluated before trigger. As it can affect the other
-    AstTop* theCompeteAst = completeAst();
-    if (theCompeteAst) {
-        // *NOTE* if we have a non-NULL complete ast, we must have complete expression
-        // The freed state is stored on the expression ( i.e. not on the ast)
-        // ISSUE: Complete expression cannot be by-passed in the GUI
-        if (c_expr_->isFree() || theCompeteAst->evaluate()) {
-
-            // Note: if a task has been set complete, the use may decide to place into queued state( via GUI)
-            //       In which case, we *want* this complete expression to be re-evaluated.
-            //       Hence, the old code below has been commented out.
-            // >>old: Set the complete as free, until begin()/requeue, // Only update state change no, if state has
-            // changed.
-            // >>old:if (!c_expr_->isFree()) freeComplete();
-
-            // ECFLOW-247 Family goes complete despite active child
-            //            Typically we have a complete expression on the family i/e f1/t1 == complete
-            //            However if we have another child that is active,submitted forcing family to complete will
-            //            cause zombies Another child could be a family which could be aborted.
-            // if computedState state is:
-            //    NState::ABORTED   -> don't complete if any of the children are aborted  -> ECFLOW-247
-            //                         This can hide active/submitted nodes, as abort has higher priority, could cause
-            //                         zombies
-            //    NState::ACTIVE    -> can cause zombies
-            //    NState::SUBMITTED -> can cause zombies
-            // hence only allow complete is we are in a NState::QUEUED state
-            NState::State theComputedState = computedState(Node::HIERARCHICAL);
-            if (theComputedState != NState::QUEUED) {
-#ifdef DEBUG_DEPENDENCIES
-                LOG(Log::DBG,
-                    "   Node::evaluateComplete() " << absNodePath() << " AST evaluation succeeded *BUT* " << debugType()
-                                                   << " has children in ACTIVE or SUBMITTED States");
-#endif
-                return false;
-            }
-
-#ifdef DEBUG_DEPENDENCIES
-            LOG(Log::DBG,
-                "   Node::evaluateComplete() " << debugNodePath() << " FREE, COMPLETE AST evaluation succeeded ");
-#endif
-            return true;
-        }
-        else {
-            /// *IMPORTANT* When a complete does not evaluate, it should *NOT* stop further tree walking
-#ifdef DEBUG_DEPENDENCIES
-            LOG(Log::DBG,
-                "   Node::evaluateComplete() " << debugNodePath() << " HOLDING, COMPLETE AST evaluation failed");
-#endif
-            return false;
-        }
-    }
-    return true;
-}
-
-bool Node::evaluateTrigger() const {
-    AstTop* theTriggerAst = triggerAst();
-    if (theTriggerAst) {
-
-        // Note 1: A trigger can be freed by the ForceCmd
-        // Note 2: if we have a non-NULL trigger ast, we must have trigger expression
-        // Note 3: The freed state is stored on the expression ( i.e. *NOT* on the ast (abstract syntax tree) )
-        if (t_expr_->isFree() || theTriggerAst->evaluate()) {
-
-            // *ALWAYS* evaluate trigger expression unless user has forcibly removed trigger dependencies
-            // ******** This allows force queued functionality, to work as expected, since trigger's will be honoured
-            // The old code below has been commented out.
-            // >> old: Set the trigger as free, until begin()/requeue.  Only update state change no, when required
-            // >> old: if (!t_expr_->isFree()) freeTrigger();
-
-#ifdef DEBUG_DEPENDENCIES
-            LOG(Log::DBG,
-                "   Node::evaluateTrigger() " << debugNodePath() << " FREE, TRIGGER AST evaluation succeeded");
-#endif
-            return true;
-        }
-
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG, "   Node::evaluateTrigger() " << debugNodePath() << " HOLDING  TRIGGER AST evaluation failed");
-#endif
-        return false; // evaluation failed. this Node holds
-    }
-
-#ifdef DEBUG_DEPENDENCIES
-    LOG(Log::DBG, "   Node::evaluateTrigger() " << debugNodePath() << " FREE NO TRIGGER defined");
-#endif
-    return true;
-}
-
-const std::string& Node::abortedReason() const {
-    return Str::EMPTY();
-}
-
-void Node::set_state(NState::State newState, bool force, const std::string& additional_info_to_log) {
-    if (st_.first.state() != newState) {
-
-        setStateOnly(newState, false, additional_info_to_log);
-
-        // Handle any state change specific functionality. This will update any repeats
-        // This is a virtual function, since we want different behaviour during state change
-        handleStateChange();
-    }
-}
-
-void Node::handleStateChange() {
-    if (state() == NState::COMPLETE) {
-        if (auto_restore_)
-            auto_restore_->do_autorestore();
-
-        Node* the_parent = parent();
-        while (the_parent) {
-            if (the_parent->state() == NState::COMPLETE && the_parent->get_autorestore()) {
-                the_parent->get_autorestore()->do_autorestore();
-            }
-            the_parent = the_parent->parent();
-        }
-    }
-}
-
-void Node::setStateOnly(NState::State newState,
-                        bool force,
-                        const std::string& additional_info_to_log,
-                        bool do_log_state_changes) {
-    if (st_.first.state() == newState) {
-        return; // if old and new state the same don't do anything
-    }
-
-    Suite* theSuite          = suite();
-    const Calendar& calendar = theSuite->calendar();
-
-#ifdef DEBUG_JOB_SUBMISSION_INTERVAL
-    // check sub submission interval/calendar increment for tasks only
-    // The job submission interval is set/obtained from the server environment and
-    // is configurable for testing.
-    // **** This is only used when jobSubmissionInterval is less than 60 ****
-    // We are attempting to refine job submission interval such that it is just
-    // greater than time taken for state change from submit->active->complete
-    // There by speeding up the test where we generate .ecf
-
-    // Ignore this during simulation, ie defs()->server().jobSubmissionInterval() = 0; for simulation
-    int jobSubmissionInterval = theSuite->defs()->server().jobSubmissionInterval();
-    if (isSubmittable() && jobSubmissionInterval != 0 && jobSubmissionInterval < 60) {
-
-        if (newState == NState::SUBMITTED)
-            submit_to_complete_duration_ = Calendar::second_clock_time();
-        else if (newState == NState::COMPLETE && !submit_to_complete_duration_.is_special()) {
-
-            // Under HYBRID we can go from UNKNOWN->COMPLETE, missing out SUBMITTED
-            // hence: submit_to_complete_duration_ is never initialised
-            // ie when we have a,date,cron dependency that relies on a day change
-
-            time_duration td = (Calendar::second_clock_time() - submit_to_complete_duration_);
-            // cout << debugNodePath() << " submit->active->complete time = " << td.total_seconds()  << " seconds.\n";
-
-            // Avoid this check if we have meters. as we wait a second between each meter update
-            if (td.total_seconds() >= jobSubmissionInterval && meters_.empty()) {
-
-                const Variable& do_check = theSuite->findVariable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL");
-                if (!do_check.empty()) {
-                    // 				cout << "Calendar::second_clock_time() = " <<
-                    // to_simple_string(Calendar::second_clock_time())
-                    // << "\n"; 				cout << "submit_to_complete_duration_ = " <<
-                    // to_simple_string(submit_to_complete_duration_) << "\n"; 				cout <<
-                    // "(Calendar::second_clock_time() - submit_to_complete_duration_) = " << to_simple_string(td) <<
-                    // "\n";
-                    cout << "Testing::" << debugNodePath() << " For each job submission interval of "
-                         << jobSubmissionInterval << " seconds, the calendar is increment by 60 seconds.\n"
-                         << " The job submission interval is too small as it takes " << td.total_seconds()
-                         << " seconds for state change of submit->active->complete, for an empty job.\n"
-                         << " Please increase the job submission interval to at least " << (td.total_seconds() + 1)
-                         << " seconds.\n";
-                }
-            }
-        }
-    }
-#endif
-
-    // Change format is significant it is used in verification of log files
-    // Please change/update LogVerification::extractNodePathAndState() all verification relies on this one function
-    //           " " +  submitted(max) + ": " + path(estimate)  + " try-no: " + try_no(estimate)  + " reason: " +
-    //           reason(estimate)
-    // reserve : 1   +  9              + 2    + 100             + 9           + 3                 + 9           + 12   =
-    // 145
-    std::string log_state_change;
-    if (do_log_state_changes) {
-        log_state_change.reserve(145 + additional_info_to_log.size());
-        log_state_change += " ";
-        log_state_change += NState::toString(newState);
-        log_state_change += ": ";
-        log_state_change += absNodePath();
-        if (!additional_info_to_log.empty()) {
-            log_state_change += " ";
-            log_state_change += additional_info_to_log;
-        }
-    }
-
-    if (newState == NState::ABORTED) {
-        if (force)
-            flag().set(ecf::Flag::FORCE_ABORT);
-        Submittable* submittable = isSubmittable();
-        if (submittable) {
-            flag().set(ecf::Flag::TASK_ABORTED);
-            if (do_log_state_changes) {
-                log_state_change += " try-no: ";
-                log_state_change += submittable->tryNo();
-                log_state_change += " reason: ";
-                log_state_change += abortedReason();
-            }
-        }
-    }
-    else {
-        flag().clear(ecf::Flag::TASK_ABORTED);
-        flag().clear(ecf::Flag::FORCE_ABORT);
-    }
-
-    if (do_log_state_changes) {
-        // SUP-408 what does submitted mean in log?
-        // We want to minimize the calls to create a new time stamp in the log file.
-        // A time stamp is automatically created, whenever a *new* client request is received, & then cached
-        // However we can get a change in state, during tree traversal, when a node is free of its dependencies
-        // If we were to just log the message it would use the last cached time stamp. Giving misleading info:
-        // Since state changes are bubbled up, we need only update the time stamp for tasks, when not in a command
-        if (!CmdContext::in_command() && isTask() && Log::instance()) {
-            // std::cout << "!!!!! NOT in cmd context updating time stamp before logging\n";
-            Log::instance()->cache_time_stamp();
-        }
-        ecf::log(Log::LOG, log_state_change); // Note: log type, must be same for debug & release for test, i.e. for log
-                                              // file verification
-    }
-
-    st_.first.setState(newState); // this will update state_change_no
-    if (newState == NState::QUEUED)
-        sc_rt_ = boost::posix_time::time_duration(0, 0, 0, 0);
-    else
-        sc_rt_ = calendar.duration() - st_.second;
-    st_.second = calendar.duration(); // record state change duration for late, autocancel,autoarchive,etc
-
-    // Record state changes for verification
-    if (misc_attrs_) {
-        size_t theSize = misc_attrs_->verifys_.size();
-        for (size_t i = 0; i < theSize; i++) {
-            if (misc_attrs_->verifys_[i].state() == newState) {
-                // cout << "Verify: calendar " << to_simple_string(calendar.date()) << "\n";
-                misc_attrs_->verifys_[i].incrementActual();
-            }
-        }
-    }
-}
-
-boost::posix_time::ptime Node::state_change_time() const {
-    const Calendar& calendar                       = suite()->calendar();
-    boost::posix_time::ptime the_state_change_time = calendar.begin_time();
-    the_state_change_time += st_.second; // st_.second is calendar duration relative to calendar begin_time
-    return the_state_change_time;
-}
-
-DState::State Node::dstate() const {
-
-    // ECFLOW-139, check for suspended must be done first
-    if (isSuspended())
-        return DState::SUSPENDED;
-
-    switch (state()) {
-        case NState::COMPLETE:
-            return DState::COMPLETE;
-            break;
-        case NState::ABORTED:
-            return DState::ABORTED;
-            break;
-        case NState::ACTIVE:
-            return DState::ACTIVE;
-            break;
-        case NState::SUBMITTED:
-            return DState::SUBMITTED;
-            break;
-        case NState::QUEUED:
-            return DState::QUEUED;
-            break;
-        case NState::UNKNOWN:
-            return DState::UNKNOWN;
-            break;
-    }
-    return DState::UNKNOWN;
-}
-
-bool Node::set_event(const std::string& event_name_or_number) {
-    for (Event& e : events_) {
-        if (e.name_or_number() == event_name_or_number) {
-            e.set_value(true);
-            return true;
-        }
-    }
-    return false;
-}
-bool Node::clear_event(const std::string& event_name_or_number) {
-    for (Event& e : events_) {
-        if (e.name_or_number() == event_name_or_number) {
-            e.set_value(false);
-            return true;
-        }
-    }
-    return false;
-}
-
-void Node::setRepeatToLastValue() {
-    repeat_.setToLastValue(); // no op for empty repeat
-    repeat_.increment();      // make repeat invalid
-}
-
-bool Node::check_in_limit_up_node_tree() const {
-    if (!inLimitMgr_.inLimit())
-        return false;
-
-    Node* theParent = parent();
-    while (theParent) {
-        if (!theParent->inLimitMgr_.inLimit())
-            return false;
-        theParent = theParent->parent();
-    }
-    return true;
-}
-
-void Node::incrementInLimit(std::set<Limit*>& limitSet) {
-    // cout << "Node::incrementInLimit " << absNodePath() << endl;
-    std::string the_abs_node_path = absNodePath();
-    inLimitMgr_.incrementInLimit(limitSet, the_abs_node_path);
-
-    Node* theParent = parent();
-    while (theParent) {
-        theParent->inLimitMgr_.incrementInLimit(limitSet, the_abs_node_path);
-        theParent = theParent->parent();
-    }
-}
-
-void Node::decrementInLimit(std::set<Limit*>& limitSet) {
-    // cout << "Node::decrementInLimit " << absNodePath() << endl;
-    std::string the_abs_node_path = absNodePath();
-    inLimitMgr_.decrementInLimit(limitSet, the_abs_node_path);
-
-    Node* theParent = parent();
-    while (theParent) {
-        theParent->inLimitMgr_.decrementInLimit(limitSet, the_abs_node_path);
-        theParent = theParent->parent();
-    }
-}
-
-void Node::decrementInLimitForSubmission(std::set<Limit*>& limitSet) {
-    // cout << "Node::decrementInLimit " << absNodePath() << endl;
-    std::string the_abs_node_path = absNodePath();
-    inLimitMgr_.decrementInLimitForSubmission(limitSet, the_abs_node_path);
-
-    Node* theParent = parent();
-    while (theParent) {
-        theParent->inLimitMgr_.decrementInLimitForSubmission(limitSet, the_abs_node_path);
-        theParent = theParent->parent();
-    }
-}
-
-static bool
-search_user_edit_variables(const std::string& name, std::string& value, const NameValueMap& user_edit_variables) {
-    auto i = user_edit_variables.find(name);
-    if (i != user_edit_variables.end()) {
-        if (((*i).second).empty()) {
-            // when we call --edit_script submit file, before a job is submitted the values
-            // of generated variables like  ECF_RID, ECF_TRYNO, ECF_NAME, ECF_PASS, ECF_JOB, ECF_JOBOUT, ECF_SCRIPT
-            // will be empty. In this case return false, so that we pick up the values from the node.
-            return false;
-        }
-        value = (*i).second;
-        return true;
-    }
-    return false;
-}
-
-// #define DEBUG_S 1
-bool Node::variableSubstitution(std::string& cmd) const {
-    char micro = '%';
-    std::string micro_char;
-    findParentUserVariableValue(Str::ECF_MICRO(), micro_char);
-    if (!micro_char.empty() && micro_char.size() == 1) {
-        micro = micro_char[0];
-    }
-
-    NameValueMap user_edit_variables;
-    return variable_substitution(cmd, user_edit_variables, micro);
-}
-
-bool Node::variable_substitution(std::string& cmd, const NameValueMap& user_edit_variables, char micro) const {
-    // scan the command for variables, and substitute
-    // edit cmd "/home/ma/map/sms/smsfectch -F %ECF_FILES% -I %ECF_INCLUDE%"
-    // We can also have
-    //
-    // "%<VAR>:<substitute>% i.e. if VAR exist use it, else use substitute
-    //
-    // ************************************************************************************************************
-    // Special case handling for user variables, and generated variables, which take precedence over node variables
-    // ************************************************************************************************************
-    //
-    // i.e. VAR is defined as BILL
-    //  %VAR:fred --f%  will either be "BILL" or if VAR is not defined "fred --f"
-    //
-    // Infinite recursion. It is possible to end up with infinite recursion:
-    //   	edit hello '%hello%'  # string like %hello% will cause infinite recursion
-    //   	edit fred '%bill%'
-    //	 	edit bill '%fred%'   # should be 10
-    // To prevent this we will use a simple count
-#ifdef DEBUG_S
-    cout << "cmd  = " << cmd << "\n";
-#endif
-    bool double_micro_found    = false;
-    std::string::size_type pos = 0;
-    int count                  = 0;
-    Alias* is_a_alias          = isAlias();
-    while (true) {
-        // A while loop here is used to:
-        //   a/ Allow for multiple substitution on a single line. i.e. `%ECF_FILES% -I %ECF_INCLUDE%`
-        //   b/ Allow for recursive substitution. %fred% -> %bill% -> 10
-
-        size_t firstPercentPos = cmd.find(micro, pos);
-        if (firstPercentPos == string::npos)
-            break;
-
-        size_t secondPercentPos = cmd.find(micro, firstPercentPos + 1);
-        if (secondPercentPos == string::npos)
-            break;
-
-        pos = 0;
-        if (secondPercentPos - firstPercentPos <= 1) {
-            // handle %% with no characters in between, skip over
-            // i.e. to handle "printf %%02d %HOUR:00%" --> "printf %02d 00" i.e. if HOUR not defined
-            pos                = secondPercentPos + 1;
-            double_micro_found = true;
-            continue;
-        }
-
-        string percentVar(cmd.begin() + firstPercentPos + 1, cmd.begin() + secondPercentPos);
-        // cout << percentVar << "\n";
-#ifdef DEBUG_S
-        cout << "   Found percentVar " << percentVar << "\n";
-#endif
-
-        // ****************************************************************************************
-        // Look for generated variables that should NOT be overridden first:
-        //    Variable like ECF_PASS can be overridden, i.e. with FREE_JOBS_PASSWORD
-        //    However for job file generation we should use the generated variables first.
-        //    if the user removes ECF_PASS then we are stuck with the wrong value in the script file
-        //    FREE_JOBS_PASSWORD is left for the server to deal with
-        // Leave ECF_JOB and ECF_JOBOUT out of this list: As user may legitimately override these. ECFLOW-999
-        bool generated_variable = false;
-        if (percentVar.find("ECF_") == 0) {
-            if (percentVar.find(Str::ECF_HOST()) != std::string::npos)
-                generated_variable = true;
-            else if (percentVar.find(Str::ECF_PORT()) != std::string::npos)
-                generated_variable = true;
-            else if (percentVar.find(Str::ECF_TRYNO()) != std::string::npos)
-                generated_variable = true;
-            else if (percentVar.find(Str::ECF_NAME()) != std::string::npos)
-                generated_variable = true;
-            else if (percentVar.find(Str::ECF_PASS()) != std::string::npos)
-                generated_variable = true;
-        }
-
-        size_t firstColon = percentVar.find(':');
-
-        // First search user variable (*ONLY* set user edit's the script)
-        // Handle case: cmd = "%fred:bill% and where we have user variable "fred:bill"
-        // Handle case: cmd = "%fred%      and where we have user variable "fred"
-        // If we fail to find the variable we return false.
-        // Note: When a variable is found, it can have an empty value  which is still valid
-        std::string varValue;
-        if (!user_edit_variables.empty() && search_user_edit_variables(percentVar, varValue, user_edit_variables)) {
-            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-        }
-        else if (generated_variable && firstColon == string::npos &&
-                 find_parent_gen_variable_value(percentVar, varValue)) {
-            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-        }
-        else {
-            if (firstColon != string::npos) {
-
-                if (is_a_alias && findParentVariableValue(percentVar, varValue)) {
-                    // For alias, we could have added variables with %A:0%, %A:1%.
-                    // Aliases allow variables with ':' in the name.
-                    cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-                }
-                else {
-                    // ':' is not a valid in variables, hence split, and search, if search fails use replacement
-                    string var(percentVar.begin(), percentVar.begin() + firstColon);
-#ifdef DEBUG_S
-                    cout << "   var " << var << "\n";
-#endif
-                    if (!user_edit_variables.empty() &&
-                        search_user_edit_variables(var, varValue, user_edit_variables)) {
-#ifdef DEBUG_S
-                        cout << "   user var value = " << varValue << "\n";
-#endif
-                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-                    }
-                    else if (generated_variable && find_parent_gen_variable_value(var, varValue)) {
-#ifdef DEBUG_S
-                        cout << "   generated var value = " << varValue << "\n";
-#endif
-                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-                    }
-                    else if (findParentVariableValue(var, varValue)) {
-                        // Note: variable can exist, but have an empty value
-#ifdef DEBUG_S
-                        cout << "   var value = " << varValue << "\n";
-#endif
-                        // replace the "%VAR:fred --f%" with var
-                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-                    }
-                    else {
-                        string substitute(percentVar.begin() + firstColon + 1, percentVar.end());
-#ifdef DEBUG_S
-                        cout << "  substitute value = " << substitute << "\n";
-#endif
-                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, substitute);
-                    }
-#ifdef DEBUG_S
-                    cout << "   cmd = " << cmd << "\n";
-#endif
-                }
-            }
-            else if (findParentVariableValue(percentVar, varValue)) {
-                // No ':' search user variables, repeat, and then generated variables.
-                cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-            }
-            else {
-                // Can't find in user variables, or node variable, hence can't go any further
-                return false;
-            }
-        }
-
-        // Simple Check for infinite recursion
-        if (count > 1000)
-            return false;
-        count++;
-    }
-
-    if (double_micro_found) {
-        // replace all double micro with a single micro, this must be a single parse
-        // date +%%Y%%m%%d" ==> date +%Y%m%d
-        // %%%%             ==> %%            // i.e. single parse
-        std::string doubleEcfMicro;
-        doubleEcfMicro += micro;
-        doubleEcfMicro += micro;
-        size_t last_pos = 0;
-        while (true) {
-            string::size_type ecf_double_micro_pos = cmd.find(doubleEcfMicro, last_pos);
-            if (ecf_double_micro_pos != std::string::npos) {
-                cmd.erase(cmd.begin() + ecf_double_micro_pos);
-                last_pos = ecf_double_micro_pos + 1;
-            }
-            else
-                break;
-        }
-    }
-
-    return true;
-}
-
-bool Node::find_all_used_variables(std::string& cmd, NameValueMap& used_variables, char micro) const {
-#ifdef DEBUG_S
-    cout << "cmd  = " << cmd << "\n";
-#endif
-    int count = 0;
-    while (true) {
-        // A while loop here is used to:
-        //   a/ Allow for multiple substitution on a single line. i.e. `%ECF_FILES% -I %ECF_INCLUDE%`
-        //   b/ Allow for recursive substitution. %fred% -> %bill% -> 10
-
-        size_t firstPercentPos = cmd.find(micro);
-        if (firstPercentPos == string::npos)
-            break;
-        size_t secondPercentPos = cmd.find(micro, firstPercentPos + 1);
-        if (secondPercentPos == string::npos)
-            break;
-        if (secondPercentPos - firstPercentPos <= 1)
-            break; // handle %% with no characters in between
-
-        string percentVar(cmd.begin() + firstPercentPos + 1, cmd.begin() + secondPercentPos);
-#ifdef DEBUG_S
-        cout << "   Found percentVar " << percentVar << "\n";
-#endif
-
-        size_t firstColon = percentVar.find(':');
-        if (firstColon != string::npos) {
-
-            string var(percentVar.begin(), percentVar.begin() + firstColon);
-#ifdef DEBUG_S
-            cout << "   var " << var << "\n";
-#endif
-
-            std::string varValue;
-            if (findParentVariableValue(var, varValue)) {
-                // Note: variable can exist, but have an empty value
-#ifdef DEBUG_S
-                cout << "   var value = " << theFoundVariable.value() << "\n";
-#endif
-                // %VAR:fred% --->  name("VAR:fred") value(theFoundVariable.value())
-                used_variables.insert(std::make_pair(percentVar, varValue));
-
-                // replace the "%VAR:fred --f%" with variable value, so that we don't process it again
-                cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-            }
-            else {
-                string substitute(percentVar.begin() + firstColon + 1, percentVar.end());
-#ifdef DEBUG_S
-                cout << "  substitute value = " << substitute << "\n";
-#endif
-
-                // %VAR:fred% --->  name("VAR:fred") value(fred)
-                used_variables.insert(std::make_pair(percentVar, substitute));
-
-                cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, substitute);
-            }
-#ifdef DEBUG_S
-            cout << "   cmd = " << cmd << "\n";
-#endif
-        }
-        else {
-
-            // If we fail to find the variable we return false.
-            // Note: When a variable is found, it can have an empty value
-            //       which is still valid
-            std::string varValue;
-            if (!findParentVariableValue(percentVar, varValue))
-                return false;
-
-            used_variables.insert(std::make_pair(percentVar, varValue));
-            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-        }
-
-        // Simple Check for infinite recursion
-        if (count > 100)
-            return false;
-        count++;
-    }
-    return true;
-}
-
-bool Node::variable_dollar_substitution(std::string& cmd) const {
-    // scan command for environment variables, and substitute
-    // edit ECF_INCLUDE $ECF_HOME/include
-
-    while (true) {
-        size_t firstPos = cmd.find('$');
-        if (firstPos == string::npos)
-            break;
-
-        size_t secondPos = cmd.find_first_not_of(Str::ALPHANUMERIC_UNDERSCORE(), firstPos + 1);
-        if (secondPos == string::npos)
-            secondPos = cmd.size();
-        if (secondPos - firstPos <= 1)
-            break; // handle $/ with no characters in between
-
-        string env(cmd.begin() + firstPos + 1, cmd.begin() + secondPos);
-        // cout << "find env " << env << "\n";
-
-        std::string envValue;
-        if (!findParentVariableValue(env, envValue)) {
-            // cout << " could not find " << env << "\n";
-            return false;
-        }
-
-        cmd.replace(firstPos, secondPos - firstPos, envValue);
-
-        if (envValue.find(env) != std::string::npos) {
-            // infinite loop
-            break;
-        }
-    }
-    return true;
-}
-
-std::string Node::completeExpression() const {
-    if (c_expr_) {
-        string ret = "complete ";
-        ret += c_expr_->expression();
-        return ret;
-    }
-    return string();
-}
-
-std::string Node::triggerExpression() const {
-    if (t_expr_) {
-        string ret = "trigger ";
-        ret += t_expr_->expression();
-        return ret;
-    }
-    return string();
-}
-
-bool Node::check_expressions(Ast* ast, const std::string& expr, bool trigger, std::string& errorMsg) const {
-    if (ast) {
-        // The expression has been parsed, and we have created the abstract syntax tree.
-        // We now try to resolve the path/node references in the expressions.
-        // And, also, resolve references to events, meter, repeats and variables.
-        AstResolveVisitor astVisitor(this);
-        ast->accept(astVisitor);
-        if (!astVisitor.errorMsg().empty()) {
-            errorMsg += "Error: Expression node tree references failed for '";
-            if (trigger)
-                errorMsg += "trigger ";
-            else
-                errorMsg += "complete ";
-            errorMsg += expr;
-            errorMsg += "' at ";
-            errorMsg += debugNodePath();
-            errorMsg += "\n ";
-            errorMsg += astVisitor.errorMsg();
-            return false;
-        }
-
-        // check divide by zero and module by zero
-        if (!ast->check(errorMsg)) {
-            errorMsg += " Error: Expression checking failed for '";
-            if (trigger)
-                errorMsg += "trigger ";
-            else
-                errorMsg += "complete ";
-            errorMsg += expr;
-            errorMsg += "' at ";
-            errorMsg += debugNodePath();
-            return false;
-        }
-    }
-    return true;
-}
-
-std::unique_ptr<AstTop>
-Node::parse_and_check_expressions(const std::string& expr, bool trigger, const std::string& context) {
-    std::unique_ptr<AstTop> ast = Expression::parse(expr, context); // will throw for errors
-
-    std::string errorMsg;
-    if (!check_expressions(ast.get(), expr, trigger, errorMsg)) {
-        std::stringstream ss;
-        ss << context << " " << errorMsg;
-        throw std::runtime_error(ss.str());
-    }
-    return ast;
-}
-
-bool Node::check(std::string& errorMsg, std::string& warningMsg) const {
-    // #ifdef DEBUG
-    //  	cout << "Node::check " << debugNodePath() << " complete and trigger\n";
-    // #endif
-
-    /// ************************************************************************************
-    /// *IMPORTANT side effect: *
-    /// The simulator relies AstResolveVisitor to set usedInTrigger() for events and meters
-    /// *************************************************************************************
-
-    /// Make Sure: To sure capture parser errors:
-    /// defs which fail parse errors should not be allowed to be loaded into the server
-    /// Even if the code parses, check the expression for divide by zero, for divide and modulo operators
-    AstTop* ctop = completeAst(errorMsg);
-    if (ctop) {
-        // capture node path resolve errors, and expression divide/module by zero
-        std::string expr;
-        if (c_expr_)
-            expr = c_expr_->expression();
-        (void)check_expressions(ctop, expr, false, errorMsg);
-    }
-
-    AstTop* ttop = triggerAst(errorMsg);
-    if (ttop) {
-        std::string expr;
-        if (t_expr_)
-            expr = t_expr_->expression();
-        (void)check_expressions(ttop, expr, true, errorMsg);
-    }
-
-    // check inLimit references to limits.
-    // Client: Unresolved references, which are not in the externs reported as errors/warnings
-    // Server: There are no externs, all unresolved references reported as errors
-    bool reportErrors   = true;
-    bool reportWarnings = true;
-    inLimitMgr_.check(errorMsg, warningMsg, reportErrors, reportWarnings);
-
-    /// Check that the references to nodes in autorestore resolve
-    if (auto_restore_)
-        auto_restore_->check(errorMsg);
-
-    return errorMsg.empty();
-}
-
-void Node::add_comment_char(std::string& ret, bool& added_comment_char) const {
-    if (!added_comment_char) {
-        ret += " #";
-        added_comment_char = true;
-    }
-}
-
-void Node::write_state(std::string& ret, bool& added_comment_char) const {
-    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e. `task a; task b;`
-    // If attribute correspond to the defaults don't write then out
-    if (state() != NState::UNKNOWN) {
-        add_comment_char(ret, added_comment_char);
-        ret += " state:";
-        ret += NState::toString(state());
-    }
-    if (st_.second.total_seconds() != 0) {
-        add_comment_char(ret, added_comment_char);
-        ret += " dur:";
-        ret += to_simple_string(st_.second);
-    }
-    if (flag_.flag() != 0) {
-        add_comment_char(ret, added_comment_char);
-        ret += " flag:";
-        flag_.write(ret);
-    }
-    if (suspended_) {
-        add_comment_char(ret, added_comment_char);
-        ret += " suspended:1";
-    }
-    if (!sc_rt_.is_special() && (sc_rt_.hours() != 0 || sc_rt_.minutes() != 0 || sc_rt_.seconds() != 0)) {
-        add_comment_char(ret, added_comment_char);
-        ret += " rt:";
-        ret += to_simple_string(sc_rt_);
-    }
-}
-
-void Node::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
-    //  0    1   2
-    // task name #
-    std::string token;
-    size_t line_tokens_size = lineTokens.size();
-    for (size_t i = 3; i < line_tokens_size; i++) {
-        token.clear();
-        const std::string& line_token_i = lineTokens[i];
-        if (line_token_i.find("state:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Node::read_state Invalid state specified for node " + name());
-            std::pair<NState::State, bool> state_pair = NState::to_state(token);
-            if (!state_pair.second)
-                throw std::runtime_error("Node::read_state Invalid state specified for node : " + name());
-            set_state_only(state_pair.first);
-        }
-        else if (line_token_i.find("flag:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Node::read_state invalid flags for node " + name());
-            flag().set_flag(token); // this can throw
-        }
-        else if (line_token_i.find("dur:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Node::read_state invalid duration for node: " + name());
-            st_.second = duration_from_string(token);
-        }
-        else if (line_token_i.find("rt:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, token))
-                throw std::runtime_error("Node::read_state invalid runtime duration for node: " + name());
-            sc_rt_ = duration_from_string(token);
-        }
-        else if (line_token_i == "suspended:1")
-            suspend();
-    }
-}
-
-std::string Node::print() const {
-    std::string s;
-    print(s);
-    return s;
-}
-
-void Node::print(std::string& os) const {
-    if (d_st_ != DState::default_state()) {
-        Indentor in;
-        Indentor::indent(os);
-        os += "defstatus ";
-        os += DState::toString(d_st_);
-        os += "\n";
-    }
-
-    if (late_)
-        late_->print(os);
-
-    if (c_expr_) {
-        c_expr_->print(os, "complete");
-        if (PrintStyle::getStyle() == PrintStyle::STATE) {
-            Indentor in;
-            if (c_expr_->isFree()) {
-                Indentor::indent(os);
-                os += "# (free)\n";
-            }
-            if (completeAst()) {
-                if (!defs()) {
-                    // Full defs is required for extern checking, and finding absolute node paths
-                    // Hence print will with no defs can give in-accurate information
-                    Indentor in2;
-                    Indentor::indent(os);
-                    os += "# Warning: Full/correct AST evaluation requires the definition\n";
-                }
-                std::stringstream ss;
-                completeAst()->print(ss);
-                os += ss.str();
-            }
-        }
-    }
-    if (t_expr_) {
-        t_expr_->print(os, "trigger");
-        if (PrintStyle::getStyle() == PrintStyle::STATE) {
-            Indentor in;
-            if (t_expr_->isFree()) {
-                Indentor::indent(os);
-                os += "# (free)\n";
-            }
-            if (triggerAst()) {
-                if (!defs()) {
-                    Indentor in2;
-                    Indentor::indent(os);
-                    os += "# Warning: Full/correct AST evaluation requires the definition\n";
-                }
-                std::stringstream ss;
-                triggerAst()->print(ss);
-                os += ss.str();
-            }
-        }
-    }
-    repeat_.print(os); // if repeat is empty print(..) does nothing
-
-    for (const Variable& v : vars_) {
-        v.print(os);
-    }
-
-    if (PrintStyle::getStyle() == PrintStyle::STATE) {
-        // Distinguish normal variable from generated, by adding a #
-        // This also allows it to be read in again and compared in the AParser/tests
-        std::vector<Variable> gvec;
-        gen_variables(gvec);
-        for (const Variable& v : gvec) {
-            v.print_generated(os);
-        }
-    }
-
-    for (limit_ptr l : limits_) {
-        l->print(os);
-    }
-    inLimitMgr_.print(os);
-
-    for (const Label& la : labels_) {
-        la.print(os);
-    }
-    for (const Meter& m : meters_) {
-        m.print(os);
-    }
-    for (const Event& e : events_) {
-        e.print(os);
-    }
-
-    for (const ecf::TimeAttr& t : times_) {
-        t.print(os);
-    }
-    for (const ecf::TodayAttr& t : todays_) {
-        t.print(os);
-    }
-    for (const DateAttr& date : dates_) {
-        date.print(os);
-    }
-    for (const DayAttr& day : days_) {
-        day.print(os);
-    }
-    for (const CronAttr& cron : crons_) {
-        cron.print(os);
-    }
-
-    if (auto_cancel_)
-        auto_cancel_->print(os);
-    if (auto_archive_)
-        auto_archive_->print(os);
-    if (auto_restore_)
-        auto_restore_->print(os);
-
-    if (misc_attrs_)
-        misc_attrs_->print(os);
-}
-
-std::string Node::print(PrintStyle::Type_t p_style) const {
-    PrintStyle print_style(p_style);
-    return to_string();
-}
-
-std::string Node::to_string() const {
-    std::string ss;
-    print(ss);
-    return ss;
-}
-
-bool Node::operator==(const Node& rhs) const {
-    if (n_ != rhs.n_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==( n_(" << n_ << ") != rhs.n_(" << rhs.n_ << ")) for: " << debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (state() != rhs.state()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  state(" << NState::toString(state()) << ") != rhs.state("
-                      << NState::toString(rhs.state()) << ")) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (d_st_ != rhs.d_st_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  ( d_st_ != rhs.d_st_) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (suspended_ != rhs.suspended_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator== suspended_ != rhs.suspended_ " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (flag_ != rhs.flag_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator== ( flag_ != rhs.flag_) : '" << flag_.to_string() << "' != '"
-                      << rhs.flag_.to_string() << "' : " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if ((t_expr_ && !rhs.t_expr_) || (!t_expr_ && rhs.t_expr_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (t_expr_ && !rhs.t_expr_) || (!t_expr_&& rhs.t_expr_)  " << debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (t_expr_ && rhs.t_expr_ && (*t_expr_ != *rhs.t_expr_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  t_expr_ && rhs.t_expr_ && (*t_expr_ != *rhs.t_expr_) " << debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if ((c_expr_ && !rhs.c_expr_) || (!c_expr_ && rhs.c_expr_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (c_expr_ && !rhs.c_expr_) || (!c_expr_&& rhs.c_expr_)  " << debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (c_expr_ && rhs.c_expr_ && (*c_expr_ != *rhs.c_expr_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  c_expr_ && rhs.c_expr_ && (*c_expr_ != *rhs.c_expr_) " << debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (vars_.size() != rhs.vars_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (vars_.size() != rhs.vars_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < vars_.size(); ++i) {
-        if (!(vars_[i] == rhs.vars_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==  (!(vars_[i] == rhs.vars_[i] )) " << debugNodePath() << "\n";
-                std::cout << "     vars_[i] name = '" << vars_[i].name() << "' value = '" << vars_[i].theValue()
-                          << "'\n";
-                std::cout << " rhs.vars_[i] name = '" << rhs.vars_[i].name() << "' value = '" << rhs.vars_[i].theValue()
-                          << "'\n";
-            }
-#endif
-            return false;
-        }
-    }
-    // We don't compare `genvar` as this is only used in server environment
-
-    if (!(inLimitMgr_ == rhs.inLimitMgr_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (!(inLimitMgr == rhs.inLimitMgr)) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (limits_.size() != rhs.limits_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (limits_.size(" << limits_.size() << ") != rhs.limits_.size("
-                      << rhs.limits_.size() << ")) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < limits_.size(); ++i) {
-        if (!(*limits_[i] == *rhs.limits_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==  (!(*limits_[i] == *rhs.limits_[i] )) " << debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (times_.size() != rhs.times_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (times_.size() != rhs.times_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < times_.size(); ++i) {
-        if (!(times_[i] == rhs.times_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==  (!(times_[i] == rhs.times_[i] ))  " << debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (todays_.size() != rhs.todays_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (todays_.size() != rhs.todays_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < todays_.size(); ++i) {
-        if (!(todays_[i] == rhs.todays_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==  (!(todays_[i] == rhs.todays_[i] ))  " << debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (dates_.size() != rhs.dates_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==   (dates_.size() != rhs.dates_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < dates_.size(); ++i) {
-        if (!(dates_[i] == rhs.dates_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==   (!(dates_[i] == rhs.dates_[i]) " << debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (days_.size() != rhs.days_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==   (days_.size() != rhs.days_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < days_.size(); ++i) {
-        if (!(days_[i] == rhs.days_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==   (!(days_[i] == rhs.days_[i]) " << debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (crons_.size() != rhs.crons_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==   (crons_.size() != rhs.crons_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < crons_.size(); ++i) {
-        if (!(crons_[i] == rhs.crons_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==   (!(crons_[i] == rhs.crons_[i]) " << debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (labels_.size() != rhs.labels_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (labels_.size() != rhs.labels_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (unsigned i = 0; i < labels_.size(); ++i) {
-        if (labels_[i] != rhs.labels_[i]) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==  (labels_[i] != rhs.labels_[i]) " << debugNodePath() << "\n";
-                std::cout << "   lhs = " << labels_[i].dump() << "\n";
-                std::cout << "   rhs = " << rhs.labels_[i].dump() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if (meters_.size() != rhs.meters_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  (meters_.size() != rhs.meters_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (size_t i = 0; i < meters_.size(); ++i) {
-        if (!(meters_[i] == rhs.meters_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==   (!(meters_[i] == rhs.meters_[i] )) " << debugNodePath() << "\n";
-                std::cout << "   " << meters_[i].dump() << "\n";
-                std::cout << "   " << rhs.meters_[i].dump() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-    if (events_.size() != rhs.events_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==   (events_.size() != rhs.events_.size()) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    for (size_t i = 0; i < events_.size(); ++i) {
-        if (!(events_[i] == rhs.events_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Node::operator==   (!(events_[i] == rhs.events_[i] )) " << debugNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    if ((misc_attrs_ && !rhs.misc_attrs_) || (!misc_attrs_ && rhs.misc_attrs_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator== (( misc_attrs_ && !rhs.misc_attrs_) || ( !misc_attrs_ && rhs.misc_attrs_)) "
-                      << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (misc_attrs_ && rhs.misc_attrs_ && !(*misc_attrs_ == *rhs.misc_attrs_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator== ( misc_attrs_ && rhs.misc_attrs_ && !(*misc_attrs_ == *(rhs.misc_attrs_))) "
-                      << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (!(repeat_ == rhs.repeat_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==   if (!(repeat_ == rhs.repeat_)) " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if ((late_ && !rhs.late_) || (!late_ && rhs.late_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator== (( late_ && !rhs.late_) || ( !late_ && rhs.late_)) " << debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-    if (late_ && rhs.late_ && !(*late_ == *rhs.late_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator== ( late_ &&   rhs.late_ && !(*late_ == *(rhs.late_))) " << debugNodePath()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (auto_restore_ && rhs.auto_restore_) {
-        if (*auto_restore_ == *rhs.auto_restore_) {
-            return true;
-        }
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator== auto_restore_ && rhs.auto_restore_   " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    else if (!auto_restore_ && rhs.auto_restore_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  !auto_restore_ && rhs.auto_restore_ " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    else if (auto_restore_ && !rhs.auto_restore_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  auto_restore_ && !rhs.auto_restore_  " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (auto_cancel_ && !rhs.auto_cancel_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  if (auto_cancel_ && !rhs.auto_cancel_)  " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (!auto_cancel_ && rhs.auto_cancel_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  if (!auto_cancel_ && rhs.auto_cancel_)  " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (auto_cancel_ && rhs.auto_cancel_ && !(*auto_cancel_ == *rhs.auto_cancel_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout
-                << "Node::operator==  (auto_cancel_ && rhs.auto_cancel_ && !(*auto_cancel_ == *rhs.auto_cancel_)) "
-                << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (auto_archive_ && !rhs.auto_archive_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  if (auto_archive_ && !rhs.auto_archive_)  " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (!auto_archive_ && rhs.auto_archive_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Node::operator==  if (!auto_archive_ && rhs.auto_archive_)  " << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (auto_archive_ && rhs.auto_archive_ && !(*auto_archive_ == *rhs.auto_archive_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout
-                << "Node::operator==  (auto_archive_ && rhs.auto_archive_ && !(*auto_archive_ == *rhs.auto_archive_)) "
-                << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    return true;
-}
-
-// #define DEBUG_WHY 1
-
-bool Node::top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
-#ifdef DEBUG_WHY
-    cout << "Node::top_down_why\n";
-#endif
-    return why(theReasonWhy, html_tags);
-}
-
-void Node::bottom_up_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
-#ifdef DEBUG_WHY
-    cout << "Node::bottom_up_why\n";
-#endif
-
-    defs()->why(theReasonWhy, html_tags);
-
-    std::vector<Node*> vec;
-    vec.push_back(const_cast<Node*>(this));
-    Node* theParent = parent();
-    while (theParent) {
-        vec.push_back(theParent);
-        theParent = theParent->parent();
-    }
-    auto r_end = vec.rend();
-    for (auto r = vec.rbegin(); r != r_end; ++r) {
-        (void)(*r)->why(theReasonWhy, html_tags);
-    }
-}
-
-bool Node::why(std::vector<std::string>& vec, bool html) const {
-#ifdef DEBUG_WHY
-    std::cout << "Node::why " << debugNodePath() << " (" << NState::toString(state()) << ") top_down(" << top_down
-              << ") html(" << html << ")\n";
-#endif
-    bool why_found = false;
-    if (isSuspended()) {
-        std::string theReasonWhy;
-        if (html) {
-            theReasonWhy = path_href();
-            theReasonWhy += " is ";
-            theReasonWhy += DState::to_html(DState::SUSPENDED);
-        }
-        else {
-            theReasonWhy = debugNodePath();
-            theReasonWhy += " is suspended";
-        }
-        vec.push_back(theReasonWhy);
-        why_found = true; // return true if why found
-    }
-    else if (state() != NState::QUEUED && state() != NState::ABORTED) {
-        std::stringstream ss;
-        if (html)
-            ss << path_href() << " (" << NState::to_html(state()) << ") is not queued or aborted";
-        else
-            ss << debugNodePath() << " (" << NState::toString(state()) << ") is not queued or aborted";
-        vec.push_back(ss.str());
-
-        // When task is active/submitted no point, going any further.
-        // However, for FAMILY/SUITE we still need to proceed
-        if (isTask())
-            return why_found;
-        why_found = true; // return true if why found
-    }
-
-    // Check limits using in limit manager
-    if (inLimitMgr_.why(vec, html))
-        why_found = true; // return true if why found
-
-    // Prefix <node-type> <path> <state>
-    std::string prefix = debugType();
-    prefix += " ";
-    if (html)
-        prefix += path_href_attribute(absNodePath());
-    else
-        prefix += absNodePath();
-    prefix += "(";
-    if (html)
-        prefix += NState::to_html(state());
-    else
-        prefix += NState::toString(state());
-    prefix += ") ";
-
-    {
-        // postfix  = <attr-type dependent> <next run time > < optional current state>
-        std::string postFix;
-        const Calendar& c = suite()->calendar();
-        for (auto day : days_) {
-            postFix.clear();
-            if (day.why(c, postFix)) {
-                vec.push_back(prefix + postFix);
-                why_found = true;
-            }
-        }
-        for (const auto& date : dates_) {
-            postFix.clear();
-            if (date.why(c, postFix)) {
-                vec.push_back(prefix + postFix);
-                why_found = true;
-            }
-        }
-        for (const auto& today : todays_) {
-            postFix.clear();
-            if (today.why(c, days_, dates_, postFix)) {
-                vec.push_back(prefix + postFix);
-                why_found = true;
-            }
-        }
-        for (const auto& time : times_) {
-            postFix.clear();
-            if (time.why(c, days_, dates_, postFix)) {
-                vec.push_back(prefix + postFix);
-                why_found = true;
-            }
-        }
-        for (const auto& cron : crons_) {
-            postFix.clear();
-            if (cron.why(c, postFix)) {
-                vec.push_back(prefix + postFix);
-                why_found = true;
-            }
-        }
-    }
-
-    // **************************************************************************************
-    // If we have a complete expression that does not evaluate then it should *NOT* hold the node.
-    // The complete expression is used to set node to complete, when it evaluates and hence
-    // should not prevent further tree walking. evaluate each leaf branch
-    // **************************************************************************************
-
-    // Only report on trigger expression, if:
-    // 1/ No complete expression
-    // 2/ Have complete expression, but it does not evaluate
-    bool report_on_trigger_expression = true;
-    AstTop* theCompleteAst            = completeAst();
-    if (theCompleteAst) {
-        if (c_expr_->isFree() || theCompleteAst->evaluate()) {
-            report_on_trigger_expression = false; // complete is free, hence we do not look at trigger
-        }
-    }
-
-    AstTop* theTriggerAst = triggerAst();
-    if (report_on_trigger_expression && theTriggerAst) {
-        // Note 1: A trigger can be freed by the ForceCmd
-        // Note 2: if we have a non-NULL trigger ast, we must have trigger expression
-        // Note 3: The freed state is stored on the expression ( i.e. *NOT* on the ast (abstract syntax tree) )
-        if (!t_expr_->isFree()) {
-#ifdef DEBUG_WHY
-            std::cout << "   Node::why " << debugNodePath() << " checking trigger dependencies\n";
-#endif
-            std::string postFix;
-            if (theTriggerAst->why(postFix, html)) {
-                vec.push_back(prefix + postFix);
-                why_found = true; // return true if why found
-            }
-        }
-    }
-
-#ifdef DEBUG_WHY
-    std::cout << "   Node::why " << debugNodePath() << " why found(" << why_found << ")\n";
-#endif
-    return why_found; // no why found
-}
-
-bool Node::checkInvariants(std::string& errorMsg) const {
-    for (const ecf::TimeAttr& t : times_) {
-        if (!t.checkInvariants(errorMsg))
-            return false;
-    }
-    for (const ecf::TodayAttr& t : todays_) {
-        if (!t.checkInvariants(errorMsg))
-            return false;
-    }
-    for (const CronAttr& cron : crons_) {
-        if (!cron.checkInvariants(errorMsg))
-            return false;
-    }
-
-    if (misc_attrs_) {
-        if (!misc_attrs_->checkInvariants(errorMsg)) {
-            return false;
-        }
-    }
-    if (!repeat_.empty()) {
-        if (repeat_.name().empty()) {
-            errorMsg += "Repeat name empty ???";
-            return false;
-        }
-    }
-    return true;
-}
-
-std::string Node::absNodePath() const {
-    std::vector<std::string> vec;
-    vec.reserve(Str::reserve_16());
-    vec.push_back(name());
-    Node* theParent = parent();
-    while (theParent) {
-        vec.push_back(theParent->name());
-        theParent = theParent->parent();
-    }
-    std::string ret;
-    ret.reserve(Str::reserve_64());
-    auto r_end = vec.rend();
-    for (auto r = vec.rbegin(); r != r_end; ++r) {
-        ret += '/';
-        ret += *r;
-    }
-
-    //	// Another algorithm broadly similar results
-    //	std::string ret; ret.reserve(Str::reserve_64());
-    // 	ret += '/';
-    //	ret += name();
-    // 	Node* theParent = parent();
-    //	while (theParent) {
-    //		ret.insert(0,"/");
-    //		ret.insert(1,theParent->name());
-    // 		theParent = theParent->parent();
-    //	}
-
-    return ret;
-}
-
-std::string Node::debugNodePath() const {
-    std::string ret = debugType();
-    ret += Str::COLON();
-    ret += absNodePath();
-    return ret;
-}
-
-std::string Node::path_href_attribute(const std::string& path) {
-    std::string ret = "<a href=\"";
-    ret += path;
-    ret += "\">";
-    ret += path;
-    ret += "</a>";
-    return ret;
-}
-
-std::string Node::path_href_attribute(const std::string& path, const std::string& path2) {
-    std::string ret = "<a href=\"";
-    ret += path;
-    ret += "\">";
-    ret += path2;
-    ret += "</a>";
-    return ret;
-}
-
-std::string Node::path_href() const {
-    std::string ret = debugType();
-    ret += " ";
-    ret += path_href_attribute(absNodePath());
-    return ret;
-}
-
-void Node::verification(std::string& errorMsg) const {
-    if (misc_attrs_)
-        misc_attrs_->verification(errorMsg);
-}
-
-void Node::getAllAstNodes(std::set<Node*>& theSet) const {
-    if (completeAst()) {
-        AstCollateNodesVisitor astVisitor(theSet);
-        completeAst()->accept(astVisitor);
-    }
-    if (triggerAst()) {
-        AstCollateNodesVisitor astVisitor(theSet);
-        triggerAst()->accept(astVisitor);
-    }
-}
-
-AstTop* Node::completeAst() const {
-    if (c_expr_) {
-        std::string ignoredErrorMsg;
-        return completeAst(ignoredErrorMsg);
-    }
-    return nullptr;
-}
-
-AstTop* Node::triggerAst() const {
-    if (t_expr_) {
-        std::string ignoredErrorMsg;
-        return triggerAst(ignoredErrorMsg);
-    }
-    return nullptr;
-}
-
-AstTop* Node::completeAst(std::string& errorMsg) const {
-    if (c_expr_) {
-        if (c_expr_->get_ast() == nullptr) {
-
-            c_expr_->createAST(const_cast<Node*>(this), "complete", errorMsg);
-#ifdef DEBUG
-            if (errorMsg.empty())
-                LOG_ASSERT(c_expr_->get_ast(), "");
-#endif
-        }
-        return c_expr_->get_ast();
-    }
-    return nullptr;
-}
-
-AstTop* Node::triggerAst(std::string& errorMsg) const {
-    if (t_expr_) {
-        if (t_expr_->get_ast() == nullptr) {
-
-            t_expr_->createAST(const_cast<Node*>(this), "trigger", errorMsg);
-#ifdef DEBUG
-            if (errorMsg.empty())
-                LOG_ASSERT(t_expr_->get_ast(), "");
-#endif
-        }
-        return t_expr_->get_ast();
-    }
-    return nullptr;
-}
-
-void Node::invalidate_trigger_references() const {
-    if (t_expr_) {
-        if (t_expr_->get_ast()) {
-            t_expr_->get_ast()->invalidate_trigger_references();
-        }
-    }
-    if (c_expr_) {
-        if (c_expr_->get_ast()) {
-            c_expr_->get_ast()->invalidate_trigger_references();
-        }
-    }
-}
-
-node_ptr Node::remove() {
-    SuiteChanged0 changed(shared_from_this());
-
-    Node* theParent = parent();
-    if (theParent)
-        return theParent->removeChild(this);
-    return defs()->removeChild(this);
-}
-
-bool Node::getLabelValue(const std::string& labelName, std::string& value) const {
-    size_t theSize = labels_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (labels_[i].name() == labelName) {
-            if (!(labels_[i].new_value().empty()))
-                value = labels_[i].new_value();
-            else
-                value = labels_[i].value();
-            return true;
-        }
-    }
-    return false;
-}
-
-bool Node::getLabelNewValue(const std::string& labelName, std::string& value) const {
-    size_t theSize = labels_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (labels_[i].name() == labelName) {
-            value = labels_[i].new_value();
-            return true;
-        }
-    }
-    return false;
-}
-
-size_t Node::position() const {
-    Node* theParent = parent();
-    if (theParent) {
-        return theParent->child_position(this);
-    }
-    else {
-        Defs* theDefs = defs();
-        if (theDefs) {
-            return theDefs->child_position(this);
-        }
-    }
-    return std::numeric_limits<std::size_t>::max();
-}
-
-void Node::gen_variables(std::vector<Variable>& vec) const {
-    repeat_.gen_variables(vec); // if repeat_ is empty vec is unchanged
-}
-
-const Variable& Node::findGenVariable(const std::string& name) const {
-    return repeat_.find_gen_variable(name); // if repeat_ is empty find returns empty variable by ref
-}
-
-void Node::update_repeat_genvar() const {
-    repeat_.update_repeat_genvar(); // if repeat_ is empty update_repeat_genvar() does nothing
-}
-
-void Node::notify_delete() {
-    // make a copy, to avoid iterating over observer list that is being changed
-    std::vector<AbstractObserver*> copy_of_observers = observers_;
-    for (auto& copy_of_observer : copy_of_observers) {
-        copy_of_observer->update_delete(this);
-    }
-
-    /// Check to make sure that the Observer called detach
-    /// We cannot call detach ourselves, since the the client needs to
-    /// call detach in the case where the graphical tree is destroyed by user
-    /// In this case the Subject/Node is being deleted.
-    assert(observers_.empty());
-
-#ifdef DEBUG_NODE
-    if (!observers_.empty()) {
-        /// Its not safe to call debugNodePath()/absNodePath() since that will traverse the parent
-        /// This may not be safe during a delete.
-        std::cout << "notify_delete : Node is not observed : " << name() << "\n";
-    }
-#endif
-}
-
-void Node::notify_start(const std::vector<ecf::Aspect::Type>& aspects) {
-    size_t observers_size = observers_.size();
-    for (size_t i = 0; i < observers_size; i++) {
-        observers_[i]->update_start(this, aspects);
-    }
-}
-
-void Node::notify(const std::vector<ecf::Aspect::Type>& aspects) {
-    size_t observers_size = observers_.size();
-    for (size_t i = 0; i < observers_size; i++) {
-        observers_[i]->update(this, aspects);
-    }
-}
-
-void Node::attach(AbstractObserver* obs) {
-    observers_.push_back(obs);
-}
-
-void Node::detach(AbstractObserver* obs) {
-    for (size_t i = 0; i < observers_.size(); i++) {
-        if (observers_[i] == obs) {
-            observers_.erase(observers_.begin() + i);
-            return;
-        }
-    }
-}
-
-bool Node::is_observed(AbstractObserver* obs) const {
-    for (auto observer : observers_) {
-        if (observer == obs) {
-            return true;
-        }
-    }
-    return false;
-}
-
-void Node::sort_attributes(ecf::Attr::Type attr, bool recursive, const std::vector<std::string>& no_sort) {
-    // cout << "Node::sort_attributes " << absNodePath() << "  " << attr << " recursive " << recursive << "
-    // no_sort.size() " << no_sort.size() << "\n";
-
-    if (recursive && !no_sort.empty()) {
-        std::string path = absNodePath();
-        for (const auto& p : no_sort) {
-            // cout << " no_sort: " << p << "\n";
-            if (p == path) {
-                return;
-            }
-        }
-    }
-    auto caseInsen = [](const auto& a, const auto& b) { return Str::caseInsLess(a.name(), b.name()); };
-
-    state_change_no_ = Ecf::incr_state_change_no();
-    switch (attr) {
-        case Attr::EVENT:
-            sort(events_.begin(), events_.end(), [](const Event& a, const Event& b) {
-                return Str::caseInsLess(a.name_or_number(), b.name_or_number());
-            });
-            break;
-        case Attr::METER:
-            sort(meters_.begin(), meters_.end(), caseInsen);
-            break;
-        case Attr::LABEL:
-            sort(labels_.begin(), labels_.end(), caseInsen);
-            break;
-        case Attr::LIMIT:
-            sort(limits_.begin(), limits_.end(), [](const limit_ptr& a, const limit_ptr& b) {
-                return Str::caseInsLess(a->name(), b->name());
-            });
-            break;
-        case Attr::VARIABLE:
-            sort(vars_.begin(), vars_.end(), caseInsen);
-            break;
-        case Attr::ALL:
-            sort(vars_.begin(), vars_.end(), caseInsen);
-            sort(events_.begin(), events_.end(), [](const Event& a, const Event& b) {
-                return Str::caseInsLess(a.name_or_number(), b.name_or_number());
-            });
-            sort(meters_.begin(), meters_.end(), caseInsen);
-            sort(labels_.begin(), labels_.end(), caseInsen);
-            sort(limits_.begin(), limits_.end(), [](const limit_ptr& a, const limit_ptr& b) {
-                return Str::caseInsLess(a->name(), b->name());
-            });
-            break;
-        case Attr::UNKNOWN:
-            break;
-        default:
-            break;
-    }
-}
-
-bool Node::checkForAutoCancel(const ecf::Calendar& calendar) const {
-    if (auto_cancel_ && state() == NState::COMPLETE) {
-        if (auto_cancel_->isFree(calendar, get_state().second)) {
-
-            /// *Only* delete this node if we don't create zombies
-            /// anywhere for our children
-            vector<Task*> taskVec;
-            getAllTasks(taskVec);
-            for (Task* t : taskVec) {
-                if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
-                    return false;
-                }
-            }
-            return true;
-        }
-    }
-    return false;
-}
-
-bool Node::check_for_auto_archive(const ecf::Calendar& calendar) const {
-    if (auto_archive_ && !isSuspended() && !isParentSuspended()) {
-        if (auto_archive_->isFree(calendar, get_state())) {
-
-            /// *Only* archive this node if we don't create zombies anywhere for our children
-            /// The most significant state could be ABORTED in family, but we could still have active tasks.
-            vector<Task*> taskVec;
-            getAllTasks(taskVec);
-            for (Task* t : taskVec) {
-                if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
-                    return false;
-                }
-            }
-            return true;
-        }
-    }
-    return false;
-}
-
-void Node::stats(NodeStats& stats) {
-    stats.vars_ += vars_.size();
-    if (c_expr_)
-        stats.c_trigger_++;
-    if (t_expr_)
-        stats.trigger_++;
-    stats.meters_ += meters_.size();
-    stats.events_ += events_.size();
-    stats.labels_ += labels_.size();
-    stats.times_ += times_.size();
-    stats.todays_ += todays_.size();
-    stats.crons_ += crons_.size();
-    stats.dates_ += dates_.size();
-    stats.days_ += days_.size();
-
-    if (late_)
-        stats.late_++;
-    if (misc_attrs_) {
-        stats.verifys_ += misc_attrs_->verifys().size();
-        stats.zombies_ += misc_attrs_->zombies().size();
-        stats.queues_ += misc_attrs_->queues().size();
-        stats.generics_ += misc_attrs_->generics().size();
-    }
-    if (!repeat_.empty())
-        stats.repeats_++;
-
-    stats.limits_ += limits_.size();
-    stats.inlimits_ += inLimitMgr_.inlimits().size();
-    if (auto_cancel_)
-        stats.auto_cancel_++;
-    if (auto_archive_)
-        stats.auto_archive_++;
-    if (auto_restore_)
-        stats.auto_restore_++;
-}
-
-static std::vector<VerifyAttr> verifys_;
-static std::vector<ZombieAttr> zombies_;
-static std::vector<QueueAttr> queues_;
-static std::vector<GenericAttr> generics_;
-const std::vector<VerifyAttr>& Node::verifys() const {
-    if (misc_attrs_)
-        return misc_attrs_->verifys();
-    return verifys_;
-}
-const std::vector<ZombieAttr>& Node::zombies() const {
-    if (misc_attrs_)
-        return misc_attrs_->zombies();
-    return zombies_;
-}
-const std::vector<QueueAttr>& Node::queues() const {
-    if (misc_attrs_)
-        return misc_attrs_->queues();
-    return queues_;
-}
-std::vector<QueueAttr>& Node::ref_queues() {
-    if (misc_attrs_)
-        return misc_attrs_->ref_queues();
-    return queues_;
-}
-const std::vector<GenericAttr>& Node::generics() const {
-    if (misc_attrs_)
-        return misc_attrs_->generics();
-    return generics_;
-}
-
-std::vector<ZombieAttr>::const_iterator Node::zombie_begin() const {
-    if (misc_attrs_)
-        return misc_attrs_->zombie_begin();
-    return zombies_.begin();
-}
-std::vector<ZombieAttr>::const_iterator Node::zombie_end() const {
-    if (misc_attrs_)
-        return misc_attrs_->zombie_end();
-    return zombies_.end();
-}
-std::vector<VerifyAttr>::const_iterator Node::verify_begin() const {
-    if (misc_attrs_)
-        return misc_attrs_->verify_begin();
-    return verifys_.begin();
-}
-std::vector<VerifyAttr>::const_iterator Node::verify_end() const {
-    if (misc_attrs_)
-        return misc_attrs_->verify_end();
-    return verifys_.end();
-}
-std::vector<QueueAttr>::const_iterator Node::queue_begin() const {
-    if (misc_attrs_)
-        return misc_attrs_->queue_begin();
-    return queues_.begin();
-}
-std::vector<QueueAttr>::const_iterator Node::queue_end() const {
-    if (misc_attrs_)
-        return misc_attrs_->queue_end();
-    return queues_.end();
-}
-std::vector<GenericAttr>::const_iterator Node::generic_begin() const {
-    if (misc_attrs_)
-        return misc_attrs_->generic_begin();
-    return generics_.begin();
-}
-std::vector<GenericAttr>::const_iterator Node::generic_end() const {
-    if (misc_attrs_)
-        return misc_attrs_->generic_end();
-    return generics_.end();
-}
-
-template <class Archive>
-void Node::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(n_));
-
-    CEREAL_OPTIONAL_NVP(ar, st_, [this]() { return st_.first != NState::default_state(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, suspended_, [this]() { return suspended_; });
-    CEREAL_OPTIONAL_NVP(ar, d_st_, [this]() { return d_st_.state() != DState::default_state(); }); // conditionally save
-
-    CEREAL_OPTIONAL_NVP(ar, vars_, [this]() { return !vars_.empty(); });  // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, c_expr_, [this]() { return c_expr_.get(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, t_expr_, [this]() { return t_expr_.get(); }); // conditionally save
-
-    CEREAL_OPTIONAL_NVP(ar, meters_, [this]() { return !meters_.empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, events_, [this]() { return !events_.empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, labels_, [this]() { return !labels_.empty(); }); // conditionally save
-
-    CEREAL_OPTIONAL_NVP(ar, times_, [this]() { return !times_.empty(); });   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, todays_, [this]() { return !todays_.empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, crons_, [this]() { return !crons_.empty(); });   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, dates_, [this]() { return !dates_.empty(); });   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, days_, [this]() { return !days_.empty(); });     // conditionally save
-
-    CEREAL_OPTIONAL_NVP(ar, late_, [this]() { return late_.get(); });             // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, misc_attrs_, [this]() { return misc_attrs_.get(); }); // conditionally save
-
-    CEREAL_OPTIONAL_NVP(ar, repeat_, [this]() { return !repeat_.empty(); });                    // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, limits_, [this]() { return !limits_.empty(); });                    // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, inLimitMgr_, [this]() { return !inLimitMgr_.inlimits().empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, flag_, [this]() { return flag_.flag() != 0; });                     // conditionally save
-
-    CEREAL_OPTIONAL_NVP(ar, auto_cancel_, [this]() { return auto_cancel_.get(); });   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, auto_archive_, [this]() { return auto_archive_.get(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, auto_restore_, [this]() { return auto_restore_.get(); }); // conditionally save
-
-    if (Archive::is_loading::value) {
-        if (auto_restore_)
-            auto_restore_->set_node(this);
-        if (misc_attrs_)
-            misc_attrs_->set_node(this);
-        for (auto& limit : limits_)
-            limit->set_node(this);
-    }
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(Node);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Node.hpp 5.13.0-1/ANode/src/ecflow/node/Node.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Node.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Node.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,924 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Node_HPP
-#define ecflow_node_Node_HPP
-
-///
-/// \note The node class does NOT serialise the triggers and complete.
-/// These are created on demand in the server. However when the client code
-/// loads the definition file, the Defs::check will create AST for trigger and
-/// complete expressions, because:
-///  1/ the AST are created, so that any parser errors can be _reported_ to the user
-///  2/ References in the AST expressions are resolved, and errors flagged.
-///
-/// This information could have been saved, however was _not_, because:
-///  1/ problems on AIX
-///  2/ Cut down on IPC load between client/server
-///
-
-#include <iosfwd>
-#include <limits>
-
-#include "ecflow/attribute/CronAttr.hpp"
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/attribute/RepeatAttr.hpp"
-#include "ecflow/attribute/TimeAttr.hpp"
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/DState.hpp"
-#include "ecflow/core/NOrder.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Aspect.hpp"
-#include "ecflow/node/Attr.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/InLimit.hpp"
-#include "ecflow/node/InLimitMgr.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-namespace ecf {
-class Simulator;
-class SimulatorVisitor;
-class DefsAnalyserVisitor;
-class FlatAnalyserVisitor;
-} // namespace ecf
-
-namespace ecf {
-class Calendar;
-class NodeTreeVisitor;
-class LateAttr;
-} // namespace ecf
-
-class Node : public std::enable_shared_from_this<Node> {
-protected:
-    Node(const std::string& name, bool check);
-    Node();
-
-public:
-    Node& operator=(const Node&);
-    bool operator<(const Node& rhs) { return name() < rhs.name(); }
-
-    Node(const Node& rhs);
-    virtual ~Node();
-    virtual bool check_defaults() const;
-
-    // parse string and create suite || family || task || alias. Can return a NULL node_ptr() for errors
-    static node_ptr create(const std::string& node_string);
-    static node_ptr create(const std::string& node_string, std::string& error_msg);
-
-    /// The Parent Must set the parent pointer. For a Suite however this will be NULL
-    void set_parent(Node* p) { parent_ = p; }
-
-    virtual node_ptr clone() const = 0;
-
-    // Server called functions:
-    //   Required when we have time attributes, when time related attribute are free they stay free, until re-queue
-    struct Calendar_args
-    {
-        Calendar_args() = default;
-
-        std::vector<node_ptr> auto_cancelled_nodes_;
-        std::vector<node_ptr> auto_archive_nodes_;
-    };
-    virtual bool calendarChanged(const ecf::Calendar&,
-                                 Node::Calendar_args&,
-                                 const ecf::LateAttr* inherited_late,
-                                 bool holding_parent_day_or_date);
-
-    /// resolving dependencies means we look at day,date,time and triggers and check to
-    /// to see if a node is free or still holding. When a node if free of its dependencies and limits
-    /// Its state is changed to submitted. When a task is in a the submitted state its
-    /// associated ecf file can be submitted.
-    /// ************************************************************************************
-    /// There is no point in resolving child dependencies if the parent is not FREE
-    //  We will return a bool, true means we are free, false for holding
-    // *************************************************************************************
-    virtual bool resolveDependencies(JobsParam& jobsParam);
-
-    /// When the server is terminated and then restarted, Allow time attributes to catch up.
-    /// We need to check all attributes dependent on time.
-    virtual bool has_time_based_attributes() const;
-
-    /// Command related functions:
-    /// suspend generation of jobs. Below this node.
-    /// Note: When a node is suspended. time/date dependencies are still handled
-    ///       A node which is free of time is marked.
-    /// Note: suspended is *NOT* a node state. It just an *attribute*. NState::State
-    /// represents all the life cycle change a Node can go through. Suspended does
-    /// not real fit into this and has been separated out.
-    bool isSuspended() const { return suspended_; }
-    bool isParentSuspended() const;
-    void suspend();
-
-    /// resume generation of jobs, and kick of an immediate job generation
-    /// If not previously suspended does nothing
-    void resume();
-
-    /// Kill the task if it is active. For NodeContainers do it hierarchically
-    /// will throw std::runtime_error for any errors
-    virtual void kill(const std::string& zombie_pid = "") = 0;
-
-    /// Show status of a node. For NodeContainers do it hierarchically
-    /// will throw std::runtime_error for any errors
-    virtual void status() = 0;
-
-    /// Order the node using the second parameter
-    virtual void order(Node* /*immediateChild*/, NOrder::Order) {}
-    virtual void move_peer(Node* /*src*/, Node* /*dest*/) {}
-
-    /// called when definition is restored from a file/checkpoint
-    virtual void handle_migration(const ecf::Calendar&);
-
-    /// reset all. Used after job generation.
-    /// Unlike re-queue/begin, will reset time attributes. see ECFLOW-1204
-    virtual void reset();
-
-    /// For suites it allows dependencies to be resolved, and changes state to defStatus
-    virtual void begin();
-
-    /// re queue this node. States are reset to defStatus
-    /// Typically resetRepeats is set to true, when called from user command
-    /// or when re-queue is called from NodeContainer/parent
-    ///
-    /// With user interaction : we need to clear the suspended state for *child* nodes
-    /// To distinguish between child and parent, we use a integer 'level'
-    /// This was done so that if user had suspended a task deep in the hierarchy. (which is then
-    /// not displayed in the GUI), and then chooses to re-queue at a *high* level,
-    /// we need to clear child suspended state.(Principle of least surprise)
-    /// However we will preserve def status.
-    /// If a user re-queues a node that is suspended then it stays suspended
-    /// We use -1 to mean leave suspended state as is
-    ///
-    /// When the user issues force-complete or run interactive commands, we want to miss
-    /// the next-time slot. (i.e to avoid running the job again).
-    /// This is done by using NO_REQUE_IF_SINGLE_TIME_DEP flag.
-    /// The flag remain set until we get to *this* function. We use it to avoid
-    /// resetting the time slots, effectively missing the next time slot. we then clear the flag.
-    /// However if the JOB *abort* we clear NO_REQUE_IF_SINGLE_TIME_DEP
-    /// Otherwise if we run again, we miss additional time slots necessarily
-    struct Requeue_args
-    {
-        enum Requeue_t { REPEAT_INCREMENT = 1, TIME = 2, FULL = 3 };
-        Requeue_args() = default;
-        explicit Requeue_args(Requeue_t r_t) : requeue_t(r_t){};
-        Requeue_args(Requeue_t r_t,
-                     bool resetRepeats,
-                     int clear_suspended_in_child_nodes,
-                     bool reset_next_time_slot,
-                     bool reset_relative_duration,
-                     bool log_state_changes = true)
-            : requeue_t(r_t),
-              clear_suspended_in_child_nodes_(clear_suspended_in_child_nodes),
-              resetRepeats_(resetRepeats),
-              reset_next_time_slot_(reset_next_time_slot),
-              reset_relative_duration_(reset_relative_duration),
-              log_state_changes_(log_state_changes) {}
-        const Requeue_t requeue_t{FULL};
-        int clear_suspended_in_child_nodes_{0};
-        const bool resetRepeats_{true};
-        const bool reset_next_time_slot_{true};
-        const bool reset_relative_duration_{true};
-        const bool log_state_changes_{true};
-    };
-    virtual void requeue(Requeue_args&);
-
-    // force queued allows a job to re-run preserving job output.
-    // However, other nodes may reference this node's events/meters/late in trigger expression,
-    // and reset events, meters and late flag ECFLOW-1617
-    virtual void reset_late_event_meters();
-
-    /// Re queue the time based attributes only.
-    /// Used as a part of Alter (clock) functionality.
-    /// Note: Under the hybrid clock this will not mark node as complete, (if we have day,date,cron attributes)
-    /// Since alter clock, should not change node state. This is left for user to re-queue the suite
-    virtual void requeue_time_attrs();
-
-    /// Previously < 4.0.6 requeue always reset the labels on requeue.
-    /// However ECFLOW-195 suggest some user prefer to see the last label value.
-    /// hence we will only reset the labels on the tasks when task is being run.
-    void requeue_labels();
-
-    /// This functionality is only required during interactive force or run
-    /// Avoid running the task on the same time slot, by missing the next time slot.
-    /// Requires we set a flag, to avoid the requeue resetting the time slots
-    void miss_next_time_slot();
-
-    /// Recursively run the tasks under this node, ignore suspend,limits,triggers, and time dependencies
-    /// if force is set, run even if task is submitted or active. (will create zombies)
-    virtual bool run(JobsParam& jobsParam, bool force) = 0;
-
-    /// Recursively determines why the node is not running.
-    virtual bool top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
-    void bottom_up_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
-
-    void freeTrigger() const;
-    void clearTrigger() const;
-    void freeComplete() const;
-    void clearComplete() const;
-    void freeHoldingDateDependencies();
-    void freeHoldingTimeDependencies();
-
-    // Used in the force cmd
-    bool set_event(const std::string& event_name_or_number);
-    bool clear_event(const std::string& event_name_or_number);
-    void setRepeatToLastValue();
-    virtual void setRepeatToLastValueHierarchically() { setRepeatToLastValue(); }
-
-    /// find all %VAR% and replaces with variable values, returns false on the
-    /// first variable that can't be found, cmd will be left half processed.
-    /// Will search for ECF_MICRO, if not found assumes % as the micro char
-    bool variableSubstitution(std::string& cmd) const;
-
-    bool variable_substitution(std::string& cmd, const NameValueMap& user_edit_variables, char micro = '%') const;
-
-    /// Find all %VAR% and add to the list, there can be more than one. i.e %ECF_FILES% -I %ECF_INCLUDE%"
-    bool find_all_used_variables(std::string& cmd, NameValueMap& used_variables, char micro = '%') const;
-
-    /// Find all environment variables, in the input string and substitute.
-    /// with correspondingly named variable value.
-    /// i.e search for ${ENV} and replace
-    bool variable_dollar_substitution(std::string& cmd) const;
-
-    /// Resolve inlimit references to limits, and check trigger and complete expression
-    virtual bool check(std::string& errorMsg, std::string& warningMsg) const;
-
-    /// Generated variables. Suites can have thousands of tasks. If the generated variables associated with
-    /// tasks are sent to the client, it can amount to a very large network traffic.
-    /// To minimise this bandwidth the generated variables for tasks/families are not persisted.
-    /// However client can demand create the generated  variable by calling this function.
-    virtual void update_generated_variables() const = 0;
-
-    ///  generates job file independent of dependencies
-    virtual void check_job_creation(job_creation_ctrl_ptr jobCtrl) = 0;
-
-    node_ptr remove(); // gets the parent then calls removeChild
-    virtual node_ptr removeChild(Node* child) = 0;
-    virtual bool
-    addChild(const node_ptr& child,
-             size_t position =
-                 std::numeric_limits<std::size_t>::max()) = 0; // return false if child of same name exist, leak!!!
-    virtual bool isAddChildOk(Node* child, std::string& errorMsg) const = 0; // return false if child of same name
-
-    virtual void verification(std::string& errorMsg) const;
-
-    /// See defs.hpp
-    virtual void generate_scripts(const std::map<std::string, std::string>& override) const = 0;
-
-    // standard functions: ==============================================
-    std::string print() const;
-    virtual void print(std::string&) const;
-    std::string print(PrintStyle::Type_t type) const;
-    bool operator==(const Node& rhs) const;
-    virtual bool checkInvariants(std::string& errorMsg) const;
-
-    /// Implements the visitor pattern
-    virtual void accept(ecf::NodeTreeVisitor&)               = 0;
-    virtual void acceptVisitTraversor(ecf::NodeTreeVisitor&) = 0; // Visitor does the traversal
-
-    // state related functions: ========================================
-
-    /// If the task was aborted provide the reason, default returns empty string
-    /// Only the task will return the reason for abort.
-    virtual const std::string& abortedReason() const;
-
-    /// This state added as an convenience, it includes Suspended attribute returned as enum
-    DState::State dstate() const;
-
-    /// This represents the persisted/saved state // First = NState, Second = time_duration
-    /// The State represent the life cycle changes of a node.
-    NState::State state() const { return st_.first.state(); }
-
-    /// return the state and duration time(relative to when suite was begun) when the state change happened
-    std::pair<NState, boost::posix_time::time_duration> get_state() const { return st_; }
-
-    /// Set the state, this can have side affects. To handle state changes
-    ///	  Should family triggers use saved state, or computed state.
-    ///	  *** If we use computed state, this may be wrong, since computed state
-    ///	  *** does not take repeats, or time dependencies into account
-    ///	  *** Hence after each state change, we bubble up node tree, work out if
-    ///	  *** Node is free of repeat, and time dependencies,
-    /// 	** Every time we set the state on a nodecontainer, we call handleStateChange
-    /// 	** This by default works out the most significant state of the children
-    /// 	** ie. the computed state. Hence setting the state on Suite/Family is really
-    /// 	** meaningless, since it will always be the computed state.
-    void set_state(NState::State s, bool force = false, const std::string& additional_info_to_log = "");
-    virtual void set_state_hierarchically(NState::State s, bool force) { set_state(s, force); }
-
-    /// Set state only, has no side effects
-    void setStateOnly(NState::State s,
-                      bool force                                = false,
-                      const std::string& additional_info_to_log = "",
-                      bool log_state_changes                    = true);
-    virtual void setStateOnlyHierarchically(NState::State s, bool force = false) { setStateOnly(s, force); }
-
-    /// This returns the time of state change: (relative to real time when the suite calendar was begun)
-    /// The returned time is *real time/computer UTC time* and *not* suite real time.
-    boost::posix_time::ptime state_change_time() const;
-
-    /// Returns the difference between last two state changes, effectively state change runtime.
-    /// queued    -> submitted : 1hr 30s,  submitted -> active    : 30s, active    -> complete  : 59m  etc
-    const boost::posix_time::time_duration& state_change_runtime() const { return sc_rt_; }
-
-    /// Sets the default status the node should have when the begin/re-queue is called
-    /// *Distinguish* between adding a def status and changing it.
-    /// Changing via d_st_.setState(s);  should alter state_change_no
-    void addDefStatus(DState::State s) { d_st_ = DState(s); }
-    DState::State defStatus() const { return d_st_.state(); }
-
-    // Query functions: =========================================================
-    /// returns my parent, for suite will return NULL;
-    Node* parent() const { return parent_; }
-    virtual Suite* suite() const = 0;
-    virtual Defs* defs() const   = 0;
-
-    // Performance hack, to avoid casts
-    virtual Task* isTask() const { return nullptr; }
-    virtual Alias* isAlias() const { return nullptr; }
-    virtual Submittable* isSubmittable() const { return nullptr; }
-    virtual NodeContainer* isNodeContainer() const { return nullptr; }
-    virtual Family* isFamily() const { return nullptr; }
-    virtual Suite* isSuite() const { return nullptr; }
-    virtual bool has_archive() const { return false; }
-
-    ///  returns the absolute node path
-    std::string absNodePath() const;
-    virtual const std::string& debugType() const = 0;
-
-    /// returns abs node path preceded by the type of the node
-    std::string debugNodePath() const;
-    static std::string path_href_attribute(const std::string& path);
-    static std::string path_href_attribute(const std::string& path, const std::string& path2);
-    std::string path_href() const;
-
-    /// returns true if this node OR any of its children
-    /// has cron,time,day,date or today time dependencies
-    virtual bool hasTimeDependencies() const { return has_time_dependencies(); }
-    bool isTimeFree() const { return (hasTimeDependencies()) ? timeDependenciesFree() : false; }
-    bool time_today_cron_is_free() const; /* used by viewer */
-
-    /// If no time dependencies then we have a resolution of 1 hour.
-    /// If we have just day/date then we have a resolution of 1 hour
-    /// Otherwise if we have time/today/cron with minutes, then resolution is 1 minute
-    void get_time_resolution_for_simulation(boost::posix_time::time_duration& resol) const;
-    void get_max_simulation_duration(boost::posix_time::time_duration& resol) const;
-
-    /// hierarchical function
-    virtual bool hasAutoCancel() const { return (auto_cancel_) ? true : false; }
-    virtual void invalidate_trigger_references() const;
-
-    // Access functions: ======================================================
-    const std::string& name() const { return n_; }
-    const Repeat& repeat() const { return repeat_; } // can be empty()
-    const std::vector<Variable>& variables() const { return vars_; }
-    const std::vector<limit_ptr>& limits() const { return limits_; }
-    const std::vector<InLimit>& inlimits() const { return inLimitMgr_.inlimits(); }
-
-    const std::vector<Meter>& meters() const { return meters_; }
-    const std::vector<Event>& events() const { return events_; }
-    const std::vector<Label>& labels() const { return labels_; }
-
-    const std::vector<ecf::TimeAttr>& timeVec() const { return times_; }
-    const std::vector<ecf::TodayAttr>& todayVec() const { return todays_; }
-    const std::vector<DateAttr>& dates() const { return dates_; }
-    const std::vector<DayAttr>& days() const { return days_; }
-    const std::vector<ecf::CronAttr>& crons() const { return crons_; }
-
-    const std::vector<VerifyAttr>& verifys() const;
-    const std::vector<ZombieAttr>& zombies() const;
-    const std::vector<QueueAttr>& queues() const;
-    const std::vector<GenericAttr>& generics() const;
-    ecf::LateAttr* get_late() const { return late_.get(); }
-    ecf::AutoRestoreAttr* get_autorestore() const { return auto_restore_.get(); }
-    ecf::AutoCancelAttr* get_autocancel() const { return auto_cancel_.get(); }
-    ecf::AutoArchiveAttr* get_autoarchive() const { return auto_archive_.get(); }
-    ecf::Flag& flag() { return flag_; }
-    const ecf::Flag& get_flag() const { return flag_; }
-
-    virtual void gen_variables(std::vector<Variable>&) const;
-    bool getLabelValue(const std::string& name, std::string& value) const;
-    bool getLabelNewValue(const std::string& name, std::string& value) const;
-
-    // Use get_trigger()/get_complete() for determining if we have trigger
-    // and complete expressions. This is many times faster than calling
-    // triggerAst()/completeAst() as this will force a parse and construction
-    // of Abstract syntax tree, first time it is called.
-    Expression* get_trigger() const { return t_expr_.get(); }
-    Expression* get_complete() const { return c_expr_.get(); }
-    AstTop* completeAst() const; // Will create AST on demand
-    AstTop* triggerAst() const;  // Will create AST on demand
-    std::string completeExpression() const;
-    std::string triggerExpression() const;
-
-    virtual void get_all_tasks(std::vector<task_ptr>&) const                   = 0;
-    virtual void get_all_nodes(std::vector<node_ptr>&) const                   = 0;
-    virtual void get_all_aliases(std::vector<alias_ptr>&) const                = 0;
-    virtual void getAllTasks(std::vector<Task*>&) const                        = 0;
-    virtual void getAllSubmittables(std::vector<Submittable*>&) const          = 0;
-    virtual void get_all_active_submittables(std::vector<Submittable*>&) const = 0;
-    virtual void getAllNodes(std::vector<Node*>&) const                        = 0;
-    virtual void getAllAstNodes(std::set<Node*>&) const;
-
-    /// returns the immediate children
-    virtual void immediateChildren(std::vector<node_ptr>&) const {}
-
-    /// retrieve _ALL_ children by hierarchically traversing down the node tree
-    virtual void allChildren(std::vector<node_ptr>&) const {}
-
-    // Add functions: ===============================================================
-    void addVerify(const VerifyAttr&); // for testing and verification Can throw std::runtime_error
-    void addVariable(const Variable&); // will update if duplicate
-    void add_variable(const std::string& name, const std::string& value); // will write to std:out if duplicates
-    void add_variable_bypass_name_check(const std::string& name,
-                                        const std::string& value); // will write to std:out if duplicates
-    void add_variable_int(const std::string& name, int);           // will throw std::runtime_error if duplicate
-
-    void add_trigger(const std::string&);          // use for short complete expressions,Can throw std::runtime_error
-    void add_complete(const std::string&);         // use for short complete expressions,Can throw std::runtime_error
-    void add_trigger_expr(const Expression&);      // Can throw std::runtime_error
-    void add_complete_expr(const Expression&);     // Can throw std::runtime_error
-    void add_part_trigger(const PartExpression&);  // for adding multiple and/or expression,Can throw std::runtime_error
-    void add_part_complete(const PartExpression&); // for adding multiple and/or expression,Can throw std::runtime_error
-    void py_add_trigger_expr(const std::vector<PartExpression>&);  // used by python api to add expression cumulative
-    void py_add_complete_expr(const std::vector<PartExpression>&); // used by python api to add expression cumulative
-
-    void addTime(const ecf::TimeAttr&);
-    void addToday(const ecf::TodayAttr&);
-    void addDate(const DateAttr&);
-    void addDay(const DayAttr&);
-    void addCron(const ecf::CronAttr&);
-
-    void addLimit(const Limit&, bool check = true);       // will throw std::runtime_error if duplicate
-    void addInLimit(const InLimit& l, bool check = true); // will throw std::runtime_error if duplicate
-    void auto_add_inlimit_externs(Defs* defs) { inLimitMgr_.auto_add_inlimit_externs(defs); }
-    void addEvent(const Event&, bool check = true); // will throw std::runtime_error if duplicate
-    void addMeter(const Meter&, bool check = true); // will throw std::runtime_error if duplicate
-    void add_meter(const std::string& name,
-                   int min,
-                   int max,
-                   int color_change,
-                   int value,
-                   bool check = true); // will throw std::runtime_error if duplicate
-    void addLabel(const Label&);       // will throw std::runtime_error if duplicate
-    void add_label(const std::string& name, const std::string& value, const std::string& new_value, bool check = true);
-    void addAutoCancel(const ecf::AutoCancelAttr&);
-    void add_autoarchive(const ecf::AutoArchiveAttr&);
-    void add_autorestore(const ecf::AutoRestoreAttr&);
-    void addLate(const ecf::LateAttr&);
-    void addRepeat(Repeat&&);             // will throw std::runtime_error if duplicate
-    void addRepeat(const Repeat&);        // will throw std::runtime_error if duplicate
-    void addZombie(const ZombieAttr&);    // will throw std::runtime_error if duplicate
-    void add_queue(const QueueAttr&);     // will throw std::runtime_error if duplicate
-    void add_generic(const GenericAttr&); // will throw std::runtime_error if duplicate
-
-    // sort
-    // expect one attr to be [ event | meter | label | limits | variable ]
-    virtual void sort_attributes(ecf::Attr::Type at,
-                                 bool recursive                          = true,
-                                 const std::vector<std::string>& no_sort = std::vector<std::string>());
-
-    // Delete functions: can throw std::runtime_error ===================================
-    // if name argument is empty, delete all attributes of that type
-    // Can throw std::runtime_error of the attribute cannot be found
-    void deleteTime(const std::string& name);
-    void delete_time(const ecf::TimeAttr&);
-    void deleteToday(const std::string& name);
-    void delete_today(const ecf::TodayAttr&);
-    void deleteDate(const std::string& name);
-    void delete_date(const DateAttr&);
-    void deleteDay(const std::string& name);
-    void delete_day(const DayAttr&);
-    void deleteCron(const std::string& name);
-    void delete_cron(const ecf::CronAttr&);
-
-    void delete_zombie(const ecf::Child::ZombieType);
-    void deleteVariable(const std::string& name); // if name not found throw, if name empty delete all variables
-    void
-    delete_variable_no_error(const std::string& name); // if variable not found don't error, if name empty do nothing
-    void deleteEvent(const std::string& name);
-    void deleteMeter(const std::string& name);
-    void deleteLabel(const std::string& name);
-    void delete_queue(const std::string& name);
-    void delete_generic(const std::string& name);
-    void deleteTrigger();
-    void deleteComplete();
-    void deleteRepeat();
-    void deleteLimit(const std::string& name);
-    void delete_limit_path(const std::string& limit_name, const std::string& limit_path);
-    void deleteInlimit(const std::string& name);
-    void deleteZombie(const std::string& type); // string must be one of [ user | ecf | path ]
-    void deleteLate();
-    void deleteAutoCancel();
-    void deleteAutoRestore();
-    void deleteAutoArchive();
-
-    // Change functions: ================================================================
-    /// returns true the change was made else false, Can throw std::runtime_error for parse errors
-    void changeVariable(const std::string& name, const std::string& value);
-    void changeEvent(const std::string& name, const std::string& setOrClear = "");
-    void changeEvent(const std::string& name, bool value);
-    void changeMeter(const std::string& name, const std::string& value);
-    void changeMeter(const std::string& name, int value);
-    void changeLabel(const std::string& name, const std::string& value);
-    void changeTrigger(const std::string& expression);
-    void changeComplete(const std::string& expression);
-    void changeRepeat(const std::string& value);
-    void changeLimitMax(const std::string& name, const std::string& maxValue);
-    void changeLimitMax(const std::string& name, int maxValue);
-    void changeLimitValue(const std::string& name, const std::string& value);
-    void changeLimitValue(const std::string& name, int value);
-    void changeDefstatus(const std::string& state);
-    void changeLate(const ecf::LateAttr&);
-    void change_time(const std::string&, const std::string&);
-    void change_today(const std::string&, const std::string&);
-
-    bool set_meter(const std::string& name, int value);  // does not throw if meter not found
-    bool set_event(const std::string& name, bool value); // does not throw if event not found
-
-    void increment_repeat(); // used in test only
-
-    // mementos functions:
-    /// Collect all the state changes, so that only small subset is returned to client
-    virtual void collateChanges(DefsDelta&) const = 0;
-    void incremental_changes(DefsDelta&, compound_memento_ptr& comp) const;
-
-    void set_memento(const NodeStateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeDefStatusDeltaMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const SuspendedMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeEventMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeMeterMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeLabelMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeQueueMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeGenericMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeQueueIndexMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeTriggerMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeCompleteMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeRepeatMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeRepeatIndexMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeLimitMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeInLimitMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeVariableMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeLateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeTodayMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeTimeMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeDayMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeCronMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeDateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeZombieMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const NodeVerifyMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const FlagMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-
-    // Find functions: ============================================================
-    // Will search for a node by name(ie not a path) first on siblings, then on a parent
-    // then up the node tree, will stop at the suite .
-    virtual node_ptr find_node_up_the_tree(const std::string& name) const = 0;
-
-    // This is used to find relative nodes.
-    virtual node_ptr find_relative_node(const std::vector<std::string>& pathToNode) = 0;
-
-    /// Look for user,generated and repeat variables
-    /// Find variable corresponding to the given name, by search up the parent hierarchy
-    /// ** We need to distinguish between a variable the exists, but has an empty value
-    /// ** hence we return true if variable is found, and false otherwise
-    bool findParentVariableValue(const std::string& name, std::string& theValue) const;
-
-    /// Look for the parent generated variable only
-    bool find_parent_gen_variable_value(const std::string& name, std::string& theValue) const;
-
-    /// Only looks at user variables
-    /// Find variable corresponding to the given name, by search up the parent hierarchy
-    /// Use when we know that variable is user defined. This is more efficient than
-    /// calling findParentVariableValue.
-    /// *** We need to distinguish between a variable the exists, but has an empty value
-    /// *** hence we return true if variable is found, and false otherwise
-    bool findParentUserVariableValue(const std::string& name, std::string& theValue) const;
-
-    /// This function should be used, when we don't care about the distinctions between
-    /// a variable that exist but has a empty value, and variable not found.(still return empty string)
-    /// Useful when we want to return by reference
-    const std::string& find_parent_user_variable_value(const std::string& name) const;
-
-    /// Search up the hierarchy, simply checks for existence independent of variable value
-    bool user_variable_exists(const std::string& name) const;
-
-    virtual node_ptr findImmediateChild(const std::string& /*name*/, size_t& /*child_pos*/) const { return node_ptr(); }
-    virtual node_ptr find_immediate_child(const std::string_view&) const { return node_ptr(); }
-    virtual std::string find_node_path(const std::string& /*type*/, const std::string& /*name*/) const {
-        return std::string();
-    }
-    const Variable& findVariable(const std::string& name) const;
-    std::string find_parent_variable_sub_value(const std::string& name) const;
-    const Variable& find_parent_variable(const std::string& name) const;
-    virtual const Variable& findGenVariable(const std::string& name) const;
-    bool findVariableValue(const std::string& name, std::string& returnedValue) const;
-    bool findGenVariableValue(const std::string& name, std::string& returnedValue) const;
-
-    bool findVerify(const VerifyAttr&) const;
-    bool findLimit(const Limit&) const;
-    bool findLabel(const std::string& name) const;
-    const Label& find_label(const std::string& name) const;
-    const QueueAttr& find_queue(const std::string& name) const;
-    QueueAttr& findQueue(const std::string& name);
-    const GenericAttr& find_generic(const std::string& name) const;
-
-    limit_ptr find_limit(const std::string& name) const;
-    limit_ptr findLimitUpNodeTree(const std::string& name) const;
-    Limit* findLimitViaInLimit(const InLimit& l) const {
-        return inLimitMgr_.findLimitViaInLimit(l);
-    } // used in *test* only
-    bool findInLimitByNameAndPath(const InLimit& l) const {
-        return inLimitMgr_.findInLimitByNameAndPath(l);
-    } // use name,path,token,
-    const Repeat& findRepeat(const std::string& name) const;
-    const Meter& findMeter(const std::string& name) const;
-    Meter& find_meter(const std::string& name);
-    const Event& findEvent(const Event&) const;
-    const Event& findEventByNameOrNumber(const std::string& name) const;
-
-    const ZombieAttr& findZombie(ecf::Child::ZombieType) const;
-    bool findParentZombie(ecf::Child::ZombieType, ZombieAttr&) const;
-
-    /// Finds the referenced node. The node path can be relative or absolute or a extern path
-    /// however if its an extern path, and corresponding suite is loaded, but we still
-    /// can't find the path, then an error is returned
-    node_ptr findReferencedNode(const std::string& nodePath, std::string& errorMsg) const;
-    node_ptr findReferencedNode(const std::string& nodePath, const std::string& externObj, std::string& errorMsg) const;
-
-    /// return true if we can find a event, meter, user, repeat or generated variable with the given name
-    bool findExprVariable(const std::string& name); // update event & meter as used in trigger for simulator
-
-    /// The status of family/suite is the inherited most significant status of all its children
-    enum TraverseType { IMMEDIATE_CHILDREN, HIERARCHICAL };
-    virtual NState::State computedState(Node::TraverseType) const = 0;
-
-    /// Sets the most significant state up the node tree. Ignores tasks
-    void set_most_significant_state_up_node_tree();
-
-    /// For use with GUI only
-    void set_graphic_ptr(void* p) { graphic_ptr_ = p; }
-    void* graphic_ptr() const { return graphic_ptr_; }
-
-    /// returns the position of this node relative to its peers
-    /// If not attached to parent returns std::numeric_limits<std::size_t>::max();
-    size_t position() const;
-
-    void stats(NodeStats&);
-
-    /// called at the end of state change function
-    /// ** Every time we set the state on a nodecontainer, we call handleStateChange
-    /// ** This by default works out the most significant state of the children
-    /// ** ie. the computed state. Hence setting the state on Suite/Family is really
-    /// ** meaningless, since it will always be the computed state.
-    /// ** For Aliases we only update the limits, and do not bubble up state changes
-    virtual void handleStateChange() = 0; // can end up changing state
-
-    /// update change numbers to force sync
-    virtual void force_sync(){};
-
-    /// check trigger expression have nodes and events,meter,repeat that resolve
-    bool check_expressions(Ast*, const std::string& expr, bool trigger, std::string& errorMsg) const;
-
-    /// check trigger expression have nodes and events,meter,repeat that resolve, will throw for error
-    std::unique_ptr<AstTop>
-    parse_and_check_expressions(const std::string& expr, bool trigger, const std::string& context);
-
-    virtual boost::posix_time::time_duration sum_runtime() { return sc_rt_; }
-
-protected:
-    void set_runtime(const boost::posix_time::time_duration& rt) { sc_rt_ = rt; }
-
-    /// Used in conjunction with Node::position()
-    /// returns std::numeric_limits<std::size_t>::max() if child not found
-    virtual size_t child_position(const Node*) const = 0;
-
-    /// The set_state_only() requires a correctly formed tree, ie since it needs suite()/calendar
-    /// to initialise the duration. We need a way set the state directly. For initialization
-    void set_state_only(NState::State s) { st_.first.setState(s); }
-
-    /// based on the *current* state increment or decrements the limits
-    /// Should *only* be called within a task
-    virtual void update_limits() = 0;
-
-    /// After job submission we need to increment the in limit, to indicate that a
-    /// resource is consumed. The set ensure we only update once during a traversal
-    void incrementInLimit(std::set<Limit*>& limitSet);
-
-    /// After job aborts or completes we need to decrement the in limit, to indicate that
-    /// additional resource is available. The set ensure we only update once during a traversal
-    void decrementInLimit(std::set<Limit*>& limitSet);
-    void decrementInLimitForSubmission(std::set<Limit*>& limitSet);
-
-    friend class InLimitMgr;
-    bool check_in_limit() const { return inLimitMgr_.inLimit(); }
-    bool check_in_limit_up_node_tree() const;
-
-    friend class Defs;
-    friend class Family;
-    friend class NodeContainer;
-    friend class HoldingDayOrDate;
-    virtual bool doDeleteChild(Node*) { return false; }
-
-    /// This function is called as a part of handling state change.
-    /// When a suite completes it can be re-queued due to:
-    ///   o repeat attribute
-    ///     When going up the hierarchy we should not reset Repeats
-    ///     The inner repeat must complete before parent repeat (if any) is incremented
-    ///     (i.e Mimics a nested loops)
-    ///  o Time, Today, cron attributes
-    ///
-    ///  Otherwise we need to traverse up the node tree and set the most significant state
-    void requeueOrSetMostSignificantStateUpNodeTree();
-
-    node_ptr non_const_this() const;
-
-    void update_repeat_genvar() const;
-
-    // returns node state without trailing new lines
-    virtual void write_state(std::string& ret, bool& added_comment_char) const;
-    void add_comment_char(std::string& ret, bool& added_comment_char) const;
-    virtual void read_state(const std::string& line, const std::vector<std::string>& lineTokens);
-
-    // Observer notifications
-protected:
-    std::vector<AbstractObserver*> observers_;
-    void notify_delete();
-    void checkForLateness(const ecf::Calendar&);
-    void check_for_lateness(const ecf::Calendar& c, const ecf::LateAttr*);
-
-public:
-    void notify_start(const std::vector<ecf::Aspect::Type>& aspects);
-    void notify(const std::vector<ecf::Aspect::Type>& aspects);
-    void attach(AbstractObserver*);
-    void detach(AbstractObserver*);
-    bool is_observed(AbstractObserver*) const; // return true if we have this observer in our list
-
-private:
-    bool why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
-    /// Function used as a part of trigger and complete expressions.
-    /// The search pattern is event,meter,user-variable,repeat, generated-variable
-    int findExprVariableValue(const std::string& name) const;
-    int findExprVariableValueAndPlus(const std::string& name, int val) const;
-    int findExprVariableValueAndMinus(const std::string& name, int val) const;
-    int findExprVariableValueAndType(const std::string& name, std::string& varType) const;
-    void findExprVariableAndPrint(const std::string& name, std::ostream& os) const;
-    friend class VariableHelper;
-    friend class AstParentVariable;
-    bool update_variable(const std::string& name, const std::string& value);
-
-private:
-    void add_trigger_expression(const Expression&);  // Can throw std::runtime_error
-    void add_complete_expression(const Expression&); // Can throw std::runtime_error
-    const Event& findEventByNumber(int number) const;
-    const Event& findEventByName(const std::string& name) const;
-    bool set_meter_used_in_trigger(const std::string& name);
-    bool set_event_used_in_trigger(const std::string& name);
-
-    /// When the begin/re-queue is called this function will initialise the state
-    /// on the node. If node has a default state this is applied to the node, and
-    /// hierarchically to all the children
-    /// Can also clear suspended see re-queue()
-    void initState(int clear_suspended_in_child_nodes, bool log_state_changes = true);
-
-    void delete_misc_attrs_if_empty();
-
-    /// Under the hybrid calendar some time dependent attributes may not be applicable
-    /// i.e if day,date,cron attributes does correspond to 24 hours of today, then we
-    /// need make them as complete.
-    void markHybridTimeDependentsAsComplete();
-    bool testTimeDependenciesForRequeue();
-    bool calendar_changed_timeattrs(const ecf::Calendar& c, Node::Calendar_args&);
-    bool holding_day_or_date(const ecf::Calendar& c) const;
-    void do_requeue_time_attrs(bool reset_next_time_slot, bool reset_relative_duration, Requeue_args::Requeue_t);
-    bool has_time_dependencies() const;
-
-private: // allow simulator access
-    friend class ecf::DefsAnalyserVisitor;
-    friend class ecf::FlatAnalyserVisitor;
-    friend class ecf::SimulatorVisitor;
-    friend class ecf::Simulator;
-    std::vector<Meter>& ref_meters() { return meters_; } // allow simulator set meter value
-    std::vector<Event>& ref_events() { return events_; } // allow simulator set event value
-    std::vector<QueueAttr>& ref_queues();                // allow simulator set event value
-
-    /// Note: If the complete expression evaluation fails. we should continue resolving dependencies
-    ///       If the complete expression evaluation evaluates, then we set node to complete
-    bool evaluateComplete() const;
-    bool evaluateTrigger() const;
-    bool timeDependenciesFree() const;
-
-    AstTop* completeAst(std::string& errorMsg) const; // Will create AST on demand
-    AstTop* triggerAst(std::string& errorMsg) const;  // Will create AST on demand
-
-private:
-    bool check_for_auto_archive(const ecf::Calendar& calendar) const;
-    bool checkForAutoCancel(const ecf::Calendar& calendar) const;
-
-private: // All mementos access
-    friend class CompoundMemento;
-    void clear(); /// Clear *ALL* internal attributes
-    void delete_attributes();
-
-private: /// For use by python interface,
-    friend void export_Node();
-    friend void export_Task();
-    friend void export_SuiteAndFamily();
-    std::vector<Meter>::const_iterator meter_begin() const { return meters_.begin(); }
-    std::vector<Meter>::const_iterator meter_end() const { return meters_.end(); }
-    std::vector<Event>::const_iterator event_begin() const { return events_.begin(); }
-    std::vector<Event>::const_iterator event_end() const { return events_.end(); }
-    std::vector<Label>::const_iterator label_begin() const { return labels_.begin(); }
-    std::vector<Label>::const_iterator label_end() const { return labels_.end(); }
-    std::vector<ecf::TimeAttr>::const_iterator time_begin() const { return times_.begin(); }
-    std::vector<ecf::TimeAttr>::const_iterator time_end() const { return times_.end(); }
-    std::vector<ecf::TodayAttr>::const_iterator today_begin() const { return todays_.begin(); }
-    std::vector<ecf::TodayAttr>::const_iterator today_end() const { return todays_.end(); }
-    std::vector<DateAttr>::const_iterator date_begin() const { return dates_.begin(); }
-    std::vector<DateAttr>::const_iterator date_end() const { return dates_.end(); }
-    std::vector<DayAttr>::const_iterator day_begin() const { return days_.begin(); }
-    std::vector<DayAttr>::const_iterator day_end() const { return days_.end(); }
-    std::vector<ecf::CronAttr>::const_iterator cron_begin() const { return crons_.begin(); }
-    std::vector<ecf::CronAttr>::const_iterator cron_end() const { return crons_.end(); }
-    std::vector<ZombieAttr>::const_iterator zombie_begin() const;
-    std::vector<ZombieAttr>::const_iterator zombie_end() const;
-    std::vector<VerifyAttr>::const_iterator verify_begin() const;
-    std::vector<VerifyAttr>::const_iterator verify_end() const;
-    std::vector<QueueAttr>::const_iterator queue_begin() const;
-    std::vector<QueueAttr>::const_iterator queue_end() const;
-    std::vector<GenericAttr>::const_iterator generic_begin() const;
-    std::vector<GenericAttr>::const_iterator generic_end() const;
-    std::vector<Variable>::const_iterator variable_begin() const { return vars_.begin(); }
-    std::vector<Variable>::const_iterator variable_end() const { return vars_.end(); }
-    std::vector<limit_ptr>::const_iterator limit_begin() const { return limits_.begin(); }
-    std::vector<limit_ptr>::const_iterator limit_end() const { return limits_.end(); }
-    std::vector<InLimit>::const_iterator inlimit_begin() const { return inLimitMgr_.inlimit_begin(); }
-    std::vector<InLimit>::const_iterator inlimit_end() const { return inLimitMgr_.inlimit_end(); }
-    std::string to_string() const; // For python interface
-
-private:
-    Node* parent_{nullptr}; // *NOT* persisted must be set by the parent class
-    std::string n_;
-    boost::posix_time::time_duration
-        sc_rt_; // state change runtime, Used to order peers, no persistence in cereal only defs.
-    std::pair<NState, boost::posix_time::time_duration> st_{
-        NState(),
-        boost::posix_time::time_duration(0, 0, 0, 0)}; // state and duration since suite start when state changed
-    DState d_st_;                                      // default value is QUEUED
-
-    std::vector<Variable> vars_;
-    mutable std::unique_ptr<Expression> c_expr_; // can only have one complete expression
-    mutable std::unique_ptr<Expression> t_expr_; // can only have one trigger expression
-
-    std::vector<Meter> meters_;
-    std::vector<Event> events_;
-    std::vector<Label> labels_;
-
-    std::vector<ecf::TimeAttr> times_;
-    std::vector<ecf::TodayAttr> todays_;
-    std::vector<ecf::CronAttr> crons_;
-    std::vector<DateAttr> dates_;
-    std::vector<DayAttr> days_;
-
-    std::unique_ptr<ecf::LateAttr> late_;   // Can only have one late attribute per node
-    std::unique_ptr<MiscAttrs> misc_attrs_; // VerifyAttr(used for statistics and test verification) & Zombies
-    Repeat repeat_;                         // each node can only have one repeat. By value, since has pimpl
-
-    std::vector<limit_ptr> limits_; // Ptrs since many in-limits can point to a single limit
-    InLimitMgr inLimitMgr_{this};   // manages the inlimit
-
-    ecf::Flag flag_;
-
-    std::unique_ptr<ecf::AutoCancelAttr> auto_cancel_;   // Can only have 1 auto cancel per node
-    std::unique_ptr<ecf::AutoArchiveAttr> auto_archive_; // Can only have 1 auto archive per node
-    std::unique_ptr<ecf::AutoRestoreAttr> auto_restore_; // Can only have 1 autorestore per node
-    void* graphic_ptr_{nullptr};                         // for use with the gui only
-
-    unsigned int state_change_no_{
-        0}; // *not* persisted, only used on server side,Used to indicate addition or deletion of attribute
-    unsigned int variable_change_no_{0};  // *not* persisted, placed here rather than Variable, to save memory
-    unsigned int suspended_change_no_{0}; // *not* persisted,
-
-#ifdef DEBUG_JOB_SUBMISSION_INTERVAL
-    boost::posix_time::ptime submit_to_complete_duration_; // *not* persisted
-#endif
-
-    bool suspended_{false};
-
-    friend class MiscAttrs;
-
-private:
-    // conditionally save to cut down on client/server bandwidth.
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_node_Node_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeAdd.cpp 5.13.0-1/ANode/src/ecflow/node/NodeAdd.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeAdd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeAdd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,428 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/MiscAttrs.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool Node::update_variable(const std::string& name, const std::string& value) {
-    size_t theSize = vars_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vars_[i].name() == name) {
-            // Variable already exist, *UPDATE* its value
-            vars_[i].set_value(value);
-            if (0 == Ecf::debug_level())
-                std::cerr << "Node::addVariable: Variable of name '" << name << "' already exist for node "
-                          << debugNodePath() << " updating with value '" << value << "'\n";
-            return true;
-        }
-    }
-    return false;
-}
-
-void Node::addVariable(const Variable& v) {
-    state_change_no_ = Ecf::incr_state_change_no();
-    if (update_variable(v.name(), v.theValue()))
-        return;
-    if (vars_.capacity() == 0)
-        vars_.reserve(5);
-    vars_.push_back(v);
-}
-
-void Node::add_variable(const std::string& name, const std::string& value) {
-    state_change_no_ = Ecf::incr_state_change_no();
-    if (update_variable(name, value))
-        return;
-    if (vars_.capacity() == 0)
-        vars_.reserve(5);
-    vars_.emplace_back(name, value);
-}
-
-void Node::add_variable_bypass_name_check(const std::string& name, const std::string& value) {
-    state_change_no_ = Ecf::incr_state_change_no();
-    if (update_variable(name, value))
-        return;
-    if (vars_.capacity() == 0)
-        vars_.reserve(5);
-    vars_.emplace_back(name, value, false);
-}
-
-void Node::add_variable_int(const std::string& name, int some_int) {
-    std::string value = ecf::convert_to<std::string>(some_int);
-    add_variable(name, value);
-}
-
-void Node::add_trigger(const std::string& string_expression) {
-    add_trigger_expression(Expression(string_expression));
-}
-void Node::add_complete(const std::string& string_expression) {
-    add_complete_expression(Expression(string_expression));
-}
-void Node::add_trigger_expr(const Expression& expr) {
-    add_trigger_expression(expr);
-}
-void Node::add_complete_expr(const Expression& expr) {
-    add_complete_expression(expr);
-}
-void Node::add_trigger_expression(const Expression& t) {
-    if (t_expr_) {
-        std::stringstream ss;
-        ss << "Node::add_trigger_expression. A Node(" << absNodePath() << " can only have one trigger ";
-        ss << "to add large triggers use multiple calls to Node::add_part_trigger( PartExpression('t1 == complete') )";
-        throw std::runtime_error(ss.str());
-    }
-    if (isSuite())
-        throw std::runtime_error("Cannot add trigger on a suite");
-
-    t_expr_          = std::make_unique<Expression>(t);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::add_complete_expression(const Expression& t) {
-    if (c_expr_) {
-        std::stringstream ss;
-        ss << "Node::add_complete_expression. A Node(" << absNodePath() << " can only have one complete expression ";
-        ss << "to add large complete expressions use multiple calls to Node::add_part_complete( PartExpression('t1 == "
-              "complete') )";
-        throw std::runtime_error(ss.str());
-    }
-    if (isSuite())
-        throw std::runtime_error("Cannot add complete trigger on a suite");
-
-    c_expr_          = std::make_unique<Expression>(t);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::py_add_trigger_expr(const std::vector<PartExpression>& vec) {
-    if (t_expr_) {
-        if (isSuite())
-            throw std::runtime_error("Cannot add trigger on a suite");
-        t_expr_->add_expr(vec);
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-    else {
-        Expression expr;
-        for (const auto& i : vec)
-            expr.add(i);
-        add_trigger_expression(expr);
-    }
-}
-
-void Node::py_add_complete_expr(const std::vector<PartExpression>& vec) {
-    if (c_expr_) {
-        if (isSuite())
-            throw std::runtime_error("Cannot add complete on a suite");
-        c_expr_->add_expr(vec);
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-    else {
-        Expression expr;
-        for (const auto& i : vec)
-            expr.add(i);
-        add_complete_expression(expr);
-    }
-}
-
-void Node::add_part_trigger(const PartExpression& part) {
-    if (isSuite())
-        throw std::runtime_error("Cannot add trigger on a suite");
-
-    if (!t_expr_)
-        t_expr_ = std::make_unique<Expression>();
-    t_expr_->add(part);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-void Node::add_part_complete(const PartExpression& part) {
-    if (isSuite())
-        throw std::runtime_error("Cannot add complete trigger on a suite");
-
-    if (!c_expr_)
-        c_expr_ = std::make_unique<Expression>();
-    c_expr_->add(part);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addTime(const ecf::TimeAttr& t) {
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Node::addTime\n";
-#endif
-
-    if (isSuite()) {
-        throw std::runtime_error("Cannot add time based dependency on a suite");
-    }
-
-    times_.push_back(t);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addToday(const ecf::TodayAttr& t) {
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Node::addToday()\n";
-#endif
-
-    if (isSuite()) {
-        throw std::runtime_error("Cannot add time based dependency on a suite");
-    }
-
-    todays_.push_back(t);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addDate(const DateAttr& d) {
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Node::addDate()\n";
-#endif
-
-    // By disallowing what effect would it have on existing suites ?
-    if (isSuite()) {
-        throw std::runtime_error("Cannot add time based dependency on a suite"); // Added at 4.0.2
-    }
-
-    dates_.push_back(d);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addDay(const DayAttr& d) {
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Node::addDay\n";
-#endif
-
-    // By disallowing what effect would it have on existing suites ?
-    if (isSuite()) {
-        throw std::runtime_error("Cannot add time based dependency on a suite"); // Added at 4.0.2
-    }
-
-    days_.push_back(d);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addCron(const CronAttr& d) {
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Node::addCron()\n";
-#endif
-
-    if (d.time().isNULL()) {
-        throw std::runtime_error("Node::addCron: The cron is in-complete, no time specified");
-    }
-    if (d.time().hasIncrement() && !repeat_.empty()) {
-        std::stringstream ss;
-        ss << "Node::addCron: Node " << absNodePath()
-           << " already has a repeat. Inappropriate to add two looping structures at the same level\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    crons_.push_back(d);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addLabel(const Label& l) {
-    if (findLabel(l.name())) {
-        std::stringstream ss;
-        ss << "Add Label failed: Duplicate label of name '" << l.name() << "' already exist for node "
-           << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    labels_.push_back(l);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::add_label(const std::string& name, const std::string& value, const std::string& new_value, bool check) {
-    if (check && findLabel(name)) {
-        std::stringstream ss;
-        ss << "Add Label failed: Duplicate label of name '" << name << "' already exist for node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    labels_.emplace_back(name, value, new_value, check);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addMeter(const Meter& m, bool check) {
-    if (check) {
-        const Meter& meter = findMeter(m.name());
-        if (!meter.empty()) {
-            std::stringstream ss;
-            ss << "Add Meter failed: Duplicate Meter of name '" << m.name() << "' already exist for node "
-               << debugNodePath();
-            throw std::runtime_error(ss.str());
-        }
-    }
-    meters_.push_back(m);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::add_meter(const std::string& name, int min, int max, int color_change, int value, bool check) {
-    if (check) {
-        const Meter& meter = findMeter(name);
-        if (!meter.empty()) {
-            std::stringstream ss;
-            ss << "Add Meter failed: Duplicate Meter of name '" << name << "' already exist for node "
-               << debugNodePath();
-            throw std::runtime_error(ss.str());
-        }
-    }
-    meters_.emplace_back(name, min, max, color_change, value, check);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addEvent(const Event& e, bool check) {
-    if (check) {
-        const Event& event = findEvent(e);
-        if (!event.empty()) {
-            std::stringstream ss;
-            ss << "Add Event failed: Duplicate Event of name '" << e.name_or_number() << "' already exist for node "
-               << debugNodePath();
-            throw std::runtime_error(ss.str());
-        }
-    }
-    events_.push_back(e);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addLimit(const Limit& l, bool check) {
-    if (check && findLimit(l)) {
-        std::stringstream ss;
-        ss << "Add Limit failed: Duplicate Limit of name '" << l.name() << "' already exist for node "
-           << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    limit_ptr the_limit = std::make_shared<Limit>(l);
-    the_limit->set_node(this);
-    limits_.push_back(the_limit);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addInLimit(const InLimit& l, bool check) {
-    inLimitMgr_.addInLimit(l, check);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-static void throwIfRepeatAlreadyExists(Node* node) {
-    if (!node->repeat().empty()) {
-        std::stringstream ss;
-        ss << "Add Repeat failed: Repeat of name '" << node->repeat().name() << "' already exist for node "
-           << node->debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-
-    if (!node->crons().empty()) {
-        std::stringstream ss;
-        ss << "Node::addRepeat: Node " << node->absNodePath()
-           << " already has a cron. Inappropriate to add two looping structures at the same level\n";
-        throw std::runtime_error(ss.str());
-    }
-}
-void Node::addRepeat(Repeat&& r) {
-    throwIfRepeatAlreadyExists(this);
-    repeat_ = std::move(r);
-    repeat_.update_repeat_genvar();
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-void Node::addRepeat(const Repeat& r) {
-    throwIfRepeatAlreadyExists(this);
-    repeat_ = r;
-    repeat_.update_repeat_genvar();
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::addAutoCancel(const ecf::AutoCancelAttr& ac) {
-    if (auto_archive_) {
-        std::stringstream ss;
-        ss << "Node::addAutoCancel: Cannot add autocancel and autoarchive on the same node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    if (auto_cancel_) {
-        std::stringstream ss;
-        ss << "Node::addAutoCancel: A node can only have one autocancel, see node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    auto_cancel_     = std::make_unique<ecf::AutoCancelAttr>(ac);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::add_autoarchive(const ecf::AutoArchiveAttr& aa) {
-    if (auto_cancel_) {
-        std::stringstream ss;
-        ss << "Node::add_autoarchive: Cannot add autocancel and autoarchive on the same node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    if (auto_archive_) {
-        std::stringstream ss;
-        ss << "Node::add_autoarchive: A node can only have one autoarchive, see node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    auto_archive_    = std::make_unique<ecf::AutoArchiveAttr>(aa);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::add_autorestore(const ecf::AutoRestoreAttr& ar) {
-    if (auto_restore_) {
-        std::stringstream ss;
-        ss << "Node::add_auto_restore: Can only have one autorestore per node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    auto_restore_ = std::make_unique<ecf::AutoRestoreAttr>(ar);
-    auto_restore_->set_node(this);
-    state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
-}
-
-void Node::addLate(const ecf::LateAttr& l) {
-    if (!late_) {
-        late_            = std::make_unique<ecf::LateAttr>(l);
-        state_change_no_ = Ecf::incr_state_change_no();
-        return;
-    }
-    throw std::runtime_error("Add Late failed: A node can only have one Late attribute, see node " + debugNodePath());
-}
-
-void Node::addVerify(const VerifyAttr& v) {
-    if (misc_attrs_) {
-        misc_attrs_->addVerify(v); // can throw
-        return;
-    }
-    misc_attrs_ = std::make_unique<MiscAttrs>(this);
-    misc_attrs_->addVerify(v);
-}
-
-void Node::addZombie(const ZombieAttr& z) {
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Node::addZombie()\n";
-#endif
-
-    if (misc_attrs_) {
-        misc_attrs_->addZombie(z); // can throw
-        return;
-    }
-    misc_attrs_ = std::make_unique<MiscAttrs>(this);
-    misc_attrs_->addZombie(z);
-}
-
-void Node::add_queue(const QueueAttr& q) {
-    if (!misc_attrs_)
-        misc_attrs_ = std::make_unique<MiscAttrs>(this);
-    misc_attrs_->add_queue(q);
-}
-
-void Node::add_generic(const GenericAttr& q) {
-    if (!misc_attrs_)
-        misc_attrs_ = std::make_unique<MiscAttrs>(this);
-    misc_attrs_->add_generic(q);
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeChange.cpp 5.13.0-1/ANode/src/ecflow/node/NodeChange.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeChange.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeChange.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,270 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-void Node::changeVariable(const std::string& name, const std::string& value) {
-    size_t theSize = vars_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vars_[i].name() == name) {
-            vars_[i].set_value(value);
-            variable_change_no_ = Ecf::incr_state_change_no();
-            return;
-        }
-    }
-    throw std::runtime_error("Node::changeVariable: Could not find variable " + name);
-}
-
-bool Node::set_event(const std::string& event_name_or_number, bool value) {
-    if (events_.empty()) {
-        return false;
-    }
-
-    // find by name first
-    size_t theSize = events_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (events_[i].name() == event_name_or_number) {
-            events_[i].set_value(value);
-            return true;
-        }
-    }
-
-    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
-    if (event_name_or_number.find_first_of(Str::NUMERIC()) == 0) {
-        try {
-            auto eventNumber = ecf::convert_to<int>(event_name_or_number);
-            for (size_t i = 0; i < theSize; i++) {
-                if (events_[i].number() == eventNumber) {
-                    events_[i].set_value(value);
-                    return true;
-                }
-            }
-        }
-        catch (const ecf::bad_conversion&) {
-        }
-    }
-    return false;
-}
-
-bool Node::set_event_used_in_trigger(const std::string& event_name_or_number) {
-    if (events_.empty()) {
-        return false;
-    }
-
-    // find by name first
-    size_t theSize = events_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (events_[i].name() == event_name_or_number) {
-            events_[i].usedInTrigger(true);
-            return true;
-        }
-    }
-
-    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
-    if (event_name_or_number.find_first_of(Str::NUMERIC()) == 0) {
-        try {
-            auto eventNumber = ecf::convert_to<int>(event_name_or_number);
-            for (size_t i = 0; i < theSize; i++) {
-                if (events_[i].number() == eventNumber) {
-                    events_[i].usedInTrigger(true);
-                    return true;
-                    ;
-                }
-            }
-        }
-        catch (const ecf::bad_conversion&) {
-        }
-    }
-    return false;
-}
-void Node::changeEvent(const std::string& event_name_or_number, const std::string& setOrClear) {
-    bool value;
-    if (!setOrClear.empty()) {
-        if (setOrClear != Event::SET() && setOrClear != Event::CLEAR()) {
-            throw std::runtime_error("Node::changeEvent: Expected empty string, 'set' or 'clear' but found " +
-                                     setOrClear + " for event " + event_name_or_number);
-        }
-        value = (setOrClear == Event::SET());
-    }
-    else
-        value = true;
-
-    changeEvent(event_name_or_number, value);
-}
-
-void Node::changeEvent(const std::string& event_name_or_number, bool value) {
-    if (set_event(event_name_or_number, value))
-        return;
-    throw std::runtime_error("Node::changeEvent: Could not find event " + event_name_or_number);
-}
-
-bool Node::set_meter(const std::string& meter_name, int value) {
-    size_t the_meter_size = meters_.size();
-    for (size_t i = 0; i < the_meter_size; ++i) {
-        if (meters_[i].name() == meter_name) {
-            meters_[i].set_value(value);
-            return true;
-        }
-    }
-    return false;
-}
-bool Node::set_meter_used_in_trigger(const std::string& meter_name) {
-    size_t the_meter_size = meters_.size();
-    for (size_t i = 0; i < the_meter_size; ++i) {
-        if (meters_[i].name() == meter_name) {
-            meters_[i].usedInTrigger(true);
-            return true;
-        }
-    }
-    return false;
-}
-void Node::changeMeter(const std::string& meter_name, const std::string& value) {
-    int theValue = 0;
-    try {
-        theValue = ecf::convert_to<int>(value);
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error("Node::changeMeter expected integer value but found " + value);
-    }
-    changeMeter(meter_name, theValue);
-}
-void Node::changeMeter(const std::string& meter_name, int value) {
-    if (set_meter(meter_name, value))
-        return;
-    throw std::runtime_error("Node::changeMeter: Could not find meter " + meter_name);
-}
-
-void Node::changeLabel(const std::string& name, const std::string& value) {
-    size_t theSize = labels_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (labels_[i].name() == name) {
-            labels_[i].set_new_value(value);
-            return;
-        }
-    }
-    throw std::runtime_error("Node::changeLabel: Could not find label " + name);
-}
-
-void Node::changeTrigger(const std::string& expression) {
-    (void)parse_and_check_expressions(expression, true /*trigger*/, "Node::changeTrigger:"); // will throw for errors
-    deleteTrigger();
-    add_trigger(expression);
-}
-
-void Node::changeComplete(const std::string& expression) {
-    (void)parse_and_check_expressions(expression, false /*complete*/, "Node::changeComplete:"); // will throw for errors
-    deleteComplete();
-    add_complete(expression);
-}
-
-void Node::changeRepeat(const std::string& value) {
-    if (repeat_.empty())
-        throw std::runtime_error("Node::changeRepeat: Could not find repeat on " + absNodePath());
-    repeat_.change(value); // this can throw std::runtime_error
-}
-
-void Node::increment_repeat() {
-    if (repeat_.empty())
-        throw std::runtime_error("Node::increment_repeat: Could not find repeat on " + absNodePath());
-    repeat_.increment();
-}
-
-void Node::changeLimitMax(const std::string& name, const std::string& maxValue) {
-    int theValue = 0;
-    try {
-        theValue = ecf::convert_to<int>(maxValue);
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error("Node::changeLimitMax expected integer value but found " + maxValue);
-    }
-    changeLimitMax(name, theValue);
-}
-
-void Node::changeLimitMax(const std::string& name, int maxValue) {
-    limit_ptr limit = find_limit(name);
-    if (!limit.get())
-        throw std::runtime_error("Node::changeLimitMax: Could not find limit " + name);
-    limit->setLimit(maxValue);
-}
-
-void Node::changeLimitValue(const std::string& name, const std::string& value) {
-    int theValue = 0;
-    try {
-        theValue = ecf::convert_to<int>(value);
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error("Node::changeLimitValue expected integer value but found " + value);
-    }
-    changeLimitValue(name, theValue);
-}
-
-void Node::changeLimitValue(const std::string& name, int value) {
-    limit_ptr limit = find_limit(name);
-    if (!limit.get())
-        throw std::runtime_error("Node::changeLimitValue: Could not find limit " + name);
-    limit->setValue(value);
-}
-
-void Node::changeDefstatus(const std::string& theState) {
-    if (!DState::isValid(theState)) {
-        throw std::runtime_error("Node::changeDefstatus expected a state but found " + theState);
-    }
-
-    // Updates state_change_no on the defStatus
-    d_st_.setState(DState::toState(theState));
-}
-
-void Node::changeLate(const ecf::LateAttr& late) {
-    late_            = std::make_unique<ecf::LateAttr>(late);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::change_time(const std::string& old, const std::string& new_time) {
-    TimeAttr old_attr(TimeSeries::create(old));      // can throw if parse fails
-    TimeAttr new_attr(TimeSeries::create(new_time)); // can throw if parse fails
-
-    size_t theSize = times_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        // Dont use '==' since that compares additional state like free_
-        if (times_[i].structureEquals(old_attr)) {
-            times_[i]        = new_attr;
-            state_change_no_ = Ecf::incr_state_change_no();
-            return;
-        }
-    }
-    throw std::runtime_error("Node::change_time : Cannot find time attribute: ");
-}
-
-void Node::change_today(const std::string& old, const std::string& new_time) {
-    TodayAttr old_attr(TimeSeries::create(old));      // can throw if parse fails
-    TodayAttr new_attr(TimeSeries::create(new_time)); // can throw if parse fails
-
-    size_t theSize = todays_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        // Dont use '==' since that compares additional state like free_
-        if (todays_[i].structureEquals(old_attr)) {
-            todays_[i]       = new_attr;
-            state_change_no_ = Ecf::incr_state_change_no();
-            return;
-        }
-    }
-    throw std::runtime_error("Node::change_today : Cannot find today attribute: ");
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeContainer.cpp 5.13.0-1/ANode/src/ecflow/node/NodeContainer.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeContainer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeContainer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1416 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/NodeContainer.hpp"
-
-#include <cassert>
-#include <limits>
-#include <sstream>
-#include <stdexcept>
-
-#include <boost/filesystem/operations.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/DefsDelta.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/NodeState.hpp"
-#include "ecflow/node/NodeTreeVisitor.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/node/move_peer.hpp"
-
-using namespace ecf;
-using namespace std;
-
-///////////////////////////////////////////////////////////////////////////////////////////
-// #define DEBUG_FIND_NODE 1
-// #define DEBUG_DEPENDENCIES 1
-
-/////////////////////////////////////////////////////////////////////////////////////////
-NodeContainer::NodeContainer(const std::string& name, bool check) : Node(name, check) {
-}
-
-NodeContainer::NodeContainer() = default;
-
-void NodeContainer::copy(const NodeContainer& rhs) {
-    for (const auto& r_n : rhs.nodes_) {
-        Task* task = r_n->isTask();
-        if (task) {
-            task_ptr task_copy = std::make_shared<Task>(*task);
-            task_copy->set_parent(this);
-            nodes_.push_back(task_copy);
-        }
-        else {
-            Family* family = r_n->isFamily();
-            assert(family);
-            family_ptr family_copy = std::make_shared<Family>(*family);
-            family_copy->set_parent(this);
-            nodes_.push_back(family_copy);
-        }
-    }
-}
-
-NodeContainer::NodeContainer(const NodeContainer& rhs) : Node(rhs) {
-    copy(rhs);
-}
-
-NodeContainer& NodeContainer::operator=(const NodeContainer& rhs) {
-    if (this != &rhs) {
-        Node::operator=(rhs);
-        nodes_.clear();
-        copy(rhs);
-        order_state_change_no_      = 0;
-        add_remove_state_change_no_ = Ecf::incr_state_change_no();
-    }
-    return *this;
-}
-
-NodeContainer::~NodeContainer() = default;
-
-bool NodeContainer::check_defaults() const {
-    if (order_state_change_no_ != 0)
-        throw std::runtime_error("NodeContainer::check_defaults(): order_state_change_no_ != 0");
-    if (add_remove_state_change_no_ != 0)
-        throw std::runtime_error("NodeContainer::check_defaults(): add_remove_state_change_no_ != 0");
-    return Node::check_defaults();
-}
-
-void NodeContainer::accept(ecf::NodeTreeVisitor& v) {
-    v.visitNodeContainer(this);
-    for (const auto& n : nodes_) {
-        n->accept(v);
-    }
-}
-
-void NodeContainer::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
-    v.visitNodeContainer(this);
-}
-
-void NodeContainer::begin() {
-    restore_on_begin_or_requeue();
-    Node::begin();
-    for (const auto& n : nodes_) {
-        n->begin();
-    }
-    handle_defstatus_propagation();
-}
-
-void NodeContainer::reset() {
-    Node::reset();
-    for (const auto& n : nodes_) {
-        n->reset();
-    }
-}
-
-void NodeContainer::handle_migration(const ecf::Calendar& c) {
-    Node::handle_migration(c);
-    for (const auto& n : nodes_) {
-        n->handle_migration(c);
-    }
-}
-
-void NodeContainer::requeue(Requeue_args& args) {
-    //	LOG(Log::DBG,"   " << debugType() << "::requeue() " << absNodePath() << " resetRepeats = " << resetRepeats);
-
-    restore_on_begin_or_requeue();
-    Node::requeue(args);
-
-    // For negative numbers, do nothing, i.e. do not clear
-    if (args.clear_suspended_in_child_nodes_ >= 0)
-        args.clear_suspended_in_child_nodes_++;
-
-    // If the node `default status` == COMPLETE, we don't log the change of state when re-queueing the descendants.
-    // Without this optimization, all children would change state to QUEUED, and eventually change back to COMPLETE.
-    // This avoids flooding the log with unnecessary messages regarding several thousand children
-    // (e.g. as it happens in operations). See ECFLOW-1239 for details.
-    bool log_state_changes_descendents = (d_st_ != DState::COMPLETE);
-
-    Node::Requeue_args largs(args.requeue_t,
-                             true /* reset repeats, Moot for tasks */,
-                             args.clear_suspended_in_child_nodes_,
-                             args.reset_next_time_slot_,
-                             true /* reset relative duration */,
-                             log_state_changes_descendents);
-
-    for (const auto& n : nodes_) {
-        n->requeue(largs);
-    }
-
-    handle_defstatus_propagation();
-}
-
-void NodeContainer::requeue_time_attrs() {
-    Node::requeue_time_attrs();
-    for (const auto& n : nodes_) {
-        n->requeue_time_attrs();
-    }
-}
-
-void NodeContainer::reset_late_event_meters() {
-    Node::reset_late_event_meters();
-    for (const auto& n : nodes_) {
-        n->reset_late_event_meters();
-    }
-}
-
-void NodeContainer::handle_defstatus_propagation() {
-    if (d_st_ == DState::COMPLETE) {
-        /// A defstatus of complete and *ONLY* complete should always be applied
-        /// hierarchically downwards
-        setStateOnlyHierarchically(NState::COMPLETE);
-    }
-    else if (d_st_ == DState::default_state()) {
-        /// Reflect that the status of the children.
-        /// *However* do NOT override the defstatus setting
-        NState::State theSignificantStateOfImmediateChildren = computedState(Node::IMMEDIATE_CHILDREN);
-        if (theSignificantStateOfImmediateChildren != state()) {
-            setStateOnly(theSignificantStateOfImmediateChildren);
-        }
-    }
-}
-
-bool NodeContainer::run(JobsParam& jobsParam, bool force) {
-    for (const auto& n : nodes_) {
-        (void)n->run(jobsParam, force);
-    }
-    return jobsParam.getErrorMsg().empty();
-}
-
-void NodeContainer::kill(const std::string& /* zombie_pid, only valid for single task */) {
-    for (const auto& n : nodes_) {
-        n->kill();
-    }
-}
-
-void NodeContainer::status() {
-    for (const auto& n : nodes_) {
-        // Avoid exception for top-down case, if Task is not active or submitted
-        // Allows status cmd to run over more Tasks, without early exit, when some tasks are not active/submitted
-        if (n->isTask() && (n->state() != NState::ACTIVE && n->state() != NState::SUBMITTED)) {
-            continue;
-        }
-        n->status();
-    }
-}
-
-bool NodeContainer::top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
-    bool why_found = Node::why(theReasonWhy, html_tags);
-    if (!why_found) {
-        for (const auto& n : nodes_) {
-            if (n->top_down_why(theReasonWhy, html_tags)) {
-                why_found = true;
-            }
-        }
-    }
-    return why_found;
-}
-
-void NodeContainer::incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const {
-    /// There no point doing a OrderMemento if children have been added/delete
-    if (add_remove_state_change_no_ > changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<ChildrenMemento>(nodes_));
-    }
-    else if (order_state_change_no_ > changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        std::vector<std::string> order_vec;
-        order_vec.reserve(nodes_.size());
-
-        for (const auto& n : nodes_)
-            order_vec.push_back(n->name());
-        comp->add(std::make_shared<OrderMemento>(order_vec));
-    }
-
-    Node::incremental_changes(changes, comp);
-}
-
-void NodeContainer::set_memento(const OrderMemento* memento,
-                                std::vector<ecf::Aspect::Type>& aspects,
-                                bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "NodeContainer::set_memento( const OrderMemento* ) " << debugNodePath() << "\n";
-#endif
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::ORDER);
-        return;
-    }
-
-    // Order nodes_ according to memento ordering
-    const std::vector<std::string>& order = memento->order_;
-    if (order.size() != nodes_.size()) {
-        // something gone wrong.
-        std::cout << "NodeContainer::set_memento OrderMemento, memento.size() " << order.size()
-                  << " Not the same as nodes_size() " << nodes_.size() << "\n";
-        return;
-    }
-
-    std::vector<node_ptr> vec;
-    vec.reserve(nodes_.size());
-    for (const auto& i : order) {
-        for (const auto& n : nodes_) {
-            if (i == n->name()) {
-                vec.push_back(n);
-                break;
-            }
-        }
-    }
-    if (vec.size() != nodes_.size()) {
-        std::cout << "NodeContainer::set_memento could not find all the names\n";
-        return;
-    }
-
-    nodes_ = vec;
-}
-
-void NodeContainer::set_memento(const ChildrenMemento* memento,
-                                std::vector<ecf::Aspect::Type>& aspects,
-                                bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "NodeContainer::set_memento( const ChildrenMemento * ) " << debugNodePath() << "\n";
-#endif
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::ADD_REMOVE_NODE);
-        return;
-    }
-
-    // setup child parent pointers
-    nodes_ = memento->children_;
-    for (auto& n : nodes_) {
-        n->set_parent(this);
-    }
-}
-
-void NodeContainer::collateChanges(DefsDelta& changes) const {
-    /// Theres no point in traversing children if we have added/removed children
-    /// since ChildrenMemento will copy all children.
-    if (add_remove_state_change_no_ > changes.client_state_change_no()) {
-        return;
-    }
-
-    // Traversal to children
-    for (const auto& n : nodes_) {
-        n->collateChanges(changes);
-    }
-}
-
-void NodeContainer::order(Node* immediateChild, NOrder::Order ord) {
-    SuiteChanged1 changed(suite());
-    switch (ord) {
-        case NOrder::TOP: {
-            for (auto i = nodes_.begin(); i != nodes_.end(); ++i) {
-                if ((*i).get() == immediateChild) {
-                    node_ptr node = (*i);
-                    nodes_.erase(i);
-                    nodes_.insert(nodes_.begin(), node);
-                    order_state_change_no_ = Ecf::incr_state_change_no();
-                    return;
-                }
-            }
-            throw std::runtime_error("NodeContainer::order TOP, immediate child not found");
-        }
-        case NOrder::BOTTOM: {
-            for (auto i = nodes_.begin(); i != nodes_.end(); ++i) {
-                if ((*i).get() == immediateChild) {
-                    node_ptr node = (*i);
-                    nodes_.erase(i);
-                    nodes_.push_back(node);
-                    order_state_change_no_ = Ecf::incr_state_change_no();
-                    return;
-                }
-            }
-            throw std::runtime_error("NodeContainer::order BOTTOM, immediate child not found");
-        }
-        case NOrder::ALPHA: {
-            std::sort(nodes_.begin(), nodes_.end(), [](const node_ptr& a, const node_ptr& b) {
-                try {
-                    int a_as_int = ecf::convert_to<int>(a->name());
-                    int b_as_int = ecf::convert_to<int>(b->name());
-                    return a_as_int < b_as_int;
-                }
-                catch (const ecf::bad_conversion&) {
-                }
-
-                return Str::caseInsLess(a->name(), b->name());
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            break;
-        }
-        case NOrder::ORDER: {
-            std::sort(nodes_.begin(), nodes_.end(), [](const node_ptr& a, const node_ptr& b) {
-                return Str::caseInsGreater(a->name(), b->name());
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            break;
-        }
-        case NOrder::UP: {
-            for (size_t t = 0; t < nodes_.size(); t++) {
-                if (nodes_[t].get() == immediateChild) {
-                    if (t != 0) {
-                        node_ptr node = nodes_[t];
-                        nodes_.erase(nodes_.begin() + t);
-                        t--;
-                        nodes_.insert(nodes_.begin() + t, node);
-                        order_state_change_no_ = Ecf::incr_state_change_no();
-                    }
-                    return;
-                }
-            }
-            throw std::runtime_error("NodeContainer::order UP, immediate child not found");
-        }
-        case NOrder::DOWN: {
-            for (size_t t = 0; t < nodes_.size(); t++) {
-                if (nodes_[t].get() == immediateChild) {
-                    if (t != nodes_.size() - 1) {
-                        node_ptr node = nodes_[t];
-                        nodes_.erase(nodes_.begin() + t);
-                        t++;
-                        nodes_.insert(nodes_.begin() + t, node);
-                        order_state_change_no_ = Ecf::incr_state_change_no();
-                    }
-                    return;
-                }
-            }
-            throw std::runtime_error("NodeContainer::order DOWN, immediate child not found");
-        }
-        case NOrder::RUNTIME: {
-            for (node_ptr node : nodes_) {
-                if (node->state() != NState::COMPLETE) {
-                    throw std::runtime_error("NodeContainer::order: To order by RUNTIME All nodes must be complete");
-                }
-            }
-            (void)sum_runtime();
-            std::sort(nodes_.begin(), nodes_.end(), [](const node_ptr& a, const node_ptr& b) {
-                return a->state_change_runtime() > b->state_change_runtime();
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            break;
-        }
-    }
-}
-
-void NodeContainer::move_peer(Node* src, Node* dest) {
-    move_peer_node(nodes_, src, dest, "NodeContainer");
-    order_state_change_no_ = Ecf::incr_state_change_no();
-}
-
-boost::posix_time::time_duration NodeContainer::sum_runtime() {
-    boost::posix_time::time_duration rt;
-    for (const auto& n : nodes_)
-        rt += n->sum_runtime();
-    set_runtime(rt);
-    return rt;
-}
-
-bool NodeContainer::calendarChanged(const ecf::Calendar& c,
-                                    Node::Calendar_args& cal_args,
-                                    const ecf::LateAttr* inherited_late,
-                                    bool holding_parent_day_or_date) {
-    // A node that is archived should not allow any change of state.
-    if (get_flag().is_set(ecf::Flag::ARCHIVED)) {
-        return false;
-    }
-
-    // holding_parent_day_or_date_ is used to avoid freeing time attributes, when we have a holding parent day/date
-    holding_parent_day_or_date = Node::calendarChanged(c, cal_args, nullptr, holding_parent_day_or_date);
-
-    // if (holding_parent_day_or_date)
-    //    cout << " calendarChanged: " << debugNodePath() << " " << holding_parent_day_or_date << " •••••••••• \n";
-
-    // The late attribute is inherited, we only set late on the task/alias
-    LateAttr overridden_late;
-    if (inherited_late && !inherited_late->isNull()) {
-        overridden_late = *inherited_late;
-    }
-    if (late_.get() != inherited_late) {
-        overridden_late.override_with(late_.get());
-    }
-
-    for (const auto& n : nodes_) {
-        (void)n->calendarChanged(c, cal_args, &overridden_late, holding_parent_day_or_date);
-    }
-    return false;
-}
-
-bool NodeContainer::hasAutoCancel() const {
-    if (Node::hasAutoCancel())
-        return true;
-    for (const auto& n : nodes_) {
-        if (n->hasAutoCancel())
-            return true;
-    }
-    return false;
-}
-
-void NodeContainer::invalidate_trigger_references() const {
-    Node::invalidate_trigger_references();
-    for (const auto& n : nodes_) {
-        n->invalidate_trigger_references();
-    }
-}
-
-bool NodeContainer::resolveDependencies(JobsParam& jobsParam) {
-#ifdef DEBUG_DEPENDENCIES
-    LogToCout toCoutAsWell;
-#endif
-
-    // cout << "NodeContainer::resolveDependencies " << absNodePath() << endl;
-    //  Don't evaluate children unless parent is free. BOMB out early for this case.
-    //  Note:: Task::resolveDependencies() will check inLimit up front. *** THIS CHECKS UP THE HIERARCHY ***
-    //  Note:: Node::resolveDependencies() may have forced family node to complete, should have
-    //         returned false in this case, to stop any job submission
-    if (!Node::resolveDependencies(jobsParam)) {
-
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG,
-            "   NodeContainer::resolveDependencies " << absNodePath()
-                                                     << " could not resolve dependencies, may have completed HOLDING");
-#endif
-        return false;
-    }
-
-    /// During *top down* traversal we check in limits at this level. Done here rather than
-    /// in Node::resolveDependencies(). Otherwise this particular check will get duplicated
-    /// since the task, will do *bottom up* traversal.
-    if (!check_in_limit()) {
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG, "   NodeContainer::resolveDependencies() " << absNodePath() << " HOLDING due to inLIMIT");
-#endif
-        return false;
-    }
-
-    for (const auto& n : nodes_) {
-        // Note: we don't bomb out early here. Since a later child could be free e.g. f1/ty or t4
-        // child t1 holding
-        // child t2 holding
-        // child f1 free
-        //   child tx holding
-        //   child ty free
-        // child t3 holding
-        // child t4 free
-        (void)n->resolveDependencies(jobsParam);
-    }
-
-    return true;
-}
-
-bool NodeContainer::has_time_based_attributes() const {
-    if (Node::has_time_based_attributes())
-        return true;
-    for (const auto& node : nodes_) {
-        if (node->has_time_based_attributes())
-            return true;
-    }
-    return false;
-}
-
-NState::State NodeContainer::computedState(Node::TraverseType traverseType) const {
-    if (nodes_.empty()) {
-        /// Note: theComputedNodeState will return unknown if no children, in this
-        /// case just return the current state.
-        return state();
-    }
-
-    // returns the computed state depending on traverseType
-    // If not IMMEDIATE_CHILDREN, will recurse down calling each child's computedState() function
-    return ecf::theComputedNodeState(nodes_, (traverseType == Node::IMMEDIATE_CHILDREN));
-}
-
-void NodeContainer::force_sync() {
-    add_remove_state_change_no_ = Ecf::incr_state_change_no();
-}
-
-node_ptr NodeContainer::removeChild(Node* child) {
-    size_t node_vec_size = nodes_.size();
-    for (size_t t = 0; t < node_vec_size; t++) {
-        if (nodes_[t].get() == child) {
-            node_ptr node = std::dynamic_pointer_cast<Node>(nodes_[t]);
-            child->set_parent(nullptr); // must set to NULL, allows it to be re-added to different parent
-            nodes_.erase(nodes_.begin() + t);
-            add_remove_state_change_no_ = Ecf::incr_state_change_no();
-            return node;
-        }
-    }
-    // Should never happen
-    LOG_ASSERT(false, "NodeContainer::removeChild: Could not remove child");
-    return node_ptr();
-}
-
-bool NodeContainer::addChild(const node_ptr& child, size_t position) {
-    // *** CANT construct shared_ptr from a raw pointer, must use dynamic_pointer_cast,
-    // *** otherwise the reference counts will get messed up.
-    try {
-        if (child->isTask()) {
-            // can throw if duplicate names
-            addTask(std::dynamic_pointer_cast<Task>(child), position);
-            return true;
-        }
-
-        if (child->isFamily()) {
-            // can throw if duplicate names
-            addFamily(std::dynamic_pointer_cast<Family>(child), position);
-            return true;
-        }
-    }
-    catch (std::runtime_error& e) {
-        return false; // Duplicate names, or trying to add a Suite?
-    }
-
-    // Duplicate names, or trying to add a Suite?
-    return false;
-}
-
-bool NodeContainer::isAddChildOk(Node* theChild, std::string& errorMsg) const {
-    Task* theTaskChild = theChild->isTask();
-    if (theTaskChild) {
-
-        node_ptr theTask = find_by_name(theChild->name());
-        if (!theTask.get())
-            return true;
-
-        std::stringstream ss;
-        ss << "Task/Family of name " << theChild->name() << " already exist in container node " << name();
-        errorMsg += ss.str();
-        return false;
-    }
-
-    Family* theFamilyChild = theChild->isFamily();
-    if (theFamilyChild) {
-
-        node_ptr theFamily = find_by_name(theChild->name());
-        if (!theFamily.get())
-            return true;
-
-        std::stringstream ss;
-        ss << "Family/Task of name " << theChild->name() << " already exist in container node " << name();
-        errorMsg += ss.str();
-        return false;
-    }
-
-    Suite* theSuite = theChild->isSuite();
-    if (theSuite) {
-        errorMsg += "Cannot add a suite as child.";
-        return false;
-    }
-
-    errorMsg += "Unknown node type";
-    return false;
-}
-
-void NodeContainer::handleStateChange() {
-    // Increment any repeats & requeue
-    requeueOrSetMostSignificantStateUpNodeTree();
-
-    Node::handleStateChange(); // may result in an auto-restore, if state is COMPLETE
-}
-
-size_t NodeContainer::child_position(const Node* child) const {
-    size_t node_vec_size = nodes_.size();
-    for (size_t t = 0; t < node_vec_size; t++) {
-        if (nodes_[t].get() == child) {
-            return t;
-        }
-    }
-    return std::numeric_limits<std::size_t>::max();
-}
-
-task_ptr NodeContainer::add_task(const std::string& task_name) {
-    if (find_by_name(task_name).get()) {
-        std::stringstream ss;
-        ss << "Add Task failed: A task/family of name '" << task_name << "' already exist on node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    task_ptr the_task = Task::create(task_name);
-    add_task_only(the_task);
-    return the_task;
-}
-
-family_ptr NodeContainer::add_family(const std::string& family_name) {
-    if (find_by_name(family_name).get()) {
-        std::stringstream ss;
-        ss << "Add Family failed: A Family/Task of name '" << family_name << "' already exist on node "
-           << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    family_ptr the_family = Family::create(family_name);
-    add_family_only(the_family);
-    return the_family;
-}
-
-void NodeContainer::addTask(const task_ptr& t, size_t position) {
-    if (find_by_name(t->name()).get()) {
-        std::stringstream ss;
-        ss << "Add Task failed: A Task/Family of name '" << t->name() << "' already exist on node " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    add_task_only(t, position);
-}
-
-void NodeContainer::add_task_only(const task_ptr& t, size_t position) {
-    if (t->parent()) {
-        std::stringstream ss;
-        ss << debugNodePath() << ": Add Task failed: A task of name '" << t->name()
-           << "' is already owned by another node";
-        throw std::runtime_error(ss.str());
-    }
-
-    t->set_parent(this);
-    if (position >= nodes_.size()) {
-        nodes_.push_back(t);
-    }
-    else {
-        nodes_.insert(nodes_.begin() + position, t);
-    }
-    add_remove_state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void NodeContainer::add_family_only(const family_ptr& f, size_t position) {
-    if (f->parent()) {
-        std::stringstream ss;
-        ss << debugNodePath() << ": Add Family failed: A family of name '" << f->name()
-           << "' is already owned by another node";
-        throw std::runtime_error(ss.str());
-    }
-
-    f->set_parent(this);
-    if (position >= nodes_.size()) {
-        nodes_.push_back(f);
-    }
-    else {
-        nodes_.insert(nodes_.begin() + position, f);
-    }
-    add_remove_state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void NodeContainer::addFamily(const family_ptr& f, size_t position) {
-    if (find_by_name(f->name()).get()) {
-        std::stringstream ss;
-        ss << "Add Family failed: A Family/Task of name '" << f->name() << "' already exist on node "
-           << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-    add_family_only(f, position);
-}
-
-void NodeContainer::add_child(const node_ptr& child, size_t position) {
-    if (child->isTask()) {
-        task_ptr task_child = std::dynamic_pointer_cast<Task>(child);
-        addTask(task_child, position);
-    }
-    else if (child->isFamily()) {
-        family_ptr family_child = std::dynamic_pointer_cast<Family>(child);
-        addFamily(family_child, position);
-    }
-}
-
-node_ptr NodeContainer::findImmediateChild(const std::string& theName, size_t& child_pos) const {
-    size_t node_vec_size = nodes_.size();
-    for (size_t t = 0; t < node_vec_size; t++) {
-        if (nodes_[t]->name() == theName) {
-            child_pos = t;
-            return nodes_[t];
-        }
-    }
-    child_pos = std::numeric_limits<std::size_t>::max();
-    return node_ptr();
-}
-
-node_ptr NodeContainer::find_immediate_child(const std::string_view& name) const {
-    for (const auto& n : nodes_) {
-        if (name == n->name()) {
-            return n;
-        }
-    }
-    return node_ptr();
-}
-
-node_ptr NodeContainer::find_node_up_the_tree(const std::string& the_name) const {
-    if (name() == the_name) {
-        return non_const_this();
-    }
-
-    size_t not_used;
-    node_ptr fnd_node = findImmediateChild(the_name, not_used);
-    if (fnd_node)
-        return fnd_node;
-
-    Node* the_parent = parent();
-    if (the_parent)
-        return the_parent->find_node_up_the_tree(the_name);
-    return node_ptr();
-}
-
-node_ptr NodeContainer::find_relative_node(const std::vector<std::string>& pathToNode) {
-#ifdef DEBUG_FIND_NODE
-    cout << "NodeContainer::find_relative_node for '" << name() << "\n";
-    cout << " path :";
-    for (const std::string& s : pathToNode) {
-        cout << " " << s;
-    }
-    cout << "\n";
-    for (node_ptr t : nodes_) {
-        cout << " " << t->name();
-    }
-    cout << "\n";
-#endif
-    if (pathToNode.empty())
-        return node_ptr();
-    auto pathSize = static_cast<int>(pathToNode.size());
-
-#ifdef DEBUG_FIND_NODE
-    cout << "NodeContainer::find_relative_node name = '" << name() << "' pathToNode[0] = '" << pathToNode[0] << "'\n";
-#endif
-
-    // Must match all children
-    int index         = 0;
-    size_t child_pos  = 0; // unused
-    node_ptr the_node = shared_from_this();
-    while (index < pathSize) {
-        the_node = the_node->findImmediateChild(pathToNode[index], child_pos);
-        if (the_node) {
-            if (index == pathSize - 1)
-                return the_node;
-            index++;
-        }
-        else {
-            return node_ptr();
-        }
-    }
-    return node_ptr();
-}
-
-void NodeContainer::find_closest_matching_node(const std::vector<std::string>& pathToNode,
-                                               int indexIntoPathNode,
-                                               node_ptr& closest_matching_node) {
-    auto pathSize = static_cast<int>(pathToNode.size());
-    if (indexIntoPathNode >= pathSize)
-        return;
-
-    int index = indexIntoPathNode;
-    if (name() == pathToNode[indexIntoPathNode]) {
-
-        closest_matching_node = shared_from_this();
-
-        // Match the Container i.e. family or suite
-        bool lastIndex = (indexIntoPathNode == pathSize - 1);
-        if (lastIndex) {
-            return;
-        }
-
-        // Match the Children, i.e. go down the hierarchy
-        index++;
-        match_closest_children(pathToNode, index, closest_matching_node);
-    }
-}
-
-void NodeContainer::match_closest_children(const std::vector<std::string>& pathToNode,
-                                           int indexIntoPathNode,
-                                           node_ptr& closest_matching_node) {
-    auto pathSize = static_cast<int>(pathToNode.size());
-    if (indexIntoPathNode >= pathSize)
-        return;
-
-    bool lastIndex = (indexIntoPathNode == pathSize - 1);
-    if (lastIndex) {
-        // Even if the name matches, it is only valid if the index is the last index
-        // e.g. given a suite /a/b/c/d/e
-        //      and the path  /a/b/c/d/e/f/g
-        // The path will match with e, but it invalid since it is not the last index
-        for (const auto& n : nodes_) {
-            if (n->name() == pathToNode[indexIntoPathNode]) {
-                closest_matching_node = n;
-                return;
-            }
-        }
-    }
-    else {
-        // Path to node is of the form "/family/task" or "/family/family/task"
-        // Path to node is of the form "/suite/task" or "/suite/family/task"
-        for (const auto& n : nodes_) {
-            Family* family = n->isFamily();
-            if (family) {
-                node_ptr matching_node;
-                family->find_closest_matching_node(pathToNode, indexIntoPathNode, matching_node);
-                if (matching_node.get()) {
-                    closest_matching_node = matching_node;
-                    return;
-                }
-            }
-        }
-    }
-}
-
-node_ptr NodeContainer::find_by_name(const std::string& name) const {
-    for (const auto& n : nodes_) {
-        if (n->name() == name) {
-            return n;
-        }
-    }
-    return node_ptr();
-}
-
-family_ptr NodeContainer::findFamily(const std::string& familyName) const {
-    for (const auto& n : nodes_) {
-        if (n->name() == familyName && n->isFamily()) {
-            return std::dynamic_pointer_cast<Family>(n);
-        }
-    }
-    return family_ptr();
-}
-
-task_ptr NodeContainer::findTask(const std::string& taskName) const {
-    for (const auto& n : nodes_) {
-        if (n->name() == taskName && n->isTask()) {
-            return std::dynamic_pointer_cast<Task>(n);
-        }
-    }
-    return task_ptr();
-}
-
-std::string NodeContainer::find_node_path(const std::string& type, const std::string& node_name) const {
-    for (const auto& n : nodes_) {
-        std::string res = n->find_node_path(type, node_name);
-        if (!res.empty()) {
-            return res;
-        }
-    }
-    return string();
-}
-
-bool NodeContainer::hasTimeDependencies() const {
-    for (const auto& n : nodes_) {
-        if (n->hasTimeDependencies())
-            return true;
-    }
-    return false;
-}
-
-void NodeContainer::immediateChildren(std::vector<node_ptr>& theChildren) const {
-    theChildren.reserve(theChildren.size() + nodes_.size());
-    for (const auto& n : nodes_) {
-        theChildren.push_back(n);
-    }
-}
-
-void NodeContainer::allChildren(std::vector<node_ptr>& vec) const {
-    for (const auto& n : nodes_) {
-        vec.push_back(n);
-        n->allChildren(vec); // for task does nothing
-    }
-}
-
-void NodeContainer::getAllFamilies(std::vector<Family*>& vec) const {
-    for (const auto& n : nodes_) {
-        Family* family = n->isFamily();
-        if (family) {
-            vec.push_back(family);
-            family->getAllFamilies(vec);
-        }
-    }
-}
-
-void NodeContainer::getAllNodes(std::vector<Node*>& vec) const {
-    for (const auto& n : nodes_) {
-        vec.push_back(n.get());
-        n->getAllNodes(vec);
-    }
-}
-
-void NodeContainer::getAllTasks(std::vector<Task*>& tasks) const {
-    for (const auto& n : nodes_) {
-        n->getAllTasks(tasks);
-    }
-}
-
-void NodeContainer::getAllSubmittables(std::vector<Submittable*>& tasks) const {
-    for (const auto& n : nodes_) {
-        n->getAllSubmittables(tasks);
-    }
-}
-
-void NodeContainer::get_all_active_submittables(std::vector<Submittable*>& tasks) const {
-    for (const auto& n : nodes_) {
-        n->get_all_active_submittables(tasks);
-    }
-}
-
-void NodeContainer::get_all_tasks(std::vector<task_ptr>& tasks) const {
-    for (const auto& n : nodes_) {
-        n->get_all_tasks(tasks);
-    }
-}
-
-void NodeContainer::get_all_nodes(std::vector<node_ptr>& nodes) const {
-    nodes.push_back(non_const_this());
-    for (const auto& n : nodes_) {
-        n->get_all_nodes(nodes);
-    }
-}
-
-void NodeContainer::get_all_aliases(std::vector<alias_ptr>& aliases) const {
-    for (const auto& n : nodes_) {
-        n->get_all_aliases(aliases);
-    }
-}
-
-void NodeContainer::getAllAstNodes(std::set<Node*>& vec) const {
-    Node::getAllAstNodes(vec);
-    for (const auto& n : nodes_) {
-        n->getAllAstNodes(vec);
-    }
-}
-
-bool NodeContainer::check(std::string& errorMsg, std::string& warningMsg) const {
-    Node::check(errorMsg, warningMsg);
-
-    // recursive to handle hierarchical families
-    for (const auto& n : nodes_) {
-        n->check(errorMsg, warningMsg);
-        // if (!errorMsg.empty()) break;
-    }
-
-    return errorMsg.empty();
-}
-
-std::vector<task_ptr> NodeContainer::taskVec() const {
-    std::vector<task_ptr> vec;
-    vec.reserve(nodes_.size());
-    for (const auto& n : nodes_) {
-        if (n->isTask()) {
-            vec.push_back(std::dynamic_pointer_cast<Task>(n));
-        }
-    }
-    return vec;
-}
-
-std::vector<family_ptr> NodeContainer::familyVec() const {
-    std::vector<family_ptr> vec;
-    for (const auto& n : nodes_) {
-        if (n->isFamily()) {
-            vec.push_back(std::dynamic_pointer_cast<Family>(n));
-        }
-    }
-    return vec;
-}
-
-bool NodeContainer::operator==(const NodeContainer& rhs) const {
-    size_t node_vec_size = nodes_.size();
-    if (node_vec_size != rhs.nodes_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "NodeContainer::operator==  node_vec_size != rhs.nodes_.size() " << absNodePath() << "\n";
-            std::cout << "   nodes_.size() = " << node_vec_size << "  rhs.nodes_.size() = " << rhs.nodes_.size()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-
-    for (size_t i = 0; i < node_vec_size; ++i) {
-
-        Task* task = nodes_[i]->isTask();
-        if (task) {
-            Task* rhs_task = rhs.nodes_[i]->isTask();
-            if (!rhs_task) {
-#ifdef DEBUG
-                if (Ecf::debug_equality()) {
-                    std::cout << "NodeContainer::operator==  if ( !rhs_task ) " << absNodePath() << "\n";
-                }
-#endif
-                return false;
-            }
-
-            if (!(*task == *rhs_task)) {
-#ifdef DEBUG
-                if (Ecf::debug_equality()) {
-                    std::cout << "NodeContainer::operator==  if ( !( *task == *rhs_task )) " << absNodePath() << "\n";
-                }
-#endif
-                return false;
-            }
-        }
-        else {
-            Family* rhs_family = rhs.nodes_[i]->isFamily();
-            if (!rhs_family) {
-#ifdef DEBUG
-                if (Ecf::debug_equality()) {
-                    std::cout << "NodeContainer::operator==  if ( !rhs_family ) " << absNodePath() << "\n";
-                }
-#endif
-                return false;
-            }
-
-            Family* family = nodes_[i]->isFamily();
-            LOG_ASSERT(family, "");
-            if (family /*keep clang happy*/ && !(*family == *rhs_family)) {
-#ifdef DEBUG
-                if (Ecf::debug_equality()) {
-                    std::cout << "NodeContainer::operator==  if ( !( *family == *rhs_family )) " << absNodePath()
-                              << "\n";
-                }
-#endif
-                return false;
-            }
-        }
-    }
-
-    return Node::operator==(rhs);
-}
-
-void NodeContainer::print(std::string& os) const {
-    for (const auto& node : nodes_) {
-        node->print(os);
-    }
-}
-
-bool NodeContainer::checkInvariants(std::string& errorMsg) const {
-    if (!Node::checkInvariants(errorMsg))
-        return false;
-
-    for (const auto& n : nodes_) {
-        if (n->parent() != this) {
-            errorMsg += "NodeContainer::checkInvariants family/task parent() not correct";
-            return false;
-        }
-        if (!n->checkInvariants(errorMsg)) {
-            return false;
-        }
-    }
-    return true;
-}
-
-void NodeContainer::verification(std::string& errorMsg) const {
-    Node::verification(errorMsg);
-    for (const auto& n : nodes_) {
-        n->verification(errorMsg);
-    }
-}
-
-void NodeContainer::setRepeatToLastValueHierarchically() {
-    setRepeatToLastValue();
-    for (const auto& n : nodes_) {
-        n->setRepeatToLastValueHierarchically();
-    }
-}
-
-void NodeContainer::setStateOnlyHierarchically(NState::State s, bool force) {
-    setStateOnly(s, force);
-    for (const auto& n : nodes_) {
-        n->setStateOnlyHierarchically(s, force);
-    }
-}
-
-void NodeContainer::set_state_hierarchically(NState::State s, bool force) {
-    setStateOnlyHierarchically(s, force);
-    if (force) {
-        // *force* is only set via ForceCmd.
-        update_limits(); // hierarchical
-    }
-    handleStateChange(); // non-hierarchical
-}
-
-void NodeContainer::update_limits() {
-    /// Only tasks can affect the limits, hence no point calling locally
-    for (const auto& n : nodes_) {
-        n->update_limits();
-    }
-}
-
-std::string NodeContainer::archive_path() const {
-    std::string the_archive_path;
-    if (!findParentUserVariableValue(Str::ECF_HOME(), the_archive_path)) {
-        std::stringstream ss;
-        ss << "NodeContainer::archive_path: cannot find ECF_HOME from " << debugNodePath();
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string the_archive_file_name = absNodePath();
-    Str::replaceall(the_archive_file_name, "/", ":"); // we use ':' since it is not allowed in the node names
-    the_archive_file_name += ".check";
-
-    std::string port = Str::DEFAULT_PORT_NUMBER();
-    Defs* the_defs   = defs();
-    if (the_defs) {
-        port = the_defs->server().find_variable(Str::ECF_PORT());
-        if (port.empty())
-            port = Str::DEFAULT_PORT_NUMBER();
-    }
-    Host host;
-    the_archive_file_name = host.prefix_host_and_port(port, the_archive_file_name);
-
-    the_archive_path += "/";
-    the_archive_path += the_archive_file_name;
-    return the_archive_path;
-}
-
-void NodeContainer::archive() {
-    if (nodes_.empty())
-        return; // nothing to archive
-
-    SuiteChanged1 changed(suite());
-
-    // make a clone of this node DEEP COPY
-    node_ptr this_clone = clone();
-
-    // re-create node tree up to the def. Do *NOT* clone we just need a SHALLOW hierarchy
-    defs_ptr archive_defs = Defs::create();
-    if (isSuite()) {
-        suite_ptr suite_clone = std::dynamic_pointer_cast<Suite>(this_clone);
-        archive_defs->addSuite(suite_clone);
-    }
-    else {
-        Node* parent_ptr = parent();
-        while (parent_ptr) {
-            if (parent_ptr->isSuite()) {
-                suite_ptr parent_suite = Suite::create(parent_ptr->name());
-                parent_suite->addChild(this_clone);
-                archive_defs->addSuite(parent_suite);
-                break;
-            }
-            else {
-                family_ptr parent_family = Family::create(parent_ptr->name());
-                parent_family->addChild(this_clone);
-                this_clone = parent_family;
-            }
-            parent_ptr = parent_ptr->parent();
-        }
-    }
-
-    // save the created defs, to disk
-    archive_defs->save_as_checkpt(archive_path());
-
-    flag().set(ecf::Flag::ARCHIVED); // flag as archived
-    flag().clear(ecf::Flag::RESTORED);
-
-    // delete the child nodes, set parent to null first.
-    for (auto& n : nodes_) {
-        n->set_parent(nullptr);
-    }
-    nodes_.clear();
-
-    std::vector<node_ptr>().swap(nodes_);                      // reclaim vector memory
-    add_remove_state_change_no_ = Ecf::incr_state_change_no(); // For sync
-    string msg                  = " autoarchive ";
-    msg += debugNodePath(); // inform user via log
-    ecf::log(Log::LOG, msg);
-}
-
-void NodeContainer::swap(NodeContainer& rhs) {
-    std::swap(nodes_, rhs.nodes_);
-    for (auto& n : nodes_) {
-        n->set_parent(this);
-    }
-}
-
-void NodeContainer::restore_on_begin_or_requeue() {
-    if (!flag().is_set(ecf::Flag::ARCHIVED))
-        return;
-    if (!nodes_.empty())
-        return;
-    if (!fs::exists(archive_path()))
-        return;
-
-    // Node::requeue(...) will clear ecf::Flag::RESTORED, set in restore()
-    try {
-        restore();
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "NodeContainer::restore_on_begin_or_requeue(): failed : " << e.what();
-        log(Log::ERR, ss.str());
-    }
-}
-
-void NodeContainer::restore() {
-    if (!flag().is_set(ecf::Flag::ARCHIVED)) {
-        std::stringstream ss;
-        ss << "NodeContainer::restore() Node " << absNodePath() << " can't restore, ecf::Flag::ARCHIVED not set";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (!nodes_.empty()) {
-        std::stringstream ss;
-        ss << "NodeContainer::restore() Node " << absNodePath() << " can't restore, Container already has children ?";
-        throw std::runtime_error(ss.str());
-    }
-
-    defs_ptr archive_defs        = Defs::create();
-    std::string the_archive_path = archive_path();
-    try {
-        archive_defs->restore(the_archive_path);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "NodeContainer::restore() Node " << absNodePath() << " could not restore file at  " << the_archive_path
-           << "  : " << e.what();
-        throw std::runtime_error(ss.str());
-    }
-
-    // find the same node in the defs.
-    node_ptr archived_node = archive_defs->findAbsNode(absNodePath());
-    if (!archived_node) {
-        std::stringstream ss;
-        ss << "NodeContainer::restore() could not find " << absNodePath() << " in the archived file "
-           << the_archive_path;
-        throw std::runtime_error(ss.str());
-    }
-    NodeContainer* archived_node_container = archived_node->isNodeContainer();
-    if (!archived_node_container) {
-        std::stringstream ss;
-        ss << "NodeContainer::restore() The node at " << absNodePath() << " recovered from " << the_archive_path
-           << " is not a container(suite/family)";
-        throw std::runtime_error(ss.str());
-    }
-
-    swap(*archived_node_container);                            // swap the children, and set parent pointers
-    flag().clear(ecf::Flag::ARCHIVED);                         // clear flag archived
-    flag().set(ecf::Flag::RESTORED);                           // set restored flag, to stop automatic autoarchive
-    add_remove_state_change_no_ = Ecf::incr_state_change_no(); // For sync
-
-    string msg = " autorestore ";
-    msg += debugNodePath(); // inform user via log
-    ecf::log(Log::LOG, msg);
-
-    fs::remove(the_archive_path); // remove the file, could still throw
-}
-
-bool NodeContainer::has_archive() const {
-    if (get_flag().is_set(ecf::Flag::ARCHIVED))
-        return true;
-    for (auto& n : nodes_) {
-        if (n->has_archive())
-            return true;
-    }
-    return false;
-}
-
-void NodeContainer::remove_archived_files() {
-    /// Called during delete, remove all child archived files
-    if (!has_archive()) {
-        return;
-    }
-
-    std::string ecf_home;
-    if (!findParentUserVariableValue(Str::ECF_HOME(), ecf_home)) {
-        return;
-    }
-
-    // <host>.<port>.ECF_NAME.check
-    // for /ecflow =  Avis-MacBook-Pro.local.4040.:ecflow.check
-    std::string the_archive_path = archive_path();
-
-    // remove trailing '.check'
-    std::string::size_type check_pos = the_archive_path.rfind(".check");
-    if (check_pos == std::string::npos) {
-        // something has gone wrong
-        return;
-    }
-    the_archive_path.erase(the_archive_path.begin() + check_pos, the_archive_path.end());
-
-    // Find *all* archived files in ECF_HOME
-    std::vector<fs::path> archived_file_vec;
-    File::find_files_with_extn(ecf_home, ".check", archived_file_vec);
-    if (archived_file_vec.empty())
-        return;
-
-    // if this nodes archive file is a prefix for any archived file, then it is child archived file and needs
-    // to be deleted. i.e. if /ecflow is being deleted then:
-    // the_archive_path = Avis-MacBook-Pro.local.4040.:ecflow
-    // Hence if this matches as a prefix for any archive file, then it needs to be deleted.
-    //  Avis-MacBook-Pro.local.4040.:ecflow.check
-    //  Avis-MacBook-Pro.local.4040.:ecflow:darwin.check
-    //  Avis-MacBook-Pro.local.4040.:ecflow:darwin:apple_clang.check
-    //  Avis-MacBook-Pro.local.4040.:ecflow:darwin:gnu.10.check
-
-    for (const auto& file_path : archived_file_vec) {
-        std::string path = file_path.string();
-
-        if (path.find(the_archive_path) == 0) {
-            try {
-                fs::remove(path);
-            }
-            catch (...) {
-            };
-        }
-    }
-}
-
-void NodeContainer::sort_attributes(ecf::Attr::Type attr, bool recursive, const std::vector<std::string>& no_sort) {
-    Node::sort_attributes(attr, recursive, no_sort);
-    if (recursive) {
-        for (const auto& n : nodes_) {
-            n->sort_attributes(attr, recursive, no_sort);
-        }
-    }
-}
-
-bool NodeContainer::doDeleteChild(Node* child) {
-    SuiteChanged1 changed(suite());
-    auto theTaskEnd = nodes_.end();
-    for (auto t = nodes_.begin(); t != theTaskEnd; ++t) {
-        if ((*t).get() == child) {
-
-            // Remove any child archived file
-            Family* fam = (*t)->isFamily();
-            if (fam) {
-                fam->remove_archived_files();
-            }
-
-            child->set_parent(nullptr); // must set to NULL, allow it to be re-added to different parent
-            nodes_.erase(t);
-            add_remove_state_change_no_ = Ecf::incr_state_change_no();
-            set_most_significant_state_up_node_tree();
-            return true;
-        }
-        if ((*t)->doDeleteChild(child)) {
-            return true;
-        }
-    }
-
-    return false;
-}
-
-void NodeContainer::check_job_creation(job_creation_ctrl_ptr jobCtrl) {
-
-    if (defStatus() != DState::COMPLETE) {
-        for (const auto& n : nodes_) {
-            n->check_job_creation(jobCtrl);
-        }
-    }
-}
-
-void NodeContainer::generate_scripts(const std::map<std::string, std::string>& override) const {
-    for (const auto& n : nodes_) {
-        n->generate_scripts(override);
-    }
-}
-
-template <class Archive>
-void NodeContainer::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Node>(this), CEREAL_NVP(nodes_));
-
-    // Set up the parent pointers. Since they are not serialised
-    if (Archive::is_loading::value) {
-        for (auto& n : nodes_) {
-            n->set_parent(this);
-        }
-    }
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(NodeContainer);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeContainer.hpp 5.13.0-1/ANode/src/ecflow/node/NodeContainer.hpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeContainer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeContainer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,175 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_NodeContainer_HPP
-#define ecflow_node_NodeContainer_HPP
-
-///
-/// \brief The NodeContainer class holds families and tasks
-///
-
-#include <limits>
-
-#include "ecflow/node/Node.hpp"
-
-class NodeContainer : public Node {
-protected:
-    NodeContainer& operator=(const NodeContainer&);
-
-public:
-    explicit NodeContainer(const std::string& name, bool check);
-    NodeContainer(const NodeContainer&);
-    NodeContainer();
-    ~NodeContainer() override;
-
-    bool check_defaults() const override;
-
-    void accept(ecf::NodeTreeVisitor&) override;
-    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
-    void reset() override;
-    void begin() override;
-    void requeue(Requeue_args&) override;
-    void requeue_time_attrs() override;
-    void handle_migration(const ecf::Calendar&) override;
-    void reset_late_event_meters() override;
-    bool run(JobsParam& jobsParam, bool force) override;
-    void kill(const std::string& zombie_pid = "") override;
-    void status() override;
-    bool top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const override;
-    void collateChanges(DefsDelta&) const override;
-    void set_memento(const OrderMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void set_memento(const ChildrenMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-    void order(Node* immediateChild, NOrder::Order) override;
-    void move_peer(Node* src, Node* dest) override;
-
-    bool hasAutoCancel() const override;
-    bool calendarChanged(const ecf::Calendar&,
-                         Node::Calendar_args&,
-                         const ecf::LateAttr* inherited_late,
-                         bool holding_parent_day_or_date) override;
-    bool resolveDependencies(JobsParam&) override;
-    bool has_time_based_attributes() const override;
-    bool check(std::string& errorMsg, std::string& warningMsg) const override;
-    void invalidate_trigger_references() const override;
-
-    task_ptr add_task(const std::string& task_name);
-    family_ptr add_family(const std::string& family_name);
-    void addTask(const task_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
-    void addFamily(const family_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
-    void add_child(const node_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
-
-    void immediateChildren(std::vector<node_ptr>&) const override;
-    void allChildren(std::vector<node_ptr>&) const override;
-
-    node_ptr findImmediateChild(const std::string& name, size_t& child_pos) const override;
-    node_ptr find_immediate_child(const std::string_view&) const override;
-    node_ptr find_node_up_the_tree(const std::string& name) const override;
-
-    node_ptr find_relative_node(const std::vector<std::string>& pathToNode) override;
-    void find_closest_matching_node(const std::vector<std::string>& pathToNode,
-                                    int indexIntoPathNode,
-                                    node_ptr& closest_matching_node);
-
-    node_ptr find_by_name(const std::string& name) const;
-    family_ptr findFamily(const std::string& familyName) const;
-    task_ptr findTask(const std::string& taskName) const;
-
-    std::string find_node_path(const std::string& type, const std::string& name) const override;
-
-    void getAllFamilies(std::vector<Family*>&) const;
-    void getAllNodes(std::vector<Node*>&) const override;
-    void getAllTasks(std::vector<Task*>&) const override;
-    void getAllSubmittables(std::vector<Submittable*>&) const override;
-    void get_all_active_submittables(std::vector<Submittable*>&) const override;
-    void get_all_tasks(std::vector<task_ptr>&) const override;
-    void get_all_nodes(std::vector<node_ptr>&) const override;
-    void get_all_aliases(std::vector<alias_ptr>&) const override;
-    void getAllAstNodes(std::set<Node*>&) const override;
-    const std::vector<node_ptr>& nodeVec() const { return nodes_; }
-    std::vector<task_ptr> taskVec() const;
-    std::vector<family_ptr> familyVec() const;
-
-    void print(std::string&) const override;
-    bool operator==(const NodeContainer& rhs) const;
-
-    bool hasTimeDependencies() const override;
-
-    void check_job_creation(job_creation_ctrl_ptr jobCtrl) override;
-    void generate_scripts(const std::map<std::string, std::string>& override) const override;
-
-    bool checkInvariants(std::string& errorMsg) const override;
-    void verification(std::string& errorMsg) const override;
-
-    NState::State computedState(Node::TraverseType) const override;
-
-    node_ptr removeChild(Node* child) override;
-    bool addChild(const node_ptr& child, size_t position = std::numeric_limits<std::size_t>::max()) override;
-    bool isAddChildOk(Node* child, std::string& errorMsg) const override;
-
-    void setRepeatToLastValueHierarchically() override;
-    void setStateOnlyHierarchically(NState::State s, bool force = false) override;
-    void set_state_hierarchically(NState::State s, bool force) override;
-    void update_limits() override;
-    void sort_attributes(ecf::Attr::Type attr,
-                         bool recursive                          = true,
-                         const std::vector<std::string>& no_sort = std::vector<std::string>()) override;
-
-    bool has_archive() const override;
-    void archive();
-    void restore();
-    void remove_archived_files();     // used in delete
-    std::string archive_path() const; // can throw if ECF_HOME not defined
-
-    boost::posix_time::time_duration sum_runtime() override;
-
-private:
-    void restore_on_begin_or_requeue();
-
-    size_t child_position(const Node*) const override;
-    void add_task_only(const task_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
-    void add_family_only(const family_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
-
-    void handle_defstatus_propagation();
-    void match_closest_children(const std::vector<std::string>& pathToNode,
-                                int indexIntoPathToNode,
-                                node_ptr& closest_matching_node);
-
-    void handleStateChange() override; // called when a state change happens
-
-    friend class Defs;
-    friend class Family;
-    bool doDeleteChild(Node* child) override;
-
-    /// For use by python interface,
-    std::vector<node_ptr>::const_iterator node_begin() const { return nodes_.begin(); }
-    std::vector<node_ptr>::const_iterator node_end() const { return nodes_.end(); }
-    friend void export_SuiteAndFamily();
-
-protected:
-    void force_sync() override;
-    void incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const;
-
-private:
-    void copy(const NodeContainer& rhs);
-    void swap(NodeContainer& rhs);
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-
-private:
-    std::vector<node_ptr> nodes_;
-
-protected:
-    unsigned int order_state_change_no_{0};      // no need to persist
-    unsigned int add_remove_state_change_no_{0}; // no need to persist
-};
-
-#endif /* ecflow_node_NodeContainer_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeDelete.cpp 5.13.0-1/ANode/src/ecflow/node/NodeDelete.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeDelete.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeDelete.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,429 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/MiscAttrs.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-void Node::deleteTime(const std::string& name) {
-    if (name.empty()) {
-        times_.clear(); // delete all
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteTime\n";
-#endif
-        return;
-    }
-    TimeAttr attr(TimeSeries::create(name)); // can throw if parse fails
-    delete_time(attr);                       // can throw if search fails
-}
-
-void Node::delete_time(const ecf::TimeAttr& attr) {
-    size_t theSize = times_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        // Dont use '==' since that compares additional state like free_
-        if (times_[i].structureEquals(attr)) {
-            times_.erase(times_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::delete_time\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::delete_time: Cannot find time attribute: ");
-}
-
-void Node::deleteToday(const std::string& name) {
-    if (name.empty()) {
-        todays_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteToday\n";
-#endif
-        return;
-    }
-
-    TodayAttr attr(TimeSeries::create(name)); // can throw if parse fails
-    delete_today(attr);                       // can throw if search fails
-}
-
-void Node::delete_today(const ecf::TodayAttr& attr) {
-    size_t theSize = todays_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        // Dont use '==' since that compares additional state like free_
-        if (todays_[i].structureEquals(attr)) {
-            todays_.erase(todays_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::delete_today\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::delete_today: Cannot find today attribute: " + attr.toString());
-}
-
-void Node::deleteDate(const std::string& name) {
-    if (name.empty()) {
-        dates_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteDate\n";
-#endif
-        return;
-    }
-
-    DateAttr attr(DateAttr::create(name)); // can throw if parse fails
-    delete_date(attr);                     // can throw if search fails
-}
-
-void Node::delete_date(const DateAttr& attr) {
-    for (size_t i = 0; i < dates_.size(); i++) {
-        // Dont use '==' since that compares additional state like free_
-        if (attr.structureEquals(dates_[i])) {
-            dates_.erase(dates_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::delete_date\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::delete_date: Cannot find date attribute: " + attr.toString());
-}
-
-void Node::deleteDay(const std::string& name) {
-    if (name.empty()) {
-        days_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteDay\n";
-#endif
-        return;
-    }
-
-    DayAttr attr(DayAttr::create(name)); // can throw if parse fails.
-    delete_day(attr);                    // can throw if search fails
-}
-
-void Node::delete_day(const DayAttr& attr) {
-    for (size_t i = 0; i < days_.size(); i++) {
-        // Dont use '==' since that compares additional state like free_
-        if (attr.structureEquals(days_[i])) {
-            days_.erase(days_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::delete_day\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::delete_day: Cannot find day attribute: " + attr.toString());
-}
-
-void Node::deleteCron(const std::string& name) {
-    if (name.empty()) {
-        crons_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteCron\n";
-#endif
-        return;
-    }
-
-    CronAttr attr = CronAttr::create(name); // can throw if parse fails
-    delete_cron(attr);                      // can throw if search fails
-}
-
-void Node::delete_cron(const ecf::CronAttr& attr) {
-    for (size_t i = 0; i < crons_.size(); i++) {
-        // Dont use '==' since that compares additional state like free_
-        if (attr.structureEquals(crons_[i])) {
-            crons_.erase(crons_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::delete_cron\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::delete_cron: Cannot find cron attribute: " + attr.toString());
-}
-
-void Node::deleteVariable(const std::string& name) {
-    if (name.empty()) {
-        vars_.clear(); // delete all
-        state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteVariable\n";
-#endif
-        return;
-    }
-
-    size_t theSize = vars_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vars_[i].name() == name) {
-            vars_.erase(vars_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::deleteVariable\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::deleteVariable: Cannot find 'user' variable of name " + name);
-}
-
-void Node::delete_variable_no_error(const std::string& name) {
-    if (name.empty()) {
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::delete_variable_no_error\n";
-#endif
-        return;
-    }
-
-    size_t theSize = vars_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vars_[i].name() == name) {
-            vars_.erase(vars_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::delete_variable_no_error\n";
-#endif
-            return;
-        }
-    }
-}
-
-void Node::deleteEvent(const std::string& name) {
-    if (name.empty()) {
-        events_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteEvent\n";
-#endif
-        return;
-    }
-
-    size_t theSize = events_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (events_[i].name_or_number() == name) {
-            events_.erase(events_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::deleteEvent\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::deleteEvent: Cannot find event: " + name);
-}
-
-void Node::deleteMeter(const std::string& name) {
-    if (name.empty()) {
-        meters_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Expression::clearFree()\n";
-#endif
-        return;
-    }
-
-    size_t theSize = meters_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (meters_[i].name() == name) {
-            meters_.erase(meters_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Expression::clearFree()\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::deleteMeter: Cannot find meter: " + name);
-}
-
-void Node::deleteLabel(const std::string& name) {
-    if (name.empty()) {
-        labels_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteLabel\n";
-#endif
-        return;
-    }
-
-    size_t theSize = labels_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (labels_[i].name() == name) {
-            labels_.erase(labels_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::deleteLabel\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::deleteLabel: Cannot find label: " + name);
-}
-
-void Node::delete_queue(const std::string& name) {
-    if (misc_attrs_) {
-        misc_attrs_->delete_queue(name);
-        return;
-    }
-    throw std::runtime_error("Node::delete_queue: Cannot find queue: " + name);
-}
-
-void Node::delete_generic(const std::string& name) {
-    if (misc_attrs_) {
-        misc_attrs_->delete_generic(name);
-        return;
-    }
-    throw std::runtime_error("Node::delete_generic : Cannot find generic: " + name);
-}
-
-void Node::deleteTrigger() {
-    if (t_expr_) {
-        t_expr_.reset(nullptr);
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteTrigger()\n";
-#endif
-    }
-}
-
-void Node::deleteComplete() {
-    if (c_expr_) {
-        c_expr_.reset(nullptr);
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteComplete()\n";
-#endif
-    }
-}
-
-void Node::deleteRepeat() {
-    if (!repeat_.empty()) {
-        repeat_.clear(); // will delete the pimple
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteRepeat())\n";
-#endif
-    }
-}
-
-void Node::deleteLimit(const std::string& name) {
-    if (name.empty()) {
-        limits_.clear();
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteLimit\n";
-#endif
-        return;
-    }
-
-    size_t theSize = limits_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (limits_[i]->name() == name) {
-            limits_.erase(limits_.begin() + i);
-            state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-            std::cout << "Node::deleteLimit\n";
-#endif
-            return;
-        }
-    }
-    throw std::runtime_error("Node::deleteLimit: Cannot find limit: " + name);
-}
-
-void Node::delete_limit_path(const std::string& name, const std::string& path) {
-    if (name.empty()) {
-        throw std::runtime_error("Node::delete_limit_path: the limit name must be provided");
-    }
-    if (path.empty()) {
-        throw std::runtime_error("Node::delete_limit_path: the limit path must be provided");
-    }
-
-    size_t theSize = limits_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (limits_[i]->name() == name) {
-            limits_[i]->delete_path(path); // will update state change no
-            return;
-        }
-    }
-    throw std::runtime_error("Node::delete_limit_path: Cannot find limit: " + name);
-}
-
-void Node::deleteInlimit(const std::string& name) {
-    // if name exists but no corresponding in limit found raises an exception
-    if (inLimitMgr_.deleteInlimit(name)) {
-        state_change_no_ = Ecf::incr_state_change_no();
-#ifdef DEBUG_STATE_CHANGE_NO
-        std::cout << "Node::deleteInlimit\n";
-#endif
-    }
-}
-
-void Node::delete_misc_attrs_if_empty() {
-    if (misc_attrs_ && misc_attrs_->empty()) {
-        misc_attrs_.reset(nullptr);
-    }
-}
-
-void Node::deleteZombie(const std::string& zombie_type) {
-    if (misc_attrs_) {
-        misc_attrs_->deleteZombie(zombie_type);
-        delete_misc_attrs_if_empty();
-    }
-}
-
-void Node::delete_zombie(Child::ZombieType zt) {
-    if (misc_attrs_) {
-        misc_attrs_->delete_zombie(zt);
-        delete_misc_attrs_if_empty();
-    }
-}
-
-void Node::deleteLate() {
-    late_.reset(nullptr);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::deleteAutoCancel() {
-    auto_cancel_.reset(nullptr);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::deleteAutoArchive() {
-    auto_archive_.reset(nullptr);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Node::deleteAutoRestore() {
-    auto_restore_.reset(nullptr);
-    state_change_no_ = Ecf::incr_state_change_no();
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeFind.cpp 5.13.0-1/ANode/src/ecflow/node/NodeFind.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeFind.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeFind.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,965 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/NodePath.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/MiscAttrs.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-/// Output a vector to cout
-template <class T>
-ostream& operator<<(ostream& os, const vector<T>& v) {
-    copy(v.begin(), v.end(), ostream_iterator<T>(cout, " "));
-    return os;
-}
-
-bool Node::findParentVariableValue(const std::string& name, std::string& theValue) const {
-    if (!vars_.empty() && findVariableValue(name, theValue))
-        return true;
-    if (!repeat_.empty() && repeat_.name() == name) {
-        theValue = repeat_.valueAsString();
-        return true;
-    }
-    if (findGenVariableValue(name, theValue))
-        return true;
-
-    Node* theParent = parent();
-    while (theParent) {
-
-        if (theParent->findVariableValue(name, theValue))
-            return true;
-        const Repeat& rep = theParent->repeat();
-        if (!rep.empty() && rep.name() == name) {
-            theValue = rep.valueAsString();
-            return true;
-        }
-        if (theParent->findGenVariableValue(name, theValue))
-            return true;
-
-        theParent = theParent->parent();
-    }
-
-    // If all else fails search defs environment, returns empty string if match not found
-    // The defs environment is constructed via:
-    //   o/ default settings for ECF_HOME,ECF_LOG, ECF_CHECK,ECF_CHECKOLD,ECF_CHECKINTERVAL
-    //                           ECF_INTERVAL ECF_CHECKMODE ECF_JOB_CMD ECF_MICRO ECF_TRIES ECF_PORT, ECF_HOST
-    //   o/ These values are updated from the server environment when the `BEGIN` command is called.
-    Defs* the_defs = defs();
-    if (the_defs) {
-        theValue = the_defs->server().find_variable(name);
-        if (!theValue.empty())
-            return true;
-    }
-    return false; // the variable cannot be found
-}
-
-bool Node::find_parent_gen_variable_value(const std::string& name, std::string& theValue) const {
-    if (findGenVariableValue(name, theValue))
-        return true;
-
-    Node* theParent = parent();
-    while (theParent) {
-        if (theParent->findGenVariableValue(name, theValue))
-            return true;
-        theParent = theParent->parent();
-    }
-
-    // If all else fails search defs environment, returns empty string if match not found
-    // The defs environment is constructed via:
-    //   o/ default settings for ECF_HOME,ECF_LOG, ECF_CHECK,ECF_CHECKOLD,ECF_CHECKINTERVAL
-    //                           ECF_INTERVAL ECF_CHECKMODE ECF_JOB_CMD ECF_MICRO ECF_TRIES ECF_PORT, ECF_HOST
-    //   o/ These values are updated from the server environment when the `BEGIN` command is called.
-    Defs* the_defs = defs();
-    if (the_defs) {
-        theValue = the_defs->server().find_variable(name);
-        if (!theValue.empty())
-            return true;
-    }
-    return false; // the variable cannot be found
-}
-
-bool Node::findParentUserVariableValue(const std::string& name, std::string& theValue) const {
-    if (findVariableValue(name, theValue))
-        return true;
-
-    Node* theParent = parent();
-    while (theParent) {
-        if (theParent->findVariableValue(name, theValue))
-            return true;
-        theParent = theParent->parent();
-    }
-
-    // If all else fails search defs environment, returns empty string if match not found
-    Defs* the_defs = defs();
-    if (the_defs) {
-        // Note: when calling ecflow_client --get_state=/suite/task
-        // The node can be detached from the defs.
-        theValue = the_defs->server().find_variable(name);
-        if (!theValue.empty())
-            return true;
-    }
-    return false; // the variable cannot be found
-}
-
-const std::string& Node::find_parent_user_variable_value(const std::string& name) const {
-    const Variable& var = findVariable(name);
-    if (!var.empty())
-        return var.theValue();
-
-    Node* theParent = parent();
-    while (theParent) {
-        const Variable& pvar = theParent->findVariable(name);
-        if (!pvar.empty())
-            return pvar.theValue();
-        theParent = theParent->parent();
-    }
-
-    Defs* the_defs = defs();
-    if (the_defs) {
-        // Note: when calling ecflow_client --get_state=/suite/task
-        // The node can be detached from the defs.
-        return the_defs->server().find_variable(name);
-    }
-    return Str::EMPTY();
-}
-
-bool Node::user_variable_exists(const std::string& name) const {
-    const Variable& var = findVariable(name);
-    if (!var.empty())
-        return true;
-
-    Node* theParent = parent();
-    while (theParent) {
-        const Variable& pvar = theParent->findVariable(name);
-        if (!pvar.empty())
-            return true;
-        theParent = theParent->parent();
-    }
-
-    // If all else fails search defs environment, returns empty string if match not found
-    Defs* the_defs = defs();
-    if (the_defs) {
-        // Note: when calling ecflow_client --get_state=/suite/task
-        // The node can be detached from the defs.
-        return the_defs->server().variable_exists(name);
-    }
-    return false;
-}
-
-const Variable& Node::findVariable(const std::string& name) const {
-    for (const auto& v : vars_) {
-        if (v.name() == name) {
-            return v;
-        }
-    }
-    return Variable::EMPTY();
-}
-
-std::string Node::find_parent_variable_sub_value(const std::string& name) const {
-    std::string ret;
-    const Variable& var = findVariable(name);
-    if (!var.empty()) {
-        ret = var.theValue();
-        variableSubstitution(ret);
-        return ret;
-    }
-
-    Node* theParent = parent();
-    while (theParent) {
-        const Variable& pvar = theParent->findVariable(name);
-        if (!pvar.empty()) {
-            ret = pvar.theValue();
-            variableSubstitution(ret);
-            return ret;
-        }
-        theParent = theParent->parent();
-    }
-
-    // If all else fails search defs environment
-    Defs* the_defs = defs();
-    if (the_defs) {
-        const Variable& pvar = the_defs->server().findVariable(name);
-        ret                  = pvar.theValue();
-        the_defs->variableSubsitution(ret);
-        return ret;
-    }
-
-    return string();
-}
-
-const Variable& Node::find_parent_variable(const std::string& name) const {
-    const Variable& var = findVariable(name);
-    if (!var.empty())
-        return var;
-
-    Node* theParent = parent();
-    while (theParent) {
-        const Variable& pvar = theParent->findVariable(name);
-        if (!pvar.empty())
-            return pvar;
-        theParent = theParent->parent();
-    }
-
-    // If all else fails search defs environment
-    Defs* the_defs = defs();
-    if (the_defs) {
-        return the_defs->server().findVariable(name);
-    }
-
-    return Variable::EMPTY();
-}
-
-bool Node::findVariableValue(const std::string& name, std::string& returnedValue) const {
-    for (const auto& var : vars_) {
-        if (var.name() == name) {
-            returnedValue = var.theValue();
-            return true;
-        }
-    }
-    return false;
-}
-
-bool Node::findGenVariableValue(const std::string& name, std::string& returnedValue) const {
-    const Variable& genVar = findGenVariable(name);
-    if (!genVar.empty()) {
-        returnedValue = genVar.theValue();
-        return true;
-    }
-    return false;
-}
-
-bool Node::findLimit(const Limit& theLimit) const {
-    for (const auto& lim : limits_) {
-        if (lim->name() == theLimit.name()) {
-            return true;
-        }
-    }
-    return false;
-}
-
-limit_ptr Node::find_limit(const std::string& theName) const {
-    for (const auto& lim : limits_) {
-        if (lim->name() == theName) {
-            return lim;
-        }
-    }
-    return limit_ptr();
-}
-
-limit_ptr Node::findLimitUpNodeTree(const std::string& name) const {
-    limit_ptr theFndLimit = find_limit(name);
-    if (theFndLimit.get())
-        return theFndLimit;
-
-    Node* theParent = parent();
-    while (theParent != nullptr) {
-
-        limit_ptr theFndLimit2 = theParent->find_limit(name);
-        if (theFndLimit2.get())
-            return theFndLimit2;
-
-        theParent = theParent->parent();
-    }
-    return limit_ptr();
-}
-
-const Event& Node::findEvent(const Event& theEvent) const {
-    for (const auto& e : events_) {
-        // compare ignores state like value_ and initial_value
-        if (e.compare(theEvent)) {
-            return e;
-        }
-    }
-    return Event::EMPTY();
-}
-
-const Event& Node::findEventByNumber(int number) const {
-    for (const auto& e : events_) {
-        if (e.number() == number) {
-            return e;
-        }
-    }
-    return Event::EMPTY();
-}
-
-const Event& Node::findEventByName(const std::string& event_name) const {
-    for (const auto& e : events_) {
-        if (e.name() == event_name) {
-            return e;
-        }
-    }
-    return Event::EMPTY();
-}
-
-const Event& Node::findEventByNameOrNumber(const std::string& theName) const {
-    const Event& event = findEventByName(theName);
-    if (!event.empty()) {
-        return event;
-    }
-
-    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
-    if (theName.find_first_of(Str::NUMERIC(), 0) == 0) {
-        try {
-            auto eventNumber = ecf::convert_to<int>(theName);
-            return findEventByNumber(eventNumber);
-        }
-        catch (const ecf::bad_conversion&) {
-        }
-    }
-    return Event::EMPTY();
-}
-
-const Meter& Node::findMeter(const std::string& name) const {
-    for (const auto& m : meters_) {
-        if (m.name() == name) {
-            return m;
-        }
-    }
-    return Meter::EMPTY();
-}
-
-Meter& Node::find_meter(const std::string& name) {
-    for (auto& m : meters_) {
-        if (m.name() == name) {
-            return m;
-        }
-    }
-    return const_cast<Meter&>(Meter::EMPTY());
-}
-
-bool Node::findLabel(const std::string& name) const {
-    for (const auto& l : labels_) {
-        if (l.name() == name) {
-            return true;
-        }
-    }
-    return false;
-}
-
-const Label& Node::find_label(const std::string& name) const {
-    for (const auto& l : labels_) {
-        if (l.name() == name) {
-            return l;
-        }
-    }
-    return Label::EMPTY();
-}
-
-bool Node::findVerify(const VerifyAttr& v) const {
-    if (misc_attrs_)
-        return misc_attrs_->findVerify(v);
-    return false;
-}
-
-const QueueAttr& Node::find_queue(const std::string& name) const {
-    if (misc_attrs_)
-        return misc_attrs_->find_queue(name);
-    return QueueAttr::EMPTY();
-}
-
-QueueAttr& Node::findQueue(const std::string& name) {
-    if (misc_attrs_)
-        return misc_attrs_->findQueue(name);
-    return QueueAttr::EMPTY1();
-}
-
-const GenericAttr& Node::find_generic(const std::string& name) const {
-    if (misc_attrs_)
-        return misc_attrs_->find_generic(name);
-    return GenericAttr::EMPTY();
-}
-
-const Repeat& Node::findRepeat(const std::string& name) const {
-    if (!repeat_.empty() && repeat_.name() == name) {
-        return repeat_;
-    }
-    return Repeat::EMPTY();
-}
-
-bool Node::findExprVariable(const std::string& name) {
-    // if event found return true; also, mark this event so simulator know it's used in a trigger
-    if (set_event_used_in_trigger(name)) {
-        return true;
-    }
-
-    // if meter found mark as used in trigger for simulator, and return
-    if (set_meter_used_in_trigger(name)) {
-        return true;
-    }
-
-    const Variable& user_variable = findVariable(name);
-    if (!user_variable.empty())
-        return true;
-
-    const Repeat& repeat = findRepeat(name);
-    if (!repeat.empty())
-        return true;
-
-    const Variable& gen_variable = findGenVariable(name);
-    if (!gen_variable.empty())
-        return true;
-
-    limit_ptr limit = find_limit(name);
-    if (limit.get())
-        return true;
-
-    QueueAttr& queue_attr = findQueue(name);
-    if (!queue_attr.empty()) {
-        queue_attr.set_used_in_trigger(true);
-        return true;
-    }
-
-    return false;
-}
-
-int Node::findExprVariableValue(const std::string& name) const {
-    const Event& event = findEventByNameOrNumber(name);
-    if (!event.empty())
-        return (event.value() ? 1 : 0);
-
-    const Meter& meter = findMeter(name);
-    if (!meter.empty())
-        return meter.value();
-
-    const Variable& variable = findVariable(name);
-    if (!variable.empty())
-        return variable.value();
-
-    const Repeat& repeat = findRepeat(name);
-    if (!repeat.empty()) {
-        // RepeatDate       last_valid_value() returns the date by its real value as a long
-        // RepeatDatelist   last_valid_value() returns the date by its real value as a long
-        // RepeatInteger    last_valid_value() returns the value, by the current value of integer
-        // RepeatEnumerated last_valid_value() returns the current value if cast-able to integer otherwise
-        // position/index,
-        //                                     (i.e. since enum can be anything)
-        // RepeatString     last_valid_value() returns the current position/index  ( Alternatives? )
-        // RepeatDay        last_valid_value() returns the current step
-        // Note: At Repeat expiration Repeat::value() may be out of range of start-end
-        //       But Repeat::last_valid_value() should always be in range, hence at Repeat expiration
-        //       will return the last valid value.
-        return repeat.last_valid_value();
-    }
-
-    const Variable& gen_variable = findGenVariable(name);
-    if (!gen_variable.empty())
-        return gen_variable.value();
-
-    limit_ptr limit = find_limit(name);
-    if (limit.get())
-        return limit->value();
-
-    const QueueAttr& queue_attr = find_queue(name);
-    if (!queue_attr.empty())
-        return queue_attr.index_or_value();
-
-    return 0;
-}
-
-int Node::findExprVariableValueAndPlus(const std::string& name, int val) const {
-    const Event& event = findEventByNameOrNumber(name);
-    if (!event.empty())
-        return ((event.value() ? 1 : 0) + val);
-
-    const Meter& meter = findMeter(name);
-    if (!meter.empty())
-        return (meter.value() + val);
-
-    const Variable& variable = findVariable(name);
-    if (!variable.empty())
-        return (variable.value() + val);
-
-    const Repeat& repeat = findRepeat(name);
-    if (!repeat.empty()) {
-        // RepeatDate       last_valid_value() returns the date by its real value as a long
-        // RepeatInteger    last_valid_value() returns the value, by the current value of integer
-        // RepeatEnumerated last_valid_value() returns the current value if cast-able as integer otherwise
-        // position/index,
-        //                                    (i.e. since enum can be anything)
-        // RepeatString     last_valid_value() returns the current position/index  ( Alternatives? )
-        // RepeatDay        last_valid_value() returns the current step
-        // Note: At Repeat expiration Repeat::value() may be out of range of start-end
-        //       But Repeat::last_valid_value() should always be in range, hence at Repeat expiration
-        //       will return the last valid value.
-        return repeat.last_valid_value_plus(val);
-    }
-
-    const Variable& gen_variable = findGenVariable(name);
-    if (!gen_variable.empty())
-        return (gen_variable.value() + val);
-
-    limit_ptr limit = find_limit(name);
-    if (limit.get())
-        return (limit->value() + val);
-
-    const QueueAttr& queue_attr = find_queue(name);
-    if (!queue_attr.empty())
-        return (queue_attr.index_or_value() + val);
-
-    return val;
-}
-
-int Node::findExprVariableValueAndMinus(const std::string& name, int val) const {
-    const Event& event = findEventByNameOrNumber(name);
-    if (!event.empty())
-        return ((event.value() ? 1 : 0) - val);
-
-    const Meter& meter = findMeter(name);
-    if (!meter.empty())
-        return (meter.value() - val);
-
-    const Variable& variable = findVariable(name);
-    if (!variable.empty())
-        return (variable.value() - val);
-
-    const Repeat& repeat = findRepeat(name);
-    if (!repeat.empty()) {
-        // RepeatDate       last_valid_value() returns the date by its real value as a long
-        // RepeatInteger    last_valid_value() returns the value, by the current value of integer
-        // RepeatEnumerated last_valid_value() returns the current value if cast-able as integer, else position/index, (
-        //                                     i.e. since enum can be anything)
-        // RepeatString     last_valid_value() returns the current position/index  ( Alternatives? )
-        // RepeatDay        last_valid_value() returns the current step
-        // Note: At Repeat expiration Repeat::value() may be out of range of start-end
-        //       But Repeat::last_valid_value() should always be in range, hence at Repeat expiration
-        //       will return the last valid value.
-        return repeat.last_valid_value_minus(val);
-    }
-
-    const Variable& gen_variable = findGenVariable(name);
-    if (!gen_variable.empty())
-        return (gen_variable.value() - val);
-
-    limit_ptr limit = find_limit(name);
-    if (limit.get())
-        return (limit->value() - val);
-
-    const QueueAttr& queue_attr = find_queue(name);
-    if (!queue_attr.empty())
-        return (queue_attr.index_or_value() - val);
-
-    return -val;
-}
-
-int Node::findExprVariableValueAndType(const std::string& name, std::string& varType) const {
-    const Event& event = findEventByNameOrNumber(name);
-    if (!event.empty()) {
-        varType = "event";
-        return (event.value() ? 1 : 0);
-    }
-    const Meter& meter = findMeter(name);
-    if (!meter.empty()) {
-        varType = "meter";
-        return meter.value();
-    }
-    const Variable& variable = findVariable(name);
-    if (!variable.empty()) {
-        varType = "user-variable";
-        return variable.value();
-    }
-    const Repeat& repeat = findRepeat(name);
-    if (!repeat.empty()) {
-        varType = "repeat";
-        return repeat.last_valid_value();
-    }
-    const Variable& gen_variable = findGenVariable(name);
-    if (!gen_variable.empty()) {
-        varType = "gen-variable";
-        return gen_variable.value();
-    }
-    limit_ptr limit = find_limit(name);
-    if (limit.get()) {
-        varType = "limit";
-        return limit->value();
-    }
-    const QueueAttr& queue_attr = find_queue(name);
-    if (!queue_attr.empty()) {
-        varType = "queue";
-        return queue_attr.index_or_value();
-    }
-
-    varType = "variable-not-found";
-    return 0;
-}
-
-void Node::findExprVariableAndPrint(const std::string& name, ostream& os) const {
-    const Event& event = findEventByNameOrNumber(name);
-    if (!event.empty()) {
-        os << "EVENT value(" << event.value() << ")";
-        return;
-    }
-    const Meter& meter = findMeter(name);
-    if (!meter.empty()) {
-        os << "METER value(" << meter.value() << ")";
-        return;
-    }
-    const Variable& variable = findVariable(name);
-    if (!variable.empty()) {
-        os << "USER-VARIABLE value(" << variable.value() << ")";
-        return;
-    }
-    const Repeat& repeat = findRepeat(name);
-    if (!repeat.empty()) {
-        os << "REPEAT value(" << repeat.value() << ")";
-        return;
-    }
-    const Variable& gen_variable = findGenVariable(name);
-    if (!gen_variable.empty()) {
-        os << "GEN-VARIABLE value(" << gen_variable.value() << ")";
-        return;
-    }
-    limit_ptr limit = find_limit(name);
-    if (limit.get()) {
-        os << limit->toString() << " value(" << limit->value() << ")";
-        return;
-    }
-    const QueueAttr& queue_attr = find_queue(name);
-    if (!queue_attr.empty()) {
-        os << "QUEUE " << queue_attr.name() << " value(" << queue_attr.index_or_value() << ")";
-        return;
-    }
-}
-
-node_ptr findRelativeNode(const vector<std::string>& theExtractedPath, node_ptr triggerNode, std::string& errorMsg) {
-    // The referenced node could be itself(error) or most likely a sibling node.
-    auto extractedPathSize = static_cast<int>(theExtractedPath.size());
-    if (extractedPathSize == 1 && triggerNode->name() == theExtractedPath[0]) {
-        // self referencing node ?
-        return triggerNode;
-    }
-
-    // Can only find *sibling* if triggerNode has a parent
-    if (!triggerNode->parent()) {
-        errorMsg = "Parent empty. Could not find referenced node\n";
-        return node_ptr();
-    }
-    if (extractedPathSize == 1) {
-        size_t child_pos; // not used
-        node_ptr theNode = triggerNode->parent()->findImmediateChild(theExtractedPath[0], child_pos);
-        if (theNode.get()) {
-            return theNode;
-        }
-    }
-    else {
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        cout << "triggerNode: " << triggerNode->debugNodePath() << "\n";
-        cout << "triggerNode->parent(): " << triggerNode->parent()->debugNodePath() << "\n";
-#endif
-        node_ptr constNode = triggerNode->parent()->find_relative_node(theExtractedPath);
-        if (constNode.get()) {
-            return constNode;
-        }
-        constNode = triggerNode->find_relative_node(theExtractedPath);
-        if (constNode.get()) {
-            return constNode;
-        }
-    }
-
-    errorMsg = "Could not find node '";
-    if (extractedPathSize == 1)
-        errorMsg += theExtractedPath[0];
-    else {
-        for (const string& s : theExtractedPath) {
-            errorMsg += s;
-            errorMsg += Str::PATH_SEPERATOR();
-        }
-    }
-    errorMsg += "' from node ";
-    errorMsg += triggerNode->absNodePath();
-    if (extractedPathSize == 1) {
-        errorMsg += " . Expected '";
-        errorMsg += theExtractedPath[0];
-        errorMsg += "' to be a sibling.";
-    }
-    errorMsg += "\n";
-    return node_ptr();
-}
-
-node_ptr Node::non_const_this() const {
-    return const_pointer_cast<Node>(shared_from_this());
-}
-
-node_ptr Node::findReferencedNode(const std::string& nodePath, std::string& errorMsg) const {
-    return findReferencedNode(nodePath, Str::EMPTY(), errorMsg);
-}
-
-// #define DEBUG_FIND_REFERENCED_NODE 1
-node_ptr
-Node::findReferencedNode(const std::string& nodePath, const std::string& extern_obj, std::string& errorMsg) const {
-#ifdef DEBUG_FIND_REFERENCED_NODE
-    cout << "Node::findReferencedNode path:" << nodePath << " extern_obj:" << extern_obj << "\n";
-#endif
-    Defs* theDefs = defs();
-    if (!theDefs) {
-        // In the case where we have a standalone Node i.e. no parent set. The Defs will be NULL.
-        // Take the case where we want to dump the state of a single node.
-        //    ecflow_client --get_state=/test/f2 --port=4141
-        // Here we are printing the state of the Node only, *NO* defs is returned.
-        // The print will cause the AST to be evaluated. The trigger evaluation will require chasing
-        // down reference nodes. Hence, we will end up here. Rather than crashing, just return a NULL Pointer.
-        return node_ptr();
-    }
-
-    /// findReferencedNode:: is used to locate references:
-    ///      a/ Trigger & complete expressions, this is where extern_obj is used.
-    ///      b/ Inlimit nodepaths.
-    ///  In *both* the case above, the node path may not exist, in the definition. Hence::
-    ///  On client side:: references not defined in externs are considered errors
-    ///  On server side:: No externs are stored, hence for unresolved node paths, we return NULL
-
-#ifdef DEBUG_FIND_REFERENCED_NODE
-    string debug_path = "Searching for path " + nodePath + " from " + debugType() + Str::COLON() + absNodePath() + "\n";
-#endif
-
-    // if an absolute path cut in early
-    if (!nodePath.empty() && nodePath[0] == '/') {
-
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        debug_path += "(!nodePath.empty() && nodePath[0] == '/') \n";
-#endif
-
-        // Must be an absolute path. i.e. /suite/family/path
-        node_ptr constNode = theDefs->findAbsNode(nodePath);
-        if (constNode.get()) {
-            return constNode;
-        }
-
-        // *NOTE*: The server does *NOT* store externs, hence the check below, will always return false, for the server:
-        // Must be an extern:
-        //    extern /referenceSuite/family/task:obj
-        //    extern /referenceSuite/family/task
-        if (theDefs->find_extern(nodePath, extern_obj)) {
-
-            // =================================================================
-            // **Client side* specific: Only client side defs, stores extrens
-            // =================================================================
-#ifdef DEBUG_FIND_REFERENCED_NODE
-            debug_path += "theDefs->find_extern(nodePath) \n";
-#endif
-
-            // return NULL *without* setting an error message as node path is defined as an extern
-
-            // OK: the node path appears in the extern list. This may be because that suite  has not been loaded.
-            // *** If the suite is loaded, then it's an error that we did not
-            // *** locate the node. i.e. in the previous call to defs->findAbsNode(nodePath);
-            vector<string> theExtractedPath;
-            NodePath::split(nodePath, theExtractedPath);
-
-            std::string referenceSuite = theExtractedPath[0];
-            if (theDefs->findSuite(referenceSuite)) {
-                // The suite referenced in the extern is LOADED, but path did not resolve,
-                // in previous call to defs->findAbsNode(nodePath);
-                errorMsg = "Extern path ";
-                errorMsg += nodePath;
-                errorMsg += " does not exist on suite ";
-                errorMsg += referenceSuite;
-                errorMsg += "\n";
-#ifdef DEBUG_FIND_REFERENCED_NODE
-                errorMsg += debug_path;
-#endif
-            }
-
-            // It's an extern path that references a suite that's NOT loaded yet
-            return node_ptr();
-        }
-
-        errorMsg = ": Could not find referenced node, using absolute path '";
-        errorMsg += nodePath;
-        errorMsg += "\n";
-        return node_ptr();
-    }
-
-    /// =============================================================================
-    /// Path is something other than ABSOLUTE path
-    /// =============================================================================
-    vector<string> theExtractedPath;
-    NodePath::split(nodePath, theExtractedPath);
-
-#ifdef DEBUG_FIND_REFERENCED_NODE
-    debug_path += "extracted path = ";
-    for (const string& s : theExtractedPath) {
-        debug_path += ",";
-        debug_path += s;
-    }
-    debug_path += "\n";
-#endif
-
-    if (theExtractedPath.empty()) {
-        std::stringstream ss;
-        ss << ": Could not find referenced node '" << nodePath << "' from node " << absNodePath() << "\n";
-        errorMsg = ss.str();
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        errorMsg += debug_path;
-#endif
-        return node_ptr();
-    }
-
-    //  i.e.   " a == complete" =====>        nodePath = a
-    if (theExtractedPath.size() == 1) {
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        debug_path += "( theExtractedPath.size() == 1)\n";
-#endif
-        // Search for a relative node first
-        string localErrorMsg;
-        node_ptr res = findRelativeNode(theExtractedPath, non_const_this(), localErrorMsg);
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        if (!localErrorMsg.empty()) {
-            debug_path += localErrorMsg;
-            localErrorMsg = debug_path;
-        }
-#endif
-
-        if (!res.get()) {
-            // Let's see if it is in an extern Node. Externs can have absolute and relative paths.
-            // In this case, it will be a relative path, and thus there is no point trying to see if suite is loaded
-            if (theDefs->find_extern(nodePath, extern_obj)) {
-                // =================================================================
-                // **Client side* specific: Only client side defs, stores externs
-                // =================================================================
-                // The path exist in the extern, and we know it is relative
-                return node_ptr();
-            }
-        }
-
-        errorMsg += localErrorMsg;
-        return res;
-    }
-
-    // handle Node path of type   a/b/c
-    if (theExtractedPath.size() >= 2 && theExtractedPath[0] != "." && theExtractedPath[0] != "..") {
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        debug_path +=
-            "(theExtractedPath.size() >= 2 && theExtractedPath[0] != \".\") && theExtractedPath[0] != \"..\"\n";
-#endif
-        // First check to see if it is in the externs
-        if (theDefs->find_extern(nodePath, extern_obj)) {
-            // =================================================================
-            // **Client side* specific: Only client side defs, stores externs
-            // =================================================================
-            // The path a/b/c exist in the extern, and we know its relative
-            // Again no point in checking to see if suite is loaded if path is relative
-            return node_ptr();
-        }
-
-        // In this case its equivalent to: ./a/b/c
-        theExtractedPath.insert(theExtractedPath.begin(), ".");
-    }
-
-    // node path == "./a"
-    if (theExtractedPath.size() >= 2 && theExtractedPath[0] == ".") {
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        debug_path += "theExtractedPath.size() == 2 && theExtractedPath[0] == \".\" \n";
-#endif
-        theExtractedPath.erase(theExtractedPath.begin() + 0);
-        node_ptr res = findRelativeNode(theExtractedPath, non_const_this(), errorMsg);
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        if (!errorMsg.empty()) {
-            debug_path += errorMsg;
-            errorMsg = debug_path;
-        }
-#endif
-        return res;
-    }
-
-    // ********************************************************************
-    // Note  ./   sibling go to parent and search down
-    //       ../  search at the level of the parent, requires we go up to parent and search down
-    // **********************************************************************
-    // Handle node path of the type "../a/b/c"  "../../a/b/c"
-    if (theExtractedPath.size() >= 2 && theExtractedPath[0] == "..") {
-
-#ifdef DEBUG_FIND_REFERENCED_NODE
-        debug_path += "( theExtractedPath.size() >= 2 && theExtractedPath[0] == \"..\")\n";
-#endif
-
-        Node* theParent = parent(); // get past the first parent
-        while (static_cast<int>(theExtractedPath.size()) && theParent && theExtractedPath[0] == "..") {
-            theExtractedPath.erase(theExtractedPath.begin() + 0);
-            theParent = theParent->parent(); // for each `..` go up the parent
-#ifdef DEBUG_FIND_REFERENCED_NODE
-            debug_path += "..: thepParent = ";
-            if (theParent)
-                debug_path += theParent->absNodePath();
-            else
-                debug_path += "NULL";
-#endif
-        }
-
-        if (theParent) {
-
-#ifdef DEBUG_FIND_REFERENCED_NODE
-            debug_path += "searching = " + theParent->name() + "\n";
-            for (const std::string& s : theExtractedPath) {
-                debug_path += Str::PATH_SEPERATOR() + s;
-            }
-            debug_path += "\n";
-#endif
-
-            node_ptr constNode = theParent->find_relative_node(theExtractedPath);
-            if (constNode) {
-                return constNode;
-            }
-        }
-        else {
-            // search suites, with the remaining path in theExtractedPath
-            std::string path;
-            for (const auto& i : theExtractedPath) {
-                path += Str::PATH_SEPERATOR();
-                path += i;
-            }
-            node_ptr fndNode = theDefs->findAbsNode(path);
-            if (fndNode) {
-                return fndNode;
-            }
-        }
-    }
-
-    errorMsg = "Unrecognised path ";
-    errorMsg += nodePath;
-    errorMsg += " for Node ";
-    errorMsg += absNodePath();
-    errorMsg += "\n";
-#ifdef DEBUG_FIND_REFERENCED_NODE
-    errorMsg += debug_path;
-#endif
-    return node_ptr();
-}
-
-const ZombieAttr& Node::findZombie(ecf::Child::ZombieType zombie_type) const {
-    if (misc_attrs_)
-        return misc_attrs_->findZombie(zombie_type);
-    return ZombieAttr::EMPTY();
-}
-
-bool Node::findParentZombie(ecf::Child::ZombieType z_type, ZombieAttr& z) const {
-    const ZombieAttr& the_zombie = findZombie(z_type);
-    if (!the_zombie.empty()) {
-        z = the_zombie;
-        return true;
-    }
-
-    Node* theParent = parent();
-    while (theParent) {
-        const ZombieAttr& the_zombie2 = theParent->findZombie(z_type);
-        if (!the_zombie2.empty()) {
-            z = the_zombie2;
-            return true;
-        }
-        theParent = theParent->parent();
-    }
-    return false;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeFwd.hpp 5.13.0-1/ANode/src/ecflow/node/NodeFwd.hpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeFwd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeFwd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,120 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_NodeFwd_HPP
-#define ecflow_node_NodeFwd_HPP
-
-#include <map>
-#include <memory>
-#include <string>
-#include <vector>
-
-class AbstractObserver;
-class Suite;
-class Family;
-class Task;
-class Alias;
-class Submittable;
-class Node;
-class Defs;
-class Repeat;
-class Expression;
-class Memento;
-class CompoundMemento;
-class ClockAttr;
-class JobCreationCtrl;
-class Event;
-class Meter;
-class Repeat;
-class Variable;
-class Zombie;
-struct NodeStats;
-class MiscAttrs;
-class VerifyAttr;
-class ZombieAttr;
-class QueueAttr;
-class GenericAttr;
-class PartExpression;
-
-namespace ecf {
-class LateAttr;
-class AutoCancelAttr;
-class AutoArchiveAttr;
-class AutoRestoreAttr;
-} // namespace ecf
-
-typedef std::shared_ptr<Memento> memento_ptr;
-typedef std::shared_ptr<CompoundMemento> compound_memento_ptr;
-typedef std::shared_ptr<ClockAttr> clock_ptr;
-
-typedef std::shared_ptr<JobCreationCtrl> job_creation_ctrl_ptr;
-typedef std::shared_ptr<Node> node_ptr;
-typedef std::shared_ptr<Task> task_ptr;
-typedef std::shared_ptr<Alias> alias_ptr;
-typedef std::shared_ptr<Submittable> submittable_ptr;
-typedef std::shared_ptr<Family> family_ptr;
-typedef std::shared_ptr<Suite> suite_ptr;
-typedef std::shared_ptr<Defs> defs_ptr;
-
-typedef std::weak_ptr<Defs> weak_defs_ptr;
-typedef std::weak_ptr<Suite> weak_suite_ptr;
-typedef std::weak_ptr<Task> weak_task_ptr;
-typedef std::weak_ptr<Alias> weak_alias_ptr;
-typedef std::weak_ptr<Submittable> weak_submittable_ptr;
-typedef std::weak_ptr<Node> weak_node_ptr;
-
-typedef std::map<std::string, std::string> NameValueMap;
-typedef std::vector<std::pair<std::string, std::string>> NameValueVec;
-
-class NodeContainer;
-class DefsDelta;
-class JobsParam;
-class JobCreationCtrl;
-class AstTop;
-class Ast;
-
-class StateMemento;
-class NodeStateMemento;
-class NodeDefStatusDeltaMemento;
-class SuspendedMemento;
-class ServerStateMemento;
-class ServerVariableMemento;
-class NodeEventMemento;
-class NodeMeterMemento;
-class NodeLabelMemento;
-class NodeTriggerMemento;
-class NodeCompleteMemento;
-class NodeRepeatMemento;
-class NodeRepeatIndexMemento;
-class NodeLimitMemento;
-class NodeInLimitMemento;
-class NodeVariableMemento;
-class NodeLateMemento;
-class NodeTodayMemento;
-class NodeTimeMemento;
-class NodeDayMemento;
-class NodeCronMemento;
-class NodeDateMemento;
-class NodeZombieMemento;
-class NodeVerifyMemento;
-class FlagMemento;
-class SubmittableMemento;
-class SuiteClockMemento;
-class SuiteBeginDeltaMemento;
-class SuiteCalendarMemento;
-class OrderMemento;
-class ChildrenMemento;
-class AliasChildrenMemento;
-class AliasNumberMemento;
-class NodeQueueMemento;
-class NodeGenericMemento;
-class NodeQueueIndexMemento;
-
-#endif /* ecflow_node_NodeFwd_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeMemento.cpp 5.13.0-1/ANode/src/ecflow/node/NodeMemento.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeMemento.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeMemento.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,794 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/DefsDelta.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/MiscAttrs.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// #define DEBUG_MEMENTO 1
-
-/// CompoundMemento relies all clearing all attributes with state
-void Node::clear() {
-    late_.reset(nullptr);
-    c_expr_.reset(nullptr);
-    t_expr_.reset(nullptr);
-
-    misc_attrs_.reset(nullptr);
-
-    todays_.clear();
-    times_.clear();
-    crons_.clear();
-    days_.clear();
-    dates_.clear();
-
-    // ************************************************************
-    // Note: auto cancel, auto restore, auto archive does not have any
-    //       changeable state, Hence it is not cleared.
-    //       Hence, no need for memento
-    // ************************************************************
-
-    meters_.clear();
-    events_.clear();
-    labels_.clear();
-
-    repeat_.clear();
-    vars_.clear();
-    limits_.clear();
-    inLimitMgr_.clear();
-}
-
-void Node::incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::incremental_changes(DefsDelta& changes) " << debugNodePath() << "\n";
-#endif
-
-    unsigned int client_state_change_no = changes.client_state_change_no();
-
-    // determine if state changed
-    if (st_.first.state_change_no() > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<NodeStateMemento>(std::make_pair(st_.first.state(), st_.second)));
-    }
-
-    // determine if def status changed
-    if (d_st_.state_change_no() > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<NodeDefStatusDeltaMemento>(d_st_.state()));
-    }
-
-    // determine if node suspend changed
-    if (suspended_change_no_ > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<SuspendedMemento>(suspended_));
-    }
-
-    // Determine if node attributes DELETED or ADDED, We copy **all** internal state
-    // When applying on the client side, we clear all node attributes( ie Node::clear())
-    // and re-add
-    if (state_change_no_ > client_state_change_no) {
-
-        /// *****************************************************************************************
-        /// Node attributes DELETED or ADDED, i.e we call comp->clear_attributes()
-        /// *****************************************************************************************
-
-#ifdef DEBUG_MEMENTO
-        std::cout << "    Node::incremental_changes()    Attributes added or deleted\n";
-#endif
-        // Note: auto-cancel does not have any alterable state hence, *NO* memento
-
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->clear_attributes();
-
-        for (const Meter& m : meters_) {
-            comp->add(std::make_shared<NodeMeterMemento>(m));
-        }
-        for (const Event& e : events_) {
-            comp->add(std::make_shared<NodeEventMemento>(e));
-        }
-        for (const Label& l : labels_) {
-            comp->add(std::make_shared<NodeLabelMemento>(l));
-        }
-
-        for (const ecf::TodayAttr& attr : todays_) {
-            comp->add(std::make_shared<NodeTodayMemento>(attr));
-        }
-        for (const ecf::TimeAttr& attr : times_) {
-            comp->add(std::make_shared<NodeTimeMemento>(attr));
-        }
-        for (const DayAttr& attr : days_) {
-            comp->add(std::make_shared<NodeDayMemento>(attr));
-        }
-        for (const DateAttr& attr : dates_) {
-            comp->add(std::make_shared<NodeDateMemento>(attr));
-        }
-        for (const CronAttr& attr : crons_) {
-            comp->add(std::make_shared<NodeCronMemento>(attr));
-        }
-
-        if (misc_attrs_) {
-            const std::vector<VerifyAttr>& verify_attrs = misc_attrs_->verifys();
-            if (!verify_attrs.empty())
-                comp->add(std::make_shared<NodeVerifyMemento>(verify_attrs));
-
-            const std::vector<ZombieAttr>& zombie_attrs = misc_attrs_->zombies();
-            for (const ZombieAttr& attr : zombie_attrs) {
-                comp->add(std::make_shared<NodeZombieMemento>(attr));
-            }
-
-            const std::vector<QueueAttr>& queue_attrs = misc_attrs_->queues();
-            for (const QueueAttr& attr : queue_attrs) {
-                comp->add(std::make_shared<NodeQueueMemento>(attr));
-            }
-
-            const std::vector<GenericAttr>& generic_attrs = misc_attrs_->generics();
-            for (const GenericAttr& attr : generic_attrs) {
-                comp->add(std::make_shared<NodeGenericMemento>(attr));
-            }
-        }
-
-        for (limit_ptr l : limits_) {
-            comp->add(std::make_shared<NodeLimitMemento>(*l));
-        }
-        for (const Variable& v : vars_) {
-            comp->add(std::make_shared<NodeVariableMemento>(v));
-        }
-
-        inLimitMgr_.get_memento(comp);
-
-        if (t_expr_)
-            comp->add(std::make_shared<NodeTriggerMemento>(*t_expr_));
-        if (c_expr_)
-            comp->add(std::make_shared<NodeCompleteMemento>(*c_expr_));
-        if (!repeat_.empty())
-            comp->add(std::make_shared<NodeRepeatMemento>(repeat_));
-        if (late_)
-            comp->add(std::make_shared<NodeLateMemento>(*late_));
-
-        changes.add(comp);
-        return;
-    }
-
-    /// *****************************************************************************************
-    /// Node attributes CHANGED
-    /// *****************************************************************************************
-
-    // ** if start to Change ZombieAttr then it needs to be added here, currently we only add/delete.
-
-    // determine if event, meter, label   changed.
-    for (const Event& e : events_) {
-        if (e.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeEventMemento>(e));
-        }
-    }
-    for (const Meter& m : meters_) {
-        if (m.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeMeterMemento>(m));
-        }
-    }
-    for (const Label& l : labels_) {
-        if (l.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeLabelMemento>(l));
-        }
-    }
-
-    // Determine if the time related dependency changed
-    for (const TodayAttr& attr : todays_) {
-        if (attr.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeTodayMemento>(attr));
-        }
-    }
-    for (const TimeAttr& attr : times_) {
-        if (attr.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeTimeMemento>(attr));
-        }
-    }
-    for (const DayAttr& attr : days_) {
-        if (attr.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeDayMemento>(attr));
-        }
-    }
-    for (const DateAttr& attr : dates_) {
-        if (attr.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeDateMemento>(attr));
-        }
-    }
-    for (const CronAttr& attr : crons_) {
-        if (attr.state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeCronMemento>(attr));
-        }
-    }
-
-    if (misc_attrs_) {
-
-        const std::vector<QueueAttr>& queue_attrs = misc_attrs_->queues();
-        for (const QueueAttr& attr : queue_attrs) {
-            if (attr.state_change_no() > client_state_change_no) {
-                if (!comp.get())
-                    comp = std::make_shared<CompoundMemento>(absNodePath());
-                comp->add(std::make_shared<NodeQueueIndexMemento>(attr.name(), attr.index(), attr.state_vec()));
-            }
-        }
-
-        // zombies have no state that changes
-        // If one verify changes then copy all. Avoids having to work out which one changed
-        const std::vector<VerifyAttr>& verify_attrs = misc_attrs_->verifys();
-        for (const VerifyAttr& v : verify_attrs) {
-            if (v.state_change_no() > client_state_change_no) {
-                if (!comp.get())
-                    comp = std::make_shared<CompoundMemento>(absNodePath());
-                comp->add(std::make_shared<NodeVerifyMemento>(verify_attrs));
-                break;
-            }
-        }
-    }
-
-    // determine if the trigger or complete changed
-    if (t_expr_ && t_expr_->state_change_no() > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<NodeTriggerMemento>(*t_expr_));
-    }
-    if (c_expr_ && c_expr_->state_change_no() > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<NodeCompleteMemento>(*c_expr_));
-    }
-
-    // determine if the repeat changed
-    if (!repeat_.empty() && repeat_.state_change_no() > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<NodeRepeatIndexMemento>(repeat_));
-    }
-
-    // determine if limits changed.
-    for (limit_ptr l : limits_) {
-        if (l->state_change_no() > client_state_change_no) {
-            if (!comp.get())
-                comp = std::make_shared<CompoundMemento>(absNodePath());
-            comp->add(std::make_shared<NodeLimitMemento>(*l));
-        }
-    }
-
-    // determine if variable values changed. Copy all variables. Save on having variable_change_no_ per variable
-    if (variable_change_no_ > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        for (const Variable& v : vars_) {
-            comp->add(std::make_shared<NodeVariableMemento>(v));
-        }
-    }
-
-    // Determine if the late attribute has changed
-    if (late_ && late_->state_change_no() > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<NodeLateMemento>(*late_));
-    }
-
-    // Determine if the flag changed
-    if (flag_.state_change_no() > client_state_change_no) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<FlagMemento>(flag_));
-    }
-
-    if (comp.get()) {
-        changes.add(comp);
-    }
-}
-
-void Node::set_memento(const NodeStateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const StateMemento* memento) " << debugNodePath() << "  "
-              << NState::toString(memento->state_) << "\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::STATE);
-    else {
-        setStateOnly(memento->state_.first);
-        st_.second = memento->state_.second;
-    }
-}
-
-void Node::set_memento(const NodeDefStatusDeltaMemento* memento,
-                       std::vector<ecf::Aspect::Type>& aspects,
-                       bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeDefStatusDeltaMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::DEFSTATUS);
-    else
-        d_st_.setState(memento->state_);
-}
-
-void Node::set_memento(const SuspendedMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const SuspendedMemento* memento) " << debugNodePath() << "\n";
-#endif
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::SUSPENDED);
-        return;
-    }
-
-    if (memento->suspended_)
-        suspend();
-    else
-        resume();
-}
-
-void Node::set_memento(const NodeEventMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeEventMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::EVENT);
-        return;
-    }
-
-    if (set_event(memento->event_.name_or_number(), memento->event_.value())) {
-        return;
-    }
-    addEvent(memento->event_);
-}
-
-void Node::set_memento(const NodeMeterMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeMeterMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::METER);
-        return;
-    }
-
-    if (set_meter(memento->meter_.name(), memento->meter_.value())) {
-        return;
-    }
-    addMeter(memento->meter_);
-}
-
-void Node::set_memento(const NodeLabelMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeLabelMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::LABEL);
-        return;
-    }
-
-    size_t theSize = labels_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (labels_[i].name() == memento->label_.name()) {
-            labels_[i] = memento->label_;
-            return;
-        }
-    }
-    addLabel(memento->label_);
-}
-
-void Node::set_memento(const NodeQueueMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-    if (aspect_only) {
-        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::QUEUE);
-        return;
-    }
-    if (misc_attrs_) {
-        misc_attrs_->set_memento(m);
-        return;
-    }
-    add_queue(m->queue_);
-}
-
-void Node::set_memento(const NodeGenericMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-    if (aspect_only) {
-        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::GENERIC);
-        return;
-    }
-    if (misc_attrs_) {
-        misc_attrs_->set_memento(m);
-        return;
-    }
-    add_generic(m->generic_);
-}
-
-void Node::set_memento(const NodeQueueIndexMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-    if (aspect_only) {
-        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::QUEUE_INDEX);
-        return;
-    }
-
-    // The queue must exist
-    if (misc_attrs_) {
-        misc_attrs_->set_memento(m);
-        return;
-    }
-}
-
-void Node::set_memento(const NodeTriggerMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeTriggerMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::EXPR_TRIGGER);
-        return;
-    }
-
-    if (t_expr_) {
-        if (memento->exp_.isFree())
-            freeTrigger();
-        else
-            clearTrigger();
-        return;
-    }
-    add_trigger_expression(memento->exp_);
-}
-
-void Node::set_memento(const NodeCompleteMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeCompleteMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::EXPR_COMPLETE);
-        return;
-    }
-
-    if (c_expr_) {
-        if (memento->exp_.isFree())
-            freeComplete();
-        else
-            clearComplete();
-        return;
-    }
-    add_complete_expression(memento->exp_);
-}
-
-void Node::set_memento(const NodeRepeatMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeRepeatMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::REPEAT);
-        return;
-    }
-
-    if (!repeat_.empty()) {
-
-        // Note: the node is incremented one past the last value.
-        // In Node, we increment() then check for validity so the_new_value may be outside the valid range.
-        // This may happen when doing an incremental sync, *hence*, allow memento to copy the value as is.
-        repeat_.set_value(memento->repeat_.index_or_value());
-
-        // Alternative, but expensive since relies on cloning and coping potentially very large vectors
-        // repeat_ = memento->repeat_;
-        return;
-    }
-
-    addRepeat(memento->repeat_);
-}
-
-void Node::set_memento(const NodeRepeatIndexMemento* memento,
-                       std::vector<ecf::Aspect::Type>& aspects,
-                       bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeRepeatIndexMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::REPEAT_INDEX);
-        return;
-    }
-
-    if (!repeat_.empty()) {
-
-        // Note: the node is incremented one past the last value.
-        // In Node we increment() then check for validity so the_new_value may be outside the valid range.
-        // This may happen when doing an incremental sync, *hence*, allow memento to copy the value as is.
-        repeat_.set_value(memento->index_or_value_);
-    }
-}
-
-void Node::set_memento(const NodeLimitMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeLimitMemento* memento) " << debugNodePath() << "  "
-              << memento->limit_.toString() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::LIMIT);
-        return;
-    }
-
-    limit_ptr limit = find_limit(memento->limit_.name());
-    if (limit.get()) {
-        limit->set_state(memento->limit_.theLimit(), memento->limit_.value(), memento->limit_.paths());
-        return;
-    }
-    addLimit(memento->limit_);
-}
-
-void Node::set_memento(const NodeInLimitMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeInLimitMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // ADD_REMOVE_ATTR aspect only, since no state
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        return;
-    }
-
-    addInLimit(memento->inlimit_);
-}
-
-void Node::set_memento(const NodeVariableMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeVariableMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    // If we have added/delete variables then ecf::Aspect::ADD_REMOVE_ATTR has already been added to aspects
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::NODE_VARIABLE);
-        return;
-    }
-
-    size_t theSize = vars_.size();
-    for (size_t i = 0; i < theSize; i++) {
-        if (vars_[i].name() == memento->var_.name()) {
-            vars_[i].set_value(memento->var_.theValue());
-            return;
-        }
-    }
-    addVariable(memento->var_);
-}
-
-void Node::set_memento(const NodeLateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeLateMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::LATE);
-        return;
-    }
-
-    if (late_) {
-        late_->setLate(memento->late_.isLate());
-        return;
-    }
-    addLate(memento->late_);
-}
-
-void Node::set_memento(const NodeTodayMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeTodayMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::TODAY);
-        return;
-    }
-
-    for (auto& today : todays_) {
-        // We need to ignore state changes in TodayAttr, (ie we don't use equality operator)
-        // otherwise today will never compare
-        if (today.structureEquals(memento->attr_)) {
-            today = memento->attr_; // need to copy over time series state
-            return;
-        }
-    }
-    addToday(memento->attr_);
-}
-
-void Node::set_memento(const NodeTimeMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeTimeMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::TIME);
-        return;
-    }
-
-    for (auto& time : times_) {
-        // We need to ignore state changes in TimeAttr, (ie we don't use equality operator)
-        // otherwise time will never compare
-        if (time.structureEquals(memento->attr_)) {
-            time = memento->attr_; // need to copy over time series state
-            return;
-        }
-    }
-    addTime(memento->attr_);
-}
-
-void Node::set_memento(const NodeDayMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeDayMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::DAY);
-        return;
-    }
-
-    for (auto& day : days_) {
-        // We need to ignore state changes (ie we don't use equality operator)
-        // otherwise attributes will never compare
-        if (day.structureEquals(memento->attr_)) {
-            day = memento->attr_;
-            return;
-        }
-    }
-    addDay(memento->attr_);
-}
-
-void Node::set_memento(const NodeDateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeDateMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::DATE);
-        return;
-    }
-
-    for (auto& date : dates_) {
-        // We need to ignore state changes (ie we don't use equality operator)
-        // otherwise attributes will never compare
-        if (date.structureEquals(memento->attr_)) {
-            if (memento->attr_.isSetFree())
-                date.setFree();
-            else
-                date.clearFree();
-            return;
-        }
-    }
-    addDate(memento->attr_);
-}
-
-void Node::set_memento(const NodeCronMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeCronMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        aspects.push_back(ecf::Aspect::CRON);
-        return;
-    }
-
-    for (auto& cron : crons_) {
-        // We need to ignore state changes (ie we don't use equality operator)
-        // otherwise attributes will never compare
-        if (cron.structureEquals(memento->attr_)) {
-            cron = memento->attr_; // need to copy over time series state
-            return;
-        }
-    }
-    addCron(memento->attr_);
-}
-
-void Node::set_memento(const FlagMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const FlagMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::FLAG);
-    else
-        flag_.set_flag(memento->flag_.flag());
-}
-
-void Node::set_memento(const NodeZombieMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeZombieMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        // No state, only ADD_REMOVE_ATTR aspect
-        return;
-    }
-
-    // Zombie attributes should always be via ADD_REMOVE_ATTR
-    // See Node::incremental_changes
-    // Since there is no state to change
-
-    /// remove existing attribute of same type, as duplicate of same type not allowed
-    delete_zombie(memento->attr_.zombie_type());
-    addZombie(memento->attr_);
-}
-
-void Node::set_memento(const NodeVerifyMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Node::set_memento(const NodeVerifyMemento* memento) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
-        return;
-    }
-
-    if (misc_attrs_) {
-        misc_attrs_->verifys_.clear();
-        misc_attrs_->verifys_ = memento->verifys_;
-        return;
-    }
-
-    misc_attrs_           = std::make_unique<MiscAttrs>(this);
-    misc_attrs_->verifys_ = memento->verifys_;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeState.hpp 5.13.0-1/ANode/src/ecflow/node/NodeState.hpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeState.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeState.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_NodeState_HPP
-#define ecflow_node_NodeState_HPP
-
-#include "ecflow/core/NState.hpp"
-
-///
-/// \brief Given a set of nodes, theComputedNodeState returns the most significant state
-/// Depend on the Node::computedState, hence include after Node.hpp
-/// This will recurse down ****
-///
-
-namespace ecf {
-
-template <class T>
-NState::State theComputedNodeState(const std::vector<T>& nodeVec, bool immediate) {
-    // std::cout << "theComputedNodeState vec size = " << nodeVec.size() << " immediate  = " <<  immediate << "\n";
-    int completeCount  = 0;
-    int queuedCount    = 0;
-    int submittedCount = 0;
-    int activeCount    = 0;
-    int abortedCount   = 0;
-
-    // We don't know the order, hence we must collate first
-    size_t theVecSize = nodeVec.size();
-    for (size_t n = 0; n < theVecSize; n++) {
-        NState::State theState;
-        if (immediate)
-            theState = nodeVec[n]->state();
-        else
-            theState = nodeVec[n]->computedState(Node::HIERARCHICAL);
-
-        // std::cout << "the computed state for " << nodeVec[n]->debugNodePath() << " is " << NState::toString(theState)
-        // << "\n";
-
-        switch (theState) {
-            case NState::ABORTED:
-                abortedCount++;
-                break;
-            case NState::ACTIVE:
-                activeCount++;
-                break;
-            case NState::SUBMITTED:
-                submittedCount++;
-                break;
-            case NState::QUEUED:
-                queuedCount++;
-                break;
-            case NState::COMPLETE:
-                completeCount++;
-                break;
-            case NState::UNKNOWN:
-                // Does nothing...
-                break;
-            default:
-                assert(false);
-                break;
-        }
-    }
-    if (abortedCount > 0)
-        return NState::ABORTED;
-    if (activeCount > 0)
-        return NState::ACTIVE;
-    if (submittedCount > 0)
-        return NState::SUBMITTED;
-    if (queuedCount > 0)
-        return NState::QUEUED;
-    if (completeCount > 0)
-        return NState::COMPLETE;
-    return NState::UNKNOWN;
-}
-
-} // namespace ecf
-
-#endif /* ecflow_node_NodeState_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeStats.cpp 5.13.0-1/ANode/src/ecflow/node/NodeStats.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeStats.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeStats.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/NodeStats.hpp"
-
-#include <sstream>
-using namespace std;
-
-std::string NodeStats::print() const {
-    stringstream ss;
-    ss << "Definition statistics\n";
-    ss << "Nodes               " << nodes_ << "\n";
-    ss << "Suites              " << suites_ << "\n";
-    ss << "Family              " << family_ << "\n";
-    ss << "Task                " << task_ << "\n";
-    ss << "Alias               " << alias_ << "\n\n";
-    if (suites_ + family_ + task_ + alias_ != nodes_)
-        ss << "suites_ + family_ +  task_ + alias_ != nodes_ ?\n";
-
-    ss << "Edit history nodes  " << edit_history_nodes_ << "\n";
-    ss << "Edit history paths  " << edit_history_paths_ << "\n\n";
-
-    ss << "vars                " << vars_ << "\n";
-    ss << "triggers            " << trigger_ << "\n";
-    ss << "complete triggers   " << c_trigger_ << "\n";
-    ss << "events              " << events_ << "\n";
-    ss << "labels              " << labels_ << "\n";
-    ss << "meters              " << meters_ << "\n\n";
-
-    ss << "times               " << times_ << "\n";
-    ss << "todays              " << todays_ << "\n";
-    ss << "crons               " << crons_ << "\n";
-    ss << "dates               " << dates_ << "\n";
-    ss << "days                " << days_ << "\n\n";
-
-    ss << "late                " << late_ << "\n";
-    ss << "inlimits            " << inlimits_ << "\n";
-    ss << "limits              " << limits_ << "\n";
-    ss << "repeats             " << repeats_ << "\n";
-    ss << "zombies             " << zombies_ << "\n\n";
-
-    ss << "auto_cancel         " << auto_cancel_ << "\n";
-    ss << "auto_archive        " << auto_archive_ << "\n";
-    ss << "auto_restore        " << auto_restore_ << "\n";
-    ss << "verifys             " << verifys_ << "\n";
-    ss << "queues              " << queues_ << "\n";
-    ss << "generics            " << generics_ << "\n";
-    return ss.str();
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeStats.hpp 5.13.0-1/ANode/src/ecflow/node/NodeStats.hpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeStats.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeStats.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_NodeStats_HPP
-#define ecflow_node_NodeStats_HPP
-
-#include <string>
-
-struct NodeStats
-{
-    NodeStats() = default;
-
-    std::string print() const;
-
-    size_t suites_{0};
-    size_t family_{0};
-    size_t task_{0};
-    size_t alias_{0};
-    size_t nodes_{0};
-
-    size_t edit_history_nodes_{0};
-    size_t edit_history_paths_{0};
-
-    size_t vars_{0};
-    size_t c_trigger_{0};
-    size_t trigger_{0};
-    size_t meters_{0};
-    size_t events_{0};
-    size_t labels_{0};
-
-    size_t times_{0};
-    size_t todays_{0};
-    size_t crons_{0};
-    size_t dates_{0};
-    size_t days_{0};
-
-    size_t late_{0};
-    size_t zombies_{0};
-    size_t verifys_{0};
-    size_t queues_{0};
-    size_t generics_{0};
-
-    size_t repeats_{0};
-    size_t limits_{0};
-    size_t inlimits_{0};
-
-    size_t auto_cancel_{0};
-    size_t auto_archive_{0};
-    size_t auto_restore_{0};
-};
-
-#endif /* ecflow_node_NodeStats_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeTime.cpp 5.13.0-1/ANode/src/ecflow/node/NodeTime.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeTime.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeTime.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,890 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/CmdContext.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-// #define DEBUG_DAY 1
-
-///////////////////////////////////////////////////////////////////////////////////////////
-
-void Node::do_requeue_time_attrs(bool reset_next_time_slot, bool reset_relative_duration, Requeue_args::Requeue_t rt) {
-    // must be done before the re-queue
-    if (reset_relative_duration) {
-        for (auto& cron : crons_) {
-            cron.resetRelativeDuration();
-        }
-        for (auto& today : todays_) {
-            today.resetRelativeDuration();
-        }
-        for (auto& time : times_) {
-            time.resetRelativeDuration();
-        }
-    }
-
-    /// If a job takes longer than it slots, then that slot is missed, and next slot is used
-    /// Note we do *NOT* reset for requeue as we want to advance to the next time slot
-    /// *NOTE* Update calendar will *free* time dependencies *even* time series. They rely
-    /// on this function to clear the time dependencies so they *HOLD* the task.
-    const Calendar& calendar = suite()->calendar();
-    for (auto& today : todays_) {
-        today.requeue(calendar, reset_next_time_slot);
-    }
-    for (auto& time : times_) {
-        time.requeue(calendar, reset_next_time_slot);
-    }
-    for (auto& cron : crons_) {
-        cron.requeue(calendar, reset_next_time_slot);
-    }
-
-    for (auto& date : dates_) {
-        date.requeue();
-    } // make sure only run once
-
-    if (!days_.empty()) {
-        // The day attribute, is matched with the corresponding *date* under requeue.
-        // HOWEVER, when re-queueing due to a *TIME* dependency we MUST keep the current date on the day attribute
-        // ADDITIONALLY WE use expired_ to remove days which have *EXPIRED* (i.e. failed for check for re-queue), thus
-        // avoiding is_free() OTHERWISE when we have multiple days, even the days which have expired are considered for
-        // running the task.
-        switch (rt) {
-            case Requeue_args::FULL: {
-#ifdef DEBUG_DAY
-                cout << " Node::do_requeue_time_attrs  Requeue_args::FULL \n";
-#endif
-                for (auto& day : days_) {
-                    day.requeue_manual(calendar);
-                }
-                break;
-            }
-            case Requeue_args::REPEAT_INCREMENT: {
-#ifdef DEBUG_DAY
-                cout << " Node::do_requeue_time_attrs  Requeue_args::REPEAT_INCREMENT \n";
-#endif
-                for (auto& day : days_) {
-                    day.requeue_repeat_increment(calendar);
-                }
-                break;
-            }
-            case Requeue_args::TIME: {
-#ifdef DEBUG_DAY
-                cout << " Node::do_requeue_time_attrs  Requeue_args::TIME \n";
-#endif
-                for (auto& day : days_) {
-                    day.requeue_time();
-                }
-                break;
-            }
-        }
-    }
-}
-
-bool Node::calendar_changed_timeattrs(const ecf::Calendar& c, Node::Calendar_args& cal_args) {
-#ifdef DEBUG_DAY
-    cout << "Node::calendar_changed_timeattrs " << debugNodePath() << " " << c.suite_time_str() << "\n";
-#endif
-
-    // For time/today/cron attributes if the time is free, it *remains* free until re-queued
-    // However if we have day/date dependencies, that do NOT match, then we should *NOT* free
-    // any time/today/cron attributes.
-    //
-    //   task t
-    //     day Monday   # this will guard the time.
-    //     time 10:00
-    //
-    // Hence if we are on Sunday we do *NOT* want to free the time on SUNDAY
-    // (Otherwise we will end up running the task at Monday Midnight
-    //  and not Monday at 10.00)
-    //
-    // Likewise:
-    //   family f1
-    //     day monday     # this will guard the time(this is different to ecflow 4.0) holding_parent_day_or_date_
-    //     task t
-    //       time 10:00
-    //
-    //   family f1
-    //      time 10:00    # time will be set down at 10.00 am
-    //      task t
-    //        day monday  # Job will run at Monday morning *AND* at 10:00
-
-    // cout << "Node::calendar_changed_timeattrs " << c.toString() << "\n";
-    //   std::vector<node_ptr> all_children1;
-    //   allChildren(all_children1);
-    //   for(size_t t = 0; t <  all_children1.size(); t++) {
-    //       cout << "   " << all_children1[t]->debugNodePath() << " " << NState::toString(all_children1[t]->state()) <<
-    //       "\n";
-    //   }
-    //   AstTop* ast = triggerAst();
-    //   if (ast) {
-    //      ast->print(cout);
-    //      cout << "\n";
-    //   }
-
-    if (days_.empty() && dates_.empty()) {
-
-        // No Day or Date, If time matches  calendarChanged(c) will free time dependencies
-        for (auto& time : times_) {
-            time.calendarChanged(c);
-        }
-        for (auto& today : todays_) {
-            today.calendarChanged(c);
-        }
-        for (auto& cron : crons_) {
-            cron.calendarChanged(c);
-        }
-    }
-    else {
-
-        // If *BEFORE* midnight we have FREE day/date and submitted or active jobs, don't clear the day/dates
-        // i.e. take:
-        //    family f1
-        //       day monday
-        //       time 23:00
-        //       task t1  # This took longer than 1 hour
-        //       task t2  # allow task to continue to the next day
-        //         trigger t1 == complete
-        // This is only applicable for NodeContainers, for task with day/date always CLEAR at midnight
-        // ECFLOW-337 versus ECFLOW-1550
-
-        bool clear_day_at_midnight  = true;
-        bool clear_date_at_midnight = true;
-        if (c.dayChanged() && isNodeContainer()) {
-
-#ifdef DEBUG_DAY
-            cout << "  Node::calendar_changed_timeattrs DAY CHANGED " << debugNodePath() << " " << c.suite_time_str()
-                 << "\n";
-#endif
-            // Check if day/date are free *BEFORE* midnight and *BEFORE* calendarChanged called(since that clears
-            // Day::makeFree_) The isFree below relies on Day::makeFree_/Date:makeFree_ not being cleared till after
-            // midnight
-            bool free_date = false;
-            bool free_day  = false;
-            for (const auto& date : dates_) {
-                if (date.isFree(c)) {
-                    free_date = true;
-                    break;
-                }
-            }
-            for (const auto& day : days_) {
-                if (day.isFree(c)) {
-                    free_day = true;
-                    break;
-                }
-            }
-
-#ifdef DEBUG_DAY
-            cout << "  Node::calendar_changed_timeattrs free_day " << free_day << " free_date " << free_date << "\n";
-#endif
-            if (free_date || free_day) {
-                // See if we have any complete submitted or active children,
-                // if so DON'T clear day/date at midnight. hence day/date will *STAY* *FREE*
-                // Allow following tasks to complete
-                std::vector<node_ptr> all_children;
-                allChildren(all_children);
-                int completed = 0;
-                int submitted = 0;
-                int queued    = 0;
-                int active    = 0;
-                for (auto& t : all_children) {
-                    // cout << all_children[t]->debugNodePath() << " " << NState::toString(all_children[t]->state()) <<
-                    // "\n";
-                    if (t->isTask()) {
-                        if (t->state() == NState::SUBMITTED)
-                            submitted++;
-                        else if (t->state() == NState::ACTIVE)
-                            active++;
-                        else if (t->state() == NState::COMPLETE)
-                            completed++;
-                        else if (t->state() == NState::QUEUED)
-                            queued++;
-                        if (active || submitted) {
-                            if (free_date)
-                                clear_date_at_midnight = false;
-                            if (free_day)
-                                clear_day_at_midnight = false;
-#ifdef DEBUG_DAY
-                            cout << "  if (active || submitted ) clear_day_date_at_midnight = false\n";
-#endif
-                            break;
-                        }
-                        if (completed && (active || submitted || queued)) {
-                            if (free_date)
-                                clear_date_at_midnight = false;
-                            if (free_day)
-                                clear_day_at_midnight = false;
-#ifdef DEBUG_DAY
-                            cout << "  if (completed && (active || submitted || queued)) clear_day_date_at_midnight = "
-                                    "false\n";
-#endif
-                            break;
-                        }
-                    }
-                }
-            }
-        }
-
-        bool at_least_one_day_free = false;
-        for (auto& day : days_) {
-            day.calendarChanged(c, clear_day_at_midnight);
-            if (!at_least_one_day_free)
-                at_least_one_day_free = day.isFree(c);
-        }
-
-        bool at_least_one_date_free = false;
-        for (auto& date : dates_) {
-            date.calendarChanged(c, clear_date_at_midnight);
-            if (!at_least_one_date_free)
-                at_least_one_date_free = date.isFree(c);
-        }
-
-        if (at_least_one_day_free || at_least_one_date_free) {
-            for (auto& time : times_) {
-                time.calendarChanged(c);
-            }
-            for (auto& today : todays_) {
-                today.calendarChanged(c);
-            }
-            for (auto& cron : crons_) {
-                cron.calendarChanged(c);
-            }
-        }
-        else {
-            // Node has *HOLDING* day or date dependency. Avoid free time dependencies of *ANY* child nodes
-#ifdef DEBUG_DAY
-            cout << "Node::calendar_changed_timeattrs " << debugNodePath()
-                 << " SETTING holding_parent_day_or_date_  at " << c.suite_time_str() << "\n";
-#endif
-            return true;
-        }
-    }
-    return false;
-}
-
-void Node::markHybridTimeDependentsAsComplete() {
-    // If hybrid clock, then we may have day/date/cron time dependencies
-    // which mean that node will be stuck in the QUEUED state, i.e. since the
-    // date/day does not change with the hybrid clock.
-    // hence Mark these Nodes as complete
-    const Calendar& calendar = suite()->calendar();
-    if (state() != NState::COMPLETE && calendar.hybrid()) {
-        if (!dates_.empty() || !days_.empty() || !crons_.empty()) {
-
-            int noOfTimeDependencies = 0;
-            if (!dates_.empty())
-                noOfTimeDependencies++;
-            if (!days_.empty())
-                noOfTimeDependencies++;
-            if (!crons_.empty())
-                noOfTimeDependencies++;
-
-            bool oneDateIsFree = false;
-            bool oneDayIsFree  = false;
-            bool oneCronIsFree = false;
-
-            for (auto& date : dates_) {
-                if (date.validForHybrid(calendar)) {
-                    if (noOfTimeDependencies == 1) {
-                        setStateOnly(NState::QUEUED);
-                        return;
-                    }
-                    oneDateIsFree = true;
-                    break;
-                }
-            }
-            for (auto& day : days_) {
-                if (day.validForHybrid(calendar)) {
-                    if (noOfTimeDependencies == 1) {
-                        setStateOnly(NState::QUEUED);
-                        return;
-                    }
-                    oneDayIsFree = true;
-                    break;
-                }
-            }
-            for (auto& cron : crons_) {
-                if (cron.validForHybrid(calendar)) {
-                    if (noOfTimeDependencies == 1) {
-                        setStateOnly(NState::QUEUED);
-                        return;
-                    }
-                    oneCronIsFree = true;
-                    break;
-                }
-            }
-
-            if (oneDateIsFree || oneDayIsFree || oneCronIsFree) {
-                if (noOfTimeDependencies > 1) {
-                    // when we have multiple time dependencies their results *MUST* be added for the node to be free.
-                    if (!dates_.empty() && !oneDateIsFree) {
-                        setStateOnly(NState::COMPLETE);
-                        return;
-                    }
-                    if (!days_.empty() && !oneDayIsFree) {
-                        setStateOnly(NState::COMPLETE);
-                        return;
-                    }
-                    if (!crons_.empty() && !oneCronIsFree) {
-                        setStateOnly(NState::COMPLETE);
-                        return;
-                    }
-
-                    // We will only get here, if we have a multiple time dependencies any there is one free in each
-                    // category
-                    setStateOnly(NState::QUEUED);
-                    return;
-                }
-            }
-
-            setStateOnly(NState::COMPLETE);
-        }
-    }
-}
-
-// #define DEBUG_REQUEUE 1
-// #include "ecflow/core/Log.hpp"
-bool Node::testTimeDependenciesForRequeue() {
-    // This function is called as a part of handling state change.
-    // We only get here if the Node has *COMPLETED* ( either automatically, or manually i.e. force complete)
-    // We are now determining if the node should be re-queued due to time dependency in the *FUTURE*
-    const Calendar& calendar = suite()->calendar();
-
-#ifdef DEBUG_REQUEUE
-    LogToCout logtocout;
-    LOG(Log::DBG, "Node::testTimeDependenciesForRequeue() " << debugNodePath() << " calendar " << calendar.toString());
-#endif
-
-    // When we have a mixture of cron *with* other time based attributes
-    // The cron *takes* priority.  Crons should always return true, for checkForRequeue
-    for (const CronAttr& cron : crons_) {
-        if (cron.checkForRequeue(calendar)) { // will always return true
-#ifdef DEBUG_REQUEUE
-            LOG(Log::DBG,
-                "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for cron -> allow-requeue");
-#endif
-            return true;
-        }
-    }
-
-    // When in a CmdContext. If we are *BEFORE* the scheduled time, then *ALLOW* re-queue
-    bool cmd_context = CmdContext::in_command();
-    if (!times_.empty()) {
-        TimeSlot the_min, the_max; // Needs to handle multiple single slot time attributes
-        for (const ecf::TimeAttr& time : times_) {
-            time.min_max_time_slots(the_min, the_max);
-        }
-        for (const ecf::TimeAttr& time : times_) {
-            if (time.checkForRequeue(calendar, the_min, the_max, cmd_context)) {
-#ifdef DEBUG_REQUEUE
-                LOG(Log::DBG,
-                    "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for " << time.toString()
-                                                                 << " -> allow-requeue");
-#endif
-                return true;
-            }
-        }
-    }
-
-    if (!todays_.empty()) {
-        TimeSlot the_min, the_max; // Needs to handle multiple single slot today attributes
-        for (const ecf::TodayAttr& today : todays_) {
-            today.min_max_time_slots(the_min, the_max);
-        }
-        for (const ecf::TodayAttr& today : todays_) {
-            if (today.checkForRequeue(calendar, the_min, the_max, cmd_context)) {
-#ifdef DEBUG_REQUEUE
-                LOG(Log::DBG,
-                    "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for " << today.toString()
-                                                                 << " -> allow-requeue");
-#endif
-                return true;
-                ;
-            }
-        }
-    }
-
-    // **********************************************************************
-    // If we get here there are **NO** time/today/cron dependencies which are free
-    // We now need to determine if this node has a *FUTURE* time dependency which
-    // should re-queue this node.
-    // *********************************************************************
-    for (const DateAttr& date : dates_) {
-        if (date.checkForRequeue(calendar)) {
-#ifdef DEBUG_REQUEUE
-            LOG(Log::DBG,
-                "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for " << date.toString()
-                                                             << " -> allow-requeue");
-#endif
-            return true;
-        }
-    }
-
-    for (DayAttr& day : days_) {
-        if (cmd_context) {
-            // In the command context,i.e. force complete or task runs and completes, then expire the day.
-            // *EVEN* if the day is in the future: why?: The user has taken control, *TYPICALLY* the day is under
-            // a repeat, by expiring, we allow the repeat to increment
-            //       before *only* if the day matched under the command context, we got this behaviour. i.e. with
-            //       check_for_expiration
-            day.set_expired();
-        }
-        else {
-            // If any day matches calendar day or is in the past, then expire it, so we don't run again on that day.
-            // Must be done BEFORE checkForRequeue
-            //   task t1
-            //      time 09:00    # time attribute get considered before day/date, allowing multiple re-queues on the
-            //      same day time 10:00    # day saturday  # After time expiration, day must be expired day sunday
-            day.check_for_expiration(calendar);
-        }
-    }
-    for (const DayAttr& day : days_) {
-        if (day.checkForRequeue(calendar)) {
-#ifdef DEBUG_REQUEUE
-            LOG(Log::DBG,
-                "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for days  -> allow-requeue");
-#endif
-            return true;
-        }
-    }
-
-#ifdef DEBUG_REQUEUE
-    LOG(Log::DBG, "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " HOLDING");
-#endif
-    return false;
-}
-
-void Node::miss_next_time_slot() {
-    // Why do we need to set NO_REQUE_IF_SINGLE_TIME_DEP flag ?
-    // This is required when we have time based attributes, which we want to miss.
-    //    time 10:00
-    //    time 12:00
-    // Essentially this avoids an automated job run, *IF* the job was run manually for a given time slot.
-    // If we call this function before 10:00, we want to miss the next time slot (i.e. 10:00)
-    // and want to *requeue*, for 12:00 time slot. However, at re-queue, we need to ensure
-    // we do *not* reset the 10:00 time slot. hence by setting NO_REQUE_IF_SINGLE_TIME_DEP
-    // we allow requeue to query this flag, and hence avoid resetting the time based attribute
-    // Note: requeue will *always* clear NO_REQUE_IF_SINGLE_TIME_DEP afterward.
-    //
-    // In the case above when we reach the last time slot, there is *NO* automatic requeue, and
-    // hence, *no* clearing of NO_REQUE_IF_SINGLE_TIME_DEP flag.
-    // This will then be up to any top level parent that has a Repeat/cron to force a requeue
-    // when all the children are complete. *or* user does a manual re-queue
-    //
-    // Additionally if the job *aborts*, we clear NO_REQUE_IF_SINGLE_TIME_DEP if it was set.
-    // Otherwise, if manually run again, we will miss further time slots.
-    if (has_time_dependencies()) {
-
-        /// Handle abort
-        /// The flag: NO_REQUE_IF_SINGLE_TIME_DEP is *only* set when doing an interactive force complete or run command.
-        /// What happens if the job aborts during the run command ?
-        ///     time 10:00
-        ///     time 11:00
-        /// If at 9.00am we used the run command, we want to miss the 10:00 time slot.
-        /// However if the run at 9.00 fails, and we run again, we also miss 11:00 time slot.
-        /// During the run the flag is still set.
-        /// Hence *ONLY* miss the next time slot *IF* Flag::NO_REQUE_IF_SINGLE_TIME_DEP is NOT set
-        if (!flag().is_set(Flag::NO_REQUE_IF_SINGLE_TIME_DEP)) {
-
-            SuiteChanged0 changed(shared_from_this());
-            flag().set(Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
-
-            // Note: when we have multiple time dependencies.
-            // We need find valid next time dependency:
-            //   time 10:00
-            //   time 11:00
-            //   time 12:00 14:00 00:30
-            // Also we could have a mix:
-            //   time  10:00
-            //   today 10:30
-            //   time 11:00
-            //   time 12:00 14:00 00:30
-
-            // for the moment assume, they have been added sequentially,
-            // hence only first non expired time is updated to miss next time slot
-            for (auto& time : times_) {
-                if (time.time_series().is_valid()) {
-                    time.miss_next_time_slot();
-                    break;
-                }
-            }
-            for (auto& today : todays_) {
-                if (today.time_series().is_valid()) {
-                    today.miss_next_time_slot();
-                    break;
-                }
-            }
-            for (auto& cron : crons_) {
-                if (cron.time_series().is_valid()) {
-                    cron.miss_next_time_slot();
-                    break;
-                }
-            }
-        }
-    }
-}
-
-void Node::freeHoldingDateDependencies() {
-    // Multiple time dependencies of the same type are *ORed*
-    // Multiple time dependencies of different types are *ANDed*
-    //
-    // Hence since we have multiple time dependencies of the same
-    // type here, we need free only one of them
-    const Calendar& calendar = suite()->calendar();
-    for (auto& date : dates_) {
-        if (!date.isFree(calendar)) {
-            date.setFree();
-            break;
-        }
-    }
-}
-
-void Node::freeHoldingTimeDependencies() {
-    // Multiple time dependencies of the same type are *ORed*
-    // Multiple time dependencies of different types are *ANDed*
-    //
-    // If we have multiple time dependencies of different types
-    // we need only free one in each category
-    const Calendar& calendar = suite()->calendar();
-    for (auto& time : times_) {
-        if (!time.isFree(calendar)) {
-            time.setFree();
-            time.miss_next_time_slot();
-            break;
-        }
-    }
-    for (auto& today : todays_) {
-        if (!today.isFree(calendar)) {
-            today.setFree();
-            today.miss_next_time_slot();
-            break;
-        }
-    }
-    for (auto& day : days_) {
-        if (!day.isFree(calendar)) {
-            day.setFree();
-            break;
-        }
-    }
-    for (auto& cron : crons_) {
-        if (!cron.isFree(calendar)) {
-            cron.setFree();
-            cron.miss_next_time_slot();
-            break;
-        }
-    }
-}
-
-bool Node::has_time_dependencies() const {
-    if (!times_.empty())
-        return true;
-    if (!todays_.empty())
-        return true;
-    if (!crons_.empty())
-        return true;
-    if (!dates_.empty())
-        return true;
-    if (!days_.empty())
-        return true;
-    return false;
-}
-
-bool Node::holding_day_or_date(const ecf::Calendar& c) const {
-    if (days_.empty() && dates_.empty())
-        return false;
-
-    bool at_least_one_day_free = false;
-    for (auto& day : days_) {
-        if (!at_least_one_day_free)
-            at_least_one_day_free = day.isFree(c);
-    }
-
-    bool at_least_one_date_free = false;
-    for (auto& date : dates_) {
-        if (!at_least_one_date_free)
-            at_least_one_date_free = date.isFree(c);
-    }
-
-    if (at_least_one_day_free || at_least_one_date_free) {
-        return false;
-    }
-    return true;
-}
-
-bool Node::timeDependenciesFree() const {
-    int noOfTimeDependencies = 0;
-    if (!times_.empty())
-        noOfTimeDependencies++;
-    if (!todays_.empty())
-        noOfTimeDependencies++;
-    if (!dates_.empty())
-        noOfTimeDependencies++;
-    if (!days_.empty())
-        noOfTimeDependencies++;
-    if (!crons_.empty())
-        noOfTimeDependencies++;
-
-    // if no time dependencies we are free
-    if (noOfTimeDependencies == 0)
-        return true;
-
-    // if we have a holding day/date don't consider other time attributes
-    const Calendar& calendar = suite()->calendar();
-    if (holding_day_or_date(calendar)) {
-        return false;
-    }
-
-    bool oneDateIsFree  = false;
-    bool oneDayIsFree   = false;
-    bool oneTodayIsFree = false;
-    bool oneTimeIsFree  = false;
-    bool oneCronIsFree  = false;
-
-    for (const auto& time : times_) {
-        if (time.isFree(calendar)) {
-            if (noOfTimeDependencies == 1)
-                return true;
-            oneTimeIsFree = true;
-            break;
-        }
-    }
-    for (const auto& cron : crons_) {
-        if (cron.isFree(calendar)) {
-            if (noOfTimeDependencies == 1)
-                return true;
-            oneCronIsFree = true;
-            break;
-        }
-    }
-    for (const auto& date : dates_) {
-        if (date.isFree(calendar)) {
-            if (noOfTimeDependencies == 1)
-                return true;
-            oneDateIsFree = true;
-            break;
-        }
-    }
-    for (const auto& day : days_) {
-        if (day.isFree(calendar)) {
-            if (noOfTimeDependencies == 1)
-                return true;
-            oneDayIsFree = true;
-            break;
-        }
-    }
-
-    if (!todays_.empty()) {
-        // : single Today: (single-time)    is free, if calendar time >= today_time
-        // : single Today: (range)          is free, if calendar time == (one of the time ranges)
-        // : multi Today : (single | range) is free, if calendar time == (one of the time ranges | today_time)
-        // : multi Today : (single | range) is free, all are free
-        if (todays_.size() == 1) {
-            // Single Today Attribute: could be single slot or range
-            if (todays_[0].isFree(calendar)) {
-                if (noOfTimeDependencies == 1)
-                    return true;
-                oneTodayIsFree = true;
-            }
-        }
-        else {
-            // Multiple Today Attributes, each could single, or range
-            size_t free_count = 0;
-            for (const auto& today : todays_) {
-                if (today.isFreeMultipleContext(calendar)) {
-                    if (noOfTimeDependencies == 1)
-                        return true;
-                    oneTodayIsFree = true;
-                    break;
-                }
-                if (today.isFree(calendar))
-                    free_count++;
-            }
-            if (free_count == todays_.size()) {
-                if (noOfTimeDependencies == 1)
-                    return true;
-                oneTodayIsFree = true;
-            }
-        }
-    }
-
-    if (oneDateIsFree || oneDayIsFree || oneTodayIsFree || oneTimeIsFree || oneCronIsFree) {
-        if (noOfTimeDependencies > 1) {
-            // *When* we have multiple time dependencies of *different types* then the results
-            // *MUST* be added for the node to be free.
-            if (!dates_.empty() && !oneDateIsFree)
-                return false;
-            if (!days_.empty() && !oneDayIsFree)
-                return false;
-            if (!todays_.empty() && !oneTodayIsFree)
-                return false;
-            if (!times_.empty() && !oneTimeIsFree)
-                return false;
-            if (!crons_.empty() && !oneCronIsFree)
-                return false;
-
-            // We will only get here, if we have a multiple time dependencies and they are free
-            return true;
-        }
-    }
-
-    return false;
-}
-
-bool Node::time_today_cron_is_free() const {
-    if (!times_.empty() || !todays_.empty() || !crons_.empty()) {
-
-        int noOfTimeDependencies = 0;
-        if (!times_.empty())
-            noOfTimeDependencies++;
-        if (!todays_.empty())
-            noOfTimeDependencies++;
-        if (!crons_.empty())
-            noOfTimeDependencies++;
-
-        bool oneTodayIsFree = false;
-        bool oneTimeIsFree  = false;
-        bool oneCronIsFree  = false;
-
-        const Calendar& calendar = suite()->calendar();
-        for (const auto& time : times_) {
-            if (time.isFree(calendar)) {
-                if (noOfTimeDependencies == 1)
-                    return true;
-                oneTimeIsFree = true;
-                break;
-            }
-        }
-        for (const auto& cron : crons_) {
-            if (cron.isFree(calendar)) {
-                if (noOfTimeDependencies == 1)
-                    return true;
-                oneCronIsFree = true;
-                break;
-            }
-        }
-
-        if (!todays_.empty()) {
-            // : single Today: (single-time)   is free, if calendar time >= today_time
-            // : single Today: (range)         is free, if calendar time == (one of the time ranges)
-            // : multi Today : (single | range)is free, if calendar time == (one of the time ranges | today_time)
-            if (todays_.size() == 1) {
-                // Single Today Attribute: could be single slot or range
-                if (todays_[0].isFree(calendar)) {
-                    if (noOfTimeDependencies == 1)
-                        return true;
-                    oneTodayIsFree = true;
-                }
-            }
-            else {
-                // Multiple Today Attributes, each could single, or range
-                for (const auto& today : todays_) {
-                    if (today.isFreeMultipleContext(calendar)) {
-                        if (noOfTimeDependencies == 1)
-                            return true;
-                        oneTodayIsFree = true;
-                        break;
-                    }
-                }
-            }
-        }
-
-        if (oneTodayIsFree || oneTimeIsFree || oneCronIsFree) {
-            if (noOfTimeDependencies > 1) {
-                // *When* we have multiple time dependencies of *different types* then the results
-                // *MUST* be added for the node to be free.
-                if (!todays_.empty() && !oneTodayIsFree)
-                    return false;
-                if (!times_.empty() && !oneTimeIsFree)
-                    return false;
-                if (!crons_.empty() && !oneCronIsFree)
-                    return false;
-
-                // We will only get here, if we have a multiple time dependencies and they are free
-                return true;
-            }
-        }
-    }
-
-    return false;
-}
-
-void Node::get_time_resolution_for_simulation(boost::posix_time::time_duration& resol) const {
-    for (const auto& time : times_) {
-        const TimeSeries& time_series = time.time_series();
-        if (time_series.start().minute() != 0) {
-            resol = minutes(1);
-            return;
-        }
-        if (time_series.hasIncrement()) {
-            if (time_series.finish().minute() != 0) {
-                resol = minutes(1);
-                return;
-            }
-            if (time_series.incr().minute() != 0) {
-                resol = minutes(1);
-                return;
-            }
-        }
-    }
-
-    for (const auto& today : todays_) {
-        const TimeSeries& time_series = today.time_series();
-        if (time_series.start().minute() != 0) {
-            resol = minutes(1);
-            return;
-        }
-        if (time_series.hasIncrement()) {
-            if (time_series.finish().minute() != 0) {
-                resol = minutes(1);
-                return;
-            }
-            if (time_series.incr().minute() != 0) {
-                resol = minutes(1);
-                return;
-            }
-        }
-    }
-
-    for (const auto& cron : crons_) {
-        const TimeSeries& time_series = cron.time_series();
-        if (time_series.start().minute() != 0) {
-            resol = minutes(1);
-            return;
-        }
-        if (time_series.hasIncrement()) {
-            if (time_series.finish().minute() != 0) {
-                resol = minutes(1);
-                return;
-            }
-            if (time_series.incr().minute() != 0) {
-                resol = minutes(1);
-                return;
-            }
-        }
-    }
-}
-
-void Node::get_max_simulation_duration(boost::posix_time::time_duration& duration) const {
-    // don't override a higher value of duration
-    if ((!times_.empty() || !todays_.empty()) && duration < hours(24))
-        duration = hours(24); // day
-    if (!days_.empty() && duration < hours(168))
-        duration = hours(168); // week
-    if (!dates_.empty() && duration < hours(24 * 7 * 31))
-        duration = hours(24 * 7 * 31); // month
-    if (!crons_.empty())
-        duration = hours(8760); // year
-    if (!repeat_.empty())
-        duration = hours(8760); // year
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeTreeVisitor.cpp 5.13.0-1/ANode/src/ecflow/node/NodeTreeVisitor.cpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeTreeVisitor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeTreeVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/NodeTreeVisitor.hpp"
-
-namespace ecf {
-
-NodeTreeVisitor::~NodeTreeVisitor() = default;
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/NodeTreeVisitor.hpp 5.13.0-1/ANode/src/ecflow/node/NodeTreeVisitor.hpp
--- 5.12.4-1/ANode/src/ecflow/node/NodeTreeVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/NodeTreeVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,36 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_NodeTreeVisitor_HPP
-#define ecflow_node_NodeTreeVisitor_HPP
-
-class Defs;
-class Suite;
-class Family;
-class Task;
-class NodeContainer;
-
-namespace ecf {
-
-class NodeTreeVisitor {
-public:
-    virtual ~NodeTreeVisitor();
-
-    virtual bool traverseObjectStructureViaVisitors() const { return false; }
-    virtual void visitDefs(Defs*)                   = 0;
-    virtual void visitSuite(Suite*)                 = 0;
-    virtual void visitFamily(Family*)               = 0;
-    virtual void visitNodeContainer(NodeContainer*) = 0;
-    virtual void visitTask(Task*)                   = 0;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_NodeTreeVisitor_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ResolveExternsVisitor.cpp 5.13.0-1/ANode/src/ecflow/node/ResolveExternsVisitor.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ResolveExternsVisitor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ResolveExternsVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,150 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/ResolveExternsVisitor.hpp"
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-///////////////////////////////////////////////////////////////////////////////
-// ResolveExternsVisitor: Will traverse node tree hierarchy
-ResolveExternsVisitor::ResolveExternsVisitor(Defs* defs) : defs_(defs) {
-}
-
-void ResolveExternsVisitor::visitDefs(Defs* d) {
-    for (suite_ptr s : d->suiteVec()) {
-        s->acceptVisitTraversor(*this);
-    }
-}
-
-void ResolveExternsVisitor::visitSuite(Suite* s) {
-    visitNodeContainer(s);
-}
-void ResolveExternsVisitor::visitFamily(Family* f) {
-    visitNodeContainer(f);
-}
-
-void ResolveExternsVisitor::visitNodeContainer(NodeContainer* nc) {
-
-    setup(nc);
-
-    for (node_ptr t : nc->nodeVec()) {
-        t->acceptVisitTraversor(*this);
-    }
-}
-
-void ResolveExternsVisitor::visitTask(Task* t) {
-    setup(t);
-}
-
-void ResolveExternsVisitor::setup(Node* n) {
-    // Defs passed in to avoid, traversing up the node tree
-    n->auto_add_inlimit_externs(defs_);
-    doSetup(n, n->completeAst());
-    doSetup(n, n->triggerAst());
-}
-
-void ResolveExternsVisitor::doSetup(Node* node, Ast* ast) {
-    if (ast) {
-        // The complete expression have been parsed and we have created the abstract syntax tree
-        AstResolveExternVisitor astVisitor(node, defs_);
-        ast->accept(astVisitor);
-    }
-}
-
-//======================================================================================
-// AstResolveExternVisitor: Will traverse ASR tree hierarchy
-AstResolveExternVisitor::AstResolveExternVisitor(Node* node, Defs* defs) : triggerNode_(node), defs_(defs) {
-}
-
-AstResolveExternVisitor::~AstResolveExternVisitor() = default;
-
-void AstResolveExternVisitor::visitNode(AstNode* astNode) {
-    // std::cout << " AstResolveExternVisitor::visitNode " << triggerNode_->debugNodePath() << "\n";
-
-    astNode->setParentNode(triggerNode_);
-
-    // See if can reference the path, on the AstNode, if we can't, it should be added as an extern
-    std::string errorMsg;
-    Node* node = astNode->referencedNode(errorMsg);
-    if (!node) {
-        /// Add this path to the extern's. Avoid adding duplicates
-        addExtern(astNode->nodePath());
-    }
-}
-
-void AstResolveExternVisitor::visitVariable(AstVariable* astVar) {
-    // std::cout << " AstResolveExternVisitor::visitNode " << triggerNode_->debugNodePath() << "\n";
-
-    astVar->setParentNode(triggerNode_);
-
-    // See if can reference the path, on the AstVariable, if we can't, it should be added as an extern
-    std::string errorMsg;
-    Node* theReferencedNode = astVar->referencedNode(errorMsg);
-    if (!theReferencedNode) {
-        addExtern(astVar->nodePath(), astVar->name());
-        return;
-    }
-    LOG_ASSERT(errorMsg.empty(), "");
-
-    // Ok,we found the referenced, node, now see if we can reference the attribute name
-    // Find in order, event, meter, user variable, repeat, generated variable
-    if (theReferencedNode->findExprVariable(astVar->name())) {
-        return;
-    }
-
-    // Can't find name, in event, meter, user variable, repeat, generated variable, add as extern
-    addExtern(astVar->nodePath(), astVar->name());
-}
-
-void AstResolveExternVisitor::visitParentVariable(AstParentVariable* astvar) {
-    // std::cout << " AstResolveExternVisitor::visitParentVariable  " << triggerNode_->debugNodePath() << "\n";
-
-    astvar->setParentNode(const_cast<Node*>(triggerNode_));
-
-    if (!astvar->find_node_which_references_variable()) {
-
-        addExtern(triggerNode_->absNodePath(), astvar->name()); // absolute var
-    }
-}
-
-void AstResolveExternVisitor::visitFlag(AstFlag* astVar) {
-    // std::cout << " AstResolveExternVisitor::visitFlag " << triggerNode_->debugNodePath() << "\n";
-
-    astVar->setParentNode(triggerNode_);
-
-    // See if can reference the path, on the AstFlag, if we can't, it should be added as an extern
-    std::string errorMsg;
-    Node* theReferencedNode = astVar->referencedNode(errorMsg);
-    if (!theReferencedNode) {
-        addExtern(astVar->nodePath(), astVar->name()); // return flag:late
-        return;
-    }
-}
-
-void AstResolveExternVisitor::addExtern(const std::string& absNodePath, const std::string& var) {
-    string ext = absNodePath;
-    if (!var.empty()) {
-        ext += Str::COLON();
-        ext += var;
-    }
-    // cout << " AstResolveExternVisitor::addExtern " << ext << "\n";
-    defs_->add_extern(ext); // stored in a set:
-}
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ResolveExternsVisitor.hpp 5.13.0-1/ANode/src/ecflow/node/ResolveExternsVisitor.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ResolveExternsVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ResolveExternsVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,80 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ResolveExternsVisitor_HPP
-#define ecflow_node_ResolveExternsVisitor_HPP
-
-#include "ecflow/node/ExprAstVisitor.hpp"
-#include "ecflow/node/NodeTreeVisitor.hpp"
-
-class Node;
-class Ast;
-
-namespace ecf {
-
-class ResolveExternsVisitor final : public NodeTreeVisitor {
-public:
-    explicit ResolveExternsVisitor(Defs*);
-
-    bool traverseObjectStructureViaVisitors() const override { return true; }
-    void visitDefs(Defs*) override;
-    void visitSuite(Suite*) override;
-    void visitFamily(Family*) override;
-    void visitNodeContainer(NodeContainer*) override;
-    void visitTask(Task*) override;
-
-private:
-    void setup(Node*);
-    void doSetup(Node* node, Ast* ast);
-
-    Defs* defs_;
-};
-
-class AstResolveExternVisitor : public ExprAstVisitor {
-public:
-    AstResolveExternVisitor(Node*, Defs*);
-    ~AstResolveExternVisitor() override;
-
-    void visitTop(AstTop*) override {}
-    void visitRoot(AstRoot*) override {}
-    void visitAnd(AstAnd*) override {}
-    void visitNot(AstNot*) override {}
-    void visitPlus(AstPlus*) override {}
-    void visitMinus(AstMinus*) override {}
-    void visitDivide(AstDivide*) override {}
-    void visitMultiply(AstMultiply*) override {}
-    void visitModulo(AstModulo*) override {}
-    void visitOr(AstOr*) override {}
-    void visitEqual(AstEqual*) override {}
-    void visitNotEqual(AstNotEqual*) override {}
-    void visitLessEqual(AstLessEqual*) override {}
-    void visitGreaterEqual(AstGreaterEqual*) override {}
-    void visitGreaterThan(AstGreaterThan*) override {}
-    void visitLessThan(AstLessThan*) override {}
-    void visitLeaf(AstLeaf*) override {}
-    void visitInteger(AstInteger*) override {}
-    void visitInstant(AstInstant*) override {}
-    void visitFunction(AstFunction*) override {}
-    void visitNodeState(AstNodeState*) override {}
-    void visitEventState(AstEventState*) override {}
-    void visitNode(AstNode*) override;
-    void visitVariable(AstVariable*) override;
-    void visitParentVariable(AstParentVariable*) override;
-    void visitFlag(AstFlag*) override;
-
-private:
-    void addExtern(const std::string& absNodePath, const std::string& var = "");
-    Node* triggerNode_;
-    Defs* defs_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_ResolveExternsVisitor_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ServerState.cpp 5.13.0-1/ANode/src/ecflow/node/ServerState.cpp
--- 5.12.4-1/ANode/src/ecflow/node/ServerState.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ServerState.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,478 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/ServerState.hpp"
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-// When a Defs is loaded into a server:
-//       	o the jobSubmissionInterval_ is set
-//       	o the jobGeneration_ is set
-ServerState::ServerState() : server_state_(default_state()) {
-    setup_default_env(Str::DEFAULT_PORT_NUMBER());
-}
-
-ServerState::ServerState(const std::string& port) : server_state_(default_state()) {
-    setup_default_env(port);
-}
-
-bool ServerState::operator==(const ServerState& rhs) const {
-    if (get_state() != rhs.get_state()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "ServerState::operator== get_state(" << SState::to_string(get_state()) << ") != rhs.get_state("
-                      << SState::to_string(rhs.get_state()) << ")\n";
-        }
-#endif
-        return false;
-    }
-
-    if (user_variables_ != rhs.user_variables_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "ServerState::compare user_variables_ != rhs.user_variables_\n";
-            std::cout << "user_variables_:\n";
-            for (std::vector<Variable>::const_iterator i = user_variables_.begin(); i != user_variables_.end(); ++i) {
-                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
-            }
-            std::cout << "rhs.user_variables_:\n";
-            for (std::vector<Variable>::const_iterator i = rhs.user_variables_.begin(); i != rhs.user_variables_.end();
-                 ++i) {
-                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
-            }
-        }
-#endif
-        return false;
-    }
-
-    /// Check pointing and PrintStyle::MIGRATE, SAVES server variables, since they are visualised by client like
-    /// ecflow_ui However the server does NOT load the server variable in the DEFS. Otherwise uses can change ECF_PID.
-
-    if (!DebugEquality::ignore_server_variables() && server_variables_ != rhs.server_variables_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "ServerState::compare server_variables_ != rhs.server_variables_ \n";
-            std::cout << "server_variables_:\n";
-            for (std::vector<Variable>::const_iterator i = server_variables_.begin(); i != server_variables_.end();
-                 ++i) {
-                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
-            }
-            std::cout << "rhs.server_variables_:\n";
-            for (std::vector<Variable>::const_iterator i = rhs.server_variables_.begin();
-                 i != rhs.server_variables_.end();
-                 ++i) {
-                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
-            }
-        }
-#endif
-        return false;
-    }
-
-    return true;
-}
-
-bool ServerState::compare(const ServerState& rhs) const {
-    if (get_state() != rhs.get_state()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "ServerState::compare get_state(" << SState::to_string(get_state()) << ") != rhs.get_state("
-                      << SState::to_string(rhs.get_state()) << ")\n";
-        }
-#endif
-        return false;
-    }
-
-    if (user_variables_ != rhs.user_variables_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "ServerState::compare user_variables_ != rhs.user_variables_\n";
-            std::cout << "user_variables_:\n";
-            for (const auto& u : user_variables_)
-                std::cout << "   " << u.name() << " " << u.theValue() << "\n";
-
-            std::cout << "rhs.user_variables_:\n";
-            for (const auto& u : rhs.user_variables_)
-                std::cout << "   " << u.name() << " " << u.theValue() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (!DebugEquality::ignore_server_variables() && server_variables_ != rhs.server_variables_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "ServerState::compare server_variables_ != rhs.server_variables_\n";
-            std::cout << "server_variables_:\n";
-            for (const auto& s : server_variables_)
-                std::cout << "   " << s.name() << " " << s.theValue() << "\n";
-
-            std::cout << "rhs.server_variables_:\n";
-            for (const auto& s : rhs.server_variables_)
-                std::cout << "   " << s.name() << " " << s.theValue() << "\n";
-        }
-#endif
-        return false;
-    }
-    return true;
-}
-
-void ServerState::sort_variables() {
-    variable_state_change_no_ = Ecf::incr_state_change_no();
-
-    auto caseless = [](const Variable& a, const Variable& b) { return Str::caseInsLess(a.name(), b.name()); };
-    sort(user_variables_.begin(), user_variables_.end(), caseless);
-    sort(server_variables_.begin(), server_variables_.end(), caseless);
-}
-
-// server variable CANNOT be modified or deleted, only overridden
-void ServerState::add_or_update_server_variables(const NameValueVec& env) {
-    for (const auto& p : env) {
-        add_or_update_server_variable(p.first, p.second);
-    }
-}
-void ServerState::add_or_update_server_variable(const std::string& name, const std::string& value) {
-    for (auto& s : server_variables_) {
-        if (s.name() == name) {
-            s.set_value(value);
-            //         std::cout << "   Server Variables: Updating " << name << "   " << value << "\n";
-            return;
-        }
-    }
-    //   std::cout << "   Server Variables: Adding " << name << "   " << value << "\n";
-    server_variables_.emplace_back(name, value);
-}
-
-void ServerState::set_server_variables(const std::vector<Variable>& e) {
-    server_variables_ = e;
-}
-
-void ServerState::delete_server_variable(const std::string& var) {
-    auto var_end = server_variables_.end();
-    for (auto i = server_variables_.begin(); i != var_end; ++i) {
-        if ((*i).name() == var) {
-            server_variables_.erase(i);
-            break;
-        }
-    }
-}
-
-// ================================================================================
-
-void ServerState::add_or_update_user_variables(const NameValueVec& env) {
-    for (const auto& p : env) {
-        add_or_update_user_variables(p.first, p.second);
-    }
-}
-
-void ServerState::add_or_update_user_variables(const std::vector<Variable>& env) {
-    for (const auto& v : env) {
-        add_or_update_user_variables(v.name(), v.theValue());
-    }
-}
-
-void ServerState::add_or_update_user_variables(const std::string& name, const std::string& value) {
-    for (auto& u : user_variables_) {
-        if (u.name() == name) {
-            u.set_value(value);
-            variable_state_change_no_ = Ecf::incr_state_change_no();
-            //         std::cout << "   ServerState::add_or_update_user_variables: Updating " << name << "   " << value
-            //         << "\n";
-            return;
-        }
-    }
-
-    //	std::cout << "   ServerState::add_or_update_user_variables: Adding " << name << "   " << value << "\n";
-    user_variables_.emplace_back(name, value);
-    variable_state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ServerState::delete_user_variable(const std::string& var) {
-    if (var.empty()) {
-        // delete all user variables
-        user_variables_.clear();
-        variable_state_change_no_ = Ecf::incr_state_change_no();
-        return;
-    }
-
-    auto var_end = user_variables_.end();
-    for (auto i = user_variables_.begin(); i != var_end; ++i) {
-        if ((*i).name() == var) {
-            user_variables_.erase(i);
-            variable_state_change_no_ = Ecf::incr_state_change_no();
-            break;
-        }
-    }
-}
-
-bool ServerState::find_user_variable(const std::string& name, std::string& value) const {
-    for (const auto& u : user_variables_) {
-        if (u.name() == name) {
-            value = u.theValue();
-            return true;
-        }
-    }
-    return false;
-}
-
-const std::string& ServerState::find_variable(const std::string& theVarName) const {
-    // SEARCH USER variables FIRST
-    for (const auto& u : user_variables_) {
-        if (u.name() == theVarName) {
-            return u.theValue();
-        }
-    }
-
-    // NOW search server variables
-    for (const auto& s : server_variables_) {
-        if (s.name() == theVarName) {
-            LOG_ASSERT(!s.theValue().empty(), "");
-            return s.theValue();
-        }
-    }
-
-    //	cerr << "FAILED to FIND '" << theVarName << "'\n";
-    return Str::EMPTY();
-}
-
-const Variable& ServerState::findVariable(const std::string& name) const {
-    // SEARCH USER variables FIRST
-    for (const auto& u : user_variables_) {
-        if (u.name() == name) {
-            // if (u.theValue().empty() )  std::cout << u.name() << " has a empty value\n";
-            return u;
-        }
-    }
-
-    // NOW search server variables
-    for (const auto& s : server_variables_) {
-        if (s.name() == name) {
-            LOG_ASSERT(!s.theValue().empty(), "");
-            // if (s.theValue().empty() )  std::cout << s.name() << " has a empty value\n";
-            return s;
-        }
-    }
-
-    // cerr << "FAILED to FIND '" << theVarName << "'\n";
-    return Variable::EMPTY();
-}
-
-bool ServerState::variable_exists(const std::string& name) const {
-    // SEARCH USER variables FIRST
-    for (const auto& u : user_variables_) {
-        if (u.name() == name)
-            return true;
-    }
-
-    // NOW search server variables
-    for (const auto& s : server_variables_) {
-        if (s.name() == name)
-            return true;
-    }
-
-    return false;
-}
-
-bool ServerState::variableSubsitution(std::string& cmd) const {
-    // scan the command for variables, and substitute
-    // We can also have
-    //
-    // "%<VAR>:<substitute>% i.e if VAR exist use it, else use substitute
-    //
-    // ************************************************************************************************************
-    // Special case handling for user variables, and generated variables, which take precedence over node variables
-    // ************************************************************************************************************
-    //
-    // i.e VAR is defined as BILL
-    //  %VAR:fred --f%  will either be "BILL" or if VAR is not defined "fred --f"
-    //
-    // Infinite recursion. Its possible to end up with infinite recursion:
-    //    edit hello '%hello%'  # string like %hello% will cause infinite recursion
-    //    edit fred '%bill%'
-    //    edit bill '%fred%'   # should be 10
-    // To prevent this we will use a simple count
-    char micro                = '%';
-    const Variable& micro_var = findVariable(Str::ECF_MICRO());
-    if (!micro_var.empty() && !micro_var.theValue().empty())
-        micro = micro_var.theValue()[0];
-
-    bool double_micro_found    = false;
-    std::string::size_type pos = 0;
-    int count                  = 0;
-    while (true) {
-        // A while loop here is used to:
-        //    a/ Allow for multiple substitution on a single line. i.e %ECF_FILES% -I %ECF_INCLUDE%"
-        //    b/ Allow for recursive substitution. %fred% -> %bill%--> 10
-
-        size_t firstPercentPos = cmd.find(micro, pos);
-        if (firstPercentPos == string::npos)
-            break;
-
-        size_t secondPercentPos = cmd.find(micro, firstPercentPos + 1);
-        if (secondPercentPos == string::npos)
-            break;
-
-        if (secondPercentPos - firstPercentPos <= 1) {
-            // handle %% with no characters in between, skip over
-            // i.e to handle "printf %%02d %HOUR:00%" --> "printf %02d 00"   i.e if HOUR not defined
-            pos                = secondPercentPos + 1;
-            double_micro_found = true;
-            continue;
-        }
-        else
-            pos = 0;
-
-        string percentVar(cmd.begin() + firstPercentPos + 1, cmd.begin() + secondPercentPos);
-
-        // First search user variable (*ONLY* set when doing user edit's the script)
-        // Handle case: cmd = "%fred:bill% and where we have user variable "fred:bill"
-        // Handle case: cmd = "%fred%      and where we have user variable "fred"
-        // If we fail to find the variable we return false.
-        // Note: When a variable is found, it can have an empty value  which is still valid
-        const Variable& variable = findVariable(percentVar);
-        if (!variable.empty()) {
-            std::string varValue = variable.theValue();
-            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-        }
-        else {
-
-            size_t firstColon = percentVar.find(':');
-            if (firstColon != string::npos) {
-
-                string var(percentVar.begin(), percentVar.begin() + firstColon);
-
-                const Variable& variable2 = findVariable(var);
-                if (!variable2.empty()) {
-                    std::string varValue = variable2.theValue();
-                    cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
-                }
-                else {
-                    string substitute(percentVar.begin() + firstColon + 1, percentVar.end());
-                    cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, substitute);
-                }
-            }
-            else {
-                // No Colon, Can't find in user variables, or node variable, hence can't go any further
-                return false;
-            }
-        }
-
-        // Simple Check for infinite recursion
-        if (count > 100)
-            return false;
-        count++;
-    }
-
-    if (double_micro_found) {
-        // replace all double micro with a single micro, this must be a single parse
-        // date +%%Y%%m%%d" ==> date +%Y%m%d
-        // %%%%             ==> %%            // i.e single parse
-        std::string doubleEcfMicro;
-        doubleEcfMicro += micro;
-        doubleEcfMicro += micro;
-        size_t last_pos = 0;
-        while (true) {
-            string::size_type ecf_double_micro_pos = cmd.find(doubleEcfMicro, last_pos);
-            if (ecf_double_micro_pos != std::string::npos) {
-                cmd.erase(cmd.begin() + ecf_double_micro_pos);
-                last_pos = ecf_double_micro_pos + 1;
-            }
-            else
-                break;
-        }
-    }
-
-    return true;
-}
-
-void ServerState::set_user_variables(const std::vector<Variable>& e) {
-    user_variables_           = e;
-    variable_state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ServerState::set_state(SState::State s) {
-    server_state_    = s;
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-void ServerState::setup_default_env(const std::string& port) {
-    // This environment is required for testing in the absence of the server.
-    // When the defs file is begun in the server this environment get *overridden*
-    hostPort_ = std::make_pair(Str::LOCALHOST(), port);
-
-    setup_default_server_variables(server_variables_, port);
-}
-
-void ServerState::setup_default_server_variables(std::vector<Variable>& server_variables, const std::string& port) {
-    Host host;
-    server_variables.emplace_back(Str::ECF_MICRO(),
-                                  Ecf::MICRO()); // Preprocessor character for variable substitution and including files
-    server_variables.emplace_back(Str::ECF_HOME(), string("."));
-    server_variables.emplace_back(string("ECF_JOB_CMD"), Ecf::JOB_CMD());   // Command to be executed to submit a job
-    server_variables.emplace_back(string("ECF_KILL_CMD"), Ecf::KILL_CMD()); // Command to be executed to kill a job
-    server_variables.emplace_back(string("ECF_STATUS_CMD"),
-                                  Ecf::STATUS_CMD()); // Command to be executed to get status of job
-    server_variables.emplace_back(string("ECF_URL_CMD"), Ecf::URL_CMD());
-    server_variables.emplace_back(string("ECF_URL_BASE"), Ecf::URL_BASE());
-    server_variables.emplace_back(string("ECF_URL"), Ecf::URL());
-    server_variables.emplace_back(string("ECF_LOG"), host.ecf_log_file(port));
-    server_variables.emplace_back(string("ECF_INTERVAL"), string("60")); // Check time dependencies and submit any jobs
-    server_variables.emplace_back(string("ECF_LISTS"), host.ecf_lists_file(port));
-    server_variables.emplace_back(string("ECF_PASSWD"), host.ecf_passwd_file(port));
-    server_variables.emplace_back(string("ECF_CUSTOM_PASSWD"), host.ecf_custom_passwd_file(port));
-    server_variables.emplace_back(string("ECF_CHECK"), host.ecf_checkpt_file(port));
-    server_variables.emplace_back(string("ECF_CHECKOLD"), host.ecf_backup_checkpt_file(port));
-    server_variables.emplace_back(string("ECF_CHECKINTERVAL"),
-                                  string("120")); // The interval in seconds to save check point file
-    server_variables.emplace_back(string("ECF_CHECKMODE"),
-                                  string("CHECK_ON_TIME")); // The check mode, must be one of NEVER, ON_TIME, ALWAYS
-
-    // Number of times a job should rerun if it aborts. If more than one and
-    // job aborts, the job is automatically re-run. Useful when jobs are run in
-    // an unreliable environments. For example using using commands like ftp(1)
-    // in a job can fail easily, but re-running the job will often work
-    server_variables.emplace_back(Str::ECF_TRIES(), string("2"));
-
-    server_variables.emplace_back(string("ECF_VERSION"), Version::raw()); // server version
-
-    // Needed to setup client environment.
-    // The server sets these variable for use by the client. i.e when creating the jobs
-    // The clients then uses them to communicate with the server.
-    server_variables.emplace_back(Str::ECF_PORT(), port);
-    server_variables.emplace_back(Str::ECF_HOST(), Str::LOCALHOST());
-}
-
-/// determines why the node is not running.
-bool ServerState::why(std::vector<std::string>& theReasonWhy) const {
-    if (server_state_ == SState::HALTED) {
-        theReasonWhy.emplace_back("The server is halted");
-        return true;
-    }
-    if (server_state_ == SState::SHUTDOWN) {
-        theReasonWhy.emplace_back("The server is shutdown");
-        return true;
-    }
-    return false;
-}
-
-template <class Archive>
-void ServerState::serialize(Archive& ar, std::uint32_t const version) {
-    ar(CEREAL_NVP(server_state_), CEREAL_NVP(server_variables_));
-    CEREAL_OPTIONAL_NVP(ar, user_variables_, [this]() { return !user_variables_.empty(); });
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(ServerState);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/ServerState.hpp 5.13.0-1/ANode/src/ecflow/node/ServerState.hpp
--- 5.12.4-1/ANode/src/ecflow/node/ServerState.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/ServerState.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,128 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_ServerState_HPP
-#define ecflow_node_ServerState_HPP
-
-#include <cstdint>
-
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/core/SState.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-/// This class stores the server state, so that it is accessible by the node tree
-///
-/// The server variables could have been added/deleted or changed, hence these
-/// variables are serialised, also:  it has proved useful i.e for
-///    a/ Client to visualise the server environment during a call like -group="get; show state"
-///    b/ Allows the test code to update environment. ie. use ECF_CLIENT
-////      allows us to replace smsinit, smscomplete,etc, with the ECF client exe
-//
-// Note The default state here is RUNNING while in the server the default state is HALTED
-// By choosing RUNNING, it allows the Defs related test, to run without explicitly setting the state
-class ServerState {
-public:
-    ServerState();
-    explicit ServerState(const std::string& port); // used in test to init server variables
-    ServerState(const ServerState& other)            = default;
-    ServerState& operator=(const ServerState& other) = default;
-
-    /// Check pointing, SAVES server variables, since they are visualised by client like ecflow_ui
-    /// HOWEVER PrintStyle::MIGRATE does not save the server variables, since they should
-    /// not take part in migration. However the testing compares migration files with check point files
-    /// This would always fail. Hence we do not compare server variables.
-    /// This does not compare server variables
-    bool operator==(const ServerState& rhs) const;
-    bool operator!=(const ServerState& rhs) const { return !operator==(rhs); }
-
-    /// This does compare server variables. Used in testing
-    bool compare(const ServerState& rhs) const;
-
-    void sort_variables();
-
-    /// The server variable: are automatically added by the server
-    /// on STARTUP and when a checkpoint file is reloaded.
-    /// The variable are required by Job creation & needed in creation of generated variables
-    /// The variables should NOT be modified.
-    ///
-    /// However user variables can be freely added,deleted and modified
-    /// They will override server variables of the same name
-
-    void add_or_update_server_variable(const std::string&, const std::string&);
-    void add_or_update_server_variables(const NameValueVec& env);
-    void delete_server_variable(const std::string&); // should only be used by test
-    void set_server_variables(const std::vector<Variable>& e);
-    const std::vector<Variable>& server_variables() const { return server_variables_; }
-
-    void add_or_update_user_variables(const NameValueVec& env);
-    void add_or_update_user_variables(const std::vector<Variable>& env);
-    void add_or_update_user_variables(const std::string&, const std::string&);
-    void delete_user_variable(const std::string&);
-
-    void set_user_variables(const std::vector<Variable>& e);
-    const std::vector<Variable>& user_variables() const { return user_variables_; }
-    bool find_user_variable(const std::string& name, std::string& value) const;
-
-    // Search user variables, and then server variables
-    const std::string& find_variable(const std::string& name) const;
-    const Variable& findVariable(const std::string& name) const;
-    bool variable_exists(const std::string& name) const;
-
-    /// find all %VAR% and replaces with variable values, returns false on the
-    /// first variable that can't be found, cmd will be left half processed.
-    /// Will search for ECF_MICRO, if not found assumes % as the micro char
-    bool variableSubsitution(std::string& cmd) const;
-
-    // These functions/data are used to during job generation
-    void jobSubmissionInterval(int s) { jobSubmissionInterval_ = s; }
-    int jobSubmissionInterval() const { return jobSubmissionInterval_; }
-    bool jobGeneration() const { return jobGeneration_; } // testing may disable job generation
-    void jobGeneration(bool f) { jobGeneration_ = f; }
-
-    void set_state(SState::State s);
-    SState::State get_state() const { return server_state_; }
-    static SState::State default_state() { return SState::RUNNING; }
-
-    // set by the server hence no need persist
-    void hostPort(const std::pair<std::string, std::string>& hostPort) { hostPort_ = hostPort; }
-    std::pair<std::string, std::string> hostPort() const { return hostPort_; }
-
-    /// Currently only SState::State server_state_ recorded
-    unsigned int state_change_no() const { return state_change_no_; }
-    unsigned int variable_state_change_no() const { return variable_state_change_no_; }
-
-    /// determines why the node is not running.
-    bool why(std::vector<std::string>& theReasonWhy) const; // return true if why found
-
-    /// Used in test
-    static void setup_default_server_variables(std::vector<Variable>& server_variables, const std::string& port);
-
-private:
-    void setup_default_env(const std::string& port);
-
-private:
-    int jobSubmissionInterval_{60};            // NOT persisted, since set in the server
-    unsigned int state_change_no_{0};          // *not* persisted, only used on server side
-    unsigned int variable_state_change_no_{0}; // *not* persisted, only used on server side
-
-    SState::State server_state_;
-    std::vector<Variable> server_variables_;
-    std::vector<Variable> user_variables_;
-
-    std::pair<std::string, std::string> hostPort_; // NOT persisted, set by server hence no need to persist
-    bool jobGeneration_{true};                     // NOT persisted, since set in the server
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-#endif /* ecflow_node_ServerState_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Signal.cpp 5.13.0-1/ANode/src/ecflow/node/Signal.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Signal.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Signal.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Signal.hpp"
-
-#include <csignal>
-
-namespace ecf {
-
-// SIGCHLD : Child status has changed (POSIX)
-// Signal sent to parent process whenever one of its child processes terminates or stops.
-
-Signal::Signal() = default;
-
-Signal::~Signal() {
-    // Unblock SIGCHLD. This will call the signal-handler in System.cpp,
-    // *IF* we have pending SIGCHLD
-    // This will not return until we have handled all the pending SIGCHLD signal
-    unblock_sigchild();
-
-    // Once the signals are processed, block them until we come in here again
-    // Now block again.
-    block_sigchild();
-}
-
-void Signal::block_sigchild() {
-    // Now block again.
-    sigset_t set;
-    sigemptyset(&set);
-    sigaddset(&set, SIGCHLD);
-    sigprocmask(SIG_BLOCK, &set, nullptr);
-}
-
-void Signal::unblock_sigchild() {
-    sigset_t set;
-    sigemptyset(&set);
-    sigaddset(&set, SIGCHLD);
-    sigprocmask(SIG_UNBLOCK, &set, nullptr);
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Signal.hpp 5.13.0-1/ANode/src/ecflow/node/Signal.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Signal.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Signal.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Signal_HPP
-#define ecflow_node_Signal_HPP
-
-///
-/// \brief The Signal class will, during destruction, un-block SIGCHILD and then
-/// reapply the block. During job generation we want to avoid being notified of
-/// of child process termination.
-/// We want to control when child process termination is handled.
-///
-
-namespace ecf {
-
-class Signal {
-public:
-    Signal();
-    // Disable copy (and move) semantics
-    Signal(const Signal&)                  = delete;
-    const Signal& operator=(const Signal&) = delete;
-
-    /// UNBLOCK SIGCHLD at start of destructor
-    /// BLOCK SIGCHLD and the end of the destructor
-    /// During the gap in between handle process termination
-    ~Signal();
-
-    static void block_sigchild();
-    static void unblock_sigchild();
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_Signal_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Submittable.cpp 5.13.0-1/ANode/src/ecflow/node/Submittable.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Submittable.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Submittable.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1185 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Submittable.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Passwd.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/DefsDelta.hpp"
-#include "ecflow/node/EcfFile.hpp"
-#include "ecflow/node/JobCreationCtrl.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// #define DEBUG_TASK_LOCATION 1
-
-/////////////////////////////////////////////////////////////////////////////////////////////////////
-// init static
-const std::string& Submittable::DUMMY_JOBS_PASSWORD() {
-    static const std::string DUMMY_JOBS_PASSWORD = "_DJP_";
-    return DUMMY_JOBS_PASSWORD;
-}
-const std::string& Submittable::FREE_JOBS_PASSWORD() {
-    static const std::string FREE_JOBS_PASSWORD = "FREE";
-    return FREE_JOBS_PASSWORD;
-}
-const std::string& Submittable::DUMMY_PROCESS_OR_REMOTE_ID() {
-    static const std::string DUMMY_PROCESS_OR_REMOTE_ID = "_RID_";
-    return DUMMY_PROCESS_OR_REMOTE_ID;
-}
-
-Submittable& Submittable::operator=(const Submittable& rhs) {
-    if (this != &rhs) {
-        Node::operator=(rhs);
-        paswd_ = rhs.paswd_;
-        rid_   = rhs.rid_;
-        abr_   = rhs.abr_;
-        tryNo_ = rhs.tryNo_;
-
-        delete sub_gen_variables_;
-        sub_gen_variables_ = nullptr;
-
-        state_change_no_ = Ecf::incr_state_change_no();
-    }
-    return *this;
-}
-
-Submittable::~Submittable() {
-    delete sub_gen_variables_;
-}
-
-bool Submittable::check_defaults() const {
-    if (tryNo_ != 0)
-        throw std::runtime_error("Submittable::check_defaults(): tryNo_ != 0");
-    if (state_change_no_ != 0)
-        throw std::runtime_error("Submittable::check_defaults(): state_change_no_ != 0");
-    if (sub_gen_variables_ != nullptr)
-        throw std::runtime_error("Submittable::check_defaults(): sub_gen_variables_ != nullptr");
-    return Node::check_defaults();
-}
-
-void Submittable::init(const std::string& the_process_or_remote_id) {
-    set_state(NState::ACTIVE);
-    set_process_or_remote_id(the_process_or_remote_id);
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Submittable::init\n";
-#endif
-}
-
-void Submittable::complete() {
-    // cout << "Completed " << debugNodePath() << " at " << suite()->calendar().toString() << "\n";
-    set_state(NState::COMPLETE);
-    flag().clear(ecf::Flag::ZOMBIE);
-
-    /// Should we clear paswd_ & process_id? It can be argued that
-    /// we should keep this. In case it is needed. i.e. The job may not really be
-    /// complete. However keeping, this means the memory usage will continue to rise
-    /// Dependent on number of tasks. This can affect network bandwidth as well.
-    /// Hence to reduce network bandwidth we chose to clear the strings
-    clear(); // jobs password, process_id, aborted_reason
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Submittable::complete()\n";
-#endif
-}
-
-void Submittable::aborted(const std::string& reason) {
-    // Called during *abnormal* child termination
-    // This will bubble the state, and decrement any limits
-    set_aborted_only(reason);
-}
-
-void Submittable::set_process_or_remote_id(const std::string& id) {
-    rid_ = id;
-    set_genvar_ecfrid(rid_);
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG
-    if (tryNo_ == 0 && rid_ != Submittable::DUMMY_PROCESS_OR_REMOTE_ID()) {
-        LogToCout logToCout;
-        LOG(Log::ERR,
-            "Submittable::set_process_or_remote_id: " << absNodePath() << " process_id(" << id
-                                                      << ") tryNo == 0, how can this be ???");
-    }
-#endif
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Submittable::set_process_or_remote_id\n";
-#endif
-}
-
-void Submittable::reset() {
-    tryNo_ = 0; // reset try number
-    clear();    // jobs password, process_id, aborted_reason
-    Node::reset();
-}
-
-void Submittable::begin() {
-    /// It is *very* important that we reset the passwords. This allows us to detect zombies.
-    tryNo_ = 0; // reset try number
-    clear();    // jobs password, process_id, aborted_reason
-
-    Node::begin(); // see  Notes in: Node::begin() about update_generated_variables()
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Submittable::begin()\n";
-#endif
-}
-
-void Submittable::requeue(Requeue_args& args) {
-    /// It is *very* important that we reset the passwords. This allows us to detect zombies.
-    tryNo_ = 0; // reset try number
-    clear();    // jobs password, process_id, aborted_reason
-
-    Node::requeue(args);
-    update_generated_variables();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Submittable::requeue\n";
-#endif
-}
-
-bool Submittable::calendarChanged(const ecf::Calendar& c,
-                                  Node::Calendar_args& cal_args,
-                                  const ecf::LateAttr* inherited_late,
-                                  bool holding_parent_day_or_date) {
-    (void)Node::calendarChanged(c, cal_args, nullptr, holding_parent_day_or_date);
-
-    // Late flag should ONLY be set on Submittable
-    check_for_lateness(c, inherited_late);
-    return false;
-}
-
-void Submittable::write_state(std::string& ret, bool& added_comment_char) const {
-    // *IMPORTANT* we *CAN'T* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e.
-    //                 `task a; task b;`
-    if (!paswd_.empty() && paswd_ != Submittable::DUMMY_JOBS_PASSWORD()) {
-        add_comment_char(ret, added_comment_char);
-        ret += " passwd:";
-        ret += paswd_;
-    }
-    if (!rid_.empty()) {
-        add_comment_char(ret, added_comment_char);
-        ret += " rid:";
-        ret += rid_;
-    }
-
-    // The abr_, can contain user generated messages, including \n and ;, hence remove these
-    // as they can mess up the parsing on reload.
-    if (!abr_.empty()) {
-        add_comment_char(ret, added_comment_char);
-        std::string the_abort_reason = abr_;
-        Str::replaceall(the_abort_reason, "\n", "\\n");
-        Str::replaceall(the_abort_reason, ";", " ");
-        ret += " abort<:";
-        ret += the_abort_reason;
-        ret += ">abort";
-    }
-    if (tryNo_ != 0) {
-        add_comment_char(ret, added_comment_char);
-        ret += " try:";
-        ret += ecf::convert_to<std::string>(tryNo_);
-    }
-    Node::write_state(ret, added_comment_char);
-}
-
-void Submittable::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
-    //  0    1   2
-    // task name #
-    size_t line_tokens_size = lineTokens.size();
-    for (size_t i = 3; i < line_tokens_size; i++) {
-        const std::string& line_token_i = lineTokens[i];
-
-        if (line_token_i.find("passwd:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, paswd_))
-                throw std::runtime_error("Submittable::read_state failed for jobs password : " + name());
-        }
-        else if (line_token_i.find("rid:") != std::string::npos) {
-            if (!Extract::split_get_second(line_token_i, rid_))
-                throw std::runtime_error("Submittable::read_state failed for rid : " + name());
-        }
-        else if (line_token_i.find("try:") != std::string::npos) {
-            std::string try_number;
-            if (!Extract::split_get_second(line_token_i, try_number))
-                throw std::runtime_error("Submittable::read_state failed for try number : " + name());
-            tryNo_ = Extract::theInt(try_number, "Submittable::read_state failed for try number");
-        }
-    }
-
-    // extract aborted reason
-    // The line tokens will truncate multiple spaces into a single space chars
-    // Hence use the line to extract the abort reason: This will preserve spaces
-    size_t first_pos = line.find("abort<:");
-    size_t last_pos  = line.find(">abort");
-    if (first_pos != std::string::npos) {
-        if (last_pos != std::string::npos) {
-            abr_ = line.substr(first_pos + 7, (last_pos - first_pos - 7));
-        }
-        else {
-            throw std::runtime_error(
-                "Submittable::read_state failed for abort reason. Expected abort reason to on single line;");
-        }
-    }
-
-    Node::read_state(line, lineTokens);
-}
-
-bool Submittable::operator==(const Submittable& rhs) const {
-    if (paswd_ != rhs.paswd_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Submittable::operator==  paswd_(" << paswd_ << ") != rhs.paswd_(" << rhs.paswd_ << ") "
-                      << debugNodePath() << "\n";
-            std::cout << "Submittable::operator==  state(" << NState::toString(state()) << ")  rhs.state("
-                      << NState::toString(rhs.state()) << ") \n";
-            // No point dumping out change numbers, since we don't persist them, hence values will always be zero on
-            // client side.
-        }
-#endif
-        return false;
-    }
-
-    if (rid_ != rhs.rid_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Submittable::operator==  rid_(" << rid_ << ") != rhs.rid_(" << rhs.rid_ << ") "
-                      << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (tryNo_ != rhs.tryNo_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Submittable::operator==  tryNo_(" << tryNo_ << ") != rhs.tryNo_(" << rhs.tryNo_ << ") "
-                      << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if (abr_ != rhs.abr_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Submittable::operator==  abr_(" << abr_ << ") != rhs.abr_(" << rhs.abr_ << ") "
-                      << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    return Node::operator==(rhs);
-}
-
-string Submittable::tryNo() const {
-    try {
-        return ecf::convert_to<std::string>(tryNo_);
-    }
-    catch (const ecf::bad_conversion&) {
-    }
-
-    LOG_ASSERT(false, "Submittable::tryNo() corrupt?");
-    return string();
-}
-
-EcfFile Submittable::locatedEcfFile() const {
-    // Look for scripts file(Task->.ecf | Alias->.usr) in the following order
-    // o/ ECF_SCRIPT Generated VARIABLE  absolute path, check if files exists
-    //    The variable MUST exist, but the file may not
-    // o/ ECF_FETCH (user variable)
-    //    if this variable exist, we need to flag it,
-    //    So that that file is obtained from running the command. (Output of popen)
-    // o/ ECF_SCRIPT_CMD (user variable)
-    //    if this variable exist, we need to flag it,
-    //    So that that file is obtained from running the command. (Output of popen)
-    // o/ ECF_FILES (Typically in the definition file, defines a directory) (backward search)
-    //    if ECF_FILES_LOOKUP=PRUNE_LEAF (forward_search)
-    // o/ ECF_HOME (backward search)
-    //    if ECF_FILES_LOOKUP=PRUNE_LEAF (forward_search)
-    //    where: backward search is root_path = (ECF_FILES | ECF_HOME) (PRUNE_ROOT)
-    //           <root-path>/suite/family/family2/task.ecf
-    //           <root-path>/family/family2/task.ecf
-    //           <root-path>/family2/task.ecf
-    //           <root-path>/task.ecf
-    //    where: forward search is root_path = (ECF_FILES | ECF_HOME) (PRUNE_LEAF)
-    //           <root-path>/suite/family/family2/task.ecf
-    //           <root-path>/suite/family/task.ecf
-    //           <root-path>/suite/task.ecf
-    //           <root-path>/task.ecf
-
-    std::string reasonEcfFileNotFound;
-    std::string theAbsNodePath = absNodePath();
-    std::string ecf_home;
-    findParentUserVariableValue(Str::ECF_HOME(), ecf_home);
-
-    /// Update local ECF_SCRIPT variable, ECF_SCRIPT is a generated variable. IT *MUST* exist
-    /// Likewise generated variable like TASK and ECF_NAME as they may occur in ECF_FETCH_CMD/ECF_SCRIPT_CMD
-    update_static_generated_variables(ecf_home, theAbsNodePath);
-
-    const Variable& genvar_ecfscript = get_genvar_ecfscript();
-
-#ifdef DEBUG_TASK_LOCATION
-    std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " searching ECF_SCRIPT = '"
-              << genvar_ecfscript.theValue() << "'\n";
-#endif
-    if (fs::exists(genvar_ecfscript.theValue())) {
-#ifdef DEBUG_TASK_LOCATION
-        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " ECF_SCRIPT = '"
-                  << genvar_ecfscript.theValue() << "' exists\n";
-#endif
-        return EcfFile(const_cast<Submittable*>(this), genvar_ecfscript.theValue(), EcfFile::ECF_SCRIPT);
-    }
-    else {
-        reasonEcfFileNotFound += "   ECF_SCRIPT(";
-        reasonEcfFileNotFound += genvar_ecfscript.theValue();
-        reasonEcfFileNotFound += ") does not exist:\n";
-    }
-
-    // Caution: This is not used in operations or research; equally it has not been tested.
-    std::string ecf_fetch_cmd;
-    findParentVariableValue(Str::ECF_FETCH(), ecf_fetch_cmd);
-    if (!ecf_fetch_cmd.empty()) {
-#ifdef DEBUG_TASK_LOCATION
-        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " ECF_FETCH = '" << ecf_fetch_cmd
-                  << "' variable exists\n";
-#endif
-        if (variableSubstitution(ecf_fetch_cmd)) {
-            return EcfFile(const_cast<Submittable*>(this), ecf_fetch_cmd, EcfFile::ECF_FETCH_CMD);
-        }
-        else {
-            reasonEcfFileNotFound += "   Variable ECF_FETCH(";
-            reasonEcfFileNotFound += ecf_fetch_cmd;
-            reasonEcfFileNotFound += ") defined, but variable substitution has failed:\n";
-            throw std::runtime_error(reasonEcfFileNotFound);
-        }
-    }
-    else {
-        reasonEcfFileNotFound += "   Variable ECF_FETCH not defined:\n";
-    }
-
-    std::string ecf_script_cmd; // ECFLOW-427
-    findParentVariableValue("ECF_SCRIPT_CMD", ecf_script_cmd);
-    if (!ecf_script_cmd.empty()) {
-#ifdef DEBUG_TASK_LOCATION
-        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " ECF_SCRIPT_CMD = '" << ecf_script_cmd
-                  << "' variable exists\n";
-#endif
-        if (variableSubstitution(ecf_script_cmd)) {
-            return EcfFile(const_cast<Submittable*>(this), ecf_script_cmd, EcfFile::ECF_SCRIPT_CMD);
-        }
-        else {
-            reasonEcfFileNotFound += "   Variable ECF_SCRIPT_CMD(";
-            reasonEcfFileNotFound += ecf_script_cmd;
-            reasonEcfFileNotFound += ") defined, but variable substitution has failed:\n";
-            throw std::runtime_error(reasonEcfFileNotFound);
-        }
-    }
-    else {
-        reasonEcfFileNotFound += "   Variable ECF_SCRIPT_CMD not defined:\n";
-    }
-
-    EcfFile::EcfFileSearchAlgorithm file_search_algo = EcfFile::PRUNE_ROOT;
-    std::string ecf_files_lookup;
-    if (findParentUserVariableValue("ECF_FILES_LOOKUP", ecf_files_lookup)) {
-        if (ecf_files_lookup == "prune_leaf" || ecf_files_lookup == "PRUNE_LEAF")
-            file_search_algo = EcfFile::PRUNE_LEAF;
-    }
-
-    std::string ecf_filesDirectory;
-    if (findParentUserVariableValue(Str::ECF_FILES(), ecf_filesDirectory)) {
-#ifdef DEBUG_TASK_LOCATION
-        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " searching ECF_FILES = '"
-                  << ecf_filesDirectory << "' backwards\n";
-#endif
-        if (!ecf_filesDirectory.empty() && fs::is_directory(ecf_filesDirectory)) {
-            // If File::backwardSearch fails it returns an empty string, i.e. failure to locate script (Task/.ecf ||
-            // Alias/.usr) file
-            std::string searchResult;
-            if (file_search_algo == EcfFile::PRUNE_ROOT)
-                searchResult = File::backwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
-            else
-                searchResult = File::forwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
-            if (searchResult.empty()) {
-                reasonEcfFileNotFound += "   Search of directory ECF_FILES(";
-                reasonEcfFileNotFound += ecf_filesDirectory;
-                reasonEcfFileNotFound += ") failed ";
-                if (file_search_algo == EcfFile::PRUNE_ROOT)
-                    reasonEcfFileNotFound += "using prune_root:\n";
-                else
-                    reasonEcfFileNotFound += "using prune_leaf:\n";
-            }
-            else
-                return EcfFile(const_cast<Submittable*>(this), searchResult, EcfFile::ECF_FILES, file_search_algo);
-        }
-        else {
-            // Before failing try again but with variable Substitution. ECFLOW-788
-            std::string original_ecf_filesDirectory = ecf_filesDirectory;
-            variableSubstitution(ecf_filesDirectory);
-            if (!ecf_filesDirectory.empty() && fs::is_directory(ecf_filesDirectory)) {
-                // If search fails it returns an empty string, i.e. failure to locate script (Task/.ecf || Alias/.usr)
-                // file
-                std::string searchResult;
-                if (file_search_algo == EcfFile::PRUNE_ROOT)
-                    searchResult = File::backwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
-                else
-                    searchResult = File::forwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
-                if (searchResult.empty()) {
-                    std::stringstream ss;
-                    ss << "   Search of directory ECF_FILES(variable substituted)(" << ecf_filesDirectory
-                       << ") failed:\n";
-                    reasonEcfFileNotFound += ss.str();
-                }
-                else
-                    return EcfFile(const_cast<Submittable*>(this), searchResult, EcfFile::ECF_FILES, file_search_algo);
-            }
-            else {
-                std::stringstream ss;
-                ss << "   Directory ECF_FILES(" << original_ecf_filesDirectory << ") does not exist:\n";
-                if (original_ecf_filesDirectory != ecf_filesDirectory)
-                    ss << "   Directory ECF_FILES(" << ecf_filesDirectory
-                       << ") after variable substitution does not exist:\n";
-                reasonEcfFileNotFound += ss.str();
-            }
-        }
-    }
-    else {
-        reasonEcfFileNotFound += "   Variable ECF_FILES not defined:\n";
-    }
-
-#ifdef DEBUG_TASK_LOCATION
-    std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " searching ECF_HOME = '" << ecf_home
-              << "' backwards\n";
-#endif
-    if (!ecf_home.empty() && fs::is_directory(ecf_home)) {
-        // If search fails it returns an empty string, i.e. failure to locate script (Task/.ecf || Alias/.usr) file
-        std::string searchResult;
-        if (file_search_algo == EcfFile::PRUNE_ROOT)
-            searchResult = File::backwardSearch(ecf_home, theAbsNodePath, script_extension());
-        else
-            searchResult = File::forwardSearch(ecf_home, theAbsNodePath, script_extension());
-        if (searchResult.empty()) {
-            reasonEcfFileNotFound += "   Search of directory ECF_HOME(";
-            reasonEcfFileNotFound += ecf_home;
-            reasonEcfFileNotFound += ") failed ";
-            if (file_search_algo == EcfFile::PRUNE_ROOT)
-                reasonEcfFileNotFound += "using prune_root:\n";
-            else
-                reasonEcfFileNotFound += "using prune_leaf:\n";
-        }
-        else {
-            return EcfFile(const_cast<Submittable*>(this), searchResult, EcfFile::ECF_HOME, file_search_algo);
-        }
-    }
-    else {
-        reasonEcfFileNotFound += "   Directory ECF_HOME(";
-        reasonEcfFileNotFound += ecf_home;
-        reasonEcfFileNotFound += ") does not exist:\n";
-    }
-
-    // failed to find  .ecf file
-    std::string error_msg = "   Script for ";
-    error_msg += theAbsNodePath;
-    error_msg += " cannot be found:\n";
-    error_msg += reasonEcfFileNotFound;
-    throw std::runtime_error(error_msg);
-}
-
-void Submittable::set_jobs_password(const std::string& p) {
-    paswd_           = p;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Submittable::set_jobs_password\n";
-#endif
-}
-
-void Submittable::increment_try_no() {
-    // EVERY time we SUBMIT a job we must:
-    // - generate a password, and hence updated generated variable ECF_PASS
-    // - increment the try number
-    //   This means we also need to regenerate the variables
-    //   since ECF_TRYNO , ECF_JOB, ECF_JOBOUT depend on the try number.
-    //   ALSO, ECF_RID is updated with empty string
-    // - Clear the process/remote id. These will be reset by the child commands
-    // *** This MUST be done before pre-processing as it uses these variables ***
-    tryNo_++;
-    rid_.clear();
-    abr_.clear();
-    paswd_           = Passwd::generate();
-    state_change_no_ = Ecf::incr_state_change_no();
-    update_generated_variables();
-}
-
-void Submittable::clear() {
-    abr_.clear();   // reset reason aborted
-    paswd_.clear(); // reset password, it will be regenerated before submission
-    rid_.clear();   // reset process id
-    state_change_no_ = Ecf::incr_state_change_no();
-}
-
-bool Submittable::submitJob(JobsParam& jobsParam) {
-    increment_try_no();
-
-    return submit_job_only(jobsParam);
-}
-
-bool Submittable::submit_job_only(JobsParam& jobsParam) {
-#ifdef DEBUG_JOB_SUBMISSION
-    cerr << "Submittable::submit_job_only for task " << name() << endl;
-#endif
-
-    if (state() == NState::ACTIVE || state() == NState::SUBMITTED) {
-        std::stringstream ss;
-        ss << "Submittable::submit_job_only: failed: Submittable " << absNodePath() << " is already "
-           << NState::toString(state()) << " : ";
-        jobsParam.errorMsg() += ss.str();
-        flag().set(ecf::Flag::EDIT_FAILED);
-        return false;
-    }
-
-    // If the task is a dummy task, return true
-    std::string theValue;
-    if (findParentUserVariableValue(Str::ECF_DUMMY_TASK(), theValue)) {
-        return true;
-    }
-
-    // state change
-    flag().clear(ecf::Flag::NO_SCRIPT);
-    flag().clear(ecf::Flag::EDIT_FAILED);
-    flag().clear(ecf::Flag::JOBCMD_FAILED);
-    flag().clear(ecf::Flag::KILLCMD_FAILED);
-    flag().clear(ecf::Flag::STATUSCMD_FAILED);
-    flag().clear(ecf::Flag::KILLED);
-    flag().clear(ecf::Flag::STATUS);
-    requeue_labels(); // ECFLOW-195, requeue no longer resets labels on tasks, hence we do it at task run time.
-
-    theValue.clear();
-    if (findParentUserVariableValue(Str::ECF_NO_SCRIPT(), theValue)) {
-        // The script is based on the ECF_JOB_CMD
-        return non_script_based_job_submission(jobsParam);
-    }
-
-    return script_based_job_submission(jobsParam);
-}
-
-bool Submittable::script_based_job_submission(JobsParam& jobsParam) {
-    try {
-        // Locate the ecf files corresponding to the task.
-        // Assign lifetime of EcfFile to JobsParam.
-        // Minimise memory allocation/de-allocation with Job lines, and allow _include file_ caching
-        jobsParam.set_ecf_file(locatedEcfFile());
-
-        // Pre-process ecf file (i.e. expand includes, remove comments,manual) and perform
-        // variable substitution. This will then form the '.job' files.
-        // If the job file already exist it is overridden
-        // The job file SHOULD be referenced in ECF_JOB_CMD
-        try {
-            const std::string& job_size = jobsParam.ecf_file().create_job(jobsParam);
-
-            //... make sure ECF_PASS is set on the task, This is substituted in <head.h> file
-            //... and hence must be done before variable substitution in ECF_/JOB file
-            //... This is used by client->server authentication
-            if (createChildProcess(jobsParam)) {
-                set_state(NState::SUBMITTED, false, job_size);
-                return true;
-            }
-            // Fall through job submission failed.
-        }
-        catch (std::exception& e) {
-            flag().set(ecf::Flag::EDIT_FAILED);
-            std::string reason = "Submittable::submit_job_only: Job creation failed for task ";
-            reason += absNodePath();
-            reason += " : \n   ";
-            reason += e.what();
-            reason += "\n";
-            jobsParam.errorMsg() += reason;
-            set_aborted_only(reason);
-            return false;
-        }
-    }
-    catch (std::exception& e) {
-        flag().set(ecf::Flag::NO_SCRIPT);
-        std::stringstream ss;
-        ss << "Submittable::submit_job_only: Script location failed for task " << absNodePath() << " :\n"
-           << e.what() << "\n";
-        jobsParam.errorMsg() += ss.str();
-        set_aborted_only(e.what()); // remember jobsParam.errorMsg() is accumulated
-        return false;
-    }
-
-    flag().set(ecf::Flag::JOBCMD_FAILED);
-    std::string reason = " Job creation failed for task ";
-    reason += absNodePath();
-    reason += " could not create child process.";
-    jobsParam.errorMsg() += reason;
-    set_aborted_only(reason);
-    return false;
-}
-
-bool Submittable::non_script_based_job_submission(JobsParam& jobsParam) {
-    // No script(i.e. .ecf file), hence it is assumed the ECF_JOB_CMD will call:
-    //  ECF_PASS=%ECF_PASS%;ECF_PORT=%ECF_PORT%;ECF_HOST=%ECF_HOST%;ECF_NAME=%ECF_NAME%;ECF_TRYNO=%ECF_TRYNO%;
-    //  ecflow_client --init %%;
-    //     . some user script, or in-line command, should use full path.;
-    //     ecflow_client (--meter,--event,--label);
-    //  ecflow_client --hcomplete
-
-    if (createChildProcess(jobsParam)) {
-        set_state(NState::SUBMITTED, false, Str::EMPTY() /*job size*/);
-        return true;
-    }
-
-    // Fall through job submission failed.
-    flag().set(ecf::Flag::JOBCMD_FAILED);
-    std::string reason = " Job creation failed for task ";
-    reason += absNodePath();
-    reason += " could not create child process.";
-    jobsParam.errorMsg() += reason;
-    set_aborted_only(reason);
-    return false;
-}
-
-class JobCreationTimer {
-public:
-    explicit JobCreationTimer(Submittable* sub) : enabled_(false), failed_(false), sub_(sub) {}
-    // Disable copy (and move) semantics
-    JobCreationTimer(const JobCreationTimer&)                  = delete;
-    const JobCreationTimer& operator=(const JobCreationTimer&) = delete;
-
-    ~JobCreationTimer() {
-        if (enabled_) {
-            std::cout << " " << sub_->absNodePath();
-            if (failed_)
-                std::cout << " (FAILED)\n";
-            else {
-                boost::posix_time::time_duration duration = Calendar::second_clock_time() - start_;
-                std::cout << " (" << duration.total_microseconds() << " ms)\n";
-            }
-        }
-    }
-
-    void set_enabled() {
-        enabled_ = true;
-        start_   = Calendar::second_clock_time();
-    }
-
-    void set_failed() { failed_ = true; }
-
-private:
-    bool enabled_;
-    bool failed_;
-    Submittable* sub_;
-    boost::posix_time::ptime start_;
-};
-
-void Submittable::check_job_creation(job_creation_ctrl_ptr jobCtrl) {
-    JobCreationTimer output_tasks_being_checked(this);
-    if (jobCtrl->verbose())
-        output_tasks_being_checked.set_enabled();
-
-    // Typically a valid try number is >=1.
-    // Since check_job_creation is only used for testing/python, we will initialise tryNum to -1
-    // so that when it is incremented it will be a try_no of zero. *zero is an invalid try_no *
-    tryNo_ = -1;
-
-    /// call just before job submission, reset data members, update try_no, and *** generate variable ***
-    increment_try_no();
-
-    if (!jobCtrl->dir_for_job_creation().empty()) {
-        /// Override ECF_JOB, can be done by either adding a new user variable of same name
-        /// or the generated variable. We choose generated, since this is automatically reset.
-        /// before a real job submission
-        std::string tmpLocationForJob = jobCtrl->dir_for_job_creation();
-        tmpLocationForJob += absNodePath();
-        tmpLocationForJob += File::JOB_EXTN();
-        tmpLocationForJob += "0"; // try number of zero ( i.e. an invalid try number)
-        set_genvar_ecfjob(tmpLocationForJob);
-    }
-
-    // Before we had a Local JobsParam  here
-    // By using the JobsParam on job_creation_ctrl_ptr, we get the effect of USING a cache.
-    // EcfFile stored on JobsParam has cache. This cache avoids opening include files more than once.
-    // Since we have a Single job_creation_ctrl_ptr, hence single JobsParam, hence single EcfFile
-    // the cache is applied for ALL tasks. See ECFLOW-1210
-    jobCtrl->jobsParam().clear(); // allow jobsParam to be re-used by clearing
-    LOG_ASSERT(!jobCtrl->jobsParam().spawnJobs(), "spawn jobs should be disabled for check job creation");
-    LOG_ASSERT(!jobCtrl->jobsParam().createJobs(), "create jobs should be disabled for check job creation");
-    if (submit_job_only(jobCtrl->jobsParam())) {
-        return;
-    }
-    output_tasks_being_checked.set_failed();
-
-    std::string errorMsg = jobCtrl->jobsParam().getErrorMsg();
-    LOG_ASSERT(!errorMsg.empty(), "failing to submit must raise an error message");
-
-    jobCtrl->error_msg() += errorMsg;
-    jobCtrl->push_back_failing_submittable(dynamic_pointer_cast<Submittable>(shared_from_this()));
-}
-
-bool Submittable::run(JobsParam& jobsParam, bool force) {
-    if (force || ((state() != NState::SUBMITTED) && (state() != NState::ACTIVE))) {
-
-        if (jobsParam.createJobs()) {
-
-            return submitJob(jobsParam);
-        }
-        else {
-            /// This is only for test path. Just return true
-            return true;
-        }
-    }
-    std::stringstream ss;
-    ss << "Submittable::run: Aborted for task " << absNodePath() << " because state is " << NState::toString(state())
-       << " and force not set\n";
-    jobsParam.errorMsg() += ss.str();
-    return false;
-}
-
-void Submittable::kill(const std::string& zombie_pid) {
-    flag().clear(ecf::Flag::KILLCMD_FAILED);
-    flag().clear(ecf::Flag::KILLED);
-
-    std::string ecf_kill_cmd;
-    if (zombie_pid.empty()) {
-        if (state() != NState::ACTIVE && state() != NState::SUBMITTED) {
-            return;
-        }
-
-        // *** Generated variables are *NOT* persisted.                                     ***
-        // *** Hence if we have recovered from a check point file, then they will be empty. ***
-        // *** i.e. terminate server with active jobs, restart from saved check_pt file
-        // *** and then try to kill the active job, will get an exception( see below) since
-        // *** Generated variable ECF_RID will be empty.
-        if (!sub_gen_variables_) {
-            // std::cout << "Generated variables empty, regenerating !!!!!\n";
-            update_generated_variables();
-        }
-
-        /// If we are in active state, then ECF_RID must have been setup
-        /// This is typically used in the KILL CMD, make sure its there
-        if (state() == NState::ACTIVE && get_genvar_ecfrid().theValue().empty()) {
-            flag().set(ecf::Flag::KILLCMD_FAILED);
-            std::stringstream ss;
-            ss << "Submittable::kill: Generated variable ECF_RID is empty for task " << absNodePath();
-            throw std::runtime_error(ss.str());
-        }
-
-        if (!findParentUserVariableValue(Str::ECF_KILL_CMD(), ecf_kill_cmd) || ecf_kill_cmd.empty()) {
-            flag().set(ecf::Flag::KILLCMD_FAILED);
-            std::stringstream ss;
-            ss << "Submittable::kill: ECF_KILL_CMD not defined, for task " << absNodePath() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else {
-        // Use input
-        if (!findParentUserVariableValue(Str::ECF_KILL_CMD(), ecf_kill_cmd) || ecf_kill_cmd.empty()) {
-            flag().set(ecf::Flag::KILLCMD_FAILED);
-            std::stringstream ss;
-            ss << "Submittable::kill: ECF_KILL_CMD not defined, for task " << absNodePath() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-
-        // replace %ECF_RID% with the input args
-        Str::replace(ecf_kill_cmd, "%ECF_RID%", zombie_pid);
-    }
-
-    if (!variableSubstitution(ecf_kill_cmd)) {
-        flag().set(ecf::Flag::KILLCMD_FAILED);
-        std::stringstream ss;
-        ss << "Submittable::kill: Variable substitution failed for ECF_KILL_CMD(" << ecf_kill_cmd << ") on task "
-           << absNodePath() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // Please note: this is *non-blocking* the output of the command(ECF_KILL_CMD) should be written to %ECF_JOB%.kill
-    // The output is accessible via the --file cmd
-    // Done as two separate steps as kill command is not blocking on the server
-    //   LOG(Log::DBG,"Submittable::kill " << absNodePath() << "  " << ecf_kill_cmd );
-    std::string errorMsg;
-    if (!System::instance()->spawn(System::ECF_KILL_CMD, ecf_kill_cmd, absNodePath(), errorMsg)) {
-        flag().set(ecf::Flag::KILLCMD_FAILED);
-        throw std::runtime_error(errorMsg);
-    }
-    flag().set(ecf::Flag::KILLED);
-}
-
-void Submittable::status() {
-    // Jobs::generate will un-block SIGCHLD (by using Signal class)
-    // This will allow child process termination to handled by the signal handler in System
-    // Note:: Jobs::generate is called every minute *AND* when there is a state change.
-    flag().clear(ecf::Flag::STATUSCMD_FAILED);
-    flag().clear(ecf::Flag::STATUS);
-
-    // Note: Only is active state do we have a ECF_RID
-    if (state() != NState::ACTIVE && state() != NState::SUBMITTED) {
-        flag().set(ecf::Flag::STATUSCMD_FAILED);
-        std::stringstream ss;
-        ss << "Submittable::status: To use status command on a *single* node(" << absNodePath()
-           << ") it must be active or submitted";
-        throw std::runtime_error(ss.str());
-    }
-
-    // *** Generated variables are *NOT* persisted.                                     ***
-    // *** Hence if we have recovered from a check point file, then they will be empty. ***
-    // *** i.e. terminate server with active jobs, restart from saved check_pt file
-    // *** and then try to kill/status the active job, will get an exception(see below) since
-    // *** Generated variable ECF_RID will be empty.
-    if (!sub_gen_variables_) {
-        // std::cout << "Generated variables empty, regenerating !!!!!\n";
-        update_generated_variables();
-    }
-
-    /// If we are in active state, then ECF_RID must have been setup
-    if (state() == NState::ACTIVE && get_genvar_ecfrid().theValue().empty()) {
-        flag().set(ecf::Flag::STATUSCMD_FAILED);
-        std::stringstream ss;
-        ss << "Submittable::status: Generated variable ECF_RID is empty for ACTIVE task " << absNodePath();
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string ecf_status_cmd;
-    if (!findParentUserVariableValue(Str::ECF_STATUS_CMD(), ecf_status_cmd) || ecf_status_cmd.empty()) {
-        flag().set(ecf::Flag::STATUSCMD_FAILED);
-        std::stringstream ss;
-        ss << "Submittable::status: ECF_STATUS_CMD not defined, for task " << absNodePath() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (!variableSubstitution(ecf_status_cmd)) {
-        flag().set(ecf::Flag::STATUSCMD_FAILED);
-        std::stringstream ss;
-        ss << "Submittable::status: Variable substitution failed for ECF_STATUS_CMD(" << ecf_status_cmd << ") on task "
-           << absNodePath() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // Please note: this is *non-blocking* the output of the command(ECF_STATUS_CMD) should be written to %ECF_JOB%.stat
-    // SPAWN process, attach signal to monitor process. returns true
-    std::string errorMsg;
-    if (!System::instance()->spawn(System::ECF_STATUS_CMD, ecf_status_cmd, absNodePath(), errorMsg)) {
-        flag().set(ecf::Flag::STATUSCMD_FAILED);
-        throw std::runtime_error(errorMsg);
-    }
-
-    flag().set(ecf::Flag::STATUS);
-}
-
-bool Submittable::createChildProcess(JobsParam& jobsParam) {
-#ifdef DEBUG_JOB_SUBMISSION
-    cout << "Submittable::createChildProcess for task " << name() << endl;
-#endif
-    std::string ecf_job_cmd;
-    findParentUserVariableValue(Str::ECF_JOB_CMD(), ecf_job_cmd);
-    if (ecf_job_cmd.empty()) {
-        jobsParam.errorMsg() += "Submittable::createChildProcess: Could not find ECF_JOB_CMD : ";
-        return false;
-    }
-
-    if (!variableSubstitution(ecf_job_cmd)) {
-        jobsParam.errorMsg() +=
-            "Submittable::createChildProcess: Variable substitution failed for ECF_JOB_CMD(" + ecf_job_cmd + ") :";
-        return false;
-    }
-
-    // Keep tabs on what was submitted for testing purposes
-    jobsParam.push_back_submittable(this);
-
-    if (jobsParam.spawnJobs()) {
-
-        // SPAWN process, attach signal to monitor process. returns true
-        return System::instance()->spawn(System::ECF_JOB_CMD, ecf_job_cmd, absNodePath(), jobsParam.errorMsg());
-    }
-
-    // Test path ONLY
-    return true;
-}
-
-void Submittable::set_aborted_only(const std::string& reason) {
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Submittable::set_aborted_only\n";
-#endif
-
-    abr_             = reason;
-    state_change_no_ = Ecf::incr_state_change_no();
-
-    // Do not use "\n" | ';' in abr_, as this can mess up, --migrate output
-    // Which would then affect --load.
-    Str::replace(abr_, "\n", "");
-    Str::replace(abr_, ";", " ");
-
-    // This will set the state and bubble up the most significant state
-    set_state(NState::ABORTED);
-}
-
-void Submittable::update_limits() {
-    NState::State task_state = state();
-    std::set<Limit*> limitSet; // ensure local limit have preference over parent
-    if (task_state == NState::COMPLETE) {
-        decrementInLimit(limitSet); // will recurse up
-    }
-    else if (task_state == NState::ABORTED) {
-        decrementInLimit(limitSet); // will recurse up
-    }
-    else if (task_state == NState::SUBMITTED) {
-        incrementInLimit(limitSet); // will recurse up
-    }
-    else if (task_state == NState::ACTIVE) {
-        // Only change those LIMITs where in-limit has -s i.e. limit submission
-        decrementInLimitForSubmission(limitSet); // will recurse up
-    }
-    else {
-        // UNKNOWN, QUEUED
-        // For all other states, this task should NOT be consuming a limit token.
-        // During interactive use a Submittable may get re-queued. In case its consuming
-        // a limit token, we decrement the limit. If we are NOT consuming
-        // a token, it's still *SAFE* to call decrementInLimit
-        decrementInLimit(limitSet); // will recurse up
-    }
-}
-
-// Memento ==========================================================
-void Submittable::incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Submittable::incremental_changes() " << debugNodePath() << "\n";
-#endif
-
-    if (state_change_no_ > changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<SubmittableMemento>(paswd_, rid_, abr_, tryNo_));
-    }
-
-    // ** if compound memento has children base class, will add it to DefsDelta
-    Node::incremental_changes(changes, comp);
-}
-
-void Submittable::set_memento(const SubmittableMemento* memento,
-                              std::vector<ecf::Aspect::Type>& aspects,
-                              bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Submittable::set_memento(const SubmittableMemento*) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::SUBMITTABLE);
-        return;
-    }
-
-    paswd_ = memento->paswd_;
-    rid_   = memento->rid_;
-    abr_   = memento->abr_;
-    tryNo_ = memento->tryNo_;
-}
-
-// Generated variables ---------------------------------------------------------------------------------
-
-void Submittable::update_generated_variables() const {
-    if (!sub_gen_variables_)
-        sub_gen_variables_ = new SubGenVariables(this);
-    sub_gen_variables_->update_generated_variables();
-    update_repeat_genvar();
-}
-
-void Submittable::update_static_generated_variables(const std::string& ecf_home,
-                                                    const std::string& theAbsNodePath) const {
-    if (!sub_gen_variables_)
-        sub_gen_variables_ = new SubGenVariables(this);
-    sub_gen_variables_->update_static_generated_variables(ecf_home, theAbsNodePath);
-}
-
-const Variable& Submittable::findGenVariable(const std::string& name) const {
-    // AST can reference generated variables. Currently, integer based values
-    // The task names can be integers, other valid option is try_no
-    if (!sub_gen_variables_)
-        update_generated_variables();
-
-    const Variable& gen_var = sub_gen_variables_->findGenVariable(name);
-    if (!gen_var.empty())
-        return gen_var;
-
-    return Node::findGenVariable(name);
-}
-
-void Submittable::gen_variables(std::vector<Variable>& vec) const {
-    if (!sub_gen_variables_)
-        update_generated_variables();
-
-    vec.reserve(vec.size() + 9);
-    sub_gen_variables_->gen_variables(vec);
-    Node::gen_variables(vec);
-}
-
-const Variable& Submittable::get_genvar_ecfrid() const {
-    if (!sub_gen_variables_)
-        return Variable::EMPTY();
-    return sub_gen_variables_->genvar_ecfrid();
-}
-
-const Variable& Submittable::get_genvar_ecfscript() const {
-    if (!sub_gen_variables_)
-        return Variable::EMPTY();
-    return sub_gen_variables_->genvar_ecfscript();
-}
-
-void Submittable::set_genvar_ecfjob(const std::string& value) {
-    if (!sub_gen_variables_)
-        sub_gen_variables_ = new SubGenVariables(this);
-    sub_gen_variables_->set_genvar_ecfjob(value);
-}
-
-void Submittable::set_genvar_ecfrid(const std::string& value) {
-    if (!sub_gen_variables_)
-        sub_gen_variables_ = new SubGenVariables(this);
-    sub_gen_variables_->set_genvar_ecfrid(value);
-}
-
-// Generated Variables ================================================================================================
-// The false below is used as a dummy argument to call the Variable constructor that does not
-// Check the variable names. i.e. we know they are valid
-SubGenVariables::SubGenVariables(const Submittable* sub)
-    : submittable_(sub),
-      genvar_ecfjob_(Str::ECF_JOB(), "", false),
-      genvar_ecfjobout_(Str::ECF_JOBOUT(), "", false),
-      genvar_ecftryno_(Str::ECF_TRYNO(), "", false),
-      genvar_task_("TASK", "", false),
-      genvar_ecfpass_(Str::ECF_PASS(), "", false),
-      genvar_ecfscript_(Str::ECF_SCRIPT(), "", false),
-      genvar_ecfname_(Str::ECF_NAME(), "", false),
-      genvar_ecfrid_(Str::ECF_RID(), "", false) {
-}
-
-void SubGenVariables::update_generated_variables() const {
-    // cache strings that are used in many variables
-    std::string theAbsNodePath = submittable_->absNodePath();
-    std::string ecf_home;
-    submittable_->findParentUserVariableValue(Str::ECF_HOME(), ecf_home);
-    update_static_generated_variables(ecf_home, theAbsNodePath);
-    update_dynamic_generated_variables(ecf_home, theAbsNodePath);
-}
-
-void SubGenVariables::update_static_generated_variables(const std::string& ecf_home,
-                                                        const std::string& theAbsNodePath) const {
-    // cache strings that are used in many variables
-    if (submittable_->isAlias() && submittable_->parent())
-        genvar_task_.set_value(submittable_->parent()->name()); // does *not* modify Variable::state_change_no
-    else
-        genvar_task_.set_value(submittable_->name());
-
-    genvar_ecfname_.set_value(theAbsNodePath); // does *not* modify Variable::state_change_no
-
-    genvar_ecfscript_.value_by_ref().reserve(ecf_home.size() + theAbsNodePath.size() + 4);
-    genvar_ecfscript_.value_by_ref() = ecf_home; // does *not* modify Variable::state_change_no
-    genvar_ecfscript_.value_by_ref() += theAbsNodePath;
-    genvar_ecfscript_.value_by_ref() += submittable_->script_extension();
-}
-
-void SubGenVariables::update_dynamic_generated_variables(const std::string& ecf_home,
-                                                         const std::string& theAbsNodePath) const {
-    // cache strings that are used in many variables
-    std::string the_try_no = submittable_->tryNo();
-
-    genvar_ecfrid_.set_value(submittable_->rid_);    // does *not* modify Variable::state_change_no
-    genvar_ecftryno_.set_value(the_try_no);          // does *not* modify Variable::state_change_no
-    genvar_ecfpass_.set_value(submittable_->paswd_); // does *not* modify Variable::state_change_no
-
-    /// The directory associated with ECF_JOB is automatically created if it does not exist.
-    /// This is Done during Job generation. See EcfFile::doCreateJobFile()
-    if (genvar_ecfjob_.value_by_ref().capacity() == 0) {
-        genvar_ecfjob_.value_by_ref().reserve(ecf_home.size() + theAbsNodePath.size() + File::JOB_EXTN().size() +
-                                              the_try_no.size());
-    }
-    genvar_ecfjob_.value_by_ref() = ecf_home; // does *not* modify Variable::state_change_no
-    genvar_ecfjob_.value_by_ref() += theAbsNodePath;
-    genvar_ecfjob_.value_by_ref() += File::JOB_EXTN();
-    genvar_ecfjob_.value_by_ref() += the_try_no;
-
-    /// If ECF_OUT is specified the user must ensure the directory exists, along with directories
-    /// associated with Suites/Families nodes.
-    /// Bottom up. Can be expensive when we have thousands of tasks.
-    std::string ecf_out;
-    submittable_->findParentUserVariableValue(Str::ECF_OUT(), ecf_out);
-
-    if (ecf_out.empty()) {
-        genvar_ecfjobout_.value_by_ref().reserve(ecf_home.size() + theAbsNodePath.size() + 1 + the_try_no.size());
-        genvar_ecfjobout_.value_by_ref() = ecf_home;
-    }
-    else {
-        // For metabuilder, where we use %ECF_HOME% for ECF_OUT
-        char micro = '%';
-        if (ecf_out.find(micro) != std::string::npos) {
-            NameValueMap user_edit_variables;
-            submittable_->variable_substitution(ecf_out, user_edit_variables, micro);
-        }
-        genvar_ecfjobout_.value_by_ref().reserve(ecf_out.size() + theAbsNodePath.size() + 1 + the_try_no.size());
-        genvar_ecfjobout_.value_by_ref() = ecf_out;
-    }
-    genvar_ecfjobout_.value_by_ref() += theAbsNodePath;
-    genvar_ecfjobout_.value_by_ref() += ".";
-    genvar_ecfjobout_.value_by_ref() += the_try_no;
-}
-
-const Variable& SubGenVariables::findGenVariable(const std::string& name) const {
-    if (genvar_ecfjob_.name() == name)
-        return genvar_ecfjob_;
-    if (genvar_ecfjobout_.name() == name)
-        return genvar_ecfjobout_;
-    if (genvar_ecftryno_.name() == name)
-        return genvar_ecftryno_;
-    if (genvar_ecfname_.name() == name)
-        return genvar_ecfname_;
-    if (genvar_task_.name() == name)
-        return genvar_task_;
-    if (genvar_ecfpass_.name() == name)
-        return genvar_ecfpass_;
-    if (genvar_ecfscript_.name() == name)
-        return genvar_ecfscript_;
-    if (genvar_ecfrid_.name() == name)
-        return genvar_ecfrid_;
-    return Variable::EMPTY();
-}
-
-void SubGenVariables::gen_variables(std::vector<Variable>& vec) const {
-    vec.push_back(genvar_task_);
-    vec.push_back(genvar_ecfjob_);
-    vec.push_back(genvar_ecfscript_);
-    vec.push_back(genvar_ecfjobout_);
-    vec.push_back(genvar_ecftryno_);
-    vec.push_back(genvar_ecfrid_);
-    vec.push_back(genvar_ecfname_);
-    vec.push_back(genvar_ecfpass_);
-}
-
-template <class Archive>
-void Submittable::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Node>(this));
-
-    CEREAL_OPTIONAL_NVP(ar, paswd_, [this]() { return !paswd_.empty(); }); // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, rid_, [this]() { return !rid_.empty(); });     // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, abr_, [this]() { return !abr_.empty(); });     // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, tryNo_, [this]() { return tryNo_ != 0; });     // conditionally save
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(Submittable);
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Submittable.hpp 5.13.0-1/ANode/src/ecflow/node/Submittable.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Submittable.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Submittable.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,203 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Submittable_HPP
-#define ecflow_node_Submittable_HPP
-
-#include "ecflow/node/Node.hpp"
-
-class EcfFile;
-class SubGenVariables;
-
-class Submittable : public Node {
-protected:
-    Submittable(const std::string& name, bool check) : Node(name, check) {}
-    Submittable() = default;
-    Submittable(const Submittable& rhs)
-        : Node(rhs),
-          paswd_(rhs.paswd_),
-          rid_(rhs.rid_),
-          abr_(rhs.abr_),
-          tryNo_(rhs.tryNo_),
-          state_change_no_(0) {}
-
-    Submittable& operator=(const Submittable&);
-
-    bool operator==(const Submittable& rhs) const;
-
-public:
-    ~Submittable() override;
-    bool check_defaults() const override;
-
-    /// Initialise the task. will set the state to NState::ACTIVE
-    void init(const std::string& processId);
-
-    /// complete the task. Will set the state to NState::COMPLETE
-    /// However if there is a valid Repeat or time dependencies then
-    /// task will be re-queued afterwards
-    void complete();
-
-    /// The late attribute, ONLY applies to the Submittable and not NodeContainer
-    bool calendarChanged(const ecf::Calendar&,
-                         Node::Calendar_args&,
-                         const ecf::LateAttr* inherited_late,
-                         bool holding_parent_day_or_date) override;
-
-    /// Overridden to reset the try number
-    /// The tasks job can be invoked multiple times. For each invocation we want to preserve
-    /// the output. The try number is used in SMSJOB/SMSJOBOUT to preserve the output when
-    /// there are multiple runs.  re-queue/begin() resets the try Number
-    void reset() override;
-    void begin() override;
-    void requeue(Requeue_args&) override;
-    bool run(JobsParam& jobsParam, bool force) override;
-    void kill(const std::string& zombie_pid = "") override;
-    void status() override;
-
-    void update_generated_variables() const override;
-    const Variable& findGenVariable(const std::string& name) const override;
-    void gen_variables(std::vector<Variable>& vec) const override;
-
-    static const std::string& DUMMY_JOBS_PASSWORD();
-    static const std::string& FREE_JOBS_PASSWORD();
-    static const std::string& DUMMY_PROCESS_OR_REMOTE_ID();
-
-    // returns the corresponding .ecf file.
-    // i.e if the ecf file is missing or empty std::runtime_error is thrown
-    // For dummy tasks, i.e tasks with no .ecf file user should add ECF_DUMMY_TASK variable
-    EcfFile locatedEcfFile() const;
-    virtual const std::string& script_extension() const = 0;
-
-    /// Spawn of a child process. Clear process and remote id before jobs is spawned
-    /// Will increment try no first, and then update generated varaibles
-    bool submitJob(JobsParam&);
-
-    /// generates job file independent of dependencies, resets the try Number
-    void check_job_creation(job_creation_ctrl_ptr jobCtrl) override;
-
-    /// See Defs.hpp
-    void generate_scripts(const std::map<std::string, std::string>&) const override {}
-
-    NState::State computedState(Node::TraverseType) const override { return state(); }
-
-    /// data members accessor's and mutators:
-    /// return the current try number as a string, and int
-    std::string tryNo() const;
-    int try_no() const { return tryNo_; }
-
-    const std::string& jobsPassword() const { return paswd_; }
-
-    /// The remote id (ECF_RID) allows a jobs to be killed when added via a queueing system
-    /// in which case the remote id is really the queueing id.
-    const std::string& process_or_remote_id() const { return rid_; }
-
-    /// Set the task to aborted, providing a reason. Will set the state to NState::ABORTED
-    /// This should only be called in two context's:
-    ///    1/ Called via Child Cmd (AbortCmd) i.e job raised a trap,
-    ///    2/ Abnormal process termination. i.e job killed by signal
-    /// *IMPORTANT* If task try number is less than ECF_TRIES then we should
-    /// resubmit the job. However we *should* not do this immediately here, instead we
-    /// wait of *next* call to resolveDependencies, as that will check if we are *inlimit*
-    void aborted(const std::string& reason);
-    const std::string& abortedReason() const override { return abr_; }
-
-    // Memento functions:
-    void incremental_changes(DefsDelta&, compound_memento_ptr& comp) const;
-    void set_memento(const SubmittableMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
-
-    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
-
-protected:
-    void write_state(std::string&, bool&) const override;
-
-    /// call just before job submission, reset data members, update try_no, and generate variable
-    void increment_try_no(); // will increment state_change_no
-
-    /// Submits the job *WITHOUT* incrementing the try number
-    bool submit_job_only(JobsParam&);
-
-    // Overridden from Node to increment/decrement limits
-    void update_limits() override;
-
-private:
-    friend class ZombieCtrl;
-    friend class AlterCmd;
-
-    void set_jobs_password(const std::string& p);
-    void set_process_or_remote_id(const std::string&);
-
-    // Use when we _only_ want to set the state,
-    void set_aborted_only(const std::string& reason);
-    bool createChildProcess(JobsParam& jobsParam);
-    void clear(); // process_id password and aborted reason
-
-    bool script_based_job_submission(JobsParam& jobsParam);
-    bool non_script_based_job_submission(JobsParam& jobsParam);
-
-    void update_static_generated_variables(const std::string& ecf_home, const std::string& theAbsNodePath) const;
-    const Variable& get_genvar_ecfrid() const;
-    const Variable& get_genvar_ecfscript() const;
-    void set_genvar_ecfjob(const std::string& value);
-    void set_genvar_ecfrid(const std::string& value);
-
-private:
-    std::string paswd_;
-    std::string rid_;
-    std::string abr_;
-    int tryNo_{0};
-    unsigned int state_change_no_{0};                     // *not* persisted, only used on server side
-    mutable SubGenVariables* sub_gen_variables_{nullptr}; // *not* persisted since they can be generated
-    friend class SubGenVariables;
-
-private:
-    // never change defaults !! or will mess up client/server protocol
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-};
-
-// We can have several thousands Submittables. This class helps in avoiding
-// the creation of generated variables until required.
-// This improves client->server down load times by avoiding thousands of string constructions
-class SubGenVariables {
-public:
-    explicit SubGenVariables(const Submittable*);
-    // Disable copy (and move) semantics
-    SubGenVariables(const SubGenVariables&)                  = delete;
-    const SubGenVariables& operator=(const SubGenVariables&) = delete;
-
-    void update_generated_variables() const;
-
-    /// distinguish between the two kinds of generated variables
-    void update_static_generated_variables(const std::string& ecf_home, const std::string& theAbsNodePath) const;
-    void update_dynamic_generated_variables(const std::string& ecf_home, const std::string& theAbsNodePath) const;
-
-    const Variable& findGenVariable(const std::string& name) const;
-    void gen_variables(std::vector<Variable>& vec) const;
-
-    const Variable& genvar_ecfrid() const { return genvar_ecfrid_; }
-    const Variable& genvar_ecfscript() const { return genvar_ecfscript_; }
-
-    void set_genvar_ecfjob(const std::string& value) { genvar_ecfjob_.set_value(value); }
-    void set_genvar_ecfrid(const std::string& value) { genvar_ecfrid_.set_value(value); }
-
-private:
-    const Submittable* submittable_;
-    mutable Variable genvar_ecfjob_;
-    mutable Variable genvar_ecfjobout_;
-    mutable Variable genvar_ecftryno_;
-    mutable Variable genvar_task_;
-    mutable Variable genvar_ecfpass_;
-    mutable Variable genvar_ecfscript_;
-    mutable Variable genvar_ecfname_;
-    mutable Variable genvar_ecfrid_;
-};
-
-#endif /* ecflow_node_Submittable_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Suite.cpp 5.13.0-1/ANode/src/ecflow/node/Suite.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Suite.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Suite.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,982 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Suite.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/DefsDelta.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/NodeTreeVisitor.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-///////////////////////////////////////////////////////////////////////////////////////////
-// #define DEBUG_FIND_NODE 1
-
-// Create the generated variable up-front. This allows them to be referenced
-// is abstract syntax tree during the post process call
-
-Suite::Suite(const Suite& rhs) : NodeContainer(rhs), begun_(rhs.begun_) {
-    if (rhs.clockAttr_.get())
-        clockAttr_ = std::make_shared<ClockAttr>(*rhs.clockAttr_);
-
-    if (rhs.clock_end_attr_.get())
-        clock_end_attr_ = std::make_shared<ClockAttr>(*rhs.clock_end_attr_);
-
-    cal_ = rhs.cal_;
-}
-
-node_ptr Suite::clone() const {
-    return std::make_shared<Suite>(*this);
-}
-
-Suite& Suite::operator=(const Suite& rhs) {
-    // defs_ not set
-    if (this != &rhs) {
-        NodeContainer::operator=(rhs);
-        begun_ = rhs.begun_;
-        if (rhs.clockAttr_.get())
-            clockAttr_ = std::make_shared<ClockAttr>(*rhs.clockAttr_);
-        if (rhs.clock_end_attr_.get())
-            clock_end_attr_ = std::make_shared<ClockAttr>(*rhs.clock_end_attr_);
-        cal_ = rhs.cal_;
-
-        state_change_no_    = 0;
-        modify_change_no_   = Ecf::incr_modify_change_no();
-        begun_change_no_    = 0;
-        calendar_change_no_ = 0;
-
-        delete suite_gen_variables_;
-        suite_gen_variables_ = nullptr;
-    }
-    return *this;
-}
-
-Suite::~Suite() {
-    //	std::cout << "Suite::~Suite() " << debugNodePath() << "\n";
-    if (!Ecf::server()) {
-        notify_delete();
-    }
-    delete suite_gen_variables_;
-}
-
-suite_ptr Suite::create(const std::string& name, bool check) {
-    return std::make_shared<Suite>(name, check);
-}
-
-suite_ptr Suite::create_me(const std::string& name) {
-    return std::make_shared<Suite>(name, true);
-}
-
-bool Suite::check_defaults() const {
-    if (defs_ != nullptr)
-        throw std::runtime_error("Suite::check_defaults(): defs_ != nullptr");
-    if (begun_ != false)
-        throw std::runtime_error("Suite::check_defaults():  begun_ != false");
-    if (state_change_no_ != 0)
-        throw std::runtime_error("Suite::check_defaults():  state_change_no_ != 0");
-    if (modify_change_no_ != 0)
-        throw std::runtime_error("Suite::check_defaults(): modify_change_no_ != 0 ");
-    if (begun_change_no_ != 0)
-        throw std::runtime_error("Suite::check_defaults():  begun_change_no_ != 0");
-    if (calendar_change_no_ != 0)
-        throw std::runtime_error("Suite::check_defaults(): calendar_change_no_ != 0");
-    if (suite_gen_variables_ != nullptr)
-        throw std::runtime_error("Suite::check_defaults(): suite_gen_variables_ != nullptr");
-    return NodeContainer::check_defaults();
-}
-
-void Suite::accept(ecf::NodeTreeVisitor& v) {
-    SuiteChanged1 changed(this);
-    v.visitSuite(this);
-    NodeContainer::accept(v);
-}
-
-void Suite::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
-    SuiteChanged1 changed(this);
-    v.visitSuite(this);
-}
-
-void Suite::begin() {
-    if (false == begun_) {
-
-        // begin will change all the states of all child nodes, reset all attributes
-        SuiteChanged1 changed(this);
-
-        // begin can cause thousands of mementos to be created, to avoid this we
-        // update the modify change number.
-        Ecf::incr_modify_change_no();
-
-        begun_           = true;
-        begun_change_no_ = Ecf::incr_state_change_no();
-
-        begin_calendar();
-
-        NodeContainer::begin();
-
-        update_generated_variables();
-    }
-}
-
-void Suite::requeue(Requeue_args& args) {
-    if (false == begun_) {
-        std::stringstream ss;
-        ss << "Suite::requeue: The suite " << name() << " must be 'begun' first\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // This is more efficient than: since no locking is required
-    //    SuiteChanged changed(std::dynamic_pointer_cast<Suite>(shared_from_this()));
-    // since no locking is required in SuiteChanged
-    SuiteChanged1 changed(this); //
-
-    // requeue can cause thousands of mementos to be created, to avoid this we
-    // update the modify change number, this will force a full sync in client
-    Ecf::incr_modify_change_no();
-
-    requeue_calendar();
-
-    NodeContainer::requeue(args);
-
-    update_generated_variables();
-}
-
-void Suite::reset() {
-    // reset will change all the states of all child nodes, reset all attributes
-    SuiteChanged1 changed(this);
-
-    // reset can cause thousands of mementos to be created, to avoid this we
-    // update the modify change number.
-    Ecf::incr_modify_change_no();
-
-    reset_begin_only();
-
-    requeue_calendar();
-
-    NodeContainer::reset();
-}
-
-void Suite::handle_migration(const ecf::Calendar& c) {
-    // called when defs is read in from a file i.e. checkpoint
-
-    NodeContainer::handle_migration(c);
-}
-
-void Suite::reset_begin() {
-    SuiteChanged1 changed(this);
-    reset_begin_only();
-}
-
-void Suite::reset_begin_only() // private
-{
-    begun_           = false;
-    begun_change_no_ = Ecf::incr_state_change_no();
-}
-
-void Suite::begin_calendar() {
-    // Begin the calendar, from the clock attribute _ELSE_
-    // Get the local time, second level resolution, based on the
-    // time zone settings of the computer.
-    if (clockAttr_.get()) {
-        clockAttr_->init_calendar(cal_); // *IF* AlterCmd was used, wait till Suite is requed
-        clockAttr_->begin_calendar(cal_);
-    }
-    else {
-        cal_.begin(Calendar::second_clock_time());
-    }
-}
-
-void Suite::requeue_calendar() {
-    // ECFLOW-417
-    // Need special handling for a Suite with hybrid clock and repeat day variable.
-    // Basically on re-queue, we need to update calendar date by the repeat day variable
-    if (clockAttr_.get() && clockAttr_->hybrid() && repeat().is_repeat_day()) {
-
-        // Get the current time, but with the *existing* date of the suite
-        boost::gregorian::date suite_date = cal_.suiteTime().date();
-        suite_date += date_duration(repeat().step());
-
-        ptime suiteTime = ptime(suite_date, Calendar::second_clock_time().time_of_day());
-        cal_.begin(suiteTime);
-
-        // make sure update variable regenerates all suite variables, i.e like ECF_DATE, etc
-        // Needed since we have changed calendar date
-        if (suite_gen_variables_)
-            suite_gen_variables_->force_update();
-
-        return;
-    }
-
-    // Carry on same as before
-    begin_calendar();
-}
-
-void Suite::updateCalendar(const ecf::CalendarUpdateParams& calParams, Node::Calendar_args& cal_args) {
-    if (begun_) {
-        //		cout << "Suite::updateCalendar " << debugNodePath()   << " serverRunning = " <<
-        // calParams.serverRunning() << " jobSubInterval = " << to_simple_string(calParams.serverPollPeriod());
-        // cout <<
-        //"\n";
-
-        SuiteChanged1 changed(this);
-
-        /// The cal_ will cache server poll period/job submission interval, as calendar increment for easy access
-        cal_.update(calParams);
-        calendar_change_no_ = Ecf::state_change_no() + 1; // ** See: collateChanges **
-
-        update_generated_variables();
-
-        (void)calendarChanged(cal_, cal_args, get_late(), false /*holding_parent_day_or_date*/);
-    }
-}
-
-bool Suite::resolveDependencies(JobsParam& jobsParam) {
-    if (begun_) {
-        SuiteChanged1 changed(this);
-
-        // improve resolution of state change time. ECFLOW-1512
-        boost::posix_time::ptime time_now = Calendar::second_clock_time();
-        cal_.update_duration_only(time_now);
-
-        //  ** See: collateChanges  and ECFLOW-1512
-        // Updating calendar_change_no_ ensure we sync suite calendar.
-        // additionally this will end up adding one more memento(SuiteCalendarMemento),
-        // and thus affects python changed_node_paths
-        calendar_change_no_ = Ecf::state_change_no() + 1;
-
-        if (jobsParam.check_for_job_generation_timeout(time_now))
-            return false;
-        return NodeContainer::resolveDependencies(jobsParam);
-    }
-    return true;
-}
-
-bool Suite::operator==(const Suite& rhs) const {
-    if (begun_ != rhs.begun_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Suite::operator==  (begun_(" << begun_ << ") != rhs.begun_(" << rhs.begun_ << ")) "
-                      << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    if ((clockAttr_.get() && !rhs.clockAttr_.get()) || (!clockAttr_.get() && rhs.clockAttr_.get())) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Suite::operator==(clockAttr_.get() && !rhs.clockAttr_.get()) || (!clockAttr_.get() && "
-                         "rhs.clockAttr_.get() "
-                      << debugNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-    if (clockAttr_.get() && rhs.clockAttr_.get() && !(*clockAttr_ == *rhs.clockAttr_)) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Suite::operator== (clockAttr_ && rhs.clockAttr_ && !(*clockAttr_ == *rhs.clockAttr_)) "
-                      << debugNodePath() << "\n";
-            std::cout << "clockAttr_: " << clockAttr_->toString() << "  rhs.clockAttr_: " << rhs.clockAttr_->toString()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-
-    return NodeContainer::operator==(rhs);
-}
-
-void Suite::print(std::string& os) const {
-    Indentor::indent(os);
-    os += "suite ";
-    os += name();
-    if (!PrintStyle::defsStyle()) {
-        bool added_comment_char = false;
-        write_state(os, added_comment_char);
-    }
-    os += "\n";
-
-    Node::print(os);
-
-    // make sure clock attribute is written before
-    if (clockAttr_.get())
-        clockAttr_->print(os);
-    if (clock_end_attr_.get())
-        clock_end_attr_->print(os);
-    if (!PrintStyle::defsStyle()) {
-        if (!cal_.is_special()) {
-            Indentor indent;
-            Indentor::indent(os);
-            os += "calendar";
-            cal_.write_state(os);
-            os += "\n";
-        }
-    }
-
-    NodeContainer::print(os);
-    Indentor::indent(os);
-    os += "endsuite\n";
-}
-
-void Suite::write_state(std::string& ret, bool& added_comment_char) const {
-    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e.
-    //                 `task a; task b;`
-    if (begun_) {
-        add_comment_char(ret, added_comment_char);
-        ret += " begun:1";
-    }
-    NodeContainer::write_state(ret, added_comment_char);
-}
-void Suite::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
-
-    // suite s1 # begun:1 state:queued flag:edit_failed suspended:1
-    if (lineTokens.size() >= 4 && lineTokens[3] == "begun:1")
-        begun_ = true;
-    NodeContainer::read_state(line, lineTokens);
-}
-
-const std::string& Suite::debugType() const {
-    return ecf::Str::SUITE();
-}
-
-std::ostream& operator<<(std::ostream& os, const Suite& d) {
-    std::string s;
-    d.print(s);
-    os << s;
-    return os;
-}
-
-void Suite::addClock(const ClockAttr& c, bool initialize_calendar) {
-    if (clockAttr_.get()) {
-        throw std::runtime_error("Add Clock failed: Suite can only have one clock " + absNodePath());
-    }
-    if (clock_end_attr_.get()) {
-        if (clock_end_attr_->ptime() <= c.ptime()) {
-            throw std::runtime_error("Add Clock failed:: End time must be greater than start time " + absNodePath());
-        }
-    }
-
-    clockAttr_ = std::make_shared<ClockAttr>(c);
-    if (initialize_calendar)
-        clockAttr_->init_calendar(cal_);
-
-    // clock_end_attr_ is always same type as clock
-    if (clock_end_attr_.get())
-        clock_end_attr_->hybrid(clockAttr_->hybrid());
-}
-
-void Suite::changeClock(const ClockAttr& c) {
-    // When changing the clock, *WAIT* till requeue/begin to init the calendar
-    clockAttr_.reset();
-    addClock(c, false);
-}
-
-void Suite::add_end_clock(const ClockAttr& c) {
-    // end clock is for simulator only
-    if (clock_end_attr_.get()) {
-        throw std::runtime_error("Add end Clock failed: Suite can only have one end clock " + absNodePath());
-    }
-    if (clockAttr_.get()) {
-        if (c.ptime() <= clockAttr_->ptime()) {
-            throw std::runtime_error("Add end Clock failed: End time must be greater than start time " + absNodePath());
-        }
-    }
-
-    clock_end_attr_ = std::make_shared<ClockAttr>(c);
-    clock_end_attr_->set_end_clock();
-
-    // clock_end_attr_ is always same type as clock
-    if (clockAttr_.get())
-        clock_end_attr_->hybrid(clockAttr_->hybrid());
-}
-
-void Suite::changeClockType(const std::string& clockType) {
-    // ISSUES:
-    // Whenever the user *alters* the clock attributes, it needs to be followed by a re-queue of the suite, because:
-    //   o/ if we change from real ->hybrid, then we need to set cron, etc. time based nodes to complete
-    //      Since we could have running tasks, it is up to user to decide when.
-    //   o/ If we change from hybrid ->real, then Node with cron attributes etc., need to be re-queued.
-    //   o/ Any relative times are no longer valid
-    //   o/ Time attributes will be incorrect, and hence may fail/pass incorrectly during dependency evaluation.
-    //   o/ Why command may be wrong
-    //
-    //
-    // *IF* the user *forgets* to do this, it can cause spurious errors, hence to *minimise* these
-    // the best we can do is to :
-    //   o/ re-sync suite calendar for clock attribute
-    //   o/ re-queue all time based attributes, *avoiding*
-    //      change of state when switching to hybrid clock (i.e. due to day,date,cron time attrs)
-    // This is handled in handle_clock_attribute_change()
-    //
-
-    if (clockType != "hybrid" && clockType != "real") {
-        throw std::runtime_error("Suite::changeClockType: expected clock type to be 'hybrid' or 'real'  but found " +
-                                 clockType);
-    }
-
-    SuiteChanged1 changed(this);
-    if (clockAttr_.get()) {
-        clockAttr_->hybrid(clockType == "hybrid"); // will update state change_no
-    }
-    else {
-        addClock(ClockAttr(clockType == "hybrid")); // will update state change_no
-    }
-
-    // clock_end_attr_ is always same type as clock
-    if (clock_end_attr_.get())
-        clock_end_attr_->hybrid(clockAttr_->hybrid());
-
-    // re-sync suite calendar for clock attribute, re-queue all time based attributes
-    handle_clock_attribute_change();
-}
-
-void Suite::changeClockDate(const std::string& theDate) {
-    // See ISSUES: Suite::changeClockType
-    int dayy, month, year;
-    DateAttr::getDate(theDate, dayy, month, year);
-    if (dayy == 0 || month == 0 || year == 0)
-        throw std::runtime_error("Suite::changeClockDate Invalid clock date:" + theDate);
-
-    // ECFLOW-417
-    // By default the user *IS* expected to requeue afterward. However, in the case where we
-    // have a hybrid clock *AND* repeat day, the calendar date will be updated after the requeue.
-    // This will update calendar by repeat days.
-    // Hence, take this into account by decrementing by number of days
-    if (clockAttr_.get() && clockAttr_->hybrid() && repeat().is_repeat_day()) {
-        boost::gregorian::date the_date(year, month, dayy);
-        the_date -= date_duration(repeat().step());
-        dayy  = the_date.day();
-        month = the_date.month();
-        year  = the_date.year();
-    }
-
-    SuiteChanged1 changed(this);
-    if (clockAttr_.get()) {
-        clockAttr_->date(dayy, month, year); // this will check the date and update state change_no
-    }
-    else {
-        addClock(ClockAttr(dayy, month, year)); // will update state change_no
-    }
-
-    handle_clock_attribute_change();
-}
-
-void Suite::changeClockGain(const std::string& gain) {
-    // See: ISSUES on Suite::changeClockType
-    long theGain = 0;
-    try {
-        theGain = ecf::convert_to<long>(gain);
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error("Suite::changeClockGain: value '" + gain +
-                                 "' is not convertible to an long, for suite " + name());
-    }
-
-    SuiteChanged1 changed(this);
-    if (!clockAttr_.get()) {
-        addClock(ClockAttr()); // will update state change_no
-    }
-
-    if (theGain > 0) {
-        clockAttr_->set_gain_in_seconds(theGain, true); // will update state change_no
-    }
-    else {
-        clockAttr_->set_gain_in_seconds(theGain, false); // will update state change_no
-    }
-
-    handle_clock_attribute_change();
-}
-
-void Suite::changeClockSync() {
-    // See: ISSUES on Suite::changeClockType
-    SuiteChanged1 changed(this);
-    if (clockAttr_.get()) {
-        clockAttr_->sync(); // clear so that on re-queue we sync with computer, + will update state change_no
-    }
-    else {
-        addClock(ClockAttr()); // will update state change_no
-    }
-
-    handle_clock_attribute_change();
-}
-
-void Suite::handle_clock_attribute_change() {
-    // re-queue time could cause thousands of mementos to be created, to avoid this we
-    // update the modify change number.
-    Ecf::incr_modify_change_no();
-
-    // Since the suite clock attribute has changed, re-sync the suite calendar
-    begin_calendar();
-
-    // re-queue all the time attributes, since clock attribute has changed, avoid changing node state.
-    // Note: when switching to hybrid clock the re-queue of time dependencies will
-    //       *not* mark hybrid (day,date,cron) as complete
-    //       since these nodes could be in an active/submitted state.
-    NodeContainer::requeue_time_attrs();
-
-    // make sure we regenerate all suite variables, i.e like ECF_DATE, etc
-    if (suite_gen_variables_)
-        suite_gen_variables_->force_update();
-
-    update_generated_variables();
-}
-
-bool Suite::checkInvariants(std::string& errorMsg) const {
-    if (!cal_.checkInvariants(errorMsg)) {
-        return false;
-    }
-    if (clockAttr_.get()) {
-        if (calendar().hybrid() != clockAttr_->hybrid()) {
-            std::stringstream ss;
-            ss << "Suite:" << name() << " Calendar(hybrid(" << calendar().hybrid() << ")) and Clock attribute(hybrid("
-               << clockAttr_->hybrid() << ")) must be in sync, clock types differs";
-            errorMsg += ss.str();
-            return false;
-        }
-    }
-
-    if (Ecf::server()) {
-        if (state_change_no_ > Ecf::state_change_no()) {
-            std::stringstream ss;
-            ss << "Suite::checkInvariants: suite_change_no(" << state_change_no_ << ") > Ecf::state_change_no("
-               << Ecf::state_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-        if (begun_change_no_ > Ecf::state_change_no()) {
-            std::stringstream ss;
-            ss << "Suite::checkInvariants: begun_change_no_(" << begun_change_no_ << ") > Ecf::state_change_no("
-               << Ecf::state_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-        if (calendar_change_no_ > Ecf::state_change_no() + 1) {
-            std::stringstream ss;
-            ss << "Suite::checkInvariants: calendar_change_no_(" << calendar_change_no_ << ") > Ecf::state_change_no("
-               << Ecf::state_change_no() + 1 << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-        if (modify_change_no_ > Ecf::modify_change_no()) {
-            std::stringstream ss;
-            ss << "Suite::checkInvariants: modify_change_no_(" << modify_change_no_ << ") > Ecf::modify_change_no("
-               << Ecf::modify_change_no() << ")\n";
-            errorMsg += ss.str();
-            return false;
-        }
-    }
-    return NodeContainer::checkInvariants(errorMsg);
-}
-
-void Suite::collateChanges(DefsDelta& changes) const {
-    /// The suite hold the max state change no, for all its children and attributes
-
-    // Optimising updates:
-    // Problem:
-    //    User has requested 1 second updated in the viewer. We used add SuiteCalendarMemento
-    //    when ever there were changes in the suite. However, this causes the suite in the
-    //    viewer to *refresh* too often.
-    //
-    // Soln 1:
-    //   Use:
-    //      calendar_change_no_ = Ecf::incr_state_change_no();
-    //
-    //   plus only create SuiteCalendarMemento, where the suite changes *AND*
-    //   calendar has actually changed.
-    //   - This fixes the problem, at the expense of *always* creating a SuiteCalendarMemento
-    //     every 60 seconds. Thus adding to network traffic.
-    //   - The regression tests will fail, since a change is made in the server,
-    //     for which the sync does nothing. *************************************
-    //     This could be fixed by creating a SuiteCalendarMemento when calendar changes
-    //     However we then go back always creating SuiteCalendarMemento every 60 seconds
-    //     even when there are **no other** changes
-    //
-    // Soln 2:
-    //    Use:
-    //       calendar_change_no_ = Ecf::state_change_no() + 1
-    //
-    //    We mimick updating Ecf::state_change_no(), thus we can create memento when required
-    //    They should however not be recognised as state change.
-    //    + This fixes the problem, and the regression test will also work
-    //    This is the solution that has been implemented
-    //
-    //    + ECFLOW-631 updated, to allow client to sync clock, before calling why cmd.
-
-    // ********************************************************************
-    // Note: we separate determining incremental changes from the traversal
-    // ********************************************************************
-
-#ifdef DEBUG_MEMENTO
-    std::cout << "Suite::collateChanges()\n";
-    std::cout << "  " << debugNodePath() << "\n";
-    std::cout << "  client_state_change_no(" << changes.client_state_change_no() << ")\n";
-    std::cout << "  suite state_change_no (" << state_change_no() << ")\n";
-    std::cout << "  calendar_change_no_   (" << calendar_change_no_ << ")\n";
-    std::cout << "  sync_suite_clock      (" << changes.sync_suite_clock() << ")\n";
-#endif
-
-    if (state_change_no() > changes.client_state_change_no() ||
-        (changes.sync_suite_clock() && calendar_change_no_ > changes.client_state_change_no())) {
-
-        // *TREAT* All changes to *a* Node, in a single compound_memento_ptr
-        size_t before = changes.size();
-
-        compound_memento_ptr suite_compound_mememto;
-        if (clockAttr_.get() && clockAttr_->state_change_no() > changes.client_state_change_no()) {
-            if (!suite_compound_mememto.get())
-                suite_compound_mememto = std::make_shared<CompoundMemento>(absNodePath());
-            suite_compound_mememto->add(std::make_shared<SuiteClockMemento>(*clockAttr_));
-        }
-        if (begun_change_no_ > changes.client_state_change_no()) {
-            if (!suite_compound_mememto.get())
-                suite_compound_mememto = std::make_shared<CompoundMemento>(absNodePath());
-            suite_compound_mememto->add(std::make_shared<SuiteBeginDeltaMemento>(begun_));
-        }
-
-        /// Collate NodeContainer and Node changes into *SAME* compound_memento_ptr
-        NodeContainer::incremental_changes(changes, suite_compound_mememto);
-
-        // Traversal, we have finished with this node:
-        // Traverse children : *SEPARATE* compound_memento_ptr created on demand
-        NodeContainer::collateChanges(changes);
-
-        /// *ONLY* create SuiteCalendarMemento, if something changed in the suite.
-        /// *OR* if it has been specifically requested. see ECFLOW-631
-        /// Additionally calendar_change_no_ updates should not register as a state change, i.e for tests
-        /// *AND* for showing the state change times.
-        /// SuiteCalendarMemento is needed so that WhyCmd can work on the client side.
-        /// Need to use new compound since the suite may not have change, but it children may have.
-        /// Hence as side affect why command with reference to time will only be accurate
-        /// after some kind of state change. Fixed with ECFLOW-631 (Client must do sync_clock, before calling why)
-        size_t after = changes.size();
-        if ((before != after || changes.sync_suite_clock()) && calendar_change_no_ > changes.client_state_change_no()) {
-            compound_memento_ptr compound_ptr = std::make_shared<CompoundMemento>(absNodePath());
-            compound_ptr->add(std::make_shared<SuiteCalendarMemento>(cal_));
-            changes.add(compound_ptr);
-        }
-    }
-}
-
-void Suite::set_memento(const SuiteClockMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Suite::set_memento( const SuiteClockMemento*) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::SUITE_CLOCK);
-    else
-        changeClock(memento->clockAttr_);
-}
-
-void Suite::set_memento(const SuiteBeginDeltaMemento* memento,
-                        std::vector<ecf::Aspect::Type>& aspects,
-                        bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Suite::set_memento( const SuiteBeginDeltaMemento* ) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only)
-        aspects.push_back(ecf::Aspect::SUITE_BEGIN);
-    else
-        begun_ = memento->begun_;
-}
-
-void Suite::set_memento(const SuiteCalendarMemento* memento,
-                        std::vector<ecf::Aspect::Type>& aspects,
-                        bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Suite::set_memento( const SuiteCalendarMemento* ) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::SUITE_CALENDAR);
-        return;
-    }
-
-    // The calendar does *NOT* persist the calendar type (hybrid/real) since we can derive this for clock attribute
-    // Hence make sure calendar/clock are in sync. part of the suite invariants
-    cal_ = memento->cal_;
-    if (clockAttr_.get()) {
-        if (clockAttr_->hybrid())
-            cal_.set_clock_type(ecf::Calendar::HYBRID);
-        else
-            cal_.set_clock_type(ecf::Calendar::REAL);
-    }
-}
-
-// generated variables ---------------------------------------------------------------------
-void Suite::update_generated_variables() const {
-    // This function is called during:
-    //   o begin()
-    //   o requeue()
-    //   o when calendar changes
-    if (!suite_gen_variables_)
-        suite_gen_variables_ = new SuiteGenVariables(this);
-    suite_gen_variables_->update_generated_variables();
-    update_repeat_genvar();
-}
-
-const Variable& Suite::findGenVariable(const std::string& name) const {
-    if (!suite_gen_variables_)
-        update_generated_variables();
-
-    const Variable& gen_var = suite_gen_variables_->findGenVariable(name);
-    if (!gen_var.empty())
-        return gen_var;
-    return NodeContainer::findGenVariable(name);
-}
-
-void Suite::gen_variables(std::vector<Variable>& vec) const {
-    if (!suite_gen_variables_)
-        update_generated_variables();
-
-    vec.reserve(vec.size() + 13);
-    NodeContainer::gen_variables(vec);
-    suite_gen_variables_->gen_variables(vec);
-}
-
-std::string Suite::find_node_path(const std::string& type, const std::string& node_name) const {
-    if (Str::caseInsCompare(type, "suite") && node_name == name()) {
-        return absNodePath();
-    }
-    return NodeContainer::find_node_path(type, node_name);
-}
-
-// =======================================================================================
-
-// The false below is used as a dummy argument to call the Variable constructor that does not
-// check the variable names. i.e. we know they are valid
-SuiteGenVariables::SuiteGenVariables(const Suite* s)
-    : suite_(s),
-      genvar_suite_("SUITE", "", false),
-      genvar_ecf_time_("ECF_TIME", "", false),
-      genvar_time_("TIME", "", false),
-      genvar_yyyy_("YYYY", "", false),
-      genvar_dow_("DOW", "", false),
-      genvar_doy_("DOY", "", false),
-      genvar_date_("DATE", "", false),
-      genvar_day_("DAY", "", false),
-      genvar_dd_("DD", "", false),
-      genvar_mm_("MM", "", false),
-      genvar_month_("MONTH", "", false),
-      genvar_ecf_date_("ECF_DATE", "", false),
-      genvar_ecf_clock_("ECF_CLOCK", "", false),
-      genvar_ecf_julian_("ECF_JULIAN", "", false),
-      force_update_(false) {
-}
-
-void SuiteGenVariables::update_generated_variables() const {
-    genvar_suite_.set_value(suite_->name());
-
-    // The cal_ is only initialised once the suite has begun
-    if (!suite_->begun_) {
-        return;
-    }
-
-    // The code below ASSUMES calendar has been initialised
-    boost::posix_time::time_duration time_of_day = suite_->cal_.suiteTime().time_of_day();
-
-    // #ifdef DEBUG
-    //     using namespace boost::gregorian;
-    //     tm t = to_tm(suite_->cal_.suiteTime());  // to_tm can be a bit of a performance hog
-    ////  cerr << "\ntm_year = " << t.tm_year << "\n";  /* year - 1900              */
-    ////  cerr << "tm_mon = " << t.tm_mon << "\n";      /* month of year (0 - 11)   */
-    ////  cerr << "tm_mday = " << t.tm_mday << "\n";    /* day of month (1 - 31)    */
-    ////  cerr << "tm_wday = " << t.tm_wday << "\n";    /* day of week (Sunday = 0) */
-    ////  cerr << "tm_yday = " << t.tm_yday << "\n";    /* day of year (0 - 365)    */
-    ////  cerr << "tm_hour = " << t.tm_hour << "\n";    /* hours (0 - 23)           */
-    ////  cerr << "tm_min = " << t.tm_min << "\n";      /* minutes (0 - 59)         */
-    ////  cerr << "tm_sec = " << t.tm_sec << "\n";      /* seconds (0 - 59)         */
-    //
-    //    // ***IMPORTANT*** suiteTime is only valid for real clock, note that
-    //    // *************** for hybrid the day does not change. hence assertion
-    //    // *************** needs to take into account calendar type
-    //       if (!suite_->cal_.hybrid()) {
-    //          assert( t.tm_wday   == cal_.day_of_week());
-    //          assert( t.tm_mday   == cal_.day_of_month());
-    //          assert( t.tm_yday+1 == cal_.day_of_year());
-    //          assert( t.tm_mon+1  == cal_.month());
-    //       }
-    //    assert( time_of_day.hours() == t.tm_hour);
-    //    assert( time_of_day.minutes() == t.tm_min);
-    //    assert( t.tm_year + 1900 == cal_.year());
-    // #endif
-
-    int hours   = time_of_day.hours();
-    int minutes = time_of_day.minutes();
-
-    constexpr int buff_size = 255;
-    char buffer[buff_size];
-    snprintf(buffer, buff_size, "%02d%02d", hours, minutes);
-    genvar_time_.set_value(buffer);
-
-    snprintf(buffer, buff_size, "%02d:%02d", hours, minutes);
-    genvar_ecf_time_.set_value(buffer);
-
-    // cout << "genvar_time_ = " << genvar_time_.theValue() << "\n";
-    // cout << "genvar_ecf_time_ = " << genvar_ecf_time_.theValue() << "\n";
-
-    // **********************************************************************
-    // The following generated variable need only be updated if NULL or if day changed
-    // Under: HYBRID the day will never change, hence a one time update
-    // **********************************************************************
-    if (suite_->cal_.dayChanged() || genvar_yyyy_.theValue().empty() || force_update_) {
-
-        force_update_ = false;
-        genvar_yyyy_.set_value(ecf::convert_to<std::string>(suite_->cal_.year()));
-        genvar_dow_.set_value(ecf::convert_to<std::string>(suite_->cal_.day_of_week()));
-        genvar_doy_.set_value(ecf::convert_to<std::string>(suite_->cal_.day_of_year()));
-        // cout << "genvar_yyyy_ = " << genvar_yyyy_.theValue() << "\n";
-        // cout << "genvar_dow_ = " << genvar_dow_.theValue() << "\n";
-        // cout << "genvar_doy_ = " << genvar_doy_.theValue() << "\n";
-
-        snprintf(buffer,
-                 buff_size,
-                 "%02d.%02d.%04d",
-                 suite_->cal_.day_of_month(),
-                 suite_->cal_.month(),
-                 suite_->cal_.year());
-        genvar_date_.set_value(buffer);
-        // cout << "genvar_date_ = " << genvar_date_.theValue() << "\n";
-
-        char* day_name[] = {const_cast<char*>("sunday"),
-                            const_cast<char*>("monday"),
-                            const_cast<char*>("tuesday"),
-                            const_cast<char*>("wednesday"),
-                            const_cast<char*>("thursday"),
-                            const_cast<char*>("friday"),
-                            const_cast<char*>("saturday"),
-                            nullptr};
-        genvar_day_.set_value(day_name[suite_->cal_.day_of_week()]);
-        // cout << "genvar_day_ = " << genvar_day_.theValue() << "\n";
-
-        snprintf(buffer, buff_size, "%02d", suite_->cal_.day_of_month());
-        genvar_dd_.set_value(buffer);
-        // cout << "genvar_dd_ = " << genvar_dd_.theValue() << "\n";
-
-        snprintf(buffer, buff_size, "%02d", suite_->cal_.month());
-        genvar_mm_.set_value(buffer);
-        // cout << "genvar_mm_ = " << genvar_mm_.theValue() << "\n";
-
-        char* month_name[] = {const_cast<char*>("january"),
-                              const_cast<char*>("february"),
-                              const_cast<char*>("march"),
-                              const_cast<char*>("april"),
-                              const_cast<char*>("may"),
-                              const_cast<char*>("june"),
-                              const_cast<char*>("july"),
-                              const_cast<char*>("august"),
-                              const_cast<char*>("september"),
-                              const_cast<char*>("october"),
-                              const_cast<char*>("november"),
-                              const_cast<char*>("december"),
-                              nullptr};
-        genvar_month_.set_value(month_name[suite_->cal_.month() - 1]);
-        // cout << "genvar_month_ = " << genvar_month_.theValue() << "\n";
-
-        snprintf(
-            buffer, buff_size, "%04d%02d%02d", suite_->cal_.year(), suite_->cal_.month(), suite_->cal_.day_of_month());
-        genvar_ecf_date_.set_value(buffer);
-        // cout << "genvar_ecf_date_ = " << genvar_ecf_date_.theValue() << "\n";
-
-        snprintf(buffer,
-                 buff_size,
-                 "%s:%s:%d:%d",
-                 day_name[suite_->cal_.day_of_week()],
-                 month_name[suite_->cal_.month() - 1],
-                 suite_->cal_.day_of_week(),
-                 suite_->cal_.day_of_year());
-        genvar_ecf_clock_.set_value(buffer);
-        // cout << "genvar_ecf_clock_ = " << genvar_ecf_clock_.theValue() << "\n";
-
-        genvar_ecf_julian_.set_value(ecf::convert_to<std::string>(suite_->cal_.suiteTime().date().julian_day()));
-    }
-}
-
-const Variable& SuiteGenVariables::findGenVariable(const std::string& name) const {
-    if (genvar_suite_.name() == name)
-        return genvar_suite_;
-    if (genvar_ecf_date_.name() == name)
-        return genvar_ecf_date_;
-    if (genvar_yyyy_.name() == name)
-        return genvar_yyyy_;
-    if (genvar_dow_.name() == name)
-        return genvar_dow_;
-    if (genvar_doy_.name() == name)
-        return genvar_doy_;
-    if (genvar_date_.name() == name)
-        return genvar_date_;
-    if (genvar_day_.name() == name)
-        return genvar_day_;
-    if (genvar_dd_.name() == name)
-        return genvar_dd_;
-    if (genvar_mm_.name() == name)
-        return genvar_mm_;
-    if (genvar_month_.name() == name)
-        return genvar_month_;
-    if (genvar_ecf_clock_.name() == name)
-        return genvar_ecf_clock_;
-    if (genvar_ecf_time_.name() == name)
-        return genvar_ecf_time_;
-    if (genvar_ecf_julian_.name() == name)
-        return genvar_ecf_julian_;
-    if (genvar_time_.name() == name)
-        return genvar_time_;
-    return Variable::EMPTY();
-}
-
-void SuiteGenVariables::gen_variables(std::vector<Variable>& vec) const {
-    vec.push_back(genvar_suite_);
-    vec.push_back(genvar_ecf_date_);
-    vec.push_back(genvar_yyyy_);
-    vec.push_back(genvar_dow_);
-    vec.push_back(genvar_doy_);
-    vec.push_back(genvar_date_);
-    vec.push_back(genvar_day_);
-    vec.push_back(genvar_dd_);
-    vec.push_back(genvar_mm_);
-    vec.push_back(genvar_month_);
-    vec.push_back(genvar_ecf_clock_);
-    vec.push_back(genvar_ecf_time_);
-    vec.push_back(genvar_ecf_julian_);
-    vec.push_back(genvar_time_);
-}
-
-template <class Archive>
-void Suite::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<NodeContainer>(this));
-    CEREAL_OPTIONAL_NVP(ar, begun_, [this]() { return begun_; });               // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, clockAttr_, [this]() { return clockAttr_.get(); }); // conditionally save
-    ar(CEREAL_NVP(cal_));
-
-    // The calendar does not persist the clock type or start stop with server since
-    // that is persisted with the clock attribute
-    if (Archive::is_loading::value) {
-        if (clockAttr_.get())
-            clockAttr_->init_calendar(cal_);
-    }
-}
-CEREAL_TEMPLATE_SPECIALIZE_V(Suite);
-CEREAL_REGISTER_TYPE(Suite)
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Suite.hpp 5.13.0-1/ANode/src/ecflow/node/Suite.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Suite.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Suite.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,167 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Suite_HPP
-#define ecflow_node_Suite_HPP
-
-#include "ecflow/attribute/ClockAttr.hpp" // IWYU pragma: keep
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/node/NodeContainer.hpp"
-
-class SuiteGenVariables;
-namespace ecf {
-class CalendarUpdateParams;
-} // namespace ecf
-
-class Suite final : public NodeContainer {
-public:
-    explicit Suite(const std::string& name, bool check = true) : NodeContainer(name, check) {}
-    Suite() = default;
-
-    Suite(const Suite&);
-    Suite& operator=(const Suite&);
-    node_ptr clone() const override;
-
-    ~Suite() override;
-
-    static suite_ptr create(const std::string& name, bool check = true);
-    static suite_ptr create_me(const std::string& name); // python api, to pick correct init function
-
-    bool check_defaults() const override;
-
-    Suite* suite() const override { return const_cast<Suite*>(this); }
-    Defs* defs() const override { return defs_; }
-    void set_defs(Defs* d) { defs_ = d; }
-    Suite* isSuite() const override { return const_cast<Suite*>(this); }
-    NodeContainer* isNodeContainer() const override { return const_cast<Suite*>(this); }
-
-    /// Overridden to take into account begin()
-    bool resolveDependencies(JobsParam&) override;
-
-    void accept(ecf::NodeTreeVisitor&) override;
-    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
-    void reset() override;
-    void handle_migration(const ecf::Calendar&) override;
-    void begin() override;
-    void requeue(Requeue_args& args) override;
-    bool begun() const { return begun_; }
-    void reset_begin();
-    void update_generated_variables() const override;
-
-    const Variable& findGenVariable(const std::string& name) const override;
-    std::string find_node_path(const std::string& type, const std::string& name) const override;
-
-    void gen_variables(std::vector<Variable>&) const override;
-
-    void updateCalendar(const ecf::CalendarUpdateParams&, Node::Calendar_args&);
-
-    const std::string& debugType() const override;
-
-    bool operator==(const Suite& rhs) const;
-    void print(std::string&) const override;
-
-    void addClock(const ClockAttr&,
-                  bool initialize_calendar = true); // throw std::run_time if more than one clock is added
-    void add_end_clock(const ClockAttr&);
-    void changeClock(const ClockAttr&);
-    void changeClockType(const std::string& theType);
-    void changeClockDate(const std::string& theDate);
-    void changeClockGain(const std::string& theIntGain);
-    void changeClockSync();
-
-    /// return the suites calendar
-    const ecf::Calendar& calendar() const { return cal_; }
-    ecf::Calendar& set_calendar() { return cal_; }
-    clock_ptr clockAttr() const { return clockAttr_; }
-    clock_ptr clock_end_attr() const { return clock_end_attr_; }
-
-    bool checkInvariants(std::string& errorMsg) const override;
-
-    // Memento functions
-    void collateChanges(DefsDelta&) const override;
-    void set_memento(const SuiteClockMemento*, std::vector<ecf::Aspect::Type>& aspects, bool);
-    void set_memento(const SuiteBeginDeltaMemento*, std::vector<ecf::Aspect::Type>& aspects, bool);
-    void set_memento(const SuiteCalendarMemento*, std::vector<ecf::Aspect::Type>& aspects, bool);
-    void set_memento(const OrderMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
-        NodeContainer::set_memento(m, aspects, f);
-    }
-    void set_memento(const ChildrenMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
-        NodeContainer::set_memento(m, aspects, f);
-    }
-
-    void set_state_change_no(unsigned int x) { state_change_no_ = x; }
-    unsigned int state_change_no() const { return state_change_no_; }
-    void set_modify_change_no(unsigned int x) { modify_change_no_ = x; }
-    unsigned int modify_change_no() const { return modify_change_no_; }
-
-    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
-
-private:
-    void reset_begin_only();
-    void begin_calendar();
-    void requeue_calendar();
-    void handle_clock_attribute_change();
-    void write_state(std::string&, bool&) const override;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-
-private:
-    Defs* defs_{nullptr}; // *NOT* persisted, set by parent Defs
-    clock_ptr clockAttr_;
-    clock_ptr clock_end_attr_;           // *NOT* persisted, used by simulator only
-    ecf::Calendar cal_;                  // *Only* persisted since used by the why() on client side
-    unsigned int state_change_no_{0};    // no need to persist
-    unsigned int modify_change_no_{0};   // no need to persist
-    unsigned int begun_change_no_{0};    // no need to persist,  record changes to begun_. Needed for SSyncCmd
-    unsigned int calendar_change_no_{0}; // no need to persist,
-    mutable SuiteGenVariables* suite_gen_variables_{
-        nullptr}; // NOT persisted can be generated by calling update_generated_variables()
-    bool begun_{false};
-    friend class SuiteGenVariables;
-};
-
-std::ostream& operator<<(std::ostream& os, const Suite&);
-
-// This class helps in avoiding the creation of generated variables until required.
-// This improves client->server down load times by avoiding thousands of string constructions
-class SuiteGenVariables {
-public:
-    explicit SuiteGenVariables(const Suite*);
-    // Disable copy (and move) semantics
-    SuiteGenVariables(const SuiteGenVariables&)                  = delete;
-    const SuiteGenVariables& operator=(const SuiteGenVariables&) = delete;
-
-    void force_update() { force_update_ = true; }
-    void update_generated_variables() const;
-    const Variable& findGenVariable(const std::string& name) const;
-    void gen_variables(std::vector<Variable>& vec) const;
-
-private:
-    const Suite* suite_;
-    mutable Variable genvar_suite_;      // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_ecf_time_;   // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_time_;       // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_yyyy_;       // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_dow_;        // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_doy_;        // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_date_;       // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_day_;        // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_dd_;         // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_mm_;         // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_month_;      // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_ecf_date_;   // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_ecf_clock_;  // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable Variable genvar_ecf_julian_; // *NOT* persisted, can be generated by calling update_generated_variables()
-    mutable bool force_update_;
-};
-
-#endif /* ecflow_node_Suite_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/SuiteChanged.cpp 5.13.0-1/ANode/src/ecflow/node/SuiteChanged.cpp
--- 5.12.4-1/ANode/src/ecflow/node/SuiteChanged.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/SuiteChanged.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifdef DEBUG
-    #include <iostream>
-#endif
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-namespace ecf {
-
-SuiteChanged::SuiteChanged(suite_ptr s)
-    : suite_(s),
-      state_change_no_(Ecf::state_change_no()),
-      modify_change_no_(Ecf::modify_change_no()) {
-}
-
-SuiteChanged::~SuiteChanged() {
-    suite_ptr suite = suite_.lock();
-    if (suite.get()) {
-        if (modify_change_no_ != Ecf::modify_change_no()) {
-            suite->set_modify_change_no(Ecf::modify_change_no());
-        }
-        if (state_change_no_ != Ecf::state_change_no()) {
-            suite->set_state_change_no(Ecf::state_change_no());
-        }
-    }
-}
-
-// ============================================================================
-SuiteChanged0::SuiteChanged0(node_ptr s)
-    : node_(s),
-      suite_(s->suite()),
-      state_change_no_(Ecf::state_change_no()),
-      modify_change_no_(Ecf::modify_change_no()) {
-}
-
-SuiteChanged0::~SuiteChanged0() {
-    node_ptr node = node_.lock();
-    if (node.get() && suite_) {
-        if (modify_change_no_ != Ecf::modify_change_no()) {
-            suite_->set_modify_change_no(Ecf::modify_change_no());
-            // std::cout << "SuiteChanged0::~SuiteChanged0() modify_ changed \n";
-        }
-        if (state_change_no_ != Ecf::state_change_no()) {
-            suite_->set_state_change_no(Ecf::state_change_no());
-            // std::cout << "SuiteChanged0::~SuiteChanged0() state changed \n";
-        }
-    }
-}
-
-// ============================================================================
-SuiteChangedPtr::SuiteChangedPtr(Node* s)
-    : suite_(s->suite()),
-      state_change_no_(Ecf::state_change_no()),
-      modify_change_no_(Ecf::modify_change_no()) {
-}
-
-SuiteChangedPtr::~SuiteChangedPtr() {
-    if (suite_) {
-        if (modify_change_no_ != Ecf::modify_change_no()) {
-            suite_->set_modify_change_no(Ecf::modify_change_no());
-            // std::cout << "SuiteChangedPtr::~SuiteChangedPtr() modify_ changed \n";
-        }
-        if (state_change_no_ != Ecf::state_change_no()) {
-            suite_->set_state_change_no(Ecf::state_change_no());
-            // std::cout << "SuiteChangedPtr::~SuiteChangedPtr() state changed \n";
-        }
-    }
-}
-//================================================================
-
-SuiteChanged1::SuiteChanged1(Suite* s)
-    : suite_(s),
-      state_change_no_(Ecf::state_change_no()),
-      modify_change_no_(Ecf::modify_change_no()) {
-}
-
-SuiteChanged1::~SuiteChanged1() {
-    if (modify_change_no_ != Ecf::modify_change_no()) {
-        suite_->set_modify_change_no(Ecf::modify_change_no());
-        // std::cout << "SuiteChanged1::~SuiteChanged0() modify_ changed \n";
-    }
-    if (state_change_no_ != Ecf::state_change_no()) {
-        suite_->set_state_change_no(Ecf::state_change_no());
-        // std::cout << "SuiteChanged1::~SuiteChanged0() modify_ changed \n";
-    }
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/SuiteChanged.hpp 5.13.0-1/ANode/src/ecflow/node/SuiteChanged.hpp
--- 5.12.4-1/ANode/src/ecflow/node/SuiteChanged.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/SuiteChanged.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_SuiteChanged_HPP
-#define ecflow_node_SuiteChanged_HPP
-
-#include "ecflow/node/NodeFwd.hpp"
-
-namespace ecf {
-
-// Determine if suite was changed or modified if so, update suite change no
-// This mechanism was used because, when changing some attributes, we cannot
-// immediately access the parent suites, to update the change numbers.
-//
-// When given a choice between where to add SuiteChanged, i.e in Node Tree or Commands
-// Generally favour commands, as it will require less maintenance over time.
-//
-// This mechanism was added specifically to support changes over client handles
-// i.e suites are added to handles, hence we need a way to determine which
-// suites (and hence handle) changed, and hence minimise the need for updates.
-
-class SuiteChanged {
-public:
-    explicit SuiteChanged(suite_ptr s);
-    // Disable copy (and move) semantics
-    SuiteChanged(const SuiteChanged&)                  = delete;
-    const SuiteChanged& operator=(const SuiteChanged&) = delete;
-
-    ~SuiteChanged();
-
-private:
-    weak_suite_ptr suite_;
-    unsigned int state_change_no_;
-    unsigned int modify_change_no_;
-};
-
-class SuiteChanged0 {
-public:
-    explicit SuiteChanged0(node_ptr s);
-    // Disable copy (and move) semantics
-    SuiteChanged0(const SuiteChanged0&)                  = delete;
-    const SuiteChanged0& operator=(const SuiteChanged0&) = delete;
-
-    ~SuiteChanged0();
-
-private:
-    weak_node_ptr node_;
-    Suite* suite_; // if node is removed suite pointer is not accessible, hence store first
-    unsigned int state_change_no_;
-    unsigned int modify_change_no_;
-};
-
-// Faster than using node_ptr.
-class SuiteChangedPtr {
-public:
-    explicit SuiteChangedPtr(Node* s);
-    // Disable copy (and move) semantics
-    SuiteChangedPtr(const SuiteChangedPtr&)                  = delete;
-    const SuiteChangedPtr& operator=(const SuiteChangedPtr&) = delete;
-
-    ~SuiteChangedPtr();
-
-private:
-    Suite* suite_; // if node is removed suite pointer is not accessible, hence store first
-    unsigned int state_change_no_;
-    unsigned int modify_change_no_;
-};
-
-class SuiteChanged1 {
-public:
-    explicit SuiteChanged1(Suite* s);
-    // Disable copy (and move) semantics
-    SuiteChanged1(const SuiteChanged1&)                  = delete;
-    const SuiteChanged1& operator=(const SuiteChanged1&) = delete;
-
-    ~SuiteChanged1();
-
-private:
-    Suite* suite_;
-    unsigned int state_change_no_;
-    unsigned int modify_change_no_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_SuiteChanged_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/System.cpp 5.13.0-1/ANode/src/ecflow/node/System.cpp
--- 5.12.4-1/ANode/src/ecflow/node/System.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/System.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,471 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cerrno>
-#include <csignal>
-
-#include <sys/wait.h> // for waitpid
-
-#ifndef O_WRONLY
-    #include <fcntl.h>
-#endif
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Signal.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/System.hpp"
-
-// #define DEBUG_FORK 1
-// #define DEBUG_CATCH_CHILD 1
-// #define DEBUG_TERMINATED_CHILD 1
-// #define DEBUG_CHILD_ABORT 1
-
-#ifdef DEBUG_FORK
-    #include <iostream>
-#endif
-
-using namespace std;
-
-namespace ecf {
-
-// ===========================================================================
-// Process
-// ===========================================================================
-struct Process
-{
-public:
-    Process(const std::string& absPath, const std::string& cmdToSpawn, System::CmdType cmd_type, pid_t pid)
-        : absNodePath_(absPath),
-          cmd_(cmdToSpawn),
-          cmd_type_(cmd_type),
-          have_status_(0),
-          pid_(pid),
-          status_(0) {}
-
-    std::string absNodePath_;  // Path to Task(ECF_JOB_CMD), empty for ECF_KILL_CMD & ECF_STATUS_CMD
-    std::string cmd_;          // the command that was spawned
-    System::CmdType cmd_type_; // Type of command
-    sig_atomic_t have_status_; // Nonzero if this process has stopped or terminated.  */
-    pid_t pid_;                // The process ID of this child.
-    int status_;               // The status of this child; 0 if running,
-                               // otherwise a status value from waitpid
-};
-std::vector<Process> processVec_;
-
-/* Nonzero means some child's status has changed
-   so look at process_list for the details.  */
-volatile int process_status_change_ = 0;
-
-// ===========================================================================
-// System
-// ===========================================================================
-System* System::instance_ = nullptr;
-
-System* System::instance() {
-    if (instance_ == nullptr) {
-
-        // Block SIGCHLD so that we control, when child process termination is handled
-        ecf::Signal::block_sigchild();
-
-        // install signal handler, that will catch Child process termination
-        // The install function can be called asynchronously, and hence deserves
-        // special consideration. Currently we temporarily unblock pending
-        // SIGCHLD signals at the end of Job generation, and then block them again.
-        // During the brief moment between unblock/block we expect
-        // the handler to be called.
-        catchChildProcessTermination();
-
-        instance_ = new System();
-    }
-    return instance_;
-}
-
-void System::destroy() {
-    delete instance_;
-    instance_ = nullptr;
-}
-
-System::System()  = default;
-System::~System() = default;
-
-bool System::spawn(System::CmdType cmd_type,
-                   const std::string& cmdToSpawn,
-                   const std::string& absPath,
-                   std::string& errorMsg) {
-#ifdef DEBUG_FORK
-    LogToCout logToCoutAsWell;
-    LOG(Log::DBG, "  System::spawn path(" << absPath << ") cmd(" << cmdToSpawn << ") cmd_type(" << cmd_type << ")\n");
-#endif
-
-    std::string msg;
-    if (sys(cmd_type, cmdToSpawn, absPath, msg)) {
-        std::stringstream ss;
-        ss << "Child process creation failed( " << msg << ") for command " << cmdToSpawn;
-        if (!absPath.empty())
-            ss << " at path(" << absPath << ")";
-        errorMsg = ss.str();
-#ifdef DEBUG_FORK
-        LOG(Log::DBG, "  System::spawn returning false\n");
-#endif
-        return false;
-    }
-    return true;
-}
-
-int System::sys(System::CmdType cmd_type,
-                const std::string& cmdToSpawn,
-                const std::string& absPath,
-                std::string& errorMsg) {
-#ifdef DEBUG_FORK
-    LogToCout logToCoutAsWell;
-    LOG(Log::DBG, "  System::sys path(" << absPath << ")  cmd(" << cmdToSpawn << ")  cmd_type(" << cmd_type << ")\n");
-#endif
-    /**************************************************************************
-     ?  Execute the command (cmdToSpawn) and return, DO NOT WAIT for the termination
-     |  of the children.
-     |  The stdin, stdout and stderr are closed (or redirected to /dev/null)
-     =  PID in case of success or 0 in case of errors.
-     ************************************o*************************************/
-    pid_t child_pid;
-    if ((child_pid = fork()) == 0) { /* The child */
-
-        int f;
-        close(2);
-        if ((f = open("/dev/null", O_WRONLY)) != 2)
-            close(f);
-
-        close(1);
-        if ((f = open("/dev/null", O_WRONLY)) != 1)
-            close(f);
-
-        close(0);
-        if ((f = open("/dev/null", O_RDONLY)) != 0)
-            close(f);
-
-        // ==============================================================================
-        // Ideally we should close all open file descriptors in the child process
-        //    On Linux: sysconf(_SC_OPEN_MAX); returns 1024
-        //    This means making 1024 - 3 system calls
-        // This is especially import for socket descriptors, since if the server goes down
-        // The children/zombies will prevent the server restart on the same port.
-        // i.e the classic Address in use
-        // Its not clear how big a performance issue this, an alternative would be, to only close
-        // open socket file descriptors. But this will require a singleton of some sort
-        // ===============================================================================
-        int fd_limit = sysconf(_SC_OPEN_MAX);
-        for (int i = 3; i < fd_limit; i++)
-            close(i);
-
-        execl("/bin/sh", "sh", "-c", cmdToSpawn.c_str(), (char*)nullptr);
-        /*
-         *  Maybe the file protection failed (no executable bit set)
-         *  or the shell couldn't be found. Look at man execve(2).
-         */
-        _exit(127);
-    }
-
-    if (child_pid == -1) {
-        std::stringstream ss;
-        ss << "fork() error(" << strerror(errno) << ")";
-        errorMsg = ss.str();
-        return 1;
-    }
-
-    // Store the process pid, so that we can wait for it. ho ho.
-    processVec_.emplace_back(absPath, cmdToSpawn, cmd_type, child_pid);
-
-#ifdef DEBUG_FORK
-    // LogToCout logToCoutAsWell;
-    LOG(Log::DBG, "   submit: Path(" << absPath << ") child_pid(" << child_pid << ") cmd(" << cmdToSpawn << ")");
-#endif
-    return 0;
-}
-
-static void catch_child(int sig)
-/**************************************************************************
-?  Catch the death of the child process
-|  This function can be called asynchronously hence it could interfere
-   with the rest of program. Hence this function does not allocate or
-   free memory. We simply store the status, for later processing
-************************************o*************************************/
-{
-#ifdef DEBUG_CATCH_CHILD
-    std::cout << "   catch_child (process death) sig = " << sig << endl;
-#endif
-
-    int saved_errno = errno; // save error number since waitpid can change this
-    int status;
-    pid_t child_pid;
-
-    // waitpid returns:
-    //  - on success, returns the process ID of the child whose state has changed
-    //  - if WNOHANG was specified and one or more child(ren) specified by pid exist,
-    //    but have *NOT* yet changed state, then *0* is returned
-    //    *** hence we MUST check for 0, other wise we will end up in an infinite loop **
-    //  - returns -1 on error
-    while ((child_pid = waitpid(-1, &status, WNOHANG)) != -1 && child_pid != 0) {
-
-        auto theEnd = processVec_.end();
-        for (auto i = processVec_.begin(); i != theEnd; ++i) {
-            if ((*i).pid_ == child_pid) {
-
-#ifdef DEBUG_CATCH_CHILD
-                std::cout << "   catch_child Found pid " << child_pid << endl;
-#endif
-                // Indicate that the status field
-                // has data to look at.  We do this only after storing it.
-                (*i).have_status_ = 1;
-
-                // store the status
-                (*i).status_ = status;
-
-                // The program should check this flag from time to time
-                // to see if there is any news in processVec_.
-                process_status_change_++;
-                break;
-            }
-        }
-    }
-
-    // restore error number
-    errno = saved_errno;
-}
-
-void System::processTerminatedChildren() {
-#ifdef DEBUG_TERMINATED_CHILD
-    std::cout << "System::processTerminatedChildren() process_status_change_ = " << process_status_change_
-              << "   processVec_.size() = " << processVec_.size() << endl;
-    LogToCout logToCoutAsWell;
-#endif
-    if (process_status_change_ == 0) {
-        return;
-    }
-
-    // Must be the first thing we do.
-    process_status_change_ = 0;
-
-    std::vector<Process>::iterator i;
-    for (i = processVec_.begin(); i != processVec_.end(); ++i) {
-
-        if ((*i).have_status_) {
-
-#ifdef DEBUG_TERMINATED_CHILD
-            std::cout << "System::processTerminatedChildren(): " << System::cmd_type((*i).cmd_type_) << " path("
-                      << (*i).absNodePath_ << ") pid(" << (*i).pid_ << ") has status(stopped or terminated)" << endl;
-#endif
-            // exit status is one of mutually exclusive [ WIFEXITED | WIFSIGNALED | WIFSTOPPED | WIFCONTINUED ]
-            if (WIFEXITED((*i).status_)) {
-
-                // *Normal* termination via exit
-                if (WEXITSTATUS((*i).status_)) {
-                    // exit is non zero.
-                    std::stringstream ss;
-                    ss << System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") path(" << (*i).absNodePath_
-                       << ") exited with status " << WEXITSTATUS((*i).status_) << " [ " << (*i).cmd_ << " ]";
-                    died((*i).absNodePath_, (*i).cmd_type_, ss.str());
-                }
-                else {
-                    // exit(0) child terminated normally
-#ifdef DEBUG_TERMINATED_CHILD
-                    LOG(Log::DBG,
-                        System::cmd_type((*i).cmd_type_)
-                            << " PID(" << (*i).pid_ << ") exited normally [ " << (*i).cmd_ << " ]");
-#endif
-                }
-
-                // remove the process since it has terminated
-                processVec_.erase(i--);
-            }
-            else if (WIFSIGNALED((*i).status_)) {
-
-                // *abnormal* child process terminated by a signal
-                std::stringstream ss;
-                ss << System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") path(" << (*i).absNodePath_
-                   << ") died of signal " << WTERMSIG((*i).status_) << " [ " << (*i).cmd_ << " ]";
-                died((*i).absNodePath_, (*i).cmd_type_, ss.str());
-
-                // remove the process since it has terminated
-                processVec_.erase(i--);
-            }
-            else if (WIFSTOPPED((*i).status_)) {
-
-                LOG(Log::WAR,
-                    System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") STOPPED? [ " << (*i).absNodePath_
-                                                     << " ] [ " << (*i).cmd_ << " ]");
-            }
-            else {
-
-                // Can only be WIFCONTINUED. (XSI extension to POSIX)
-                LOG(Log::WAR,
-                    System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") CONTINUED? [ " << (*i).absNodePath_
-                                                     << " ] [ " << (*i).cmd_ << " ]");
-            }
-        }
-        else {
-#ifdef DEBUG_TERMINATED_CHILD
-            LOG(Log::DBG,
-                System::cmd_type((*i).cmd_type_)
-                    << " stray PID(" << (*i).pid_ << ") (ignored) [ " << (*i).cmd_ << " ]");
-#endif
-        }
-    }
-
-#ifdef DEBUG_TERMINATED_CHILD
-    std::cout << "System::processTerminatedChildren() process size = " << processVec_.size() << endl;
-#endif
-}
-
-int System::process() const {
-    return static_cast<int>(processVec_.size());
-}
-
-// ============================================================================
-// See: Advanced programming in the UNIX environment: Page 328
-// Note: with sigaction the handle stays installed, until changed
-//       this is different to the signal(..) which on some system needs
-//       to be reinstalled at start/end of SignalFunction.
-// ============================================================================
-typedef void SignalFunction(int);
-SignalFunction* signal_(int signo, SignalFunction* func) {
-    struct sigaction act, oact;
-    act.sa_handler = func;
-    sigemptyset(&act.sa_mask);
-    act.sa_flags = 0;
-    if (signo == SIGALRM) {
-#ifdef SA_INTERRUPT
-        act.sa_flags |= SA_INTERRUPT;
-#endif
-    }
-    else {
-        // We intentionally try to set the SA_RESTART flag for all signals other than SIGALRM
-        // so that any system call interrupted by these other signals in automatically restarted
-#ifdef SA_RESTART
-        act.sa_flags |= SA_RESTART;
-#endif
-    }
-
-    if (sigaction(signo, &act, &oact) < 0)
-        return (SIG_ERR);
-
-    // Return the old handler
-    return oact.sa_handler;
-}
-
-void System::catchChildProcessTermination() {
-    // Call our local version (which uses sigaction) rather than the out date signal(..)
-    signal_(SIGCHLD, catch_child);
-}
-
-void System::died(const std::string& absNodePath, CmdType cmd_type, const std::string& reason)
-/**************************************************************************
- ?  Process the death of the process. This is most unwanted and implies
- |  that the shell died abnormally.
- ************************************o*************************************/
-{
-#ifdef DEBUG_CHILD_ABORT
-    std::cout << "System::died path = '" << absNodePath << "'" << endl;
-#endif
-
-    /// always write to log, before returning
-    ecf::log(Log::ERR, reason);
-
-    /// If the Path is empty, then this could be something *OTHER THAN* job submission
-    /// Typically testing, don't assert
-    if (absNodePath.empty()) {
-        return;
-    }
-
-    defs_ptr defs = defs_.lock();
-    if (!defs.get()) {
-        LOG_ASSERT(defs.get(), "System::died, defs not defined ???");
-        return;
-    }
-
-    node_ptr node = defs->findAbsNode(absNodePath);
-    if (!node.get()) {
-#ifdef DEBUG_CHILD_ABORT
-        std::cout << "System::died " << absNodePath << " could not be found in defs \n";
-#endif
-        return;
-    }
-
-    Submittable* submittable = node->isSubmittable();
-    if (!submittable) {
-#ifdef DEBUG_CHILD_ABORT
-        std::cout << "System::died " << absNodePath << " path is NOT a Task or Alias \n";
-#endif
-        return;
-    }
-
-    // This function can get called at any time.
-    // AND out of context of any command, hence we must handle case where Suite handles are used.
-    // Otherwise the view will not know about aborted states.
-    // ECFLOW-104 aborted state for a task following an error at submission
-    SuiteChanged1 changed(submittable->suite());
-
-    // Only failure of the JOB command should cause SUBMITTABLE to abort.
-    // i.e Badly formed status and kill commands should not abort a running job
-    switch (cmd_type) {
-        case System::ECF_JOB_CMD: {
-            submittable->flag().set(ecf::Flag::JOBCMD_FAILED);
-
-            if (submittable->state() == NState::COMPLETE || submittable->state() == NState::ACTIVE) {
-                // ABNORMAL flow
-                // Occasionally TRIMURTI can time out and fail, even when the job is active or complete.(i.e for super
-                // fast jobs) queued->submitted->active->complete  See: ECFLOW-1589 In this case we should *AVOID*
-                // setting node to aborted.
-                std::string str = "System::died: ECF_JOB_CMD *failed*, but state is ";
-                str += NState::toString(submittable->state());
-                str += "(";
-                str += absNodePath;
-                str += ") setting zombie flag";
-                ecf::log(Log::ERR, str);
-                submittable->flag().set(ecf::Flag::ZOMBIE);
-#ifdef DEBUG_CHILD_ABORT
-                std::cout << str << "\n";
-#endif
-                return;
-            }
-
-#ifdef DEBUG_CHILD_ABORT
-            std::cout << "System::died aborting task " << absNodePath << "\n";
-#endif
-            // NORMAL flow   :  queued->submitted->abort  : for failing ECF_JOB_CMD
-            //
-            // Set state aborted since the job terminated abnormally, and provide a reason
-            submittable->aborted(reason);
-            break;
-        }
-        case System::ECF_KILL_CMD:
-            submittable->flag().set(ecf::Flag::KILLCMD_FAILED);
-            break;
-        case System::ECF_STATUS_CMD:
-            submittable->flag().set(ecf::Flag::STATUSCMD_FAILED);
-            break;
-    };
-}
-
-std::string System::cmd_type(System::CmdType cmd_type) {
-    switch (cmd_type) {
-        case System::ECF_JOB_CMD:
-            return "ECF_JOB_CMD";
-        case System::ECF_KILL_CMD:
-            return "ECF_KILL_CMD";
-        case System::ECF_STATUS_CMD:
-            return "ECF_STATUS_CMD";
-        default:
-            assert(false);
-    }
-    return "ECF_JOB_CMD";
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/System.hpp 5.13.0-1/ANode/src/ecflow/node/System.hpp
--- 5.12.4-1/ANode/src/ecflow/node/System.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/System.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,108 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_System_HPP
-#define ecflow_node_System_HPP
-
-///
-/// \brief Works with class Signal
-///
-/// When a child process terminates it does not disappear entirely.
-/// Instead, it becomes a ‘zombie process’ which is no longer capable of executing,
-/// but which still has a PID and an entry in the process table.
-/// This is indicated by the state code Z in ps or top.
-///
-/// The presence of a moderate number of zombie processes is not particularly harmful,
-/// but they add unnecessary clutter that can be confusing to the administrator.
-/// In extreme cases they could exhaust the number of available process table slots.
-///
-/// For these reasons, well-behaved programs should ensure that zombie processes are removed in a timely manner.
-/// The process of eliminating zombie processes is known as ‘reaping’.
-/// The simplest method is to call wait, but this will block the parent process if the child has not yet terminated.
-/// Alternatives are to use waitpid to poll or SIGCHLD to reap asynchronously.
-/// The Class uses waitpid.
-///
-
-#include <string>
-
-#include "ecflow/node/NodeFwd.hpp"
-
-namespace ecf {
-
-/// Job submission in ECF is a two phase step.
-/// phase 1: Spawn of ECF_JOB_CMD
-/// phase 2: Invocation of ECF_JOB_CMD, this creates the *real* job which communicates with the server
-/// For TEST     :ECF_JOB_CMD = "%ECF_JOB% 1> %ECF_JOBOUT% 2>&1
-///     this collapses phase 1 and 2, to a single step
-/// For Operation:ECF_JOB_CMD = ecf_submit %USER% %REMOTE_HOST% %ECFJOB% %ECFJOBOUT%'
-///     This uses ecf_submit,This spawns the process to the different load levellers depending on OS, etc.
-///   and hence involves at least 2 process.
-/// This class handles phase 1, we capture the death of the child process
-/// and hence this class will not in operations handle the death of the real job
-/// created by ecf_submit.
-
-class System {
-public:
-    // Disable copy (and move) semantics
-    System(const System&)                  = delete;
-    const System& operator=(const System&) = delete;
-
-    static System* instance();
-
-    /// Destroy the singleton. used in test only, to avoid valgrind issues
-    static void destroy();
-
-    /// Let the server set this. Typically only set once, however in test  can be many times
-    /// Note:: In test the Defs file in the server can be cleared, i.e. for each new test
-    ///        Hence we maintain a weak_ptr to the Defs.
-    void setDefs(const defs_ptr& defs) { defs_ = defs; }
-
-    // return true, if command can be spawned, else false.
-    // For jobs, We can't store reference to Task*, as future functionality like
-    // auto-migrate, etc, means we may end up pointing to garbage.
-    // so instead we will store absNodePath. For other commands this can be empty
-    enum CmdType { ECF_JOB_CMD, ECF_KILL_CMD, ECF_STATUS_CMD };
-    bool spawn(CmdType, const std::string& cmdToSpawn, const std::string& absPath, std::string& errorMsg);
-
-    // Handle children that have stopped,aborted or terminated, etc.
-    // The signal handler is kept as light as possible, since it is re-entrant.
-    // So Signal handles stores the termination state which handled later
-    // by processTerminatedChildren. Typically, when we un-block SIGCHILD
-    void processTerminatedChildren();
-
-    /// returns the number of active process.
-    /// for debug only
-    int process() const;
-
-private:
-    ~System();
-    System();
-
-    /// Install signals that can catch signal from child process termination
-    static void catchChildProcessTermination();
-
-    // When a process terminates abnormally. This function is used to find the
-    // associated task, and set it to the abort state.
-    // Relies on the stored Defs ptr. which was set in the server
-    void died(const std::string& absNodePath, CmdType, const std::string& reason);
-
-    /// Does the real work of spawning children
-    int sys(CmdType, const std::string& cmdToSpawn, const std::string& absPath, std::string& errorMsg);
-
-    static std::string cmd_type(CmdType);
-
-private:
-    weak_defs_ptr defs_; // weak_ptr is an observer of a shared_ptr
-    static System* instance_;
-};
-
-} // namespace ecf
-
-#endif
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Task.cpp 5.13.0-1/ANode/src/ecflow/node/Task.cpp
--- 5.12.4-1/ANode/src/ecflow/node/Task.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Task.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,962 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/Task.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/DefsDelta.hpp"
-#include "ecflow/node/JobProfiler.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/NodeTreeVisitor.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/TaskScriptGenerator.hpp"
-#include "ecflow/node/move_peer.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// #define DEBUG_TASK_LOCATION 1
-void Task::copy(const Task& rhs) {
-    size_t theSize = rhs.aliases_.size();
-    for (size_t s = 0; s < theSize; s++) {
-        alias_ptr alias_copy = std::make_shared<Alias>(*rhs.aliases_[s]);
-        alias_copy->set_parent(this);
-        aliases_.push_back(alias_copy);
-    }
-}
-
-Task::Task(const Task& rhs) : Submittable(rhs), alias_no_(rhs.alias_no_) {
-    copy(rhs);
-}
-
-node_ptr Task::clone() const {
-    return std::make_shared<Task>(*this);
-}
-
-bool Task::check_defaults() const {
-    if (order_state_change_no_ != 0)
-        throw std::runtime_error("Task::check_defaults(): order_state_change_no_ != 0");
-    if (add_remove_state_change_no_ != 0)
-        throw std::runtime_error("Task::check_defaults(): add_remove_state_change_no_ != 0");
-    if (alias_change_no_ != 0)
-        throw std::runtime_error("Task::check_defaults(): alias_change_no_ != 0");
-    if (alias_no_ != 0)
-        throw std::runtime_error("Task::check_defaults(): alias_no_ != 0");
-    return Submittable::check_defaults();
-}
-
-Task& Task::operator=(const Task& rhs) {
-    if (this != &rhs) {
-        Submittable::operator=(rhs);
-        aliases_.clear();
-        alias_no_ = rhs.alias_no_;
-        copy(rhs);
-
-        order_state_change_no_      = 0;
-        alias_change_no_            = 0;
-        add_remove_state_change_no_ = Ecf::incr_state_change_no();
-    }
-    return *this;
-}
-
-Task::~Task() {
-    if (!Ecf::server()) {
-        notify_delete();
-    }
-}
-
-task_ptr Task::create(const std::string& name, bool check) {
-    return std::make_shared<Task>(name, check);
-}
-
-task_ptr Task::create_me(const std::string& name) {
-    return std::make_shared<Task>(name, true);
-}
-
-void Task::print(std::string& os) const {
-    Indentor in;
-    Indentor::indent(os);
-    os += "task ";
-    os += name();
-    if (!PrintStyle::defsStyle()) {
-        bool added_comment_char = false;
-        write_state(os, added_comment_char);
-    }
-    os += "\n";
-
-    Node::print(os);
-
-    // Generated variable are not persisted since they are created on demand
-    // There *NO* point in printing them they will always be empty
-
-    // Alias are not printed, but are check point able.
-    if (!PrintStyle::defsStyle()) {
-        Indentor in2;
-        size_t node_vec_size = aliases_.size();
-        for (size_t t = 0; t < node_vec_size; t++) {
-            aliases_[t]->print(os);
-        }
-        if (node_vec_size != 0) {
-            Indentor in3;
-            Indentor::indent(os);
-            os += "endalias\n";
-        }
-    }
-
-    // if ( PrintStyle::defsStyle() ) Indentor::indent(os); os += "endtask\n";
-}
-
-void Task::write_state(std::string& ret, bool& added_comment_char) const {
-    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
-    //             multiple statement on a single line i.e.
-    //                 task a; task b;
-    if (alias_no_ != 0) {
-        add_comment_char(ret, added_comment_char);
-        ret += " alias_no:";
-        ret += ecf::convert_to<std::string>(alias_no_);
-    }
-    Submittable::write_state(ret, added_comment_char);
-}
-
-void Task::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
-
-    if (line.find("alias_no:") != std::string::npos) {
-        // task t1 # alias_no:0 passwd:_DJP_
-        size_t line_tokens_size = lineTokens.size();
-        for (size_t i = 3; i < line_tokens_size; i++) {
-            if (lineTokens[i].find("alias_no:") != std::string::npos) {
-                std::string token;
-                if (!Extract::split_get_second(lineTokens[i], token))
-                    throw std::runtime_error("Task::read_state could not read alias_no for task " + name());
-                alias_no_ = Extract::theInt(token, "Task::read_state: invalid alias_no specified : " + line);
-                break;
-            }
-        }
-    }
-    Submittable::read_state(line, lineTokens);
-}
-
-std::ostream& operator<<(std::ostream& os, const Task& d) {
-    std::string s;
-    d.print(s);
-    os << s;
-    return os;
-}
-
-bool Task::operator==(const Task& rhs) const {
-    if (alias_no_ != rhs.alias_no_) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Task::operator==  alias_no_(" << alias_no_ << ")  != rhs.alias_no_(" << rhs.alias_no_
-                      << ") : " << absNodePath() << "\n";
-        }
-#endif
-        return false;
-    }
-
-    size_t vec_size = aliases_.size();
-    if (vec_size != rhs.aliases_.size()) {
-#ifdef DEBUG
-        if (Ecf::debug_equality()) {
-            std::cout << "Task::operator==  aliases_.size() != rhs.aliases_.size() " << absNodePath() << "\n";
-            std::cout << "   aliases_.size() = " << vec_size << "  rhs.aliases_.size() = " << rhs.aliases_.size()
-                      << "\n";
-        }
-#endif
-        return false;
-    }
-
-    for (size_t i = 0; i < vec_size; ++i) {
-
-        if (!(*aliases_[i] == *rhs.aliases_[i])) {
-#ifdef DEBUG
-            if (Ecf::debug_equality()) {
-                std::cout << "Task::operator==  !( *aliases_[i] == *rhs.aliases_[i] : " << absNodePath() << "\n";
-            }
-#endif
-            return false;
-        }
-    }
-
-    return Submittable::operator==(rhs);
-}
-
-alias_ptr Task::add_alias(std::vector<std::string>& user_file_contents,
-                          const NameValueVec& user_variables,
-                          bool create_directory) {
-    // Create directory
-    std::string dir_to_create;
-    if (create_directory) {
-
-        if (user_file_contents.empty()) {
-            std::stringstream ss;
-            ss << "Task::add_alias: No .usr file contents specified. Alias creation failed for task " << absNodePath();
-            throw std::runtime_error(ss.str());
-        }
-
-        findParentUserVariableValue(Str::ECF_HOME(), dir_to_create);
-        dir_to_create += absNodePath();
-        if (!File::createDirectories(dir_to_create)) {
-            throw std::runtime_error("Task::add_alias: could not create directory " + dir_to_create);
-        }
-    }
-
-    // create alias
-    std::string alias_name = "alias" + ecf::convert_to<std::string>(alias_no_);
-    alias_ptr alias        = Alias::create(alias_name);
-    alias->set_parent(this);
-
-    // create .usr file
-    if (create_directory) {
-        std::string file_path = dir_to_create + "/" + alias_name + alias->script_extension();
-        std::string error_msg;
-        if (!File::create(file_path, user_file_contents, error_msg)) {
-            std::stringstream ss;
-            ss << "Task::add_alias: could not create .usr file at path(" << file_path << "): " << error_msg.c_str();
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    // copy over events, meters, labels, but clear state (ECFLOW-1278)
-    for (Meter meter : meters()) {
-        meter.reset();
-        alias->addMeter(meter);
-    }
-    for (Event event : events()) {
-        event.reset();
-        alias->addEvent(event);
-    }
-    for (Label label : labels()) {
-        label.reset();
-        alias->addLabel(label);
-    }
-
-    // Add user_variables as variables. Note: to reduce memory we could choose
-    // to only add those variable that have been changed/added. However this
-    // would mean an alias could be affected by changed to an inherited variable.
-    // Hence kept as existing sms functionality
-    //
-    // The variables may be **different** to normal variables in that they may contain a ":" & $
-    // This is **not** allowed in normal variables.
-    // i.e it allows for  %A:1%, %A:2%, %A:3%
-    // This is not really recommended but its what the old system supported.
-    // **** Hence add_alias_variable by passes variable name checking ***
-    auto theEnd = user_variables.end();
-    for (auto i = user_variables.begin(); i != theEnd; ++i) {
-        alias->add_alias_variable((*i).first, (*i).second);
-    }
-
-    // increment alias number and store, alias in vector
-    alias_no_++; // Alias number must be set to next valid alias number
-    aliases_.push_back(alias);
-
-    alias_change_no_            = Ecf::incr_state_change_no();
-    add_remove_state_change_no_ = alias_change_no_;
-    return alias;
-}
-
-alias_ptr Task::add_alias_only() {
-    std::vector<std::string> empty_user_file_contents;
-    NameValueVec empty_user_variables;
-    return add_alias(empty_user_file_contents, empty_user_variables, false /* don't create directory or .usr file*/);
-}
-
-alias_ptr Task::add_alias(const std::string& name) {
-    // Do not update alias_no, since that will be read in
-    alias_ptr alias = Alias::create(name);
-    alias->set_parent(this);
-    aliases_.push_back(alias);
-    return alias;
-}
-
-alias_ptr Task::find_alias(const std::string& name) const {
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (aliases_[i]->name() == name) {
-            return aliases_[i];
-        }
-    }
-    return alias_ptr();
-}
-
-void Task::reset_alias_number() {
-    alias_no_        = 0;
-    alias_change_no_ = Ecf::incr_state_change_no();
-}
-
-node_ptr Task::findImmediateChild(const std::string& name, size_t& child_pos) const {
-    child_pos       = std::numeric_limits<std::size_t>::max();
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (aliases_[i]->name() == name) {
-            child_pos = i;
-            return aliases_[i];
-        }
-    }
-    return node_ptr();
-}
-
-node_ptr Task::find_immediate_child(const std::string_view& name) const {
-    for (const auto& n : aliases_) {
-        if (name == n->name()) {
-            return n;
-        }
-    }
-    return node_ptr();
-}
-
-std::string Task::find_node_path(const std::string& type, const std::string& node_name) const {
-    if (Str::caseInsCompare(type, "task")) {
-        if (node_name == name()) {
-            return absNodePath();
-        }
-    }
-    return string();
-}
-
-void Task::reset() {
-    if (aliases_.empty()) {
-        if (alias_no_ != 0) {
-            reset_alias_number();
-        }
-    }
-    Submittable::reset();
-}
-
-void Task::begin() {
-    if (aliases_.empty()) {
-        if (alias_no_ != 0) {
-            reset_alias_number();
-        }
-    }
-
-    Submittable::begin();
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Task::begin()\n";
-#endif
-}
-
-void Task::requeue(Requeue_args& args) {
-    if (aliases_.empty()) {
-        if (alias_no_ != 0) {
-            reset_alias_number();
-        }
-    }
-
-    Submittable::requeue(args);
-
-#ifdef DEBUG_STATE_CHANGE_NO
-    std::cout << "Task::requeue\n";
-#endif
-}
-
-void Task::accept(ecf::NodeTreeVisitor& v) {
-    v.visitTask(this);
-}
-
-void Task::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
-    v.visitTask(this);
-}
-
-const std::string& Task::debugType() const {
-    return ecf::Str::TASK();
-}
-
-void Task::getAllNodes(std::vector<Node*>& vec) const {
-    // See notes: getAllSubmittables, about reserve
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        vec.push_back(aliases_[i].get());
-    }
-}
-
-void Task::immediateChildren(std::vector<node_ptr>& vec) const {
-    size_t vec_size = aliases_.size();
-    vec.reserve(vec.size() + vec_size);
-    for (size_t i = 0; i < vec_size; i++) {
-        vec.push_back(std::dynamic_pointer_cast<Node>(aliases_[i]));
-    }
-}
-
-void Task::getAllTasks(std::vector<Task*>& vec) const {
-    vec.push_back(const_cast<Task*>(this));
-}
-
-void Task::getAllSubmittables(std::vector<Submittable*>& vec) const {
-    // *DO NOT reserve here, as it dominate time , for very large defs */
-    // * Previously we had::
-    //    vec.reserve(vec.size() + vec_size + 1);
-    // * This took 47 seconds when delete the full defs, i.e when check for active tasks
-
-    vec.push_back(const_cast<Task*>(this));
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        vec.push_back(aliases_[i].get());
-    }
-}
-
-node_ptr Task::find_node_up_the_tree(const std::string& name) const {
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (aliases_[i]->name() == name) {
-            return aliases_[i];
-        }
-    }
-    Node* the_parent = parent();
-    if (the_parent)
-        return the_parent->find_node_up_the_tree(name);
-    return node_ptr();
-}
-
-void Task::get_all_active_submittables(std::vector<Submittable*>& vec) const {
-    // See notes: getAllSubmittables, about reserve
-    if (state() == NState::ACTIVE || state() == NState::SUBMITTED) {
-        vec.push_back(const_cast<Task*>(this));
-    }
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (aliases_[i]->state() == NState::ACTIVE || aliases_[i]->state() == NState::SUBMITTED) {
-            vec.push_back(aliases_[i].get());
-        }
-    }
-}
-
-void Task::get_all_tasks(std::vector<task_ptr>& vec) const {
-    vec.push_back(std::dynamic_pointer_cast<Task>(non_const_this()));
-}
-
-void Task::get_all_nodes(std::vector<node_ptr>& nodes) const {
-    nodes.push_back(non_const_this());
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        aliases_[i]->get_all_nodes(nodes);
-    }
-}
-
-void Task::get_all_aliases(std::vector<alias_ptr>& destinationVec) const {
-    destinationVec.reserve(destinationVec.size() + aliases_.size());
-    std::copy(aliases_.begin(), aliases_.end(), std::back_inserter(destinationVec));
-}
-
-bool Task::resolveDependencies(JobsParam& jobsParam) {
-    if (jobsParam.timed_out_of_job_generation())
-        return false;
-    JobProfiler profile_me(this, jobsParam, JobProfiler::task_threshold());
-    if (jobsParam.timed_out_of_job_generation())
-        return false;
-
-    // Calling Submittable::resolveDependencies(jobsParam) up front can be expensive.
-    // Due to trigger and complete evaluations. Hence low cost state checks first
-
-    // Do state checking for tasks only. Note: container nodes inherit the most significant state
-    // from the children, hence we can't use the same same algorithm for containers nodes and leaf
-    // nodes like task.
-    NState::State task_state = state();
-    if (task_state == NState::COMPLETE || task_state == NState::ACTIVE || task_state == NState::SUBMITTED ||
-        task_state == NState::UNKNOWN) {
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG,
-            "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state " << NState::toString(state())
-                                              << " is not valid for job submission");
-#endif
-        return false;
-    }
-    else if (task_state == NState::ABORTED) {
-
-        /// If we have been forcibly aborted by the user. Do not resubmit jobs, until *begin* or *re-queue*. ECFLOW-344
-        if (get_flag().is_set(ecf::Flag::FORCE_ABORT)) {
-#ifdef DEBUG_DEPENDENCIES
-            LOG(Log::DBG,
-                "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state "
-                                                  << NState::toString(state()) << " has been forcibly aborted.");
-#endif
-            return false;
-        }
-
-        /// If we have been killed by the user. Do not resubmit jobs, until *begin* or *re-queue*
-        if (get_flag().is_set(ecf::Flag::KILLED)) {
-#ifdef DEBUG_DEPENDENCIES
-            LOG(Log::DBG,
-                "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state "
-                                                  << NState::toString(state()) << " has been killed.");
-#endif
-            return false;
-        }
-
-        // Job cmd failed. Do not resubmit jobs, until *begin* or *re-queue*. ECFLOW-1216
-        if (get_flag().is_set(ecf::Flag::EDIT_FAILED)) {
-            return false; // pre-processing, variable subs, create directory, change job file permission failed
-        }
-        if (get_flag().is_set(ecf::Flag::NO_SCRIPT)) {
-            return false; // .ecf file location failed
-        }
-        if (get_flag().is_set(ecf::Flag::JOBCMD_FAILED)) {
-            return false; // Process exited with non-zero exit.
-                          // *OR* Job submission failed.
-        }
-
-        // If the task was aborted, and we have not exceeded ECF_TRIES, then resubmit
-        // otherwise ONLY in state QUEUED can we submit jobs
-        std::string varValue;
-        if (findParentUserVariableValue(Str::ECF_TRIES(), varValue)) {
-            // std::cout << "tryNo_ = " << tryNo_ << " ECF_TRIES = " <<  varValue << "\n";
-            try {
-                auto ecf_tries = ecf::convert_to<int>(varValue);
-                if (try_no() >= ecf_tries) {
-#ifdef DEBUG_DEPENDENCIES
-                    LOG(Log::DBG,
-                        "   Task::resolveDependencies() " << absNodePath() << " HOLDING as tryNo_("
-                                                          << tryNo_ ") >= ECF_TRIES(" << ecf_tries
-                                                          << ") state = " << NState::toString(state()));
-#endif
-                    return false;
-                }
-            }
-            catch (const ecf::bad_conversion&) {
-                LOG(Log::ERR,
-                    "Variable ECF_TRIES must be convertible to an integer. Cannot resubmit job for task:"
-                        << absNodePath());
-                return false;
-            }
-        }
-    }
-#ifdef DEBUG
-    else {
-        /// Only one state left
-        assert(task_state == NState::QUEUED);
-    }
-#endif
-
-    /// If we have been forcibly aborted by the user. Do not resubmit jobs, until *begin* or *re-queue*
-    /// ***** This can be set via ALTER, so independent of state ***********
-    if (get_flag().is_set(ecf::Flag::FORCE_ABORT)) {
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG,
-            "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state " << NState::toString(state())
-                                              << " has been forcibly aborted.");
-#endif
-        return false;
-    }
-
-    // Improve the granularity for the check for lateness (during job submission). See SUP-873 "late" functionality
-    // Does not deal with inherited late
-    if (get_late()) {
-        // since the suite() traverse up the tree, only call when have a late attribute
-        checkForLateness(suite()->calendar());
-    }
-
-    if (!Node::resolveDependencies(jobsParam)) {
-
-#ifdef DEBUG_JOB_SUBMISSION
-        LOG(Log::DBG,
-            "   Task::resolveDependencies " << absNodePath() << " could not resolve dependencies, may have completed");
-        cout << "Task::resolveDependencies " << absNodePath() << " could not resolve dependencies may have completed"
-             << endl;
-#endif
-        return false;
-    }
-
-    /// By default node tree traversal is top down. hence we only check in limits, at *that* level.
-    /// However *EACH* job submission can *affect* the in limits, hence we *must* check we are in
-    /// limit *up* the node tree. Done last and only in this function (as opposed to Node) as an optimisation
-    if (!check_in_limit_up_node_tree()) {
-#ifdef DEBUG_DEPENDENCIES
-        LOG(Log::DBG, "   Task::resolveDependencies() " << absNodePath() << " FREE of TRIGGER and inLIMIT");
-#endif
-        return false;
-    }
-
-    // call just before job submission, reset data members, update try_no, and generate variable
-    // *PLACED* outside of submitJob() so that we can configure job generation file ECF_JOB for test/python
-    increment_try_no(); // will increment state_change_no
-
-    if (jobsParam.createJobs()) {
-        // The task are ready for job submission.Clear process id and remote id (ECF_RID)
-        // Locate the ecf files corresponding to the task. Pre-process
-        // them(i.e expand includes, remove comments,manual) and perform
-        // variable substitution. This will then form the jobs file.
-        // If the job file already exist it is overridden
-        submit_job_only(jobsParam);
-    }
-    else {
-        // *************************************************************************************
-        // Debug/test path only... Enabled for testing when we don't want to create/spawn jobs
-        // ** Simulate ** job submission as closely as possible. For testing
-        // *************************************************************************************
-        jobsParam.push_back_submittable(this);
-
-        // follow normal life cycle queued->submitted->active. In real life there may be a noticeable
-        // time delay between process creation (via a user command, which could do anything)
-        // and when created process start talking back to the server.
-        // *** Setting state to SUBMITTED will increment any inlimit/Limit via handleStateChange
-        set_state(NState::SUBMITTED);
-
-        // The spawned process will typically call this, via client api. Set task into active state
-        // *** Test path, we take the hit of calling handleStateChange again.
-        init(Submittable::DUMMY_PROCESS_OR_REMOTE_ID());
-    }
-    return true;
-}
-
-void Task::generate_scripts(const std::map<std::string, std::string>& override) const {
-    TaskScriptGenerator ecf(this);
-    ecf.generate(override);
-}
-
-node_ptr Task::removeChild(Node* child) {
-#ifdef DEBUG
-    assert(child);
-    assert(child->isAlias());
-#endif
-    SuiteChanged1 changed(suite());
-    size_t node_vec_size = aliases_.size();
-    for (size_t t = 0; t < node_vec_size; t++) {
-        if (aliases_[t].get() == child) {
-            child->set_parent(nullptr);
-            node_ptr node = std::dynamic_pointer_cast<Alias>(aliases_[t]);
-            aliases_.erase(aliases_.begin() + t);
-            add_remove_state_change_no_ = Ecf::incr_state_change_no();
-            return node;
-        }
-    }
-    // Should never happen
-    LOG_ASSERT(false, "Task::removeChild: Could not remove child");
-    return node_ptr();
-}
-
-bool Task::doDeleteChild(Node* child) {
-    SuiteChanged1 changed(suite());
-    auto the_end = aliases_.end();
-    for (auto t = aliases_.begin(); t != the_end; ++t) {
-        if ((*t).get() == child) {
-            if (child && child->parent())
-                child->set_parent(nullptr);
-            aliases_.erase(t);
-            add_remove_state_change_no_ = Ecf::incr_state_change_no();
-            return true;
-        }
-    }
-    return false;
-}
-
-bool Task::addChild(const node_ptr&, size_t) {
-    // Only used during PLUG: aliases can't be plugged.
-    LOG_ASSERT(false, "");
-    return false;
-}
-
-bool Task::isAddChildOk(Node*, std::string& errorMsg) const {
-    // Only used during PLUG: aliases can't be plugged.
-    errorMsg += "Cannot add children to a task node.";
-    return false;
-}
-
-size_t Task::child_position(const Node* child) const {
-    size_t vec_size = aliases_.size();
-    for (size_t t = 0; t < vec_size; t++) {
-        if (aliases_[t].get() == child) {
-            return t;
-        }
-    }
-    return std::numeric_limits<std::size_t>::max();
-}
-
-void Task::order(Node* immediateChild, NOrder::Order ord) {
-    SuiteChanged1 changed(suite());
-    switch (ord) {
-        case NOrder::TOP: {
-            for (auto i = aliases_.begin(); i != aliases_.end(); ++i) {
-                if ((*i).get() == immediateChild) {
-                    alias_ptr node = (*i);
-                    aliases_.erase(i);
-                    aliases_.insert(aliases_.begin(), node);
-                    order_state_change_no_ = Ecf::incr_state_change_no();
-                    return;
-                }
-            }
-            throw std::runtime_error("Task::order TOP, immediate child not found");
-        }
-        case NOrder::BOTTOM: {
-            for (auto i = aliases_.begin(); i != aliases_.end(); ++i) {
-                if ((*i).get() == immediateChild) {
-                    alias_ptr node = (*i);
-                    aliases_.erase(i);
-                    aliases_.push_back(node);
-                    order_state_change_no_ = Ecf::incr_state_change_no();
-                    return;
-                }
-            }
-            throw std::runtime_error("Task::order BOTTOM, immediate child not found");
-        }
-        case NOrder::ALPHA: {
-            std::sort(aliases_.begin(), aliases_.end(), [](const alias_ptr& a, const alias_ptr& b) {
-                return Str::caseInsLess(a->name(), b->name());
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            break;
-        }
-        case NOrder::ORDER: {
-            std::sort(aliases_.begin(), aliases_.end(), [](const alias_ptr& a, const alias_ptr& b) {
-                return Str::caseInsGreater(a->name(), b->name());
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            break;
-        }
-        case NOrder::UP: {
-            for (size_t t = 0; t < aliases_.size(); t++) {
-                if (aliases_[t].get() == immediateChild) {
-                    if (t != 0) {
-                        alias_ptr node = aliases_[t];
-                        aliases_.erase(aliases_.begin() + t);
-                        t--;
-                        aliases_.insert(aliases_.begin() + t, node);
-                        order_state_change_no_ = Ecf::incr_state_change_no();
-                    }
-                    return;
-                }
-            }
-            throw std::runtime_error("Task::order UP, immediate child not found");
-        }
-        case NOrder::DOWN: {
-            for (size_t t = 0; t < aliases_.size(); t++) {
-                if (aliases_[t].get() == immediateChild) {
-                    if (t != aliases_.size() - 1) {
-                        alias_ptr node = aliases_[t];
-                        aliases_.erase(aliases_.begin() + t);
-                        t++;
-                        aliases_.insert(aliases_.begin() + t, node);
-                        order_state_change_no_ = Ecf::incr_state_change_no();
-                    }
-                    return;
-                }
-            }
-            throw std::runtime_error("Task::order DOWN, immediate child not found");
-        }
-        case NOrder::RUNTIME: {
-            for (alias_ptr alias : aliases_) {
-                if (alias->state() != NState::COMPLETE) {
-                    throw std::runtime_error("Task::order: To order by RUNTIME All aliases must be complete");
-                }
-            }
-            (void)sum_runtime();
-            std::sort(aliases_.begin(), aliases_.end(), [](const alias_ptr& a, const alias_ptr& b) {
-                return a->state_change_runtime() > b->state_change_runtime();
-            });
-            order_state_change_no_ = Ecf::incr_state_change_no();
-            break;
-        }
-    }
-}
-
-void Task::move_peer(Node* src, Node* dest) {
-    move_peer_node(aliases_, src, dest, "Task");
-    order_state_change_no_ = Ecf::incr_state_change_no();
-}
-
-bool Task::checkInvariants(std::string& errorMsg) const {
-    if (!Node::checkInvariants(errorMsg))
-        return false;
-
-    size_t vec_size = aliases_.size();
-    for (size_t t = 0; t < vec_size; t++) {
-        if (aliases_[t]->parent() != this) {
-            std::stringstream ss;
-            ss << "Task::checkInvariants alias(" << aliases_[t]->name()
-               << ") parent() not correct. See task : " << absNodePath();
-            errorMsg += ss.str();
-            return false;
-        }
-        if (!aliases_[t]->checkInvariants(errorMsg)) {
-            return false;
-        }
-    }
-    //   if ( vec_size > alias_no_ ) {
-    //      std::stringstream ss;
-    //      ss << "Task::checkInvariants: alias vector size " << vec_size << " should be less or equal to alias_no_ " <<
-    //      alias_no_ << " for task " << absNodePath() << "\n"; errorMsg += ss.str(); return false;
-    //   }
-    return true;
-}
-
-void Task::handleStateChange() {
-    /// Increment/decrement limits based on the current state
-    update_limits();
-
-    // Check if a re queue is required, then can eventually change the state, if
-    // repeats, time,today, or cron are involved, hence must be done last
-    // This will recurse up the node tree, causing repeats to increment, at the parent
-    // level and resetting repeats in the children. To mimic nested loops.
-    requeueOrSetMostSignificantStateUpNodeTree();
-
-    Node::handleStateChange(); // may do a autorestore, if state is COMPLETE
-}
-
-const std::string& Task::script_extension() const {
-    // Migration support, allow user to specify extension. This allows users to use '.sms'
-    // Note: This should be removed in the future since there is performance hit.
-    //       searching up the node tree, when most of the time we are using .ecf
-    const std::string& ecf_extn = find_parent_user_variable_value(Str::ECF_EXTN());
-    if (!ecf_extn.empty())
-        return ecf_extn;
-    return File::ECF_EXTN(); // ".ecf"
-}
-
-void Task::collateChanges(DefsDelta& changes) const {
-    //   std::cout << "Task::collateChanges " << debugNodePath()
-    //             << " changes.client_state_change_no() = " << changes.client_state_change_no()
-    //             << " add_remove_state_change_no_ = " << add_remove_state_change_no_
-    //             << " order_state_change_no_ = " << order_state_change_no_
-    //             << " alias_change_no_ " << alias_change_no_
-    //             << "\n";
-
-    /// All changes to Task should be on ONE compound_memento_ptr
-    compound_memento_ptr comp;
-
-    /// There no point doing a OrderMemento if children have been added/delete
-    if (add_remove_state_change_no_ > changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<AliasChildrenMemento>(aliases_));
-    }
-    else if (order_state_change_no_ > changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        std::vector<std::string> order_vec;
-        order_vec.reserve(aliases_.size());
-        size_t node_vec_size = aliases_.size();
-        for (size_t i = 0; i < node_vec_size; i++)
-            order_vec.push_back(aliases_[i]->name());
-        comp->add(std::make_shared<OrderMemento>(order_vec));
-    }
-
-    if (alias_change_no_ > changes.client_state_change_no()) {
-        if (!comp.get())
-            comp = std::make_shared<CompoundMemento>(absNodePath());
-        comp->add(std::make_shared<AliasNumberMemento>(alias_no_));
-    }
-
-    // ** base class will add compound memento into changes.
-    Submittable::incremental_changes(changes, comp);
-
-    // Traversal to children
-    size_t vec_size = aliases_.size();
-    for (size_t t = 0; t < vec_size; t++) {
-        aliases_[t]->collateChanges(changes);
-    }
-}
-
-void Task::set_memento(const OrderMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Task::set_memento( const OrderMemento* ) " << debugNodePath() << "\n";
-#endif
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::ORDER);
-        return;
-    }
-
-    // Order aliases_ according to memento ordering
-    const std::vector<std::string>& order = memento->order_;
-    if (order.size() != aliases_.size()) {
-        // something gone wrong.
-        std::cout << "Task::set_memento OrderMemento, memento.size() " << order.size()
-                  << " Not the same as aliases_size() " << aliases_.size() << "\n";
-        return;
-    }
-
-    std::vector<alias_ptr> vec;
-    vec.reserve(aliases_.size());
-    size_t node_vec_size = aliases_.size();
-    for (const auto& i : order) {
-        for (size_t t = 0; t < node_vec_size; t++) {
-            if (i == aliases_[t]->name()) {
-                vec.push_back(aliases_[t]);
-                break;
-            }
-        }
-    }
-    if (vec.size() != aliases_.size()) {
-        std::cout << "Task::set_memento(const OrderMemento* memento) could not find all the names\n";
-        return;
-    }
-
-    aliases_ = vec;
-}
-
-void Task::set_memento(const AliasChildrenMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Task::set_memento( const AliasChildrenMemento* ) " << debugNodePath() << "\n";
-#endif
-
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::ADD_REMOVE_NODE);
-        return;
-    }
-
-    // set up alias parent pointers. since they are *NOT* serialised.
-    aliases_        = memento->children_;
-    size_t vec_size = aliases_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        aliases_[i]->set_parent(this);
-    }
-}
-
-void Task::set_memento(const AliasNumberMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
-#ifdef DEBUG_MEMENTO
-    std::cout << "Task::set_memento( const AliasNumberMemento* ) " << debugNodePath() << "\n";
-#endif
-    if (aspect_only) {
-        aspects.push_back(ecf::Aspect::ALIAS_NUMBER);
-        return;
-    }
-
-    alias_no_ = memento->alias_no_;
-}
-
-template <class Archive>
-void Task::serialize(Archive& ar, std::uint32_t const version) {
-    ar(cereal::base_class<Submittable>(this));
-    CEREAL_OPTIONAL_NVP(ar, alias_no_, [this]() { return alias_no_ != 0; });   // conditionally save
-    CEREAL_OPTIONAL_NVP(ar, aliases_, [this]() { return !aliases_.empty(); }); // conditionally save
-
-    // Setup the alias parent pointers. Since they are not serialised
-    // ********************************************************************
-    // WE do not serialise the Alias parent pointer:
-    // WHY: AliasChildrenMenento saves a vector of aliases, had we serialised
-    //      the parent, it would also serialise the parent pointer(Task)
-    //      i.e the ENTIRE task, and then Task parent, and so on, up the parent hierarchy.
-    //      In our case it lead to unregistered class exception when trying to
-    //      serialise the Task's parent.
-    // SOLN: WE will not serialise the alias parent pointer. This will be left to
-    //       Parent task.
-    // ********************************************************************
-    if (Archive::is_loading::value) {
-        size_t vec_size = aliases_.size();
-        for (size_t i = 0; i < vec_size; i++) {
-            aliases_[i]->set_parent(this);
-        }
-    }
-}
-
-CEREAL_TEMPLATE_SPECIALIZE_V(Task);
-CEREAL_REGISTER_TYPE(Task)
diff -pruN 5.12.4-1/ANode/src/ecflow/node/Task.hpp 5.13.0-1/ANode/src/ecflow/node/Task.hpp
--- 5.12.4-1/ANode/src/ecflow/node/Task.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/Task.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_Task_HPP
-#define ecflow_node_Task_HPP
-
-#include "ecflow/node/Submittable.hpp"
-
-class Task final : public Submittable {
-public:
-    explicit Task(const std::string& name, bool check = true) : Submittable(name, check) {}
-    Task() = default;
-    Task(const Task& rhs);
-    Task& operator=(const Task&);
-    node_ptr clone() const override;
-    ~Task() override;
-
-    bool check_defaults() const override;
-
-    static task_ptr create(const std::string& name, bool check = true);
-    static task_ptr create_me(const std::string& name); // python api, to pick correct init function
-
-    void print(std::string&) const override;
-    bool operator==(const Task& rhs) const;
-
-    /// Add an alias. The .usr is populated with contents of user_file_contents
-    /// If create_directory is unset we create the alias with creating directory or .usr file
-    alias_ptr add_alias(std::vector<std::string>& user_file_contents,
-                        const NameValueVec& user_variables,
-                        bool create_directory = true);
-
-    /// Add alias without creating directory & user file
-    alias_ptr add_alias_only();
-
-    /// For Addition of alias via Defs Files
-    alias_ptr add_alias(const std::string& name);
-
-    /// Given a name find the alias.
-    alias_ptr find_alias(const std::string& name) const;
-
-    /// Reset alias number. Used in testing
-    void reset_alias_number();
-
-    /// return list of aliases held by this task
-    const std::vector<alias_ptr>& aliases() { return aliases_; }
-    void immediateChildren(std::vector<node_ptr>&) const override;
-
-    /// Overidden from Submittable
-    const std::string& script_extension() const override;
-
-    node_ptr find_node_up_the_tree(const std::string& name) const override;
-
-    std::string find_node_path(const std::string& type, const std::string& name) const override;
-
-    /// Added for consistency, really used to find relative nodes, aliases should never, be in referenced nodes
-    node_ptr find_relative_node(const std::vector<std::string>& pathToNode) override { return node_ptr(); }
-
-    /// Overridden to reset the try number
-    /// The tasks job can be invoked multiple times. For each invocation we want to preserve
-    /// the output. The try number is used in SMSJOB/SMSJOBOUT to preserve the output when
-    /// there are multiple runs.  re-queue/begin() resets the try Number
-    void reset() override;
-    void begin() override;
-    void requeue(Requeue_args&) override;
-
-    Suite* suite() const override { return parent()->suite(); }
-    Defs* defs() const override {
-        return (parent()) ? parent()->defs() : nullptr;
-    } // exposed to python hence check for NULL first
-    Task* isTask() const override { return const_cast<Task*>(this); }
-    Submittable* isSubmittable() const override { return const_cast<Task*>(this); }
-
-    void accept(ecf::NodeTreeVisitor&) override;
-    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
-
-    void getAllNodes(std::vector<Node*>&) const override;
-    void getAllTasks(std::vector<Task*>&) const override;
-    void getAllSubmittables(std::vector<Submittable*>&) const override;
-    void get_all_active_submittables(std::vector<Submittable*>&) const override;
-    void get_all_tasks(std::vector<task_ptr>&) const override;
-    void get_all_nodes(std::vector<node_ptr>&) const override;
-    void get_all_aliases(std::vector<alias_ptr>&) const override;
-
-    const std::string& debugType() const override;
-
-    /// submits the jobs of the dependencies resolve
-    bool resolveDependencies(JobsParam& jobsParam) override;
-
-    node_ptr removeChild(Node* child) override;
-    bool addChild(const node_ptr& child, size_t position = std::numeric_limits<std::size_t>::max()) override;
-    bool isAddChildOk(Node* child, std::string& errorMsg) const override;
-
-    void order(Node* immediateChild, NOrder::Order) override;
-    void move_peer(Node* src, Node* dest) override;
-
-    void generate_scripts(const std::map<std::string, std::string>& override) const override;
-
-    bool checkInvariants(std::string& errorMsg) const override;
-
-    void collateChanges(DefsDelta&) const override;
-    void set_memento(const OrderMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool);
-    void set_memento(const AliasChildrenMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool);
-    void set_memento(const AliasNumberMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool);
-    void set_memento(const SubmittableMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
-        Submittable::set_memento(m, aspects, f);
-    }
-
-    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
-
-private:
-    void copy(const Task&);
-    size_t child_position(const Node*) const override;
-    void write_state(std::string&, bool&) const override;
-
-private:
-    /// For use by python interface,
-    std::vector<alias_ptr>::const_iterator alias_begin() const { return aliases_.begin(); }
-    std::vector<alias_ptr>::const_iterator alias_end() const { return aliases_.end(); }
-    friend void export_Task();
-
-private:
-    // Overridden from Node to increment/decrement limits
-    void handleStateChange() override;
-    bool doDeleteChild(Node* child) override;
-
-    // Overridden to locate alias's
-    node_ptr findImmediateChild(const std::string& name, size_t& child_pos) const override;
-    node_ptr find_immediate_child(const std::string_view&) const override;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version);
-
-private:
-    unsigned int order_state_change_no_{0};      // no need to persist
-    unsigned int add_remove_state_change_no_{0}; // no need to persist
-
-    unsigned int alias_change_no_{0}; // no need to persist, for alias number only
-    unsigned int alias_no_{0};
-    std::vector<alias_ptr> aliases_;
-};
-
-std::ostream& operator<<(std::ostream& os, const Task&);
-
-#endif /* ecflow_node_Task_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/TaskScriptGenerator.cpp 5.13.0-1/ANode/src/ecflow/node/TaskScriptGenerator.cpp
--- 5.12.4-1/ANode/src/ecflow/node/TaskScriptGenerator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/TaskScriptGenerator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,328 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/TaskScriptGenerator.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace boost;
-
-namespace ecf {
-
-TaskScriptGenerator::TaskScriptGenerator(const Task* task) : task_(task), is_dummy_task_(false) {
-    /// if ECF_DUMMY_TASK specified ignore
-    std::string theValue;
-    is_dummy_task_ = task_->findParentUserVariableValue(Str::ECF_DUMMY_TASK(), theValue);
-    if (is_dummy_task_)
-        return;
-
-    /// if ECF_FILES specified use this before ECF_HOME
-    if (task_->findParentUserVariableValue(Str::ECF_FILES(), ecf_files_)) {
-        // Create any missing directories if ECF_FILES is specified
-        try {
-            fs::create_directories(ecf_files_);
-        }
-        catch (std::exception& e) {
-            std::stringstream ss;
-            ss << "TaskScriptGenerator: Could not create directories for ECF_FILES " << ecf_files_ << " " << e.what();
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    /// Find ECF_HOME and ECF_INCLUDE
-    if (!task_->findParentUserVariableValue(Str::ECF_HOME(), ecf_home_)) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator: Could not generate scripts for task " << task_->absNodePath()
-           << " no ECF_HOME specified\n";
-        throw std::runtime_error(ss.str());
-    }
-    if (!task_->findParentUserVariableValue(Str::ECF_INCLUDE(), ecf_include_)) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator: Could not generate scripts for task " << task_->absNodePath()
-           << " no ECF_INCLUDE specified\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // Create any missing directories,
-    try {
-        fs::create_directories(ecf_home_);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator: Could not create directories for ECF_HOME " << ecf_home_ << " " << e.what();
-        throw std::runtime_error(ss.str());
-    }
-
-    try {
-        fs::create_directories(ecf_include_);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator: Could not create directories for ECF_INCLUDE " << ecf_include_ << " " << e.what();
-        throw std::runtime_error(ss.str());
-    }
-}
-
-void TaskScriptGenerator::generate(const std::map<std::string, std::string>& override) {
-    // Ignore generation for dummy tasks
-    if (is_dummy_task_)
-        return;
-
-    // If ECF_FILES was specified use that in preference to ECF_HOME for the ecf files.
-    std::string root_directory_for_ecf_files;
-    if (!ecf_files_.empty())
-        root_directory_for_ecf_files = ecf_files_;
-    else
-        root_directory_for_ecf_files = ecf_home_;
-
-    // Note: task_->absNodePath() starts with /.
-    std::string ecf_file_path = root_directory_for_ecf_files + task_->absNodePath() + task_->script_extension();
-    if (fs::exists(ecf_file_path)) {
-        std::cout << "Cannot generate. Script file " << ecf_file_path << " already exists\n";
-        return;
-    }
-
-    if (!File::createMissingDirectories(ecf_file_path)) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator::generate: Could not create missing directories '" << ecf_file_path << "' for task "
-           << task_->absNodePath();
-        throw std::runtime_error(ss.str());
-    }
-
-    // Create file head.h and tail.h in directory ECF_INCLUDE, check to see if they exist first
-    // If the variable ECF_CLIENT_EXE_PATH is specified use it
-    generate_head_file();
-    generate_tail_file();
-
-    // Create ECF file with default template or custom  file.
-    // cout << "creating ecf file  " << ecf_file_path << "\n";
-    std::string contents;
-    auto it = override.find(task_->absNodePath());
-    if (it == override.end()) {
-        contents = getDefaultTemplateEcfFile();
-    }
-    else {
-        contents = (*it).second;
-    }
-
-    std::string errorMsg;
-    if (!File::create(ecf_file_path, contents, errorMsg)) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator::generate: Could not create '.ecf' script for task " << task_->absNodePath() << " "
-           << errorMsg;
-        throw std::runtime_error(ss.str());
-    }
-    std::cout << "Generated script file " << ecf_file_path << "\n";
-}
-
-static void add_queue(std::string& content, const std::string& client_exe, const std::string& sleep, const Node* node) {
-    const std::vector<QueueAttr>& queues = node->queues();
-    for (const QueueAttr& queue : queues) {
-        content += "\n";
-        content += "for i in";
-        const std::vector<std::string>& queue_list = queue.list();
-        for (const auto& i : queue_list) {
-            content += " ";
-            content += i;
-        }
-        content += "\n";
-        content += "do\n";
-        content += "   step=$(" + client_exe + "--queue=" + queue.name() + " active " + node->absNodePath() + " )\n";
-        content += "   echo $step\n";
-        content += "   " + sleep;
-        content += "   " + client_exe + "--queue=" + queue.name() + " complete $step " + node->absNodePath() + "\n";
-        content += "done\n";
-    }
-}
-
-std::string TaskScriptGenerator::getDefaultTemplateEcfFile() const {
-    std::string content;
-
-    std::string sleep, var_sleep;
-    if (task_->findParentUserVariableValue("SLEEP", var_sleep))
-        sleep = "sleep %SLEEP%\n";
-    else
-        sleep = "sleep 1\n";
-
-    std::string client_exe = "%ECF_CLIENT_EXE_PATH:";
-    client_exe += Ecf::CLIENT_NAME();
-    client_exe += "% ";
-
-    content += "%include <head.h>\n";
-    content += "%manual\n";
-    content += "This is the default **generated** ecf script file\n";
-    content += "If the task has events, meters or labels then the associated client\n";
-    content += "to server commands are automatically generated.\n";
-    content += "Will default to sleep for one second in between calls to the events, meters & labels,\n";
-    content += "this can be overridden by adding a variable SLEEP\n";
-    content += "%end\n";
-    content += "\n";
-    content += "%comment\n";
-    content += "#============================================================\n";
-    content += "# Using angle brackets means we look in directory ECF_INCLUDE\n";
-    content += "# and then ECF_HOME\n";
-    content += "#============================================================\n";
-    content += "%end\n";
-    content += "\n";
-    content += "echo do some work\n";
-    for (const Event& e : task_->events()) {
-        if (e.initial_value())
-            content += client_exe + "--event=" + e.name_or_number() + " clear\n";
-        else
-            content += client_exe + "--event=" + e.name_or_number() + "\n"; // same as set
-        content += sleep;
-    }
-
-    content += "\n";
-    for (const Meter& m : task_->meters()) {
-        content += "for i in";
-        for (int i = m.min(); i <= m.max(); i = i + 1) {
-            content += " ";
-            content += ecf::convert_to<std::string>(i);
-        }
-        content += "\n";
-        content += "do\n";
-        content += "   " + client_exe + "--meter=" + m.name() + " $i\n";
-        content += "   " + sleep;
-        content += "done\n";
-    }
-    content += "\n";
-
-    /// labels require at least 2 arguments,
-    for (const Label& label : task_->labels()) {
-
-        if (!label.new_value().empty()) {
-            content += client_exe + "--label=" + label.name() + " " + label.new_value() + "\n";
-        }
-        else if (!label.value().empty()) {
-            content += client_exe + "--label=" + label.name() + " " + label.value() + "\n";
-        }
-        content += sleep;
-    }
-
-    /// Queues
-    add_queue(content, client_exe, sleep, task_);
-    Node* parent = task_->parent();
-    while (parent) {
-        add_queue(content, client_exe, sleep, parent);
-        parent = parent->parent();
-    }
-
-    content += "\n";
-    if (task_->events().empty() && task_->meters().empty() && task_->queues().empty()) {
-        content += sleep;
-    }
-    content += "\necho end of job\n";
-    content += "\n%include <tail.h>\n";
-    return content;
-}
-
-void TaskScriptGenerator::generate_head_file() const {
-    std::string path = ecf_include_ + "/head.h";
-    if (fs::exists(path)) {
-        std::cout << "Skipping generation of head file: " << path << " as it already exists\n";
-        return;
-    }
-
-    std::string client_exe = "%ECF_CLIENT_EXE_PATH:";
-    client_exe += Ecf::CLIENT_NAME();
-    client_exe += "% ";
-
-    std::string contents;
-    contents += "#!/usr/bin/env bash\n";
-    contents += "set -e          # stop the shell on first error X\n";
-    contents += "set -u          # fail when using an undefined variable\n";
-    contents += "set -o pipefail # fail if last(rightmost) command exits with a non-zero status\n";
-    contents += "set -x          # echo script lines as they are executed\n";
-    contents += "\n";
-    contents += "# Defines the variables that are needed for any communication with ECF\n";
-    contents += "export ECF_PORT=%ECF_PORT%    # The server port number\n";
-    contents += "export ECF_HOST=%ECF_HOST%    # The name of ecf host that issued this task\n";
-    contents += "export ECF_NAME=%ECF_NAME%    # The name of this current task\n";
-    contents += "export ECF_PASS=%ECF_PASS%    # A unique password\n";
-    contents += "export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task\n";
-    contents += "export ECF_RID=$$\n";
-    contents += "export ECF_TIMEOUT=300 # Only wait 5 minutes, if the server cannot be contacted (note default is 24 "
-                "hours) before failing\n";
-    contents += "if [[ \"%ECF_SSL:%\" != \"\" ]] ; then\n";
-    contents += "   export ECF_SSL=%ECF_SSL:%\n";
-    contents += "fi\n";
-    contents += "#export ECF_DEBUG_CLIENT=1\n";
-    contents += "\n";
-    contents +=
-        "# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address\n";
-    contents += "os_name=$(uname -s)\n";
-    contents += "if [[ $os_name = Linux ]] ; then\n";
-    contents += "   ping -c 1 %ECF_HOST%\n";
-    contents += "fi\n";
-    contents += "\n";
-    contents += "# Tell ecFlow we have started\n";
-    contents += client_exe + "--init=$$\n";
-    contents += "\n";
-    contents += "# Defined a error handler\n";
-    contents += "ERROR() {\n";
-    contents += "   echo 'ERROR() called'\n";
-    contents += "   set +e                      # Clear -e flag, so we don't fail\n";
-    contents += "   wait                        # wait for background process to stop\n";
-    contents +=
-        "   " + client_exe + "--abort=trap   # Notify ecFlow that something went wrong, using 'trap' as the reason\n";
-    contents += "   trap 0                      # Remove the trap\n";
-    contents += "   exit 0                      # End the script\n";
-    contents += "}\n";
-    contents += "\n";
-    contents += "# Trap any calls to exit and errors caught by the -e flag\n";
-    contents += "trap ERROR 0\n";
-    contents += "\n";
-    contents += "# Trap any signal that may cause the script to fail\n";
-    contents += "trap '{ echo \"Killed by a signal\"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15\n";
-
-    std::string errorMsg;
-    if (!File::create(path, contents, errorMsg)) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator::generate_tail_file: Could not create head.h " << path << " " << errorMsg;
-        throw std::runtime_error(ss.str());
-    }
-
-    std::cout << "Generated header file: " << path << "\n";
-}
-
-void TaskScriptGenerator::generate_tail_file() const {
-    std::string path = ecf_include_ + "/tail.h";
-    if (fs::exists(path)) {
-        std::cout << "Skipping generation of tail file: " << path << " as it already exists\n";
-        return;
-    }
-
-    std::string contents = "%ECF_CLIENT_EXE_PATH:";
-    contents += Ecf::CLIENT_NAME();
-    contents += "% --complete    # Notify ecFlow of a normal end\n";
-
-    contents += "trap 0                 # Remove all traps\n";
-    contents += "exit 0                 # End the shell\n";
-
-    std::string errorMsg;
-    if (!File::create(path, contents, errorMsg)) {
-        std::stringstream ss;
-        ss << "TaskScriptGenerator::generate_tail_file: Could not create tail.h " << path << " " << errorMsg;
-        throw std::runtime_error(ss.str());
-    }
-
-    std::cout << "Generated tail file: " << path << "\n";
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/ANode/src/ecflow/node/TaskScriptGenerator.hpp 5.13.0-1/ANode/src/ecflow/node/TaskScriptGenerator.hpp
--- 5.12.4-1/ANode/src/ecflow/node/TaskScriptGenerator.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/TaskScriptGenerator.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_TaskScriptGenerator_HPP
-#define ecflow_node_TaskScriptGenerator_HPP
-
-#include <map>
-#include <string>
-class Task;
-
-namespace ecf {
-
-class TaskScriptGenerator {
-public:
-    explicit TaskScriptGenerator(const Task*);
-
-    // Disable copy (and move) semantics
-    TaskScriptGenerator(const TaskScriptGenerator&)                  = delete;
-    const TaskScriptGenerator& operator=(const TaskScriptGenerator&) = delete;
-
-    void generate(const std::map<std::string, std::string>& override);
-
-private:
-    void generate_head_file() const;
-    void generate_tail_file() const;
-    std::string getDefaultTemplateEcfFile() const;
-
-private:
-    const Task* task_;
-    bool is_dummy_task_;
-    std::string ecf_files_;
-    std::string ecf_home_;
-    std::string ecf_include_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_node_TaskScriptGenerator_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/move_peer.hpp 5.13.0-1/ANode/src/ecflow/node/move_peer.hpp
--- 5.12.4-1/ANode/src/ecflow/node/move_peer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/move_peer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_move_peer_HPP
-#define ecflow_node_move_peer_HPP
-
-#include "ecflow/node/Node.hpp"
-
-template <typename ct>
-void move_peer_node(std::vector<ct>& vec, Node* source, Node* dest, const std::string& error_str) {
-    if (!source) {
-        std::stringstream ss;
-        ss << error_str << "::move source is NULL";
-        throw std::runtime_error(ss.str());
-    }
-    if (!dest) {
-        std::stringstream ss;
-        ss << error_str << "::move destination is NULL";
-        throw std::runtime_error(ss.str());
-    }
-    if (source == dest) {
-        std::stringstream ss;
-        ss << error_str << "move choose a different location as sibling " << dest->absNodePath()
-           << " matches node to be moved";
-        throw std::runtime_error(ss.str());
-    }
-    if (source->parent() != dest->parent()) {
-        std::stringstream ss;
-        ss << error_str << "move source and destination node are not siblings";
-        throw std::runtime_error(ss.str());
-    }
-
-    for (size_t t = 0; t < vec.size(); t++) {
-        if (vec[t].get() == source) {
-            for (size_t s = 0; s < vec.size(); s++) {
-                if (vec[s].get() == dest) {
-
-                    ct node = vec[t];
-                    vec.erase(vec.begin() + t);
-
-                    vec.insert(vec.begin() + s, node);
-                    return;
-                }
-            }
-            std::stringstream ss;
-            ss << error_str << "::move could not find sibling node " << dest->absNodePath() << " when moving node "
-               << source->absNodePath();
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    std::stringstream ss;
-    ss << error_str << "::move source node " << source->absNodePath() << " not found on parent";
-    throw std::runtime_error(ss.str());
-}
-
-#endif /* ecflow_node_move_peer_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/AutoArchiveParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/AutoArchiveParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/AutoArchiveParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/AutoArchiveParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/AutoArchiveParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-// The -i is the last token before the comments start.
-static bool has_idle_flag(std::vector<std::string>& lineTokens) {
-    return (lineTokens.size() >= 3 && lineTokens[2] == "-i");
-}
-
-bool AutoArchiveParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // autoarchive +01:00    # archive one hour after complete
-    // autoarchive 01:00     # archive at 1 am in morning after complete
-    // autoarchive 10        # archive 10 days after complete
-    // autoarchive 0         # archive immediately after complete
-
-    // autoarchive +01:00 -i   # archive one hour after complete,queued,aborted
-    // autoarchive 01:00  -i   # archive at 1 am in morning after complete,queued,aborted
-    // autoarchive 10     -i   # archive 10 days after complete,queued,aborted
-    // autoarchive 0      -i   # archive immediately after complete,queued,aborted
-
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("AutoArchiveParser::doParse: Invalid autoarchive :" + line);
-    if (nodeStack().empty())
-        throw std::runtime_error(
-            "AutoArchiveParser::doParse: Could not add autoarchive as node stack is empty at line: " + line);
-
-    if (lineTokens[1].find_first_of(':') == string::npos) {
-        // Must be of the form:
-        // autoarchive 10        # archive 10 days after complete
-        // autoarchive 0         # archive immediately after complete
-        int days = Extract::theInt(lineTokens[1], "invalid autoarchive " + line);
-
-        nodeStack_top()->add_autoarchive(AutoArchiveAttr(days, has_idle_flag(lineTokens)));
-    }
-    else {
-        // Must be of the form:
-        // autoarchive +01:00    # archive one hour after complete
-        // autoarchive 01:00     # archive at 1 am in morning after complete
-        int hour      = 0;
-        int min       = 0;
-        bool relative = TimeSeries::getTime(lineTokens[1], hour, min);
-
-        nodeStack_top()->add_autoarchive(AutoArchiveAttr(TimeSlot(hour, min), relative, has_idle_flag(lineTokens)));
-    }
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/AutoArchiveParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/AutoArchiveParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/AutoArchiveParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/AutoArchiveParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_AutoArchiveParser_HPP
-#define ecflow_node_parser_AutoArchiveParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class AutoArchiveParser : public Parser {
-public:
-    explicit AutoArchiveParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "autoarchive"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_AutoArchiveParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/AutoCancelParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/AutoCancelParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/AutoCancelParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/AutoCancelParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,54 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/AutoCancelParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool AutoCancelParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // autocancel +01:00    # cancel one hour after complete
-    // autocancel 01:00     # cancel at 1 am in morning after complete
-    // autocancel 10        # cancel 10 days after complete
-    // autocancel 0         # cancel immediately after complete
-
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("AutoCancelParser::doParse: Invalid autocancel :" + line);
-    if (nodeStack().empty())
-        throw std::runtime_error(
-            "AutoCancelParser::doParse: Could not add autocancel as node stack is empty at line: " + line);
-
-    if (lineTokens[1].find_first_of(':') == string::npos) {
-        // Must be of the form:
-        // autocancel 10        # cancel 10 days after complete
-        // autocancel 0         # cancel immediately after complete
-        int days = Extract::theInt(lineTokens[1], "invalid autocancel " + line);
-
-        nodeStack_top()->addAutoCancel(AutoCancelAttr(days));
-    }
-    else {
-        // Must be of the form:
-        // autocancel +01:00    # cancel one hour after complete
-        // autocancel 01:00     # cancel at 1 am in morning after complete
-        int hour      = 0;
-        int min       = 0;
-        bool relative = TimeSeries::getTime(lineTokens[1], hour, min);
-
-        nodeStack_top()->addAutoCancel(AutoCancelAttr(TimeSlot(hour, min), relative));
-    }
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/AutoCancelParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/AutoCancelParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/AutoCancelParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/AutoCancelParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_AutoCancelParser_HPP
-#define ecflow_node_parser_AutoCancelParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class AutoCancelParser : public Parser {
-public:
-    explicit AutoCancelParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "autocancel"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_AutoCancelParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/AutoRestoreParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/AutoRestoreParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/AutoRestoreParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/AutoRestoreParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/AutoRestoreParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool AutoRestoreParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // autorestore /s1/f1
-    // autorestore ../f1
-
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("AutoRestoreParser::doParse: Invalid autorestore :" + line);
-    if (nodeStack().empty())
-        throw std::runtime_error(
-            "AutoRestoreParser::doParse: Could not add autorestore as node stack is empty at line: " + line);
-
-    std::vector<std::string> nodes_to_restore;
-    for (size_t i = 1; i < lineTokens.size(); i++) {
-        if (lineTokens[i][0] == '#')
-            break;
-        nodes_to_restore.push_back(lineTokens[i]);
-    }
-
-    if (nodes_to_restore.empty())
-        throw std::runtime_error("AutoRestoreParser::doParse: no paths specified " + line);
-
-    nodeStack_top()->add_autorestore(ecf::AutoRestoreAttr(nodes_to_restore));
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/AutoRestoreParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/AutoRestoreParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/AutoRestoreParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/AutoRestoreParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_AutoRestoreParser_HPP
-#define ecflow_node_parser_AutoRestoreParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class AutoRestoreParser : public Parser {
-public:
-    explicit AutoRestoreParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "autorestore"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_AutoRestoreParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/CalendarParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/CalendarParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/CalendarParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/CalendarParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,35 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/CalendarParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Suite.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool CalendarParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    if (lineTokens.size() < 2) {
-        throw std::runtime_error("CalendarParser::doParse: Invalid calendar :" + line);
-    }
-    if (nodeStack().empty()) {
-        throw std::runtime_error("CalendarParser::doParse: Could not add calendar as node stack is empty at line: " +
-                                 line);
-    }
-
-    Suite* suite = nodeStack_top()->isSuite();
-    if (!suite)
-        throw std::runtime_error("Calendar can only be added to suites and not " + nodeStack_top()->debugType());
-    suite->set_calendar().read_state(line, lineTokens);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/CalendarParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/CalendarParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/CalendarParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/CalendarParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_CalendarParser_HPP
-#define ecflow_node_parser_CalendarParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class CalendarParser : public Parser {
-public:
-    explicit CalendarParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "calendar"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_CalendarParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/ClockParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/ClockParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/ClockParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/ClockParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,183 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/ClockParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace ecf;
-using namespace std;
-
-static void extractTheGain(const std::string& theGainToken, ClockAttr& clockAttr) {
-    if (theGainToken.find(Str::COLON()) != std::string::npos) {
-        // clock real +01:00
-        // clock real  01:36
-        int hour, min;
-        bool positiveGain = TimeSeries::getTime(theGainToken, hour, min);
-        clockAttr.set_gain(hour, min, positiveGain);
-        return;
-    }
-
-    long theGain           = 0;
-    std::string theGainStr = theGainToken;
-    bool positiveGain      = false;
-    if (theGainStr[0] == '+') {
-        positiveGain = true;
-        theGainStr.erase(theGainStr.begin());
-    }
-    theGain = Extract::theInt(theGainStr, "Invalid clock gain:" + theGainToken);
-    clockAttr.set_gain_in_seconds(theGain, positiveGain);
-}
-
-bool ClockParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // clock hybrid   # a comment
-    // clock hybrid
-    // clock real                  #a comment
-    // clock real 300
-    // clock real +01:00
-    // clock real 20.1.2007
-    // clock real 20.1.2007 +01:00
-
-    // For Testing we allow calendar increment to be change on a per suite basis
-    // -c is optional
-    // clock real 20.1.2007 +01:00
-    // clock hybrid
-
-    // Allow clock to be stopped/started when the server is stopped/started
-    // and hence always honour time dependencies. See Calendar.h for more details
-    // This is optional.( Need to advertise this functionality)
-    // clock real 20.1.2007 +01:00 -s
-    // clock hybrid -s
-    if (lineTokens.size() < 2) {
-        throw std::runtime_error("ClockParser::doParse: Invalid clock :" + line);
-    }
-    if (nodeStack().empty()) {
-        throw std::runtime_error("ClockParser::doParse: Could not add clock as node stack is empty at line: " + line);
-    }
-
-    bool hybrid = true;
-    if (lineTokens[1] == "real")
-        hybrid = false;
-    else if (lineTokens[1] == "hybrid")
-        hybrid = true;
-    else
-        throw std::runtime_error("Invalid clock :" + line);
-
-    ClockAttr clockAttr(hybrid);
-
-    if (lineTokens.size() >= 3 && lineTokens[2][0] != '#') {
-        // if third token is not a comment the time must be of the form
-        // clock real 300
-        // clock real +01:00
-        // clock real 20.1.2007
-        // clock real 20.1.2007
-        // clock real           # on requeue we use current date
-        // clock real -s
-
-        if (lineTokens[2].find(".") != std::string::npos) {
-            // clock real 20.1.2007
-
-            // If 0 returned then day,month,year is of form *, and not valid
-            int day, month, year;
-            DateAttr::getDate(lineTokens[2], day, month, year);
-
-            // This will throw std::aout_of_range for an invalid clock date. Note no wild carding allowed.
-            clockAttr.date(day, month, year); // this will check the date
-
-            if (lineTokens.size() >= 4 && lineTokens[3][0] != '#') {
-                // clock real 20.1.2007 +01:00
-                // clock real 20.1.2007 +300
-                // clock real 20.1.2007 350
-                extractTheGain(lineTokens[3], clockAttr);
-            }
-        }
-        else {
-            if (lineTokens[2] != "-s") {
-                // clock real 300
-                // clock real +01:00
-                extractTheGain(lineTokens[2], clockAttr);
-            }
-        }
-    }
-
-    Suite* suite = nodeStack_top()->isSuite();
-    if (!suite)
-        throw std::runtime_error("Clock can only be added to suites and not " + nodeStack_top()->debugType());
-
-    suite->addClock(clockAttr);
-
-    return true;
-}
-
-bool EndClockParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // Note: endclock > clock
-    // Also endclock will be same type as the clock
-
-    // endclock 300
-    // endclock 300
-    // endclock +01:00
-    // endclock 20.1.2007
-    // endclock 20.1.2007 +01:00
-
-    // Allow clock to be stopped/started when the server is stopped/started
-    // and hence always honour time dependencies. See Calendar.h for more details
-    if (lineTokens.size() < 2) {
-        throw std::runtime_error("ClockEndParser::doParse: Invalid clock :" + line);
-    }
-    if (nodeStack().empty()) {
-        throw std::runtime_error("ClockEndParser::doParse: Could not add end clock as node stack is empty at line: " +
-                                 line);
-    }
-
-    ClockAttr clockAttr(false);
-
-    if (lineTokens.size() >= 2 && lineTokens[1][0] != '#') {
-        // if third token is not a comment the time must be of the form
-        // endclock 300
-        // endclock +01:00
-        // endclock 20.1.2007
-
-        if (lineTokens[1].find(".") != std::string::npos) {
-            // endclock 20.1.2007
-
-            // If 0 returned then day,month,year is of form *, and not valid
-            int day, month, year;
-            DateAttr::getDate(lineTokens[1], day, month, year);
-
-            // This will throw std::out_of_range for an invalid clock date. Note no wild carding allowed.
-            clockAttr.date(day, month, year); // this will check the date
-
-            if (lineTokens.size() >= 3 && lineTokens[2][0] != '#') {
-                // endclock 20.1.2007 +01:00
-                // endclock 20.1.2007 +300
-                // endclock 20.1.2007 350
-                extractTheGain(lineTokens[2], clockAttr);
-            }
-        }
-        else {
-            // endclock 300
-            // endclock +01:00
-            extractTheGain(lineTokens[1], clockAttr);
-        }
-    }
-
-    Suite* suite = nodeStack_top()->isSuite();
-    if (!suite)
-        throw std::runtime_error("Clock can only be added to suites and not " + nodeStack_top()->debugType());
-
-    suite->add_end_clock(clockAttr);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/ClockParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/ClockParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/ClockParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/ClockParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_ClockParser_HPP
-#define ecflow_node_parser_ClockParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class ClockParser : public Parser {
-public:
-    explicit ClockParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "clock"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-class EndClockParser : public Parser {
-public:
-    explicit EndClockParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "endclock"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_ClockParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/CronParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/CronParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/CronParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/CronParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/CronParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-// #define DEBUG_CRON 1
-
-bool CronParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // cron 23:00                 # run every day at 23:00
-    // cron 10:00 20:00 01:00     # run every hour between 10am and 8pm
-    // cron -w 0,1 10:00          # run every sunday and monday at 10am
-    // cron -d 10,11,12 12:00     # run 10th, 11th and 12th of each month at noon
-    // cron -m 1,2,3 12:00        # run on Jan,Feb and March every day at noon.
-    // cron -w 0 -m 5,6,7,8 10:00 20:00 01:00 # run every sunday, between May-Aug, every hour between 10am and 8pm
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("CronParser::doParse: Invalid cron: " + line);
-
-#ifdef DEBUG_CRON
-    cerr << "CronParser::doParse " << line << "\n";
-#endif
-
-    bool parse_state = (rootParser()->get_file_type() != PrintStyle::DEFS);
-
-    size_t index = 1; // to get over the cron
-    CronAttr cronAttr;
-    CronAttr::parse(cronAttr, lineTokens, index, parse_state);
-
-    nodeStack_top()->addCron(cronAttr);
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/CronParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/CronParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/CronParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/CronParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_CronParser_HPP
-#define ecflow_node_parser_CronParser_HPP
-
-//============================================================================
-// Name        :
-// Author      : Avi
-// Revision    : $Revision: #6 $
-//
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-// Description :
-//============================================================================
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class CronParser : public Parser {
-public:
-    explicit CronParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "cron"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_CronParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DateParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/DateParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DateParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DateParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/DateParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool DateParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    //  date 15.11.2009 # <value>   // with PersistStyle::STATE & MIGRATE
-    //  date 15.*.*
-    //  date *.1.*
-    if (lineTokens.size() < 2) {
-        throw std::runtime_error("DateParser::doParse: Invalid date :" + line);
-    }
-
-    if (nodeStack().empty()) {
-        throw std::runtime_error("DateParser::doParse: Could not add date as node stack is empty at line: " + line);
-    }
-
-    // DateAttr::create can throw for invalid dates
-    nodeStack_top()->addDate(DateAttr::create(lineTokens, rootParser()->get_file_type() != PrintStyle::DEFS));
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DateParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/DateParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DateParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DateParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_DateParser_HPP
-#define ecflow_node_parser_DateParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class DateParser : public Parser {
-public:
-    explicit DateParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "date"; }
-    bool doParse(const std::string& /*line*/, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_DateParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DayParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/DayParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DayParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DayParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,34 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/DayParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-
-bool DayParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    //  day monday  # free expired
-    //  day tuesday # expired
-    if (lineTokens.size() < 2) {
-        throw std::runtime_error("DayParser::doParse: Invalid day :" + line);
-    }
-    if (nodeStack().empty()) {
-        throw std::runtime_error("DayParser::doParse: Could not add day as node stack is empty at line: " + line);
-    }
-
-    // parse day and state
-    nodeStack_top()->addDay(DayAttr::create(lineTokens, rootParser()->get_file_type() != PrintStyle::DEFS));
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DayParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/DayParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DayParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DayParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_DayParser_HPP
-#define ecflow_node_parser_DayParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class DayParser : public Parser {
-public:
-    explicit DayParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "day"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_DayParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,464 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/DefsParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/node/parser/AutoArchiveParser.hpp"
-#include "ecflow/node/parser/AutoCancelParser.hpp"
-#include "ecflow/node/parser/AutoRestoreParser.hpp"
-#include "ecflow/node/parser/CalendarParser.hpp"
-#include "ecflow/node/parser/ClockParser.hpp"
-#include "ecflow/node/parser/CronParser.hpp"
-#include "ecflow/node/parser/DateParser.hpp"
-#include "ecflow/node/parser/DayParser.hpp"
-#include "ecflow/node/parser/DefsStateParser.hpp"
-#include "ecflow/node/parser/DefsStatusParser.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-#include "ecflow/node/parser/EventParser.hpp"
-#include "ecflow/node/parser/ExternParser.hpp"
-#include "ecflow/node/parser/GenericParser.hpp"
-#include "ecflow/node/parser/InlimitParser.hpp"
-#include "ecflow/node/parser/LabelParser.hpp"
-#include "ecflow/node/parser/LateParser.hpp"
-#include "ecflow/node/parser/LimitParser.hpp"
-#include "ecflow/node/parser/MeterParser.hpp"
-#include "ecflow/node/parser/QueueParser.hpp"
-#include "ecflow/node/parser/RepeatParser.hpp"
-#include "ecflow/node/parser/TimeParser.hpp"
-#include "ecflow/node/parser/TodayParser.hpp"
-#include "ecflow/node/parser/TriggerParser.hpp"
-#include "ecflow/node/parser/VariableParser.hpp"
-#include "ecflow/node/parser/VerifyParser.hpp"
-#include "ecflow/node/parser/ZombieAttrParser.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-// #define DEBUG_PARSER 1
-
-template <class T>
-ostream& operator<<(ostream& os, const vector<T>& v) {
-    copy(v.begin(), v.end(), ostream_iterator<T>(cout, ","));
-    return os;
-}
-
-class AliasParser : public Parser {
-public:
-    explicit AliasParser(DefsStructureParser* p) : Parser(p) {
-        reserve_vec(21);
-        addParser(new VariableParser(p));
-        addParser(new LabelParser(p));
-        addParser(new MeterParser(p));
-        addParser(new EventParser(p));
-        addParser(new TriggerParser(p));
-        addParser(new InlimitParser(p));
-        addParser(new LateParser(p));
-        addParser(new DefsStatusParser(p));
-        addParser(new CompleteParser(p));
-        addParser(new TimeParser(p));
-        addParser(new RepeatParser(p));
-        addParser(new TodayParser(p));
-        addParser(new CronParser(p));
-        addParser(new LimitParser(p));
-        addParser(new DateParser(p));
-        addParser(new DayParser(p));
-        addParser(new AutoCancelParser(p));
-        addParser(new VerifyParser(p));
-        addParser(new ZombieAttrParser(p));
-        addParser(new QueueParser(p));
-        addParser(new GenericParser(p));
-    }
-
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
-
-        const char* first_token = lineTokens[0].c_str();
-        if (Str::local_strcmp(first_token, keyword()) == 0) {
-
-            if (lineTokens.size() < 2)
-                throw std::runtime_error("Alias name missing.");
-
-            addAlias(line, lineTokens);
-
-            return true;
-        }
-        else if (Str::local_strcmp(first_token, "endalias") == 0) { // required at the end
-            popNode();
-            return true;
-        }
-        return Parser::doParse(line, lineTokens);
-    }
-
-    const char* keyword() const override { return "alias"; }
-
-private:
-    void addAlias(const std::string& line, std::vector<std::string>& lineTokens) const {
-        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-
-        if (nodeStack().empty() && rootParser()->parsing_node_string()) {
-            alias_ptr alias = Alias::create(lineTokens[1], check);
-            if (rootParser()->get_file_type() != PrintStyle::DEFS)
-                alias->read_state(line, lineTokens);
-            nodeStack().emplace(alias.get(), this);
-            rootParser()->set_node_ptr(alias);
-            return;
-        }
-
-        // bad test data can mean that last node is not a suite family or task, will fail parse
-        if (nodeStack().empty())
-            throw std::runtime_error("Add alias failed empty node stack");
-
-        // alias can only be added to tasks
-        Task* lastAddedTask = nodeStack_top()->isTask();
-        if (lastAddedTask) {
-
-            alias_ptr alias = lastAddedTask->add_alias(lineTokens[1]);
-            alias->read_state(line, lineTokens);
-            nodeStack().emplace(alias.get(), this);
-        }
-        else {
-            if (nodeStack_top()->isAlias()) {
-
-                // Alias can _only_ be added to tasks pop the top Node to get to the task
-                popNode();
-                addAlias(line, lineTokens);
-            }
-            else
-                throw std::runtime_error("Add alias failed, expected task on node stack");
-        }
-    }
-};
-
-//================================================================================
-
-class TaskParser : public Parser {
-public:
-    explicit TaskParser(DefsStructureParser* p) : Parser(p) {
-        reserve_vec(25);
-        addParser(new VariableParser(p));
-        addParser(new TriggerParser(p));
-        addParser(new LabelParser(p));
-        addParser(new InlimitParser(p));
-        addParser(new EventParser(p));
-        addParser(new LateParser(p));
-        addParser(new MeterParser(p));
-        addParser(new DefsStatusParser(p));
-        addParser(new CompleteParser(p));
-        addParser(new TimeParser(p));
-        addParser(new RepeatParser(p));
-        addParser(new TodayParser(p));
-        addParser(new CronParser(p));
-        addParser(new LimitParser(p));
-        addParser(new DateParser(p));
-        addParser(new DayParser(p));
-        addParser(new AutoCancelParser(p));
-        addParser(new VerifyParser(p));
-        addParser(new ZombieAttrParser(p));
-        addParser(new AliasParser(p));
-        addParser(new QueueParser(p));
-        addParser(new AutoRestoreParser(p));
-        addParser(new GenericParser(p));
-    }
-
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
-
-        const char* first_token = lineTokens[0].c_str();
-        if (Str::local_strcmp(first_token, keyword()) == 0) {
-            if (lineTokens.size() < 2)
-                throw std::runtime_error("Task name missing.");
-            addTask(line, lineTokens);
-            return true;
-        }
-        else if (Str::local_strcmp(first_token, "endfamily") == 0) {
-            if (parent())
-                return parent()->doParse(line, lineTokens);
-        }
-        else if (Str::local_strcmp(first_token, "endtask") == 0) { // optional
-            popToContainerNode();
-            return true;
-        }
-        return Parser::doParse(line, lineTokens);
-    }
-
-    const char* keyword() const override { return "task"; }
-
-private:
-    void addTask(const std::string& line, std::vector<std::string>& lineTokens) const {
-        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-
-        if (nodeStack().empty() && rootParser()->parsing_node_string()) {
-            task_ptr task = Task::create(lineTokens[1], check);
-            if (rootParser()->get_file_type() != PrintStyle::DEFS)
-                task->read_state(line, lineTokens);
-            nodeStack().emplace(task.get(), this);
-            rootParser()->set_node_ptr(task);
-            return;
-        }
-
-        // bad test data can mean that last node is not a suite family or task, will fail parse
-        if (nodeStack().empty())
-            throw std::runtime_error("Add task failed empty node stack");
-
-        // end task is optional, so if we get another task, whilst in a task pop the parser
-        if (nodeStack_top()->isTask()) {
-            popToContainerNode(); // pop the node stack
-        }
-
-        NodeContainer* lastAddedContainer = nodeStack_top()->isNodeContainer();
-        if (lastAddedContainer) {
-
-            task_ptr task = Task::create(lineTokens[1], check);
-            if (rootParser()->get_file_type() != PrintStyle::DEFS)
-                task->read_state(line, lineTokens);
-            nodeStack().emplace(task.get(), this);
-            lastAddedContainer->addTask(task);
-        }
-        else {
-            if (nodeStack_top()->isTask()) {
-
-                // Task can _only_ be added to suite and families.
-                // pop the top Node to get to the Container(suite or family), then call recursively to add task
-                popNode();
-                addTask(line, lineTokens);
-            }
-        }
-    }
-};
-
-//================================================================================
-
-class FamilyParser : public Parser {
-public:
-    explicit FamilyParser(DefsStructureParser* p) : Parser(p) {
-        reserve_vec(25);
-        addParser(new VariableParser(p));
-        addParser(new TaskParser(p));
-        addParser(new TriggerParser(p));
-        addParser(new InlimitParser(p));
-        addParser(new DefsStatusParser(p));
-        addParser(new LimitParser(p));
-        addParser(new CompleteParser(p));
-        addParser(new MeterParser(p));
-        addParser(new TimeParser(p));
-        addParser(new LabelParser(p));
-        addParser(new RepeatParser(p));
-        addParser(new LateParser(p));
-        addParser(new EventParser(p));
-        addParser(new TodayParser(p));
-        addParser(new CronParser(p));
-        addParser(new DateParser(p));
-        addParser(new DayParser(p));
-        addParser(new AutoCancelParser(p));
-        addParser(new VerifyParser(p));
-        addParser(new ZombieAttrParser(p));
-        addParser(new QueueParser(p));
-        addParser(new AutoArchiveParser(p));
-        addParser(new AutoRestoreParser(p));
-        addParser(new GenericParser(p));
-    }
-
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
-
-        const char* first_token = lineTokens[0].c_str();
-        if (Str::local_strcmp(first_token, keyword()) == 0) {
-
-            if (lineTokens.size() < 2)
-                throw std::runtime_error("Family name missing.");
-
-            addFamily(line, lineTokens);
-
-            return true;
-        }
-        else if (Str::local_strcmp(first_token, "endfamily") == 0) {
-
-            popFamily();
-            return true;
-        }
-        else if (Str::local_strcmp(first_token, "endtask") == 0) { // optional
-            popNode();
-            return true;
-        }
-        return Parser::doParse(line, lineTokens);
-    }
-
-    const char* keyword() const override { return "family"; }
-
-private:
-    void addFamily(const std::string& line, const std::vector<std::string>& lineTokens) const {
-        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-
-        if (nodeStack().empty() && rootParser()->parsing_node_string()) {
-            family_ptr family = Family::create(lineTokens[1], check);
-            rootParser()->set_node_ptr(family);
-            if (rootParser()->get_file_type() != PrintStyle::DEFS)
-                family->read_state(line, lineTokens);
-            nodeStack().emplace(family.get(), this);
-        }
-        else {
-            assert(!nodeStack().empty());
-            Suite* lastAddedSuite = nodeStack_top()->isSuite();
-            if (lastAddedSuite) {
-
-                family_ptr family = Family::create(lineTokens[1], check);
-                if (rootParser()->get_file_type() != PrintStyle::DEFS)
-                    family->read_state(line, lineTokens);
-
-                nodeStack().emplace(family.get(), this);
-                lastAddedSuite->addFamily(family);
-            }
-            else {
-                // support hierarchical families
-                Family* lastAddedFamily = nodeStack_top()->isFamily();
-                if (lastAddedFamily) {
-
-                    family_ptr family = Family::create(lineTokens[1], check);
-                    if (rootParser()->get_file_type() != PrintStyle::DEFS)
-                        family->read_state(line, lineTokens);
-
-                    nodeStack().emplace(family.get(), this);
-                    lastAddedFamily->addFamily(family);
-                }
-                else {
-                    Task* lastAddedTask = nodeStack_top()->isTask();
-                    if (lastAddedTask) {
-                        // Pop the node, since tasks don't always have end task
-                        popNode();
-                        addFamily(line, lineTokens);
-                    }
-                }
-            }
-        }
-    }
-
-    void popFamily() const {
-        // Compensate for the fact that Task don't have endtask, hence when we pop for a
-        // family, the top should be a suite/family
-        if (nodeStack_top()->isTask()) {
-            nodeStack().pop(); // pop the task
-            nodeStack().pop(); // pop the family to get to suite/family
-        }
-        else {
-            nodeStack().pop(); // pop the family to get to suite/family
-        }
-    }
-};
-
-//================================================================================
-
-// See ECFLOW-106, and SUP-1198, why we don't allow time,today,date,day ate the suite level.
-class SuiteParser : public Parser {
-public:
-    explicit SuiteParser(DefsStructureParser* p) : Parser(p), started_(false) {
-        reserve_vec(25);
-        addParser(new VariableParser(p));
-        addParser(new FamilyParser(p));
-        addParser(new TaskParser(p));
-        addParser(new LimitParser(p));
-        addParser(new DefsStatusParser(p));
-        addParser(new ClockParser(p));
-        addParser(new InlimitParser(p));
-        addParser(new RepeatParser(p));
-        addParser(new LateParser(p));
-        addParser(new CronParser(p));
-        addParser(new AutoCancelParser(p));
-        addParser(new VerifyParser(p));
-        addParser(new ZombieAttrParser(p));
-        addParser(new EventParser(p));
-        addParser(new LabelParser(p));
-        addParser(new CalendarParser(p));
-        addParser(new MeterParser(p));
-        addParser(new EndClockParser(p));
-        addParser(new QueueParser(p));
-        addParser(new AutoArchiveParser(p));
-        addParser(new AutoRestoreParser(p));
-        addParser(new GenericParser(p));
-    }
-
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
-
-        const char* first_token = lineTokens[0].c_str();
-        if (Str::local_strcmp(first_token, keyword()) == 0) {
-
-            if (started_)
-                throw std::runtime_error("Can't have hierarchical suites.");
-            if (lineTokens.size() < 2)
-                throw std::runtime_error("Suite name missing.");
-            started_ = true;
-
-            addSuite(line, lineTokens);
-
-            return true;
-        }
-        else if (Str::local_strcmp(first_token, "endsuite") == 0) {
-
-            if (!started_) {
-                throw std::runtime_error("Misplaced endsuite..");
-            }
-
-            // ... process end suite
-            while (!nodeStack().empty())
-                nodeStack().pop();
-            started_ = false; // since this parser is reused
-            return true;
-        }
-        return Parser::doParse(line, lineTokens);
-    }
-
-    const char* keyword() const override { return "suite"; }
-
-private:
-    void addSuite(const std::string& line, std::vector<std::string>& lineTokens) const {
-
-        if (!nodeStack().empty()) {
-            throw std::runtime_error("SuiteParser::addSuite node stack should be empty");
-        }
-
-        bool check      = (rootParser()->get_file_type() != PrintStyle::NET);
-        suite_ptr suite = Suite::create(lineTokens[1], check);
-        if (rootParser()->get_file_type() != PrintStyle::DEFS)
-            suite->read_state(line, lineTokens);
-
-        nodeStack().emplace(suite.get(), this);
-        if (defsfile())
-            defsfile()->addSuite(suite);
-        rootParser()->set_node_ptr(suite);
-    }
-
-    bool started_;
-};
-
-//================================================================================
-
-DefsParser::DefsParser(DefsStructureParser* p) : Parser(p) {
-    reserve_vec(5);
-    addParser(new HistoryParser(p));
-    addParser(new SuiteParser(p));
-    addParser(new VariableParser(p, true));
-    addParser(new ExternParser(p));
-
-    // for defs stat only
-    addParser(new DefsStateParser(p));
-}
-
-DefsParser::DefsParser(DefsStructureParser* p, bool /*node_parser_only*/) : Parser(p) {
-    reserve_vec(4);
-    addParser(new TaskParser(p));
-    addParser(new FamilyParser(p));
-    addParser(new SuiteParser(p));
-    addParser(new AliasParser(p));
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_DefsParser_HPP
-#define ecflow_node_parser_DefsParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class DefsParser : public Parser {
-public:
-    explicit DefsParser(DefsStructureParser* p);
-    DefsParser(DefsStructureParser* p, bool node_parser_only);
-    const char* keyword() const override { return "DEFS"; }
-};
-
-#endif /* ecflow_node_parser_DefsParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsStateParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsStateParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsStateParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsStateParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/DefsStateParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-
-bool DefsStateParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // cout << "line = " << line << "\n";
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("DefsStateParser::doParse Invalid defs_state " + line);
-
-    if (lineTokens[1] == PrintStyle::to_string(PrintStyle::STATE))
-        rootParser()->set_file_type(PrintStyle::STATE);
-    else if (lineTokens[1] == PrintStyle::to_string(PrintStyle::MIGRATE))
-        rootParser()->set_file_type(PrintStyle::MIGRATE);
-    else if (lineTokens[1] == PrintStyle::to_string(PrintStyle::NET))
-        rootParser()->set_file_type(PrintStyle::NET);
-    else
-        throw std::runtime_error("DefsStateParser::doParse: file type not specified : " + line);
-
-    defsfile()->read_state(line, lineTokens); // this can throw
-    return true;
-}
-
-bool HistoryParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // cout << "line = " << line << "\n";
-    defsfile()->read_history(line, lineTokens); // this can throw
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsStateParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsStateParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsStateParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsStateParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_DefsStateParser_HPP
-#define ecflow_node_parser_DefsStateParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class DefsStateParser : public Parser {
-public:
-    explicit DefsStateParser(DefsStructureParser* p) : Parser(p) {}
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-    const char* keyword() const override { return "defs_state"; }
-};
-
-class HistoryParser : public Parser {
-public:
-    explicit HistoryParser(DefsStructureParser* p) : Parser(p) {}
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-    const char* keyword() const override { return "history"; }
-};
-
-#endif /* ecflow_node_parser_DefsStateParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsStatusParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsStatusParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsStatusParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsStatusParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/DefsStatusParser.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/core/DState.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-bool DefsStatusParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("DefsStatusParser::doParse: Invalid defstatus :" + line);
-
-    if (!DState::isValid(lineTokens[1])) {
-        throw std::runtime_error("DefsStatusParser::doParse: Invalid defstatus state :" + line);
-    }
-
-    if (!nodeStack().empty()) {
-        Node* node = nodeStack_top();
-
-        // Check default status not already defined for this node.
-        auto it = defStatusMap().find(node);
-        if (it != defStatusMap().end()) {
-            if ((*it).second) {
-                std::stringstream ss;
-                ss << "DefsStatusParser::doParse: " << node->debugType() << " " << node->name()
-                   << " already has a default status\n";
-                throw std::runtime_error(ss.str());
-            }
-        }
-        defStatusMap()[node] = true;
-        node->addDefStatus(DState::toState(lineTokens[1]));
-    }
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsStatusParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsStatusParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsStatusParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsStatusParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_DefsStatusParser_HPP
-#define ecflow_node_parser_DefsStatusParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class DefsStatusParser : public Parser {
-public:
-    explicit DefsStatusParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "defstatus"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_DefsStatusParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsStructureParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsStructureParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsStructureParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsStructureParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,290 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-#include <sstream>
-
-#include <boost/tokenizer.hpp>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/node/Defs.hpp"
-
-// #define DEBUG_PARSER 1
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-/////////////////////////////////////////////////////////////////////////////////////
-DefsStructureParser::DefsStructureParser(Defs* defsfile, const std::string& file_name)
-    : parsing_node_string_(false),
-      infile_(file_name),
-      defsfile_(defsfile),
-      defsParser_(this),
-      lineNumber_(0),
-      file_type_(PrintStyle::DEFS),
-      defs_as_string_(Str::EMPTY()) {
-    if (!infile_.ok()) {
-        std::stringstream ss;
-        ss << "DefsStructureParser::DefsStructureParser: Unable to open file! " << infile_.file_name() << "\n\n";
-        ss << Version::description() << "\n";
-        error_ = ss.str();
-    }
-}
-
-DefsStructureParser::DefsStructureParser(Defs* defsfile, const std::string& str, bool)
-    : parsing_node_string_(false),
-      infile_(""),
-      defsfile_(defsfile),
-      defsParser_(this),
-      lineNumber_(0),
-      file_type_(PrintStyle::DEFS),
-      defs_as_string_(str) {
-    if (defs_as_string_.empty()) {
-        std::stringstream ss;
-        ss << "DefsStructureParser::DefsStructureParser :  Unable to parse empty string\n\n";
-        ss << Version::description() << "\n";
-        error_ = ss.str();
-    }
-}
-
-DefsStructureParser::DefsStructureParser(const std::string& defs_node_string)
-    : parsing_node_string_(true),
-      infile_(""),
-      defsfile_(nullptr),
-      defsParser_(this, true /* only parse nodes */),
-      lineNumber_(0),
-      file_type_(PrintStyle::MIGRATE),
-      defs_as_string_(defs_node_string) {
-    if (defs_as_string_.empty()) {
-        std::stringstream ss;
-        ss << "DefsStructureParser::DefsStructureParser :  Unable to parse empty string\n\n";
-        ss << Version::description() << "\n";
-        error_ = ss.str();
-    }
-}
-
-DefsStructureParser::~DefsStructureParser() {
-#ifdef SHOW_PARSER_STATS
-    defsParser_.printStats();
-#endif
-}
-
-bool DefsStructureParser::doParse(std::string& errorMsg, std::string& warningMsg) {
-    if (!error_.empty()) {
-        errorMsg = error_;
-        return false;
-    }
-
-    if (defs_as_string_.empty()) {
-        if (!do_parse_file(errorMsg)) {
-            return false;
-        }
-    }
-    else {
-        if (!do_parse_string(errorMsg)) {
-            return false;
-        }
-    }
-
-    if (PrintStyle::is_persist_style(file_type_) || parsing_node_string_) {
-        warningMsg += faults_;
-        return true;
-    }
-
-    // Note:: if parsing_node_string_ == false, then defsfile_ == NULL
-    // Now parse the trigger/complete expressions and resolve in-limits
-    return defsfile_->check(errorMsg, warningMsg);
-}
-
-bool DefsStructureParser::do_parse_file(std::string& errorMsg) {
-    std::vector<std::string> lineTokens;
-    lineTokens.reserve(64);
-    string line;
-    line.reserve(1024);
-    while (infile_.good()) {
-        getNextLine(line); // will increment lineNumer_
-        if (!do_parse_line(line, lineTokens, errorMsg)) {
-            return false;
-        }
-    }
-    return true;
-}
-
-bool DefsStructureParser::do_parse_string(std::string& errorMsg) {
-    std::vector<std::string> lineTokens;
-    lineTokens.reserve(64);
-    string line;
-    line.reserve(1024);
-    while (defs_as_string_.good()) {
-        getNextLine(line); // will increment lineNumer_
-        if (!do_parse_line(line, lineTokens, errorMsg)) {
-            the_node_ptr_ = node_ptr();
-            return false;
-        }
-    }
-    return true;
-}
-
-bool DefsStructureParser::do_parse_line(const std::string& line,
-                                        std::vector<std::string>& lineTokens,
-                                        std::string& errorMsg) {
-    lineTokens.clear(); // This is re-used, hence clear up front
-    Str::split(line, lineTokens);
-    if (lineTokens.empty())
-        return true; // ignore empty lines
-
-    // Process each line, according to the parser which is on *top* of the stack
-    // If the *top* of the stack is empty use the DefsParser
-    Parser* theCurrentParser = (nodeStack_.empty()) ? &defsParser_ : const_cast<Parser*>(nodeStack_.top().second);
-    if (theCurrentParser == nullptr) {
-        std::stringstream ss;
-        ss << "No parser found: Could not parse '" << line << "' around line number " << lineNumber_ << "\n";
-        ss << Version::description() << "\n\n";
-        errorMsg = ss.str();
-        return false;
-    }
-
-    try {
-        // Note: if the chosen parser does not recognise first token then the parent parser has a go at parsing.
-        //       If first token begins with '#' it is ignored
-        // cout << "DefsStructureParser::currentParser() = " << theCurrentParser->keyword() << "\n";
-        theCurrentParser->doParse(line, lineTokens);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << e.what() << "\n";
-        ss << "Could not parse '" << line << "' around line number " << lineNumber_ << "\n";
-        ss << Version::description() << "\n\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    return true;
-}
-
-void DefsStructureParser::getNextLine(std::string& line) {
-    // *ALL* the handling of multiple statements per line are handled in this function
-    // The presence of ';' signals multiple statements per line.
-    if (multi_statements_per_line_vec_.empty()) {
-        if (defs_as_string_.empty())
-            infile_.getline(line);
-        else
-            defs_as_string_.getline(line);
-        lineNumber_++;
-        if (PrintStyle::is_persist_style(file_type_)) {
-            return; // ignore multiline for migrate, *BECAUSE* *history* for group command uses ';'
-        }
-
-        if (!line.empty()) {
-
-            // See if there are multi statements per line, ie task a; task b; task b # comment
-            if (line.find(';') != std::string::npos) {
-
-                // ignore lines which have ';' but start with a comment.  i.e.
-                //     # task a, task b
-                /// calling trim can be very expensive, hence avoid if possible
-                std::vector<std::string> lineTokens;
-                Str::split(line, lineTokens);
-                if (!lineTokens.empty()) {
-                    if (lineTokens[0][0] == '#') {
-                        // found leading_comment can ignore this line
-                        return;
-                    }
-
-                    // Can't properly handle labels with ';'. ECFLOW-1554   label foo "a;b;c"
-                    // Just assume labels are on one line. Hence we don't support multiple labels on one line
-                    if (lineTokens[0] == "label") {
-                        return;
-                    }
-                }
-
-                // Handle multiple statement with # comment at the end
-                //      suite fred; task a; task b; endsuite   # suite fred; task a; task b; endsuite
-                // Remove comment at the end, to avoid adding to list of tokens
-                std::string::size_type commentPos = line.find('#');
-                if (commentPos != std::string::npos)
-                    line = line.substr(0, commentPos);
-
-                char_separator<char> sep(";");
-                typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
-                tokenizer tokens(line, sep);
-                std::copy(tokens.begin(), tokens.end(), back_inserter(multi_statements_per_line_vec_));
-                assert(!multi_statements_per_line_vec_.empty());
-
-                if (semiColonInEditVariable()) {
-                    // clear multi_statements_per_line_vec_ since we can't cope with ';' in variable value
-                    // hence    edit VAR1 'A;B';   edit VAR2 "b;C"
-                    // will be treated as one variable and not two
-                    // TODO need more sophisticated parsing
-                    multi_statements_per_line_vec_.clear();
-                }
-                else {
-                    line = *(multi_statements_per_line_vec_.begin());
-                    multi_statements_per_line_vec_.erase(multi_statements_per_line_vec_.begin());
-                }
-            }
-        }
-    }
-    else {
-        line = *(multi_statements_per_line_vec_.begin());
-        multi_statements_per_line_vec_.erase(multi_statements_per_line_vec_.begin());
-    }
-
-#ifdef DEBUG_PARSER
-    Parser* theParser = currentParser();
-    if (theParser == NULL) {
-        cout << lineNumber_ << ": '" << line << "'              parser( NULL ) node(";
-    }
-    else {
-        cout << lineNumber_ << ": '" << line << "'              parser(" << theParser->keyword() << ") ";
-        if (theParser->parent())
-            cout << " parent_parser(" << theParser->parent()->keyword() << ")";
-        cout << " node(";
-    }
-
-    if (!nodeStack_.empty())
-        cout << nodeStack_top()->debugType() << " : " << nodeStack_top()->name() << ")\n";
-    else
-        cout << "NULL)\n";
-#endif
-}
-
-bool DefsStructureParser::semiColonInEditVariable() {
-    if (multi_statements_per_line_vec_[0].find("edit") != std::string::npos) {
-        // all statements must start with a edit, else we have a semi colon inside variable
-        //    edit A fred;        edit B bill         # valid
-        //    edit A 'fred;bill'; edit B 'bill;bill'  # Can't cope with this, will be ONE variable !!!!
-        for (auto& i : multi_statements_per_line_vec_) {
-            ecf::algorithm::trim(i);
-            if (i.find("edit") != 0) {
-                return true;
-            }
-        }
-    }
-    return false;
-}
-
-////////////////////////////////////////////////////////////////////////////////////////////////
-DefsString::DefsString(const std::string& defs_as_string) : empty_(defs_as_string.empty()) {
-    if (!empty_) {
-        lines_.reserve(256);
-        Str::split_using_string_view(defs_as_string, lines_, "\n");
-    }
-}
-
-bool DefsString::good() const {
-    return line_pos_ < lines_.size();
-}
-
-void DefsString::getline(std::string& line) {
-    line = lines_[line_pos_++];
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/DefsStructureParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/DefsStructureParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/DefsStructureParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/DefsStructureParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,116 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_DefsStructureParser_HPP
-#define ecflow_node_parser_DefsStructureParser_HPP
-
-#include <stack>
-#include <string>
-#include <unordered_map>
-#include <vector>
-
-#include "ecflow/core/File_r.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-#include "ecflow/node/parser/DefsParser.hpp"
-
-class Parser;
-
-// This class is used get a line of defs format from a defs string
-class DefsString {
-public:
-    explicit DefsString(const std::string& defs_as_string);
-    // Disable copy (and move) semantics
-    DefsString(const DefsString&)                  = delete;
-    const DefsString& operator=(const DefsString&) = delete;
-
-    bool good() const;
-    void getline(std::string& line);
-    bool empty() const { return empty_; }
-
-private:
-    std::vector<std::string> lines_;
-    size_t line_pos_{0};
-    bool empty_;
-};
-
-// This class is used to parse the DEFS file.
-// The file can be of different styles:
-//    DEFS: This is the structure only (default)
-//    STATE: structure + state
-//    MIGRATE: structure + state (No checking, and no externs and fault tolerant)
-class DefsStructureParser {
-public:
-    DefsStructureParser(Defs* defsfile, const std::string& file_name);
-    DefsStructureParser(Defs* defsfile, const std::string& def_str, bool);
-    explicit DefsStructureParser(const std::string& defs_node_string);
-    // Disable copy (and move) semantics
-    DefsStructureParser(const DefsStructureParser&)                  = delete;
-    const DefsStructureParser& operator=(const DefsStructureParser&) = delete;
-    ~DefsStructureParser();
-
-    /// Parse the definition file, *AND* check expressions and limits
-    /// return true if parse and check are OK, false otherwise
-    /// if false is returned, and error message is also returned
-    bool doParse(std::string& errorMsg, std::string& warningMsg);
-
-    /// The string passed to the DefsStructureParser is node string, and always in MIGRATE mode
-    /// Only used when constructor is DefsStructureParser(const std::string& defs_node_string);
-    node_ptr the_node_ptr() const { return the_node_ptr_; }
-
-    // return the file/string type read in.
-    PrintStyle::Type_t get_file_type() const { return file_type_; }
-
-    // warn about tokens not understood.
-    std::string& faults() { return faults_; }
-
-protected: // allow test code access
-    bool do_parse_file(std::string& errorMsg);
-    bool do_parse_string(std::string& errorMsg);
-
-private:
-    bool parsing_node_string_;
-    ecf::File_r infile_;
-    Defs* defsfile_;
-    DefsParser defsParser_; // Child parsers will be deleted as well
-    int lineNumber_;
-    PrintStyle::Type_t file_type_;
-    DefsString defs_as_string_;
-    node_ptr the_node_ptr_;
-
-    std::stack<std::pair<Node*, const Parser*>> nodeStack_; // stack of nodes used in parsing
-    std::vector<std::string> multi_statements_per_line_vec_;
-    std::string faults_; // In MIGRATE mode we ignore unrecognised tokens, store here for later reporting
-    std::string error_;
-    std::unordered_map<Node*, bool> defStatusMap_; // check for duplicates
-    friend class Parser;
-
-private:
-    // read in the next line form the defs file
-    void getNextLine(std::string& line);
-    void getNextStringLine(std::string& line);
-    bool do_parse_line(const std::string& line, std::vector<std::string>& lineTokens, std::string& errorMsg);
-    bool semiColonInEditVariable();
-
-    void set_node_ptr(node_ptr node) { the_node_ptr_ = node; }
-    bool parsing_node_string() const { return parsing_node_string_; }
-
-    // store file type read in
-    void set_file_type(PrintStyle::Type_t t) { file_type_ = t; }
-
-    friend class FamilyParser; // access set_node_ptr(), parsing_node_string()
-    friend class SuiteParser;  // access set_node_ptr(), parsing_node_string()
-    friend class TaskParser;   // access set_node_ptr(), parsing_node_string()
-    friend class AliasParser;  // access set_node_ptr(), parsing_node_string()
-    friend class TriggerCompleteParser;
-    friend class DefsStateParser;
-};
-
-#endif /* ecflow_node_parser_DefsStructureParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/EventParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/EventParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/EventParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/EventParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/EventParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-using namespace ecf;
-
-bool EventParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("EventParser::doParse: Invalid event : " + line);
-
-    // Events added to suite/family cannot be signaled by child command
-    // However alter/force should allow events to set/cleared on Family/suite
-    if (nodeStack().empty()) {
-        throw std::runtime_error("EventParser::doParse: Could not add event as node stack is empty at line: " + line);
-    }
-
-    // ===============================================================
-    // Don't use -1, to represent that no number was specified, as on
-    // AIX portable binary archive can't cope with this
-    // use std::numeric_limits<int>::max()
-    // THIS HAS TO BE THE SAME AS THE Event() constructor
-    // ================================================================
-    string name;
-    bool initial_value = false;
-    int number         = std::numeric_limits<int>::max();
-
-    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
-    if (lineTokens[1].find_first_of(Str::NUMERIC()) == 0) {
-        //   event 0
-        //   event 1 eventName
-        //   event 2 eventNamea
-        try {
-            number = ecf::convert_to<int>(lineTokens[1]);
-            if (lineTokens.size() >= 3 && lineTokens[2][0] != '#') {
-                name = lineTokens[2];
-                // event 1 eventName set
-                if (lineTokens.size() >= 4 && lineTokens[3] == "set")
-                    initial_value = true;
-            }
-            else {
-                // event 0 set
-                if (lineTokens.size() >= 3 && lineTokens[2] == "set")
-                    initial_value = true;
-            }
-        }
-        catch (const ecf::bad_conversion&) {
-            name = lineTokens[1];
-            if (lineTokens.size() >= 3 && lineTokens[2] == "set")
-                initial_value = true;
-        }
-    }
-    else {
-        // event name
-        // event name set
-        name = lineTokens[1];
-        if (lineTokens.size() >= 3 && lineTokens[2] == "set")
-            initial_value = true;
-    }
-
-    // structure
-    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-    Event event(number, name, initial_value, check);
-
-    // state
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        if (lineTokens[lineTokens.size() - 1] == Event::SET()) {
-            event.set_value(true);
-        }
-        else if (lineTokens[lineTokens.size() - 1] == Event::CLEAR()) {
-            event.set_value(false);
-        }
-    }
-
-    nodeStack_top()->addEvent(event, check);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/EventParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/EventParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/EventParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/EventParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_EventParser_HPP
-#define ecflow_node_parser_EventParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class EventParser : public Parser {
-public:
-    explicit EventParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "event"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_EventParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/ExternParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/ExternParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/ExternParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/ExternParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/ExternParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-
-bool ExternParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // cout << "line = " << line << "\n";
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("ExternParser::doParse Invalid extern " + line);
-
-    // Guard against
-    // extern   # empty extern with a comment
-    // extern   #empty extern with a comment
-    if (lineTokens[1][0] == '#') {
-        throw std::runtime_error("ExternParser::doParse Invalid extern paths." + line);
-    }
-
-    // Expecting:
-    //   extern <path>
-    //   extern <path>:<attr>
-    // where attr is the name of [ event, meter, repeat, variable, generated variable ]
-    //
-    // We will not split it up:
-
-    // cout << "add extern  = '" << lineTokens[1] << "'\n";
-    defsfile()->add_extern(lineTokens[1]);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/ExternParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/ExternParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/ExternParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/ExternParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_ExternParser_HPP
-#define ecflow_node_parser_ExternParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-///
-/// Externs: will typically have a absolute path, however sometimes when
-///          suite are generated incrementally relative paths can be added
-/// extern a           path =  a
-/// extern /a/b/c      path = /a/b/c
-/// extern a/b/c       path = a/b/c
-/// extern /a/b/c:YMD  path = /a/b/c   variable:YMD (i.e event, meter, variable, repeat, generated variable)
-///
-/// Externs are not persisted, why ?:
-///   o Externs are un-resolved references to node paths in trigger expressions and inlimits
-///     These references could be dynamically generated.
-///   o Saves on network bandwidth and checkpoint file size.
-/// Hence, externs are *ONLY* used on the client side.
-///
-
-class ExternParser : public Parser {
-public:
-    explicit ExternParser(DefsStructureParser* p) : Parser(p) {}
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-    const char* keyword() const override { return "extern"; }
-};
-
-#endif /* ecflow_node_parser_ExternParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/GenericParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/GenericParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/GenericParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/GenericParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,47 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/GenericParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool GenericParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // expected format:
-    //    generic <key> <value1> <value2> .... # any comment after a first # is ignored
-    // examples:
-    //    generic fred va1 val2 # some comment
-    //    generic fred # another comment
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("GenericParser::doParse: Invalid generic :" + line);
-
-    if (nodeStack().empty()) {
-        throw std::runtime_error("GenericParser::doParse: Could not add generic as node stack is empty at line: " +
-                                 line);
-    }
-
-    size_t line_tokens_size = lineTokens.size();
-    std::vector<std::string> values;
-    values.reserve(line_tokens_size);
-    for (size_t i = 2; i < line_tokens_size; i++) {
-        if (lineTokens[i][0] == '#')
-            break;
-        values.push_back(lineTokens[i]);
-    }
-
-    Node* node = nodeStack_top();
-    node->add_generic(GenericAttr(lineTokens[1], values));
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/GenericParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/GenericParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/GenericParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/GenericParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_GenericParser_HPP
-#define ecflow_node_parser_GenericParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class GenericParser : public Parser {
-public:
-    explicit GenericParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "generic"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_GenericParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/InlimitParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/InlimitParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/InlimitParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/InlimitParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,80 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/InlimitParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-
-bool InlimitParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // inlimit /suite:queue1
-    // inlimit disk 50
-    // inlimit -n /suite:queue1 2
-    // inlimit -n fam
-    size_t lineTokens_size = lineTokens.size();
-    if (lineTokens_size < 2)
-        throw std::runtime_error("InlimitParser::doParse: Invalid inlimit :" + line);
-
-    if (nodeStack().empty())
-        throw std::runtime_error("InlimitParser::doParse: Could not add inlimit as node stack is empty at line: " +
-                                 line);
-
-    bool limit_this_node_only = false;
-    int token_pos             = 1;
-    if (lineTokens[token_pos] == "-n") {
-        limit_this_node_only = true;
-        token_pos++;
-    }
-    bool limit_submission = false;
-    if (lineTokens[token_pos] == "-s") {
-        limit_submission = true;
-        token_pos++;
-    }
-    if (limit_this_node_only && limit_submission) {
-        throw std::runtime_error(
-            "InlimitParser::doParse: can't limit family only(-n) and limit submission(-s) at the same time");
-    }
-
-    string path_to_node_holding_the_limit;
-    string limitName;
-    if (!Extract::pathAndName(lineTokens[token_pos], path_to_node_holding_the_limit, limitName)) {
-        throw std::runtime_error("InlimitParser::doParse: Invalid inlimit : " + line);
-    }
-
-    token_pos++;
-    int tokens = Extract::optionalInt(lineTokens, token_pos, 1, "Invalid in limit : " + line);
-
-    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-
-    InLimit inlimit(limitName, path_to_node_holding_the_limit, tokens, limit_this_node_only, limit_submission, check);
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        token_pos++;
-        bool incremented = false;
-        for (size_t i = token_pos; i < lineTokens_size; i++) {
-            // see InLimit::print(..) is to why "incremented:1"
-            if (lineTokens[i].find("incremented:1") != std::string::npos) {
-                incremented = true;
-                break;
-            }
-        }
-        inlimit.set_incremented(incremented);
-    }
-
-    //  cout << inlimit.toString() << "\n";
-    Node* node = nodeStack_top();
-    node->addInLimit(inlimit, check);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/InlimitParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/InlimitParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/InlimitParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/InlimitParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_InlimitParser_HPP
-#define ecflow_node_parser_InlimitParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class InlimitParser : public Parser {
-public:
-    explicit InlimitParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "inlimit"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_InlimitParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/LabelParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/LabelParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/LabelParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/LabelParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,34 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/LabelParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-using namespace ecf;
-
-bool LabelParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    if (nodeStack().empty()) {
-        throw std::runtime_error("LabelParser::doParse: Could not add label as node stack is empty at line: " + line);
-    }
-
-    std::string name, value, new_value;
-    Label::parse(line, lineTokens, rootParser()->get_file_type() != PrintStyle::DEFS, name, value, new_value);
-
-    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-
-    nodeStack_top()->add_label(name, value, new_value, check);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/LabelParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/LabelParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/LabelParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/LabelParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_LabelParser_HPP
-#define ecflow_node_parser_LabelParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class LabelParser : public Parser {
-public:
-    explicit LabelParser(DefsStructureParser* p) : Parser(p) {}
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-    const char* keyword() const override { return "label"; }
-};
-
-#endif /* ecflow_node_parser_LabelParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/LateParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/LateParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/LateParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/LateParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/LateParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool LateParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    if (lineTokens.size() < 3)
-        throw std::runtime_error("LateParser::doParse: Invalid late :" + line);
-
-    // late -s +00:15  -a  20:00  -c +02:00     #The option can be in any order
-    //  0   1    2      3   4     5     6        7     8     9  10 11 12  13
-    // late -s +00:15  -c +02:00                # not all options are needed
-    //  0    1   2      3   4                   5
-
-    LateAttr lateAttr; // lateAttr.isNull() will return true;
-    size_t start_index = 1;
-    LateAttr::parse(lateAttr, line, lineTokens, start_index);
-
-    // state
-    if (rootParser()->get_file_type() != PrintStyle::DEFS && lineTokens[lineTokens.size() - 1] == "late") {
-        lateAttr.setLate(true);
-    }
-
-    nodeStack_top()->addLate(lateAttr);
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/LateParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/LateParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/LateParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/LateParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_LateParser_HPP
-#define ecflow_node_parser_LateParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class LateParser : public Parser {
-public:
-    explicit LateParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "late"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_LateParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/LimitParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/LimitParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/LimitParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/LimitParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,65 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/LimitParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-
-bool LimitParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // limit name the_limit # value path1 path2
-    size_t line_tokens_size = lineTokens.size();
-    if (line_tokens_size < 3)
-        throw std::runtime_error("LimitParser::doParse: Invalid limit " + line);
-
-    if (nodeStack().empty())
-        throw std::runtime_error("LimitParser::doParse: Could not add limit as node stack is empty at line: " + line);
-
-    int limitValue = Extract::theInt(lineTokens[2], "LimitParser::doParse: Invalid limit value: " + line);
-
-    Node* node = nodeStack_top();
-
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        // state
-        int value = 0;
-        std::set<std::string> paths;
-        bool comment_fnd     = false;
-        bool value_processed = false;
-        for (size_t i = 3; i < line_tokens_size; i++) {
-            if (comment_fnd) {
-                if (!value_processed) {
-                    value           = Extract::theInt(lineTokens[i],
-                                            "LimitParser::doParse: Could not extract limit value: " + lineTokens[i]);
-                    value_processed = true;
-                }
-                else {
-                    paths.insert(lineTokens[i]);
-                }
-            }
-            if (lineTokens[i] == "#")
-                comment_fnd = true;
-        }
-
-        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-
-        node->addLimit(Limit(lineTokens[1], limitValue, value, paths, check), check);
-    }
-    else {
-        // structure
-        node->addLimit(Limit(lineTokens[1], limitValue));
-    }
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/LimitParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/LimitParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/LimitParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/LimitParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_LimitParser_HPP
-#define ecflow_node_parser_LimitParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class LimitParser : public Parser {
-public:
-    explicit LimitParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "limit"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_LimitParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/MeterParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/MeterParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/MeterParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/MeterParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/MeterParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool MeterParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // meter 0 100 100 # value
-    size_t line_tokens_size = lineTokens.size();
-    if (line_tokens_size < 4)
-        throw std::runtime_error("MeterParser::doParse: Invalid meter :" + line);
-
-    if (nodeStack().empty()) {
-        throw std::runtime_error("MeterParser::doParse: Could not add meter as node stack is empty at line: " + line);
-    }
-
-    int min         = Extract::theInt(lineTokens[2], "Invalid meter : " + line);
-    int max         = Extract::theInt(lineTokens[3], "Invalid meter : " + line);
-    int colorChange = Extract::optionalInt(lineTokens, 4, std::numeric_limits<int>::max(), "Invalid meter : " + line);
-
-    // state
-    int value = std::numeric_limits<int>::max();
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        bool comment_fnd = false;
-        for (size_t i = 3; i < line_tokens_size; i++) {
-            if (comment_fnd) {
-                // token after comment is the value
-                value = Extract::theInt(lineTokens[i], "MeterParser::doParse, could not extract meter value");
-                break;
-            }
-            if (lineTokens[i] == "#")
-                comment_fnd = true;
-        }
-    }
-
-    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
-
-    nodeStack_top()->add_meter(lineTokens[1], min, max, colorChange, value, check);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/MeterParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/MeterParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/MeterParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/MeterParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_MeterParser_HPP
-#define ecflow_node_parser_MeterParser_HPP
-
-//============================================================================
-// Name        :
-// Author      : Avi
-// Revision    : $Revision: #6 $
-//
-// Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-// In applying this licence, ECMWF does not waive the privileges and immunities
-// granted to it by virtue of its status as an intergovernmental organisation
-// nor does it submit to any jurisdiction.
-//
-// Description :
-//============================================================================
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class MeterParser : public Parser {
-public:
-    explicit MeterParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "meter"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_MeterParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/Parser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/Parser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/Parser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/Parser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,173 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/Parser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Stl.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-#ifdef SHOW_PARSER_STATS
-    #include "ecflow/core/Indentor.hpp"
-#endif
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-using namespace boost::gregorian;
-
-// #define DEBUG_PARSER 1
-
-template <class T>
-ostream& operator<<(ostream& os, const vector<T>& v) {
-    copy(v.begin(), v.end(), ostream_iterator<T>(cout, ","));
-    return os;
-}
-
-// ===============================================================================
-
-Parser::Parser(DefsStructureParser* p)
-    : parent_(nullptr),
-      rootParser_(p)
-#ifdef SHOW_PARSER_STATS
-      ,
-      parserCount_(0)
-#endif
-{
-}
-
-Parser::~Parser() {
-    DeletePtrs(expectedParsers_);
-}
-
-bool Parser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    const char* first_token = lineTokens[0].c_str();
-    size_t theSize          = expectedParsers_.size();
-    for (size_t i = 0; i < theSize; ++i) {
-        Parser* p = expectedParsers_[i];
-
-        if (Str::local_strcmp(first_token, p->keyword()) == 0) {
-
-#ifdef SHOW_PARSER_STATS
-            p->incrementParserCount(); // used for stats
-#endif
-
-            return p->doParse(line, lineTokens);
-        }
-    }
-
-#ifdef DEBUG_PARSER
-    cerr << "Parser::" << keyword() << " token = '" << *lineTokens.begin() << "' did not match parsers(";
-    for (Parser* p : expectedParsers_) {
-        cerr << " " << p->keyword();
-    }
-    cerr << ") Trying parent ";
-    if (parent())
-        cout << "Parser::" << parent()->keyword();
-    cerr << "\n";
-#endif
-
-    // Parent should handle "endfamily", "family" and "endsuite" for hierarchical families
-    if (parent() &&
-        ((Str::local_strcmp(first_token, "endfamily") == 0) || (Str::local_strcmp(first_token, "family") == 0) ||
-         (Str::local_strcmp(first_token, "endsuite") == 0))) {
-        return parent()->doParse(line, lineTokens);
-    }
-
-    // Check if first token is '#' comment character
-    // very first non space character is # comment, hence ignore this line
-    if (*first_token == '#') {
-        // std::cout << "Ignoring line with leading comment : " << line << "\n";
-        return true;
-    }
-
-    // Does not match any parser, or leading comment
-    std::string errorMsg = "# Unexpected keyword ";
-    errorMsg += *lineTokens.begin();
-    errorMsg += " found whilst parsing ";
-    errorMsg += keyword();
-    if (!nodeStack().empty()) {
-        errorMsg += " ";
-        errorMsg += nodeStack_top()->absNodePath();
-    }
-
-    // in MIGRATE be fault tolerant, ignore unrecognised tokens
-    if (PrintStyle::is_persist_style(rootParser()->get_file_type())) {
-        rootParser()->faults() += errorMsg + " -> ignoring\n";
-        return true;
-    }
-
-    throw std::runtime_error(errorMsg);
-    return false;
-}
-
-Defs* Parser::defsfile() const {
-    return rootParser_->defsfile_;
-}
-std::stack<std::pair<Node*, const Parser*>>& Parser::nodeStack() const {
-    return rootParser_->nodeStack_;
-}
-Node* Parser::nodeStack_top() const {
-    return rootParser_->nodeStack_.top().first;
-}
-std::unordered_map<Node*, bool>& Parser::defStatusMap() const {
-    return rootParser_->defStatusMap_;
-}
-
-void Parser::dumpStackTop(const std::string& msg, const std::string& msg2) const {
-    std::cout << msg << "  '" << msg2 << "' ++++++++++++++++++++++++++++++++++++++++++++++++++\n";
-    if (rootParser_->nodeStack_.empty())
-        std::cout << "nodeStack_ is EMPTY\n";
-    else
-        std::cout << "TOP = " << rootParser_->nodeStack_.top().first->debugType() << " '"
-                  << rootParser_->nodeStack_.top().first->name() << "'\n";
-}
-
-void Parser::addParser(Parser* p) {
-    p->parent(this);
-    expectedParsers_.push_back(p);
-}
-
-void Parser::popNode() const {
-    nodeStack().pop();
-}
-
-void Parser::popToContainerNode() const {
-    while (!nodeStack().empty() && !nodeStack_top()->isNodeContainer()) {
-        nodeStack().pop(); // keep poping till we get to family or suite
-    }
-}
-
-void Parser::dump(const std::vector<std::string>& lineTokens) {
-    cout << "tokens:";
-    for (const auto& lineToken : lineTokens) {
-        cout << " '" << lineToken << "' ";
-    }
-    cout << "\n";
-}
-
-#ifdef SHOW_PARSER_STATS
-void Parser::printStats() {
-    Indentor::indent(std::cout) << "Parser::" << keyword() << "\n";
-    for (Parser* p : expectedParsers_) {
-        Indentor::indent(std::cout) << p->keyword() << " " << p->parserCount() << "\n";
-    }
-
-    Indentor in;
-    for (Parser* p : expectedParsers_) {
-        if (p->hasChildren()) {
-            p->printStats();
-        }
-    }
-}
-#endif
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/Parser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/Parser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/Parser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/Parser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_Parser_HPP
-#define ecflow_node_parser_Parser_HPP
-
-#include <stack>
-#include <string>
-#include <unordered_map>
-#include <vector>
-
-class DefsStructureParser;
-class Node;
-class Defs;
-
-// #define SHOW_PARSER_STATS 1
-
-class Parser {
-public:
-    explicit Parser(DefsStructureParser* p);
-    virtual ~Parser();
-
-    // if child does not recognise token try the parent
-    virtual bool doParse(const std::string& line, std::vector<std::string>& lineTokens);
-    Parser* parent() const { return parent_; }
-    void parent(Parser* p) { parent_ = p; }
-
-    virtual const char* keyword() const = 0;
-
-    DefsStructureParser* rootParser() const { return rootParser_; }
-
-    // convenience function that access DefsStructureParser
-    std::stack<std::pair<Node*, const Parser*>>& nodeStack() const;
-    Node* nodeStack_top() const;
-    std::unordered_map<Node*, bool>& defStatusMap() const;
-
-#ifdef SHOW_PARSER_STATS
-    // The following function used in parser stats only
-    void printStats();
-#endif
-
-protected:
-    Defs* defsfile() const;
-    void dumpStackTop(const std::string& msg, const std::string& msg2 = "") const;
-    void addParser(Parser* p);
-    void popNode() const;
-    void popToContainerNode() const;
-    static void dump(const std::vector<std::string>& lineTokens);
-    void reserve_vec(int res) { expectedParsers_.reserve(res); }
-
-private:
-    bool hasChildren() const { return !expectedParsers_.empty(); }
-
-    Parser* parent_;
-    DefsStructureParser* rootParser_;
-    std::vector<Parser*> expectedParsers_;
-
-#ifdef SHOW_PARSER_STATS
-    // The following function used in parser stats only
-    void incrementParserCount() { parserCount_++; }
-    int parserCount() const { return parserCount_; }
-    int parserCount_;
-#endif
-};
-
-#endif /* ecflow_node_parser_Parser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/QueueParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/QueueParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/QueueParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/QueueParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/QueueParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool QueueParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    if (nodeStack().empty()) {
-        throw std::runtime_error("QueueParser::doParse: Could not add queue, as node stack is empty at line: " + line);
-    }
-
-    bool parse_state = false;
-    if (rootParser()->get_file_type() != PrintStyle::DEFS)
-        parse_state = true;
-
-    QueueAttr queue_attr;
-    QueueAttr::parse(queue_attr, line, lineTokens, parse_state);
-    Node* node = nodeStack_top();
-    node->add_queue(queue_attr);
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/QueueParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/QueueParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/QueueParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/QueueParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_QueueParser_HPP
-#define ecflow_node_parser_QueueParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class QueueParser : public Parser {
-public:
-    explicit QueueParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "queue"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_QueueParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/RepeatParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/RepeatParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/RepeatParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/RepeatParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,266 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/RepeatParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-bool RepeatParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    size_t line_token_size = lineTokens.size();
-    if (line_token_size < 3)
-        throw std::runtime_error("RepeatParser::doParse: Invalid repeat " + line);
-    if (nodeStack().empty())
-        throw std::runtime_error("RepeatParser::doParse: Could not add repeat as node stack is empty at line: " + line);
-
-    string errorMsg = "Invalid repeat : ";
-    errorMsg += line;
-
-    if (lineTokens[1] == "date") {
-        // repeat date VARIABLE yyyymmdd yyyymmdd [delta]
-        if (line_token_size < 5)
-            throw std::runtime_error(errorMsg);
-
-        string name  = lineTokens[2];
-        int startYMD = Extract::ymd(lineTokens[3], errorMsg);
-        int endYMD   = Extract::ymd(lineTokens[4], errorMsg);
-        int delta    = Extract::optionalInt(lineTokens, 5, 1, errorMsg);
-        RepeatDate rep(name, startYMD, endYMD, delta);
-        int value = 0;
-        if (get_value(lineTokens, value))
-            rep.set_value(value);
-
-        nodeStack_top()->addRepeat(Repeat(rep));
-    }
-    else if (lineTokens[1] == "datetime") {
-        // repeat datetime VARIABLE yyyy-mm-ddTMM:HH:SS yyyy-mm-ddTMM:HH:SS [MM:HH[:SS]]
-        if (line_token_size < 5)
-            throw std::runtime_error(errorMsg);
-
-        string name      = lineTokens[2];
-        Instant startYMD = Instant::parse(lineTokens[3]);
-        Instant endYMD   = Instant::parse(lineTokens[4]);
-        Duration delta   = Duration{std::chrono::seconds{86400}}; // by default, consider delta = 24 hours
-        if (line_token_size >= 6) {
-            delta = Duration::parse(lineTokens[5]);
-        }
-        RepeatDateTime rep(name, startYMD, endYMD, delta);
-        ecf::Instant value;
-        if (get_value(lineTokens, value)) {
-            rep.set_value(coerce_from_instant(value));
-        }
-
-        nodeStack_top()->addRepeat(Repeat(rep));
-    }
-    else if (lineTokens[1] == "datelist") {
-
-        if (line_token_size < 4)
-            throw std::runtime_error(errorMsg);
-
-        // repeat datelist VARIABLE "YYYYMMDD" "YYYYMMDD" "YYYYMMDD" # comment
-        string name = lineTokens[2];
-        std::vector<int> theEnums;
-        theEnums.reserve(line_token_size);
-        for (size_t i = 3; i < line_token_size; i++) {
-            std::string theEnum = lineTokens[i];
-            if (theEnum[0] == '#')
-                break;
-            Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
-            Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
-
-            int date = 0;
-            try {
-                date = ecf::convert_to<int>(theEnum);
-            }
-            catch (const ecf::bad_conversion&) {
-                throw std::runtime_error("RepeatParser::doParse: repeat datelist " + name +
-                                         ", invalid date : " + theEnum);
-            }
-            theEnums.push_back(date);
-        }
-        if (theEnums.empty())
-            throw std::runtime_error(errorMsg);
-
-        RepeatDateList rep(name, theEnums);
-        int index = 0; // This is *assumed to be the index* and not the value
-        if (get_value(lineTokens, index))
-            rep.set_value(index);
-
-        nodeStack_top()->addRepeat(Repeat(rep));
-    }
-    else if (lineTokens[1] == "enumerated") {
-
-        if (line_token_size < 4)
-            throw std::runtime_error(errorMsg);
-
-        // repeat enumerated VARIABLE "first" "second" "last" # comment
-        string name = lineTokens[2];
-        std::vector<std::string> theEnums;
-        theEnums.reserve(line_token_size);
-        for (size_t i = 3; i < line_token_size; i++) {
-            std::string theEnum = lineTokens[i];
-            if (theEnum[0] == '#')
-                break;
-            Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
-            Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
-            theEnums.push_back(theEnum);
-        }
-        if (theEnums.empty())
-            throw std::runtime_error(errorMsg);
-
-        RepeatEnumerated rep(name, theEnums);
-        int index = 0; // This is *assumed to be the index* and not the value
-        if (get_value(lineTokens, index))
-            rep.set_value(index);
-
-        nodeStack_top()->addRepeat(Repeat(rep));
-    }
-    else if (lineTokens[1] == "integer") {
-        // repeat integer VARIABLE start end [step]
-        if (line_token_size < 5)
-            throw std::runtime_error(errorMsg);
-
-        string name = lineTokens[2];
-        int start   = Extract::theInt(lineTokens[3], errorMsg);
-        int end     = Extract::theInt(lineTokens[4], errorMsg);
-        int step    = Extract::optionalInt(lineTokens, 5, 1, errorMsg);
-        RepeatInteger rep(name, start, end, step);
-        int value = 0;
-        if (get_value(lineTokens, value))
-            rep.set_value(value);
-
-        nodeStack_top()->addRepeat(Repeat(rep));
-    }
-    else if (lineTokens[1] == "day") {
-        // repeat day step [ yyyymmdd ]  # the step can be positive or negative
-        // *** See RepeatAttr.h ***
-        // *** We will not support end date until there is a clear requirement for this
-        int step = Extract::theInt(lineTokens[2], "Invalid repeat day:");
-
-        // report end date as a parser error
-        if (line_token_size >= 4 && lineTokens[3][0] != '#') {
-            throw std::runtime_error("RepeatParser::doParse: repeat day, <end-date> not supported: " + line);
-        }
-        // day has no state
-        nodeStack_top()->addRepeat(Repeat(RepeatDay(step)));
-    }
-    else if (lineTokens[1] == "string") {
-
-        if (line_token_size < 4)
-            throw std::runtime_error(errorMsg);
-
-        string name = lineTokens[2];
-        std::vector<std::string> theEnums;
-        theEnums.reserve(line_token_size);
-        for (size_t i = 3; i < line_token_size; i++) {
-            std::string theEnum = lineTokens[i];
-            if (theEnum[0] == '#')
-                break;
-            Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
-            Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
-            theEnums.push_back(theEnum);
-        }
-        if (theEnums.empty())
-            throw std::runtime_error(errorMsg);
-
-        RepeatString rep(name, theEnums);
-        int index = 0;
-        if (get_value(lineTokens, index))
-            rep.set_value(index);
-
-        nodeStack_top()->addRepeat(Repeat(rep));
-    }
-    else if (lineTokens[1] == "month") {
-        // repeat month step [ yyyymmdd ]  # the step can be positive or negative
-        throw std::runtime_error("RepeatParser::doParse: repeat month not supported: " + line);
-
-        //		int endDate = 0;
-        //		int step = 0;
-        //		extractDayMonthYear( lineTokens, step, endDate );
-        //		nodeStack_top()->addRepeat( Repeat( RepeatMonth( step, endDate ) ) );
-    }
-    else if (lineTokens[1] == "year") {
-        // repeat year step [ yyyymmdd ]  # the step can be positive or negative
-        throw std::runtime_error("RepeatParser::doParse: repeat year not supported: " + line);
-        //		int endDate = 0;
-        //		int step = 0;
-        //		extractDayMonthYear( lineTokens, step, endDate );
-        //		nodeStack_top()->addRepeat( Repeat( RepeatYear( step, endDate ) ) );
-    }
-    else if (lineTokens[1] == "file") {
-        // NOT SUPPORTED
-    }
-    else {
-        throw std::runtime_error("RepeatParser::doParse: Invalid repeat " + line);
-    }
-    return true;
-}
-
-// void RepeatParser::extractDayMonthYear( const std::vector< std::string >& lineTokens,
-//										int& x,
-//										int& endDate )
-//{
-//	x = Extract::theInt( lineTokens[2], "invalid repeat" );
-//	if ( lineTokens.size() >= 4 && lineTokens[3][0] != '#') {
-//		std::string errorMsg = "Invalid repeat";
-//		endDate = Extract::ymd( lineTokens[3], errorMsg );
-//  	}
-//	if ( ! nodeStack_top()->isSuite() ) {
-//		throw std::runtime_error( "RepeatParser::doParse: Invalid repeat day/month/year only valid for suite "
-//);
-//	}
-// }
-
-bool RepeatParser::get_value(const std::vector<std::string>& lineTokens, int& value) const {
-    // state
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        // search back for comment
-        // repeat integer VARIABLE start end [step] # value
-        std::string token_after_comment;
-        for (size_t i = lineTokens.size() - 1; i > 3; i--) {
-            if (lineTokens[i] == "#") {
-                // token after comment is the value
-                value = Extract::theInt(token_after_comment, "RepeatParser::doParse, could not extract repeat value");
-                return true;
-            }
-            else
-                token_after_comment = lineTokens[i];
-        }
-    }
-    return false;
-}
-
-bool RepeatParser::get_value(const std::vector<std::string>& lineTokens, Instant& value) const {
-    // state
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        // search back for comment
-        // repeat integer VARIABLE start end [step] # value
-        std::string token_after_comment;
-        for (size_t i = lineTokens.size() - 1; i > 3; i--) {
-            if (lineTokens[i] == "#") {
-                // token after comment is the value
-                value = Instant::parse(token_after_comment);
-                return true;
-            }
-            else
-                token_after_comment = lineTokens[i];
-        }
-    }
-    return false;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/RepeatParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/RepeatParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/RepeatParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/RepeatParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_RepeatParser_HPP
-#define ecflow_node_parser_RepeatParser_HPP
-
-#include "ecflow/core/Chrono.hpp"
-#include "ecflow/node/parser/Parser.hpp"
-
-class RepeatParser : public Parser {
-public:
-    explicit RepeatParser(DefsStructureParser* p) : Parser(p) {}
-
-    const char* keyword() const override { return "repeat"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-
-private:
-    // void extractDayMonthYear(const std::vector<std::string>& lineTokens,int& x, int& endDate);
-    bool get_value(const std::vector<std::string>& lineTokens, int& value) const;
-    bool get_value(const std::vector<std::string>& lineTokens, ecf::Instant& value) const;
-};
-
-#endif
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/TimeParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/TimeParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/TimeParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/TimeParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,47 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/TimeParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/TimeSeries.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool TimeParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    size_t line_tokens_size = lineTokens.size();
-    if (line_tokens_size < 2)
-        throw std::runtime_error("TimeParser::doParse: Invalid time :" + line);
-
-    bool parse_state = false;
-    bool isFree      = false;
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        parse_state      = true;
-        bool comment_fnd = false;
-        for (size_t i = 2; i < line_tokens_size; i++) {
-            if (comment_fnd && lineTokens[i] == "free")
-                isFree = true;
-            if (lineTokens[i] == "#")
-                comment_fnd = true;
-        }
-    }
-
-    size_t index = 1;
-    TimeAttr attr(TimeSeries::create(index, lineTokens, parse_state));
-    if (isFree)
-        attr.setFree();
-
-    nodeStack_top()->addTime(attr);
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/TimeParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/TimeParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/TimeParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/TimeParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_TimeParser_HPP
-#define ecflow_node_parser_TimeParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class TimeParser : public Parser {
-public:
-    explicit TimeParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "time"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_TimeParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/TodayParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/TodayParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/TodayParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/TodayParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,47 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/TodayParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool TodayParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    size_t line_tokens_size = lineTokens.size();
-    if (line_tokens_size < 2)
-        throw std::runtime_error("TodayParser::doParse: Invalid today :" + line);
-
-    bool parse_state = false;
-    bool isFree      = false;
-    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-        parse_state      = true;
-        bool comment_fnd = false;
-        for (size_t i = 2; i < line_tokens_size; i++) {
-            if (comment_fnd && lineTokens[i] == "free")
-                isFree = true;
-            if (lineTokens[i] == "#")
-                comment_fnd = true;
-        }
-    }
-
-    size_t index = 1;
-    TodayAttr attr(TimeSeries::create(index, lineTokens, parse_state));
-    if (isFree)
-        attr.setFree();
-
-    nodeStack_top()->addToday(attr);
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/TodayParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/TodayParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/TodayParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/TodayParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_TodayParser_HPP
-#define ecflow_node_parser_TodayParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class TodayParser : public Parser {
-public:
-    explicit TodayParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "today"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_TodayParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/TriggerParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/TriggerParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/TriggerParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/TriggerParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,182 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/TriggerParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-static bool hasExtension(const std::string& line, const std::vector<std::string>& lineTokens) {
-    //    cout << "hasExtension = ";
-    if (line[line.size() - 1] == '\\') {
-        //       cout << "true\n";
-        return true;
-    }
-    const std::string& lastToken = lineTokens.back();
-    if (lastToken == "\\" || lastToken[lastToken.size() - 1] == '\\') {
-        //       cout << "true\n";
-        return true;
-    }
-    //    cout << "false\n";
-    return false;
-}
-
-// ===============================================================================
-
-void TriggerCompleteParser::getExpression(const std::string& line,
-                                          std::vector<std::string>& theLineTokens,
-                                          std::string& expression,
-                                          bool& andExp,
-                                          bool& orExp,
-                                          bool& isFree) const {
-    assert(*theLineTokens.begin() == keyword());
-    if (theLineTokens.size() < 2)
-        throw std::runtime_error("Invalid " + std::string(keyword()) + " " + line);
-
-    // trigger -a n == complete
-    // complete -o n == complete
-    if (theLineTokens[1] == "-a") {
-        andExp = true;
-        theLineTokens.erase(theLineTokens.begin() + 1);
-    }
-    else if (theLineTokens[1] == "-o") {
-        orExp = true;
-        theLineTokens.erase(theLineTokens.begin() + 1);
-    }
-
-    // Handle continuations, by removing them and adding to expression
-    if (hasExtension(line, theLineTokens)) {
-        /*
-             trigger a == complete and  /
-                         b == complete
-         */
-        std::vector<std::string> accumalatedTokens = theLineTokens;
-        while (true) {
-
-            std::string line2;
-            rootParser()->getNextLine(line2);
-
-            std::vector<std::string> lineTokens2;
-            Str::split(line2, lineTokens2);
-
-            std::copy(lineTokens2.begin(), lineTokens2.end(), std::back_inserter(accumalatedTokens));
-
-            if (!hasExtension(line2, lineTokens2)) {
-                break;
-            }
-
-            if (accumalatedTokens.back() == "\\") { // remove continuation
-                accumalatedTokens.pop_back();
-            }
-        }
-
-        size_t accumalated_tokens_size = accumalatedTokens.size();
-        for (size_t i = 1; i < accumalated_tokens_size; i++) {
-            std::string token = accumalatedTokens[i];
-            if (token[token.size() - 1] == '\\') {
-                token.erase(token.begin() + token.size() - 1);
-            }
-            if (token.empty())
-                continue;
-            if (token.at(0) == '#')
-                break;
-            if (i != 1)
-                expression += " ";
-            expression += token;
-        }
-    }
-    else {
-
-        // lineTokens[0] == "trigger";/ "complete"
-        size_t line_token_size = theLineTokens.size();
-        expression.reserve(line.size());
-        for (size_t i = 1; i < line_token_size; i++) {
-            if (theLineTokens[i].at(0) == '#')
-                break;
-            if (i != 1)
-                expression += " ";
-            expression += theLineTokens[i];
-        }
-
-        // state
-        if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-            bool comment_fnd = false;
-            for (size_t i = 3; i < line_token_size; i++) {
-                if (comment_fnd) {
-                    if (theLineTokens[i] == "free") {
-                        isFree = true;
-                        break;
-                    }
-                }
-                if (theLineTokens[i] == "#")
-                    comment_fnd = true;
-            }
-        }
-    }
-
-    //	cout << "expression = '" << expression << "'\n";
-    if (expression.empty())
-        throw std::runtime_error("Invalid trigger " + line);
-}
-
-bool TriggerParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    bool andExp = false;
-    bool orExp  = false;
-    bool isFree = false;
-    std::string expression;
-    getExpression(line, lineTokens, expression, andExp, orExp, isFree);
-
-    if (!nodeStack().empty()) {
-        Node* node = nodeStack_top();
-        if (!andExp && !orExp)
-            node->add_part_trigger(PartExpression(std::move(expression)));
-        else if (andExp)
-            node->add_part_trigger(PartExpression(std::move(expression), true));
-        else if (orExp)
-            node->add_part_trigger(PartExpression(std::move(expression), false));
-        else
-            throw std::runtime_error("Invalid trigger " + line);
-        if (isFree)
-            node->freeTrigger();
-    }
-
-    return true;
-}
-
-bool CompleteParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    bool andExp = false;
-    bool orExp  = false;
-    bool isFree = false;
-    std::string expression;
-    getExpression(line, lineTokens, expression, andExp, orExp, isFree);
-
-    if (!nodeStack().empty()) {
-        Node* node = nodeStack_top();
-        if (!andExp && !orExp)
-            node->add_part_complete(PartExpression(std::move(expression)));
-        else if (andExp)
-            node->add_part_complete(PartExpression(std::move(expression), true));
-        else if (orExp)
-            node->add_part_complete(PartExpression(std::move(expression), false));
-        else
-            throw std::runtime_error("Invalid complete trigger " + line);
-        if (isFree)
-            node->freeComplete();
-    }
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/TriggerParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/TriggerParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/TriggerParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/TriggerParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_TriggerParser_HPP
-#define ecflow_node_parser_TriggerParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class TriggerCompleteParser : public Parser {
-protected:
-    explicit TriggerCompleteParser(DefsStructureParser* p) : Parser(p) {}
-    void getExpression(const std::string& line,
-                       std::vector<std::string>& lineTokens,
-                       std::string& expression,
-                       bool& andExr,
-                       bool& orExpr,
-                       bool& isFree) const;
-};
-
-class TriggerParser : public TriggerCompleteParser {
-public:
-    explicit TriggerParser(DefsStructureParser* p) : TriggerCompleteParser(p) {}
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-    const char* keyword() const override { return "trigger"; }
-};
-
-class CompleteParser : public TriggerCompleteParser {
-public:
-    explicit CompleteParser(DefsStructureParser* p) : TriggerCompleteParser(p) {}
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-    const char* keyword() const override { return "complete"; }
-};
-
-#endif /* ecflow_node_parser_TriggerParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/VariableParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/VariableParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/VariableParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/VariableParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,128 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/VariableParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool VariableParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // Note: For migrate the defs can have variables
-    Node* node = nullptr;
-    if (nodeStack().empty()) {
-        if (!parsing_defs_)
-            throw std::runtime_error(
-                "VariableParser::doParse: Could not add variable, as node stack is empty at line: " + line);
-    }
-    else
-        node = nodeStack_top();
-
-    size_t line_tokens_size = lineTokens.size();
-    if (line_tokens_size < 3) {
-        std::stringstream ss;
-        ss << "VariableParser::doParse: expected at least 3 tokens, found " << line_tokens_size << " on line:" << line
-           << "\n";
-        if (node)
-            ss << "At node: " << node->debugNodePath() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // There is no need check for '#' comment character in variable name
-    // since the variable constructor will check for this
-    // i.e  edit #var value
-    //      edit var# value
-
-    // Make sure value does not begin with '#' comment character
-    if (lineTokens[2][0] == '#') {
-        // edit fred #comment
-        // edit fred #
-        std::stringstream ss;
-        ss << "VariableParser::doParse: Expected value but found comment at line:" << line << "\n";
-        if (node)
-            ss << "At node: " << node->debugNodePath() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // ** For aliases, the variables may be **different** to normal variables in that they may contain a ":" & $
-    // ** This is **not** allowed in normal variables.
-    // ** i.e it allows for  %A:1%, %A:2%, %A:3%
-    // ** This is not really recommended but its what the old system supported.
-    // ** Hence the variable construction by-passes variable name checking ***
-
-    bool net = (rootParser()->get_file_type() == PrintStyle::NET);
-
-    // Note:
-    // edit OWNER 'fred'               => value = fred
-    // edit OWNER 'fred and "ginger"'  => value = fred and "ginger"
-    // edit OWNER ""                   => value =
-    // edit OWNER ''                   => value =
-    // edit OWNER '"fred"'             => value = "fred"   * quotes are preserved *
-    // edit OWNER "'fred'"             => value = fred     * tick are not preserved *
-    if (line_tokens_size == 3) {
-        // The order of removing double quotes and then single quotes is significant here
-        Str::removeQuotes(lineTokens[2]);       // if first *and* last character is "
-        Str::removeSingleQuotes(lineTokens[2]); // if first *and* last character is '
-        if (node) {
-            if (net || node->isAlias())
-                node->add_variable_bypass_name_check(lineTokens[1], lineTokens[2]); // bypass name checking
-            else
-                node->add_variable(lineTokens[1], lineTokens[2]);
-        }
-        else
-            defsfile()->set_server().add_or_update_user_variables(lineTokens[1], lineTokens[2]);
-        return true;
-    }
-
-    // i.e
-    //  0     1         2
-    // edit var_name "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  #fred
-    // edit var_name "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # server  // server variables on Defs
-    std::string value;
-    value.reserve(line.size() - 4);
-    size_t comment_pos = 0;
-    for (size_t i = 2; i < line_tokens_size; ++i) {
-        if (lineTokens[i].at(0) == '#') {
-            comment_pos = i;
-            break;
-        }
-        if (i != 2)
-            value += " ";
-        value += lineTokens[i];
-    }
-
-    Str::removeQuotes(value);
-    Str::removeSingleQuotes(value);
-    if (node) {
-        if (net || node->isAlias())
-            node->add_variable_bypass_name_check(lineTokens[1], value); // bypass name checking
-        else
-            node->add_variable(lineTokens[1], value);
-    }
-    else {
-        bool server_variable = false;
-        if (comment_pos != 0 && comment_pos + 1 < line_tokens_size) {
-            if (lineTokens[comment_pos + 1] == "server")
-                server_variable = true;
-        }
-        if (server_variable)
-            defsfile()->set_server().add_or_update_server_variable(lineTokens[1], value);
-        else
-            defsfile()->set_server().add_or_update_user_variables(lineTokens[1], value);
-    }
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/VariableParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/VariableParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/VariableParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/VariableParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,51 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_VariableParser_HPP
-#define ecflow_node_parser_VariableParser_HPP
-
-///
-/// \brief
-///   edit fred 'val'
-///   edit FRED "smscheck %WSHOST% %EXPVER% %ECF_JOB%"
-///
-/// In the old SMS single quotes are used if no interpretation
-/// is required and double quotes to allow variable substitution
-/// However this is ONLY a requirement for CDP.
-/// Note when OLD SMS uses the show command it always outputs with single quotes
-///
-/// Do we remove the quotes when we store internally ?
-///   i.e if we have :
-///      edit YMD '20090901'
-/// Then the value '20090901' is not immediately convertible to an integer
-/// *************************************************************
-/// This is required for evaluation in the abstract syntax tree
-/// *************************************************************
-///
-/// Hence we will do the following:
-///   a/ On parsing always remove quotes ie single or double
-///   b/ On serialising always add single quotes
-///
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class VariableParser : public Parser {
-public:
-    explicit VariableParser(DefsStructureParser* p, bool parsing_defs = false)
-        : Parser(p),
-          parsing_defs_(parsing_defs) {}
-    const char* keyword() const override { return "edit"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-
-private:
-    bool parsing_defs_;
-};
-
-#endif
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/VerifyParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/VerifyParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/VerifyParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/VerifyParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/VerifyParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool VerifyParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // expect:
-    //    verify <state>:<expected> # actual  i.e
-    //    verify complete:3 # 2
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("VerifyParser::doParse: Invalid verify :" + line);
-
-    if (!nodeStack().empty()) {
-        Node* node = nodeStack_top();
-
-        std::string stateInt = lineTokens[1];
-
-        size_t colonPos = stateInt.find_first_of(':');
-        if (colonPos == std::string::npos)
-            throw std::runtime_error("Invalid verify :" + line);
-
-        std::string state    = stateInt.substr(0, colonPos);
-        std::string expected = stateInt.substr(colonPos + 1);
-        // cout << "state = " << state << "\n";
-        // cout << "expected = " << expected << "\n";
-
-        if (!NState::isValid(state)) {
-            throw std::runtime_error("VerifyParser::doParse: Invalid state :" + line);
-        }
-
-        NState::State theState  = NState::toState(state);
-        int theExpectedStateCnt = Extract::theInt(expected, "Invalid verify");
-
-        // STATE
-        int actual = 0;
-        if (rootParser()->get_file_type() != PrintStyle::DEFS) {
-            if (lineTokens.size() >= 4) {
-                if (lineTokens[2] == "#") {
-                    try {
-                        actual = ecf::convert_to<int>(lineTokens[3]);
-                    }
-                    catch (const ecf::bad_conversion&) { /* ignore could be other comment */
-                    }
-                }
-            }
-        }
-
-        node->addVerify(VerifyAttr(theState, theExpectedStateCnt, actual));
-    }
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/VerifyParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/VerifyParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/VerifyParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/VerifyParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_VerifyParser_HPP
-#define ecflow_node_parser_VerifyParser_HPP
-
-///
-/// \brief A verify attribute parser.
-///
-/// Note that verify are only used for verification and do not constitute to the structure of a definition file
-///
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class VerifyParser : public Parser {
-public:
-    explicit VerifyParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "verify"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_VerifyParser_HPP */
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/ZombieAttrParser.cpp 5.13.0-1/ANode/src/ecflow/node/parser/ZombieAttrParser.cpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/ZombieAttrParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/ZombieAttrParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/node/parser/ZombieAttrParser.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool ZombieAttrParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
-    // expect:  tokenizer
-    //    zombie <zombie_type>: action : child_cmds :  lifetime
-    //    zombie_type = [ user | ecf | ecf_pid | ecf_pid_passwd | ecf_passwd| path ]  # can only have one
-    //    action      = [ fob | fail | block | remove | adopt ]                       # can only have one
-    //    child_cmd   = [ init, event, meter, label, wait, abort, complete ]          # can have multiple
-    //    zombie ecf:fob::                                                            # fob all child commands
-    //    zombie ecf:fail:event,meter:200                                             # fail child command  event,meter
-    //    and block other children
-    if (lineTokens.size() < 2)
-        throw std::runtime_error("ZombieAttrParser::doParse: Invalid zombie :" + line);
-    if (nodeStack().empty())
-        throw std::runtime_error("Add zombie failed empty node stack");
-
-    // cout << "ZombieAttrParser::doParse: " << lineTokens[1] << "\n";
-
-    nodeStack_top()->addZombie(ZombieAttr::create(lineTokens[1]));
-
-    return true;
-}
diff -pruN 5.12.4-1/ANode/src/ecflow/node/parser/ZombieAttrParser.hpp 5.13.0-1/ANode/src/ecflow/node/parser/ZombieAttrParser.hpp
--- 5.12.4-1/ANode/src/ecflow/node/parser/ZombieAttrParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/src/ecflow/node/parser/ZombieAttrParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_ZombieAttrParser_HPP
-#define ecflow_node_parser_ZombieAttrParser_HPP
-
-#include "ecflow/node/parser/Parser.hpp"
-
-class ZombieAttrParser : public Parser {
-public:
-    explicit ZombieAttrParser(DefsStructureParser* p) : Parser(p) {}
-    const char* keyword() const override { return "zombie"; }
-    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
-};
-
-#endif /* ecflow_node_parser_ZombieAttrParser_HPP */
diff -pruN 5.12.4-1/ANode/test/MyDefsFixture.hpp 5.13.0-1/ANode/test/MyDefsFixture.hpp
--- 5.12.4-1/ANode/test/MyDefsFixture.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/MyDefsFixture.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,288 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_test_MyDefsFixture_HPP
-#define ecflow_node_test_MyDefsFixture_HPP
-
-///
-/// \brief The structure ONLY used to test the persistence/migration
-/// as each new object is created we add it here, to test Serialisation
-/// read/write and migration of previous fixtures.
-///
-
-#include <algorithm>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/MiscAttrs.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-// =======================================================================
-// This struct is used in the node migration tests.
-// If we ever add to this , then update TestMigration.cpp
-// **Ensure** that we keep old fixture.def file, to test that future ecflow
-// versions can migrate old data.
-// =======================================================================
-struct MyDefsFixture
-{
-
-    explicit MyDefsFixture(const std::string& port = ecf::Str::DEFAULT_PORT_NUMBER()) : defsfile_(port) {
-        suite_ptr suite = create_suite();
-
-        // Must be done last
-        defsfile_.addSuite(suite);
-        defsfile_.add_extern("/limits:event");
-        defsfile_.add_extern("/a/b/c:meter");
-        defsfile_.add_extern("/a/b/c/d");
-
-        // add an empty suite. Needed for CHECK_JOB_GEN_ONLY cmd
-        defsfile_.addSuite(Suite::create("EmptySuite"));
-
-        // Check expression parse
-        std::string errorMsg, warningMsg;
-        bool result = defsfile_.check(errorMsg, warningMsg);
-        if (!result || !errorMsg.empty()) {
-            std::cout << errorMsg;
-            assert(false);
-        }
-    }
-    ~MyDefsFixture() = default;
-
-    const Defs& fixtureDefsFile() const { return defsfile_; }
-
-    defs_ptr create_defs(const std::string& port = ecf::Str::DEFAULT_PORT_NUMBER()) const {
-
-        defs_ptr defs = Defs::create(port);
-
-        defs->addSuite(create_suite());
-        defs->add_extern("/limits:event");
-        defs->add_extern("/a/b/c:meter");
-        defs->add_extern("/a/b/c/d");
-        defs->set_server().add_or_update_user_variables("MyDefsFixture_user_variable",
-                                                        "This is a user variable added to server");
-        defs->set_server().add_or_update_server_variable("MyDefsFixture_server_variable", "This is a server variable");
-
-        // add an empty suite. Needed for CHECK_JOB_GEN_ONLY cmd
-        defs->addSuite(Suite::create("EmptySuite"));
-
-        // Check expression parse
-        std::string errorMsg, warningMsg;
-        bool result = defs->check(errorMsg, warningMsg);
-        if (!result || !errorMsg.empty()) {
-            std::cout << errorMsg;
-            assert(false);
-        }
-        return defs;
-    }
-
-    Defs defsfile_;
-
-private:
-    suite_ptr create_suite() const {
-        std::string sname = "suiteName";
-        suite_ptr suite   = Suite::create(sname);
-
-        ClockAttr clockAttr(false);
-        clockAttr.date(1, 1, 2009);
-        clockAttr.set_gain_in_seconds(3600);
-        suite->addClock(clockAttr);
-
-        suite->addAutoCancel(ecf::AutoCancelAttr(2));
-        suite->addVariable(Variable("VAR", "value"));
-        suite->addVariable(Variable("VAR1", "\"value\""));
-        suite->addVariable(Variable("ECF_FETCH", "\"smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%\""));
-
-        std::vector<std::string> queue_items;
-        queue_items.emplace_back("000");
-        queue_items.emplace_back("001");
-        queue_items.emplace_back("002");
-        suite->add_queue(QueueAttr("queue", queue_items));
-        suite->add_queue(QueueAttr("queue1", queue_items));
-        suite->add_generic(GenericAttr("gen1", queue_items));
-        suite->add_generic(GenericAttr("gen2", queue_items));
-        suite->add_task("t1");
-        suite->add_task("t2");
-        task_ptr suiteTask = suite->add_task("t3");
-        suiteTask->add_part_trigger(PartExpression("t1 == complete"));
-        suiteTask->add_part_trigger(PartExpression("t2 == complete", false));
-        suiteTask->add_part_complete(PartExpression("t1 == complete"));
-        suiteTask->add_part_complete(PartExpression("t2 == complete", true));
-
-        std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
-        suiteTask->addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
-        suiteTask->addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
-        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
-        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::FAIL, 100));
-        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::FAIL, 100));
-        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::FAIL, 100));
-
-        task_ptr suiteTask4 = suite->add_task("t4");
-        suiteTask4->addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::ADOPT, 10));
-        suiteTask4->addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
-        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::REMOVE, 100));
-        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::KILL, 100));
-        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::FOB, 100));
-        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::BLOCK, 100));
-
-        ecf::CronAttr cronAttr;
-        ecf::TimeSlot start(0, 0);
-        ecf::TimeSlot finish(10, 0);
-        ecf::TimeSlot incr(0, 5);
-        std::vector<int> weekdays;
-        for (int i = 0; i < 7; ++i)
-            weekdays.push_back(i);
-        std::vector<int> daysOfMonth;
-        for (int i = 1; i < 32; ++i)
-            daysOfMonth.push_back(i);
-        std::vector<int> months;
-        for (int i = 1; i < 13; ++i)
-            months.push_back(i);
-        cronAttr.addTimeSeries(start, finish, incr);
-        cronAttr.addWeekDays(weekdays);
-        cronAttr.addDaysOfMonth(daysOfMonth);
-        cronAttr.addMonths(months);
-        suite->addCron(cronAttr);
-
-        ecf::LateAttr lateAttr;
-        lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
-        lateAttr.addActive(ecf::TimeSlot(3, 12));
-        lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
-
-        std::string suiteLimit  = "suiteLimit";
-        std::string suiteLimit2 = "suiteLimit2";
-        std::string suiteLimit3 = "suiteLimit3";
-        suite->addLimit(Limit(suiteLimit, 10));
-        suite->addLimit(Limit(suiteLimit2, 10));
-        suite->addLimit(Limit(suiteLimit3, 10));
-
-        // Add tasks with all the repeat variants
-        std::vector<std::string> stringList{"10", "20", "30"};
-        task_ptr t5 = suite->add_task("t5");
-        t5->addRepeat(RepeatEnumerated("AEnum", stringList));
-
-        task_ptr t6 = suite->add_task("t6");
-        t6->addRepeat(RepeatString("aString", stringList));
-
-        task_ptr t7 = suite->add_task("t7");
-        t7->addRepeat(RepeatInteger("rep", 0, 100, 1));
-
-        task_ptr t8 = suite->add_task("t8");
-        t8->addRepeat(RepeatDate("YMD", 20090916, 20090916, 1));
-
-        task_ptr t9 = suite->add_task("t9");
-        t9->addRepeat(RepeatDateList("YMD", {20090916, 20090916}));
-
-        task_ptr t10 = suite->add_task("t10");
-        t10->addRepeat(RepeatDay(2));
-
-        suite->add_family("f1")->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
-        suite->add_family("f2")->add_autoarchive(ecf::AutoArchiveAttr(5, 22, true));
-        suite->add_family("f3")->add_autoarchive(ecf::AutoArchiveAttr(4));
-        suite->add_family("f4")->add_autoarchive(ecf::AutoArchiveAttr(0));
-        suite->add_family("f5")->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true, true));
-        suite->add_family("f6")->add_autoarchive(ecf::AutoArchiveAttr(5, 22, true, true));
-        suite->add_family("f7")->add_autoarchive(ecf::AutoArchiveAttr(4, true));
-        suite->add_family("f8")->add_autoarchive(ecf::AutoArchiveAttr(0, true));
-
-        for (int i = 0; i < 3; ++i) {
-            std::string fname     = "familyName";
-            std::string tname     = "taskName";
-            std::string eventName = "eventName";
-            std::string labelName = "labelName";
-            std::string limitName = "limitName";
-            if (i != 0) {
-                fname += ecf::convert_to<std::string>(i);
-                tname += ecf::convert_to<std::string>(i);
-                labelName += ecf::convert_to<std::string>(i);
-            }
-
-            family_ptr fam = suite->add_family(fname);
-            fam->addDate(DateAttr(0, 0, 2009)); // 0 is equivalent to a *
-            fam->addRepeat(RepeatEnumerated("AEnum", stringList));
-            fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), true));
-            fam->addVariable(Variable("VAR", "value"));
-            fam->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), true));
-            fam->addLimit(Limit(limitName, 20));
-            fam->addLate(lateAttr);
-            fam->addInLimit(InLimit(suiteLimit2, "/" + sname, 2, true /*limit this node only*/));
-            fam->add_queue(QueueAttr("queue1", queue_items));
-            fam->add_generic(GenericAttr("gen1", queue_items));
-
-            task_ptr task = fam->add_task(tname);
-            task->addDate(DateAttr(1, 2, 2009));
-            task->addDay(DayAttr(DayAttr::MONDAY));
-            task->addVariable(Variable("VAR1", "\"value\""));
-            task->addEvent(Event(i));
-            task->addEvent(Event(i + 1, eventName));
-            task->addEvent(Event(i + 2, "my_event", true /*init value*/));
-            task->addMeter(Meter("myMeter", 0, 100, 100));
-            task->addLabel(Label(labelName, "\"labelValue\""));
-            task->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 10), true));
-            task->addToday(ecf::TodayAttr(ecf::TimeSlot(10, 12)));
-            task->addToday(ecf::TodayAttr(ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 3), ecf::TimeSlot(0, 1), true));
-            task->addDefStatus(DState::COMPLETE);
-            task->addInLimit(InLimit(suiteLimit, "/" + sname));
-            task->addInLimit(
-                InLimit(suiteLimit3, "/" + sname, 1, false /*limit this node only*/, true /*limit submission*/));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 3));
-            task->addLate(lateAttr);
-            task->add_queue(QueueAttr("queue1", queue_items));
-            task->add_generic(GenericAttr("gen1", queue_items));
-            task->add_generic(GenericAttr("gen2", std::vector<std::string>()));
-
-            std::vector<std::string> nodes_to_restore;
-            nodes_to_restore.emplace_back("/EmptySuite");
-            task->add_autorestore(ecf::AutoRestoreAttr(nodes_to_restore));
-            if (i == 2) {
-                std::string compExpr = "../familyName" + ecf::convert_to<std::string>(i - 1);
-                compExpr += "/taskName" + ecf::convert_to<std::string>(i - 1);
-                compExpr += ":myMeter ge 10";
-                task->add_complete(compExpr);
-
-                std::string expression = "../familyName" + ecf::convert_to<std::string>(i - 1);
-                expression += "/taskName" + ecf::convert_to<std::string>(i - 1);
-                expression += " == complete";
-                task->add_trigger(expression);
-            }
-            task->add_alias_only(); // add alias without creating dir & .usr file
-            task->add_alias_only();
-
-            // Add a hierarchical family to the first family
-            if (i == 0) {
-                std::string heirFamily = "heir_" + fname;
-                family_ptr hierFam     = fam->add_family(heirFamily);
-                hierFam->addVariable(Variable("VAR1", "value"));
-                hierFam->addRepeat(RepeatString("aString", stringList));
-                hierFam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
-
-                task_ptr task1 = hierFam->add_task(tname);
-                task1->addVariable(Variable("VAR1", "value"));
-                task1->addEvent(Event(i));
-                task1->addEvent(Event(i + 1, eventName));
-                task1->addEvent(Event(i + 2, "my_event", true /*init value*/));
-                task1->addMeter(Meter("myMeter", 0, 100, 100));
-                task1->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(0, 1), false));
-            }
-        }
-        return suite;
-    }
-};
-
-#endif /* ecflow_node_test_MyDefsFixture_HPP */
diff -pruN 5.12.4-1/ANode/test/TestAdd.cpp 5.13.0-1/ANode/test/TestAdd.cpp
--- 5.12.4-1/ANode/test/TestAdd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestAdd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,119 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Add)
-
-BOOST_AUTO_TEST_CASE(test_add) {
-    cout << "ANode:: ...test_add\n";
-
-    defs_ptr defs = Defs::create();
-    task_ptr t1   = Task::create("t1");
-    family_ptr f1 = Family::create("f1");
-    suite_ptr s1  = Suite::create("s1");
-
-    defs->addSuite(s1);
-    s1->addFamily(f1);
-    f1->addTask(t1);
-
-    defs_ptr defs2 = Defs::create();
-    suite_ptr s2   = Suite::create("s2");
-    family_ptr f2  = Family::create("f2");
-
-    // This should all fail since, they are already owned.
-    // Otherwise we end up with two different container owning the same object
-    BOOST_CHECK_THROW(s2->addFamily(f1), std::runtime_error);
-    BOOST_CHECK_THROW(f2->addTask(t1), std::runtime_error);
-    BOOST_CHECK_THROW(defs2->addSuite(s1), std::runtime_error);
-}
-
-BOOST_AUTO_TEST_CASE(test_add_error) {
-    cout << "ANode:: ...test_add_error\n";
-
-    defs_ptr defs = Defs::create();
-    suite_ptr s1  = defs->add_suite("s1");
-    s1->add_task("t1");
-    s1->add_family("f1");
-    BOOST_CHECK_THROW(defs->add_suite("s1"), std::runtime_error); // duplicate suite
-    BOOST_CHECK_THROW(s1->add_task("t1"), std::runtime_error);    // duplicate task
-    BOOST_CHECK_THROW(s1->add_family("t1"), std::runtime_error);  // duplicate name
-    BOOST_CHECK_THROW(s1->add_task("f1"), std::runtime_error);    // duplicate name
-}
-
-BOOST_AUTO_TEST_CASE(test_add_delete_time) {
-    cout << "ANode:: ...test_add_delete_time\n"; // ECFLOW-1260
-
-    // Make sure that if we delete any time based attributes
-    Defs defs;
-    suite_ptr s1 = defs.add_suite("s1");
-    task_ptr t1  = s1->add_task("t1");
-
-    BOOST_REQUIRE_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
-
-    ecf::CronAttr cronAttr;
-    ecf::TimeSlot start(0, 0);
-    ecf::TimeSlot finish(10, 0);
-    ecf::TimeSlot incr(0, 5);
-    std::vector<int> weekdays;
-    for (int i = 0; i < 7; ++i)
-        weekdays.push_back(i);
-    std::vector<int> daysOfMonth;
-    for (int i = 1; i < 32; ++i)
-        daysOfMonth.push_back(i);
-    std::vector<int> months;
-    for (int i = 1; i < 13; ++i)
-        months.push_back(i);
-    cronAttr.addTimeSeries(start, finish, incr);
-    cronAttr.addWeekDays(weekdays);
-    cronAttr.addDaysOfMonth(daysOfMonth);
-    cronAttr.addMonths(months);
-    t1->addCron(cronAttr);
-    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
-    t1->deleteCron("");
-    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
-
-    t1->addDate(DateAttr(1, 2, 2009));
-    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
-    t1->deleteDate("");
-    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
-
-    t1->addDay(DayAttr(DayAttr::MONDAY));
-    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
-    t1->deleteDay("");
-    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
-
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), true));
-    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
-    t1->deleteTime("");
-    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
-
-    t1->addToday(ecf::TodayAttr(ecf::TimeSlot(10, 12)));
-    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
-    t1->deleteToday("");
-    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestAlias.cpp 5.13.0-1/ANode/test/TestAlias.cpp
--- 5.12.4-1/ANode/test/TestAlias.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestAlias.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,151 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Alias)
-
-BOOST_AUTO_TEST_CASE(test_alias_create) {
-    cout << "ANode:: ...test_alias_create\n";
-    std::string ecf_home = File::test_data("ANode/test/data/alias", "ANode");
-
-    task_ptr t;
-    Defs theDefs;
-    {
-        suite_ptr s  = theDefs.add_suite("test_alias_create");
-        family_ptr f = s->add_family("f");
-        t            = f->add_task("t");
-        // ECFLOW-1278  set values for event,meter,labels, then ensure alias creation clears them
-        Meter meter1("met", 0, 100, 100);
-        meter1.set_value(10);
-        Meter meter2("met2", 0, 100, 100);
-        meter2.set_value(10);
-        Event event1(1, "event1");
-        event1.set_value(true);
-        Event event2(1, "event2");
-        event2.set_value(true);
-        Label label1("name", "value");
-        label1.set_new_value("new_value");
-        Label label2("name2", "value");
-        label2.set_new_value("new_value");
-        t->addMeter(meter1);
-        t->addMeter(meter2);
-        t->addEvent(event1);
-        t->addEvent(event2);
-        t->addLabel(label1);
-        t->addLabel(label2);
-        s->add_variable(Str::ECF_HOME(), ecf_home);
-    }
-
-    // Create .usr file content
-    std::vector<std::string> usr_file_vec;
-    usr_file_vec.emplace_back("#This is a .usr file.");
-
-    // Create list of variables
-    NameValueVec used_variables;
-    used_variables.push_back(std::make_pair(std::string("a"), std::string("a_value")));
-    used_variables.push_back(std::make_pair(std::string("b"), std::string("b_value")));
-
-    // Finally create the alias.
-    alias_ptr alias = t->add_alias(usr_file_vec, used_variables);
-
-    // Test that default node state is QUEUED
-    BOOST_CHECK_MESSAGE(alias->state() == NState::QUEUED, "Expected initial state of QUEUED");
-
-    // Test that CHILD specific attributes event, meter, labels are copied over from the task  AND that they are reset.
-    BOOST_CHECK_MESSAGE(alias->meters().size() == 2,
-                        "Expected 2 meter to be copied from task but found " << alias->meters().size());
-    BOOST_CHECK_MESSAGE(alias->events().size() == 2,
-                        "Expected 2 events to be copied from task but found " << alias->events().size());
-    BOOST_CHECK_MESSAGE(alias->labels().size() == 2,
-                        "Expected 2 labels to be copied from task but found " << alias->labels().size());
-    for (const Meter& meter : alias->meters()) {
-        BOOST_CHECK_MESSAGE(meter.value() == meter.min(),
-                            "Expected meter value " << meter.min() << " but found " << meter.value() << " for "
-                                                    << meter.dump());
-    }
-    for (const Event& event : alias->events()) {
-        BOOST_CHECK_MESSAGE(!event.value(), "Expected " << event.dump() << " to be clear");
-    }
-    for (const Label& label : alias->labels()) {
-        BOOST_CHECK_MESSAGE(label.new_value().empty(), "Expected " << label.dump() << " to be clear");
-    }
-
-    // Ensure Task state was not changed
-    BOOST_CHECK_MESSAGE(t->meters().size() == 2,
-                        "Did not expect task state to change, expected 2 meter but found: " << t->meters().size());
-    BOOST_CHECK_MESSAGE(t->events().size() == 2,
-                        "Did not expect task state to change, expected 2 events but found:" << t->events().size());
-    BOOST_CHECK_MESSAGE(t->labels().size() == 2,
-                        "Did not expect task state to change, expected 2 labels but found:" << t->labels().size());
-    for (const Meter& meter : t->meters()) {
-        BOOST_CHECK_MESSAGE(meter.value() == 10,
-                            "Expected meter value 10 but found " << meter.value() << " for " << meter.dump());
-    }
-    for (const Event& event : t->events()) {
-        BOOST_CHECK_MESSAGE(event.value(), "Expected " << event.dump() << " to be set");
-    }
-    for (const Label& label : t->labels()) {
-        BOOST_CHECK_MESSAGE(label.new_value() == "new_value",
-                            "Expected label with 'new_value' but found " << label.new_value());
-    }
-
-    // test that user variables passed in got added as Variables
-    BOOST_CHECK_MESSAGE(alias->variables().size() == 2,
-                        "Expected 2 variables to be create from input args but found " << alias->variables().size());
-
-    // Test directory creation
-    fs::path dir(ecf_home + "/" + t->absNodePath());
-    BOOST_CHECK_MESSAGE(fs::exists(dir), "Expected directory to be created " + dir.string());
-
-    // Test alias0.usr file creation
-    fs::path usr_file(ecf_home + "/" + t->absNodePath() + "/" + "alias0.usr");
-    BOOST_CHECK_MESSAGE(fs::exists(usr_file), "Expected alias0.usr file to be created " + usr_file.string());
-
-    // Create another alias. This should get created as alias1.usr
-    alias_ptr alias1 = t->add_alias(usr_file_vec, used_variables);
-    fs::path usr_file1(ecf_home + "/" + t->absNodePath() + "/" + "alias1.usr");
-    BOOST_CHECK_MESSAGE(fs::exists(usr_file1), "Expected alias1.usr file to be created " + usr_file1.string());
-
-    // Test Defs::get_all_aliases()
-    std::vector<alias_ptr> alias_vec;
-    theDefs.get_all_aliases(alias_vec);
-    BOOST_CHECK_MESSAGE(alias_vec.size() == 2, "Expected 2 aliases but found " << alias_vec.size());
-
-    // Check alias remove
-    for (alias_ptr al : alias_vec) {
-        al->remove();
-    }
-    alias_vec.clear();
-    theDefs.get_all_aliases(alias_vec);
-    BOOST_CHECK_MESSAGE(alias_vec.empty(), "Expected no aliases but found " << alias_vec.size());
-
-    // Cleanup by removing the created directory
-    fs::remove_all(ecf_home);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestAssignmentOperator.cpp 5.13.0-1/ANode/test/TestAssignmentOperator.cpp
--- 5.12.4-1/ANode/test/TestAssignmentOperator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestAssignmentOperator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,180 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "ecflow/core/Ecf.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_AssignmentOperator)
-
-BOOST_AUTO_TEST_CASE(test_defs_assignment_operator) {
-    cout << "ANode:: ...test_defs_assignment_operator\n";
-    MyDefsFixture theDefsFixture;
-
-    Defs defs;
-    defs = theDefsFixture.defsfile_;
-    Ecf::set_debug_equality(true); // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(defs == theDefsFixture.defsfile_, "assignment failed");
-    Ecf::set_debug_equality(false); // only has affect in DEBUG build
-
-    Defs empty;
-    defs = empty;
-    Ecf::set_debug_equality(true); // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(defs == empty, "assignment failed");
-    Ecf::set_debug_equality(false); // only has affect in DEBUG build
-
-    BOOST_CHECK_MESSAGE(!(defs == theDefsFixture.defsfile_), "assignment failure EXPECTED");
-
-    theDefsFixture.defsfile_ = empty;
-    BOOST_CHECK_MESSAGE(theDefsFixture.defsfile_ == empty, "assignment failed");
-}
-
-BOOST_AUTO_TEST_CASE(test_suite_assignment_operator) {
-    cout << "ANode:: ...test_suite_assignment_operator\n";
-    Suite empty("empty");
-
-    Suite s1("s1");
-    ClockAttr clockAttr(false);
-    clockAttr.date(1, 1, 2009);
-    clockAttr.set_gain_in_seconds(3600);
-    s1.addClock(clockAttr);
-    s1.addAutoCancel(ecf::AutoCancelAttr(2));
-    s1.addVariable(Variable("VAR", "value"));
-    s1.add_task("t1");
-    s1.add_family("f1");
-    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
-    s1.addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
-    s1.addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
-    s1.addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
-
-    ecf::CronAttr cronAttr;
-    ecf::TimeSlot start(0, 0);
-    ecf::TimeSlot finish(10, 0);
-    ecf::TimeSlot incr(0, 5);
-    std::vector<int> weekdays;
-    for (int i = 0; i < 7; ++i)
-        weekdays.push_back(i);
-    std::vector<int> daysOfMonth;
-    for (int i = 1; i < 32; ++i)
-        daysOfMonth.push_back(i);
-    std::vector<int> months;
-    for (int i = 1; i < 13; ++i)
-        months.push_back(i);
-    cronAttr.addTimeSeries(start, finish, incr);
-    cronAttr.addWeekDays(weekdays);
-    cronAttr.addDaysOfMonth(daysOfMonth);
-    cronAttr.addMonths(months);
-    s1.addCron(cronAttr);
-
-    ecf::LateAttr lateAttr;
-    lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
-    lateAttr.addActive(ecf::TimeSlot(3, 12));
-    lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
-
-    std::string suiteLimit = "suiteLimit";
-    s1.addLimit(Limit(suiteLimit, 10));
-
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    Suite s2(s1);                 // s2 is copy
-    BOOST_CHECK_MESSAGE(s1 == s2, "copy constructor failed");
-
-    Suite s3("s3");
-    s3 = empty;
-    BOOST_CHECK_MESSAGE(s3 == empty, "assignment failed");
-
-    s3 = s1;
-    BOOST_CHECK_MESSAGE(s3 == s1, "assignment failed");
-
-    s1 = s2;
-    BOOST_CHECK_MESSAGE(s1 == s2, "assignment failed");
-}
-
-BOOST_AUTO_TEST_CASE(test_task_assignment_operator) {
-    cout << "ANode:: ...test_task_assignment_operator\n";
-    Task empty("empty");
-
-    Task s1("s1");
-    s1.addAutoCancel(ecf::AutoCancelAttr(2));
-    s1.addVariable(Variable("VAR", "value"));
-    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
-    s1.addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
-    s1.addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
-    s1.addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
-
-    ecf::CronAttr cronAttr;
-    ecf::TimeSlot start(0, 0);
-    ecf::TimeSlot finish(10, 0);
-    ecf::TimeSlot incr(0, 5);
-    std::vector<int> weekdays;
-    for (int i = 0; i < 7; ++i)
-        weekdays.push_back(i);
-    std::vector<int> daysOfMonth;
-    for (int i = 1; i < 32; ++i)
-        daysOfMonth.push_back(i);
-    std::vector<int> months;
-    for (int i = 1; i < 13; ++i)
-        months.push_back(i);
-    cronAttr.addTimeSeries(start, finish, incr);
-    cronAttr.addWeekDays(weekdays);
-    cronAttr.addDaysOfMonth(daysOfMonth);
-    cronAttr.addMonths(months);
-    s1.addCron(cronAttr);
-
-    ecf::LateAttr lateAttr;
-    lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
-    lateAttr.addActive(ecf::TimeSlot(3, 12));
-    lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
-
-    std::string suiteLimit = "suiteLimit";
-    s1.addLimit(Limit(suiteLimit, 10));
-
-    s1.addDate(DateAttr(1, 2, 2009));
-    s1.addDay(DayAttr(DayAttr::MONDAY));
-    s1.addVariable(Variable("VAR1", "\"value\""));
-    s1.addEvent(Event(1));
-    s1.addEvent(Event(2, "eventname"));
-    s1.addEvent(Event(3, "eventname2", true /* init value */));
-    s1.addEvent(Event(4, "eventname4", true /* init value */, true /* value */));
-    s1.addMeter(Meter("myMeter", 0, 100, 100));
-    s1.addLabel(Label("label", "\"labelValue\""));
-    s1.addTime(ecf::TimeAttr(ecf::TimeSlot(10, 10), true));
-    s1.addToday(ecf::TodayAttr(ecf::TimeSlot(10, 12)));
-    s1.addToday(ecf::TodayAttr(ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 3), ecf::TimeSlot(0, 1), true));
-    s1.addDefStatus(DState::COMPLETE);
-    s1.addInLimit(InLimit(suiteLimit, "/name"));
-    s1.addVerify(VerifyAttr(NState::COMPLETE, 3));
-    s1.addLate(lateAttr);
-
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    Task s2(s1);                  // s2 is copy
-    BOOST_CHECK_MESSAGE(s1 == s2, "copy constructor failed");
-
-    Task s3("s3");
-    s3 = empty;
-    BOOST_CHECK_MESSAGE(s3 == empty, "assignment failed");
-
-    s3 = s1;
-    BOOST_CHECK_MESSAGE(s3 == s1, "assignment failed");
-
-    s1 = s2;
-    BOOST_CHECK_MESSAGE(s1 == s2, "assignment failed");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestChangeMgrSingleton.cpp 5.13.0-1/ANode/test/TestChangeMgrSingleton.cpp
--- 5.12.4-1/ANode/test/TestChangeMgrSingleton.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestChangeMgrSingleton.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,129 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/AbstractObserver.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-class MyObserver : public AbstractObserver {
-public:
-    explicit MyObserver(Defs* defs) : update_count_(0), defs_(defs), node_(nullptr) { defs->attach(this); }
-    explicit MyObserver(Node* node) : update_count_(0), defs_(nullptr), node_(node) { node->attach(this); }
-
-    ~MyObserver() override {
-        /* std::cout << "~MyObserver()\n"; */
-        if (defs_)
-            defs_->detach(this);
-        if (node_)
-            node_->detach(this);
-    }
-
-    void update_start(const Node*, const std::vector<ecf::Aspect::Type>&) override {}
-    void update_start(const Defs*, const std::vector<ecf::Aspect::Type>&) override {}
-
-    void update(const Node*, const std::vector<ecf::Aspect::Type>&) override { update_count_++; }
-    void update(const Defs*, const std::vector<ecf::Aspect::Type>&) override { update_count_++; }
-
-    /// After this call, the node will be deleted, hence observers must *NOT* use the pointers
-    void update_delete(const Node* node) override {
-        // std::cout << "update_delete(const Node* node)\n";
-        const_cast<Node*>(node)->detach(this);
-    }
-    void update_delete(const Defs* defs) override {
-        // std::cout << "update_delete(const Defs* node)\n";
-        const_cast<Defs*>(defs)->detach(this);
-    }
-
-    int update_count() const { return update_count_; }
-
-private:
-    int update_count_;
-    Defs* defs_;
-    Node* node_;
-};
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_ChangeMgrSingleton)
-
-BOOST_AUTO_TEST_CASE(test_change_mgr_singleton) {
-    cout << "ANode:: ...test_change_mgr_singleton\n";
-    {
-        defs_ptr theDefs = Defs::create();
-
-        {
-            // ensure defs pointer out-lives the observer
-            MyObserver defs_obs(theDefs.get());
-
-            std::vector<ecf::Aspect::Type> aspects;
-            theDefs->notify(aspects);
-            theDefs->notify(aspects);
-            theDefs->notify(aspects);
-            theDefs->notify(aspects);
-            theDefs->notify(aspects);
-            BOOST_CHECK_MESSAGE(defs_obs.update_count() == 5, "Expected 5 update");
-        }
-
-        theDefs.reset();
-    }
-
-    {
-        // **** Note using node_ptr can extend the life of the Node, hence we use scoping ***
-        auto* theDefs = new Defs;
-        std::vector<MyObserver*> obs_vec;
-        {
-            {
-                suite_ptr suite = theDefs->add_suite("suite1");
-                family_ptr fam  = suite->add_family("family");
-                fam->add_task("t1");
-            }
-
-            // get all nodes and observer them.
-            std::vector<node_ptr> node_vec;
-            theDefs->get_all_nodes(node_vec);
-
-            // Need to make sure life time of observer is greater than Node tree
-            for (auto& i : node_vec) {
-                obs_vec.push_back(new MyObserver(i.get()));
-            }
-
-            // Do some updates
-            std::vector<ecf::Aspect::Type> aspects;
-            for (auto& i : node_vec) {
-                i->notify(aspects);
-                i->notify(aspects);
-            }
-            for (auto& i : obs_vec) {
-                BOOST_CHECK_MESSAGE(i->update_count() == 2, "Expected 2 updates");
-            }
-
-            // delete observers
-            for (auto& i : obs_vec) {
-                delete i;
-            }
-        }
-
-        // make sure no node_ptr are in scope as they can *delay*
-        // the destructor to the end of the scope, and hence affect this test
-        delete theDefs;
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestClientSuiteMgr.cpp 5.13.0-1/ANode/test/TestClientSuiteMgr.cpp
--- 5.12.4-1/ANode/test/TestClientSuiteMgr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestClientSuiteMgr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,139 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/ClientSuiteMgr.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_ClientSuiteMgr)
-
-BOOST_AUTO_TEST_CASE(test_client_suite_mgr_remove_user) {
-    cout << "ANode:: ...test_client_suite_mgr_remove_user\n";
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_client_suite_mgr_remove_user");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-    }
-
-    std::vector<std::string> suites  = {"s1", "s2", "s3"};
-    std::vector<std::string> suites1 = {"s1", "s2", "s3", "s4"};
-    std::vector<std::string> names;
-
-    ClientSuiteMgr mgr(&theDefs);
-
-    unsigned int handle = mgr.create_client_suite(true, suites, "avi");
-    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle), "Expected valid handle");
-    BOOST_CHECK_MESSAGE(handle == 1, "Expected handle 1 but found " << handle);
-    mgr.suites(handle, names);
-    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected");
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
-                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
-
-    names.clear();
-    handle = mgr.create_client_suite(true, suites1, "avi");
-    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle), "Expected valid handle");
-    BOOST_CHECK_MESSAGE(handle == 2, "Expected handle 2 but found " << handle);
-    mgr.suites(handle, names);
-    BOOST_CHECK_MESSAGE(names == suites1, "suite not as expected for handle_fred");
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 2,
-                        "Expected client suite of size 2 but found " << mgr.clientSuites().size());
-
-    names.clear();
-    handle = mgr.create_client_suite(true, suites, "fred");
-    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle), "Expected valid handle");
-    BOOST_CHECK_MESSAGE(handle == 3, "Expected handle 3 but found " << handle);
-    mgr.suites(handle, names);
-    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected for handle_fred");
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 3,
-                        "Expected client suite of size 3 but found " << mgr.clientSuites().size());
-
-    mgr.remove_client_suites("avi"); // should remove two handles
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
-                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
-    BOOST_CHECK_THROW(mgr.remove_client_suites("avi"), std::runtime_error);
-
-    mgr.remove_client_suites("fred");
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 0,
-                        "Expected client suite of size 0 but found " << mgr.clientSuites().size());
-    BOOST_CHECK_THROW(mgr.remove_client_suites("fred"), std::runtime_error);
-}
-
-BOOST_AUTO_TEST_CASE(test_client_suite_mgr_remove_handle) {
-    cout << "ANode:: ...test_client_suite_mgr_remove_handle\n";
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_client_suite_mgr_remove_handle");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-    }
-
-    std::vector<std::string> suites  = {"s1", "s2", "s3"};
-    std::vector<std::string> suites1 = {"s1", "s2", "s3", "s4"};
-    std::vector<std::string> names;
-
-    ClientSuiteMgr mgr(&theDefs);
-
-    unsigned int handle1 = mgr.create_client_suite(true, suites, "avi");
-    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle1), "Expected valid handle");
-    BOOST_CHECK_MESSAGE(handle1 == 1, "Expected handle 1 but found " << handle1);
-    mgr.suites(handle1, names);
-    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected");
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
-                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
-
-    names.clear();
-    unsigned int handle2 = mgr.create_client_suite(true, suites1, "avi");
-    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle2), "Expected valid handle");
-    BOOST_CHECK_MESSAGE(handle2 == 2, "Expected handle 2 but found " << handle2);
-    mgr.suites(handle2, names);
-    BOOST_CHECK_MESSAGE(names == suites1, "suite not as expected for handle_fred");
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 2,
-                        "Expected client suite of size 2 but found " << mgr.clientSuites().size());
-
-    names.clear();
-    unsigned int handle3 = mgr.create_client_suite(true, suites, "fred");
-    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle3), "Expected valid handle");
-    BOOST_CHECK_MESSAGE(handle3 == 3, "Expected handle 3 but found " << handle3);
-    mgr.suites(handle3, names);
-    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected for handle_fred");
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 3,
-                        "Expected client suite of size 3 but found " << mgr.clientSuites().size());
-
-    mgr.remove_client_suite(handle1);
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 2,
-                        "Expected client suite of size 2 but found " << mgr.clientSuites().size());
-    BOOST_CHECK_THROW(mgr.remove_client_suite(handle1), std::runtime_error);
-
-    mgr.remove_client_suite(handle2);
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
-                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
-    BOOST_CHECK_THROW(mgr.remove_client_suite(handle2), std::runtime_error);
-
-    mgr.remove_client_suite(handle3);
-    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 0,
-                        "Expected client suite of size 0 but found " << mgr.clientSuites().size());
-    BOOST_CHECK_THROW(mgr.remove_client_suite(handle3), std::runtime_error);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestCopyConstructor.cpp 5.13.0-1/ANode/test/TestCopyConstructor.cpp
--- 5.12.4-1/ANode/test/TestCopyConstructor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestCopyConstructor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "ecflow/core/Ecf.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_CopyConstructor)
-
-BOOST_AUTO_TEST_CASE(test_copy_constructors) {
-    cout << "ANode:: ...test_copy_constructors\n";
-    MyDefsFixture theDefsFixture;
-
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    Defs copy = Defs(theDefsFixture.defsfile_);
-    BOOST_CHECK_MESSAGE(copy == theDefsFixture.defsfile_, "copy constructor failed");
-}
-
-BOOST_AUTO_TEST_CASE(test_default_constructors) {
-    cout << "ANode:: ...test_default_constructors \n";
-
-    Task t;
-    BOOST_CHECK_MESSAGE(t.check_defaults(), "constructor test for defaults failed");
-
-    Task t2("fred");
-    BOOST_CHECK_MESSAGE(t2.check_defaults(), "constructor test for defaults failed");
-
-    Suite s;
-    BOOST_CHECK_MESSAGE(s.check_defaults(), "constructor test for defaults failed");
-
-    Suite s2("fred");
-    BOOST_CHECK_MESSAGE(s2.check_defaults(), "constructor test for defaults failed");
-
-    Family f;
-    BOOST_CHECK_MESSAGE(f.check_defaults(), "constructor test for defaults failed");
-
-    Family f2("fred");
-    BOOST_CHECK_MESSAGE(f2.check_defaults(), "constructor test for defaults failed");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestDefStatus.cpp 5.13.0-1/ANode/test/TestDefStatus.cpp
--- 5.12.4-1/ANode/test/TestDefStatus.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestDefStatus.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,178 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_DefsStatus)
-
-BOOST_AUTO_TEST_CASE(test_defstatus) {
-    cout << "ANode:: ...test_defstatus\n";
-
-    // Create a defs file corresponding to:
-    // suite suite1
-    //	family f1
-    //   	task t1
-    //   	task t2
-    //	family f2
-    //   	task t1
-    //   	task t2
-    Defs theDefs;
-    suite_ptr suite = theDefs.add_suite("suite1");
-    family_ptr f1   = suite->add_family("f1");
-    task_ptr t1     = f1->add_task("t1");
-    task_ptr t2     = f1->add_task("t2");
-
-    family_ptr f2  = suite->add_family("f2");
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-
-    // Get all nodes and tasks for ease of test
-    vector<Node*> nodes;
-    vector<Task*> tasks;
-    theDefs.getAllNodes(nodes);
-    theDefs.getAllTasks(tasks);
-
-    BOOST_CHECK_MESSAGE(!suite->begun(), "Expected suite not to be begun ");
-
-    /// It should be noted that once a suite has begun, it stays begun, however for test purposes we had
-    /// added ability to reset the begin state.
-
-    /// Test 1: with no defstatus. All nodes should be set to NState::QUEUED
-    theDefs.beginAll();
-    BOOST_CHECK_MESSAGE(suite->begun(), "Expected suite to be begun ");
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
-    }
-
-    theDefs.requeue();
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
-    }
-
-    /// Test 2: with defstatus on suite. With complete the status should have been propagated down
-    suite->addDefStatus(DState::COMPLETE);
-    theDefs.reset_begin(); // for test purposes only
-    BOOST_CHECK_MESSAGE(!suite->begun(), "Expected suite not to be begun ");
-
-    theDefs.beginAll();
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
-                            "Expected complete but found " << NState::toString(n->state()));
-    }
-
-    theDefs.requeue();
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
-                            "Expected complete but found " << NState::toString(n->state()));
-    }
-
-    /// Test 3: defstatus of family f1 and f2. The parent node(suite) should reflect status of children
-    /// Also setting defstatus complete on a family should have propagated it downwards to tasks
-    suite->addDefStatus(DState::default_state()); // reset defstatus
-    f1->addDefStatus(DState::COMPLETE);
-    f2->addDefStatus(DState::COMPLETE);
-    theDefs.reset_begin(); // for test purposes only
-    theDefs.beginAll();
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
-                            "Expected complete but found " << NState::toString(n->state()));
-    }
-
-    theDefs.requeue();
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
-                            "Expected complete but found " << NState::toString(n->state()));
-    }
-
-    // Suspend is really a user interaction the real state suould be queued
-    f1->addDefStatus(DState::default_state()); // reset defstatus
-    f2->addDefStatus(DState::default_state()); // reset defstatus
-    suite->addDefStatus(DState::SUSPENDED);    // reset defstatus
-    theDefs.reset_begin();                     // for test purposes only
-    theDefs.beginAll();
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
-    }
-
-    theDefs.requeue();
-    for (Node* n : nodes) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_139) {
-    cout << "ANode:: ...test_ECFLOW_139\n";
-
-    // Create a defs file corresponding to:
-    // suite suite1
-    // family f1
-    //    task t1; defstatus suspended
-    //    task t2; defstatus suspended
-    // family f2
-    //    task t1; defstatus suspended
-    //    task t2; defstatus suspended
-    Defs theDefs;
-    suite_ptr suite = theDefs.add_suite("suite1");
-    family_ptr f1   = suite->add_family("f1");
-    task_ptr t1     = f1->add_task("t1");
-    task_ptr t2     = f1->add_task("t2");
-    t1->addDefStatus(DState::SUSPENDED);
-    t2->addDefStatus(DState::SUSPENDED);
-
-    family_ptr f2  = suite->add_family("f2");
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-    f2_t1->addDefStatus(DState::SUSPENDED);
-    f2_t2->addDefStatus(DState::SUSPENDED);
-
-    // Get all nodes and tasks for ease of test
-    vector<Task*> tasks;
-    theDefs.getAllTasks(tasks);
-
-    /// It should be noted that once a suite has begun, it stays begun, however for test purposes we had
-    /// added ability to reset the begin state.
-
-    /// Test 1: Check NODE state All nodes should be set to NState::QUEUED
-    theDefs.beginAll();
-    for (Task* n : tasks) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
-    }
-
-    /// Check: DSTATE
-    for (Task* n : tasks) {
-        BOOST_CHECK_MESSAGE(n->dstate() == DState::SUSPENDED,
-                            "Expected suspended but found " << DState::toString(n->dstate()));
-    }
-
-    theDefs.requeue();
-    for (Task* n : tasks) {
-        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
-    }
-    for (Task* n : tasks) {
-        BOOST_CHECK_MESSAGE(n->dstate() == DState::SUSPENDED,
-                            "Expected suspended but found " << DState::toString(n->dstate()));
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestDefs.cpp 5.13.0-1/ANode/test/TestDefs.cpp
--- 5.12.4-1/ANode/test/TestDefs.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestDefs.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,104 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Defs)
-
-BOOST_AUTO_TEST_CASE(test_defs_absorb) {
-    cout << "ANode:: ...test_defs_absorb\n";
-
-    // Create a defs file corresponding to:
-    // suite suite1
-    //  family family
-    //   	task t1
-    //  endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-    }
-    // Then ABSORB a new def
-    // suite suite1-n
-    //   family family
-    //   		task suite1_task1
-    //   endfamily
-    // endsuite
-    Defs otherDefs;
-    {
-        for (int i = 0; i < 14; ++i) {
-            suite_ptr suite1 = otherDefs.add_suite("suite" + ecf::convert_to<std::string>(i));
-            family_ptr fam   = suite1->add_family("family");
-            fam->add_task("suite1_task1");
-        }
-    }
-
-    theDefs.absorb(&otherDefs, true);
-    BOOST_CHECK_MESSAGE(otherDefs.suiteVec().empty(), "absorb failed");
-}
-
-BOOST_AUTO_TEST_CASE(test_defs_absorb_server_user_variables) {
-    cout << "ANode:: ...test_defs_absorb_server_user_variables\n";
-
-    Defs theDefs;
-    Defs otherDefs;
-    {
-        otherDefs.set_server().add_or_update_user_variables("VAR1", "VAL");
-        otherDefs.set_server().add_or_update_user_variables("VAR2", "VAL");
-        otherDefs.set_server().add_or_update_user_variables("VAR3", "VAL");
-        otherDefs.add_suite("suite");
-    }
-
-    BOOST_CHECK_MESSAGE(theDefs.server().user_variables().empty(), "Expected no server user variables");
-
-    theDefs.absorb(&otherDefs, true);
-
-    BOOST_CHECK_MESSAGE(otherDefs.suiteVec().empty(), "absorb failed");
-    BOOST_CHECK_MESSAGE(theDefs.suiteVec().size() == 1, "absorb failed");
-    BOOST_CHECK_MESSAGE(theDefs.server().user_variables().size() == 3, "Expected 3 server user variables");
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_1684) {
-    cout << "ANode:: ...test_ECFLOW_1684\n";
-
-    Defs defs;
-    defs.add_edit_history("/", "request");
-    defs.add_edit_history("/a/made/up/path1", "request");
-    defs.add_edit_history("/a/made/up/path1", "request2");
-    defs.add_edit_history("/a/made/up/path2", "request2");
-    defs.add_edit_history("/a/made/up/path3", "request2");
-
-    BOOST_CHECK_MESSAGE(defs.get_edit_history().size() == 4,
-                        "Expected edit history of size 4 but found " << defs.get_edit_history().size());
-
-    // This should remove all edit history, where the history paths do not exist as nodes in a defs, BUT need to leave
-    // ROOT as is though.
-    defs.handle_migration();
-    BOOST_CHECK_MESSAGE(defs.get_edit_history().size() == 1,
-                        "Expected edit history of size 1 but found " << defs.get_edit_history().size());
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestEcfFile.cpp 5.13.0-1/ANode/test/TestEcfFile.cpp
--- 5.12.4-1/ANode/test/TestEcfFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestEcfFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1697 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib> // for getenv
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Pid.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/EcfFile.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_EcfFile)
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_with_bad_ECF_MICRO) {
-    cout << "ANode:: ...test_ecf_file_with_bad_ECF_MICRO\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  task t1
-    //     ECF_MICRO ""   # cannot be empty if overridden
-    //  task t2
-    //     ECF_MICRO "ss" # must be a single char
-    // endsuite
-
-    task_ptr task_t1;
-    task_ptr task_t2;
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        task_t1         = suite->add_task("t1");
-        task_t1->add_variable("ECF_MICRO", "");
-        task_t2 = suite->add_task("t2");
-        task_t2->add_variable("ECF_MICRO", "ss");
-    }
-
-    // Check we throw for bad ECF_MICRO chars
-    std::string ecf_file_location;
-    BOOST_REQUIRE_THROW(EcfFile ecfFile(task_t1.get(), ecf_file_location), std::runtime_error);
-    BOOST_REQUIRE_THROW(EcfFile ecfFile(task_t2.get(), ecf_file_location), std::runtime_error);
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_simple_include_file) {
-    // The specific files are specified in ECF_INCLUDE and common files
-    // are specified in ECF_HOME. This test will ensure that if the file common.h
-    // is not found in ECF_INCLUDE we then look at ECF_HOME
-    cout << "ANode:: ...test_ecf_simple_include_file";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_simple_include_file"));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string header   = "%include <simple_head.h>\n";
-    string body     = "#body\n";
-    string tail     = "%include <simple_tail.h>\n";
-    string ecf_file = header;
-    ecf_file += body;
-    ecf_file += tail;
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Check generation of '.usr' and job files
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-    // Open the job file/
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-
-    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-    BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
-                        "Expected\n"
-                            << expected_job_file_contents << "' but found \n"
-                            << job_file_contents << "'");
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_495) {
-    // This tests for a regression where, *NOT* all the include file were processed.
-    cout << "ANode:: ...test_ECFLOW_495";
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-    Defs theDefs;
-    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_ECFLOW_495"));
-    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-    task_ptr task_t1 = suite->add_task("t1");
-
-    // PrintStyle style(PrintStyle::STATE);
-    // std::cout << theDefs << "\n";
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    // Create the ecf file; *NOTE* <a.h> includes <b.h>
-    string ecf_file = "%include <a.h>\n";
-    ecf_file += "%PAR_EXE:parallel% --gnu --verbose -j $PAR_THR ${run:-0} ::: $(seq %PAR_BEG:0% %PAR_END:50%)\n";
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-    // Open the job file and check job file contents match what we expected
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-
-    std::string expected_job_file_contents =
-        "#a.h\n#b.h\nparallel --gnu --verbose -j $PAR_THR ${run:-0} ::: $(seq 0 50)";
-    BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
-                        "Expected\n'" << expected_job_file_contents << "' but found \n'" << job_file_contents << "'");
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ECF_SCRIPT_CMD_ECFLOW_427) {
-    cout << "ANode:: ...test_ECF_SCRIPT_CMD_ECFLOW_427";
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name("test_ECF_SCRIPT_CMD_ECFLOW_427"));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("body", "body"));
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string header = "%include <simple_head.h>\n";
-    string body   = "#%body%\n";
-    body += "%manual\nThis is a manual\n%end\n";
-    body += "%comment\nThis is a comment\n%end\n";
-    string tail     = "%include <simple_tail.h>\n";
-    string ecf_file = header;
-    ecf_file += body;
-    ecf_file += tail;
-
-    std::string cmd = "cat %ECF_HOME%/%ECF_NAME%.ecf";
-    task_t1->add_variable("ECF_SCRIPT_CMD", cmd);
-
-    /// Now finally the test, use this as this will perform variable expansion on ECF_SCRIPT_CMD
-    EcfFile ecfFile = task_t1->locatedEcfFile();
-
-    // *******************************************************************************************************
-    // CREATE the file after locatedEcfFile() otherwise it will just use script as is, and NOT ECF_SCRIPT_CMD
-    // *******************************************************************************************************
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    /// Check generation of job files
-    JobsParam jobsParam(true); // spawn_jobs = false
-    {
-        task_t1->update_generated_variables();
-
-        try {
-            ecfFile.create_job(jobsParam);
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-        }
-
-        string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-        BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-        // Open the job file and check contents
-        std::string job_file_contents;
-        BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                            "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-        std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-        BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
-                            "Expected\n'" << expected_job_file_contents << "' but found:\n'" << job_file_contents
-                                          << "'");
-    }
-
-    /// Check pre-processing arbitrary file, should return same result as task pre-processing for job generation
-    {
-        task_t1->update_generated_variables();
-
-        string ecf_file_location = ecf_home + task_t1->absNodePath() + ".ecf";
-        std::vector<std::string> user_edit_file;
-        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(ecf_file_location, user_edit_file),
-                            "Could not open file " << ecf_file_location);
-
-        string processed_file;
-        try {
-            ecfFile.pre_process_user_file(user_edit_file, processed_file);
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Expected pre-processing succeed " << e.what());
-        }
-
-        // because we have read file, as a vector of lines, expect extra \n at the end
-        std::string expected_job_file_contents = "#head.h\n#body\n#tail.h\n";
-        BOOST_CHECK_MESSAGE(processed_file == expected_job_file_contents,
-                            "Expected\n'" << expected_job_file_contents << "' but found:\n'" << processed_file << "'");
-    }
-
-    /// Check manual extraction
-    {
-        std::string manual;
-        try {
-            ecfFile.manual(manual);
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Expected manual extraction to succeed " << e.what());
-        }
-
-        std::string expected_manual = "This is a manual\n";
-        BOOST_CHECK_MESSAGE(manual == expected_manual,
-                            "Expected:\n'" << expected_manual << "' but found:\n'" << manual << "'");
-    }
-
-    /// Check script
-    {
-        std::string script;
-        try {
-            ecfFile.script(script);
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Expected script extraction to succeed " << e.what());
-        }
-        string the_ecf_file = ecfFile.ecf_file_origin_dump() + "\n" + ecf_file;
-        BOOST_CHECK_MESSAGE(script == the_ecf_file,
-                            "Expected:\n'" << the_ecf_file << "' but found:\n'" << script << "'");
-    }
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_include_file) {
-    // The specific files are specified in ECF_INCLUDE and common files
-    // are specified in ECF_HOME. This test will ensure that if the file common.h
-    // is not found in ECF_INCLUDE we then look at ECF_HOME
-    cout << "ANode:: ...test_ecf_include_file";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    // edit SLEEPTIME 10
-    // edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_include_file"));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("SLEEPTIME", "1"));
-        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string header   = "%include <head.h>\n\n";
-    string body     = "%include <common.h>\n\n";
-    string tail     = "%include <tail.h>\n# ===================================";
-    string ecf_file = header;
-    ecf_file += body;
-    ecf_file += tail;
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Check generation of '.usr' and job files
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-    // Open the job file/
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_include_multi_paths_ECFLOW_261) {
-    // The specific files are specified in ECF_INCLUDE with multiple paths
-    cout << "ANode:: ...test_ecf_include_multi_paths_ECFLOW_261";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    // edit ECF_INCLUDE "$ECF_HOME/empty_include1:$ECF_HOME/empty_include2:$ECF_HOME/includes:$ECF_HOME/includes2"
-    //    task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_include_multi_paths_ECFLOW_261"));
-    Defs theDefs;
-    {
-        suite->addVariable(
-            Variable(Str::ECF_INCLUDE(),
-                     "$ECF_HOME/empty_include1:$ECF_HOME/empty_include2:$ECF_HOME/includes:$ECF_HOME/includes2"));
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string header   = "%include <head.h>\n\n";
-    string body     = "%include <fred.h>\n\n"; // this is only defined in ANode/test/data/includes2
-    string tail     = "%include <tail.h>\n# ===================================";
-    string ecf_file = header;
-    ecf_file += body;
-    ecf_file += tail;
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Check generation of job files
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-    // Open the job file
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_include_ECFLOW_274) {
-    // Test .ecf scripts with includes like %include "../bill.h"
-    // In this case we expect to find bill.h in the same directory as the script
-    cout << "ANode:: ...test_ecf_include_ECFLOW_274";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    // edit ECF_INCLUDE "$ECF_HOME/includes"
-    //    task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_include_ECFLOW_274"));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string header   = "%include <head.h>\n\n";
-    string body     = "%include \"./t1.h\"\n\n";
-    string tail     = "%include <tail.h>\n# ===================================";
-    string ecf_file = header;
-    ecf_file += body;
-    ecf_file += tail;
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    //   cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // generate bill.h
-    string header_file          = "# in t1.h";
-    string header_file_location = ecf_home + task_t1->absNodePath() + ".h";
-    //   cout << "file_location = " << header_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::create(header_file_location, header_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(header_file_location), "Expected File " << header_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Check generation of job files
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-    // Open the job file
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-
-    /// Remove the directories that were generated. This occasionally fails on ecgb and lxg ???
-    try {
-        fs::remove_all(ecf_home + suite->absNodePath());
-    }
-    catch (const fs::filesystem_error& e) {
-        cout << "Could not remove directory " << ecf_home + suite->absNodePath() << " : " << e.what() << "\n";
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_simple_used_variables) {
-    // Test that used variables are as expected
-    // This should PRUNE the generated variables from the used variables list
-    // Additionally it should NOT affect variables like ESUITE but should ignore generated variable SUITE
-    // See File: ANode/test/data/includes/used_variables.h
-    cout << "ANode:: ...test_ecf_simple_used_variables";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1;
-    suite_ptr suite;
-    Defs theDefs;
-    {
-        suite = theDefs.add_suite(Pid::unique_name("test_ecf_simple_used_variables"));
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->add_variable("ESUITE", "suite");
-        task_t1 = suite->add_family("f1")->add_task("t1");
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string ecf_file          = "%include <used_variables.h>\n";
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    string file_with_used_variables;
-    ecfFile.edit_used_variables(file_with_used_variables);
-    string expected_used_variables =
-        "%comment - ecf user variables\nESUITE = suite\n%end - ecf user variables\n%include <used_variables.h>\n";
-    BOOST_CHECK_MESSAGE(file_with_used_variables == expected_used_variables,
-                        "Expected\n"
-                            << expected_used_variables << "\nBut found:\n"
-                            << file_with_used_variables);
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_simple_used_variables_with_comments) {
-    // Test that used variables are as expected
-    // This should PRUNE the generated variables from the used variables list
-    // Additionally it should NOT affect variables like ETASK but should ignore generated variable TASK
-    // See File: ANode/test/data/includes/used_variables_with_comments.h
-    //
-    // This WILL test that when we have user comment and manuals, we can still extract user variables
-    // Those variable defined within comments and manuals that are not defined should be ignored
-    cout << "ANode:: ...test_ecf_simple_used_variables_with_comments";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1;
-    suite_ptr suite;
-    Defs theDefs;
-    {
-        suite = theDefs.add_suite(Pid::unique_name("test_ecf_simple_used_variables_with_comments"));
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->add_variable("ETASK", "suite");
-        suite->add_variable("FRED", "fred");
-        task_t1 = suite->add_family("f1")->add_task("t1");
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string ecf_file          = "%include <used_variables_with_comments.h>\n";
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    string file_with_used_variables;
-    ecfFile.edit_used_variables(file_with_used_variables);
-    string expected_used_variables = "%comment - ecf user variables\nETASK = suite\nFRED = fred\n%end - ecf user "
-                                     "variables\n%include <used_variables_with_comments.h>\n";
-    BOOST_CHECK_MESSAGE(file_with_used_variables == expected_used_variables,
-                        "Expected\n"
-                            << expected_used_variables << "\nBut found:\n"
-                            << file_with_used_variables);
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_simple_used_variables_errors) {
-    // Test that used variables are as expected
-    // This is similar to test_ecf_simple_used_variables_with_comments
-    // BUT we DO NOT define variable FRED, hence we expect failure
-    cout << "ANode:: ...test_ecf_simple_used_variables_errors";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1;
-    suite_ptr suite;
-    Defs theDefs;
-    {
-        suite = theDefs.add_suite(Pid::unique_name("test_ecf_simple_used_variables_errors"));
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->add_variable("ETASK", "suite");
-        task_t1 = suite->add_family("f1")->add_task("t1");
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string ecf_file          = "%include <used_variables_with_comments.h>\n";
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    // Expect a throw since %FRED% is not defined, on the suite, but exists in used_variables_with_comments.h
-    string file_with_used_variables;
-    BOOST_REQUIRE_THROW(ecfFile.edit_used_variables(file_with_used_variables), std::runtime_error);
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file) {
-    cout << "ANode:: ...test_ecf_file";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // # Test the sms file can be found via ECF_SCRIPT
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // #
-    // suite suite
-    //	edit SLEEPTIME 10
-    //	edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    NameValueMap expected_used_variables;
-    expected_used_variables.insert(std::make_pair(string("VAR1"), string("_val1_")));
-    expected_used_variables.insert(std::make_pair(string("VAR2"), string("_val2_")));
-    expected_used_variables.insert(std::make_pair(string("VAR2_fred"), string("<ignored>")));
-
-    // Create a defs file, where the task name mirrors the sms files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_file"));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("SLEEPTIME", "1"));
-        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
-        for (const NameValueMap::value_type& p : expected_used_variables) {
-            task_t1->addVariable(Variable(p.first, p.second));
-        }
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-
-    // Override ECF_HOME.   ECF_HOME is need to locate to the .ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string header      = "%include <head.h>\n\n";
-    string manual_head = "%manual\n";
-    string manual_body = " manual. The contents of the manual\n";
-    manual_body += " end.\n";
-    string manual_tail  = "%end\n\n";
-    string comment_head = "%comment\n";
-    string comment_body = " comment. The contents of the comment\n";
-    comment_body += " end.\n";
-    string comment_tail = "%end\n\n";
-    string ecf_body;
-    {
-        for (std::pair<std::string, std::string> p : expected_used_variables) {
-            ecf_body += Ecf::MICRO() + p.first + Ecf::MICRO() + "\n";
-        }
-        ecf_body += "%VAR3:substitute_var%\n";
-    }
-    string tail = "\n%include <tail.h>\n# ===================================";
-
-    string ecf_file = header;
-    ecf_file += manual_head;
-    ecf_file += manual_body;
-    ecf_file += manual_tail;
-    ecf_file += comment_head;
-    ecf_file += comment_body;
-    ecf_file += comment_tail;
-    ecf_file += ecf_body;
-    ecf_file += tail;
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    //	cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Test manual extraction
-    /// The manual is manual of all the pre-processed includes
-    /// Test: SUP-762 Lines starting with "manually" are not shown in manual
-    std::string expected_manual = "#This is the manual from the head.h file\n manual. The contents of the manual\n "
-                                  "end.\n#This is the manual from the tail.h file\n";
-
-    string theExtractedManual;
-    try {
-        ecfFile.manual(theExtractedManual);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, e.what());
-    }
-    BOOST_CHECK_MESSAGE(theExtractedManual == expected_manual,
-                        "Expected \n'" << expected_manual << "' but found \n'" << theExtractedManual << "'");
-
-    /// Test script extraction
-    string theExtractedScript;
-    try {
-        ecfFile.script(theExtractedScript);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, e.what());
-    }
-    BOOST_CHECK_MESSAGE(theExtractedScript == ecf_file,
-                        "\nExpected\n"
-                            << ecf_file << "\nsize = " << ecf_file.size() << " but found-----------------\n"
-                            << theExtractedScript << "\nsize = " << theExtractedScript.size());
-
-    /// Test User edit script, this should return all the used variables, between %comment -%end
-    string file_with_used_variables;
-    ecfFile.edit_used_variables(file_with_used_variables);
-    //    std::cout << "file_with_used_variables:----------------------------------------------------------------\n" <<
-    //    file_with_used_variables << "\n";
-    BOOST_CHECK_MESSAGE(file_with_used_variables.find("%comment") == 0,
-                        "Expected to find variable %comment on the very first line: but found at: "
-                            << file_with_used_variables.find("%comment"));
-    for (std::pair<std::string, std::string> p : expected_used_variables) {
-        BOOST_CHECK_MESSAGE(file_with_used_variables.find(p.first) != string::npos,
-                            "Expected to find variable" << p.first);
-    }
-
-    /// Test extraction of all the used variables
-    std::vector<string> script_lines;
-    Str::split(file_with_used_variables, script_lines, "\n"); //  will ignore empty lines, but will do for this case
-    NameValueMap extracted_used_variables;
-    EcfFile::extract_used_variables(extracted_used_variables, script_lines);
-    for (std::pair<std::string, std::string> p : expected_used_variables) {
-        BOOST_CHECK_MESSAGE(extracted_used_variables.find(p.first) != extracted_used_variables.end(),
-                            " expected to find variable " << p.first << " in the extracted variables\n");
-    }
-    //    cout << "Expected:----\n"; for(p:expected_used_variables) { cout << p.first << " " << p.second << "\n";}
-    //    cout << "Actual:------\n"; for(p:extracted_used_variables) { cout << p.first << " " << p.second << "\n";}
-
-    /// Test pre-processing
-    string pre_processed_file;
-    ecfFile.pre_process(pre_processed_file);
-    //	cout << "pre_processed_file\n" << pre_processed_file << "\n";
-    BOOST_CHECK_MESSAGE(!pre_processed_file.empty(), "Expected file not to be empty");
-    BOOST_CHECK_MESSAGE(pre_processed_file.find("%include") == string::npos, "Expected all includes to be removed");
-
-    /// Check generation of '.usr' and job files
-    string man_file_location = ecf_home + task_t1->absNodePath() + File::MAN_EXTN();
-    string usr_file_location = ecf_home + task_t1->absNodePath() + File::USR_EXTN();
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    JobsParam jobsParam(true); // spawn_jobs = false
-    jobsParam.set_user_edit_variables(extracted_used_variables);
-    jobsParam.set_user_edit_file(script_lines);
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-    BOOST_CHECK_MESSAGE(fs::exists(usr_file_location), "Expected File " << usr_file_location << " to exist");
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-    // Open the job file/
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-
-    // Test the contents of the job file.
-    //    cout << "\n" << job_file_contents << "\n";
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PORT%") == string::npos, "Expected variables to be substituted:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_HOST%") == string::npos, "Expected variables to be substituted:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_NAME%") == string::npos, "Expected variables to be substituted:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PASS%") == string::npos, "Expected variables to be substituted");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_TRYNO%") == string::npos, "Expected variables to be substituted");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%include") == string::npos, "Expected all includes to be expanded");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%manual") == string::npos, "%manual should have been removed");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%comment") == string::npos, "%comment should have been removed:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%end") == string::npos, "%end should have been removed:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ecfmicro") == string::npos, "%ecfmicro should have been removed:");
-
-    /// Remove all the generated files
-    fs::remove(man_file_location);
-    fs::remove(ecf_file_location);
-    fs::remove(usr_file_location);
-    fs::remove(job_file_location);
-    fs::remove(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_includenoop) {
-    cout << "ANode:: ...test_ecf_file_includenopp";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // This test is used to check that %includenopp are expanded only.
-    // There should be NO variable substitution, or removal of comments/manual
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_file_includenoop"));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("SLEEPTIME", "1"));
-        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-    // cout << theDefs << "\n";
-
-    // Override ECF_HOME. ECF_HOME is need to locate to the .ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string header   = "%includenopp <head.h>\n";
-    string tail     = "%includenopp <tail.h>";
-    string ecf_file = header;
-    ecf_file += tail;
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location),
-                        "Could not create missing dir " << ecf_file_location << "\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables. Then EcfFile
-    task_t1->update_generated_variables();
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Check generation of job files
-    string man_file_location = ecf_home + task_t1->absNodePath() + File::MAN_EXTN();
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-
-    // Open the job file and check the contents
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected job File " << job_file_location << " to exist");
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-
-    // Test the contents of the job file. We expect includenopp to be expanded
-    // The contents should be left as is: i.e no pre_processing,hence expect to find %manual %comment, %VARIABLES%
-    // cout << "\n" << job_file_contents << "\n";
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%includenopp") == string::npos, "Expected all includes to be removed");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PORT%") != string::npos, "Expected variables as is:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_HOST%") != string::npos, "Expected variables as is:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_NAME%") != string::npos, "Expected variables as is:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PASS%") != string::npos, "Expected variables as is:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_TRYNO%") != string::npos, "Expected variables as is:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%manual") != string::npos,
-                        "%manual should exist inside %nopp/%end pair:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%comment") != string::npos,
-                        "%comment should exist inside %nopp/%end pair:");
-    BOOST_CHECK_MESSAGE(job_file_contents.find("%end") != string::npos,
-                        "%end associated with comment and manual should exist:");
-
-    // Remove all the generated files
-    fs::remove(ecf_file_location);
-    fs::remove(man_file_location);
-    fs::remove(job_file_location);
-    fs::remove(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_override_ECF_JOB) {
-    cout << "ANode:: ...test_ecf_file_override_ECF_JOB";
-
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // This test is used to check that when user has added a variable ECF_JOB
-    // to specify the location of the job file, we use that, in preference
-    // to generated ECF_JOB for the location of the job file.
-    // Note: The directories to the job file should be created by EcfFile
-
-    // SET ECF_HOME
-    std::string ecf_home          = File::test_data("ANode/test/data", "ANode");
-    std::string job_file_location = ecf_home + "/a/made/up/path/t1.job";
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    task_t1->addVariable(Variable("ECF_JOB", job_file_location));
-    suite_ptr suite = Suite::create(Pid::unique_name("test_ecf_file_override_ECF_JOB"));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("SLEEPTIME", "1"));
-        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-    // cout << theDefs << "\n";
-
-    // Override ECF_HOME. ECF_HOME is need to locate to the .ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    // generate the dummy ecf file;
-    string header   = "%include <head.h>\n";
-    string tail     = "%include <tail.h>";
-    string ecf_file = header;
-    ecf_file += "# ";
-    ecf_file += tail;
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location),
-                        "Could not create missing dir " << ecf_file_location << "\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables. Then EcfFile
-    task_t1->update_generated_variables();
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Check generation of job files
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-
-    // Open the job file and check the contents
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected job File " << job_file_location << " to exist");
-    std::string job_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-    BOOST_CHECK_MESSAGE(!job_file_contents.empty(), "Job should not be empty");
-
-    // Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-    fs::remove_all(ecf_home + "/a");
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_manual_files) {
-    // The specific files are specified in ECF_INCLUDE and common files are specified in ECF_HOME.
-    cout << "ANode:: ...test_manual_files\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data/SMSHOME", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    // edit SLEEPTIME 10
-    // edit ECF_INCLUDE $ECF_HOME/includes
-    //  family
-    //     task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    Defs theDefs;
-    suite_ptr suite = theDefs.add_suite("suite"); // ** relies on name of suite, in SMSHOME/suite
-    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/../includes"));
-    family_ptr family = suite->add_family("family");
-    task_ptr task_t1  = family->add_task("t1");
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    // PrintStyle style(PrintStyle::STATE);
-    // std::cout << theDefs << "\n";
-
-    /// Now finally the test
-
-    // Task
-    {
-        std::string manual;
-        EcfFile ecf_file = task_t1->locatedEcfFile(); // will throw std::runtime_error for errors
-        ecf_file.manual(manual);                      // will throw std::runtime_error for errors
-        BOOST_REQUIRE_MESSAGE(!manual.empty(), "Manual not found");
-        BOOST_CHECK_MESSAGE(manual.find("ECF_MICRO=%") != std::string::npos,
-                            "Variable pre-processing failed during manual extraction");
-        BOOST_CHECK_MESSAGE(manual.find("manual-1") != std::string::npos,
-                            "Pre-processing of ecfmicro in manuals failed, expected to find string 'manual-1'\n"
-                                << manual);
-        BOOST_CHECK_MESSAGE(manual.find("end-1") != std::string::npos,
-                            "Pre-processing of ecfmicro in manuals failed, expected to find string 'end-1'\n"
-                                << manual);
-        BOOST_CHECK_MESSAGE(manual.find("Test manual files are pre-processed") != std::string::npos,
-                            "%include <manual.h> pre-processing failed inside manual->end\n"
-                                << manual);
-    }
-
-    {
-        // Family, Check the suite manuals are pre-processed. i.e %includes are expanded
-        // When the node container manual(family or suite) '.man' file, has content but *NO* %manual->%end directives
-        // Just pre-process and return file as is. Since the whole file is a manual.
-        std::string man_file = ecf_home + family->absNodePath() + File::MAN_EXTN();
-        EcfFile ecf_file(family.get(), man_file);
-
-        std::string manual;
-        ecf_file.manual(manual);
-        // cout << manual << "\n";
-        BOOST_CHECK_MESSAGE(!manual.empty(), "Manual not found");
-        BOOST_CHECK_MESSAGE(manual.find("Test manual files are pre-processed") != std::string::npos,
-                            "Pre-processing in manual failed");
-        BOOST_CHECK_MESSAGE(manual.find("Special case where there are no manual directives") != std::string::npos,
-                            "family manual extraction failed");
-    }
-
-    {
-        // Suite, Check the suite manuals are pre-processed. i.e %includes are expanded
-        std::string man_file = ecf_home + suite->absNodePath() + File::MAN_EXTN();
-        EcfFile ecf_file(suite.get(), man_file);
-
-        std::string manual;
-        ecf_file.manual(manual);
-        // cout << manual << "\n";
-        BOOST_CHECK_MESSAGE(!manual.empty(), "Manual not found");
-        BOOST_CHECK_MESSAGE(manual.find("Test manual files are pre-processed") != std::string::npos,
-                            "Pre-processing in manual failed");
-        BOOST_CHECK_MESSAGE(manual.find("suite manual") != std::string::npos, "Suite manual extraction failed");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_672) {
-    // test for recursive includes that are not recursive
-    cout << "ANode:: ...test_ECFLOW_672";
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // Create the defs file corresponding to the text below
-    // suite ECFLOW_672
-    //  edit ECF_INCLUDE $ECF_HOME/ECFLOW_672
-    //  task t
-    // endsuite
-    Defs theDefs;
-    suite_ptr suite = theDefs.add_suite("ECFLOW_672");
-    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/ECFLOW_672"));
-    task_ptr task_t1 = suite->add_task("t");
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    JobsParam jobsParam(true); // spawn_jobs = false
-    try {
-        ecfFile.create_job(jobsParam);
-    }
-    catch (std::exception& e) {
-        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-    }
-
-    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-    /// Remove generate file
-    fs::remove(job_file_location);
-}
-
-static void basic_test_template(const std::string& test_name,
-                                const std::string& ecf_file1,
-                                const std::string& expected_job_file_contents,
-                                const std::string& ecf_micro = "",
-                                bool expect_success          = true) {
-    cout << "ANode:: ..." << test_name;
-    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
-    if (getenv("ECFLOW_CRAY_BATCH")) {
-        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
-        return;
-    }
-    cout << "\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  task t1
-    // endsuite
-
-    // Create a defs file, where the task name mirrors the ecf files in the given directory
-    task_ptr task_t1 = Task::create("t1");
-    suite_ptr suite  = Suite::create(Pid::unique_name(test_name));
-    Defs theDefs;
-    {
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->add_variable("simple", "simple");
-        suite->add_variable("tail", "tail");
-        if (!ecf_micro.empty())
-            suite->add_variable("ECF_MICRO", ecf_micro);
-        suite->addTask(task_t1);
-        theDefs.addSuite(suite);
-    }
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    std::string ecf_home = File::test_data("ANode/test/data", "ANode");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // generate the ecf file;
-    string ecf_file          = ecf_file1;
-    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
-    // cout << "file_location = " << ecf_file_location << "\n";
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-
-    // Create the generated variables
-    task_t1->update_generated_variables();
-
-    /// Now finally the test
-    EcfFile ecfFile(task_t1.get(), ecf_file_location);
-
-    /// Check generation of '.usr' and job files
-    JobsParam jobsParam(true); // spawn_jobs = false
-    if (expect_success) {
-        std::string file_with_used_variables;
-        try {
-            ecfFile.edit_used_variables(file_with_used_variables);
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Expected edit_used_variables to succeed " << e.what());
-        }
-
-        try {
-            ecfFile.create_job(jobsParam);
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
-        }
-
-        string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
-        BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
-
-        // Open the job file, make sure it matches our expected file
-        std::string job_file_contents;
-        BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
-                            "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
-        BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
-                            "Expected\n"
-                                << expected_job_file_contents << "' but found \n"
-                                << job_file_contents << "'");
-    }
-    else {
-        BOOST_REQUIRE_THROW(ecfFile.create_job(jobsParam), std::runtime_error);
-    }
-
-    /// Remove all the generated files
-    fs::remove_all(ecf_home + suite->absNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_includeonce) {
-    // simplest test of include once, no hierarchy
-    // generate the ecf file;
-    string ecf_file = "%includeonce <simple_head.h>\n";
-    ecf_file += "%includeonce <simple_head.h>\n";
-    ecf_file += "%include <simple_head.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "%includeonce <simple_tail.h>\n";
-    ecf_file += "%include <simple_tail.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#head.h\n#body\n#tail.h\n#tail.h";
-
-    basic_test_template("test_includeonce", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_includeonce_hierarchical) {
-    // Test the pre-processing is done depth first, ( < 4.1.1 it was done breadth first)
-    // generate the ecf file;
-    string ecf_file = "%includeonce <AA.h>\n";
-    ecf_file += "%includeonce <BB.h>\n";
-    ecf_file += "%includeonce <CC.h>\n";
-
-    std::string expected_job_file_contents = "#startAA\n#startBB\n#CC\n#endBB\n#endAA";
-
-    basic_test_template("test_includeonce_hierarchical", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_include_with_variables) {
-    // Test includes with variables %include <%head%.h> ECFLOW-765
-
-    string ecf_file;
-    ecf_file += "%include <%simple%_head.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "%include <simple_%tail%.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-
-    basic_test_template("test_include_with_variables", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_include_with_variable_alternative) {
-    string ecf_file;
-    ecf_file += "%include %FRED:<simple_head.h>%\n";
-    ecf_file += "#body\n";
-    ecf_file += "%include %TAIL:<simple_tail.h>%\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-
-    basic_test_template("test_include_with_variable_alternative", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_include_with_variables_change_micro) {
-    string ecf_file;
-    ecf_file += "%ecfmicro &\n"; // ecf_micro in script OVERRIDES ECF_MICRO variable, but *only* in script
-    ecf_file += "&include <&simple&_head.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "&ecfmicro *\n";
-    ecf_file += "*include <simple_*tail*.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-
-    basic_test_template("test_include_with_variables_change_micro", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_script_override_ecf_micro) {
-    string ecf_file;             // ecf_micro in script OVERRIDES ECF_MICRO variable, but *only* in script
-    ecf_file += "$simple$\n";    // ECF_MICRO is set to $
-    ecf_file += "$ecfmicro &\n"; // ecfmicro change from $ -> &
-    ecf_file += "&include <&simple&_head.h>\n";
-    ecf_file += "#body$fred&simple&\n";
-    ecf_file += "&ecfmicro *\n"; // ecfmicro change from & -> *
-    ecf_file += "*include <simple_*tail*.h>\n";
-
-    std::string expected_job_file_contents = "simple\n#head.h\n#body$fredsimple\n#tail.h";
-
-    basic_test_template("test_script_override_ecf_micro", ecf_file, expected_job_file_contents, "$");
-}
-
-BOOST_AUTO_TEST_CASE(test_mistyped_ecf_micro) {
-    // same test as above, but we have mistyped ecf_micro. Make sure we don't ignore this.
-    string ecf_file;
-    ecf_file += "$simple$\n";
-    ecf_file += "$ecf_micro &\n"; // ecfmicro has been mistyped
-    ecf_file += "&include <&simple&_head.h>\n";
-    ecf_file += "#body$fred&simple&\n";
-    ecf_file += "&ecf_micro *\n";
-    ecf_file += "*include <simple_*tail*.h>\n";
-
-    std::string expected_job_file_contents = "simple\n#head.h\n#body$fredsimple\n#tail.h";
-
-    basic_test_template("test_mistyped_ecf_micro", ecf_file, expected_job_file_contents, "$", false);
-}
-
-BOOST_AUTO_TEST_CASE(test_include_with_variables_mismatched_micros) {
-    // generate the ecf file, where include file has missmatched ecf_micro
-    string ecf_file;
-    ecf_file += "%include <%simple%_head%.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "%include <simple_%tail%.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-
-    basic_test_template("test_include_with_variables_mismatched_micros",
-                        ecf_file,
-                        expected_job_file_contents,
-                        "" /*ecf_micro*/,
-                        false /*expect failure*/);
-}
-
-BOOST_AUTO_TEST_CASE(test_include_with_variable_not_defined) {
-    string ecf_file;
-    ecf_file += "%include %simple_head.h%\n";
-    ecf_file += "#body\n";
-    ecf_file += "%include <simple_%tail%.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-
-    basic_test_template("test_include_with_variable_not_defined",
-                        ecf_file,
-                        expected_job_file_contents,
-                        "" /*ecf_micro*/,
-                        false /*expect failure*/);
-}
-
-BOOST_AUTO_TEST_CASE(test_nopp_preserves_contents) {
-    string ecf_file;
-    ecf_file += "%include <simple_head.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "%nopp\n";
-    ecf_file += "%comment\n";
-    ecf_file += "--comment\n";
-    ecf_file += "%end\n";
-    ecf_file += "%manual\n";
-    ecf_file += "--manual\n";
-    ecf_file += "%end\n";
-    ecf_file += "%end\n";
-    ecf_file += "%include <simple_tail.h>\n";
-
-    std::string expected_job_file_contents =
-        "#head.h\n#body\n%comment\n--comment\n%end\n%manual\n--manual\n%end\n#tail.h";
-
-    basic_test_template("test_nopp_preserves_contents", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_nopp_preserves_contents2) {
-    string ecf_file;
-    ecf_file += "%include <simple_head.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "%nopp\n";
-    ecf_file += "%ecfmicro @\n";
-    ecf_file += "%end\n";
-    ecf_file += "%include <simple_tail.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body\n%ecfmicro @\n#tail.h";
-
-    basic_test_template("test_nopp_preserves_contents2", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_comment_and_manual_removal) {
-    string ecf_file;
-    ecf_file += "%include <simple_head.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "%comment\n";
-    ecf_file += "--comment\n";
-    ecf_file += "%end\n";
-    ecf_file += "%manual\n";
-    ecf_file += "--manual\n";
-    ecf_file += "%end\n";
-    ecf_file += "%include <simple_tail.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
-
-    basic_test_template("test_comment_and_manual_removal", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_unterminated_manual) {
-    string ecf_file;
-    ecf_file += "%include <simple_head.h>\n";
-    ecf_file += "#body\n";
-    ecf_file += "%comment\n";
-    ecf_file += "--comment\n";
-    ecf_file += "%end\n";
-    ecf_file += "%manual\n";
-    ecf_file += "%include <simple_tail.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\n#body%manual\n#tail.h";
-
-    basic_test_template("test_unterminated_manual", ecf_file, expected_job_file_contents, "", false);
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_micro_with_comments_ECFLOW_1686) {
-    string ecf_file;
-    ecf_file += "%include <simple_head.h>\n";
-    ecf_file += "var=%XXXX:2 # fred%\n";
-    ecf_file += "# %comment\n";
-    ecf_file += "var=%X:2 # CC% # comment\n";
-    ecf_file += "%include <simple_tail.h>\n";
-
-    std::string expected_job_file_contents = "#head.h\nvar=2 # fred\n# %comment\nvar=2 # CC # comment\n#tail.h";
-
-    basic_test_template("test_ecf_micro_with_comments_ECFLOW_1686", ecf_file, expected_job_file_contents);
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_resolve_single_ecf_include_with_dollar) {
-    Defs d;
-    suite_ptr s = d.add_suite("suite");                      // suite suite
-    s->add_variable("CORE", "/path/to/core");                //   edit CORE /path/to/core
-    s->add_variable("ECF_INCLUDE", "$CORE/%SUITE%/include"); //   edit ECF_INCLUDE $CORE/include
-    task_ptr t1 = s->add_task("t1");                         //   task t1
-
-    std::string ecf_file_location;
-    EcfFile ecf(t1.get(), ecf_file_location);
-
-    auto ecf_include_paths = EcfFile::get_ecf_include_paths(ecf);
-    BOOST_REQUIRE_EQUAL(ecf_include_paths.size(), 1u);
-    BOOST_REQUIRE_EQUAL(ecf_include_paths[0], "/path/to/core/suite/include");
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_resolve_single_ecf_include) {
-    Defs d;
-    suite_ptr s = d.add_suite("suite");                       // suite suite
-    s->add_variable("CORE", "/path/to/core");                 //   edit CORE /path/to/core
-    s->add_variable("ECF_INCLUDE", "%CORE%/%SUITE%/include"); //   edit ECF_INCLUDE %CORE%/%SUITE%/include
-    task_ptr t1 = s->add_task("t1");                          //   task t1
-
-    std::string ecf_file_location;
-    EcfFile ecf(t1.get(), ecf_file_location);
-
-    auto ecf_include_paths = EcfFile::get_ecf_include_paths(ecf);
-    BOOST_REQUIRE_EQUAL(ecf_include_paths.size(), 1u);
-    BOOST_REQUIRE_EQUAL(ecf_include_paths[0], "/path/to/core/suite/include");
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_resolve_multiple_ecf_include) {
-    Defs d;
-    suite_ptr s = d.add_suite("suite");                                   // suite suite
-    s->add_variable("CORE", "/path/to/core");                             //   edit CORE /path/to/core
-    s->add_variable("ECF_INCLUDE", "%CORE%/%SUITE%/include:%CORE%/more"); //   edit ECF_INCLUDE %CORE%/%SUITE%...
-    task_ptr t1 = s->add_task("t1");                                      //   task t1
-
-    std::string location;
-    EcfFile ecf(t1.get(), location);
-
-    auto ecf_include_paths = EcfFile::get_ecf_include_paths(ecf);
-    BOOST_REQUIRE_EQUAL(ecf_include_paths.size(), 2u);
-    BOOST_REQUIRE_EQUAL(ecf_include_paths[0], "/path/to/core/suite/include");
-    BOOST_REQUIRE_EQUAL(ecf_include_paths[1], "/path/to/core/more");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestEcfFileLocator.cpp 5.13.0-1/ANode/test/TestEcfFileLocator.cpp
--- 5.12.4-1/ANode/test/TestEcfFileLocator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestEcfFileLocator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,493 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Pid.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/EcfFile.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_EcfFileLocator)
-
-void located_ecf_file(task_ptr task,
-                      EcfFile::Origin expected_origin,
-                      EcfFile::EcfFileSearchAlgorithm expected_search,
-                      int line) {
-    try {
-        task->update_generated_variables();
-        EcfFile ecf_file = task->locatedEcfFile();
-        // cout << "located_ecf_file task: " << task->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
-        BOOST_REQUIRE_MESSAGE(ecf_file.valid(),
-                              "\nline:" << line << " Expected search to pass with "
-                                        << EcfFile::search_algorithm_str(expected_search));
-        BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == expected_origin,
-                              "\nline:" << line << " Expected ecf_file to be obtained from("
-                                        << EcfFile::origin_str(expected_origin) << ") but found "
-                                        << ecf_file.ecf_file_origin_dump());
-        BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_search_algorithm() == expected_search,
-                              "\nline:" << line << " Expected search " << EcfFile::search_algorithm_str(expected_search)
-                                        << " but found "
-                                        << EcfFile::search_algorithm_str(ecf_file.ecf_file_search_algorithm()));
-    }
-    catch (std::exception& e) {
-        BOOST_REQUIRE_MESSAGE(true, "Expected search to succeed " << e.what());
-    }
-}
-
-void located_ecf_file_fail(task_ptr task, int line) {
-    task->update_generated_variables();
-    try {
-        EcfFile ecf_file = task->locatedEcfFile();
-        BOOST_REQUIRE_MESSAGE(!ecf_file.valid(),
-                              "\nline:" << line << " Expected search to fail with standard look up(i.e PRUNE_ROOT) "
-                                        << ecf_file.ecf_file_origin_dump());
-    }
-    catch (std::exception& e) {
-        BOOST_REQUIRE_MESSAGE(true, "\nline:" << line << "Expected search to fail " << e.what());
-    }
-}
-
-void create_ecf_file(const std::string& ecf_file_location) {
-    // cout << "create file  = " << ecf_file_location << "\n";
-    //  generate the ecf file;
-    string header   = "%include <simple_head.h>\n";
-    string body     = "#body\n";
-    string tail     = "%include <simple_tail.h>\n";
-    string ecf_file = header;
-    ecf_file += body;
-    ecf_file += tail;
-
-    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
-    string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
-    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_search) {
-    cout << "ANode:: ...test_ecf_file_search\n";
-    // Do test which fails first, i.e does not find the ecf file, then add variable ECF_FILES_LOOKUP(PRUNE_LEAF)
-    // The test should then succeed
-    // Note: Setting ECF_FILES_LOOKUP(PRUNE_LEAF) or ECF_FILES_LOOKUP(PRUNE_ROOT)/default affects the lookup for
-    //       ecf files in BOTH ECF_HOME and ECF_LISTS
-    // PRUNE_ROOT/defaults
-    //    <root>/suite/f1/f2/f3/task.ecf
-    //    <root>/f1/f2/f3/task.ecf
-    //    <root>/f2/f3/task.ecf
-    //    <root>/f3/task.ecf
-    //    <root>/task.ecf
-    // PRUNE_LEAF( new from ecflow 4.12.0)
-    //    <root>/suite/f1/f2/f3/task.ecf
-    //    <root>/suite/f1/f2/task.ecf
-    //    <root>/suite/f1/task.ecf
-    //    <root>/suite/task.ecf
-    //    <root>/task.ecf
-    // IMPORTANT: The first and last lookups are the *SAME* for both search lookups.
-
-    // Create a defs file corresponding to:
-    // suite test_ecf_file_search
-    // edit ECF_INCLUDE $ECF_HOME/includes
-    // family f1
-    //    family f2
-    //       family f3
-    //          task task
-    Defs theDefs;
-    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_ecf_file_search"));
-    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-    family_ptr f1 = suite->add_family("f1");
-    family_ptr f2 = f1->add_family("f2");
-    family_ptr f3 = f2->add_family("f3");
-    task_ptr task = f3->add_task("task");
-
-    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
-    // or when file does not exist in ECF_INCLUDE
-    std::string ecf_home  = File::test_data("ANode/test/data", "ANode");
-    std::string ecf_lists = File::test_data("ANode/test/data", "ANode");
-    suite->add_variable(Str::ECF_HOME(), ecf_home);
-    // cerr << theDefs << "\n";
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    {
-        // cout << "Test ECF_HOME/ECF_LISTS at leaf location this should be using ECF_SCRIPT\n";
-        string ecf_file_location = ecf_home + task->absNodePath() + File::ECF_EXTN();
-        create_ecf_file(ecf_file_location);
-
-        located_ecf_file(task, EcfFile::ECF_SCRIPT, EcfFile::PRUNE_ROOT, __LINE__);
-        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
-        located_ecf_file(task,
-                         EcfFile::ECF_SCRIPT,
-                         EcfFile::PRUNE_ROOT,
-                         __LINE__); // ECF_FILES_LOOKUP make *NO* difference for lookup with EcfFile::ECF_SCRIPT
-
-        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
-
-        suite->add_variable(Str::ECF_FILES(), ecf_lists);
-        located_ecf_file(task,
-                         EcfFile::ECF_SCRIPT,
-                         EcfFile::PRUNE_ROOT,
-                         __LINE__); // ECF_FILES make no difference for lookup with EcfFile::ECF_SCRIPT
-        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
-        located_ecf_file(task,
-                         EcfFile::ECF_SCRIPT,
-                         EcfFile::PRUNE_ROOT,
-                         __LINE__); // ECF_FILES_LOOKUP make *NO* difference for lookup with EcfFile::ECF_SCRIPT
-
-        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
-        suite->deleteVariable("ECF_FILES");        // cleanup
-        fs::remove(ecf_file_location);             // cleanup
-    }
-    {
-        // cout << "Test ECF_HOME/ECF_LISTS at root location\n";
-        string ecf_file_location = ecf_home + "/" + task->name() + File::ECF_EXTN();
-        create_ecf_file(ecf_file_location);
-
-        located_ecf_file(task, EcfFile::ECF_HOME, EcfFile::PRUNE_ROOT, __LINE__);
-        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
-        located_ecf_file(task, EcfFile::ECF_HOME, EcfFile::PRUNE_LEAF, __LINE__);
-
-        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
-
-        suite->add_variable(Str::ECF_FILES(), ecf_lists);
-        located_ecf_file(task, EcfFile::ECF_FILES, EcfFile::PRUNE_ROOT, __LINE__);
-        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
-        located_ecf_file(task, EcfFile::ECF_FILES, EcfFile::PRUNE_LEAF, __LINE__);
-
-        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
-        suite->deleteVariable("ECF_FILES");        // cleanup
-        fs::remove(ecf_file_location);             // cleanup
-    }
-    {
-        // cout << "Test ECF_HOME at intermediate location prune_leaf\n";
-        Node* node = task.get();
-        node       = node->parent();
-        node       = node->parent();
-        while (node) {
-
-            string ecf_file_location = ecf_home + node->absNodePath() + "/" + task->name() + File::ECF_EXTN();
-            create_ecf_file(ecf_file_location);
-
-            // cout << "Node: " << node->absNodePath() << "\n";
-            located_ecf_file_fail(task, __LINE__);
-
-            // change look up method
-            suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf");
-            located_ecf_file(task, EcfFile::ECF_HOME, EcfFile::PRUNE_LEAF, __LINE__);
-
-            // Remove this file, required for the following test
-            fs::remove(ecf_file_location);
-
-            // Remove ECF_FILES_LOOKUP variable
-            suite->deleteVariable("ECF_FILES_LOOKUP");
-
-            node = node->parent();
-        }
-        /// Remove all the generated files
-        fs::remove_all(ecf_home + suite->absNodePath());
-    }
-    {
-        // cout << "Test ECF_FILES at intermediate location, by prune_leaf\n";
-        suite->add_variable(Str::ECF_FILES(), ecf_lists);
-        Node* node = task.get();
-        node       = node->parent();
-        node       = node->parent();
-        while (node) {
-
-            string ecf_file_location = ecf_lists + node->absNodePath() + "/" + task->name() + File::ECF_EXTN();
-            create_ecf_file(ecf_file_location);
-
-            // cout << "Node: " << node->absNodePath() << "\n";
-            located_ecf_file_fail(task, __LINE__);
-
-            // change look up method
-            suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf");
-            located_ecf_file(task, EcfFile::ECF_FILES, EcfFile::PRUNE_LEAF, __LINE__);
-
-            // Remove this file, required for the following test
-            fs::remove(ecf_file_location);
-
-            // Remove ECF_FILES_LOOKUP variable
-            suite->deleteVariable("ECF_FILES_LOOKUP");
-
-            node = node->parent();
-        }
-
-        /// Remove all the generated files
-        fs::remove_all(ecf_home + suite->absNodePath());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_locator) {
-    cout << "ANode:: ...test_ecf_file_locator\n";
-
-    // SET ECF_HOME
-    std::string smshome = File::test_data("ANode/test/data/SMSHOME", "ANode");
-
-    // Create a defs file corresponding to:
-    // # Test the sms file can be found via ECF_SCRIPT
-    // #
-    // suite suite
-    //	edit ECF_INCLUDE $ECF_HOME/includes
-    //	edit SLEEPTIME 10
-    //	family family
-    //   		task t1
-    //   		task t2
-    //    		task t3
-    //  	endfamily
-    // endsuite
-    //
-    // #
-    // # This test suite should force a backwards search since the ecf files
-    // # are located in ECF_HOME
-    // suite suite1
-    //  	family family
-    //   		task suite1_task1
-    //   		task suite1_task2
-    //    		task suite1_task3
-    //    endfamily
-    // endsuite
-    //
-    // #
-    // # This suite is used to test command substition with ECF_FETCH command
-    // #
-    // suite suite2
-    //	edit ECF_INCLUDE $ECF_HOME/includes
-    //	edit ECF_FILES   $ECF_HOME
-    //	family family
-    //		edit SMSFETCH "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"
-    //		task t2
-    //	endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("SLEEPTIME", "10"));
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t1");
-        fam->add_task("t2");
-        fam->add_task("t3");
-    }
-    {
-        suite_ptr suite = theDefs.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("suite1_task1");
-        fam->add_task("suite1_task2");
-        fam->add_task("suite1_task3");
-    }
-    {
-        suite_ptr suite2 = theDefs.add_suite("suite2");
-        suite2->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite2->addVariable(Variable(Str::ECF_FILES(), "$ECF_HOME"));
-        family_ptr fam = suite2->add_family("family");
-        fam->addVariable(Variable(Str::ECF_FETCH(), "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"));
-        fam->add_task("t2");
-    }
-    {
-        suite_ptr suite = theDefs.add_suite("suite3");
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable(Str::ECF_FILES(), "$ECF_HOME"));
-        family_ptr fam = suite->add_family("family");
-        fam->addVariable(Variable("ECF_SCRIPT_CMD", "script_cmd -F %ECF_FILES% -I %ECF_INCLUDE%"));
-        fam->add_task("t2");
-    }
-    // 	cerr << theDefs << "\n";
-
-    // get all the task, assume non hierarchical families
-    std::vector<Task*> theTasks;
-    theDefs.getAllTasks(theTasks);
-    BOOST_REQUIRE_MESSAGE(theTasks.size() == 8, "Expected 8 tasks but found, " << theTasks.size());
-
-    // Override ECF_HOME.   ECF_HOME is need to locate to the ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), smshome);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // Test for ECF_ file location
-    for (Task* t : theTasks) {
-        try {
-            EcfFile ecf_file = t->locatedEcfFile();
-            // cout << "Task: " << t->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
-            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task ");
-            Suite* suite = t->suite();
-            if (suite->name() == "suite")
-                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_SCRIPT,
-                                      "Expected ecf_file to be obtained from ECF_SCRIPT "
-                                          << ecf_file.ecf_file_origin_dump());
-            if (suite->name() == "suite1")
-                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_HOME,
-                                      "Expected ecf_file to be obtained from ECF_HOME "
-                                          << ecf_file.ecf_file_origin_dump());
-            if (suite->name() == "suite2")
-                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_FETCH_CMD,
-                                      "Expected ecf_file to be obtained from ECF_FETCH_CMD "
-                                          << ecf_file.ecf_file_origin_dump());
-            if (suite->name() == "suite3")
-                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_SCRIPT_CMD,
-                                      "Expected ecf_file to be obtained from ECF_SCRIPT_CMD "
-                                          << ecf_file.ecf_file_origin_dump());
-        }
-        catch (std::exception& e) {
-            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task " << e.what());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_locator_using_ECF_FILES) {
-    cout << "ANode:: ...test_ecf_file_locator_using_ECF_FILES\n";
-
-    // This test will check we can locate the ecf files in ECF_FILES directory
-
-    // SET ECF_HOME. *** TO A DIRECTORY WHERE THERE ARE NO .ECF FILES **
-    std::string smshome = File::test_data("ANode/test/data", "ANode");
-
-    // set ECF_FILES where we do have some .ecf files
-    std::string ecf_files = File::test_data("ANode/test/data/SMSHOME/suite/family", "ANode");
-
-    // Create a defs file corresponding to:
-    // # Test the sms file can be found via ECF_SCRIPT
-    // #
-    // edit ECF_HOME    ANode/test/data
-    // edit ECF_FILES   ANode/test/data/SMSHOME/suite/family
-    // suite suite
-    // edit ECF_INCLUDE $ECF_HOME/includes
-    // edit SLEEPTIME 10
-    // family family
-    //       task t1
-    //       task t2
-    //       task t3
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("SLEEPTIME", "10"));
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t1");
-        fam->add_task("t2");
-        fam->add_task("t3");
-    }
-
-    // get all the task, assume non hierarchical families
-    std::vector<Task*> theTasks;
-    theDefs.getAllTasks(theTasks);
-    BOOST_REQUIRE_MESSAGE(theTasks.size() == 3, "Expected 3 tasks but found, " << theTasks.size());
-
-    // ECF_HOME, a directory with no .ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), smshome);
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_FILES(), ecf_files);
-
-    //    cerr << theDefs << "\n";
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // Test for ECF_ file location
-    for (Task* t : theTasks) {
-        try {
-            EcfFile ecf_file = t->locatedEcfFile();
-            // cout << "Task: " << t->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
-            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task " << t->absNodePath());
-            BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_FILES,
-                                  "Expected ecf_file to be obtained from ECF_FILES "
-                                      << ecf_file.ecf_file_origin_dump());
-        }
-        catch (std::exception& e) {
-            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task\n" << e.what());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ecf_file_locator_using_ECF_FILES_variable_substitution) {
-    cout << "ANode:: ...test_ecf_file_locator_using_ECF_FILES_variable_substitution\n";
-
-    // ECFLOW-788
-    // This test will check we can locate the ecf files in ECF_FILES directory
-    // Will attempt variable substitution, on ECF_FILES is directory does not exist
-
-    // SET ECF_HOME. ***TO A DIRECTORY WHERE THERE ARE NO .ECF FILE **
-    std::string smshome = File::test_data("ANode/test/data", "ANode");
-
-    // set ECF_FILES where we do have some .ecf files
-    std::string ecf_files = File::test_data("ANode/test/data/SMSHOME/suite/%FAMILY%", "ANode");
-
-    // Create a defs file corresponding to:
-    // # Test the sms file can be found via ECF_SCRIPT
-    // #
-    // edit ECF_HOME    ANode/test/data
-    // edit ECF_FILES   ANode/test/data/SMSHOME/suite/%FAMILY%   # test we variable substitute
-    // suite suite
-    // edit ECF_INCLUDE $ECF_HOME/includes
-    // edit SLEEPTIME 10
-    // family family
-    //       task t1
-    //       task t2
-    //       task t3
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable("SLEEPTIME", "10"));
-        family_ptr fam = suite->add_family("family");
-        fam->addVariable(Variable("FAMILY", "family"));
-        fam->add_task("t1");
-        fam->add_task("t2");
-        fam->add_task("t3");
-    }
-
-    // get all the task, assume non hierarchical families
-    std::vector<Task*> theTasks;
-    theDefs.getAllTasks(theTasks);
-    BOOST_REQUIRE_MESSAGE(theTasks.size() == 3, "Expected 3 tasks but found, " << theTasks.size());
-
-    // ECF_HOME, a directory with no .ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), smshome);
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_FILES(), ecf_files);
-
-    //    cerr << theDefs << "\n";
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // Test for ECF_ file location
-    for (Task* t : theTasks) {
-        try {
-            EcfFile ecf_file = t->locatedEcfFile();
-            // cout << "Task: " << t->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
-            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task " << t->absNodePath());
-            BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_FILES,
-                                  "Expected ecf_file to be obtained from ECF_FILES "
-                                      << ecf_file.ecf_file_origin_dump());
-        }
-        catch (std::exception& e) {
-            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task\n" << e.what());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestEnviromentSubstitution.cpp 5.13.0-1/ANode/test/TestEnviromentSubstitution.cpp
--- 5.12.4-1/ANode/test/TestEnviromentSubstitution.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestEnviromentSubstitution.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,97 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_EnvironmentSubstitution)
-
-BOOST_AUTO_TEST_CASE(test_environment_substitution) {
-    std::cout << "ANode:: ...test_environment_substitution\n";
-
-    Defs defs;
-    Suite* s = nullptr;
-    {
-        suite_ptr suite = defs.add_suite("suite");
-        s               = suite.get();
-        suite->addVariable(Variable("AVI", "avi"));
-
-        std::vector<std::pair<std::string, std::string>> env;
-        env.emplace_back(Str::ECF_HOME(), string("/home/smshome"));
-        env.emplace_back(string("FRED"), string("/home/fred"));
-        env.emplace_back(string("BILL"), string("/home/bill"));
-        env.emplace_back(string("JANE"), string("/home/jane"));
-        env.emplace_back(string("REP"), string("$REP/bill"));
-        defs.set_server().add_or_update_user_variables(env);
-    }
-
-    // Check for recursive, in which case we only substitute once
-    string expected = "$REP/bill";
-    std::string cmd = "$REP";
-    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    // See page 31, section 5.1 variable inheritance, of SMS users guide
-    cmd      = "$ECF_HOME";
-    expected = "/home/smshome";
-    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "$ECF_HOME/include";
-    expected = "/home/smshome/include";
-    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "$ECF_HOME$FRED$BILL$JANE";
-    expected = "/home/smshome/home/fred/home/bill/home/jane";
-    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "$ECF_HOME/$FRED/$BILL/$JANE";
-    expected = "/home/smshome//home/fred//home/bill//home/jane";
-    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH";
-    expected = "%PATH";
-    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "$$";
-    expected = "$$";
-    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "$ERROR$";
-    expected = "$ERROR$";
-    BOOST_CHECK_MESSAGE(!s->variable_dollar_substitution(cmd),
-                        " substitution expected to fail since ERROR does not exist");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestExprParser.cpp 5.13.0-1/ANode/test/TestExprParser.cpp
--- 5.12.4-1/ANode/test/TestExprParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestExprParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,756 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <map>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/ExprParser.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_ExprParser)
-
-BOOST_AUTO_TEST_CASE(test_expression_parser_basic) {
-    std::cout << "ANode:: ...test_expression_parser_basic\n";
-
-    using namespace std::string_literals;
-
-    // This must be nicely formatted, i.e. AST is nicely space formatted otherwise it will fail the test
-    // This test ENSURES that the AST matches the expression. (i.e. by getting AST to print the expression)
-    // Note: we can use NOT,eq,ne,le,ge or brackets
-    //       we can't use a:event_name  ==> a:event_name == set
-    std::vector expressions = {
-        "a == complete"s,
-        "a != complete"s,
-        "a:value == 10"s,
-        "a:value != 10"s,
-        "a:value >= 10"s,
-        "a:value <= 10"s,
-        "a:value > 10"s,
-        "a:value < 10"s,
-        "1 == 1"s,
-        "1 == 0"s,
-        "a:event_name == set"s,
-        "a:event_name != set"s,
-        "a:event_name == clear"s,
-        "a:event_name != clear"s,
-        "../a/b:eventname == set"s,
-        "../a/b:eventname == clear"s,
-        "../a/b:eventname != clear"s,
-        "../a:event_name >= 10"s,
-        "a == unknown and b != complete"s,
-        "a == unknown or b != complete"s,
-        "a == complete and b == complete or c == complete"s,
-        "! a == unknown"s,
-        "/mc/main:YMD <= /mc/main/ref:MC_STOP"s,
-        "! ../../../prod2diss/operation_is_late:yes == set or ! a == complete"s,
-        "./a:YMD - ./b:YMD < 5"s,
-        "./a:YMD + ./b:YMD < 5"s,
-        "./a:YMD / ./b:YMD < 5"s,
-        "./a:YMD * ./b:YMD < 5"s,
-        "./a:YMD % ./b:YMD < 5"s,
-        "inigroup:YMD == ! 1"s,
-        "inigroup:YMD == ! 0"s,
-        "comp == complete and notready == complete"s, // ECFLOW-493
-        "comp == complete and not ready == complete"s,
-        "comp == complete and ! ready == complete"s, // we now store the not from the parse, for test comparison
-        "comp == complete and ~ ready == complete"s,
-        ":VAR == 1"s,
-        ":VAR == /mc/main/ref:MC_STOP"s,
-        ":YMD - :YMD < 5"s,
-        ":YMD + :YMD < 5"s,
-        ":YMD / :YMD < 5"s,
-        ":YMD * :YMD < 5"s,
-        ":YMD % :YMD < 5"s,
-        ":VARIABLE == 20230101T000000"s,
-        ":VARIABLE >= 20230101T000000"s,
-        ":VARIABLE <= 20230101T000000"s,
-        ":VARIABLE + 3 <= 19700101T000000"s,
-        ":VARIABLE <= 19700101T000000 + 3"s};
-
-    for (const auto& expression : expressions) {
-
-        PartExpression part(expression);
-        std::string error;
-        auto ast = part.parseExpressions(error);
-        BOOST_REQUIRE_MESSAGE(ast.get(), "Failed to parse\n" << expression << "  " << error);
-
-        std::stringstream s2;
-        ast->print_flat(s2);
-        std::string actual_expression = s2.str();
-        BOOST_CHECK_MESSAGE(expression == actual_expression,
-                            " Failed\n'" << expression << "' != '" << actual_expression << "'");
-
-        std::string why;
-        ast->why(why);
-        if (ast->evaluate()) {
-            BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << expression);
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << expression);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_expression_parser_basic_with_braces) {
-    std::cout << "ANode:: ...test_expression_parser_basic_with_braces\n";
-
-    using namespace std::string_literals;
-
-    // This must be nicely formatted, i.e. AST is nicely space formatted otherwise it will fail the test
-    // This test ENSURES that the AST matches the expression. (i.e. by getting AST to print the expression)
-    // Note: we can use NOT,eq,ne,le,ge,
-    //       we can't use a:event_name  ==> a:event_name == set
-    std::vector expressions = {
-        "((a == complete) and (b == complete))"s,
-        "(((a == complete) or (b == complete)) and (c == complete))"s,
-        "((a == complete) and ((b == complete) or (nodepath:eventname == set)))"s,
-        "((a == complete) and ((b == complete) or ((a == complete) and (b == complete))))"s,
-        "! ((a == unknown))"s,
-        "((t:step + 20) >= (t:step1 - 20))"s,
-        "(((/o/main/12/an/slwet == complete) and ((/o/main/12/an/4dvar/ifstraj:finalwave == set) or (/o/main/12/an/4dvar == complete))) or (/o/main/12/an == complete))"s,
-        "((obs:YMD <= (main:YMD + 1)) and ((../make/setup == complete) and (obs:YMD <= /o/lag:YMD)))"s,
-        "(((stage == complete) or (./stage:YMD > ./retrieve:YMD)) and ((./retrieve:YMD - ./load:YMD) < 5))"s,
-        "((./a:YMD - ./b:YMD) < 5)"s,
-        "((:YMD + :YMD) < 5)"s,
-        "((:YMD + :YMD) < 5)"s,
-        "((:VARIABLE == 19700101T123456) and (b == complete))"s,
-        "((:VARIABLE < 19700101T123456) and (b == complete))"s};
-
-    for (const auto& expression : expressions) {
-
-        PartExpression part(expression);
-        std::string error;
-        std::unique_ptr<AstTop> ast = part.parseExpressions(error);
-        BOOST_REQUIRE_MESSAGE(ast.get(), "Failed to parse " << expression << "  " << error);
-
-        std::stringstream s2;
-        ast->print_flat(s2, true /*add_brackets*/);
-        std::string actual_expression = s2.str();
-        BOOST_CHECK_MESSAGE(expression == actual_expression,
-                            " Failed '" << expression << "' != '" << actual_expression << "'");
-
-        std::string why;
-        ast->why(why);
-        if (ast->evaluate()) {
-            BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << expression);
-        }
-        else {
-            BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << expression);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_parser_good_expressions) {
-    std::cout << "ANode:: ...test_parser_good_expressions\n";
-
-    // The map key  = trigger expression,
-    // value.first  = type of the expected root abstract syntax tree
-    // value.second = result of expected evaluation
-    map<string, std::pair<string, bool>> exprMap;
-
-    exprMap["a:value == 0"]  = std::make_pair(AstEqual::stype(), true);
-    exprMap["a:value == 10"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["a:value eq 10"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["a:value != 10"] = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["a:value ne 10"] = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["a:value > 10"]  = std::make_pair(AstGreaterThan::stype(), false);
-    exprMap["a:value gt 10"] = std::make_pair(AstGreaterThan::stype(), false);
-    exprMap["a:value >= 10"] = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["a:value ge 10"] = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["a:value < 10"]  = std::make_pair(AstLessThan::stype(), true);
-    exprMap["a:value lt 10"] = std::make_pair(AstLessThan::stype(), true);
-    exprMap["a:value <= 10"] = std::make_pair(AstLessEqual::stype(), true);
-    exprMap["a:value le 10"] = std::make_pair(AstLessEqual::stype(), true);
-
-    exprMap["0 == a:value"]  = std::make_pair(AstEqual::stype(), true);
-    exprMap["10 == a:value"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["10 eq a:value"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["10 != a:value"] = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["10 ne a:value"] = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["10 > a:value"]  = std::make_pair(AstGreaterThan::stype(), true);
-    exprMap["10 gt a:value"] = std::make_pair(AstGreaterThan::stype(), true);
-    exprMap["10 >= a:value"] = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["10 < a:value"]  = std::make_pair(AstLessThan::stype(), false);
-    exprMap["10 lt a:value"] = std::make_pair(AstLessThan::stype(), false);
-    exprMap["10 <= a:value"] = std::make_pair(AstLessEqual::stype(), false);
-    exprMap["10 le a:value"] = std::make_pair(AstLessEqual::stype(), false);
-
-    exprMap["a == complete"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["a==complete"]   = std::make_pair(AstEqual::stype(), false);
-    exprMap["a eq complete"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["a ne complete"] = std::make_pair(AstNotEqual::stype(), true);
-
-    exprMap["0 eq 1"]    = std::make_pair(AstEqual::stype(), false);
-    exprMap["1000 eq 9"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["10 eq 10"]  = std::make_pair(AstEqual::stype(), true);
-    exprMap["10 ge 4"]   = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["10 le 4"]   = std::make_pair(AstLessEqual::stype(), false);
-
-    exprMap["0 == 0"]    = std::make_pair(AstEqual::stype(), true);
-    exprMap["0 == 1"]    = std::make_pair(AstEqual::stype(), false);
-    exprMap["0 != 1"]    = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["0 < 1"]     = std::make_pair(AstLessThan::stype(), true);
-    exprMap["10 < 1"]    = std::make_pair(AstLessThan::stype(), false);
-    exprMap["1000 == 9"] = std::make_pair(AstEqual::stype(), false);
-    exprMap["10 == 10"]  = std::make_pair(AstEqual::stype(), true);
-    exprMap["10 >= 4"]   = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["10 <= 4"]   = std::make_pair(AstLessEqual::stype(), false);
-    exprMap["0 > 1"]     = std::make_pair(AstGreaterThan::stype(), false);
-    exprMap["10 > 1"]    = std::make_pair(AstGreaterThan::stype(), true);
-
-    // Integer is distinct from task/family names that are integers, since nodes with integer
-    // names that occur in trigger/complete expression must have path ./0 ./1
-    exprMap["./12:eventname"]             = std::make_pair(AstEqual::stype(), false);
-    exprMap["./12:eventname == 0"]        = std::make_pair(AstEqual::stype(), true);
-    exprMap["./12/b:eventname"]           = std::make_pair(AstEqual::stype(), false);
-    exprMap["/12/b:eventname"]            = std::make_pair(AstEqual::stype(), false);
-    exprMap["../12/b:eventname == set"]   = std::make_pair(AstEqual::stype(), false);
-    exprMap["../12/b:eventname == clear"] = std::make_pair(AstEqual::stype(), true);
-    exprMap["../12/b:eventname != clear"] = std::make_pair(AstNotEqual::stype(), false);
-    exprMap["12:eventname == set"]        = std::make_pair(AstEqual::stype(), false);
-    exprMap["12:eventname != set"]        = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["12:eventname == clear"]      = std::make_pair(AstEqual::stype(), true);
-    exprMap["./12:eventname == set"]      = std::make_pair(AstEqual::stype(), false);
-    exprMap["./12:eventname != set"]      = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["./12:eventname == clear"]    = std::make_pair(AstEqual::stype(), true);
-
-    exprMap["a:eventname"]               = std::make_pair(AstEqual::stype(), false);
-    exprMap["a:eventname == 0"]          = std::make_pair(AstEqual::stype(), true);
-    exprMap["./a/b:eventname"]           = std::make_pair(AstEqual::stype(), false);
-    exprMap["/a/b:eventname"]            = std::make_pair(AstEqual::stype(), false);
-    exprMap["../a/b:eventname == set"]   = std::make_pair(AstEqual::stype(), false);
-    exprMap["../a/b:eventname == clear"] = std::make_pair(AstEqual::stype(), true);
-    exprMap["../a/b:eventname != clear"] = std::make_pair(AstNotEqual::stype(), false);
-    exprMap["a:eventname == set"]        = std::make_pair(AstEqual::stype(), false);
-    exprMap["a:eventname != set"]        = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["a:eventname == clear"]      = std::make_pair(AstEqual::stype(), true);
-
-    exprMap["a:metername >= 100"]        = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["b:metername le 100"]        = std::make_pair(AstLessEqual::stype(), true);
-    exprMap["./b:metername <= 100"]      = std::make_pair(AstLessEqual::stype(), true);
-    exprMap["../a/b:metername ge 100"]   = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["../a/b/c:metername >= 100"] = std::make_pair(AstGreaterEqual::stype(), false);
-
-    exprMap["!a:a  &&   b:b"]          = std::make_pair(AstAnd::stype(), false);
-    exprMap["a:a   && ! b:b"]          = std::make_pair(AstAnd::stype(), false);
-    exprMap["! a:a ||   b:b"]          = std::make_pair(AstOr::stype(), true);
-    exprMap["a:a   || ! b:b"]          = std::make_pair(AstOr::stype(), true);
-    exprMap["! a:a &&   b:b &&   c:c"] = std::make_pair(AstAnd::stype(), false);
-    exprMap["! a:a &&   b:b ||   c:c"] = std::make_pair(AstOr::stype(), false);
-    exprMap["a:a && !   b:b &&   c:c"] = std::make_pair(AstAnd::stype(), false);
-    exprMap["a:a && !   b:b ||   c:c"] = std::make_pair(AstOr::stype(), false);
-    exprMap["a:a ||     b:b && ! c:c"] = std::make_pair(AstOr::stype(), false);
-    exprMap["a:a ||     b:b || ! c:c"] = std::make_pair(AstOr::stype(), true);
-
-    exprMap["a:b && b:c && c:d && ../c:b && ./x:y && z:x"]             = std::make_pair(AstAnd::stype(), false);
-    exprMap["! a:b && b:c && c:d && ../c:b && ./x:y && z:x"]           = std::make_pair(AstAnd::stype(), false);
-    exprMap["! a:b || b:c && c:d && ../c:b && ./x:y && z:x"]           = std::make_pair(AstOr::stype(), true);
-    exprMap["a:b || b:c && ! c:d && ../c:b && ./x:y && z:x"]           = std::make_pair(AstOr::stype(), false);
-    exprMap["a:b && b:c && c:d && ../c:b && ./x:y && ! z:x"]           = std::make_pair(AstAnd::stype(), false);
-    exprMap["x:x || a:b && b:c && c:d && ../c:b && ./x:y && z:x"]      = std::make_pair(AstOr::stype(), false);
-    exprMap["x:x == 0 || a:b && b:c && c:d && ../c:b && ./x:y && z:x"] = std::make_pair(AstOr::stype(), true);
-    exprMap["! a:a && ! b:b && ! c:c && ! d:d "]                       = std::make_pair(AstAnd::stype(), true);
-    exprMap["! a:a || ! b:b || ! c:c || ! d:d "]                       = std::make_pair(AstOr::stype(), true);
-
-    exprMap["./a == unknown"]      = std::make_pair(AstEqual::stype(), true);
-    exprMap["./a/b != queued"]     = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["../a == complete"]    = std::make_pair(AstEqual::stype(), false);
-    exprMap["../a/b == aborted"]   = std::make_pair(AstEqual::stype(), false);
-    exprMap["../a/b/c != aborted"] = std::make_pair(AstNotEqual::stype(), true);
-
-    exprMap["inigroup:YMD == ! 1"]                 = std::make_pair(AstEqual::stype(), true);
-    exprMap["1 != ! 1"]                            = std::make_pair(AstNotEqual::stype(), true);
-    exprMap["b == complete or nodepath:eventname"] = std::make_pair(AstOr::stype(), false);
-
-    exprMap["a eq unknown and b ne complete"]    = std::make_pair(AstAnd::stype(), true);
-    exprMap["a eq complete or b eq complete"]    = std::make_pair(AstOr::stype(), false);
-    exprMap["a eq complete or b eq unknown"]     = std::make_pair(AstOr::stype(), true);
-    exprMap["a eq complete and b eq complete"]   = std::make_pair(AstAnd::stype(), false);
-    exprMap["(a eq complete and b == complete)"] = std::make_pair(AstAnd::stype(), false);
-
-    exprMap["a == unknown && b != complete"]    = std::make_pair(AstAnd::stype(), true);
-    exprMap["a == complete || b == complete"]   = std::make_pair(AstOr::stype(), false);
-    exprMap["a == complete || b == unknown"]    = std::make_pair(AstOr::stype(), true);
-    exprMap["a eq complete && b eq complete"]   = std::make_pair(AstAnd::stype(), false);
-    exprMap["(a == complete && b == complete)"] = std::make_pair(AstAnd::stype(), false);
-
-    // This should be interpreted as '(a == complete and b == complete) or c == complete'
-    // because 'and' has a higher priority than the 'or'. Hence 'OR' must be at the root.
-    exprMap["a == complete and b == complete or c == complete"]             = std::make_pair(AstOr::stype(), false);
-    exprMap["a == complete &&  b == complete || c == complete"]             = std::make_pair(AstOr::stype(), false);
-    exprMap["a == complete and b == complete or c == unknown"]              = std::make_pair(AstOr::stype(), true);
-    exprMap["a == complete and (b == complete or c == complete)"]           = std::make_pair(AstAnd::stype(), false);
-    exprMap["a == complete or b == complete and c == complete"]             = std::make_pair(AstOr::stype(), false);
-    exprMap["((a == complete or b == complete)) and c == complete"]         = std::make_pair(AstAnd::stype(), false);
-    exprMap["a == complete && b == complete and c == complete or x:a == 0"] = std::make_pair(AstOr::stype(), true);
-    exprMap["a == complete || b == complete and c == complete and x:a == 0 || x == complete"] =
-        std::make_pair(AstOr::stype(), false);
-    exprMap["a == complete || b == complete and c == complete and x:a || x == complete"] =
-        std::make_pair(AstOr::stype(), false);
-
-    exprMap["(a != aborted and b == unknown or c != queued)"]          = std::make_pair(AstOr::stype(), true);
-    exprMap["(a == complete and b == complete) or nodepath:eventname"] = std::make_pair(AstOr::stype(), false);
-    exprMap["(a == complete and b == complete) or (a == complete and b == complete)"] =
-        std::make_pair(AstOr::stype(), false);
-    exprMap["a == complete and (b == complete or a == complete) and b == complete"] =
-        std::make_pair(AstAnd::stype(), false);
-
-    // Expression that initially fail to parse for the operational suites
-    exprMap["(/skull/consumer/admin/leader:1 and (0 le /skull/consumer/produce1/produce:STEP)) or (not "
-            "/skull/consumer/admin/leader:1)"] = std::make_pair(AstOr::stype(), true);
-    exprMap["./pdb eq complete and  (  not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)"] =
-        std::make_pair(AstAnd::stype(), false);
-    exprMap["! ../../../prod2diss//operation_is_late:yes"]                    = std::make_pair(AstNot::stype(), true);
-    exprMap["not ../../../prod2diss//operation_is_late:yes"]                  = std::make_pair(AstNot::stype(), true);
-    exprMap["not ../../../prod2diss/operation_is_late:yes"]                   = std::make_pair(AstNot::stype(), true);
-    exprMap["not ../../../prod2diss/operation_is_late:yes or a == complete "] = std::make_pair(AstOr::stype(), true);
-    exprMap["not ../../../prod2diss/operation_is_late:yes or not a == complete "] =
-        std::make_pair(AstOr::stype(), true);
-    exprMap["not ( a == complete )"]                      = std::make_pair(AstNot::stype(), true);
-    exprMap["not ( a == unknown )"]                       = std::make_pair(AstNot::stype(), false);
-    exprMap["~ ( a == unknown )"]                         = std::make_pair(AstNot::stype(), false);
-    exprMap["~ ( a != unknown )"]                         = std::make_pair(AstNot::stype(), true);
-    exprMap["! ( a == unknown )"]                         = std::make_pair(AstNot::stype(), false);
-    exprMap["!( a == unknown )"]                          = std::make_pair(AstNot::stype(), false);
-    exprMap["inigroup:YMD eq ~ 1"]                        = std::make_pair(AstEqual::stype(), true);
-    exprMap["inigroup:YMD eq ~ 0"]                        = std::make_pair(AstEqual::stype(), false);
-    exprMap["inigroup:YMD eq ! 0"]                        = std::make_pair(AstEqual::stype(), false);
-    exprMap["/net/main:YMD le /net/cleanplus1:YMD and 1"] = std::make_pair(AstAnd::stype(), true);
-
-    exprMap["! ../../../operation_is_late:yes == set"]                    = std::make_pair(AstNot::stype(), true);
-    exprMap["2 == (((/seasplots/lag:YMD / 100 ) % 100) % 3)"]             = std::make_pair(AstEqual::stype(), false);
-    exprMap["(((/seasplots/lag:YMD / 100 ) % 100) % 3) ==  2"]            = std::make_pair(AstEqual::stype(), false);
-    exprMap["! ../../../a:yes == set or ! a == complete or y == aborted"] = std::make_pair(AstOr::stype(), true);
-
-    exprMap["bins/wamabs eq complete and links eq complete"] = std::make_pair(AstAnd::stype(), false);
-    exprMap["/mc/main:YMD le /mc/main/ref:MC_STOP"]          = std::make_pair(AstLessEqual::stype(), true);
-    exprMap["/mc//main:YMD le /mc/main//ref:MC_STOP"]        = std::make_pair(AstLessEqual::stype(), true);
-    exprMap["(  ( /o/main/12/an/slwet eq complete and  ( /o/main/12/an/4dvar/ifstraj:finalwave or /o/main/12/an/4dvar "
-            "eq complete)) or /o/main/12/an eq complete)"]   = std::make_pair(AstOr::stype(), false);
-    exprMap["../../sv/getsvs eq complete and  ( getae:1 or getae eq complete)"] =
-        std::make_pair(AstAnd::stype(), false);
-    exprMap["(  ( /o/lag:YMD gt /sync/o/o/lag:YMD) or  ( /o/main:YMD gt /sync/o/o/main:YMD) or 1 eq 0) and /sync/o ne "
-            "active and /sync/o ne submitted"] = std::make_pair(AstAnd::stype(), false);
-
-    exprMap["t:step + 20 le 19"]               = std::make_pair(AstLessEqual::stype(), false);
-    exprMap["(t:step + 20) le 19"]             = std::make_pair(AstLessEqual::stype(), false);
-    exprMap["t:step + 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["t:step - 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["t:step + 20 ge t:step1 - 20"]     = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["(t:step + 20) ge (t:step1 - 20)"] = std::make_pair(AstGreaterEqual::stype(), true);
-
-    // Note: t:step will evaluate to 0,  0 % number  == 0, however 20 % 0 is a runtime error, same as divide by zero
-    exprMap["t:step % 20 < 19"]                = std::make_pair(AstLessThan::stype(), true);
-    exprMap["t:step % 10 == 0"]                = std::make_pair(AstEqual::stype(), true);
-    exprMap["t:step % 20 ge 19"]               = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["(t:step % 20) ge 19"]             = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["t:step % 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["t:step % 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
-    exprMap["t:step % 20 ge t:step1 - 20"]     = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["(t:step % 20) ge (t:step1 - 20)"] = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["(t:step % 20) == (t:step1 % 10)"] = std::make_pair(AstEqual::stype(), true);
-
-    exprMap["( obs:YMD le  ( main:YMD + 1)) and ../make/setup eq complete and  ( obs:YMD le /o/lag:YMD)"] =
-        std::make_pair(AstAnd::stype(), false);
-    exprMap["( stage eq complete or ./stage:YMD gt ./retrieve:YMD) and ( ./retrieve:YMD - ./load:YMD lt 5)"] =
-        std::make_pair(AstAnd::stype(), false);
-    exprMap["./a:YMD - ./b:YMD lt 5"] = std::make_pair(AstLessThan::stype(), true);
-
-    exprMap["comp == complete and notready == complete"] = std::make_pair(AstAnd::stype(), false);
-
-    exprMap["/s/f/t<flag>late"]                          = std::make_pair(AstFlag::stype(), false);
-    exprMap["./s<flag>late"]                             = std::make_pair(AstFlag::stype(), false);
-    exprMap["../s/f/t<flag>late"]                        = std::make_pair(AstFlag::stype(), false);
-    exprMap["/s/f/t<flag>late == 0"]                     = std::make_pair(AstEqual::stype(), true);
-    exprMap["0 == /s/f/t<flag>late"]                     = std::make_pair(AstEqual::stype(), true);
-    exprMap["/s/f/t<flag>late and /s/f/t<flag>late"]     = std::make_pair(AstAnd::stype(), false);
-    exprMap["! /s/f/t<flag>late and ! /s/f/t<flag>late"] = std::make_pair(AstAnd::stype(), true);
-    exprMap["! /s/f/t<flag>late"]                        = std::make_pair(AstNot::stype(), true);
-    exprMap["/s/f/t<flag>late + 2 >= 2"]                 = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["(/s/f/t<flag>late or 1)"]                   = std::make_pair(AstOr::stype(), true);
-    exprMap["/<flag>late"]                               = std::make_pair(AstFlag::stype(), false);
-
-    exprMap["/s/f/t<flag>zombie"]                            = std::make_pair(AstFlag::stype(), false);
-    exprMap["./s<flag>zombie"]                               = std::make_pair(AstFlag::stype(), false);
-    exprMap["../s/f/t<flag>zombie"]                          = std::make_pair(AstFlag::stype(), false);
-    exprMap["/s/f/t<flag>zombie == 0"]                       = std::make_pair(AstEqual::stype(), true);
-    exprMap["0 == /s/f/t<flag>zombie"]                       = std::make_pair(AstEqual::stype(), true);
-    exprMap["/s/f/t<flag>zombie and /s/f/t<flag>zombie"]     = std::make_pair(AstAnd::stype(), false);
-    exprMap["/s/f/t<flag>zombie or /s/f/t<flag>zombie"]      = std::make_pair(AstOr::stype(), false);
-    exprMap["! /s/f/t<flag>zombie and ! /s/f/t<flag>zombie"] = std::make_pair(AstAnd::stype(), true);
-    exprMap["! /s/f/t<flag>zombie"]                          = std::make_pair(AstNot::stype(), true);
-    exprMap["/s/f/t<flag>zombie + 2 >= 2"]                   = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["(/s/f/t<flag>zombie or 1)"]                     = std::make_pair(AstOr::stype(), true);
-
-    exprMap["/s/f/t<flag>archived"]                              = std::make_pair(AstFlag::stype(), false);
-    exprMap["./s<flag>archived"]                                 = std::make_pair(AstFlag::stype(), false);
-    exprMap["../s/f/t<flag>archived"]                            = std::make_pair(AstFlag::stype(), false);
-    exprMap["/s/f/t<flag>archived == 0"]                         = std::make_pair(AstEqual::stype(), true);
-    exprMap["0 == /s/f/t<flag>archived"]                         = std::make_pair(AstEqual::stype(), true);
-    exprMap["/s/f/t<flag>archived and /s/f/t<flag>archived"]     = std::make_pair(AstAnd::stype(), false);
-    exprMap["/s/f/t<flag>archived or /s/f/t<flag>archived"]      = std::make_pair(AstOr::stype(), false);
-    exprMap["! /s/f/t<flag>archived and ! /s/f/t<flag>archived"] = std::make_pair(AstAnd::stype(), true);
-    exprMap["! /s/f/t<flag>archived"]                            = std::make_pair(AstNot::stype(), true);
-    exprMap["/s/f/t<flag>archived + 2 >= 2"]                     = std::make_pair(AstGreaterEqual::stype(), true);
-    exprMap["(/s/f/t<flag>archived or 1)"]                       = std::make_pair(AstOr::stype(), true);
-
-    exprMap[":VAR == 0"]                    = std::make_pair(AstEqual::stype(), true);
-    exprMap[":VAR == 1"]                    = std::make_pair(AstEqual::stype(), false);
-    exprMap[":VAR == /mc/main/ref:MC_STOP"] = std::make_pair(AstEqual::stype(), true);
-    exprMap[":YMD - :YMD <= 5"]             = std::make_pair(AstLessEqual::stype(), true);
-    exprMap[":YMD + :YMD <= 5"]             = std::make_pair(AstLessEqual::stype(), true);
-    exprMap[":YMD * :YMD <= 5"]             = std::make_pair(AstLessEqual::stype(), true);
-    exprMap[":YMD + 1 == 1"]                = std::make_pair(AstEqual::stype(), true);
-
-    exprMap[":VAR == 20000101T235959"] = std::make_pair(AstEqual::stype(), false);
-    exprMap[":VAR <= 20000101T235959"] = std::make_pair(AstLessEqual::stype(), true);
-    exprMap[":VAR >= 20000101T235959"] = std::make_pair(AstGreaterEqual::stype(), false);
-
-    int parse_failure = 0;
-    int ast_failure   = 0;
-    // std::pair<string, std::pair<string,bool> > p;
-    for (const auto& p : exprMap) {
-
-        // cout << "parsing: " << p.first << "\n";
-        ExprParser theExprParser(p.first);
-        std::string errorMsg;
-        bool ok = theExprParser.doParse(errorMsg);
-        if (!ok)
-            parse_failure++;
-        BOOST_CHECK_MESSAGE(ok, errorMsg + "failed for " + p.first);
-
-        if (ok) {
-            string expectedRootType       = p.second.first;
-            bool expectedEvaluationResult = p.second.second;
-
-            Ast* top = theExprParser.getAst();
-            if (!top)
-                ast_failure++;
-            BOOST_CHECK_MESSAGE(top, "No abstract syntax tree " + p.first);
-            if (top) {
-                BOOST_CHECK_MESSAGE(top->left(), "No root created " + p.first);
-                BOOST_CHECK_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
-                                    "First child of top should be a root or attribute " + p.first);
-                BOOST_CHECK_MESSAGE(top->left()->is_evaluateable(),
-                                    "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
-                BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
-                                    "expected root type '" << expectedRootType << "' or 'variable' but found '"
-                                                           << top->left()->type() << "' " << p.first);
-                BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(),
-                                    "evaluation not as expected for:\n"
-                                        << p.first << "\n"
-                                        << *top);
-
-                std::string error_msg;
-                BOOST_CHECK_MESSAGE(top->check(error_msg), error_msg << ":  Check failed for " << *top);
-
-                std::string why;
-                top->why(why);
-                // cout << "why: " << p.first << " -> " << why << "\n";
-                if (top->evaluate()) {
-                    BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << p.first);
-                }
-                else {
-                    BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << p.first);
-                }
-            }
-        }
-    }
-    BOOST_REQUIRE_MESSAGE(parse_failure == 0 && ast_failure == 0,
-                          "Found failures parse_failure:" << parse_failure << " ast failure:" << ast_failure);
-}
-
-BOOST_AUTO_TEST_CASE(test_trigger_functions) {
-    std::cout << "ANode:: ...test_trigger_functions\n";
-
-    // The map key  = trigger expression,
-    // value.first  = type of the expected root abstract syntax tree
-    // value.second = result of expected evaluation
-    map<string, std::pair<string, bool>> exprMap;
-
-    exprMap["cal::date_to_julian(A:x) == 0"]                          = std::make_pair(AstEqual::stype(), true);
-    exprMap["cal::date_to_julian( 0 ) == cal::date_to_julian( 0 )"]   = std::make_pair(AstEqual::stype(), true);
-    exprMap["cal::date_to_julian( 0 ) == cal::date_to_julian( A:x )"] = std::make_pair(AstEqual::stype(), true);
-    exprMap["2457620 == cal::date_to_julian( 20160819 )"]             = std::make_pair(AstEqual::stype(), true);
-    exprMap["20160819 == cal::julian_to_date( 2457620 )"]             = std::make_pair(AstEqual::stype(), true);
-
-    // test 10 digit integer, ie yyyymmddhh
-    exprMap["2457620 == cal::date_to_julian( 2016081912 )"] = std::make_pair(AstEqual::stype(), true);
-
-    int parse_failure = 0;
-    int ast_failure   = 0;
-    for (std::pair<string, std::pair<string, bool>> p : exprMap) {
-
-        // cout << "parsing: " << p.first << "\n";
-        ExprParser theExprParser(p.first);
-        std::string errorMsg;
-        bool ok = theExprParser.doParse(errorMsg);
-        if (!ok)
-            parse_failure++;
-        BOOST_CHECK_MESSAGE(ok, errorMsg + "failed for " + p.first);
-
-        if (ok) {
-            string expectedRootType       = p.second.first;
-            bool expectedEvaluationResult = p.second.second;
-
-            Ast* top = theExprParser.getAst();
-            if (!top)
-                ast_failure++;
-            BOOST_CHECK_MESSAGE(top, "No abstract syntax tree " + p.first);
-            if (top) {
-                BOOST_CHECK_MESSAGE(top->left(), "No root created " + p.first);
-                BOOST_CHECK_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
-                                    "First child of top should be a root or attribute " + p.first);
-                BOOST_CHECK_MESSAGE(top->left()->is_evaluateable(),
-                                    "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
-                BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
-                                    "expected root type '" << expectedRootType << "' or 'variable' but found '"
-                                                           << top->left()->type() << "' " << p.first);
-                BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(),
-                                    "evaluation not as expected for:\n"
-                                        << p.first << "\n"
-                                        << *top);
-
-                std::string error_msg;
-                BOOST_CHECK_MESSAGE(top->check(error_msg), error_msg << ":  Check failed for " << *top);
-
-                std::string why;
-                top->why(why);
-                // cout << "why: " << p.first << " -> " << why << "\n";
-                if (top->evaluate()) {
-                    BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << p.first);
-                }
-                else {
-                    BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << p.first);
-                }
-            }
-        }
-    }
-    BOOST_REQUIRE_MESSAGE(parse_failure == 0 && ast_failure == 0,
-                          "Found failures parse_failure:" << parse_failure << " ast failure:" << ast_failure);
-}
-
-BOOST_AUTO_TEST_CASE(test_date_to_julian_with_repeat_YMD) {
-    std::cout << "ANode:: ...test_date_to_julian_with_repeat_YMD\n";
-
-    Defs theDefs;
-    suite_ptr suite = theDefs.add_suite("s1");
-    suite->addRepeat(RepeatDate("YMD", 20170101, 20180101, 1));
-    task_ptr t1 = suite->add_task("t1");
-    t1->add_trigger("2457755 == cal::date_to_julian( /s1:YMD )");
-    theDefs.beginAll();
-
-    std::string err_msg, warn_msg;
-    theDefs.check(err_msg, warn_msg);
-    BOOST_REQUIRE_MESSAGE(err_msg.empty() && warn_msg.empty(),
-                          "Expected no errors but found " << err_msg
-                                                          << "\nexpected no warnings but found: " << warn_msg);
-
-    // make sure we can resolve /s1:YMD if this the case bottom_up_why should return vector of size 0
-    std::vector<std::string> theReasonWhy;
-    t1->bottom_up_why(theReasonWhy);
-    BOOST_CHECK_MESSAGE(theReasonWhy.empty(), "When all is well expected empty reason vec");
-
-    // be more flexible, of vector is returned we should not get: variable-not-found
-    for (auto& i : theReasonWhy) {
-        cout << i << "\n";
-        BOOST_CHECK_MESSAGE(i.find("variable-not-found") == string::npos, "Variable YMD not found: " << i);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_trigger_functions_with_boost_date) {
-    std::cout << "ANode:: ...test_trigger_functions_with_boost_date\n";
-    // The map key  = trigger expression,
-    // value.first  = type of the expected root abstract syntax tree
-    // value.second = result of expected evaluation
-    map<string, std::pair<string, bool>> exprMap;
-
-    boost::gregorian::date startDate(2017, 1, 1);
-    boost::gregorian::date endDate(2017, 12, 31);
-    while (startDate != endDate) {
-        long julian_day                    = startDate.julian_day();
-        std::string str_julian_day         = ecf::convert_to<std::string>(julian_day);
-        std::string eight_digit_iso_string = to_iso_string(startDate);
-        string expr   = str_julian_day + " ==  cal::date_to_julian(" + eight_digit_iso_string + ")";
-        exprMap[expr] = std::make_pair(AstEqual::stype(), true);
-
-        std::string ten_digit_string = eight_digit_iso_string + "12";
-        expr                         = str_julian_day + " ==  cal::date_to_julian(" + ten_digit_string + ")";
-        exprMap[expr]                = std::make_pair(AstEqual::stype(), true);
-
-        string expr2   = to_iso_string(startDate) + " == cal::julian_to_date(" + str_julian_day + ")";
-        exprMap[expr2] = std::make_pair(AstEqual::stype(), true);
-        startDate += days(1);
-    }
-
-    int parse_failure = 0;
-    int ast_failure   = 0;
-    for (std::pair<string, std::pair<string, bool>> p : exprMap) {
-
-        // cout << "parsing: " << p.first << "\n";
-        ExprParser theExprParser(p.first);
-        std::string errorMsg;
-        bool ok = theExprParser.doParse(errorMsg);
-        if (!ok)
-            parse_failure++;
-        BOOST_CHECK_MESSAGE(ok, errorMsg + "failed for " + p.first);
-
-        if (ok) {
-            string expectedRootType       = p.second.first;
-            bool expectedEvaluationResult = p.second.second;
-
-            Ast* top = theExprParser.getAst();
-            if (!top)
-                ast_failure++;
-            BOOST_CHECK_MESSAGE(top, "No abstract syntax tree " + p.first);
-            if (top) {
-                BOOST_CHECK_MESSAGE(top->left(), "No root created " + p.first);
-                BOOST_CHECK_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
-                                    "First child of top should be a root or attribute " + p.first);
-                BOOST_CHECK_MESSAGE(top->left()->is_evaluateable(),
-                                    "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
-                BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
-                                    "expected root type '" << expectedRootType << "' or 'variable' but found '"
-                                                           << top->left()->type() << "' " << p.first);
-                BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(),
-                                    "evaluation not as expected for:\n"
-                                        << p.first << "\n"
-                                        << *top);
-
-                std::string error_msg;
-                BOOST_CHECK_MESSAGE(top->check(error_msg), error_msg << ":  Check failed for " << *top);
-            }
-        }
-    }
-    BOOST_REQUIRE_MESSAGE(parse_failure == 0 && ast_failure == 0,
-                          "Found failures parse_failure:" << parse_failure << " ast failure:" << ast_failure);
-}
-
-BOOST_AUTO_TEST_CASE(test_trigger_expression_divide_by_zero) {
-    std::cout << "ANode:: ...test_trigger_expression_divide_by_zero\n";
-
-    // The map key  = trigger expression,
-    // value.first  = type of the expected root abstract syntax tree
-    // value.second = result of expected evaluation
-    map<string, std::pair<string, bool>> exprMap;
-
-    // Divide by zero or modulo by zero would lead to run-time crash
-    // However the Ast::evaluate() checks for this, and return zero for the whole expression i.e ./a:YMD % 0 returns 0
-    exprMap["./a:YMD % 0 == 0"] = std::make_pair(AstEqual::stype(), true);
-    exprMap["./a:YMD / 0 == 0"] = std::make_pair(AstEqual::stype(), true);
-    exprMap[":YMD % 0 == 0"]    = std::make_pair(AstEqual::stype(), true);
-    exprMap[":YMD / 0 == 0"]    = std::make_pair(AstEqual::stype(), true);
-
-    // std::pair<string, std::pair<string,bool> > p;
-    for (const auto& p : exprMap) {
-
-        ExprParser theExprParser(p.first);
-        std::string errorMsg;
-        bool ok = theExprParser.doParse(errorMsg);
-        BOOST_REQUIRE_MESSAGE(ok, errorMsg);
-
-        string expectedRootType       = p.second.first;
-        bool expectedEvaluationResult = p.second.second;
-
-        Ast* top = theExprParser.getAst();
-        BOOST_REQUIRE_MESSAGE(top, "No abstract syntax tree");
-        BOOST_CHECK_MESSAGE(top->left(), "No root created");
-        BOOST_CHECK_MESSAGE(top->left()->isRoot(), "First child of top should be a root");
-        BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType,
-                            "expected root type " << expectedRootType << " but found " << top->left()->type());
-        BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(), "evaluation not as expected for " << *top);
-
-        // expect check to fail, due to divide/modulo by zero
-        std::string error_msg;
-        BOOST_CHECK_MESSAGE(!top->check(error_msg), error_msg << ":  Check failed for " << *top);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_parser_bad_expressions) {
-    std::cout << "ANode:: ...test_parser_bad_expressions\n";
-
-    std::vector expressions = {"/s/f/t<flag>restored"s,
-                               "a <= complete"s,
-                               "a >= complete"s,
-                               "a = complete"s,
-                               "a e complete"s,
-                               "a=complete"s,
-                               "a ! complete"s,
-                               "a==complet e"s,
-                               "a eq complet e"s,
-                               "a::eventname"s,
-                               "a:eventname =  set"s,
-                               "a:eventname == "s,
-                               "a:eventname !  set"s,
-                               "a:eventname ! = set"s,
-                               "a:eventname %"s,
-                               "a:event <= set"s,
-                               "a:event >= set"s,
-                               "a:event >= clear"s,
-                               "a:event >= fred"s,
-                               "a:metername  100"s,
-                               ". == complete"s,
-                               "/ == complete"s,
-                               ". == error"s,
-                               "./ == error"s,
-                               ".a == error"s,
-                               ".a == unknown"s,
-                               ".a/. == unknown"s,
-                               ".. == unknown"s,
-                               ".a/b == queued"s,
-                               "./a/b/ == active"s,
-                               "..a == complete"s,
-                               ".../a == complete"s,
-                               "../.../a == complete"s,
-                               ".. /a == complete"s,
-                               "../.. /a == complete"s,
-                               "../../.a == complete"s,
-                               "..a/b == aborted"s,
-                               "..a/b/c == aborted"s,
-                               "a == complete and"s,
-                               "a %"s,
-                               "(a == complete   b == complete)"s,
-                               "a == complete and  b == complete)"s,
-                               "(a == complete and  b == complete"s,
-                               "(a = complete and b = complete or c = complete)"s,
-                               "(a erro complete and b == complete) or nodepath:eventname"s,
-                               "(a == complete and b == complete or (a == complete and b == complete)"s,
-                               // triggers that don't make sense in the operational suites
-                               "../../../legA/fc/pf/01 eq complete eq complete"s,
-                               "/mofc/mon/hind/14/back == complete or %s:DOW ne 5"s, // ECFLOW-888
-                               ":VAR eq 20001332T257890"s};
-
-    for (const auto& expression : expressions) {
-
-        // std::cout << "parsing expression " << expr << "\n";
-        ExprParser theExprParser(expression);
-        std::string error;
-        auto actual = theExprParser.doParse(error);
-        BOOST_CHECK_MESSAGE(!actual, expression << " expected to fail ");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestExprRepeatDateArithmetic.cpp 5.13.0-1/ANode/test/TestExprRepeatDateArithmetic.cpp
--- 5.12.4-1/ANode/test/TestExprRepeatDateArithmetic.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestExprRepeatDateArithmetic.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,220 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_ExprRepeatDateArithmetic)
-
-BOOST_AUTO_TEST_CASE(test_repeat_data_arithmetic) {
-    cout << "ANode:: ...test_repeat_data_arithmetic\n";
-
-    Defs theDefs;
-    task_ptr t2, t1;
-    {
-        suite_ptr s1 = theDefs.add_suite("s1");
-        t1           = s1->add_task("t1");
-        t1->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
-        t2 = s1->add_task("t2");
-        t2->add_trigger("t1:YMD ge 20080601");
-    }
-    theDefs.beginAll();
-
-    // Check trigger expressions
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
-
-    // Get the trigger AST
-    AstTop* trigger = t2->triggerAst();
-    BOOST_REQUIRE_MESSAGE(trigger, "Expected trigger");
-
-    // check evaluation
-    BOOST_CHECK_MESSAGE(trigger->evaluate(), "Expected trigger to evaluate i.e 20090101 >= 20080601");
-
-    // Check date arithmetic. Basics, end of months
-    t2->changeTrigger("t1:YMD - 1 eq 20081231"); // 20090101 - 1  == 20081231
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
-
-    t2->changeTrigger("t1:YMD + 1 eq 20090102"); // 20090101 + 1  == 20090102
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_data_arithmetic_add_to_end_of_month) {
-    cout << "ANode:: ...test_repeat_data_arithmetic_add_to_end_of_month\n";
-
-    Defs theDefs;
-    task_ptr t2, t1;
-    {
-        suite_ptr s1 = theDefs.add_suite("s1");
-        t1           = s1->add_task("t1");
-        t1->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
-        t2 = s1->add_task("t2");
-        t2->add_trigger("t1:YMD ge 20080601");
-    }
-    theDefs.beginAll();
-
-    // Check trigger expressions
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
-
-    // Check the end of each month + 1
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090131, 20101231, 1)); // jan
-    t2->changeTrigger("t1:YMD + 1 eq 20090201");             // 20090131 + 1  == 20090201
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090228, 20101231, 1)); // feb
-    t2->changeTrigger("t1:YMD + 1 eq 20090301");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090331, 20101231, 1)); // mar
-    t2->changeTrigger("t1:YMD + 1 eq 20090401");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090430, 20101231, 1)); // apr
-    t2->changeTrigger("t1:YMD + 1 eq 20090501");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090531, 20101231, 1)); // may
-    t2->changeTrigger("t1:YMD + 1 eq 20090601");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090630, 20101231, 1)); // June
-    t2->changeTrigger("t1:YMD + 1 eq 20090701");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090731, 20101231, 1)); // July
-    t2->changeTrigger("t1:YMD + 1 eq 20090801");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090831, 20101231, 1)); // Aug
-    t2->changeTrigger("t1:YMD + 1 eq 20090901");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090930, 20101231, 1)); // Sept
-    t2->changeTrigger("t1:YMD + 1 eq 20091001");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20091031, 20101231, 1)); // Oct
-    t2->changeTrigger("t1:YMD + 1 eq 20091101");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20091130, 20101231, 1)); // Nov
-    t2->changeTrigger("t1:YMD + 1 eq 20091201");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20091231, 20101231, 1)); // Dec
-    t2->changeTrigger("t1:YMD + 1 eq 20100101");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_data_arithmetic_take_from_end_of_month) {
-    cout << "ANode:: ...test_repeat_data_arithmetic_take_from_end_of_month\n";
-
-    Defs theDefs;
-    task_ptr t2, t1;
-    {
-        suite_ptr s1 = theDefs.add_suite("s1");
-        t1           = s1->add_task("t1");
-        t1->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
-        t2 = s1->add_task("t2");
-        t2->add_trigger("t1:YMD ge 20080601");
-    }
-    theDefs.beginAll();
-
-    // Check trigger expressions
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
-
-    // Check the end of each month - 1
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090201, 20101231, 1)); // jan
-    t2->changeTrigger("t1:YMD - 1 eq 20090131");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090301, 20101231, 1)); // feb
-    t2->changeTrigger("t1:YMD - 1 eq 20090228");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090401, 20101231, 1)); // mar
-    t2->changeTrigger("t1:YMD - 1 eq 20090331");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090501, 20101231, 1)); // apr
-    t2->changeTrigger("t1:YMD - 1 eq 20090430");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090601, 20101231, 1)); // may
-    t2->changeTrigger("t1:YMD - 1 eq 20090531");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090701, 20101231, 1)); // June
-    t2->changeTrigger("t1:YMD - 1 eq 20090630");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090801, 20101231, 1)); // July
-    t2->changeTrigger("t1:YMD - 1 eq 20090731");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20090901, 20101231, 1)); // Aug
-    t2->changeTrigger("t1:YMD - 1 eq 20090831");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20091001, 20101231, 1)); // Sept
-    t2->changeTrigger("t1:YMD - 1 eq 20090930");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20091101, 20101231, 1)); // Oct
-    t2->changeTrigger("t1:YMD - 1 eq 20091031");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20091201, 20101231, 1)); // Nov
-    t2->changeTrigger("t1:YMD - 1 eq 20091130");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDate("YMD", 20100101, 20101231, 1)); // Dec
-    t2->changeTrigger("t1:YMD - 1 eq 20091231");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestExprRepeatDateListArithmetic.cpp 5.13.0-1/ANode/test/TestExprRepeatDateListArithmetic.cpp
--- 5.12.4-1/ANode/test/TestExprRepeatDateListArithmetic.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestExprRepeatDateListArithmetic.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,220 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_ExprRepeatDateListArithmetic)
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_list_arithmetic) {
-    cout << "ANode:: ... test_repeat_date_list_arithmetic\n";
-
-    Defs theDefs;
-    task_ptr t2, t1;
-    {
-        suite_ptr s1 = theDefs.add_suite("s1");
-        t1           = s1->add_task("t1");
-        t1->addRepeat(RepeatDateList("YMD", {20090101, 20091231}));
-        t2 = s1->add_task("t2");
-        t2->add_trigger("t1:YMD ge 20080601");
-    }
-    theDefs.beginAll();
-
-    // Check trigger expressions
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
-
-    // Get the trigger AST
-    AstTop* trigger = t2->triggerAst();
-    BOOST_REQUIRE_MESSAGE(trigger, "Expected trigger");
-
-    // check evaluation
-    BOOST_CHECK_MESSAGE(trigger->evaluate(), "Expected trigger to evaluate i.e 20090101 >= 20080601");
-
-    // Check date arithmetic. Basics, end of months
-    t2->changeTrigger("t1:YMD - 1 eq 20081231"); // 20090101 - 1  == 20081231
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
-
-    t2->changeTrigger("t1:YMD + 1 eq 20090102"); // 20090101 + 1  == 20090102
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_list_arithmetic_add_to_end_of_month) {
-    cout << "ANode:: ...test_repeat_date_list_arithmetic_add_to_end_of_month \n";
-
-    Defs theDefs;
-    task_ptr t2, t1;
-    {
-        suite_ptr s1 = theDefs.add_suite("s1");
-        t1           = s1->add_task("t1");
-        t1->addRepeat(RepeatDateList("YMD", {20090101, 20091231}));
-        t2 = s1->add_task("t2");
-        t2->add_trigger("t1:YMD ge 20080601");
-    }
-    theDefs.beginAll();
-
-    // Check trigger expressions
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
-
-    // Check the end of each month + 1
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090131, 20101231})); // jan
-    t2->changeTrigger("t1:YMD + 1 eq 20090201");                // 20090131 + 1  == 20090201
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090228, 20101231})); // feb
-    t2->changeTrigger("t1:YMD + 1 eq 20090301");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090331, 20101231})); // mar
-    t2->changeTrigger("t1:YMD + 1 eq 20090401");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090430, 20101231})); // apr
-    t2->changeTrigger("t1:YMD + 1 eq 20090501");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090531, 20101231})); // may
-    t2->changeTrigger("t1:YMD + 1 eq 20090601");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090630, 20101231})); // June
-    t2->changeTrigger("t1:YMD + 1 eq 20090701");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090731, 20101231})); // July
-    t2->changeTrigger("t1:YMD + 1 eq 20090801");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090831, 20101231})); // Aug
-    t2->changeTrigger("t1:YMD + 1 eq 20090901");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090930, 20101231})); // Sept
-    t2->changeTrigger("t1:YMD + 1 eq 20091001");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20091031, 20101231})); // Oct
-    t2->changeTrigger("t1:YMD + 1 eq 20091101");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20091130, 20101231})); // Nov
-    t2->changeTrigger("t1:YMD + 1 eq 20091201");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20091231, 20101231})); // Dec
-    t2->changeTrigger("t1:YMD + 1 eq 20100101");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_list_arithmetic_take_from_end_of_month) {
-    cout << "ANode:: ... test_repeat_date_list_arithmetic_take_from_end_of_month\n";
-
-    Defs theDefs;
-    task_ptr t2, t1;
-    {
-        suite_ptr s1 = theDefs.add_suite("s1");
-        t1           = s1->add_task("t1");
-        t1->addRepeat(RepeatDateList("YMD", {20090101, 20091231}));
-        t2 = s1->add_task("t2");
-        t2->add_trigger("t1:YMD ge 20080601");
-    }
-    theDefs.beginAll();
-
-    // Check trigger expressions
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
-
-    // Check the end of each month - 1
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090201, 20101231})); // jan
-    t2->changeTrigger("t1:YMD - 1 eq 20090131");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090301, 20101231})); // feb
-    t2->changeTrigger("t1:YMD - 1 eq 20090228");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090401, 20101231})); // mar
-    t2->changeTrigger("t1:YMD - 1 eq 20090331");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090501, 20101231})); // apr
-    t2->changeTrigger("t1:YMD - 1 eq 20090430");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090601, 20101231})); // may
-    t2->changeTrigger("t1:YMD - 1 eq 20090531");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090701, 20101231})); // June
-    t2->changeTrigger("t1:YMD - 1 eq 20090630");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090801, 20101231})); // July
-    t2->changeTrigger("t1:YMD - 1 eq 20090731");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20090901, 20101231})); // Aug
-    t2->changeTrigger("t1:YMD - 1 eq 20090831");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20091001, 20101231})); // Sept
-    t2->changeTrigger("t1:YMD - 1 eq 20090930");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20091101, 20101231})); // Oct
-    t2->changeTrigger("t1:YMD - 1 eq 20091031");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20091201, 20101231})); // Nov
-    t2->changeTrigger("t1:YMD - 1 eq 20091130");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-
-    t1->deleteRepeat();
-    t1->addRepeat(RepeatDateList("YMD", {20100101, 20101231})); // Dec
-    t2->changeTrigger("t1:YMD - 1 eq 20091231");
-    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestFindAbsNodePath.cpp 5.13.0-1/ANode/test/TestFindAbsNodePath.cpp
--- 5.12.4-1/ANode/test/TestFindAbsNodePath.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestFindAbsNodePath.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_FindAbsNodePath)
-
-BOOST_AUTO_TEST_CASE(test_find_abs_node_path) {
-    cout << "ANode:: ...test_find_abs_node_path\n";
-
-    size_t no_of_nodes = 0;
-    size_t no_of_alias = 0;
-    Defs theDefs;
-    {
-        for (int s = 0; s < 3; s++) {
-            suite_ptr suite = theDefs.add_suite("suite" + ecf::convert_to<std::string>(s));
-            no_of_nodes++;
-            for (int f = 0; f < 3; f++) {
-                family_ptr fam = suite->add_family("family" + ecf::convert_to<std::string>(f));
-                no_of_nodes++;
-                for (int ff = 0; ff < 3; ff++) {
-                    family_ptr hfam = fam->add_family("family" + ecf::convert_to<std::string>(ff));
-                    no_of_nodes++;
-                    for (int t = 0; t < 3; t++) {
-                        task_ptr task = hfam->add_task("t1" + ecf::convert_to<std::string>(t));
-                        no_of_nodes++;
-                        for (int a = 0; a < 3; a++) {
-                            task->add_alias_only();
-                            no_of_nodes++;
-                            no_of_alias++;
-                        }
-                    }
-                }
-            }
-        }
-    }
-
-    // Test Defs::getAllNodes()
-    std::vector<Node*> all_nodes;
-    theDefs.getAllNodes(all_nodes);
-    BOOST_CHECK_MESSAGE(all_nodes.size() == no_of_nodes,
-                        "Expected theDefs.getAllNodes() to return " << no_of_nodes << " node, but found "
-                                                                    << all_nodes.size());
-
-    // Test Defs::get_all_aliases()
-    std::vector<alias_ptr> alias_vec;
-    theDefs.get_all_aliases(alias_vec);
-    BOOST_CHECK_MESSAGE(alias_vec.size() == no_of_alias,
-                        "Expected theDefs.get_all_aliases() to return " << no_of_alias << " node, but found "
-                                                                        << alias_vec.size());
-
-    // Test Defs::findAbsNode()
-    //   PrintStyle style(PrintStyle::STATE); std::cout << theDefs;
-    for (auto node : all_nodes) {
-        node_ptr found_node = theDefs.findAbsNode(node->absNodePath());
-        BOOST_CHECK_MESSAGE(found_node.get(), "Could not find node " << node->debugNodePath());
-        BOOST_CHECK_MESSAGE(found_node.get() == node,
-                            " Expected to find " << node->debugNodePath() << " but found "
-                                                 << found_node->debugNodePath());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestFlag.cpp 5.13.0-1/ANode/test/TestFlag.cpp
--- 5.12.4-1/ANode/test/TestFlag.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestFlag.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Flag.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Flag)
-
-BOOST_AUTO_TEST_CASE(test_node_flags) {
-    cout << "ANode:: ...test_node_flags\n";
-
-    Flag flag;
-    std::string expected_flags =
-        "force_aborted,user_edit,task_aborted,edit_failed,ecfcmd_failed,killcmd_failed,statuscmd_failed,no_script,"
-        "killed,status,late,message,by_rule,queue_limit,task_waiting,locked,zombie,no_reque,archived,restored,"
-        "threshold,sigterm,log_error,checkpt_error";
-
-    /// Set the flags
-    std::vector<Flag::Type> flag_list = Flag::list();
-    for (auto& i : flag_list) {
-        flag.set(i);
-        BOOST_REQUIRE_MESSAGE(flag.is_set(i), "Expected flag to be set");
-    }
-    BOOST_REQUIRE_MESSAGE(flag.to_string() == expected_flags,
-                          "Expected string '" << expected_flags << "' but found '" << flag.to_string() << "'");
-    for (auto& i : flag_list) {
-        BOOST_REQUIRE_MESSAGE(flag.is_set(i), "Expected flag to be set");
-    }
-
-    /// clears the flags
-    for (auto& i : flag_list) {
-        flag.clear(i);
-        BOOST_REQUIRE_MESSAGE(!flag.is_set(i), "Expected flag to be clear");
-    }
-    for (auto& i : flag_list) {
-        BOOST_REQUIRE_MESSAGE(!flag.is_set(i), "Expected flag to be clear");
-    }
-
-    /// set all flags
-    for (auto& i : flag_list) {
-        flag.set(i);
-    }
-
-    // reset, all flags should be clear
-    flag.reset();
-    for (auto& i : flag_list) {
-        BOOST_REQUIRE_MESSAGE(!flag.is_set(i), "Expected flag to be clear");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_node_flags_parsing) {
-    cout << "ANode:: ...test_node_flags_parsing\n";
-
-    /// Set the flags
-    Flag flag;
-    std::vector<Flag::Type> flag_list = Flag::list();
-    for (auto& i : flag_list)
-        flag.set(i);
-
-    Flag flag2;
-    flag2.set_flag(flag.to_string());
-    BOOST_REQUIRE_MESSAGE(flag == flag2,
-                          "Flags should be equal.\nflag1:" << flag.to_string() << "\nflag2:" << flag2.to_string());
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestHistoryParser.cpp 5.13.0-1/ANode/test/TestHistoryParser.cpp
--- 5.12.4-1/ANode/test/TestHistoryParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestHistoryParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,112 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <iterator>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_HistoryParser)
-
-static std::string dump(const std::vector<std::string>& vec) {
-    std::stringstream ss;
-    std::copy(vec.begin(), vec.end(), std::ostream_iterator<std::string>(ss, "\n"));
-    return ss.str();
-}
-
-BOOST_AUTO_TEST_CASE(test_defs_history_parser) {
-    cout << "ANode:: ...test_defs_history_parser\n";
-
-    {
-        string str1("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
-        DefsHistoryParser parser;
-        parser.parse(str1);
-
-        std::vector<std::string> expected_messages;
-        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
-
-        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
-                            "Expected:\n"
-                                << dump(expected_messages) << "but found:\n"
-                                << dump(parser.parsed_messages()));
-    }
-    {
-        string str1("MSG:[12:03:55 21.8.2013] --shutdown=yes :mapMSG:[12:34:08 21.8.2013] --restart :map");
-        DefsHistoryParser parser;
-        parser.parse(str1);
-
-        std::vector<std::string> expected_messages;
-        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
-        expected_messages.emplace_back("MSG:[12:34:08 21.8.2013] --restart :map");
-        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
-                            "Expected:\n"
-                                << dump(expected_messages) << "but found:\n"
-                                << dump(parser.parsed_messages()));
-    }
-    {
-        string str1(
-            "MSG:[12:03:55 21.8.2013] --shutdown=yes :mapMSG:[12:34:08 21.8.2013] --restart :mapMSG:[12:47:22 "
-            "21.8.2013] --alter add variable SMSNODE 0 /  :mapMSG:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 "
-            "/  :mapMSG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :mapMSG:[15:36:14 "
-            "21.8.2013] --shutdown=yes :mapMSG:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
-        DefsHistoryParser parser;
-        parser.parse(str1);
-
-        std::vector<std::string> expected_messages;
-        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
-        expected_messages.emplace_back("MSG:[12:34:08 21.8.2013] --restart :map");
-        expected_messages.emplace_back("MSG:[12:47:22 21.8.2013] --alter add variable SMSNODE 0 /  :map");
-        expected_messages.emplace_back("MSG:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 /  :map");
-        expected_messages.emplace_back(
-            "MSG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :map");
-        expected_messages.emplace_back("MSG:[15:36:14 21.8.2013] --shutdown=yes :map");
-        expected_messages.emplace_back("MSG:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
-        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
-                            "Expected:\n"
-                                << dump(expected_messages) << "but found:\n"
-                                << dump(parser.parsed_messages()));
-    }
-    {
-        string str1(
-            "MSG:[12:03:55 21.8.2013] --shutdown=yes :mapLOG:[12:34:08 21.8.2013] --restart :mapERR:[12:47:22 "
-            "21.8.2013] --alter add variable SMSNODE 0 /  :mapWAR:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 "
-            "/  :mapDBG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :mapOTH:[15:36:14 "
-            "21.8.2013] --shutdown=yes :mapOTH:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
-        DefsHistoryParser parser;
-        parser.parse(str1);
-
-        std::vector<std::string> expected_messages;
-        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
-        expected_messages.emplace_back("LOG:[12:34:08 21.8.2013] --restart :map");
-        expected_messages.emplace_back("ERR:[12:47:22 21.8.2013] --alter add variable SMSNODE 0 /  :map");
-        expected_messages.emplace_back("WAR:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 /  :map");
-        expected_messages.emplace_back(
-            "DBG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :map");
-        expected_messages.emplace_back("OTH:[15:36:14 21.8.2013] --shutdown=yes :map");
-        expected_messages.emplace_back("OTH:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
-        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
-                            "Expected:\n"
-                                << dump(expected_messages) << "but found:\n"
-                                << dump(parser.parsed_messages()));
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestInLimit.cpp 5.13.0-1/ANode/test/TestInLimit.cpp
--- 5.12.4-1/ANode/test/TestInLimit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestInLimit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,125 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestSerialisation.hpp"
-#include "ecflow/node/InLimit.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_InLimit)
-
-BOOST_AUTO_TEST_CASE(test_inlimit_basics) {
-    cout << "ANode:: ...test_inlimit_basics \n";
-    {
-        InLimit empty;
-        InLimit empty2;
-        BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
-
-        InLimit l1("name", "path");
-        InLimit l2("name", "path");
-        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
-
-        InLimit a("name", "path", 10);
-        InLimit b("name", "path");
-        BOOST_CHECK_MESSAGE(!(a == b), "Equality passed when should fail");
-    }
-    {
-        InLimit inlim("fred", "/path/to/node", 1, true);
-        {
-            InLimit testCopy = inlim;
-            BOOST_CHECK_MESSAGE(testCopy == inlim, "Copy constructor failed");
-        }
-        {
-            InLimit testCopy;
-            testCopy = inlim;
-            BOOST_CHECK_MESSAGE(testCopy == inlim, "Assignment failed");
-        }
-    }
-    {
-        InLimit inlim("fred", "/path/to/node", 1, false);
-        {
-            InLimit testCopy = inlim;
-            BOOST_CHECK_MESSAGE(testCopy == inlim, "Copy constructor failed");
-        }
-        {
-            InLimit testCopy;
-            testCopy = inlim;
-            BOOST_CHECK_MESSAGE(testCopy == inlim, "Assignment failed");
-        }
-    }
-    {
-        InLimit inlim("fred", "/path/to/node", 1, false, true);
-        {
-            InLimit testCopy = inlim;
-            BOOST_CHECK_MESSAGE(testCopy == inlim, "Copy constructor failed");
-        }
-        {
-            InLimit testCopy;
-            testCopy = inlim;
-            BOOST_CHECK_MESSAGE(testCopy == inlim, "Assignment failed");
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_inlimit_duplicates) {
-    cout << "ANode:: ...test_inlimit_duplicates \n";
-
-    InLimit inlim("fred", "/path/to/node", 1, true);
-
-    task_ptr task = Task::create("task");
-    task->addInLimit(inlim);
-
-    // duplicate should throw
-    BOOST_REQUIRE_THROW(task->addInLimit(inlim), std::runtime_error);
-
-    // still a duplicate
-    InLimit inlim2("fred", "/path/to/node");
-    BOOST_REQUIRE_THROW(task->addInLimit(inlim2), std::runtime_error);
-}
-
-// Globals used throughout the test
-static std::string fileName = "test_InLimit_serialisation.txt";
-BOOST_AUTO_TEST_CASE(test_InLimit_serialisation) {
-    cout << "ANode:: ...test_InLimit_serialisation\n";
-    {
-        // save and restore the default constructor
-        doSaveAndRestore<InLimit>(fileName);
-
-        InLimit saved("limitName", "/path/to/some/node", 20, true);
-        save(fileName, saved);
-
-        InLimit restored;
-        restore(fileName, restored);
-        BOOST_CHECK_MESSAGE(saved == restored, " save and restored don't match");
-        std::remove(fileName.c_str());
-    }
-    {
-        InLimit saved("limitName", "/path/to/some/node", 20, false, true);
-        save(fileName, saved);
-
-        InLimit restored;
-        restore(fileName, restored);
-        BOOST_CHECK_MESSAGE(saved == restored, " save and restored don't match");
-        std::remove(fileName.c_str());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestJobCreator.cpp 5.13.0-1/ANode/test/TestJobCreator.cpp
--- 5.12.4-1/ANode/test/TestJobCreator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestJobCreator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,116 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_JobCreator)
-
-BOOST_AUTO_TEST_CASE(test_job_creator) {
-    cout << "ANode:: ...test_job_creator\n";
-
-    // SET SMSHOME
-    std::string ecf_home = File::test_data("ANode/test/data/SMSHOME", "ANode");
-
-    // Create the defs file corresponding to the text below
-    // # Test the sms file can be found via ECF_SCRIPT
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // #
-    // suite suite
-    //	edit SLEEPTIME 10
-    //	edit ECF_INCLUDE $ECF_HOME/includes
-    //	family family
-    //   	task t1
-    //   	task t2
-    //    	task t3
-    //  	endfamily
-    // endsuite
-    // #
-    // # This test suite should force a backwards search since the sms files
-    // # are located in SMSHOME
-    // suite suite1
-    //    family family
-    //   		task suite1_task1
-    //   		task suite1_task2
-    //    	    task suite1_task3
-    //    endfamily
-    // endsuite
-    // Create a defs file, where the task name mirrors the sms files in the given directory
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("suite");
-        family_ptr fam  = Family::create("family");
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/../includes"));
-        suite->addVariable(Variable("SLEEPTIME", "1"));
-        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
-        fam->addTask(Task::create("t1"));
-        fam->addTask(Task::create("t2"));
-        fam->addTask(Task::create("t3"));
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-    {
-        suite_ptr suite1(new Suite("suite1"));
-        family_ptr fam(new Family("family"));
-        fam->addTask(Task::create("suite1_task1"));
-        fam->addTask(Task::create("suite1_task2"));
-        fam->addTask(Task::create("suite1_task3"));
-        suite1->addFamily(fam);
-        theDefs.addSuite(suite1);
-    }
-    // 	cerr << theDefs << "\n";
-
-    // get all the task, assume non hierarchical families
-    std::vector<Task*> theTasks;
-    theDefs.getAllTasks(theTasks);
-    BOOST_REQUIRE_MESSAGE(theTasks.size() == 6, "Expected 6 tasks but found, " << theTasks.size());
-
-    // Override ECF_HOME.   ECF_HOME is need to locate to the .ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    // Test Job creator. The job creation should succeed 3 times only, since
-    // the sms file suite1_task1, suite1_task2,suite1_task3 are empty.
-    JobsParam jobsParam(true /*create jobs*/); // spawn_jobs = false
-    Jobs jobs(&theDefs);
-    jobs.generate(jobsParam);
-    BOOST_REQUIRE_MESSAGE(jobsParam.submitted().size() == 3,
-                          "expected 3 jobs but found " << jobsParam.submitted().size() << "\n"
-                                                       << jobsParam.errorMsg());
-
-    // Expect error message complaining about sms file suite1_task1, suite1_task2,suite1_task3 being empty
-    BOOST_REQUIRE_MESSAGE(!jobsParam.errorMsg().empty(), "expected error message about empty ecf files");
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestJobProfiler.cpp 5.13.0-1/ANode/test/TestJobProfiler.cpp
--- 5.12.4-1/ANode/test/TestJobProfiler.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestJobProfiler.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_JobProfiler)
-
-BOOST_AUTO_TEST_CASE(test_job_profiler) {
-    cout << "ANode:: ...test_job_profiler\n";
-
-    // delete the log file if it exists.
-    std::string log_path = File::test_data("ANode/test/logfile.txt", "ANode");
-    fs::remove(log_path);
-    BOOST_CHECK_MESSAGE(!fs::exists(log_path), "log file " << log_path << " not deleted ");
-
-    // Create a new log, file, we will look in here to see if job profiling is working
-    // Hence this test relies on output to be flushed
-    TestLog test_log(log_path); // will create log file, and destroy log and remove file at end of scope
-
-    // SET ECF_HOME, re-use exist test of directory and scripts
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), File::test_data("ANode/test/data/includes", "ANode")));
-        suite->addVariable(Variable("ECF_HOME", File::test_data("ANode/test/data/SMSHOME", "ANode")));
-        suite->addVariable(Variable("SLEEPTIME", "10"));
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t1");
-    }
-    // cerr << theDefs << "\n";
-
-    // begin , will cause creation of generated variables. The generated variables
-    // are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    // By setting submitJobsInterval to -1, we enable the jobs profiling testing
-    // createJobs enables us to ensure job size is profiled
-    // spawn jobs set to false, do not create a separate process to spawn jobs
-    JobsParam jobParam(-1 /*submitJobsInterval*/, true /*createJobs*/, false /* spawn jobs */);
-    Jobs job(&theDefs);
-    bool ok = job.generate(jobParam);
-    BOOST_CHECK_MESSAGE(ok, "generate failed: " << jobParam.getErrorMsg());
-
-    // Check the log file, has the profiling
-    Log::instance()->flush_only();
-    std::string log_file_contents;
-    BOOST_CHECK_MESSAGE(File::open(log_path, log_file_contents),
-                        "Could not open log file at " << log_path << " (" << strerror(errno) << ")");
-    BOOST_CHECK_MESSAGE(!log_file_contents.empty(), "log file is is empty ?");
-    BOOST_CHECK_MESSAGE(log_file_contents.find("Exceeds ECF_TASK_THRESHOLD") != std::string::npos,
-                        "Exceeds ECF_TASK_THRESHOLD  not in profile");
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestLimit.cpp 5.13.0-1/ANode/test/TestLimit.cpp
--- 5.12.4-1/ANode/test/TestLimit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestLimit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,216 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestSerialisation.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/Limit.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Limit)
-
-BOOST_AUTO_TEST_CASE(test_limit_basics) {
-    cout << "ANode:: ...test_limit_basics \n";
-
-    {
-        Limit empty;
-        Limit empty2;
-        BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
-
-        Limit l1("name", 2);
-        Limit l2("name", 2);
-        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
-
-        Limit l3("name", 2);
-        Limit l4("name", 4);
-        BOOST_CHECK_MESSAGE(!(l3 == l4), "Equality failed");
-    }
-
-    std::set<std::string> expected_empty_paths;
-    std::set<std::string> expected_paths;
-
-    Limit l1("name", 100);
-    for (int i = 1; i < 10; i++) {
-        std::string path = ecf::convert_to<std::string>(i);
-        expected_paths.insert(path);
-        l1.increment(1, path);
-        BOOST_CHECK_MESSAGE(l1.paths() == expected_paths, "Expected paths not the same at " << i);
-    }
-
-    for (int i = 9; i >= 1; i--) {
-        std::string path = ecf::convert_to<std::string>(i);
-        l1.decrement(1, path);
-        auto iter = expected_paths.find(path);
-        expected_paths.erase(iter);
-
-        if (l1.paths() != expected_paths) {
-            std::cout << " Expected:";
-            std::copy(expected_paths.begin(), expected_paths.end(), std::ostream_iterator<std::string>(std::cout, " "));
-            std::cout << "    Found:";
-            std::copy(l1.paths().begin(), l1.paths().end(), std::ostream_iterator<std::string>(std::cout, " "));
-        }
-        BOOST_CHECK_MESSAGE(l1.paths() == expected_paths, "Expected paths not the same at " << i);
-    }
-
-    expected_paths.insert("/a/b/c");
-    l1.increment(1, "/a/b/c");
-    BOOST_CHECK_MESSAGE(l1.paths() == expected_paths, "Expected paths not the same");
-
-    l1.decrement(1, "/a/b/c");
-    BOOST_CHECK_MESSAGE(l1.paths() == expected_empty_paths, "Expected paths not the same");
-    BOOST_CHECK_MESSAGE(l1.value() == 0, "Expected value to be 0");
-
-    l1.increment(1, "/a/b/c");
-    l1.increment(1, "/a/b/d");
-    BOOST_CHECK_MESSAGE(l1.paths().size() == 2, "Expected 2 paths but found " << l1.paths().size());
-    BOOST_CHECK_MESSAGE(l1.value() == 2, "Expected value to be 2 but found " << l1.value());
-    l1.reset();
-    BOOST_CHECK_MESSAGE(l1.value() == 0, "Expected value to be 0 after reset, but found " << l1.value());
-    BOOST_CHECK_MESSAGE(l1.paths().size() == 0, "Expected 0 paths after reset but found " << l1.paths().size());
-
-    l1.setValue(10);
-    BOOST_CHECK_MESSAGE(l1.value() == 10, "Expected value to be 10, but found " << l1.value());
-    BOOST_CHECK_MESSAGE(l1.paths().size() == 0, "Expected 0 paths after reset but found " << l1.paths().size());
-}
-
-BOOST_AUTO_TEST_CASE(test_limit_increment) {
-    cout << "ANode:: ...test_limit_increment\n";
-
-    Limit limit("name", 10);    // Limit of 10
-    limit.increment(1, "path"); // consume 1 token
-
-    BOOST_CHECK_MESSAGE(limit.value() == 1,
-                        "Expected increment to consume 1 token but it has consumed " << limit.value());
-    BOOST_CHECK_MESSAGE(limit.paths().size() == 1, "Expected 1 task path but found " << limit.paths().size());
-
-    limit.increment(1, "path"); // Increment with same path, should *NOT* consume a token
-
-    BOOST_CHECK_MESSAGE(limit.value() == 1, "Expected 1 token but it has consumed " << limit.value());
-    BOOST_CHECK_MESSAGE(limit.paths().size() == 1, "Expected 1 task path but found " << limit.paths().size());
-}
-
-BOOST_AUTO_TEST_CASE(test_limit_increment_2) {
-    cout << "ANode:: ...test_limit_increment_2\n";
-
-    Limit limit("name", 10); // Limit of 10
-    for (int i = 0; i < 20; i++) {
-        // increment should keep increasing limit value, *EVEN* if over the limit. See ECFLOW-324
-        std::string path = ecf::convert_to<std::string>(i);
-        limit.increment(1, path);
-        BOOST_CHECK_MESSAGE(limit.value() == i + 1,
-                            "Expected limit value of " << i + 1 << " but found " << limit.value());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_limit_decrement) {
-    cout << "ANode:: ...test_limit_decrement\n";
-
-    Ecf::set_server(true); // needed to test state_change_numbers
-
-    Limit limit("name", 10); // Limit of 10
-    unsigned int expected_state_change_no = limit.state_change_no();
-
-    limit.increment(1, "path");
-    expected_state_change_no++; // consume 1 token, should increment state change no
-    BOOST_CHECK_MESSAGE(limit.value() == 1, "Expected limit of value 1  but found " << limit.value());
-    BOOST_CHECK_MESSAGE(limit.paths().size() == 1, "Expected 1 task path but found " << limit.paths().size());
-    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
-                        "Expected increment to increase state change no, expected "
-                            << expected_state_change_no << " but found " << limit.state_change_no());
-
-    // Since 'path_x' is NOT in the list of paths stored by the limit, there should be NO change to state_change_no
-    limit.decrement(1, "path_x");
-    BOOST_CHECK_MESSAGE(
-        limit.value() == 1,
-        " decrement of path that does not exist, should not affect the Limit: Expected limit of value 1  but found "
-            << limit.value());
-    BOOST_CHECK_MESSAGE(
-        limit.paths().size() == 1,
-        " decrement of path that does not exist, should not affect the Limit : Expected 1 task path but found "
-            << limit.paths().size());
-    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
-                        "Expected no change in state change no, expected " << expected_state_change_no << " but found "
-                                                                           << limit.state_change_no());
-
-    // Multiple decrements should leave Limit of value = 0, and not a negative number
-    limit.decrement(1, "path");
-    expected_state_change_no++;
-    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
-                        "Expected decrement to increase state change no, expected "
-                            << expected_state_change_no << " but found " << limit.state_change_no());
-
-    // Since we have removed 'path' from the limit expect no further state changes
-    limit.decrement(1, "path");
-    limit.decrement(1, "path");
-    limit.decrement(1, "path");
-    BOOST_CHECK_MESSAGE(limit.value() == 0, "Expected limit of value 0  but found " << limit.value());
-    BOOST_CHECK_MESSAGE(limit.paths().size() == 0, "Expected no task paths but found " << limit.paths().size());
-    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
-                        "Expected no change to state change no, expected " << expected_state_change_no << " but found "
-                                                                           << limit.state_change_no());
-
-    Ecf::set_server(false); // needed to test state_change_numbers
-    // reset, to avoid effecting downstream tests
-    Ecf::set_state_change_no(0);
-    Ecf::set_modify_change_no(0);
-}
-
-BOOST_AUTO_TEST_CASE(test_limit_set_value) {
-    cout << "ANode:: ...test_limit_set_value\n";
-
-    Limit limit("name", 10);     // Limit of 10
-    limit.increment(1, "path");  // consume 1 token
-    limit.increment(1, "path2"); // consume 1 token
-
-    BOOST_CHECK_MESSAGE(limit.value() == 2,
-                        "Expected increment to consume 2 token but it has consumed " << limit.value());
-    BOOST_CHECK_MESSAGE(limit.paths().size() == 2, "Expected 2 task paths but found " << limit.paths().size());
-
-    limit.setValue(4);
-    BOOST_CHECK_MESSAGE(limit.value() == 4, "Expected setValue(4) but value found is: " << limit.value());
-    BOOST_CHECK_MESSAGE(limit.paths().size() == 2, "Expected 2 task paths but found " << limit.paths().size());
-
-    limit.setValue(0);
-    BOOST_CHECK_MESSAGE(limit.value() == 0, "Expected setValue(0) but found " << limit.value());
-    BOOST_CHECK_MESSAGE(limit.paths().empty(),
-                        "Setting value to zero should clear the paths, but found " << limit.paths().size());
-}
-
-// Globals used throughout the test
-static std::string fileName = "testLimit.txt";
-BOOST_AUTO_TEST_CASE(test_LimitDefaultConstructor_serialisation) {
-    cout << "ANode:: ...test_LimitDefaultConstructor_serialisation \n";
-
-    doSaveAndRestore<Limit>(fileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_Limit_serialisation) {
-    cout << "ANode:: ...test_Limit_serialisation\n";
-    Limit saved1("limitName", 100);
-    doSaveAndRestore(fileName, saved1);
-
-    std::set<std::string> paths;
-    paths.insert("path1");
-    paths.insert("path2");
-    Limit saved2("limitName", 100, 10, paths);
-    doSaveAndRestore(fileName, saved2);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestMigration.cpp 5.13.0-1/ANode/test/TestMigration.cpp
--- 5.12.4-1/ANode/test/TestMigration.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "TestSerialisation.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-// #define UPDATE_TESTS 1
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Migration)
-
-BOOST_AUTO_TEST_CASE(test_default_constructor_persistence) {
-    cout << "ANode:: ...test_default_constructor_persistence\n";
-
-    std::string file_name = File::test_data("ANode/test/data/migration/", "ANode");
-
-    Defs defs;
-    Suite suite;
-    Family family;
-    Task task;
-
-    // Can't persist server variable are dependent on HOST.i.e ECF_LISTS,ECF_CHECK,etc
-    // Hence is not cross-platform
-    doSave(file_name + "Defs.def", defs);
-
-#ifdef UPDATE_TESTS
-    doSave(file_name + "Suite.def", suite);
-    doSave(file_name + "Family.def", family);
-    doSave(file_name + "Task.def", task);
-    doSave(file_name + "Limit.def", Limit());
-#endif
-
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    do_restore<Defs>(file_name + "Defs.def", defs);
-    do_restore<Suite>(file_name + "Suite.def", suite);
-    do_restore<Family>(file_name + "Family.def", family);
-    do_restore<Task>(file_name + "Task.def", task);
-    do_restore<Limit>(file_name + "Limit.def", Limit());
-
-    fs::remove(file_name + "Defs.def"); // Remove the file. Comment out for debugging
-}
-
-BOOST_AUTO_TEST_CASE(test_compare_cereal_and_defs_checkpt_file) {
-    cout << "ANode:: ...test_compare_cereal_and_defs_checkpt_file\n";
-
-    std::string file_name = File::test_data("ANode/test/data/migration/", "ANode");
-
-    // Cannot save these tests since server variable use HOST which is different for each platform
-    MyDefsFixture fixture;
-    doSave(file_name + "cereal.checkpt", fixture.fixtureDefsFile());
-    fixture.fixtureDefsFile().save_as_checkpt(file_name + "defs.checkpt");
-
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    do_restore<Defs>(file_name + "cereal.checkpt", fixture.fixtureDefsFile());
-
-    Defs defs;
-    defs.restore(file_name + "defs.checkpt");
-    BOOST_CHECK_MESSAGE(defs == fixture.fixtureDefsFile(), " ");
-
-    fs::remove(file_name + "defs.checkpt");   // Remove the file. Comment out for debugging
-    fs::remove(file_name + "cereal.checkpt"); // Remove the file. Comment out for debugging
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestMissNextTimeSlot.cpp 5.13.0-1/ANode/test/TestMissNextTimeSlot.cpp
--- 5.12.4-1/ANode/test/TestMissNextTimeSlot.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestMissNextTimeSlot.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,121 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_MissNextTimeSlot)
-
-BOOST_AUTO_TEST_CASE(test_miss_next_time_slot) {
-    cout << "ANode:: ...test_miss_next_time_slot\n";
-
-    // Start TIME at 9:30
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user set of time slots. In this case the node should complete and then
-    // requee and miss the next time. If this is repeated, eventually we should reach the
-    // end of the time slot. In which case the node should *not* re-queue and stay complete
-    //
-    // When the node is then re-queued check that the time has been correctly reset.
-
-    //   suite s1
-    //       task t1
-    //          time 10:00
-    //          time 11:00
-    //          time 12:00
-    //          time 13:00
-    //   endsuite
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    task_ptr t1     = suite->add_task("t1");
-    t1->addTime(TimeAttr(10, 0));
-    t1->addTime(TimeAttr(11, 0));
-    t1->addTime(TimeAttr(12, 0));
-    t1->addTime(TimeAttr(13, 0));
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // *start* at 9:30
-    suite->addClock(clockAttr);
-
-    suite->begin();
-
-    // get all the time attributes
-    const TimeSeries& ts_10 = t1->timeVec()[0].time_series();
-    const TimeSeries& ts_11 = t1->timeVec()[1].time_series();
-    const TimeSeries& ts_12 = t1->timeVec()[2].time_series();
-    const TimeSeries& ts_13 = t1->timeVec()[3].time_series();
-    BOOST_CHECK_MESSAGE(ts_10.is_valid(), "Expected time 10 to be valid since we started at 9:30 ");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
-
-    const TimeSlot& time_10 = t1->timeVec()[0].time_series().get_next_time_slot();
-    const TimeSlot& time_11 = t1->timeVec()[1].time_series().get_next_time_slot();
-    const TimeSlot& time_12 = t1->timeVec()[2].time_series().get_next_time_slot();
-    const TimeSlot& time_13 = t1->timeVec()[3].time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(time_10 == TimeSlot(10, 0),
-                        "Expected next time slot of 10:00 but found " << time_10.toString());
-    BOOST_CHECK_MESSAGE(time_11 == TimeSlot(11, 0),
-                        "Expected next time slot of 11:00 but found " << time_11.toString());
-    BOOST_CHECK_MESSAGE(time_12 == TimeSlot(12, 0),
-                        "Expected next time slot of 12:00 but found " << time_12.toString());
-    BOOST_CHECK_MESSAGE(time_13 == TimeSlot(13, 0),
-                        "Expected next time slot of 13:00 but found " << time_13.toString());
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    t1->miss_next_time_slot();
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set,");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
-
-    // Calling miss_next_time_slot again, should have *NO* effect, since its only takes affect when
-    // NO_REQUE_IF_SINGLE_TIME_DEP is clear
-    t1->miss_next_time_slot();
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set,");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
-
-    // Clear the flag and call miss_next_time_slot, this time an additional time slot should have expired
-    t1->flag().clear(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
-    t1->miss_next_time_slot();
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
-
-    // call twice more, to expire all time slots
-    t1->flag().clear(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
-    t1->miss_next_time_slot();
-    t1->flag().clear(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
-    t1->miss_next_time_slot();
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired");
-    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired");
-    BOOST_CHECK_MESSAGE(!ts_13.is_valid(), "Expected time 13 to be expired");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestMovePeer.cpp 5.13.0-1/ANode/test/TestMovePeer.cpp
--- 5.12.4-1/ANode/test/TestMovePeer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestMovePeer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,104 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_MovePeer)
-
-BOOST_AUTO_TEST_CASE(test_move_peer) {
-    cout << "ANode:: ...test_move_peer\n";
-    Defs defs;
-    {
-        std::vector<string> vec{"3", "2", "1"};
-        for (const auto& str0 : vec) {
-            suite_ptr s = defs.add_suite("s" + str0);
-            for (const auto& str : vec) {
-                family_ptr f1 = s->add_family("f" + str);
-                for (const auto& str2 : vec) {
-                    f1->add_task("t" + str2);
-                }
-            }
-        }
-    }
-    Defs expectedDefs;
-    {
-        std::vector<string> vec{"1", "2", "3"};
-        for (const auto& str0 : vec) {
-            suite_ptr s = expectedDefs.add_suite("s" + str0);
-            for (const auto& str : vec) {
-                family_ptr f1 = s->add_family("f" + str);
-                for (const auto& str2 : vec) {
-                    f1->add_task("t" + str2);
-                }
-            }
-        }
-    }
-    //   std::cout << defs << "\n";
-
-    suite_ptr s3 = defs.findSuite("s3");
-    suite_ptr s2 = defs.findSuite("s2");
-    suite_ptr s1 = defs.findSuite("s1");
-    // order     is s3,s2,s1
-    defs.move_peer(s1.get(), s3.get()); // order now is s1,s3,s2
-    defs.move_peer(s2.get(), s3.get()); // order now is s1,s2,s3
-
-    //   std::cout << defs << "\n";
-
-    node_ptr s1_f1 = defs.findAbsNode("/s1/f1");
-    node_ptr s1_f2 = defs.findAbsNode("/s1/f2");
-    node_ptr s1_f3 = defs.findAbsNode("/s1/f3");
-
-    // order is f3,f2,f1
-    s1->move_peer(s1_f1.get(), s1_f3.get()); // order is f1,f3,f2
-    s1->move_peer(s1_f2.get(), s1_f3.get()); // order is f1,f3,f2
-
-    node_ptr s2_f1 = defs.findAbsNode("/s2/f1");
-    node_ptr s2_f2 = defs.findAbsNode("/s2/f2");
-    node_ptr s2_f3 = defs.findAbsNode("/s2/f3");
-    // order is f3,f2,f1
-    s2->move_peer(s2_f1.get(), s2_f3.get()); // order is f1,f3,f2
-    s2->move_peer(s2_f2.get(), s2_f3.get()); // order is f1,f3,f2
-
-    node_ptr s3_f1 = defs.findAbsNode("/s3/f1");
-    node_ptr s3_f2 = defs.findAbsNode("/s3/f2");
-    node_ptr s3_f3 = defs.findAbsNode("/s3/f3");
-    // order is f3,f2,f1
-    s3->move_peer(s3_f1.get(), s3_f3.get()); // order is f1,f3,f2
-    s3->move_peer(s3_f2.get(), s3_f3.get()); // order is f1,f3,f2
-
-    for (auto suite : defs.suiteVec()) {
-        for (auto family : suite->familyVec()) {
-
-            node_ptr t1 = defs.findAbsNode(family->absNodePath() + "/t1");
-            node_ptr t2 = defs.findAbsNode(family->absNodePath() + "/t2");
-            node_ptr t3 = defs.findAbsNode(family->absNodePath() + "/t3");
-
-            family->move_peer(t1.get(), t3.get());
-            family->move_peer(t2.get(), t3.get());
-        }
-    }
-    //   std::cout << defs << "\n";
-
-    BOOST_CHECK_MESSAGE(defs == expectedDefs, "Defs are not the same");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestNodeBeginRequeue.cpp 5.13.0-1/ANode/test/TestNodeBeginRequeue.cpp
--- 5.12.4-1/ANode/test/TestNodeBeginRequeue.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestNodeBeginRequeue.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,80 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_NodeBeginRequeue)
-
-BOOST_AUTO_TEST_CASE(test_node_begin_requeue_hybrid) {
-    cout << "ANode:: ...test_node_begin_reque_hybrid\n";
-
-    // Create a suite with a *HYBRID* clock, and tasks with day,date and cron time attributes
-    defs_ptr the_defs = Defs::create();
-    suite_ptr s1      = the_defs->add_suite("s1");
-    s1->addClock(ClockAttr(true));
-    family_ptr f1 = s1->add_family("f1");
-
-    CronAttr cron;
-    std::vector<int> week_days;
-    week_days.push_back(0);
-    week_days.push_back(1);
-    cron.addWeekDays(week_days);
-    cron.add_time_series(10, 10, true);
-
-    // For task t1 which has day attribute. For this test to succeed the day must not match today day.
-    // So that under the hybrid clock, its is set to complete
-    boost::gregorian::date todays_date = Calendar::second_clock_time().date();
-    int todays_day_as_number           = todays_date.day_of_week().as_number();
-    int tommorrow                      = todays_day_as_number + 1;
-    if (tommorrow > 6)
-        tommorrow = 0;
-
-    task_ptr t1 = f1->add_task("t1");
-    t1->addDay(DayAttr(DayAttr::Day_t(tommorrow)));
-    task_ptr t2 = f1->add_task("t2");
-    t2->addDate(DateAttr(0, 0, 2014));
-    task_ptr t3 = f1->add_task("t3");
-    t3->addCron(cron);
-
-    // begin the suite, Under hybrid clock, nodes with day,date and cron attributes should be marked as complete
-    the_defs->beginAll();
-    BOOST_CHECK_MESSAGE(t1->state() == NState::COMPLETE, "Expected node to be complete");
-    BOOST_CHECK_MESSAGE(t2->state() == NState::COMPLETE, "Expected node to be complete");
-    BOOST_CHECK_MESSAGE(t3->state() == NState::COMPLETE, "Expected node to be complete");
-
-    // Change the node state, so that we can test re-queue
-    t1->set_state(NState::QUEUED);
-    t2->set_state(NState::QUEUED);
-    t3->set_state(NState::QUEUED);
-    BOOST_CHECK_MESSAGE(t1->state() == NState::QUEUED, "Expected node to be QUEUED");
-    BOOST_CHECK_MESSAGE(t2->state() == NState::QUEUED, "Expected node to be QUEUED");
-    BOOST_CHECK_MESSAGE(t3->state() == NState::QUEUED, "Expected node to be QUEUED");
-
-    // Now re-queue all and make sure re-queue also Under hybrid clock, nodes with day,date and cron
-    // attributes should be marked as complete
-    the_defs->requeue();
-    BOOST_CHECK_MESSAGE(t1->state() == NState::COMPLETE, "Expected node to be complete");
-    BOOST_CHECK_MESSAGE(t2->state() == NState::COMPLETE, "Expected node to be complete");
-    BOOST_CHECK_MESSAGE(t3->state() == NState::COMPLETE, "Expected node to be complete");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestNodeState.cpp 5.13.0-1/ANode/test/TestNodeState.cpp
--- 5.12.4-1/ANode/test/TestNodeState.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestNodeState.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,139 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_NodeState)
-
-BOOST_AUTO_TEST_CASE(test_state_hierarchy) {
-    cout << "ANode:: ...test_state_hierarchy\n";
-
-    // Create a defs file corresponding to:
-    // suite s1
-    // family f1
-    //    task t1
-    //    task t2
-    //    task t3
-    //    task t4
-    //    task t5
-    //  endfamily
-    // endsuite
-    Defs theDefs;
-    suite_ptr s1  = theDefs.add_suite("suite1");
-    family_ptr f1 = s1->add_family("family");
-    task_ptr t1   = f1->add_task("t1");
-    task_ptr t2   = f1->add_task("t2");
-    task_ptr t3   = f1->add_task("t3");
-    task_ptr t4   = f1->add_task("t4");
-
-    NState::State result = s1->computedState(Node::IMMEDIATE_CHILDREN);
-    BOOST_REQUIRE_MESSAGE(result == NState::UNKNOWN,
-                          "Expected NState::UNKNOWN for suite but found " << NState::toString(result));
-
-    result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-    BOOST_REQUIRE_MESSAGE(result == NState::UNKNOWN,
-                          "Expected NState::UNKNOWN for family but found " << NState::toString(result));
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::QUEUED,
-                              "Expected NState::QUEUED for family but found " << NState::toString(result));
-    }
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        t1->set_state(NState::ABORTED);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::ABORTED,
-                              "Expected NState::ABORTED for family but found " << NState::toString(result));
-    }
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        t2->set_state(NState::SUBMITTED);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::SUBMITTED,
-                              "Expected NState::SUBMITTED for family but found " << NState::toString(result));
-    }
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        t3->set_state(NState::ACTIVE);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::ACTIVE,
-                              "Expected NState::ACTIVE for family but found " << NState::toString(result));
-    }
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        t3->set_state(NState::ACTIVE);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::ACTIVE,
-                              "Expected NState::ACTIVE for family but found " << NState::toString(result));
-    }
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        t1->set_state(NState::COMPLETE);
-        t2->set_state(NState::COMPLETE);
-        t3->set_state(NState::COMPLETE);
-        t4->set_state(NState::COMPLETE);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::COMPLETE,
-                              "Expected NState::COMPLETE for family but found " << NState::toString(result));
-    }
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        t1->set_state(NState::COMPLETE);
-        t2->set_state(NState::ACTIVE);
-        t3->set_state(NState::ACTIVE);
-        t4->set_state(NState::QUEUED);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::ACTIVE,
-                              "Expected NState::ACTIVE for family but found " << NState::toString(result));
-    }
-
-    {
-        f1->setStateOnlyHierarchically(NState::QUEUED);
-        t1->set_state(NState::COMPLETE);
-        t2->set_state(NState::ACTIVE);
-        t3->set_state(NState::ABORTED);
-        t4->set_state(NState::QUEUED);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::ABORTED,
-                              "Expected NState::ABORTED for family but found " << NState::toString(result));
-    }
-
-    { // ECFLOW-347
-        f1->setStateOnlyHierarchically(NState::UNKNOWN);
-        t1->set_state(NState::COMPLETE);
-        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
-        BOOST_REQUIRE_MESSAGE(result == NState::COMPLETE,
-                              "Expected NState::COMPLETE for family but found " << NState::toString(result));
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestNode_main.cpp 5.13.0-1/ANode/test/TestNode_main.cpp
--- 5.12.4-1/ANode/test/TestNode_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestNode_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Node
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/ANode/test/TestOrder.cpp 5.13.0-1/ANode/test/TestOrder.cpp
--- 5.12.4-1/ANode/test/TestOrder.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestOrder.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,475 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Order)
-
-static void test_invariants(Defs& the_defs, int line) {
-    std::string errorMsg;
-    bool passed = the_defs.checkInvariants(errorMsg);
-    BOOST_REQUIRE_MESSAGE(passed, "Invariants failed " << errorMsg << " at line " << line);
-}
-
-BOOST_AUTO_TEST_CASE(test_order) {
-    cout << "ANode:: ...test_order\n";
-    std::vector<std::string> vec;
-    vec.reserve(5);
-    vec.emplace_back("a");
-    vec.emplace_back("A");
-    vec.emplace_back("b");
-    vec.emplace_back("B");
-    vec.emplace_back("c");
-    Defs theDefs;
-    {
-        for (size_t s = 0; s < vec.size(); s++) {
-            suite_ptr suite = theDefs.add_suite(vec[s]);
-            for (size_t f = 0; f < vec.size(); f++) {
-                family_ptr fam = suite->add_family(vec[f]);
-                for (const auto& t : vec) {
-                    fam->add_task(t);
-                }
-            }
-        }
-    }
-
-    std::vector<std::string> alpha;
-    alpha.emplace_back("a");
-    alpha.emplace_back("A");
-    alpha.emplace_back("b");
-    alpha.emplace_back("B");
-    alpha.emplace_back("c");
-
-    std::vector<std::string> order;
-    order.emplace_back("c");
-    order.emplace_back("B");
-    order.emplace_back("b");
-    order.emplace_back("A");
-    order.emplace_back("a");
-
-    // Test suite ordering ==========================================================================
-    // In init state all suite should be in alpha order
-    theDefs.order(theDefs.findAbsNode("/A").get(), NOrder::ALPHA);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
-                          "NOrder::ALPHA expected "
-                              << ecf::algorithm::join(alpha) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
-
-    // sort in reverse order
-    theDefs.order(theDefs.findAbsNode("/a").get(), NOrder::ORDER);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == order,
-                          "NOrder::ORDER expected "
-                              << ecf::algorithm::join(order) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
-
-    // Change back to alpha, then move suite 'c' to the top
-    theDefs.order(theDefs.findAbsNode("/A").get(), NOrder::ALPHA);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
-                          "NOrder::ALPHA expected "
-                              << ecf::algorithm::join(alpha) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
-    test_invariants(theDefs, __LINE__);
-
-    std::vector<std::string> expected;
-    expected.emplace_back("c");
-    expected.emplace_back("a");
-    expected.emplace_back("A");
-    expected.emplace_back("b");
-    expected.emplace_back("B");
-    theDefs.order(theDefs.findAbsNode("/c").get(), NOrder::TOP);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == expected,
-                          "NOrder::TOP expected "
-                              << ecf::algorithm::join(expected) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
-
-    // move suite 'c' back to the bottom
-    theDefs.order(theDefs.findAbsNode("/c").get(), NOrder::BOTTOM);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
-                          "NOrder::BOTTOM order not as expected");
-
-    // move suite 'a' up one place. Should be no change, since its already at the top
-    theDefs.order(theDefs.findAbsNode("/a").get(), NOrder::UP);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
-                          "NOrder::UP order not as expected");
-
-    // move suite 'c' down one place. Should be no change, since its already at the bottom
-    theDefs.order(theDefs.findAbsNode("/c").get(), NOrder::DOWN);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
-                          "NOrder::DOWN order not as expected");
-
-    // Move suite 'a' down by one place
-    expected.clear();
-    expected.emplace_back("A");
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("B");
-    expected.emplace_back("c");
-    theDefs.order(theDefs.findAbsNode("/a").get(), NOrder::DOWN);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == expected,
-                          "NOrder::DOWN order not as expected");
-
-    // Move suite 'b' up by one place
-    expected.clear();
-    expected.emplace_back("A");
-    expected.emplace_back("b");
-    expected.emplace_back("a");
-    expected.emplace_back("B");
-    expected.emplace_back("c");
-    theDefs.order(theDefs.findAbsNode("/b").get(), NOrder::UP);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == expected,
-                          "NOrder::UP order not as expected");
-
-    // Test family ordering ==========================================================================
-    // In init state all suite should be in alpha order
-    suite_ptr suite = theDefs.findSuite("a");
-    BOOST_REQUIRE_MESSAGE(suite.get(), "Expected suite /a to exist ");
-
-    theDefs.order(theDefs.findAbsNode("/a/a").get(), NOrder::ALPHA);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
-                          "NOrder::ALPHA Init order "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // sort in reverse order
-    std::sort(expected.begin(), expected.end(), std::greater<std::string>());
-    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::ORDER);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == order,
-                          "NOrder::ORDER order "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(order));
-
-    // Change back to alpha, then move family 'e' to the top
-    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::ALPHA);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
-                          "NOrder::ALPHA expected "
-                              << ecf::algorithm::join(alpha) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec())));
-    test_invariants(theDefs, __LINE__);
-    expected.clear();
-    expected.emplace_back("c");
-    expected.emplace_back("a");
-    expected.emplace_back("A");
-    expected.emplace_back("b");
-    expected.emplace_back("B");
-    suite->order(theDefs.findAbsNode("/a/c").get(), NOrder::TOP);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == expected,
-                          "NOrder::TOP order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(expected));
-
-    //  move family 'c' back to the bottom
-    suite->order(theDefs.findAbsNode("/a/c").get(), NOrder::BOTTOM);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
-                          "NOrder::BOTTOM order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // move family 'a' up one place. Should be no change, since its already at the top
-    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::UP);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
-                          "NOrder::UP order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // move family 'c' down one place. Should be no change, since its already at the bottom
-    suite->order(theDefs.findAbsNode("/a/c").get(), NOrder::DOWN);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
-                          "NOrder::DOWN order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // Move family 'a' down by one place
-    expected.clear();
-    expected.emplace_back("A");
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("B");
-    expected.emplace_back("c");
-    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::DOWN);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == expected,
-                          "NOrder::DOWN order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(expected));
-
-    // Move family 'b' up by one place
-    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::ALPHA); // reset
-    test_invariants(theDefs, __LINE__);
-    expected.clear();
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("A");
-    expected.emplace_back("B");
-    expected.emplace_back("c");
-    suite->order(theDefs.findAbsNode("/a/b").get(), NOrder::UP);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == expected,
-                          "NOrder::UP order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(expected));
-
-    // Test Task ordering ==========================================================================
-    // In init state all tasks should be in alpha order
-    Family* family = theDefs.findAbsNode("/a/a")->isFamily();
-    BOOST_REQUIRE_MESSAGE(family, "Expected family /a/a to exist ");
-
-    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::ALPHA);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
-                          "NOrder::ALPHA Init state "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // sort in reverse order
-    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::ORDER);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == order,
-                          "NOrder::ORDER  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(order));
-
-    // Change back to alpha, then move task 'c' to the top
-    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::ALPHA); // reset
-    expected.clear();
-    expected.emplace_back("c");
-    expected.emplace_back("a");
-    expected.emplace_back("A");
-    expected.emplace_back("b");
-    expected.emplace_back("B");
-    family->order(theDefs.findAbsNode("/a/a/c").get(), NOrder::TOP);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == expected,
-                          "NOrder::TOP order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(expected));
-
-    //  move task 'c' back to the bottom
-    family->order(theDefs.findAbsNode("/a/a/c").get(), NOrder::BOTTOM);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
-                          "NOrder::BOTTOM order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // move task 'a' up one place. Should be no change, since its already at the top
-    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::UP);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
-                          "NOrder::UP order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // move task 'e' down one place. Should be no change, since its already at the bottom
-    family->order(theDefs.findAbsNode("/a/a/c").get(), NOrder::DOWN);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
-                          "NOrder::DOWN order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(alpha));
-
-    // Move task 'a' down by one place
-    expected.clear();
-    expected.emplace_back("A");
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    expected.emplace_back("B");
-    expected.emplace_back("c");
-    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::DOWN);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == expected,
-                          "NOrder::DOWN order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(expected));
-
-    // Move task 'b' up by one place
-    family->order(theDefs.findAbsNode("/a/a/b").get(), NOrder::DOWN);
-    expected.clear();
-    expected.emplace_back("A");
-    expected.emplace_back("a");
-    expected.emplace_back("B");
-    expected.emplace_back("b");
-    expected.emplace_back("c");
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == expected,
-                          "NOrder::UP order  "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
-                              << " not as expected " << ecf::algorithm::join(expected));
-}
-
-BOOST_AUTO_TEST_CASE(test_alias_order) {
-    cout << "ANode:: ...test_alias_order\n";
-    task_ptr task;
-    Defs theDefs;
-    {
-        suite_ptr s = theDefs.add_suite("s");
-        task        = s->add_task("t");
-        task->add_alias_only(); // alias0
-        task->add_alias_only(); // alias1
-        task->add_alias_only(); // alias2
-        task->add_alias_only(); // alias3
-    }
-
-    // Test alias ordering ==========================================================================
-    // In init state all suite should be in alpha order
-    alias_ptr alias0 = task->find_alias("alias0");
-    BOOST_REQUIRE_MESSAGE(alias0, "expected to find alias0");
-
-    std::vector<std::string> expected;
-    expected.emplace_back("alias1");
-    expected.emplace_back("alias0");
-    expected.emplace_back("alias2");
-    expected.emplace_back("alias3");
-    task->order(alias0.get(), NOrder::DOWN);
-    test_invariants(theDefs, __LINE__);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                          "NOrder::DOWN expected "
-                              << ecf::algorithm::join(expected) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-
-    task->order(alias0.get(), NOrder::ALPHA);
-    test_invariants(theDefs, __LINE__);
-    expected.clear();
-    expected.emplace_back("alias0");
-    expected.emplace_back("alias1");
-    expected.emplace_back("alias2");
-    expected.emplace_back("alias3");
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                          "NOrder::ALPHA expectex "
-                              << ecf::algorithm::join(expected) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-
-    task->order(task->find_alias("alias3").get(), NOrder::UP);
-    test_invariants(theDefs, __LINE__);
-    expected.clear();
-    expected.emplace_back("alias0");
-    expected.emplace_back("alias1");
-    expected.emplace_back("alias3");
-    expected.emplace_back("alias2");
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                          "NOrder::UP expected "
-                              << ecf::algorithm::join(expected) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-
-    // sort in reverse order
-    std::sort(expected.begin(), expected.end(), std::greater<std::string>());
-    task->order(alias0.get(), NOrder::ORDER);
-    test_invariants(theDefs, __LINE__);
-    expected.clear();
-    expected.emplace_back("alias3");
-    expected.emplace_back("alias2");
-    expected.emplace_back("alias1");
-    expected.emplace_back("alias0");
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                          "NOrder::ORDER expected "
-                              << ecf::algorithm::join(expected) << " but found "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-}
-
-BOOST_AUTO_TEST_CASE(test_order_by_runtime) {
-    cout << "ANode:: ...test_order_by_runtime\n";
-    Defs defs;
-    {
-        std::vector<string> vec{"3", "2", "1"};
-        for (const auto& str0 : vec) {
-            suite_ptr s = defs.add_suite("s" + str0);
-            for (const auto& str : vec) {
-                family_ptr f1 = s->add_family("f" + str);
-                for (const auto& str2 : vec) {
-                    f1->add_task("t" + str2);
-                }
-            }
-        }
-    }
-    Defs expectedDefs;
-    {
-        std::vector<string> vec{"1", "2", "3"};
-        for (const auto& str0 : vec) {
-            suite_ptr s = expectedDefs.add_suite("s" + str0);
-            for (const auto& str : vec) {
-                family_ptr f1 = s->add_family("f" + str);
-                for (const auto& str2 : vec) {
-                    f1->add_task("t" + str2);
-                }
-            }
-        }
-    }
-    // std::cout << defs;
-
-    defs.beginAll();
-    expectedDefs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-
-    Jobs jobs(&defs);
-    JobsParam jobsParam;
-    jobs.generate(jobsParam);
-
-    for (Submittable* s : jobsParam.submitted()) {
-        defs.updateCalendar(calUpdateParams);
-        s->set_state(NState::ACTIVE);
-
-        defs.updateCalendar(calUpdateParams);
-        if (s->name() == "t2" || s->name() == "t1")
-            defs.updateCalendar(calUpdateParams);
-        if (s->name() == "t1")
-            defs.updateCalendar(calUpdateParams);
-        s->set_state(NState::COMPLETE);
-    }
-
-    // PrintStyle style(PrintStyle::MIGRATE);
-    // std::cout << defs;
-
-    defs.order(nullptr, NOrder::RUNTIME); // moot when you only have one suite
-    for (auto suite : defs.suiteVec()) {
-        suite->order(nullptr, NOrder::RUNTIME);
-        for (auto family : suite->familyVec()) {
-            family->order(nullptr, NOrder::RUNTIME);
-        }
-    }
-    // std::cout << defs;
-
-    defs.requeue();
-    expectedDefs.requeue();
-
-    BOOST_CHECK_MESSAGE(defs == expectedDefs, "Defs are not the same");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestPersistence.cpp 5.13.0-1/ANode/test/TestPersistence.cpp
--- 5.12.4-1/ANode/test/TestPersistence.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestPersistence.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_FIXTURE_TEST_SUITE(U_Node, MyDefsFixture)
-
-BOOST_AUTO_TEST_SUITE(T_Persistence)
-
-// Allow for multiple archives
-static void testPersistence(const Defs& fixtureDefs) {
-    std::string check_pt_file = "fixture_defs.check";
-    fixtureDefs.cereal_save_as_checkpt(check_pt_file);
-    std::string error_msg;
-    BOOST_CHECK_MESSAGE(fixtureDefs.checkInvariants(error_msg), error_msg);
-
-    Defs restoredDefs;
-    restoredDefs.cereal_restore_from_checkpt(check_pt_file);
-    error_msg.clear();
-    BOOST_CHECK_MESSAGE(restoredDefs.checkInvariants(error_msg), error_msg);
-
-    bool theyCompare = (restoredDefs == fixtureDefs);
-    if (!theyCompare) {
-
-        std::cout << "Dump restored defs\n" << restoredDefs << "\n";
-        std::cout << "Dump fixture defs\n" << fixtureDefs << "\n";
-
-        BOOST_CHECK_MESSAGE(theyCompare, "restored defs file is not same as fixtureDefs defs file");
-    }
-
-    cout << " check pt file_size: " << fs::file_size(check_pt_file) << "\n";
-
-    // Uncomment if you want see what this file looks like
-    fs::remove(check_pt_file);
-}
-
-BOOST_AUTO_TEST_CASE(test_node_tree_persistence_text) {
-    cout << left << setw(54) << "ANode:: ...test_node_tree_persistence_text";
-    BOOST_CHECK_MESSAGE(true, ""); // stop boost complaining about no assertions
-    testPersistence(fixtureDefsFile());
-}
-
-BOOST_AUTO_TEST_CASE(test_node_defs_persistence) {
-    cout << "ANode:: ...test_node_defs_persistence\n";
-
-    const Defs& defs = fixtureDefsFile();
-    std::vector<node_ptr> all_nodes;
-    defs.get_all_nodes(all_nodes);
-    BOOST_REQUIRE_MESSAGE(all_nodes.size() > 0, "Expected nodes");
-    for (auto& all_node : all_nodes) {
-        std::string node_as_defs_string = all_node->print(PrintStyle::MIGRATE);
-        node_ptr the_copy               = Node::create(node_as_defs_string);
-        BOOST_REQUIRE_MESSAGE(the_copy,
-                              "Failed to create node " << all_node->absNodePath() << " from string:\n"
-                                                       << node_as_defs_string);
-        BOOST_REQUIRE_MESSAGE(*the_copy == *all_node, "Nodes not the same");
-    }
-    for (auto& all_node : all_nodes) {
-        std::string node_as_defs_string = all_node->print(PrintStyle::NET);
-        node_ptr the_copy               = Node::create(node_as_defs_string);
-        BOOST_REQUIRE_MESSAGE(the_copy,
-                              "Failed to create node " << all_node->absNodePath() << " from string:\n"
-                                                       << node_as_defs_string);
-        BOOST_REQUIRE_MESSAGE(*the_copy == *all_node, "Nodes not the same");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestPreProcessing.cpp 5.13.0-1/ANode/test/TestPreProcessing.cpp
--- 5.12.4-1/ANode/test/TestPreProcessing.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestPreProcessing.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,213 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <set>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-void findVariable(std::string& line, std::set<std::string>& variables) {
-    // scan for variables
-    // edit SMSFETCH "/home/ma/map/sms/smsfectch -F %ECF_FILES% -I %ECF_INCLUDE%"
-    // We can also have
-    //
-    // "%<VAR>:<substitute>% i.e if VAR exist use it, else use substitute
-    //
-    // i.e VAR is defined as BILL
-    //  %VAR:fred --f%  will either be "BILL" or if VAR is not defined "fred --f"
-    while (true) {
-        size_t firstPercentPos = line.find(Ecf::MICRO());
-        if (firstPercentPos == string::npos)
-            break;
-        size_t secondPercentPos = line.find(Ecf::MICRO(), firstPercentPos + 1);
-        if (secondPercentPos == string::npos)
-            break;
-        if (secondPercentPos - firstPercentPos <= 1)
-            break; // handle %% with no characters in between
-
-        string percentVar(line.begin() + firstPercentPos + 1, line.begin() + secondPercentPos);
-
-        size_t firstColon = percentVar.find(':');
-        if (firstColon != string::npos) {
-            string var(percentVar.begin(), percentVar.begin() + firstColon);
-            percentVar = var;
-        }
-
-        // Ignore auto-generated variables
-        if (percentVar.find("ECF_") == string::npos && percentVar != "DATE" && percentVar != "DAY" &&
-            percentVar != "DD" && percentVar != "DOW" && percentVar != "DOY" && percentVar != "MM" &&
-            percentVar != "MONTH" && percentVar != "YYYY" && percentVar != "TASK" && percentVar != "FAMILY" &&
-            percentVar != "FAMILY1" && percentVar != "SUITE") {
-            variables.insert(percentVar);
-        }
-
-        // std::cerr << "line before delete " << line << "\n";
-        line.erase(firstPercentPos, secondPercentPos - firstPercentPos + 1);
-        // std::cerr << "line after delete " << line << "\n";
-    }
-}
-
-void autoDiscoverVariables(const std::string& directory, std::set<std::string>& variables) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-    // std::cout << "\nIn directory: " << full_path << "\n\n";
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (fs::is_directory(dir_itr->status())) {
-                autoDiscoverVariables(relPath.string(), variables);
-                continue;
-            }
-            // std::cout << "......autoDiscoverVariables for file " << relPath.string() << "\n";
-            if (relPath.extension() != ".h")
-                continue; // Only look at .h files
-
-            // open the file, and find variables.
-            std::vector<std::string> lines;
-            if (File::splitFileIntoLines(relPath.string(), lines)) {
-                for (auto& line : lines) {
-                    findVariable(line, variables);
-                }
-            }
-        }
-        catch (const std::exception& ex) {
-            std::cout << "Exception::" << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_PreProcessing)
-
-// *Auto* discover the good/bad sms files
-void test_sms_preprocessing(const std::string& directory, bool pass) {
-    // SET ECF_HOME
-    std::string ecf_home = directory;
-
-    auto full_path = fs::absolute(directory);
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-    // Create a defs file, where the task name mirrors the sms files in the given directory
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
-        suite->addVariable(Variable(Str::ECF_OUT(), "$ECF_HOME"));
-        suite->addVariable(Variable("SLEEPTIME", "10"));
-        family_ptr fam = suite->add_family("family");
-
-        // for operations auto discover the variables used in the header files and give
-        // them a dummy value. This would allow the test to pass when doing
-        // variable substitution. hence if variable substitution fails its likely to be
-        // a bug in autoDiscoverVariables
-        std::set<std::string> discoveredVariables;
-        autoDiscoverVariables(ecf_home + "/includes", discoveredVariables);
-        for (const string& var : discoveredVariables) {
-            // 			cerr << "autoDiscoverVariables = " << var << "\n";
-            suite->addVariable(Variable(var, "gobblygook"));
-        }
-
-        // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
-        fs::directory_iterator end_iter;
-        for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-            try {
-                fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-                // Ignore directories were only interested in .ecf files.
-                if (fs::is_directory(relPath))
-                    continue;
-                if (File::getExt(relPath.filename().string()) != "ecf")
-                    continue; // ignore other files
-
-                // std::cout << "......Parsing file " << relPath.string() << "\n";
-                // std::cout << "      adding task name " << relPath.leaf() << "\n";
-                fam->add_task(relPath.stem().string());
-            }
-            catch (const std::exception& ex) {
-                std::cout << "Exception " << dir_itr->path().filename() << " " << ex.what() << std::endl;
-            }
-        }
-        // cerr << "The defs\n" << theDefs << "\n";
-    }
-
-    // get all the task
-    std::vector<Task*> theTasks;
-    theDefs.getAllTasks(theTasks);
-
-    // Override ECF_HOME.   ECF_HOME is need to locate the ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are used in client scripts(sms) and used to locate the sms files
-    theDefs.beginAll();
-
-    // Test Job creator, this will pre-process and perform variable substitution on ecf files
-    for (Task* t : theTasks) {
-
-        // cout << "  task " << t->absNodePath() << "\n";
-        JobsParam jobsParam; // create jobs =  false, spawn_jobs = false
-        bool ok = t->submitJob(jobsParam);
-
-        if (pass) { // Test expected to pass
-            BOOST_CHECK_MESSAGE(ok, "Failed to create jobs. " << jobsParam.getErrorMsg());
-        }
-        else { // test expected to fail
-            BOOST_CHECK_MESSAGE(!ok, "Expected failure " << jobsParam.getErrorMsg());
-            BOOST_CHECK_MESSAGE(!ok, "expected no passes but found " << t->absNodePath() << " passes");
-            // cerr << "\n" << jobsParam.getErrorMsg() << " \n"; // un-comment to ensure correct error message
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_good_sms) {
-    cout << "ANode:: ...test_good_ecf\n";
-
-    std::string path = File::test_data("ANode/test/data/SMSHOME2/good", "ANode");
-
-    // All the sms in this directory are expected to pass
-    test_sms_preprocessing(path, true);
-}
-
-BOOST_AUTO_TEST_CASE(test_bad_sms) {
-    cout << "ANode:: ...test_bad_ecf\n";
-
-    std::string path = File::test_data("ANode/test/data/SMSHOME2/bad", "ANode");
-
-    // All the sms in this directory are expected to fail
-    test_sms_preprocessing(path, false);
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestRepeatWithTimeDependencies.cpp 5.13.0-1/ANode/test/TestRepeatWithTimeDependencies.cpp
--- 5.12.4-1/ANode/test/TestRepeatWithTimeDependencies.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestRepeatWithTimeDependencies.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,248 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_RepeatWithTimeDependencies)
-
-BOOST_AUTO_TEST_CASE(test_repeat_day_time_combination_in_hierarchy) {
-    cout << "ANode:: ...test_repeat_day_time_combination_in_hierarchy \n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  family f
-    //    repeat integer rep 0 1
-    //    family f1
-    //       day monday
-    //       task t1
-    //         time 10:00  # should run, monday at 10:00 twice, due to repeat
-    //         time 11:00  # should run, monday at 11:00 twice, due to repeat
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    family_ptr f  = suite->add_family("f");
-    family_ptr f1 = f->add_family("f1");
-    f1->addRepeat(RepeatInteger("rep", 0, 1, 1));
-    f1->addDay(DayAttr(DayAttr::MONDAY));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(11, 0)));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time1 =
-        boost::posix_time::ptime(date(2019, 8, 5), time_duration(10, 0, 0)); // Monday & 10
-    boost::posix_time::ptime expected_time2 =
-        boost::posix_time::ptime(date(2019, 8, 5), time_duration(11, 0, 0)); // Monday & 11
-    boost::posix_time::ptime expected_time3 =
-        boost::posix_time::ptime(date(2019, 8, 12), time_duration(10, 0, 0)); // Monday & 10
-    boost::posix_time::ptime expected_time4 =
-        boost::posix_time::ptime(date(2019, 8, 12), time_duration(11, 0, 0)); // Monday & 11
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 212; m++) { // run for 9 days
-
-        // const std::vector<DayAttr>& days = f1->days();
-        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // " " << days[0].dump() << " " << times[0].dump() << " rep: " << f1->repeat().value() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n";
-
-            // 1st Run: Monday at 10:00 am
-            if (submitted == 1)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
-                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            // 2nd Run: Monday at 11:00 am
-            if (submitted == 2)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time2,
-                                    "\nExpected to submit at " << expected_time2 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            // 3rd Run: Monday at 10:00 am
-            if (submitted == 3)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time3,
-                                    "\nExpected to submit at " << expected_time3 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            // 4th Run: Monday at 11:00 am
-            if (submitted == 4)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time4,
-                                    "\nExpected to submit at " << expected_time4 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            t1->set_state(NState::COMPLETE); // cause repeat to loop
-            // cout << "   set_complete t1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n";
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 4, "Expected four submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_time_day_combination_in_hierarchy) {
-    cout << "ANode:: ...test_repeat_time_day_combination_in_hierarchy \n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  family f
-    //    repeat integer rep 0 1
-    //    family f1
-    //       time 10:00  # should run, 2 on monday at midnight, the time has NO effect
-    //       task t1
-    //          day monday
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    family_ptr f  = suite->add_family("f");
-    family_ptr f1 = f->add_family("f1");
-    f1->addRepeat(RepeatInteger("rep", 0, 3, 1)); // four iteration
-    f1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addDay(DayAttr(DayAttr::MONDAY));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time1 =
-        boost::posix_time::ptime(date(2019, 8, 5), time_duration(0, 0, 0)); // Monday & 00:00
-    boost::posix_time::ptime expected_time3 =
-        boost::posix_time::ptime(date(2019, 8, 12), time_duration(0, 0, 0)); // Monday & 00:00
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 212; m++) { // run for 9 days
-
-        // const std::vector<DayAttr>& days = t1->days();
-        // const std::vector<ecf::TimeAttr>& times = f1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // " " << days[0].dump() << " " << times[0].dump() << " rep: " << f1->repeat().value() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n";
-
-            // 1st Run: Monday at 00:00 am
-            if (submitted == 1)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
-                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            // 1st Run: Monday at 00:00 am
-            if (submitted == 2)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time3,
-                                    "\nExpected to submit at " << expected_time3 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            t1->set_state(NState::COMPLETE); // cause repeat to loop
-            // cout << "   set_complete t1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n"; PrintStyle style(PrintStyle::MIGRATE); cout << defs << "\n";
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 2, "Expected two submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_with_impossible_day_combination_in_hierarchy) {
-    cout << "ANode:: ...test_repeat_with_impossible_day_combination_in_hierarchy\n";
-    // Create the suite, starting on a sunday
-    //   suite s1
-    //     clock real 04.08.2019            # Sunday
-    //     family f
-    //       repeat integer rep 0 1
-    //       family f1
-    //          day monday
-    //          task t1
-    //               day tuesday            # cant be free on Monday and Tuesday,
-    //               time 10:00
-    //               verify complete:1
-    Defs defs;
-    suite_ptr suite = defs.add_suite("s1");
-    suite->addClock(ClockAttr(boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)))); // sunday
-    family_ptr f  = suite->add_family("f");
-    family_ptr f1 = f->add_family("f1");
-    f1->addRepeat(RepeatInteger("rep", 0, 1, 1)); // 2 iteration
-    f1->addDay(DayAttr(DayAttr::MONDAY));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addDay(DayAttr(DayAttr::TUESDAY));
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 212; m++) { // run for 9 days
-
-        // const std::vector<DayAttr>& fdays = f1->days();
-        // const std::vector<DayAttr>& days = t1->days();
-        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // "\n   "
-        //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
-        //          f1->repeat().value() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << " submitted at " << suite->calendar().suiteTime() << " dayChanged:" <<
-            // suite->calendar().dayChanged() << "\n   "
-            //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
-            //          f1->repeat().value() << "\n";
-
-            t1->set_state(NState::COMPLETE); // cause repeat to loop
-                                             // PrintStyle style(PrintStyle::MIGRATE);
-            // cout << defs << "\n";
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 0, "Expected 0 submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestReplace.cpp 5.13.0-1/ANode/test/TestReplace.cpp
--- 5.12.4-1/ANode/test/TestReplace.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestReplace.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1052 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-class ExpectStateChange {
-public:
-    ExpectStateChange() : state_change_no_(Ecf::state_change_no()) { Ecf::set_server(true); }
-    ~ExpectStateChange() {
-        BOOST_CHECK_MESSAGE(state_change_no_ != Ecf::state_change_no(), "Expected state change");
-        Ecf::set_server(false);
-    }
-
-private:
-    unsigned int state_change_no_;
-};
-
-class ExpectModifyChange {
-public:
-    ExpectModifyChange() : modify_change_no_(Ecf::modify_change_no()) { Ecf::set_server(true); }
-    ~ExpectModifyChange() {
-        BOOST_CHECK_MESSAGE(modify_change_no_ != Ecf::modify_change_no(), "Expected Modify change");
-        Ecf::set_server(false);
-    }
-
-private:
-    unsigned int modify_change_no_;
-};
-
-class ExpectNoChange {
-public:
-    ExpectNoChange() : state_change_no_(Ecf::state_change_no()), modify_change_no_(Ecf::modify_change_no()) {
-        Ecf::set_server(true);
-    }
-    ~ExpectNoChange() {
-        BOOST_CHECK_MESSAGE(state_change_no_ == Ecf::state_change_no() && modify_change_no_ == Ecf::modify_change_no(),
-                            "Expected no change");
-        Ecf::set_server(false);
-    }
-
-private:
-    unsigned int state_change_no_;
-    unsigned int modify_change_no_;
-};
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Replace)
-
-BOOST_AUTO_TEST_CASE(test_replace_add_task) {
-    cout << "ANode:: ...test_replace_add_task\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t2");
-        clientDef->addSuite(suite);
-    }
-
-    // add Child t2 to the server defs
-    Defs serverDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-        serverDefs.addSuite(suite);
-    }
-
-    Defs expectedDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t2"); // notice we preserve client position, and not server position
-        fam->add_task("t1");
-        expectedDefs.addSuite(suite);
-    }
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs.replaceChild(
-            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_add_suite) {
-    cout << "ANode:: ...test_replace_add_suite\n";
-    // In this test the server defs is *EMPTY* hence we should copy/move over the whole suite
-    // provided the a/ Path to node exists in the client def, b/ create nodes as needed is TRUE
-    Defs expectedDefs;
-    {
-        suite_ptr suite = expectedDefs.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-        fam->add_task("t2");
-    }
-
-    {
-        // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
-        defs_ptr clientDef = Defs::create();
-        {
-            suite_ptr suite = clientDef->add_suite("suite1");
-            family_ptr fam  = suite->add_family("family");
-            fam->add_task("t1");
-            fam->add_task("t2");
-        }
-
-        ExpectModifyChange expect_state_change;
-        Defs serverDefs; // Server defs is empty
-
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild(
-                "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-
-    {
-        // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
-        defs_ptr clientDef = Defs::create();
-        {
-            suite_ptr suite = clientDef->add_suite("suite1");
-            family_ptr fam  = suite->add_family("family");
-            fam->add_task("t1");
-            fam->add_task("t2");
-        }
-
-        ExpectModifyChange expect_state_change;
-        Defs serverDefs; // Server defs is empty
-
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild(
-                "/suite1/family", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-
-    {
-        // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
-        defs_ptr clientDef = Defs::create();
-        {
-            suite_ptr suite = clientDef->add_suite("suite1");
-            family_ptr fam  = suite->add_family("family");
-            fam->add_task("t1");
-            fam->add_task("t2");
-        }
-
-        ExpectModifyChange expect_state_change;
-        Defs serverDefs; // Server defs is empty
-
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_child) {
-    cout << "ANode:: ...test_replace_child\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        clientDef->addSuite(suite);
-    }
-    Defs comparisonDef;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        comparisonDef.addSuite(suite);
-    }
-    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
-
-    ExpectModifyChange expect_state_change;
-    std::string errorMsg;
-    Defs serverDefs;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs.replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_CHECK_MESSAGE(comparisonDef == serverDefs, "comparisonDef and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_add_preserves_states) {
-    cout << "ANode:: ...test_replace_add_preserves_states\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-        fam->add_task("t2");
-        fam->add_task("t3");
-        fam->add_task("t4");
-    }
-
-    // add Child t4 to the server defs, the states on t1->t3 should be preserved
-    // The abort should be progagated up the node tree
-    family_ptr fam;
-    suite_ptr suite;
-    Defs serverDefs;
-    {
-        suite       = serverDefs.add_suite("suite1");
-        fam         = suite->add_family("family");
-        task_ptr t1 = fam->add_task("t1");
-        task_ptr t2 = fam->add_task("t2");
-        task_ptr t3 = fam->add_task("t3");
-        serverDefs.beginAll();
-        t1->set_state(NState::COMPLETE);
-        t2->set_state(NState::ABORTED);
-        t3->set_state(NState::ACTIVE);
-    }
-
-    // cout << serverDefs;
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs.replaceChild(
-            "/suite1/family/t4", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-
-    /// The Nodes t1,t2,t3 may have been replaced hence we must get Nodes again
-    node_ptr st1 = serverDefs.findAbsNode("/suite1/family/t1");
-    node_ptr st2 = serverDefs.findAbsNode("/suite1/family/t2");
-    node_ptr st3 = serverDefs.findAbsNode("/suite1/family/t3");
-    node_ptr st4 = serverDefs.findAbsNode("/suite1/family/t4");
-    BOOST_REQUIRE_MESSAGE(st1, "Expected to find task t1");
-    BOOST_REQUIRE_MESSAGE(st2, "Expected to find task t2");
-    BOOST_REQUIRE_MESSAGE(st3, "Expected to find task t3");
-    BOOST_REQUIRE_MESSAGE(st4, "Expected to find task t4");
-    BOOST_REQUIRE_MESSAGE(st1->state() == NState::COMPLETE, " state on task t1 not preserved after replace");
-    BOOST_REQUIRE_MESSAGE(st2->state() == NState::ABORTED, " state on task t2 not preserved after replace");
-    BOOST_REQUIRE_MESSAGE(st3->state() == NState::ACTIVE, " state on task t3 not preserved after replace");
-    BOOST_REQUIRE_MESSAGE(st4->state() == NState::QUEUED, " state on task t4 to be queued");
-    BOOST_REQUIRE_MESSAGE(fam->state() == NState::ABORTED, "Aborted should have propagated to family");
-    BOOST_REQUIRE_MESSAGE(suite->state() == NState::ABORTED, "Aborted should have propagated to suite");
-    BOOST_REQUIRE_MESSAGE(serverDefs.state() == NState::ABORTED, "Aborted should have propagated to Defs");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_preserves_suspend) {
-    cout << "ANode:: ...test_replace_preserves_suspend\n"; // ECFLOW-1520
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-        fam->add_task("t2");
-        fam->add_task("t3");
-        fam->add_task("t4");
-    }
-
-    Defs comparisonDef;
-    {
-        suite_ptr suite = comparisonDef.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        task_ptr t1     = fam->add_task("t1");
-        task_ptr t2     = fam->add_task("t2");
-        task_ptr t3     = fam->add_task("t3");
-        task_ptr t4     = fam->add_task("t4");
-        BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
-        comparisonDef.beginAll();
-
-        fam->suspend();
-        t1->suspend();
-        t2->suspend();
-        t3->suspend();
-        t4->suspend();
-    }
-
-    defs_ptr serverDefs = Defs::create();
-    {
-        suite_ptr suite = serverDefs->add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        task_ptr t1     = fam->add_task("t1");
-        task_ptr t2     = fam->add_task("t2");
-        task_ptr t3     = fam->add_task("t3");
-        task_ptr t4     = fam->add_task("t4");
-        serverDefs->beginAll();
-        fam->suspend();
-        t1->suspend();
-        t2->suspend();
-        t3->suspend();
-        t4->suspend();
-    }
-
-    //   PrintStyle style(PrintStyle::MIGRATE);
-    //   cout << serverDefs;
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs->replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1"), "Can't find suite1");
-    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1")->begun(), "Expected replaced suite to preserve begun status");
-    DebugEquality debug_equality; // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(comparisonDef == *serverDefs, "comparisonDef and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_preserves_suspend2) {
-    cout << "ANode:: ...test_replace_preserves_suspend2\n"; // ECFLOW-1520
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        family_ptr f1   = suite->add_family("f1");
-        family_ptr fam  = f1->add_family("fam");
-        fam->add_task("t1");
-    }
-
-    Defs comparisonDef;
-    {
-        suite_ptr suite = comparisonDef.add_suite("suite1");
-        family_ptr f1   = suite->add_family("f1");
-        family_ptr fam  = f1->add_family("fam");
-        task_ptr t1     = fam->add_task("t1");
-
-        BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
-        comparisonDef.beginAll();
-
-        f1->suspend();
-        fam->suspend();
-    }
-
-    defs_ptr serverDefs = Defs::create();
-    {
-        suite_ptr suite = serverDefs->add_suite("suite1");
-        family_ptr f1   = suite->add_family("f1");
-        family_ptr fam  = f1->add_family("fam");
-        serverDefs->beginAll();
-        f1->suspend();
-        fam->suspend();
-    }
-
-    //   PrintStyle style(PrintStyle::MIGRATE);
-    //   cout << serverDefs;
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs->replaceChild(
-            "/suite1/f1/fam/t1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1"), "Can't find suite1");
-    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1")->begun(), "Expected replaced suite to preserve begun status");
-    DebugEquality debug_equality; // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(comparisonDef == *serverDefs, "comparisonDef and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_preserves_sibling_states) {
-    cout << "ANode:: ...test_replace_preserves_sibling_states\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t4");
-        clientDef->addSuite(suite);
-    }
-
-    // add Child t4 to the server defs, the states on t1->t4 should be preserved
-    task_ptr t1, t2, t3;
-    Defs serverDefs;
-    {
-        suite_ptr suite = serverDefs.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        t1              = fam->add_task("t1");
-        t1->set_state(NState::COMPLETE);
-        t2 = fam->add_task("t2");
-        t2->set_state(NState::ABORTED);
-        t3 = fam->add_task("t3");
-        t3->set_state(NState::ACTIVE);
-        fam->add_task("t4");
-    }
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs.replaceChild(
-            "/suite1/family/t4", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_REQUIRE_MESSAGE(t1->state() == NState::COMPLETE, " state on task t1 not preserved after replace");
-    BOOST_REQUIRE_MESSAGE(t2->state() == NState::ABORTED, " state on task t2 not preserved after replace");
-    BOOST_REQUIRE_MESSAGE(t3->state() == NState::ACTIVE, " state on task t3 not preserved after replace");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_preserves_begun_status) {
-    cout << "ANode:: ...test_replace_preserves_begun_status\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->addTask(Task::create("t1"));
-    }
-    Defs comparisonDef;
-    {
-        suite_ptr suite = comparisonDef.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->addTask(Task::create("t1"));
-    }
-    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
-    comparisonDef.beginAll();
-
-    defs_ptr serverDefs = Defs::create();
-    {
-        suite_ptr suite = serverDefs->add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->addTask(Task::create("t1"));
-    }
-    serverDefs->beginAll();
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs->replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1"), "Can't find suite1");
-    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1")->begun(), "Expected replaced suite to preserve begun status");
-    DebugEquality debug_equality; // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(comparisonDef == *serverDefs, "comparisonDef and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_preserves_begun_where_client_not_begun) {
-    cout << "ANode:: ...test_replace_preserves_begun_where_client_not_begun\n"; // ECFLOW-1612
-    // In this test we will end up calling begin on the time attribute.
-    // However we had called begin on the client defs side, where the calendar/suite had not been begun
-    // Thus causing an assert failure. The fix is to call begin on the server side, after the replace.
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = suite->add_family("family");
-        task_ptr t2     = fam->add_task("t2");
-        t2->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), false));
-        clientDef->addSuite(suite);
-    }
-
-    // add Child t2 to the server defs
-    Defs serverDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-        serverDefs.addSuite(suite);
-        serverDefs.beginAll();
-    }
-
-    Defs expectedDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = suite->add_family("family");
-        task_ptr t2     = fam->add_task("t2"); // notice we preserve client position, and not server position
-        t2->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), false));
-        fam->add_task("t1");
-        expectedDefs.addSuite(suite);
-        expectedDefs.beginAll();
-    }
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs.replaceChild(
-            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_add_node) {
-    cout << "ANode:: ...test_replace_add_node\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        suite->addTask(Task::create("t2"));
-        clientDef->addSuite(suite);
-    }
-    Defs comparisonDef;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        suite->addTask(Task::create("t2"));
-        comparisonDef.addSuite(suite);
-    }
-    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
-
-    // Here /suite1/t2 does not exist in the server. Moved from client defs to server
-    Defs serverDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        serverDefs.addSuite(suite);
-    }
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs.replaceChild("/suite1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_CHECK_MESSAGE(comparisonDef == serverDefs, "comparisonDef and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_add_hierarchy) {
-    cout << "ANode:: ...test_replace_add_hierarchy\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fa   = Family::create("fa");
-        family_ptr fb   = Family::create("fb");
-        family_ptr fc   = Family::create("fc");
-        family_ptr fd   = Family::create("fd");
-        fa->addFamily(fb);
-        fb->addFamily(fc);
-        fc->addFamily(fd);
-        fd->addTask(Task::create("t1"));
-        suite->addFamily(fa);
-        clientDef->addSuite(suite);
-    }
-    Defs comparisonDef;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fa   = Family::create("fa");
-        family_ptr fb   = Family::create("fb");
-        family_ptr fc   = Family::create("fc");
-        family_ptr fd   = Family::create("fd");
-        fa->addFamily(fb);
-        fb->addFamily(fc);
-        fc->addFamily(fd);
-        fd->addTask(Task::create("t1"));
-        suite->addFamily(fa);
-        comparisonDef.addSuite(suite);
-    }
-    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
-
-    // Here /suite1/fa/fb/fc/fd/t1 does not exist in the server.  These should be created.
-    // by adding family "fa" as a child of suite1
-    Defs serverDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        serverDefs.addSuite(suite);
-    }
-
-    ExpectStateChange expect_state_change;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        serverDefs.replaceChild(
-            "/suite1/fa/fb/fc/fd/t1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        errorMsg);
-    BOOST_CHECK_MESSAGE(comparisonDef == serverDefs, "comparisonDef and servers defs should be the same");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_order_preserved_for_suite) {
-    cout << "ANode:: ...test_replace_order_preserved_for_suite\n";
-    // Test that when we replace a suite, its order is preserved,
-    // See  ECFLOW-23 - When replacing a node the order is changed.
-    defs_ptr clientDef = Defs::create();
-    {
-        clientDef->add_suite("s1");
-        clientDef->add_suite("s2");
-        clientDef->add_suite("s3");
-    }
-
-    // Replace suite s1 with another suite s1 check order is preserved
-    Defs serverDefs;
-    {
-        serverDefs.add_suite("s1");
-        serverDefs.add_suite("s2");
-        serverDefs.add_suite("s3");
-    }
-
-    Defs expectedDefs;
-    {
-        expectedDefs.add_suite("s1");
-        expectedDefs.add_suite("s2");
-        expectedDefs.add_suite("s3");
-    }
-
-    std::string errorMsg;
-    {
-        ExpectModifyChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild("/s1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-    {
-        ExpectModifyChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild("/s2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-    {
-        ExpectModifyChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild("/s3", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_order_preserved_for_family) {
-    cout << "ANode:: ...test_replace_order_preserved_for_family\n";
-    // Test that when we replace a family, its order is preserved,
-    // See  ECFLOW-23 - When replacing a node the order is changed.
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        suite->add_family("f1");
-        suite->add_family("f2");
-        suite->add_family("f3");
-    }
-
-    // Replace family f1 with another family f1 check order is preserved
-    Defs serverDefs;
-    {
-        suite_ptr suite = serverDefs.add_suite("suite1");
-        suite->add_family("f1");
-        suite->add_family("f2");
-        suite->add_family("f3");
-    }
-
-    Defs expectedDefs;
-    {
-        suite_ptr suite = expectedDefs.add_suite("suite1");
-        suite->add_family("f1");
-        suite->add_family("f2");
-        suite->add_family("f3");
-    }
-
-    std::string errorMsg;
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    {
-        ExpectStateChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
-                                  "/suite1/f1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-                              errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-    {
-        ExpectStateChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
-                                  "/suite1/f2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-                              errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-    {
-        ExpectStateChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
-                                  "/suite1/f3", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-                              errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_order_preserved_for_task) {
-    cout << "ANode:: ...test_replace_order_preserved_for_task\n";
-    // Test that when we replace a family, its order is preserved,
-    // See  ECFLOW-23 - When replacing a node the order is changed.
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        family_ptr f1   = suite->add_family("f1");
-        f1->add_task("t1");
-        f1->add_task("t2");
-        f1->add_task("t3");
-    }
-
-    // Replace task t1 with another task t1, check order is preserved
-    Defs serverDefs;
-    {
-        suite_ptr suite = serverDefs.add_suite("suite1");
-        family_ptr f1   = suite->add_family("f1");
-        f1->add_task("t1");
-        f1->add_task("t2");
-        f1->add_task("t3");
-    }
-
-    Defs expectedDefs;
-    {
-        suite_ptr suite = expectedDefs.add_suite("suite1");
-        family_ptr f1   = suite->add_family("f1");
-        f1->add_task("t1");
-        f1->add_task("t2");
-        f1->add_task("t3");
-    }
-
-    std::string errorMsg;
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    {
-        ExpectStateChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild(
-                "/suite1/f1/t1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-    {
-        ExpectStateChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild(
-                "/suite1/f1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-    {
-        ExpectStateChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild(
-                "/suite1/f1/t3", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-            errorMsg);
-        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_child_errors) {
-    cout << "ANode:: ...test_replace_child_errors\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        suite->addTask(Task::create("t2"));
-        clientDef->addSuite(suite);
-    }
-
-    ExpectNoChange expect_no_change;
-    Defs serverDefs;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(
-        !serverDefs.replaceChild(
-            "/suite1/i/dont/exist", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-        "Expected failure");
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_child_errors_2) {
-    cout << "ANode:: ...test_replace_child_errors_2\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        suite->addTask(Task::create("t2"));
-        clientDef->addSuite(suite);
-    }
-    Defs serverDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        serverDefs.addSuite(suite);
-    }
-
-    std::string errorMsg;
-    {
-        ExpectNoChange expect_no_change;
-        // because createNodesAsNeeded is false, child adoption should fail since /suite1/t2
-        // does not exist on the server
-        BOOST_REQUIRE_MESSAGE(
-            !serverDefs.replaceChild("/suite1/t2", clientDef, false /*create nodes as needed*/, false, errorMsg),
-            "Expected failure");
-    }
-    {
-        // With flag now set, we will create any missing nodes even if they dont exist in the server
-        ExpectStateChange expect_state_change;
-        errorMsg.clear();
-        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
-                                  "/suite1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-                              "Expected success " << errorMsg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_child_errors_3) {
-    // test force option
-    cout << "ANode:: ...test_replace_child_errors_3\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        suite->addTask(Task::create("t2"));
-        clientDef->addSuite(suite);
-    }
-
-    Defs serverDefs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr fam  = Family::create("family");
-        fam->addTask(Task::create("t1"));
-        suite->addFamily(fam);
-        task_ptr t2 = Task::create("t2");
-        suite->addTask(t2);
-        serverDefs.addSuite(suite);
-
-        t2->set_state(NState::ACTIVE); // Must be done after parent has been setup
-    }
-
-    std::string errorMsg;
-    {
-        ExpectNoChange expect_no_change;
-        BOOST_REQUIRE_MESSAGE(!serverDefs.replaceChild(
-                                  "/suite1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
-                              "Expected failure since server task t2 is active, and force not used");
-    }
-    {
-        errorMsg.clear();
-        ExpectStateChange expect_state_change;
-        BOOST_REQUIRE_MESSAGE(
-            serverDefs.replaceChild("/suite1/t2", clientDef, true /*create nodes as needed*/, true /*force*/, errorMsg),
-            errorMsg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_add_task_with_bad_trigger) {
-    cout << "ANode:: ...test_replace_add_task_with_bad_trigger\n";
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        task_ptr task   = fam->add_task("t2");
-        task->add_trigger("txx eq complete");
-    }
-
-    // add Child t2 to the server defs
-    Defs serverDefs;
-    {
-        suite_ptr suite = serverDefs.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-    }
-
-    // Expect to pass, since the replace part is ok.
-    std::string errorMsg;
-    node_ptr replaced_node;
-    {
-        ExpectStateChange expect_state_change;
-        replaced_node = serverDefs.replaceChild(
-            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
-        BOOST_REQUIRE_MESSAGE(replaced_node, "Expected replaced to succeed, even though triggers are dodgy");
-    }
-
-    // Although we have change the data model, Check if the trigger expressions are still valid. Should fail
-    std::string warning_msg;
-    BOOST_REQUIRE_MESSAGE(!replaced_node->suite()->check(errorMsg, warning_msg), "Expected failure " << errorMsg);
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_add_suite_with_bad_triggers) {
-    cout << "ANode:: ...test_replace_add_suite_with_bad_triggers\n";
-
-    // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
-    defs_ptr clientDef = Defs::create();
-    {
-        suite_ptr suite = clientDef->add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_task("t1");
-        fam->add_task("t2");
-        task_ptr t3 = fam->add_task("t3");
-        t3->add_trigger("txxxxx eq complete");
-    }
-
-    // Server defs is empty
-    Defs serverDefs;
-
-    // Expect to pass, since the replace part is ok.
-    std::string errorMsg;
-    node_ptr replaced_node;
-    {
-        ExpectModifyChange expect_state_change;
-        replaced_node = serverDefs.replaceChild(
-            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
-        BOOST_REQUIRE_MESSAGE(replaced_node, "Expected replaced to succeed, even though triggers are dodgy");
-    }
-
-    // Although we have changed the data model, Check if the trigger expressions are still valid. Should fail.
-    std::string warning_msg;
-    BOOST_REQUIRE_MESSAGE(!replaced_node->suite()->check(errorMsg, warning_msg), "Expected failure " << errorMsg);
-
-    // reset, to avoid effecting downstream tests
-    Ecf::set_state_change_no(0);
-    Ecf::set_modify_change_no(0);
-}
-
-BOOST_AUTO_TEST_CASE(test_replace_task_ECFLOW_1135) {
-    cout << "ANode:: ...test_replace_task_ECFLOW_1135\n";
-
-    // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
-    defs_ptr clientDef = Defs::create();
-    {
-        clientDef->add_suite("o")
-            ->add_family("main")
-            ->add_family("00")
-            ->add_family("an")
-            ->add_family("4dvar")
-            ->add_task("vardata");
-    }
-
-    // Server
-    Defs serverDefs;
-    { serverDefs.add_suite("o")->add_family("main")->add_family("00")->add_family("an")->add_task("4dvar"); }
-
-    // Expect to fail *IF*  irrespective of 'create nodes as needed' flag, since path in the server is a *TASK*
-    {
-        std::string errorMsg;
-        ExpectNoChange expect_no_change;
-        node_ptr replaced_node = serverDefs.replaceChild(
-            "/o/main/00/an/4dvar/vardata", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
-        BOOST_REQUIRE_MESSAGE(!replaced_node, "Expected replace to fail");
-        BOOST_REQUIRE_MESSAGE(!errorMsg.empty(), "Expected error message");
-    }
-    {
-        std::string errorMsg;
-        ExpectNoChange expect_no_change;
-        node_ptr replaced_node = serverDefs.replaceChild(
-            "/o/main/00/an/4dvar/vardata", clientDef, false /*create nodes as needed*/, false /*force*/, errorMsg);
-        BOOST_REQUIRE_MESSAGE(!replaced_node, "Expected replace to fail");
-        BOOST_REQUIRE_MESSAGE(!errorMsg.empty(), "Expected error message");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_trigger_references_during_replace) {
-    cout << "ANode:: ...test_trigger_references_during_replace\n"; // ECFLOW-1319
-
-    // This is used to check that the trigger references in AST, are invalidated after replace.
-
-    Defs serverDefs;
-    suite_ptr server_suite;
-    {
-        server_suite = serverDefs.add_suite("suite");
-        server_suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/../includes"));
-        server_suite->addVariable(Variable("SLEEPTIME", "1"));
-        server_suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
-        family_ptr fam = server_suite->add_family("family");
-        fam->add_task("t1")->add_trigger("/suite1/family/suite1_task1 == complete");
-        fam->add_task("t2")->add_trigger("/suite1/family/suite1_task2 == complete");
-        fam->add_task("t3")->add_trigger("/suite1/family/suite1_task3 == complete");
-    }
-    task_ptr suite1_task1, suite1_task2, suite1_task3;
-    {
-        suite_ptr suite = serverDefs.add_suite("suite1");
-        family_ptr fam  = suite->add_family("family");
-        suite1_task1    = fam->add_task("suite1_task1");
-        suite1_task2    = fam->add_task("suite1_task2");
-        suite1_task3    = fam->add_task("suite1_task3");
-    }
-
-    // Override ECF_HOME. ECF_HOME is need to locate to the .ecf files
-    std::string ecf_home = File::test_data("ANode/test/data/SMSHOME", "ANode");
-    serverDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    serverDefs.beginAll();
-
-    suite1_task1->set_state(NState::COMPLETE);
-    suite1_task2->set_state(NState::COMPLETE);
-    suite1_task3->set_state(NState::COMPLETE);
-
-    // We need JOB generation to *FORCE* the creation of the trigger AST, and hence references
-    {
-        JobsParam jobsParam(true /*create jobs*/); // spawn_jobs = false
-        Jobs jobs(&serverDefs);
-        jobs.generate(jobsParam);
-        BOOST_REQUIRE_MESSAGE(jobsParam.submitted().size() == 3,
-                              "expected 3 jobs but found " << jobsParam.submitted().size() << "\n"
-                                                           << jobsParam.errorMsg());
-    }
-
-    {
-        // Now replace the suite1/family thereby, invalidating the trigger reference on suite/family/t1,t2,t3
-        defs_ptr clientDef = Defs::create();
-        suite_ptr suite    = clientDef->add_suite("suite1");
-        family_ptr fam     = suite->add_family("family");
-        fam->add_task("suite1_task1");
-        fam->add_task("suite1_task2");
-        fam->add_task("suite1_task3");
-        fam->add_task("dummy");
-
-        std::string errorMsg;
-        serverDefs.replaceChild(
-            "/suite1/family", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
-        BOOST_REQUIRE_MESSAGE(errorMsg.empty(), "Expected no message " << errorMsg);
-    }
-    {
-        std::vector<Node*> all_server_nodes;
-        serverDefs.getAllNodes(all_server_nodes);
-
-        // Now check the Trigger reference. The old reference to nodes in the trigger expressions should have been
-        // removed
-        std::vector<Task*> theTasks;
-        server_suite->getAllTasks(theTasks);
-        BOOST_REQUIRE_MESSAGE(theTasks.size() == 3, "Expected 3 tasks but found, " << theTasks.size());
-        for (auto& theTask : theTasks) {
-
-            std::set<Node*> referenced_nodes;
-            theTask->getAllAstNodes(referenced_nodes);
-            BOOST_REQUIRE_MESSAGE(referenced_nodes.size() == 1, " expected 1 referenced node");
-
-            // The reference nodes must exist in the server. Otherwise replace has still kept references to old nodes in
-            // the triggers
-            bool found_reference = false;
-            for (auto& all_server_node : all_server_nodes) {
-                if (all_server_node == (*referenced_nodes.begin())) {
-                    found_reference = true;
-                    break;
-                }
-            }
-            BOOST_CHECK_MESSAGE(found_reference,
-                                "Could not find trigger reference " << (*referenced_nodes.begin())->absNodePath()
-                                                                    << " in the server");
-        }
-    }
-
-    // reset, to avoid effecting downstream tests
-    Ecf::set_state_change_no(0);
-    Ecf::set_modify_change_no(0);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestSetState.cpp 5.13.0-1/ANode/test/TestSetState.cpp
--- 5.12.4-1/ANode/test/TestSetState.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestSetState.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,145 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_SetState)
-
-static void set_state(node_ptr n, NState::State set, NState::State expected) {
-    n->set_state(set);
-    BOOST_REQUIRE_MESSAGE(n->state() == expected,
-                          "Expected state " << NState::toString(expected) << " but found "
-                                            << NState::toString(n->state()) << " for " << n->debugNodePath());
-}
-
-static void test_state(node_ptr n, NState::State expected) {
-    BOOST_REQUIRE_MESSAGE(n->state() == expected,
-                          "Expected state " << NState::toString(expected) << " but found "
-                                            << NState::toString(n->state()) << " for " << n->debugNodePath());
-}
-
-BOOST_AUTO_TEST_CASE(test_set_state) {
-    cout << "ANode:: ...test_set_state\n";
-    std::vector<NState::State> stateVec = NState::states();
-
-    // 	cout << "Defs setState\n";
-    Defs theDefs;
-    for (NState::State state : stateVec) {
-        theDefs.set_state(state);
-        BOOST_REQUIRE_MESSAGE(theDefs.state() == state,
-                              "Expected defs state " << NState::toString(state) << " but found "
-                                                     << NState::toString(theDefs.state()));
-    }
-    //  	theDefs.resume();                   // unset the suspended state. Start with default, for next set of
-    //  test
-    theDefs.set_state(NState::UNKNOWN); // Start with default, for next set of test
-
-    // 	cout << "Suite setState\n";
-    suite_ptr s = Suite::create("s");
-    theDefs.addSuite(s);
-    for (NState::State state : stateVec) {
-        set_state(s, state, state); // suite with no children, state should be what was set
-    }
-    s->resume();                   // unset the suspended state. Start with default, for next set of test
-    s->set_state(NState::UNKNOWN); // Start with default, for next set of test
-
-    // 	cout << "family setState\n";
-    family_ptr f = Family::create("f");
-    s->addFamily(f);
-    for (NState::State state : stateVec) {
-        set_state(f, state, state); // family with no children, state should be what was set
-    }
-    f->resume();                   // unset the suspended state. Start with default, for next set of test
-    f->set_state(NState::UNKNOWN); // Start with default, for next set of test
-
-    // 	cout << "task setState\n";
-    task_ptr t = Task::create("t");
-    f->addTask(t);
-
-    for (NState::State state : stateVec) {
-        f->setStateOnly(NState::UNKNOWN); // reset family state
-        s->setStateOnly(NState::UNKNOWN); // reset suite state
-        set_state(t, state, state);       // task state should be what was set
-
-        test_state(f, state); // family state should be computed state
-        test_state(s, state); // suite state should be computed state
-    }
-
-    /// Everytime we set the state on a nodecontainer, we call handleStateChange
-    /// This by default works out the most significant state of the children
-    /// ie. the computed state. Hence setting the state on Suite/Family is really
-    /// meaningless, since it will always be the computed state.
-}
-
-BOOST_AUTO_TEST_CASE(test_set_aborted) {
-    // see ECFLOW-344
-    cout << "ANode:: ...test_set_aborted\n";
-
-    Defs defs;
-    suite_ptr suite = defs.add_suite("s1");
-    task_ptr t1     = suite->add_task("t1");
-    t1->addDefStatus(DState::COMPLETE);
-    defs.beginAll();
-
-    {
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "No jobs should be submitted when task is complete but found "
-                                << jobsParam.submitted().size() << " submitted");
-    }
-
-    t1->setStateOnly(NState::ABORTED, true /*force*/);
-    {
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "No jobs should be submitted when task is forcibly aborted but found "
-                                << jobsParam.submitted().size() << " submitted");
-    }
-
-    Node::Requeue_args args;
-    t1->requeue(args);
-
-    t1->set_state(NState::ABORTED); // mimic non forced, i.e like job aborted
-    {
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 1,
-                            "Expected 1 job, when job aborts and ECF_TRIES > 1 but found "
-                                << jobsParam.submitted().size() << " submitted");
-        BOOST_CHECK_MESSAGE(t1->try_no() == 1, " expected try_no to be 1 but found " << t1->try_no());
-    }
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestSingleExprParse.cpp 5.13.0-1/ANode/test/TestSingleExprParse.cpp
--- 5.12.4-1/ANode/test/TestSingleExprParse.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestSingleExprParse.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,126 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-#include <map>
-#include <string>
-
-#include <boost/date_time/posix_time/conversion.hpp>
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/ExprDuplicate.hpp"
-#include "ecflow/node/ExprParser.hpp"
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-// DEBUG AID: to see the expression tree, invert the expected evaluation
-//            so that test fail's
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_SingleExprParse)
-
-BOOST_AUTO_TEST_CASE(test_single_expression) {
-    std::cout << "ANode:: ...test_single_expression\n";
-
-    // Duplicate AST are held in a static map. Delete them, to avoid ASAN complaining
-    ExprDuplicate reclaim_cloned_ast_memory;
-
-    // The map key = trigger expression,
-    // value.first  = type of expected root abstract syntax tree
-    // value.second = result of expected evaluation
-    map<string, std::pair<string, bool>> exprMap;
-
-    exprMap[":var == 0"] = std::make_pair(AstEqual::stype(), true);
-    exprMap[":var != 1"] = std::make_pair(AstNotEqual::stype(), true);
-
-    for (std::pair<string, std::pair<string, bool>> p : exprMap) {
-
-        ExprParser theExprParser(p.first);
-        std::string errorMsg;
-        bool ok = theExprParser.doParse(errorMsg);
-        BOOST_REQUIRE_MESSAGE(ok, errorMsg);
-
-        string expectedRootType       = p.second.first;
-        bool expectedEvaluationResult = p.second.second;
-
-        Ast* top = theExprParser.getAst();
-        BOOST_REQUIRE_MESSAGE(top, "No abstract syntax tree");
-        BOOST_REQUIRE_MESSAGE(top->left(), "No root created");
-        BOOST_REQUIRE_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
-                              "First child of top should be a root or attribute " + p.first);
-        BOOST_REQUIRE_MESSAGE(top->left()->is_evaluateable(),
-                              "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
-        BOOST_REQUIRE_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
-                              "expected root type " << expectedRootType << " or 'variable' but found "
-                                                    << top->left()->type() << " " << p.first);
-        {
-            std::stringstream ss;
-            top->print_flat(ss);
-            std::string print_flat = ss.str();
-            cout << print_flat << "\n";
-            BOOST_REQUIRE_MESSAGE(expectedEvaluationResult == top->evaluate(),
-                                  "evaluation not as expected for:\n"
-                                      << p.first << "\n"
-                                      << print_flat << "\n"
-                                      << *top);
-        }
-        {
-            std::stringstream ss;
-            top->print(ss);
-            cout << ss.str() << "\n";
-        }
-
-        std::string why;
-        top->why(why);
-        cout << "why: " << why << "\n";
-    }
-}
-
-// BOOST_AUTO_TEST_CASE( test_expression_read_from_file )
-//{
-//    std::cout <<  "ANode:: ...test_expression_read_from_file\n";
-//
-//    std::string filename = "${ECF_TEST_DEFS_DIR}/triggers.list";
-//    std::ifstream the_file(filename.c_str(),std::ios_base::in);
-//    BOOST_REQUIRE_MESSAGE(the_file,"file " << filename << "not found");
-//
-//    int  i = 0;
-//    string line;
-//    while ( std::getline(the_file,line) ) {
-//       i++;
-//       // cout << i << ": " << line << "\n";
-//       ExprParser theExprParser(line);
-//       std::string errorMsg;
-//       bool ok = theExprParser.doParse(errorMsg);
-//       BOOST_CHECK_MESSAGE(ok,errorMsg << " line: " << i );
-//
-//       if (ok) {
-//          Ast* top = theExprParser.getAst();
-//          BOOST_REQUIRE_MESSAGE( top ,"No abstract syntax tree " + line);
-//          BOOST_REQUIRE_MESSAGE( top->left() ,"No root created " + line);
-//          BOOST_REQUIRE_MESSAGE( top->left()->isRoot() || top->left()->is_attribute() ,"First child of top should be a
-//          root or variable " + line);
-//          //top->print_flat(ss);
-//       }
-//    }
-//
-//    ExprDuplicate reclaim_cloned_ast_memory;
-//    cout << " read " << i << " expressions\n";
-// }
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestSingleExprParse_main.cpp 5.13.0-1/ANode/test/TestSingleExprParse_main.cpp
--- 5.12.4-1/ANode/test/TestSingleExprParse_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestSingleExprParse_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_SingleExprParse
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/ANode/test/TestSpecificIssues.cpp 5.13.0-1/ANode/test/TestSpecificIssues.cpp
--- 5.12.4-1/ANode/test/TestSpecificIssues.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestSpecificIssues.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,314 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_SpecificIssues)
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_195) {
-    cout << "ANode:: ...test_ECFLOW_195 re-queue on task should retain label value\n";
-
-    defs_ptr defs = Defs::create();
-    suite_ptr s1  = defs->add_suite("s1");
-    family_ptr f1 = s1->add_family("f1");
-    task_ptr t1   = f1->add_task("t1");
-
-    s1->addLabel(Label("s1", "s1"));
-    f1->addLabel(Label("f1", "f1"));
-    t1->addLabel(Label("t1", "t1"));
-
-    defs->beginAll();
-
-    // Set the labels, with new values
-    s1->changeLabel("s1", "xx");
-    f1->changeLabel("f1", "xx");
-    t1->changeLabel("t1", "xx");
-
-    { // Check new values have not changed
-        Label s1_label = s1->find_label("s1");
-        BOOST_CHECK_MESSAGE(!s1_label.empty(), "expected to find label 's1'");
-        BOOST_CHECK_MESSAGE(s1_label.new_value() == "xx", "expected xx but found " << s1_label.new_value());
-
-        Label f1_label = f1->find_label("f1");
-        BOOST_CHECK_MESSAGE(!f1_label.empty(), "expected to find label 'f1'");
-        BOOST_CHECK_MESSAGE(f1_label.new_value() == "xx", "expected xx but found " << f1_label.new_value());
-
-        Label t1_label = t1->find_label("t1");
-        BOOST_CHECK_MESSAGE(!t1_label.empty(), "expected to find label 't1'");
-        BOOST_CHECK_MESSAGE(t1_label.new_value() == "xx", "expected xx but found " << t1_label.new_value());
-    }
-
-    // Now requee. the suite and family should be cleared and task label should remain.
-    defs->requeue();
-
-    { // Suite and Family labels should be reset, and task labels should retain their values
-        Label s1_label = s1->find_label("s1");
-        BOOST_CHECK_MESSAGE(!s1_label.empty(), "expected to find label 's1'");
-        BOOST_CHECK_MESSAGE(s1_label.new_value().empty(),
-                            "expected empty string for suite label value after re-queue, but found "
-                                << s1_label.new_value());
-
-        Label f1_label = f1->find_label("f1");
-        BOOST_CHECK_MESSAGE(!f1_label.empty(), "expected to find label 'f1'");
-        BOOST_CHECK_MESSAGE(f1_label.new_value().empty(),
-                            "expected empty string for family label value after re-queue, but found "
-                                << f1_label.new_value());
-
-        Label t1_label = t1->find_label("t1");
-        BOOST_CHECK_MESSAGE(!t1_label.empty(), "expected to find label 't1'");
-        BOOST_CHECK_MESSAGE(t1_label.new_value() == "xx",
-                            "Expected task label to remain unchanged after re-queue but found "
-                                << t1_label.new_value());
-    }
-
-    // After explicit re-queue expect new labels to be empty
-    s1->requeue_labels();
-    f1->requeue_labels();
-    t1->requeue_labels();
-    {
-        Label s1_label = s1->find_label("s1");
-        BOOST_CHECK_MESSAGE(!s1_label.empty(), "expected to find label 's1'");
-        BOOST_CHECK_MESSAGE(s1_label.new_value().empty(),
-                            "expected empty string for suite label value after explicit re-queue, but found "
-                                << s1_label.new_value());
-
-        Label f1_label = f1->find_label("f1");
-        BOOST_CHECK_MESSAGE(!f1_label.empty(), "expected to find label 'f1'");
-        BOOST_CHECK_MESSAGE(f1_label.new_value().empty(),
-                            "expected empty string for family label value after explicit re-queue, but found "
-                                << f1_label.new_value());
-
-        Label t1_label = t1->find_label("t1");
-        BOOST_CHECK_MESSAGE(!t1_label.empty(), "expected to find label 't1'");
-        BOOST_CHECK_MESSAGE(t1_label.new_value().empty(),
-                            "expected empty string for task label value after explicit re-queue, but found "
-                                << t1_label.new_value());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_247) {
-    cout << "ANode:: ...test_ECFLOW_247  \n";
-
-    defs_ptr defs = Defs::create();
-    suite_ptr s1  = defs->add_suite("s1");
-    family_ptr f1 = s1->add_family("f1");
-    f1->add_complete("f1/t1 == complete");
-    task_ptr t1 = f1->add_task("t1");
-    task_ptr t2 = f1->add_task("t2");
-    task_ptr t3 = f1->add_task("t3");
-    task_ptr t4 = f1->add_task("t4");
-
-    PrintStyle style(PrintStyle::MIGRATE);
-    {
-        defs->beginAll();
-        t1->set_state(NState::COMPLETE);
-        // cout << defs;
-
-        t4->set_state(NState::ABORTED);
-        t4->flag().set(ecf::Flag::FORCE_ABORT); // stopped bu user mimic, otherwise it be be queued
-
-        Jobs jobs(defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-        // cout << defs;
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ABORTED,
-                            "The complete for family should not evaluate if child is aborted");
-    }
-    {
-        defs->requeue();
-        t1->set_state(NState::COMPLETE);
-        // cout << defs;
-
-        t4->set_state(NState::ACTIVE);
-
-        Jobs jobs(defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        // cout << defs;
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "The complete for family should not evaluate if child is active");
-    }
-
-    {
-        defs->requeue();
-        t1->set_state(NState::COMPLETE);
-
-        Jobs jobs(defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        t4->set_state(NState::SUBMITTED);
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::SUBMITTED,
-                            "The complete for family should not evaluate if child is submitted");
-        // cout << defs;
-    }
-
-    {
-        defs->requeue();
-        t1->set_state(NState::COMPLETE);
-        // cout << defs;
-
-        Jobs jobs(defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
-                            "The complete for family should not evaluate if child is submitted");
-        // cout << defs;
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_417_real_clock) {
-    // Make sure reque resets calendar according to the clock attribute *FOR* a real clock
-    cout << "ANode:: ...test_ECFLOW_417_real_clock  \n";
-
-    defs_ptr defs = Defs::create();
-    suite_ptr s1  = defs->add_suite("s1");
-    s1->addRepeat(RepeatDay(1));
-    s1->addClock(ClockAttr(1, 10, 2015, false /*real clock*/));
-    task_ptr t1 = s1->add_task("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(16, 0), false));
-
-    defs->beginAll();
-
-    // ECF_DATE = year/month/day of month
-    {
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151001", "expected 20151001 but found " << ecf_date.theValue());
-    }
-
-    // now requeue and date should be reset
-    {
-        defs->requeue();
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151001", "expected 20151001 but found " << ecf_date.theValue());
-    }
-
-    // Now change the clock date to 10.10.2015.
-    {
-        s1->changeClockDate("10.10.2015");
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151010", "expected 20151010 but found " << ecf_date.theValue());
-    }
-
-    // now requeue
-    {
-        defs->requeue();
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151010", "expected 20151010 but found " << ecf_date.theValue());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_417_hybrid_clock) {
-    // ECFLOW-417
-    // For a suite with a hybrid clock *AND* repeat day. requue should update calendar date, by the repeat day interval
-    cout << "ANode:: ...test_ECFLOW_417_hybrid_clock  \n";
-
-    defs_ptr defs = Defs::create();
-    suite_ptr s1  = defs->add_suite("s1");
-    s1->addRepeat(RepeatDay(1));
-    s1->addClock(ClockAttr(1, 10, 2015, true /*hybrid*/));
-    task_ptr t1 = s1->add_task("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(16, 0), false));
-
-    defs->beginAll();
-
-    // ECF_DATE = year/month/day of month
-    {
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151001", "expected 20151001 but found " << ecf_date.theValue());
-    }
-
-    // now requeue and date should be incremented
-    {
-        defs->requeue();
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151002", "expected 20151002 but found " << ecf_date.theValue());
-    }
-
-    // now requeue again and date should be incremented
-    {
-        defs->requeue();
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151003", "expected 20151003 but found " << ecf_date.theValue());
-    }
-
-    // Now change the clock date to 10.10.2015. We expect date to decremented to 09.10.2015,
-    // Since user should always re-queue after changing suite clock attributes.
-    // This will get us back to the original date set by the user.
-    {
-        s1->changeClockDate("10.10.2015");
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151009", "expected 20151009 but found " << ecf_date.theValue());
-    }
-
-    // now requeue and date should be incremented
-    {
-        defs->requeue();
-        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
-        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
-        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151010", "expected 20151010 but found " << ecf_date.theValue());
-    }
-
-    // Now update calendar for more than 24 hours, and calendar date should *NOT* change for hybrid
-    {
-        using namespace boost::posix_time;
-        using namespace boost::gregorian;
-
-        boost::posix_time::ptime time_now                 = s1->calendar().suiteTime();
-        boost::posix_time::time_duration serverPollPeriod = boost::posix_time::time_duration(0, 1, 0, 0);
-        std::string expectedDate                          = "2015-Oct-10";
-
-        for (int hour = 1; hour <= 60; hour++) {
-
-            // Update calendar every hour, for 60 hours
-            time_now += hours(1);
-            CalendarUpdateParams param(time_now, serverPollPeriod, true, /* serverRunning */ false /* forTest */);
-
-            defs->updateCalendar(param);
-
-            // cout << "hour = " << hour << " timeAfterUpdate " << to_simple_string(s1->calendar().suiteTime()) << "\n";
-
-            std::string actualDate = to_simple_string(s1->calendar().suiteTime().date());
-            BOOST_CHECK_MESSAGE(actualDate == expectedDate,
-                                "Expected '" << expectedDate << "' but found " << actualDate << " at hour " << hour);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestSystem.cpp 5.13.0-1/ANode/test/TestSystem.cpp
--- 5.12.4-1/ANode/test/TestSystem.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestSystem.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Signal.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_System)
-
-BOOST_AUTO_TEST_CASE(test_system) {
-    cout << "ANode:: ...test_system \n";
-
-    std::string file = "test_system.log";
-    std::string cmd  = "echo sat siri akal dunyia > " + file;
-
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(System::instance()->spawn(System::ECF_STATUS_CMD, cmd, "", errorMsg),
-                          "System::instance()->spawn() failed: " << errorMsg);
-    while (System::instance()->process() != 0) {
-        // Capture child process termination. Child sends SIGNAl SIGCHLD, caught by parent
-        Signal unblock_on_desctruction_then_reblock;
-        // sleep(1); // Need to wait for child termination()
-        System::instance()->processTerminatedChildren();
-    }
-
-    BOOST_CHECK_MESSAGE(fs::exists(file), "Expected cmd(" << cmd << ") to produce a file " << file);
-
-    fs::remove(file); // Remove the file. Comment out for debugging
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestSystemStandalone.cpp 5.13.0-1/ANode/test/TestSystemStandalone.cpp
--- 5.12.4-1/ANode/test/TestSystemStandalone.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestSystemStandalone.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-#include <stdexcept>
-#include <string>
-#include <unistd.h>
-
-#include "ecflow/node/Signal.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// leap42 boost_1_64_0 gcc-5.3.0 release mode
-//    time bin/gcc-5.3.0/release/perf_aparser_only ${ECF_TEST_DEFS_DIR}/vsms2.31415.def
-//    real    0m2.79s
-//    user    0m2.59s
-//    sys     0m0.18s
-
-int main(int argc, char* argv[]) {
-    cout << "argc = " << argc << "\n";
-    for (int i = 0; i < argc; i++) {
-        cout << "arg " << i << ":" << argv[i] << "\n";
-    }
-
-    if (argc != 2) {
-        cout << "Expect single argument \n";
-        return 1;
-    }
-
-    cout << "Invoke command: " << argv[1] << "\n";
-    std::string errorMsg;
-    if (!System::instance()->spawn(System::ECF_STATUS_CMD, argv[1], "", errorMsg)) {
-        throw std::runtime_error(errorMsg);
-    }
-
-    while (System::instance()->process() != 0) {
-        // cout << "no of System::instance()->process() " << System::instance()->process() << "\n";
-
-        // Capture child process termination. Child sends SIGNAl SIGCHLD, caught by parent
-        Signal unblock_on_desctruction_then_reblock;
-        sleep(1); // Need to wait for child termination()
-        System::instance()->processTerminatedChildren();
-    }
-
-    return 0;
-}
diff -pruN 5.12.4-1/ANode/test/TestTaskScriptGenerator.cpp 5.13.0-1/ANode/test/TestTaskScriptGenerator.cpp
--- 5.12.4-1/ANode/test/TestTaskScriptGenerator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestTaskScriptGenerator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,247 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/EcfFile.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/JobCreationCtrl.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_TaskScriptGenerator)
-
-BOOST_AUTO_TEST_CASE(test_reset_after_job_generation_checking) {
-    cout << "ANode:: ...test_reset_after_job_generation_checking\n";
-    {
-        Defs defs   = Defs();
-        suite_ptr s = defs.add_suite("s");
-        task_ptr t  = s->add_task("t");
-        t->addTime(TimeAttr("+00:00 23:00 00:30"));
-
-        Defs defs_copy = Defs(defs);
-        BOOST_REQUIRE_MESSAGE(defs_copy == defs, "Expected defs to be equal");
-
-        // After check_job_creation, the defs SHOULD be reset. see ECFLOW-1203
-        job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
-        defs.check_job_creation(jobCtrl);
-        BOOST_REQUIRE_MESSAGE(!jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
-
-        DebugEquality debug_equality; // only as affect in DEBUG build
-        BOOST_REQUIRE_MESSAGE(defs_copy == defs, "reset failed - Expected defs to be equal");
-    }
-
-    {
-        // test reset with a full definition
-        MyDefsFixture theDefsFixture;
-        Defs copy = Defs(theDefsFixture.defsfile_);
-
-        BOOST_REQUIRE_MESSAGE(copy == theDefsFixture.defsfile_, "Expected defs to be equal");
-
-        // After check_job_creation, the defs SHOULD be reset. see ECFLOW-1203
-        job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
-        theDefsFixture.defsfile_.check_job_creation(jobCtrl);
-
-        DebugEquality debug_equality; // only as affect in DEBUG build
-        BOOST_REQUIRE_MESSAGE(copy == theDefsFixture.defsfile_, "reset failed - Expected defs to be equal");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_task_script_generator) {
-    cout << "ANode:: ...test_task_script_generator\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data/TaskScriptGenerator", "ANode");
-
-    std::string head = ecf_home + "/head.h";
-    std::string tail = ecf_home + "/tail.h";
-    fs::remove_all(ecf_home);
-    BOOST_REQUIRE_MESSAGE(!fs::exists(head), "Remove of head file failed");
-    BOOST_REQUIRE_MESSAGE(!fs::exists(tail), "Remove of tail file failed");
-
-    // Create a defs file corresponding to:
-    // suite suite
-    // edit ECF_INCLUDE $ECF_HOME/includes
-    // edit SLEEP 10
-    // task t1
-    //    family f1
-    //       task t1
-    //       task t2
-    //    endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->add_variable(Str::ECF_INCLUDE(), ecf_home);
-        suite->add_variable(Str::ECF_HOME(), ecf_home);
-        suite->add_variable("SLEEP", "10");
-        task_ptr t1 = suite->add_task("t1");
-        t1->addEvent(Event("event1"));
-        t1->addEvent(Event("event2"));
-        t1->addEvent(Event("event4"));
-        t1->addMeter(Meter("meter1", 1, 100, 90));
-        t1->addMeter(Meter("meter2", 1, 100, 90));
-        t1->addLabel(Label("label", "label value"));
-        family_ptr fam = suite->add_family("f1");
-        fam->add_task("t1");
-        fam->add_task("t2");
-        //    cerr << theDefs << "\n";
-    }
-
-    /// generate the scripts and head.h and tail.h
-    theDefs.generate_scripts();
-
-    /// Test the ecf file were created, by doing job creation
-    /// JobCreationCtrl is used control what node we generate the jobs for:
-    /// Since we have not set the node on it, we force job generation for all tasks
-    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
-    theDefs.check_job_creation(jobCtrl);
-    BOOST_REQUIRE_MESSAGE(jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
-    BOOST_REQUIRE_MESSAGE(jobCtrl->fail_submittables().empty(), "Expected no failing tasks");
-
-    /// Additional sanity tests #######################################################
-
-    /// test that header and tail file were created
-    BOOST_REQUIRE_MESSAGE(fs::exists(head), "Head file " << head << " not created");
-    BOOST_REQUIRE_MESSAGE(fs::exists(tail), "Tail file " << tail << " not created");
-
-    // get all the task, assume non hierarchical families
-    std::vector<Task*> theTasks;
-    theDefs.getAllTasks(theTasks);
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the sms files
-    theDefs.beginAll();
-
-    // Test for ECF_ file location
-    for (Task* t : theTasks) {
-        try {
-            EcfFile ecf_file = t->locatedEcfFile();
-            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task ");
-        }
-        catch (std::exception& e) {
-            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task " << e.what());
-        }
-    }
-
-    // Remove the directories that were generated. This occasionally fails on ecgb and lxg ?
-    try {
-        fs::remove_all(ecf_home);
-    }
-    catch (const fs::filesystem_error& e) {
-        cout << "Could not remove directory " << ecf_home << " : " << e.what() << "\n";
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_task_script_generator_with_dummy_tasks) {
-    cout << "ANode:: ...test_task_script_generator_with_dummy_tasks\n";
-
-    // SET ECF_HOME
-    std::string ecf_home = File::test_data("ANode/test/data/TaskScriptGenerator", "ANode");
-
-    std::string head = ecf_home + "/head.h";
-    std::string tail = ecf_home + "/tail.h";
-    fs::remove_all(ecf_home);
-    BOOST_REQUIRE_MESSAGE(!fs::exists(head), "Remove of head file failed");
-    BOOST_REQUIRE_MESSAGE(!fs::exists(tail), "Remove of tail file failed");
-
-    // Create a defs file corresponding to:
-    // suite suite
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   edit ECF_HOME $ECF_HOME/includes
-    //   edit SLEEP 10
-    //   family f1
-    //       task t1
-    //       task t2
-    //   endfamily
-    //   family f2
-    //       edit ECF_DUMMY_TASK ''
-    //       task t1
-    //       task t2
-    //   endfamily
-    // endsuite
-    std::vector<task_ptr> tasks_with_scripts, tasks_without_scripts;
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->add_variable(Str::ECF_INCLUDE(), ecf_home);
-        suite->add_variable(Str::ECF_HOME(), ecf_home);
-        suite->add_variable("SLEEP", "10");
-        family_ptr f1 = suite->add_family("f1");
-        tasks_with_scripts.push_back(f1->add_task("t1"));
-        family_ptr f2 = suite->add_family("f2");
-        f2->add_variable("ECF_DUMMY_TASK", "");
-        tasks_without_scripts.push_back(f2->add_task("t1"));
-        tasks_without_scripts.push_back(f2->add_task("t2"));
-        //      cout << theDefs << "\n";
-    }
-
-    /// generate the scripts and head.h and tail.h
-    theDefs.generate_scripts();
-
-    /// Test the ecf file were created, by doing job creation
-    /// JobCreationCtrl is used control what node we generate the jobs for:
-    /// Since we have *NOT* set the node on it, we force job generation for all tasks
-    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
-    theDefs.check_job_creation(jobCtrl);
-    BOOST_REQUIRE_MESSAGE(jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
-    BOOST_REQUIRE_MESSAGE(jobCtrl->fail_submittables().empty(), "Expected no failing tasks");
-
-    /// Additional sanity tests #######################################################
-
-    /// test that header and tail file were created
-    BOOST_REQUIRE_MESSAGE(fs::exists(head), "Head file " << head << " not created");
-    BOOST_REQUIRE_MESSAGE(fs::exists(tail), "Tail file " << tail << " not created");
-
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files
-    theDefs.beginAll();
-
-    // Test for script generation
-    for (task_ptr t : tasks_with_scripts) {
-        try {
-            EcfFile ecf_file = t->locatedEcfFile();
-            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task ");
-        }
-        catch (std::exception& e) {
-            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task " << e.what());
-        }
-    }
-
-    // Test  that no scripts are generated when ECF_DUMMY_TASK is used
-    for (task_ptr t : tasks_without_scripts) {
-        BOOST_REQUIRE_THROW(t->locatedEcfFile(), std::runtime_error);
-    }
-
-    // Remove the directories that were generated. This occasionally fails on ecgb and lxg ?
-    try {
-        fs::remove_all(ecf_home);
-    }
-    catch (const fs::filesystem_error& e) {
-        cout << "Could not remove directory " << ecf_home << " : " << e.what() << "\n";
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestTimeDependencies.cpp 5.13.0-1/ANode/test/TestTimeDependencies.cpp
--- 5.12.4-1/ANode/test/TestTimeDependencies.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestTimeDependencies.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,479 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-using namespace boost::gregorian;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_TimeDependencies)
-
-// See ECFLOW-337
-// See ECFLOW-833. Also See Note: ACore/doc/TimeDependencies.ddoc
-
-BOOST_AUTO_TEST_CASE(test_day_time_combination) {
-    cout << "ANode:: ...test_day_time_combination\n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  clock real 7.6.2015  # sunday
-    //  task t1              # run task monday at 10, Day acts like a guard, time if ignored until day is free
-    //      day monday
-    //      time 10:00
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    task_ptr t1 = suite->add_task("t1");
-    t1->addDay(DayAttr(DayAttr::MONDAY));
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time =
-        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
-    // cout << "expected_time =  " << expected_time << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 120; m++) { // run for 5 days
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "submitted at " << suite->calendar().suiteTime() << "\n";
-            BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
-                                "\nExpected to submit at " << expected_time << " only, but also found "
-                                                           << suite->calendar().suiteTime());
-        }
-
-        defs.updateCalendar(calUpdateParams);
-        if (suite->calendar().dayChanged()) {
-            Node::Requeue_args args(Node::Requeue_args::TIME);
-            t1->requeue(args);
-        }
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged: " <<   suite->calendar().dayChanged()
-        // << "\n";
-    }
-    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_date_time_combination) {
-    cout << "ANode:: ...test_date_time_combination\n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  clock real 7.6.2015  # sunday
-    //  task t1              # run task monday at 10, Date acts like a guard, time if ignored until date is free
-    //      date 8.6.2015
-    //      time 10:00
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    task_ptr t1 = suite->add_task("t1");
-    t1->addDate(DateAttr(8, 6, 2015)); // Monday
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time =
-        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 100; m++) {
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "submitted at " << suite->calendar().suiteTime() << "\n";
-            BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
-                                "\nExpected to submit at " << expected_time << " only, but also found "
-                                                           << suite->calendar().suiteTime());
-        }
-
-        defs.updateCalendar(calUpdateParams);
-        if (suite->calendar().dayChanged()) {
-            Node::Requeue_args args;
-            t1->requeue(args);
-        }
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged: " <<   suite->calendar().dayChanged()
-        // << "\n";
-    }
-    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_day_time_combination_in_hierarchy) {
-    cout << "ANode:: ...test_day_time_combination_in_hierarchy\n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  clock real 7.6.2015 # sunday
-    //  family f1
-    //    day monday     # day attribute prevents time from being free
-    //    task t1
-    //      time 10:00   # should run ONCE, monday at 10:00
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    family_ptr f1 = suite->add_family("f1");
-    f1->addDay(DayAttr(DayAttr::MONDAY));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time =
-        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 120; m++) { // run for 5 days
-
-        // const std::vector<DayAttr>& days = f1->days();
-        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // " " << days[0].dump() << " " << times[0].dump() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n";
-
-            // 1st Run: Monday at 10:00 am
-            if (submitted == 1)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
-                                    "\nExpected to submit at " << expected_time << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            Node::Requeue_args args;
-            f1->requeue(args);
-            // cout << "   requeue f1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n";
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_time_day_combination_in_hierarchy) {
-    cout << "ANode:: ...test_time_day_combination_in_hierarchy\n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  clock real 7.6.2015 # sunday
-    //  family f1
-    //    time 10:00
-    //    task t1      # task should run *TWICE*, Monday morning @00:00 and, at 10:00
-    //      day monday
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    family_ptr f1 = suite->add_family("f1");
-    f1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addDay(DayAttr(DayAttr::MONDAY));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time1 =
-        boost::posix_time::ptime(date(2015, 6, 8), time_duration(0, 0, 0)); // Monday & 00:00
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 120; m++) { // run for 5 days
-        // const std::vector<DayAttr>& days = t1->days();
-        // const std::vector<ecf::TimeAttr>& times = f1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // " " << days[0].dump() << " " << times[0].dump() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n";
-
-            // 1st Run: Monday at 00:00 am
-            if (submitted == 1)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
-                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            Node::Requeue_args args;
-            f1->requeue(args);
-            // cout << "   requeue f1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
-            // times[0].dump() << "\n";
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 2, "Expected two submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_date_time_combination_in_hierarchy) {
-    cout << "ANode:: ...test_date_time_combination_in_hierarchy\n";
-
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  clock real 7.6.2015 # sunday
-    //  family f1
-    //    date 8.6.15  # monday date now guards the time
-    //    task t1
-    //      time 10:00
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    family_ptr f1 = suite->add_family("f1");
-    f1->addDate(DateAttr(8, 6, 2015)); // Monday
-    task_ptr t1 = f1->add_task("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time =
-        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 100; m++) {
-
-        // const std::vector<DateAttr>& dates = f1->dates();
-        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // " " << dates[0].dump() << " " << times[0].dump() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "  submitted at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
-            // times[0].dump() << "\n";
-
-            // New to ecflow 5.0, parent date will guard the time. i.e will not let time be free until date is
-            // satisfied.
-            if (submitted == 1)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
-                                    "\nExpected to submit at " << expected_time << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            Node::Requeue_args args;
-            f1->requeue(args);
-            // cout << "  requeue at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
-            // times[0].dump() << "\n";
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_time_date_combination_in_hierarchy) {
-    cout << "ANode:: ...test_time_date_combination_in_hierarchy \n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  clock real 7.6.2015 # sunday
-    //  family f1
-    //    time 10:00
-    //    task t1
-    //       date 8.6.15  # monday, run once at Monday morning, and gain Monday at 10:00
-    //
-    Defs defs;
-    suite_ptr suite                   = defs.add_suite("s1");
-    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
-    suite->addClock(ClockAttr(the_time));
-    family_ptr f1 = suite->add_family("f1");
-    f1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addDate(DateAttr(8, 6, 2015)); // Monday
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    boost::posix_time::ptime expected_time1 =
-        boost::posix_time::ptime(date(2015, 6, 8), time_duration(0, 0, 0)); // Monday & 00:00
-    boost::posix_time::ptime expected_time2 =
-        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 100; m++) {
-
-        // const std::vector<DateAttr>& dates = t1->dates();
-        // const std::vector<ecf::TimeAttr>& times = f1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // " " << dates[0].dump() << " " << times[0].dump() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << "  submitted at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
-            // times[0].dump() << "\n";
-
-            // 1st Run: MONDAY Morning 00:00 time was free from sunday
-            if (submitted == 1)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
-                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            // 2nd Run: Monday at 10:00
-            if (submitted == 2)
-                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time2,
-                                    "\nExpected to submit at " << expected_time2 << " only, but also found "
-                                                               << suite->calendar().suiteTime());
-
-            Node::Requeue_args args;
-            f1->requeue(args);
-            // cout << "  requeue at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
-            // times[0].dump() << "\n";
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 2, "Expected two submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_impossible_day_combination) {
-    cout << "ANode:: ...test_impossible_day_combination\n";
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  clock real 4.8.2019 # sunday
-    //  family f1
-    //    day monday
-    //    task t1        # task should never run, can't be Sunday/Monday at same time.
-    //      day tuesday
-    //      time 10:00
-    Defs defs;
-    suite_ptr suite = defs.add_suite("s1");
-    suite->addClock(ClockAttr(boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)))); // sunday
-    family_ptr f1 = suite->add_family("f1");
-    f1->addDay(DayAttr(DayAttr::MONDAY));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    t1->addDay(DayAttr(DayAttr::TUESDAY));
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 100; m++) {
-        // const std::vector<DateAttr>& fdates = f1->dates();
-        // const std::vector<DateAttr>& dates = t1->dates();
-        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // "\n   "
-        //          << fdates[0].dump() << " " << dates[0].dump() << " " << times[0].dump() << " rep: " <<
-        //          f1->repeat().value() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << " submitted " << suite->calendar().suiteTime() << " dayChanged:" <<
-            // suite->calendar().dayChanged() << "\n   "
-            //          << fdates[0].dump() << " " << dates[0].dump() << " " << times[0].dump() << " rep: " <<
-            //          f1->repeat().value() << "\n";
-            Node::Requeue_args args;
-            t1->requeue(args);
-        }
-
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 0, "Expected zero submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_CASE(test_impossible_date_combination) {
-    cout << "ANode:: ...test_impossible_date_combination\n";
-
-    // Create the suite, starting on a sunday
-    // suite s1
-    //  family f1
-    //    date 5.8.2019   # monday
-    //    task t1         # task should never run, can't be Sunday/Monday at same time.
-    //      date 6.8.2019 # tuesday
-    //      time 10:00
-    Defs defs;
-    suite_ptr suite = defs.add_suite("s1");
-    suite->addClock(ClockAttr(boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)))); // sunday
-    family_ptr f1 = suite->add_family("f1");
-    f1->addDate(DateAttr(5, 8, 2019)); // Monday
-    task_ptr t1 = f1->add_task("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
-    t1->addDate(DateAttr(6, 8, 2019)); // Tuesday
-    defs.beginAll();
-
-    CalendarUpdateParams calUpdateParams(hours(1));
-    // cout << defs << "\n";
-
-    int submitted = 0;
-    for (int m = 1; m < 100; m++) {
-        // const std::vector<DayAttr>& fdays = f1->days();
-        // const std::vector<DayAttr>& days = t1->days();
-        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
-        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
-        // "\n   "
-        //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
-        //          f1->repeat().value() << "\n";
-
-        Jobs jobs(&defs);
-        JobsParam jobsParam;
-        jobs.generate(jobsParam);
-
-        if (jobsParam.submitted().size()) {
-            submitted++;
-            // cout << " submitted at " << suite->calendar().suiteTime() << " dayChanged:" <<
-            // suite->calendar().dayChanged() << "\n   "
-            //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
-            //          f1->repeat().value() << "\n";
-            Node::Requeue_args args;
-            t1->requeue(args);
-        }
-        defs.updateCalendar(calUpdateParams);
-    }
-    BOOST_CHECK_MESSAGE(submitted == 0, "Expected zero submission but found " << submitted);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestVariableGeneration.cpp 5.13.0-1/ANode/test/TestVariableGeneration.cpp
--- 5.12.4-1/ANode/test/TestVariableGeneration.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestVariableGeneration.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,109 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Cal.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_VariableGeneration)
-
-static void findParentVariableValue(task_ptr t, const std::string& name, const std::string& expected) {
-    std::string value;
-    BOOST_CHECK_MESSAGE(t->findParentVariableValue(name, value),
-                        "Task " << t->debugNodePath() << " could not find variable of name " << name);
-    //   if (expected.empty()) std::cout << name  << " = " << value << "\n";
-    if (!expected.empty())
-        BOOST_CHECK_MESSAGE(value == expected,
-                            "From task " << t->debugNodePath() << " for variable " << name << " expected value "
-                                         << expected << " but found " << value);
-}
-
-BOOST_AUTO_TEST_CASE(test_generated_variables) {
-    std::cout << "ANode:: ...test_generated_variables\n";
-
-    task_ptr t;
-
-    Defs defs;
-    {
-
-        suite_ptr suite = defs.add_suite("suite");
-        suite->addRepeat(RepeatInteger("RepeatInteger", 10, 20, 1));
-
-        family_ptr fam = suite->add_family("f");
-        fam->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
-
-        t = fam->add_family("f2")->add_task("t");
-        std::vector<std::string> stringList;
-        stringList.reserve(3);
-        stringList.emplace_back("AA");
-        stringList.emplace_back("BB");
-        stringList.emplace_back("CC");
-        t->addRepeat(RepeatEnumerated("AEnum", stringList));
-    }
-
-    // Generate variables, needed since,findParentVariableValue also serach's the generated variables
-    defs.beginAll();
-
-    // Check Submittable generated variables
-    findParentVariableValue(t, "TASK", "t");
-    findParentVariableValue(t, Str::ECF_RID(), "");
-    findParentVariableValue(t, Str::ECF_TRYNO(), "0");
-    findParentVariableValue(t, Str::ECF_NAME(), "/suite/f/f2/t");
-    findParentVariableValue(t, Str::ECF_PASS(), "");
-    findParentVariableValue(t, Str::ECF_JOB(), "./suite/f/f2/t.job0");
-    findParentVariableValue(t, Str::ECF_JOBOUT(), "./suite/f/f2/t.0");
-    findParentVariableValue(t, Str::ECF_SCRIPT(), "./suite/f/f2/t.ecf");
-
-    // Check Family generated variables
-    findParentVariableValue(t, "FAMILY", "f/f2");
-    findParentVariableValue(t, "FAMILY1", "f2");
-
-    // Check Suite generated variables
-    findParentVariableValue(t, "SUITE", "suite");
-    findParentVariableValue(t, "YYYY", "");
-    findParentVariableValue(t, "DOW", "");
-    findParentVariableValue(t, "DOY", "");
-    findParentVariableValue(t, "DATE", "");
-    findParentVariableValue(t, "DAY", "");
-    findParentVariableValue(t, "DD", "");
-    findParentVariableValue(t, "MM", "");
-    findParentVariableValue(t, "MONTH", "");
-    findParentVariableValue(t, "ECF_DATE", "");
-    findParentVariableValue(t, "ECF_CLOCK", "");
-    findParentVariableValue(t, "ECF_TIME", "");
-    findParentVariableValue(t, "ECF_JULIAN", "");
-
-    // Test repeat generated variables
-    findParentVariableValue(t, "AEnum", "AA");
-    findParentVariableValue(t, "YMD", "20090101");
-    findParentVariableValue(t, "YMD_YYYY", "2009");
-    findParentVariableValue(t, "YMD_MM", "1");
-    findParentVariableValue(t, "YMD_DD", "1");
-    findParentVariableValue(t, "YMD_DOW", "4");
-    findParentVariableValue(t, "YMD_JULIAN", ecf::convert_to<std::string>(Cal::date_to_julian(20090101)));
-    findParentVariableValue(t, "RepeatInteger", "10");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestVariableInheritance.cpp 5.13.0-1/ANode/test/TestVariableInheritance.cpp
--- 5.12.4-1/ANode/test/TestVariableInheritance.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestVariableInheritance.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,80 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_VariableInheritance)
-
-static void findParentVariableValue(task_ptr t, const std::string& name, const std::string& expected) {
-    std::string value;
-    BOOST_CHECK_MESSAGE(t->findParentVariableValue(name, value),
-                        "Task " << t->debugNodePath() << " could not find variable of name " << name);
-    BOOST_CHECK_MESSAGE(value == expected,
-                        "From task " << t->debugNodePath() << " for variable " << name << " expected value " << expected
-                                     << " but found " << value);
-}
-
-BOOST_AUTO_TEST_CASE(test_variable_inheritance) {
-    std::cout << "ANode:: ...test_variable_inheritance\n";
-
-    // See page 31, section 5.1 variable inheritance, of SMS users guide
-    task_ptr t;
-    task_ptr t2;
-    task_ptr z;
-
-    Defs defs;
-    {
-        suite_ptr suite = defs.add_suite("suite");
-        suite->addVariable(Variable("TOPLEVEL", "10"));
-        suite->addVariable(Variable("MIDDLE", "10"));
-        suite->addVariable(Variable("LOWER", "10"));
-
-        family_ptr fam = suite->add_family("f");
-        fam->addVariable(Variable("MIDDLE", "20"));
-        t = fam->add_task("t");
-        t->addVariable(Variable("LOWER", "abc"));
-        t2 = fam->add_task("t2");
-
-        family_ptr fam2 = suite->add_family("f2");
-        fam2->addVariable(Variable("TOPLEVEL", "40"));
-        z = fam2->add_task("z");
-    }
-
-    // Generate variables, needed since,findParentVariableValue also serach's the generated variables
-    defs.beginAll();
-
-    // See page 31, section 5.1 variable inheritance, of SMS users guide
-    findParentVariableValue(t, "TOPLEVEL", "10");
-    findParentVariableValue(t2, "TOPLEVEL", "10");
-    findParentVariableValue(z, "TOPLEVEL", "40");
-
-    findParentVariableValue(t, "MIDDLE", "20");
-    findParentVariableValue(t2, "MIDDLE", "20");
-    findParentVariableValue(z, "MIDDLE", "10");
-
-    findParentVariableValue(t, "LOWER", "abc");
-    findParentVariableValue(t2, "LOWER", "10");
-    findParentVariableValue(z, "LOWER", "10");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestVariableSubstitution.cpp 5.13.0-1/ANode/test/TestVariableSubstitution.cpp
--- 5.12.4-1/ANode/test/TestVariableSubstitution.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestVariableSubstitution.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,494 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_VariableSubstitution)
-
-BOOST_AUTO_TEST_CASE(test_variable_substitution) {
-    std::cout << "ANode:: ...test_variable_substitution\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    {
-        s->addVariable(Variable("AVI", "avi"));
-        s->addVariable(Variable("BAHRA", "bahra"));
-        s->addVariable(Variable("LOWER", "10"));
-        s->addVariable(Variable("PATH", "/fred/bill/joe"));
-        s->addVariable(Variable("EMPTY_VARIABLE", ""));
-        s->addVariable(Variable("fred", "%bill%"));
-        s->addVariable(Variable("bill", "%fred%"));
-        s->addVariable(Variable("hello", "%hello%"));
-        s->addVariable(Variable("mary", "%jane%"));
-        s->addVariable(Variable("jane", "10"));
-    }
-
-    // See page 31, section 5.1 variable inheritance, of SMS users guide
-    std::string cmd = "%AVI%-%BAHRA%-%LOWER%-%AVI%";
-    string expected = "avi-bahra-10-avi";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%ECF_VERSION%";
-    expected = Version::raw();
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH%";
-    expected = "/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "/%AVI%/%BAHRA%/%LOWER%%PATH%";
-    expected = "/avi/bahra/10/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%EMPTY_VARIABLE%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%mary%";
-    expected = "10"; // double substitution
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%fred%";
-    expected = "%fred%"; // infinite substitution
-    BOOST_CHECK_MESSAGE(!s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%hello%";
-    expected = "%hello%"; // infinite substitution
-    BOOST_CHECK_MESSAGE(!s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = Ecf::MICRO();
-    expected = Ecf::MICRO();
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH";
-    expected = "%PATH";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%";
-    expected = "%";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%ERROR%";
-    expected = "%ERROR%";
-    BOOST_CHECK_MESSAGE(!s->variableSubstitution(cmd), " substitution expected to fail since ERROR does not exist");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    // new rules
-    // %<VAR>:substitute %
-    // If we find VAR, then use it, else use substitute
-    cmd      = "%AVI:goblly gook%";
-    expected = "avi";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH:goblly::: gook%";
-    expected = "/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%LOWER:fred% %AVI:fred2%";
-    expected = "10 avi";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%LOWER:fred% %AVI:fred2";
-    expected = "10 %AVI:fred2";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%EMPTY_VARIABLE::goblly gook%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL:goblly gook%";
-    expected = "goblly gook";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL::goblly gook%";
-    expected = ":goblly gook";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL:%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%:%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-}
-
-BOOST_AUTO_TEST_CASE(test_variable_substitution_double_micro) {
-    std::cout << "ANode:: ...test_variable_substitution_double_micro\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-
-    std::string cmd      = "%%";
-    std::string expected = "%";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%%";
-    expected = "%%";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%%%";
-    expected = "%%";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%%%%";
-    expected = "%%%";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "date +%%Y.%%m.%%d";
-    expected = "date +%Y.%m.%d";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "printf %%02d %HOUR:00%";
-    expected = "printf %02d 00";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    s->addVariable(Variable("HOUR", "hammer time"));
-    cmd      = "printf %%02d %HOUR:00%";
-    expected = "printf %02d hammer time";
-    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-}
-
-BOOST_AUTO_TEST_CASE(test_user_variable_substitution) {
-    std::cout << "ANode:: ...test_user_variable_substitution\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    {
-        s->addVariable(Variable("AVI", "avi"));
-        s->addVariable(Variable("BAHRA", "bahra"));
-        s->addVariable(Variable("LOWER", "10"));
-        s->addVariable(Variable("PATH", "/fred/bill/joe"));
-        s->addVariable(Variable("EMPTY_VARIABLE", ""));
-        s->addVariable(Variable("fred", "%bill%"));
-        s->addVariable(Variable("bill", "%fred%"));
-        s->addVariable(Variable("hello", "%hello%"));
-        s->addVariable(Variable("mary", "%jane%"));
-        s->addVariable(Variable("jane", "10"));
-    }
-
-    NameValueMap user_variables;
-    user_variables.insert(std::make_pair(string("AVI"), string("_avi")));
-    user_variables.insert(std::make_pair(string("BAHRA"), string("_bahra")));
-    user_variables.insert(std::make_pair(string("LOWER"), string("_10")));
-    user_variables.insert(std::make_pair(string("PATH"), string("_/fred/bill/joe")));
-    user_variables.insert(std::make_pair(string("EMPTY_VARIABLE"), string("_")));
-    user_variables.insert(std::make_pair(string("fred"), string("%bill%")));
-    user_variables.insert(std::make_pair(string("bill"), string("%fred%")));
-    user_variables.insert(std::make_pair(string("hello"), string("%hello%")));
-    user_variables.insert(std::make_pair(string("mary"), string("%jane%")));
-    user_variables.insert(std::make_pair(string("jane"), string("_10")));
-
-    // See page 31, section 5.1 variable inheritance, of SMS users guide
-    std::string cmd = "%AVI%-%BAHRA%-%LOWER%-%AVI%";
-    string expected = "_avi-_bahra-_10-_avi";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH%";
-    expected = "_/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "/%AVI%/%BAHRA%/%LOWER%%PATH%";
-    expected = "/_avi/_bahra/_10_/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%EMPTY_VARIABLE%";
-    expected = "_";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%mary%";
-    expected = "_10"; // double substitution
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%fred%";
-    expected = "%fred%"; // infinite substitution
-    BOOST_CHECK_MESSAGE(!s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%hello%";
-    expected = "%hello%"; // infinite substitution
-    BOOST_CHECK_MESSAGE(!s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = Ecf::MICRO();
-    expected = Ecf::MICRO();
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH";
-    expected = "%PATH";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%";
-    expected = "%";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%ERROR%";
-    expected = "%ERROR%";
-    BOOST_CHECK_MESSAGE(!s->variable_substitution(cmd, user_variables),
-                        " substitution expected to fail since ERROR does not exist");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    // new rules
-    // %<VAR>:substitute %
-    // If we find VAR, then use it, else use substitute
-    cmd      = "%AVI:goblly gook%";
-    expected = "_avi";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH:goblly::: gook%";
-    expected = "_/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%LOWER:fred% %AVI:fred2%";
-    expected = "_10 _avi";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%LOWER:fred% %AVI:fred2";
-    expected = "_10 %AVI:fred2";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%EMPTY_VARIABLE::goblly gook%";
-    expected = "_";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL:goblly gook%";
-    expected = "goblly gook";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL::goblly gook%";
-    expected = ":goblly gook";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL:%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%:%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-}
-
-BOOST_AUTO_TEST_CASE(test_user_variable_substitution_1) {
-    std::cout << "ANode:: ...test_user_variable_substitution_1\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    s->addVariable(Variable("AVI", "avi"));
-
-    NameValueMap user_variables;
-    user_variables.insert(std::make_pair(string("AVI:goblly gook"), string("avtar")));
-
-    // new rules
-    // %<VAR>:substitute %
-    // If we find VAR, then use it, else use substitute
-    // However when we have user_variables if we find the complete string
-    // in the user variable list, we use user veriable value:
-    // cmd = %FRED:BILL%"   and   user_variable = "FRED:BILL","Joe90"   ===> cmd = "Joe90"
-    std::string cmd      = "%AVI:goblly gook%";
-    std::string expected = "avtar";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%AVI:goblly%";
-    expected = "avi";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%FRED:goblly%";
-    expected = "goblly";
-    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-}
-
-static std::vector<std::string> required_server_variables() {
-    std::vector<std::string> required_server_variables;
-    required_server_variables.push_back(Str::ECF_PORT());
-    required_server_variables.push_back(Str::ECF_HOST());
-
-    required_server_variables.push_back(Str::ECF_HOME());
-    required_server_variables.emplace_back("ECF_LOG");
-    required_server_variables.emplace_back("ECF_CHECK");
-    required_server_variables.emplace_back("ECF_CHECKOLD");
-
-    // These variable are read in from the environment, but are not exposed
-    // since they only affect the server
-    // ECF_CHECKINTERVAL
-    // ECF_LISTS
-
-    // variables that can be overridden, in the suite definition
-    required_server_variables.emplace_back("ECF_JOB_CMD");
-    required_server_variables.emplace_back("ECF_KILL_CMD");
-    required_server_variables.emplace_back("ECF_STATUS_CMD");
-    required_server_variables.emplace_back("ECF_URL_CMD");
-    required_server_variables.emplace_back("ECF_URL_BASE");
-    required_server_variables.emplace_back("ECF_URL");
-    required_server_variables.emplace_back("ECF_MICRO");
-
-    // Reference variable, these should be read only
-    required_server_variables.emplace_back("ECF_PID");     // server PID
-    required_server_variables.emplace_back("ECF_VERSION"); // server version
-    return required_server_variables;
-}
-
-BOOST_AUTO_TEST_CASE(test_server_variable_substitution) {
-    std::cout << "ANode:: ...test_server_variable_substitution\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-
-    std::vector<std::string> vec = required_server_variables();
-    for (const auto& i : vec) {
-        if (i == "ECF_PID")
-            continue; // CANT test since, this is process ID of server
-        std::string value;
-        BOOST_CHECK_MESSAGE(s->findParentVariableValue(i, value), "Could not find Server variable " << i);
-        BOOST_CHECK_MESSAGE(!value.empty(), "Empty server variable value for " << i);
-    }
-
-    for (const auto& i : vec) {
-        if (i == "ECF_JOB_CMD")
-            continue; // CANT test since it requires %ECF_JOB% and %ECF_JOBOUT%
-        if (i == "ECF_KILL_CMD")
-            continue; // CANT test since it requires %ECF_PID%
-        if (i == "ECF_STATUS_CMD")
-            continue; // CANT test since it requires %ECF_RID%
-        if (i == "ECF_PID")
-            continue; // CANT test since, this is process ID of server
-        std::string cmd = "%";
-        cmd += i;
-        cmd += "%";
-        BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed for " << i << " : " << cmd);
-        if (i == "ECF_VERSION") {
-            BOOST_CHECK_MESSAGE(cmd == Version::raw(), "expected '" << Version::raw() << "' but found '" << cmd << "'");
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_generated_variable_substitution) {
-    // test that if ECF_OUT is defined using %, then we perform variable substitution
-    // test that if ECF_JOBOUT or ECF_JOB are specified, they take priority over the generated variables
-    std::cout << "ANode:: ...test_generated_variable_substitution\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    s->addVariable(Variable("PATH", "/fred/bill/joe"));
-    s->addVariable(Variable("ECF_HOME", "/ecf_home"));
-    family_ptr f = s->add_family("f");
-    task_ptr t   = f->add_task("t");
-    t->addVariable(Variable("ECF_OUT", "%PATH%"));
-    family_ptr f1 = s->add_family("f1");
-    f1->addVariable(Variable("PATH2", "/fred/bill/joe2"));
-    task_ptr t1 = f1->add_task("t1");
-    t1->addVariable(Variable("ECF_OUT", "%PATH2%"));
-    task_ptr t2 = f1->add_task("t2");
-    t2->addVariable(Variable("ECF_JOBOUT", "ECFLOW-999"));
-    t2->addVariable(Variable("ECF_JOB", "ECFLOW-999"));
-
-    // begin_all
-    defs.beginAll();
-    t->update_generated_variables();
-    t1->update_generated_variables();
-    t2->update_generated_variables();
-
-    // cout << defs;
-
-    string value;
-    value.clear();
-    t->findParentVariableValue(Str::ECF_JOBOUT(), value);
-    BOOST_CHECK_MESSAGE(value == "/fred/bill/joe/suite/f/t.0",
-                        "ECF_JOBOUT expected /fred/bill/joe/suite/f/t.0, but found " << value);
-
-    value.clear();
-    t1->findParentVariableValue(Str::ECF_JOBOUT(), value);
-    BOOST_CHECK_MESSAGE(value == "/fred/bill/joe2/suite/f1/t1.0",
-                        "ECF_JOBOUT expected /fred/bill/joe/suite/f/t.0, but found " << value);
-
-    // ECFLOW-999  make sure that if ECF_JOBOUT or ECF_JOB are overridden, they take priority over
-    // the generated variables of the same name
-    std::string cmd = Ecf::JOB_CMD();
-    BOOST_CHECK_MESSAGE(t2->variableSubstitution(cmd), " variableSubstitution failed for " << Ecf::JOB_CMD());
-
-    std::string expected = "ECFLOW-999 1> ECFLOW-999 2>&1";
-    BOOST_CHECK_MESSAGE(cmd == expected, "variable substitution failed expected " << expected << " but found " << cmd);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestVariableSubstitutionDefs.cpp 5.13.0-1/ANode/test/TestVariableSubstitutionDefs.cpp
--- 5.12.4-1/ANode/test/TestVariableSubstitutionDefs.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestVariableSubstitutionDefs.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,194 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_VariableSubstitutionDefs)
-
-BOOST_AUTO_TEST_CASE(test_defs_variable_substitution) {
-    std::cout << "ANode:: ...test_defs_variable_substitution\n";
-
-    Defs defs;
-    {
-        std::vector<Variable> vec;
-        vec.emplace_back("AVI", "avi");
-        vec.emplace_back("BAHRA", "bahra");
-        vec.emplace_back("LOWER", "10");
-        vec.emplace_back("PATH", "/fred/bill/joe");
-        vec.emplace_back("fred", "%bill%");
-        vec.emplace_back("bill", "%fred%");
-        vec.emplace_back("hello", "%hello%");
-        vec.emplace_back("mary", "%jane%");
-        vec.emplace_back("jane", "10");
-        defs.set_server().add_or_update_user_variables(vec);
-    }
-
-    // See page 31, section 5.1 variable inheritance, of SMS users guide
-    std::string cmd = "%AVI%-%BAHRA%-%LOWER%-%AVI%";
-    string expected = "avi-bahra-10-avi";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%ECF_VERSION%";
-    expected = Version::raw();
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH%";
-    expected = "/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "/%AVI%/%BAHRA%/%LOWER%%PATH%";
-    expected = "/avi/bahra/10/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%mary%";
-    expected = "10"; // double substitution
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%fred%";
-    expected = "%fred%"; // infinite substitution
-    BOOST_CHECK_MESSAGE(!defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%hello%";
-    expected = "%hello%"; // infinite substitution
-    BOOST_CHECK_MESSAGE(!defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = Ecf::MICRO();
-    expected = Ecf::MICRO();
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH";
-    expected = "%PATH";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%";
-    expected = "%";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%ERROR%";
-    expected = "%ERROR%";
-    BOOST_CHECK_MESSAGE(!defs.variableSubsitution(cmd), " substitution expected to fail since ERROR does not exist");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "";
-    expected = "";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    // new rules
-    // %<VAR>:substitute %
-    // If we find VAR, then use it, else use substitute
-    cmd      = "%AVI:goblly gook%";
-    expected = "avi";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%PATH:goblly::: gook%";
-    expected = "/fred/bill/joe";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%LOWER:fred% %AVI:fred2%";
-    expected = "10 avi";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%LOWER:fred% %AVI:fred2";
-    expected = "10 %AVI:fred2";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL:goblly gook%";
-    expected = "goblly gook";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL::goblly gook%";
-    expected = ":goblly gook";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%NULL:%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%:%";
-    expected = "";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-}
-
-BOOST_AUTO_TEST_CASE(test_defs_variable_substitution_double_micro) {
-    std::cout << "ANode:: ...test_defs_variable_substitution_double_micro\n";
-
-    Defs defs;
-
-    std::string cmd      = "%%";
-    std::string expected = "%";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%%";
-    expected = "%%";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%%%";
-    expected = "%%";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "%%%%%";
-    expected = "%%%";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "date +%%Y.%%m.%%d";
-    expected = "date +%Y.%m.%d";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    cmd      = "printf %%02d %HOUR:00%";
-    expected = "printf %02d 00";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-
-    defs.set_server().add_or_update_user_variables("HOUR", "hammer time");
-    cmd      = "printf %%02d %HOUR:00%";
-    expected = "printf %02d hammer time";
-    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
-    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/TestZombies.cpp 5.13.0-1/ANode/test/TestZombies.cpp
--- 5.12.4-1/ANode/test/TestZombies.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/TestZombies.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Node)
-
-BOOST_AUTO_TEST_SUITE(T_Zombies)
-
-BOOST_AUTO_TEST_CASE(test_zombies) {
-    cout << "ANode:: ...test_zombies\n";
-    Defs theDefs;
-    suite_ptr s = theDefs.add_suite("s");
-    task_ptr t  = s->add_family("f")->add_task("t");
-
-    // SANITY
-    {
-        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 0, "Expected 0 zombies but found " << s->zombies().size());
-        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::USER).empty(), "Expected no zombies");
-        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF).empty(), "Expected no zombies");
-        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF_PID).empty(), "Expected no zombies");
-        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF_PASSWD).empty(), "Expected no zombies");
-        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF_PID_PASSWD).empty(), "Expected no zombies");
-        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::PATH).empty(), "Expected no zombies");
-        ZombieAttr attr;
-        BOOST_REQUIRE_MESSAGE(!t->findParentZombie(ecf::Child::PATH, attr) && attr.empty(),
-                              "Expected to NOT find PATH zombies on parent");
-    }
-
-    // ADD
-    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
-    {
-        s->addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
-        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 1, "Expected 1 zombie but found " << s->zombies().size());
-        s->addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
-        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 2, "Expected 2 zombie but found " << s->zombies().size());
-        s->addZombie(ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::FAIL, 100));
-        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 3, "Expected 3 zombie but found " << s->zombies().size());
-        s->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::FAIL, 100));
-        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 4, "Expected 4 zombie but found " << s->zombies().size());
-        s->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::FAIL, 100));
-        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 5, "Expected 5 zombie but found " << s->zombies().size());
-        s->addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
-        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 6, "Expected 6 zombie but found " << s->zombies().size());
-    }
-
-    // FIND
-    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::USER).empty(), "Expected to find USER zombies");
-    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF).empty(), "Expected to find ECF zombies");
-    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF_PID).empty(), "Expected to find ECF_PID zombies");
-    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF_PID_PASSWD).empty(),
-                          "Expected to find ECF_PID_PASSWD zombies");
-    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF_PASSWD).empty(), "Expected to find ECF_PASSWD zombies");
-    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::PATH).empty(), "Expected to find PATH zombies");
-
-    // FIND on parent
-    {
-        ZombieAttr path_z, ecf_z, ecf_pid_z, ecf_pid_passwd_z, ecf_passwd_z, user_z;
-        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::PATH, path_z) && !path_z.empty(),
-                              "Expected to find PATH zombies on parent");
-        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF, ecf_z) && !ecf_z.empty(),
-                              "Expected to find ECF zombies on parent");
-        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF_PID, ecf_pid_z) && !ecf_pid_z.empty(),
-                              "Expected to find ECF_PID zombies on parent");
-        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF_PID_PASSWD, ecf_pid_passwd_z) &&
-                                  !ecf_pid_passwd_z.empty(),
-                              "Expected to find ECF_PID_PASSWD zombies on parent");
-        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF_PASSWD, ecf_passwd_z) && !ecf_passwd_z.empty(),
-                              "Expected to find ECF_PASSWD zombies on parent");
-        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::USER, user_z) && !user_z.empty(),
-                              "Expected to find USER zombies on parent");
-    }
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/base_date.h 5.13.0-1/ANode/test/data/ECFLOW_672/base_date.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/base_date.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/base_date.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#base_date.h
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/base_ic.h 5.13.0-1/ANode/test/data/ECFLOW_672/base_ic.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/base_ic.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/base_ic.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-#base_ic.h
-%include <suite.h>
-%include <date.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/base_se.h 5.13.0-1/ANode/test/data/ECFLOW_672/base_se.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/base_se.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/base_se.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-#base_se.h
-%include <suite.h>
-%include <lib.h>
-%include <date.h>
-%include <ic.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/date.h 5.13.0-1/ANode/test/data/ECFLOW_672/date.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/date.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/date.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-#date.h
-%include <base_date.h>
-%include <hc_date.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/hc_date.h 5.13.0-1/ANode/test/data/ECFLOW_672/hc_date.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/hc_date.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/hc_date.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#hc_date.h
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/ic.h 5.13.0-1/ANode/test/data/ECFLOW_672/ic.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/ic.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/ic.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#ic.h
-%include <suite.h>
-%include <base_ic.h>
-%include <hc_date.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/lib.h 5.13.0-1/ANode/test/data/ECFLOW_672/lib.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/lib.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/lib.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#lib.h
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/ms.h 5.13.0-1/ANode/test/data/ECFLOW_672/ms.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/ms.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/ms.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-#ms.h
-%include <suite.h>
-%include <ic.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/ms_mem.h 5.13.0-1/ANode/test/data/ECFLOW_672/ms_mem.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/ms_mem.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/ms_mem.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-#ms_mem.h
-%include <ms.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/se.h 5.13.0-1/ANode/test/data/ECFLOW_672/se.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/se.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/se.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-#se.h
-%include <base_se.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/se_mem.h 5.13.0-1/ANode/test/data/ECFLOW_672/se_mem.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/se_mem.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/se_mem.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-#se_mem.h
-%include <se.h>
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/suite.h 5.13.0-1/ANode/test/data/ECFLOW_672/suite.h
--- 5.12.4-1/ANode/test/data/ECFLOW_672/suite.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/suite.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#suite.h
diff -pruN 5.12.4-1/ANode/test/data/ECFLOW_672/t.ecf 5.13.0-1/ANode/test/data/ECFLOW_672/t.ecf
--- 5.12.4-1/ANode/test/data/ECFLOW_672/t.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/ECFLOW_672/t.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-%include <se_mem.h>
-%include <ms_mem.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME/suite/family/head.h 5.13.0-1/ANode/test/data/SMSHOME/suite/family/head.h
--- 5.12.4-1/ANode/test/data/SMSHOME/suite/family/head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME/suite/family/head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,47 +0,0 @@
-#!/bin/ksh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-set -e # stop the shell on first error
-set -u # fail when using an undefined variable
-set -x # echo script lines as they are executed
-
-# Defines the three variables that are needed for any
-# communication with ECF_
-
-export ECF_PORT=%ECF_PORT%    # ECF_ port numner
-export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%
-fi
-
-# Tell ECF_ we have stated
-# The ECF_ variable ECF_RID will be set to parameter of smsinit
-# Here we give the current PID.
-
-#smsinit $$
-
-# Defined a error hanlder
-
-ERROR() {
-	set +e        # Clear -e flag, so we don't fail
-	#smsabort      # Notify ECF_ that something went wrong
-	trap 0        # Remove the trap
-	exit 0        # End the script
-}
-
-# Trap any calls to exit and errors caught by the -e flag
-
-trap ERROR 0
-
-# Trap any signal that may cause the script to fail
-
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME/suite/family/t1.ecf 5.13.0-1/ANode/test/data/SMSHOME/suite/family/t1.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME/suite/family/t1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME/suite/family/t1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,81 +0,0 @@
-%manual
-	OPERATORS: This is an example of using a manual
-	
-	This is used to also test variable subsitution of 
-	generated variables
-	SUITE     = %SUITE%
-	DATE      = %DATE%
-	DAY       = %DAY%
-	DD        = %DD%
-	DOW       = %DOW%
-	DOY       = %DOY%
-	MM        = %MM%
-	MONTH     = %MONTH%
-	YYYY      = %YYYY%
-	ECF_DATE   = %ECF_DATE%
-	ECF_TIME   = %ECF_TIME%
-	ECF_CLOCK  = %ECF_CLOCK%
-
-	FAMILY    = %FAMILY%
-	FAMILY1   = %FAMILY1%
-
-	TASK      = %TASK%
-	ECF_RID    = %ECF_RID:<not defined yet, since empty string in task>%
-	ECF_TRYNO  = %ECF_TRYNO%
-	ECF_NAME   = %ECF_NAME%
-	ECF_PASS   = %ECF_PASS%
-	ECF_SCRIPT = %ECF_SCRIPT%
-	ECF_JOB    = %ECF_JOB%
-	ECF_JOBOUT = %ECF_JOBOUT%
-    
-    Other ECF_ variables
-   ECF_KILL_CMD    = %ECF_KILL_CMD:<not defined yet>%
-   ECF_STATUS_CMD  = %ECF_STATUS_CMD:<not defined yet>%
-	ECF_JOB_CMD     = %ECF_JOB_CMD%
-	ECF_HOME      = %ECF_HOME%
-	ECF_TRIES     = %ECF_TRIES:<Error>%
-	SMFILES       = %SMFILES:<not defined yet>%
-	ECF_INCLUDE   = %ECF_INCLUDE:<not defined yet>%
-	ECF_FETCH     = %ECF_FETCH:<not defined yet>%
-	ECF_OUT       = %ECF_OUT:<not defined yet>%
-	ECF_MICRO=%ECF_MICRO%
-%end
-
-#============================================================
-# Using angle brackets should use ECF_INCLUDES
-#=========================================================
-%include <head.h>
-
-
-echo do some work
-# SLEEPTIME is defined thedefs.def file. Test variable substituition
-sleep %SLEEPTIME%
-echo end of job
-
-
-%include <tail.h>
-
-# This is used in TestEcfFile.cpp
-# o check we handle ecfmicro when extracting manuals
-# o ensure we only handle manual/end if preceded with current ecfmicro char
-# o Pre-process %includes in manual, treat contents as manual contents
-%ecfmicro *
-*manual
-*include <manual.h>
- manual-1
- end-1
-*end
-*ecfmicro %
-
-%manual
-Rest of the manual page is placed here, closer to the code
-%end
-%comment
-  Comment start
-%end
-%comment
-  Comment end
-%end
-%nopp
-  ignore everything in here
-%end
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME/suite/family/t2.ecf 5.13.0-1/ANode/test/data/SMSHOME/suite/family/t2.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME/suite/family/t2.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME/suite/family/t2.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
- 
-# using %include "filename"
-# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
-#
-# since we are using quotes we expect to find 'head.h' and 'tail.h'
-# in the same directory as the sms files.
-#======================================================================
-%include "head.h"
-
-
-echo do some work
-# SLEEPTIME is defined thedefs.def file. Test variable substituition
-sleep 10
-echo end of job
-
-
-%include "tail.h"
-
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME/suite/family/t3.ecf 5.13.0-1/ANode/test/data/SMSHOME/suite/family/t3.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME/suite/family/t3.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME/suite/family/t3.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,39 +0,0 @@
-# using %include "filename"
-# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
-#
-# since we are using quotes we expect to find 'head.h' and 'tail.h'
-# in the same directory as the sms files.
-#======================================================================
-%include "head.h"
-
-
-echo do some work
-sleep 10
-echo end of job
-
-#=====================================================
-# change the ecfmicro character
-%ecfmicro &
-
-&manual
-	START Rest of the manual page is placed here, closer to the code
-&end
-&comment
-  Comment start
-  &SUITE&
-&end
-&comment
-  Comment end
-&end
-&nopp
-  ignore everything in here
-&end
-&manual
-	END of the manual
-&end
-#=====================================================
-# change the ecfmicro character back
-&ecfmicro %
-
-
-%include "tail.h"
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME/suite/family/tail.h 5.13.0-1/ANode/test/data/SMSHOME/suite/family/tail.h
--- 5.12.4-1/ANode/test/data/SMSHOME/suite/family/tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME/suite/family/tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-#smscomplete  # Notify SMS of a normal end
-trap 0       # Remove all traps
-exit 0       # End the shell
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME/suite/family.man 5.13.0-1/ANode/test/data/SMSHOME/suite/family.man
--- 5.12.4-1/ANode/test/data/SMSHOME/suite/family.man	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME/suite/family.man	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-Special case where there are no manual directives.
-Just include contents of file as is:
-
-no directives in here either
-%include <manual.h> 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME/suite.man 5.13.0-1/ANode/test/data/SMSHOME/suite.man
--- 5.12.4-1/ANode/test/data/SMSHOME/suite.man	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME/suite.man	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-%manual
-%include <manual.h>
-suite manual
-%end
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-
-# test for unterminated manual
-
-%manual
-	OPERATORS: This is an example of using a manual
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad1.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad1.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-# test for unterminated comment
-
-%comment
-	OPERATORS: This is an example of using a manual
-  
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad10.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad10.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad10.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad10.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-
- 
-# test for uneven number for microcharacter's
- 
-%ecfmicro £
-sleep £SLEEPTIME
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad11.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad11.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad11.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad11.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-
- 
-# test for uneven number for microcharacter's
- 
-%ecfmicro £
-sleep £SLEEPTIME££
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad12.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad12.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad12.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad12.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-sleep %SLEEPTIME # test for uneven number for microcharacter's with comments, start of line
-                 # this is different to bad9.ecf
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad13.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad13.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad13.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad13.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-# test missnamed include
-%includeblahblah <good_head.h>
-%includeblah <good_tail.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad14.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad14.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad14.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad14.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-# unknow directive
-%fred
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad15.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad15.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad15.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad15.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-# test unrecognized pre-processing directive
-%ecfmicro * 
-*VAR
-*ecfmicro %
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad2.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad2.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad2.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad2.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-
-# test for missing nopp, manual, comment
-
-%end
-	 
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad3.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad3.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad3.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad3.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-
-# test for unterminate nopp
-
-%nopp
-  ignore everything in here
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad4.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad4.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad4.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad4.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-
-#
-# test for embedded manual
-%manual
-	OPERATORS: This is an example of usinh a manual
-	First include head.h
-	
-%manual
-    Illegal we can't have embedded manuals
-%end
-
-%end
- 
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad5.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad5.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad5.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad5.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-
-#
-# test for embedded comments
-#
-
-%comment
-	OPERATORS: This is an example of using a manual
-	First include head.h
-	
-%comment
-    Illegal we can't have embedded comments
-%end
-
-%end
- 
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad6.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad6.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad6.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad6.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-
-#
-# test for embedded  manual/comment
-#
-
-%comment
-	OPERATORS: This is an example of usinh a manual
-	First include head.h
-	
-%manual
-    Illegal we cannt have embedded manuals in a comment
-%end
-
-%end
- 
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad7.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad7.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad7.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad7.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
- 
- 
-# test for uneven number for microcharacter's
- 
-sleep %SLEEPTIME%%
-
- 
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad8.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad8.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad8.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad8.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-# test for uneven number for microcharacter's
-sleep %SLEEPTIME
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad9.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad9.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad9.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad9.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-
-sleep %SLEEPTIME # test for uneven number for microcharacter's with comments
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-
-
-# Test that a replacement character should be specified for ecfmicro
- 
-%ecfmicro
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-# Test that a replacement character for ecfmicro must be single character
-# Note: a single £ is multi-character of size 2
- 
-%ecfmicro ££
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/a.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/a.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/a.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/a.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-# a.h
-%include <b.h>
-%include <c.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/b.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/b.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/b.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/b.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-# b.h
-%include <d.h>
-%include <e.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/c.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/c.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/c.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/c.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-# c.h
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/d.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/d.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/d.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/d.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-# d.h
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/e.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/e.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/e.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/e.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-%include <b.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/good_head.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/good_head.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/good_head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/good_head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-# just need empty file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/good_tail.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/good_tail.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/good_tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/good_tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-# just need empty file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/ok.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/ok.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/ok.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/ok.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-# file ok.h
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/recursive_head.h 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/recursive_head.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/includes/recursive_head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/includes/recursive_head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-#!/bin/ksh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-#
-# test recursive include
-#
-%include <recursive_head.h>
-
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/recursive_include1.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/recursive_include1.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/recursive_include1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/recursive_include1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-#======================================================================
-# test recursive include
-#======================================================================
-%include <recursive_head.h>
-
-
-echo do some work
-sleep 10
-echo end of job
-
-
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/bad/recursive_include2.ecf 5.13.0-1/ANode/test/data/SMSHOME2/bad/recursive_include2.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/bad/recursive_include2.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/bad/recursive_include2.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-# test for recursive includes
-%include <a.h>
-
-# a.h -> b.h -> d.h
-#               e.h -> b.h
-#        c.h
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/.gitignore 5.13.0-1/ANode/test/data/SMSHOME2/good/.gitignore
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/.gitignore	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/.gitignore	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-/suite
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/ecf_micro_2.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/ecf_micro_2.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/ecf_micro_2.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/ecf_micro_2.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-
-%ecfmicro ^
-exe_time=`date +%s -r ACore/bin/^COMPILER_TEST_PATH:gcc^/u_acore`
-^ecfmicro %
-
-%manual
-  Rest of the manual page is placed here, closer to the code
-%end
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/ecfmicro.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/ecfmicro.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/ecfmicro.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/ecfmicro.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-
-# test exfmicro with a pound sign, this is multi-character
-%ecfmicro £  
-
-£VAR:sub£
-
-£ecfmicro %
-
-%VAR1:sub%
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/good.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/good.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/good.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/good.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-%manual
-	OPERATORS: This is an example of usinh a manual
-	First include head.h
-%end
-
-echo do some work
-echo end of job
-
-%manual
-  Rest of the manual page is placed here, closer to the code
-%end
-%comment
-  Comment start
-%end
-%comment
-  Comment end
-%end
-
-%nopp
-  ignore everything in here
-%end
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/good1.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/good1.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/good1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/good1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
- #============================================================
-# test for include included twice. 
-# This is not a recursive include
-#=========================================================
-%include <head.h>
-%include <head.h>
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/good2.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/good2.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/good2.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/good2.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-# sleep %SLEEPTIME test for uneven number for microcharacter's
-sleep %SLEEPTIME%
-# sleep %SLEEPTIME test for uneven number for microcharacter's
-# %fred
-# fred%
-        # %%fred%
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includeonce.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/includeonce.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includeonce.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includeonce.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-%includeonce <head.h>
-%includeonce <head.h>
-%include <head.h>
-%includeonce <tail.h>
-%include <tail.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includeonce_recursive.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/includeonce_recursive.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includeonce_recursive.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includeonce_recursive.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-%includeonce <recursive_include.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/config.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/config.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/config.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/config.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,1527 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-#=======================================================================
-#  config.h
-#=======================================================================
-banner config.h
-
-if [[ "$ARCH" != "linux" ]] ;then
-  typeset -l ARCH
-fi
-
-export SCRATCHDIR=${SCRATCHDIR:-UNDEFINED}
-export ARCH=${ARCH:-sgimips}
-export TMPDIR=${TMPDIR:-UNDEFINED}
-export HOST=${HOST:-`hostname`}
-export NPES=${NPES:-0}
-
-if [[ $ARCH = linux ]] ; then
-  export EMOS_TMPDIR=/var/tmp/tmpdir/%TASK%_%ECF_TRYNO%.$$
-  export TMPDIR=$EMOS_TMPDIR
-  [[ -d $TMPDIR ]] || mkdir -p $TMPDIR
-  export USE_EMOS_TMP="true"
-  cd $TMPDIR
-else
-  EMOS_TMPDIR=""
-fi
-
-if [[ "$TMPDIR" = "UNDEFINED" ]] ; then
-   TMPDIR="$TEMP/NQS_tmpdir.$$"  export TMPDIR
-   export USE_EMOS_TMP="true"
-   [[ -d $TMPDIR ]] || mkdir $TMPDIR
-   if [[ $? -ne 0 ]] ; then
-      echo "####### CANNOT CREATE TMPDIR #######" >&2
-      exit 1
-   fi
-fi
-
-PS4="+ "
-
-echo "\
-  This is the config.h file and\n\
-  System variables used were:\n\
-  USER     $USER\n\
-  TMPDIR   $TMPDIR\n\
-  HOME     $HOME\n\
-  HOST     $HOST\n\
-  ARCH     $ARCH\n\
-  PATH     $PATH\n\
-"
-set -xa
-
-#=======================================================================
-#  Experiment version and initial data origin (default values)
-#=======================================================================
-
-EXPVER=%VERSION:0001%
-GRIBCLASS=1
-BASEVER=0001
-BASETIME=1996072200
-
-#=======================================================================
-#  Software configuration (library cycles etc)
-#=======================================================================
-
-IFSMASTER=ifsMASTER
-#####################################
-IFS_CYCLE=35r3
-#####################################
-
-
-SUITE_TYPE=%SUITE_TYPE:"undef"%
-NEWSTREAM=none
-EMOS_CYCLE=000370
-VIEW_IFS=
-VIEW_IFSAUX=
-VIEW_OBSPROC=
-VIEW_OBSORT=
-VIEW_TOVSCODE=
-VIEW_SSMICODE=
-VIEW_BL=
-VIEW_SSA=
-VIEW_SST=
-VIEW_WAM=
-MAKE_LIBS=yes
-
-GRIB_API_VERSION=1.8.0
-GRIB_API_INCLUDE="-I/usr/local/lib/metaps/lib/grib_api/jasper/include -I/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/include"
-GRIB_API_LIB="-L/usr/local/lib/metaps/lib/grib_api/jasper/lib -ljasper -L/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/lib -lgrib_api_f90 -lgrib_api"
-export GRIB_API=/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/bin   # change to fixed version
-export PATH=$GRIB_API:$PATH
-
-#=======================================================================
-#  Model configuration
-#=======================================================================
-
-RESOL=799
-LEVELS=91
-GTYPE=l_2
-FCLENGTH=%FCLENGTH:6%
-FCLENGTH0N=$FCLENGTH
-RUN_GFC=no
-
-#=======================================================================
-#  Analysis parameters
-#=======================================================================
-
-IFSMODE=early_delivery
-PERIOD=6
-TSTEP=720
-
-if [[ "%STREAM%" = SCDA ]] && [[ %MXUP_TRAJ:3% = 1 ]] ; then
-  RESOLINC_0=255 # HR:255, LR:159
-  TSTEP_INC_0=1800
-else
-  RESOLINC_0=95
-  TSTEP_INC_0=3600
-fi
-
-RESOLINC_1=159     # 255 32r1
-RESOLINC_2=255     # 159 32r1
-TSTEP_INC_1=1800
-TSTEP_INC_2=1800
-
-LFG=.false.
-
-ITER_MIN_0=70
-ITER_MIN_1=50
-ITER_MIN_2=50
-MXUP_TRAJ=%MXUP_TRAJ:3%
-NMINSIMPHY=1
-LINCNMI=false
-LVERIFY_SCREEN=true
-SCRANA=active
-
-RESOLFCE=42
-ITER_FCE=150
-NWRIEVEC=25
-
-OBPATH=ops
-BLACK_DS=ops
-BLACK_MM=ops
-BLACK_EX=ops
-
-LOZONE=true
-LOZONECH=true
-ANEMOM_HT=true
-LISENTRPP=true
-LESUITE=false
-
-OBNLAT=90.00
-OBSLAT=-90.00
-OBWLON=-180.00
-OBELON=180.00
-
-MPLARGS="check=0"
-
-#================================
-# New for 25r3
-
-LINRADEX=true
-LREDUCOB=false
-TSLOTSEC=1800
-UPTRAJ_FCE=0
-LAMV_REASSIGN=false
-
-#================================
-# New for 25r4
-
-BRANCH=""
-BRF=0
-LAIRS=true
-PARALLEL=4
-PROJECTS="none"
-
-#================================
-# New for 26r3
-
-if [[ "%SUITE%" = o || "%SUITE%" = e_* ]] ; then
-  LARCHINCR=true
-else
-  LARCHINCR=false
-fi
-
-#================================
-# New for 28r1
-
-FPOSCLD=%FPOSCLD:false%  # should be true for 4dvar, false for 3d_fgat
-PROFILE=%PROFILE:0%  # for diagnostic purposes
-LANOBSENS=false
-
-#================================
-# New for 28r2
-#==========================================================
-# Variables configuring testOfAnalysis
-#==========================================================
-LTESTVAR=false
-NTESTVAR=0
-LCVTEST=false
-LTLTEST=false
-LADTEST=false
-LGRTEST=false
-LTESTINC=false    # should be set to false and will turn off other testing
-
-#==========================================================
-# New for 28r3
-#==========================================================
-REINIHOUR=%REINIHOUR:0%
-ED_PERIOD=%ED_PERIOD:12%
-ED_ONLY=%ED_ONLY:false%
-REINICLASS=%REINICLASS:od%
-REINI_NOT_ED=%REINI_NOT_ED:false%
-OBSTREAM=%STREAM%
-
-#==========================================================
-# New for 29r1
-#==========================================================
-set -a
-LOBREALTIME=%OBREALTIME:false% ; # false in catchup mode, true in rt
-LCALC_PSBIAS=%CALC_PSBIAS:true%
-LUSE_PSBIAS=%USE_PSBIAS:true%
-INIPSBIAS=%INIPSBIAS:true%
-INIVARBC=%INIVARBC:false%
-
-NTYPE_MODERR=2
-NCOMP_MODERR=1
-LFGMODERR=true
-ALPHAQ=0.3         # 31r2
-NSERR=-1
-LINITCV=true
-LMODERRFC=false
-LBGMODERR=false
-
-LPROPTL=false
-LINTEST=false
-
-SAVINI=false
-
-EPSROTPATH=""
-
-#==========================================================
-# New for 29r2
-#==========================================================
-set -a
-LTWINTRUTH=false
-LTWINEXP=false
-TRUTHEXP="none"
-LCO2=false
-LCO2ANER=false
-INICO2=false
-LERA40_PREODB=false
-Q2CREATE_NEWSTREAM=false
-Q2USE=false
-Q2CHANGELIST=0
-
-# EPS
-NSVET=50
-NITERLET=120
-EPSBASIS=50 # number of tropical singular vectors used in
-            # Gaussian sampling
-EPSBASIST=5 # number of tropical singular vectors used in
-
-            # in order to startup emc suite this might be set to 25
-            # for the first 2 way. Then make_sv would not be used.
-
-EPSEVO_NORMALIZE=true
-ICPEXPVER=%ICPEXPVER:0001%
-EPSGAMMA_TC2INI=1.5
-EPSGAMMA_EVO2INI=1.0 # 1.5 for 29r2
-EPSGAMMA=0.014
-EPSSIMPL=5     # Gaussian sampling for all singular vectors
-#==========================================================
-# New for 29r3
-#==========================================================
-
-LGPINNER=true
-NFRDHP=3
-
-#==========================================================
-# New for 30r1
-#==========================================================
-FILTERRESOL=255
-FILTERFACTOR=5
-FILTEREXPONENT=4
-EC_FILL_NANS=false
-USE_SMT=%USE_SMT:true%
-
-if [[ "%EC_SMT:yes%" = yes ]] ; then
-  USE_SMT=true
-else
-  USE_SMT=false
-fi
-
-#==========================================================
-# New for 30r2
-#==========================================================
-LUSE_RSTBIAS=%USE_RSTBIAS:true%
-ERA_MODE=false
-
-#==========================================================
-# New for 31r1
-#==========================================================
-DOFDBK=true # ie true
-LCALC_RSTBIAS=%CALC_RSTBIAS:false%
-VARBC_PATH=%VARBC_PATH:standard%
-NCS_CONFIG=2  # 31r2
-USE_SMT=%USE_SMT:true%
-LPML=%PRODUCE_EPS_ML:0%
-
-if [[ %EC_SMT:yes% = yes ]] && [[ %USE_SMT:true% = false ]] ; then
-  echo "ECF_ variable EC_SMT and USE_SMT are not compatible"
-  exit 1
-elif [[ %EC_SMT:yes% = no ]] && [[ %USE_SMT:true% = true ]] ; then
-  echo "ECF_ variable EC_SMT and USE_SMT are not compatible"
-  exit 1
-fi
-#==========================================================
-# New for 31r2
-#==========================================================
-LRAIN4D=true
-LNMPHYS=true   #32r1
-ENDANENS=0
-ENDANENSODB=0
-
-P4CLIENT=0     #32r1 not used in operations
-
-#==========================================================
-# New for 32r1
-#==========================================================
-LCONSTANT_VARBC=false
-
-#==========================================================
-# New for 32r2
-#==========================================================
-LIASI=true
-
-INIMODISALB=true # if intial data was run with 32r1 or later
-VARBC_ARCHIVE_EVOLVE=false
-
-#==========================================================
-# New for 32r3
-#==========================================================
-LFULL_IASI=%LFULL_IASI:true%   # true = use full iasi data and screen: false use screened data
-LGEMS=false                    # run with gems parameters
-GHGVAR=
-GRGVAR=
-AEROVAR=
-TRACVAR=
-INIGHG=false
-INIGRG=false
-INIAERO=false
-INITRAC=false
-LEVGEN=true          # Use van Genuchten hydrology
-INIHTESSEL=true      # if starteding from experiment where LEVGEN=true
-LCALC_RSTRHBIAS=%CALC_RSTRHBIAS:true%
-LUSE_RSTRHBIAS=%LUSE_RSTRHBIAS:true%
-LSSMI1D=true
-LSSMIS1D=true
-LAMSRE1D=true
-LTMI1D=true
-LAMSRE1D=true
-ODB_IO_OPENMP=1
-
-#==========================================================
-# New for 33r2
-#==========================================================
-LOBSCOR=false
-
-#==========================================================
-# New for 35r2
-#==========================================================
-
-LECURR=false
-INIECURR=false
-LSCATT_NEUTRAL=false
-D3GGFIELDSSTEND="0"
-LFSOBS=false
-LSEKF=false
-
-#==========================================================
-# New for 35r3
-#==========================================================
-# if EPS or associated then LEMISKF & LWEAK4DVAR=false
-INIOZONE=true
-
-WEAK4D_INTERV=0.0
-LMODERR_PERIODIC=false
-NSPLIT4DWIN=0
-LBALSTRATO=false
-AMSU_LAND=Dynamic_emis
-EMISKF_PATH=standard
-INIEMISKF=true
-INIMODERR=true
-LDUCTDIA=false
-LASCATSM=true
-if [[ %SUITE% = "e_*" ]] ; then LANOBSENS=true; fi
-
-#==========================================================
-# Variables configuring ifs_ctm
-#==========================================================
-LCOUPLO4=false
-CTM_MODEL=mozart
-NFRCOUPLO4=1
-NFRCOUPLO4_FB=1
-LGLOBALGP=true
-LGLOBALSP=true
-MPROCGPG=1
-MPROCSPG=1
-LOUT_SPC=false
-LOUT_FLUX=true
-LOUT_COOR=false
-LIN_GRG=true
-LIN_COOR=false
-LCOUPLO4_CTM=true
-LOUT_GRG=false
-LOUT_CO=false
-LOUT_SO2=false
-LOUT_NOX=false
-LOUT_NO2=false
-LOUT_GO3=false
-LOUT_HCHO=false
-LNOX2NO2=false
-INTERP2D=bilinear
-PARA_SEARCH=global
-IF_MASKED=novalue
-LGRG_CYCLE=true
-LDIFF_GRG=false
-LCONV_GRG=false
-LDIA_GRG=false
-NPROC_CTM=8
-NPROC_CTM_AN=8
-NPROC_DRV=1
-CTM_THREADS=4
-CTM_THREADS_AN=4
-DRV_THREADS=1
-DRV_THREADS_AN=1
-IFS_THREADS_AN=6
-LSTATS=true
-
-#==========================================================
-# Variables configuring Gems
-#==========================================================
-LGEMS=false
-GHGVAR=""
-INIGHG=false
-GRGVAR=""
-INIGRG=false
-AEROVAR=""
-INIAERO=false
-TRACVAR=""
-INITRAC=false
-
-#=======================================================================
-# DR_HOOK
-#=======================================================================
-DR_HOOK=true # 30r1 was false
-DR_HOOK_OPT="none" # 30r1 was "prof"
-DR_HOOK_PROFILE_LIMIT=-10
-DR_HOOK_HASHBITS=15
-DR_HOOK_CATCH_SIGNALS=false
-DR_HOOK_IGNORE_SIGNALS=false
-
-LIBHPM=""
-if [[ $DR_HOOK = true ]] ; then
-  DR_HOOK_OPT=`echo $DR_HOOK_OPT | sed -e 's/\// /g'`
-  if [[ $ARCH = ibm_power4 ]] ; then
-    LIBHPM="-L/usr/pmapi/lib -lpmapi"
-  fi
-fi
-
-#=======================================================================
-#  BC project setup for analysis (only those that are different)
-#=======================================================================
-
-if [[ "%STREAM%" = SCDA ]] ; then
-  PERIOD_4D=6 ;
-  WINDOW_LENGTH_4D=%WINDOW_LENGTH_4D:12%
-  WINDOW_OFFSET_4D=%WINDOW_OFFSET_4D:9%
-
-  if [[ %MXUP_TRAJ:3% = 3 ]] ; then
-
-  IFSMODE=4d_inc
-
-  else
-
-  IFSMODE=3d_fgat
-  ITER_MIN=70
-  ITER_MIN_1=0
-  SIMUL_MIN=80
-  SIMUL_MIN_1=0
-  LISENTRPP=false
-  LVERIFY_SCREEN=false
-
-  fi
-else
-  # PERIOD_4D=6 ; # 20040423 should stay 12 by default (for SCDA reinit), then SMS variable is set to 12, this variable is considered for reinit = false (vardata.sms)
-if [[ `echo %FAMILY:NOT_DEF% | cut -d / -f 1` = "main" ]] ; then
-  ## RD behaviour : default is constant 12,
-  ## if SMS variable is changed, task should consider it specifically
-  ## some tasks (vardata, fetcherr) may want this default and not SMS
-  ## variable for REINITIALIZE state
-  PERIOD_4D=12
-  WINDOW_LENGTH_4D=12
-  WINDOW_OFFSET_4D=3
-
-else  # SMS variable IS the environment variable for other families
-  PERIOD_4D=%PERIOD_4D:12%
-  WINDOW_LENGTH_4D=%WINDOW_LENGTH_4D:12%
-  WINDOW_OFFSET_4D=%WINDOW_OFFSET_4D:3%
-fi
-fi
-
-#=================================================
-#  Simplified Kalman filter parameters
-#=================================================
-
-TSTEP_SV=1200
-RESOLSV=42
-NLANTYPE=6
-NJDSTOP=48
-NITERL=60
-NINNER=30
-NEIGEVO=60
-HESSTYPE=3d
-SVPPFRQ=6
-
-
-################### New for 23r1 #############
-LATE4DSTART=true
-FPOSINC=false
-INICLOUDAN=true
-
-
-#=======================================================================
-#  Satellite parameters
-#=======================================================================
-
-LTOVS=.false.
-LATOVS=true
-LAIRS=true # 31r1
-LSSMI=true # 33r1
-LSCAT=.true.
-LGEOS=true
-LRAIN1D=false    # 35r2
-LSSMIRAIN=true   # 33r2
-LSSMISRAIN=true  # 35r3
-LTMIRAIN=true    # 35r3
-LAMSRERAIN=true  # 33r2
-LPRERAD1C=false
-LREO3=true
-LAEOLUS=false # 31r1
-LSSMIS=true   # 31r2
-LAMSRE=true   # 31r2
-LMERIS=true # 20080714 until which was false  # 33r2
-LTMI=true     # 31r2
-LGPSRO=true   # 31r2
-
-BIAS_PATH_AMV=none
-BIAS_PATH_REO3=none
-LREO3_BCOR=false
-
-BIASCOLD=yes
-BIASDAYS=14
-BIASMISS=7
-BIAS_ARCHIVE=1
-
-if [[ "%SUITE%" = o || "%SUITE%" = e_* ]] ; then
-  export FDB_NOF_BUFF=4
-  export FDB_BUF_SECT_SIZE=25165824
-elif [[ "%SUITE%" = bc || "%SUITE%" = ebc_* ]] ; then
-  export FDB_NOF_BUFF=3
-  export FDB_BUF_SECT_SIZE=33554432
-else
-  export FDB_NOF_BUFF=4
-  export FDB_BUF_SECT_SIZE=4194304
-fi
-
-# 23r4
-RSTBIAS=true
-
-# 24r2
-ERAFS=false
-
-#  SATMON parameters
-SMON_OPT_DIR=""
-SMON_OPT_GEOS=ops
-SMON_OPT_NOAA=ops
-SMON_OPT_DMSP=ops
-SMON_OPT_O3=ops
-SMON_OPT_O3KNMI=ops
-SMON_OPT_O3MSG=ops
-SMON_OPT_TEMP=ops
-SMON_OPT_PWC=ops
-SMON_OPT_AMV=ops
-SMON_OPT_DBAMV=ops       # 33r1
-SMON_OPT_AIRS=ops
-SMON_OPT_IASI=ops        # 32r3
-SMON_OPT_EARS=ops
-SMON_OPT_PACRARS=ops     # 33r1
-SMON_OPT_MERIS=ops       # 33r2
-SMON_OPT_SSMIS=ops       # 31r2
-SMON_OPT_AMSRE=ops       # 31r2
-SMON_OPT_TMI=ops         # 31r2
-SMON_OPT_GPSRO=ops       # 31r2
-SMON_OPT_SCATT=ops       # 35r3
-SMON_OPT_SLMOIST=ops     # 35r3
-
-
-SATROOT=/od_archive/data/satmon
-
-#==========================================================
-# Variables configuring Reanalysis
-#==========================================================
-MEANS=true
-MOMENTS=true
-INTEGRALS=true
-INCREMENTS=true
-PLOTS=true
-RSTBIAS_TS=false
-RSTBIAS_SE=true
-ERAPRODUCTS="/era/intprod/data/monitor"
-
-#=======================================================================
-#  Coupled wave model parameters
-#=======================================================================
-
-WAVE=yes
-WAM2WAY=yes
-WAMNSTPW=1
-  if [[ "%FSFAMILY%" = @(mc|refc|assim) ]] ; then
-WAMRESOL=global100
-else
-WAMRESOL=global36 # HR global50
-fi
-WAMALT=yes
-WAMSAR=yes
-WAMSARASS=true
-
-if [[ "%FSFAMILY%" = "euroshelf" || $SUITE_TYPE = "law" ]] ; then  # law suites
-  WAMNFRE=30  # 36 future 0044
-  WAMNANG=24  # 36 future 0044
-else
-  WAMNFRE=30
-  WAMNANG=24
-fi
-
-date_ers1_wave=1994010100
-
-if [[ $BASETIME -lt $date_ers1_wave || $WAMALT != yes ]] ; then
-  WAMANPARAM_DYN="215/216/220/221/222/223/224/225/226/227/228/229/230/231/232/233/234/235/236/237/238/239/244/245/249"
-else
-  WAMANPARAM_DYN="215/216/217/218/220/221/222/223/224/225/226/227/228/229/230/231/232/233/234/235/236/237/238/239/244/245/246/247/248/249/252/253/254"
-fi
-
-WAMANPARAM_STAT="219"
-WAMANPARAM=$WAMANPARAM_STAT/$WAMANPARAM_DYN
-
-WAMFCPARAM_STAT="219"
-WAMFCPARAM_DYN="215/216/217/218/220/221/222/223/224/225/226/227/228/229/230/231/232/233/234/235/236/237/238/239/244/245/249/252/253/254"
-WAMFCPARAM=$WAMFCPARAM_STAT/$WAMFCPARAM_DYN
-
-INIWAVE=yes
-WAMCOLDLENGTH=240
-WAMSTREAM=0
-# Many of these values are overridden for
-# local area model in law.h
-
-if [[ "%STREAM%" = SCDA ]] ; then
-  WAMSTREAM=1027
-elif  [[ "%STREAM%" = DCDA ]] ; then
-  WAMSTREAM=1029
-fi
-
-#=======================================================================
-#  Initial data parameters
-#=======================================================================
-
-
-INITIME=%INITIME:2001042900%
-INICLASS=%INICLASS:od%
-INISTREAM=%INISTREAM:da%
-# da : early delivery suite initialised from standard suite
-# dcda : early delivery suite initialised from another delayed cutoff suite
-INITYPE=4v
-INIEXPVER=%INIEXPVER:0001%
-INILEVELS=%INILEVELS:60%
-INISTEP=%INISTEP:0%
-# size of the 4dvar window
-
-# offset from the beginning of the 4V for FC
-INIOFFSET_4D=%INIOFFSET_4D:3%
-# 9 : early delivery suite initialised from standard suite
-# 3 : early delivery suite initialised from another ealry delivery suite
-INITILES=true
-INIRESOL=799 # was 511
-INICI=true
-FORCE_FP=no
-
-if [[ "%FAMILY1:NOT_DEF%" = sv || "%FAMILY1:NOT_DEF%" = m2_12 || "%FAMILY1:NOT_DEF%" = m2_00 || "%FAMILY1:NOT_DEF%" = m1_12 || "%FAMILY1:NOT_DEF%" = m1_00 ]] ; then
-  INITYPE=fc
-#  ------- vv
-#  INISTEP=12   # for 00,12 UTC forecasts
-#  ------- ^^
-  INISTEP=6     # for 06,18 UTC forecasts
-  INISTREAM=dcda
-  INISUFFIX="_sv"
-else
-  INISUFFIX=
-fi
-
-if [[ "$ARCH" != "linux" ]];then
-  typeset -l REINITIALIZE
-fi
-REINITIALIZE=%REINITIALIZE:false%
-REINIEXPVER=%REINIEXPVER:0001%
-REINISTREAM=%REINISTREAM:da%
-REINIPERIOD_4D=%REINIPERIOD_4D:12%
-REINIOFFSET=%REINIOFFSET:12%
-ED_CUTOFF=%ED_CUTOFF:4%
-
-#=================================================
-# PE settings
-#=================================================
-NPES_MKCMA=%MKCMANPES:1%
-NPES_AN=%ANNPES:1%
-NPES_FC=%FCNPES:1%
-NPES_SV=%FCNPES:1%
-#=================================================
-#  PREPAN parameters
-#=================================================
-
-OWNER=emos
-AMASTER=/ws/home/ma/emos/amaster/xxxx
-RUN_PARALLEL=true
-
-#=======================================================================
-#  Sami's variables + ODB
-#=======================================================================
-
-CONCAT=1
-PMETHOD=2
-FSODB=/emos_backup
-
-ODB_CTX_DEBUG=0
-ODB_MAXHANDLE=5
-ODB_STATIC_LINKING=1
-ODB_UNDEF=2146959359
-ODB_CCMA_CREATE_DIRECT=1
-ODBSAVE_ODBCMP=true     #31r2
-ODB_FROM_FB=false
-if [[ "%STREAM%" = SCDA ]] ; then
-  ODBSAVE_CCMA=false
-  ODBSAVE_ECMA=false
-else
-  ODBSAVE_CCMA=true
-  ODBSAVE_ECMA=true
-fi
-ODB_CATCH_SIGNALS=0
-ODB_CCMA_IGNORE_TSLOTS=0
-ODB_CCMA_OBS_RANDOMIZE=0
-ODB_CCMA_WTMETHOD=107
-ODB_ERRTRA=1
-ODB_FLPCHECK=0
-ODB_INTCHECK=0
-ODB_IO_METHOD=4
-ODB_IO_FILESIZE=128
-ODB_PACKING=-1
-ODB_REPRODUCIBLE_SEQNO=4
-ODB_TEST_INDEX_RANGE=0
-ODB_WRITE_EMPTY_FILES=0
-
-MANPATH=""
-#=======================================================================
-#  Coupled wave variables
-#=======================================================================
-
-WGRIBIN=yes
-
-#================================
-# New for 19r1, should be put in correct place.
-
-HESS3D=3d
-PPFRQ=12
-LINCNMI=false
-NEIGEVO=60
-#================================
-# New for 24r4
-
-LMAPSOP=false
-MPP_TYPE=1
-if [[ "%STREAM%" = SCDA ]] && [[ %MXUP_TRAJ:3% = 1 ]] ; then
-  LTRAJHR=false
-else
-  LTRAJHR=true
-fi
-
-#================================
-# New for 26r3
-
-LMODERR=false
-
-#=======================================================================
-#  Plot control
-#=======================================================================
-
-PLOT_RMS=true
-
-#=======================================================================
-#  Standard libraries
-#=======================================================================
-
-SCHOST=%SCHOST%
-SCHOST_BKUP=%SCHOST_BKUP:not_set%
-# storage host
-STHOST=%STHOST:%
-STHOST_BKUP=%STHOST_BKUP%
-WSHOST=%WSHOST%
-
-LIBRESOL=.R64.D64.I32
-ELIB=/usr/local/lib/metaps/lib/${EMOS_CYCLE}
-
-if [[ $ARCH = ibm_power* ]] ; then
-  SLIB=/usr/local/lib
-###########################################
-#temporary setting: A.Hofstadler, 200200821
-  EMOSLIB="-lemos.R64.D64.I32"
-  ECLIB="-L $SLIB "
-  FDBLIB="-L $SLIB -lfdb"
-#temporary setting:
-###########################################
-  EMOSLIB="-L $ELIB $EMOSLIB"
-  OBJECT_MODE=64
-  XLFRTEOPTS=err_recovery=no
-else
-###########################################
-#temporary setting: A.Hofstadler, 200200821
-#  EMOSLIB="-lemos.R64.D64.I32"
-  EMOSLIB="-lemos.R32.D64.I32" # or single???
-#temporary setting:
-###########################################
-  SLIB=/usr/local/lib
-  EMOSLIB="-L $ELIB $EMOSLIB"
-fi
-
-emosbin=/home/ma/emos/bin/${EMOS_CYCLE}/$ARCH
-#=======================================================================
-#  Singular vector configuration
-#  NSVHEM=1 for SVs over NH only
-#         2      "       SH only
-#         3      "       NH+SH
-#=======================================================================
-
-EPSSVPATH=
-EPSSVROTPATH=
-EPSFCRES=%EPSFCRES:399% # HR 255
-
-# VAREPS 30r2
-EPSFCRES_A=%EPSFCRES_A:399% # HR 255
-EPSFCRES_B=%EPSFCRES_B:255% # HR 255
-EPSFCRES_C=%EPSFCRES_C:255% # HR 255
-
-EPSFCLENGTH_A=%EPSFCLENGTH_A:240%
-EPSFCLENGTH_B=%EPSFCLENGTH_B:144%
-EPSFCLENGTH_C=%EPSFCLENGTH_C:408%
-
-EPSINISTEP_B=%EPSINISTEP_B:216%
-EPSINISTEP_C=%EPSINISTEP_C:360%
-
-EPSFCGTYPE=%EPSFCGTYPE:l_2%
-EPSFCGTYPE_A=%EPSFCGTYPE_A:l_2%
-EPSFCGTYPE_B=%EPSFCGTYPE_B:l_2%
-EPSFCGTYPE_C=%EPSFCGTYPE_C:l_2%
-
-EPSVARHDIF=false
-EPSVARHDIFT=24
-
-EPS_USE_ICP=0
-# /VAREPS
-
-EPSFCLEV=%EPSFCLEV:62%  # HR 40
-EPSSVRES=%EPSSVRES:42%
-EPSSVGTYPE=_full
-EPSSVLEV=%EPSSVLEV:62%  # HR 40
-EPSMEMBERS=`echo "%ENSEMBLES:50% + 1" | bc`
-EPSNENS=%ENSEMBLES:50%
-EPSEVO=1
-EPSHEM=%EPSHEM:3%
-EPSEVOTIME=48
-
-EPSWAMRESOL=%EPSWAMRESOL:global100%
-EPSWAMNSTPW=%EPSWAMSTPW:1%
-EPSTSTEP=%TSTEP:1800% # HR 2700
-EPSSVTSTEP=%EPSSVTSTEP:900%
-
-if [[ %STREAM% = MAED ]] ; then
-  INIMODISALB=false
-TSTEP=$EPSTSTEP
-fi
-
-EPSTSTEP_SV=900 # HR 1200
-EPSWAMALT=no
-EPSTYPE=%EPSTYPE%
-EPSMEMBER=%MEMBER%
-FCTOTAL=$EPSMEMBERS
-NTOTAL=$EPSNENS
-EPSSVDIAB=%EPSSVDIAB:false%
-EPSSVNUM=%EPSSVNUM:0%
-
-# 28r3
-DELTAHH_TC_TRACKS=12 # 12h lag from previous TC used in targets task
-EPSSV_TOPT=48        # optimization time for the tropical singular vectors
-                     # targets
-
-TC_TRACKS_EXPVER=%VERSION:0001%    # ???TDB
-
-if [[ %VERSION:0001% = 0020 ]] ; then
-  TC_TRACKS_EXPVER=0001
-fi
-
-OD_PROJ=%OD_PROJ:od%
-
-if [[ "%SUITE%" = emc* ]] && [[ %IS_REAL_TIME:false% = false ]] ; then
-  TC_TRACKS_PATH=/emos/tc/0001
-elif [[ $REINITIALIZE = true ]] ; then
-  TC_TRACKS_PATH=/emos/tc/$REINIEXPVER
-elif [[ %FIRST_DAY% = 1 ]] ; then
-  TC_TRACKS_PATH=/emos/tc/$INIEXPVER
-  TC_TRACKS_EXPVER=0001
-elif [[ ! "$OD_PROJ" = "od" ]] ; then
-# || [[ %IS_REAL_TIME:false% = false ]] ; then
-  ## MC_NO and other MS suites
-  ## and catchup mode running 12 cycle only
-  TC_TRACKS_PATH=/emos/tc/0001
-else
-  TC_TRACKS_PATH=/emos/tc/%VERSION%
-fi
-
-TC_TRACKS_FROM_MARS=true
-TC_TRACKS_CLASS=od
-
-EPSSVTCSUB=%EPSSVTCSUB:0%
-EPSTCBB=%EPSTCBB:1%       # use TC tracks to define optimization regions
-EPSSVOP=%EPSSVOP:0%       # not required to set sms variable in OD
-EPSSVTC_ORTHONORM=1       # ortho-normalize tropical SVs
-
-RUNHINDCAST=%RUNHINDCAST:0% # 1 for back loop and 0 for realtime
-
-#=======================================================================
-# EFI PATHS:
-#=======================================================================
-EFI_WS_CACHE=/efi_clim/data/cache
-EFI_WS_SCRATCH=/efi_clim/data/scratch
-EFI_ECFS_PATH=ec:/emos/efi_clim
-EFI_HPCF_PATH=/home/ma/emos/data/efi_clim
-#=======================================================================
-#  Ocean model configuration
-#=======================================================================
-
-OCVER=h2e2
-ASVER=cy2r3
-
-#=======================================================================
-#  Configuration for sensitivity suite
-#=======================================================================
-
-SENSFCRES=255
-SENSFCLEV=60
-SENSADJRES=63
-SENSADJLEV=60
-SENSADJGTYPE=_2
-SENSFCGTYPE=l_2
-SENSADJSTEP=48
-SENSADJTSTEP=600.0
-SENSRUNFC=yes
-INISPQ=no
-
-#new for 25r1
-SENSADJADVEC=euler
-SENSFORCE=false
-SENSDIAB=true
-SENSITER=6
-
-#=======================================================================
-#  The disk configuration
-#  Look at e-suite configuration below also
-#=======================================================================
-
-if [[ $ARCH = ibm_power* ]] ; then
-  if [[ "%SUITE%" = mc_no ]] ; then
-    TROOT=$STHOST/ms_crit/teps
-    WROOT=$STHOST/ms_crit/teps
-    OROOT=$STHOST/emos_data
-    FDB_ROOT=$STHOST/ms_crit/fdb
-    FDB_IROOT=$STHOST/ms_crit/fdb
-    WAVEEPS_ROOT=$FDB_ROOT
-    WAVEEPS_IROOT=$FDB_IROOT
-  elif [[ "%SUITE%" = e*35r3* || "%SUITE%" = "e_sync" || "%SUITE%" = "emc_no*" ]] ; then
-    TROOT=$STHOST/emos_esuite/emos_data
-    WROOT=$STHOST/emos_esuite/emos_data
-    OROOT=$STHOST/emos_data
-    WBASE=/
-    FDB_ROOT=$STHOST/emos_esuite/ma_fdb
-    FDB_ROOT_BKUP=$STHOST_BKUP/emos_esuite/ma_fdb
-    FDB_IROOT=$STHOST/emos_esuite/ma_fdb
-    WAVEEPS_ROOT=$FDB_ROOT
-    WAVEEPS_IROOT=$FDB_IROOT
-  else
-    TROOT=$STHOST/emos_data
-    WROOT=$STHOST/emos_data
-    OROOT=$STHOST/emos_data
-    FDB_ROOT=$STHOST/ma_fdb
-    FDB_ROOT_BKUP=$STHOST_BKUP/ma_fdb
-    FDB_IROOT=$STHOST/ma_fdb
-    WAVEEPS_ROOT=$STHOST$FDB_ROOT
-    WAVEEPS_IROOT=$STHOST$FDB_IROOT
-  fi
-  if [[ "%FSFAMILY%" = mars  ]] ; then
-    WROOT=/od_archive/data
-  fi
-elif [[ $ARCH = linux ]] ; then
-  TROOT=/var/tmp/tmpdir/emos
-  WROOT=/var/tmp/tmpdir/emos
-  OROOT=/var/tmp/tmpdir/emos
-  FDB_ROOT=""
-  FDB_IROOT=""
-else
-  TROOT=/var/tmp/emos
-  WROOT=/var/tmp/emos
-  OROOT=/var/tmp/emos
-  FDB_ROOT=""
-  FDB_IROOT=""
-fi
-
-WBASE=${WROOT}/${EXPVER}
-
-XROOT=/home/ma/emos
-XLIB=$XROOT/lib/${IFS_CYCLE}
-XDATA=$XROOT/data
-XBINS=$XROOT/bin
-XMOD=/cc/rd/module/frt
-XSRC=$XROOT/src
-ODATA=/home/ma/emos/data
-SCRATCH=/ws/scratch/ma/emos
-
-FSROOT=/$USER
-FSOROOT=/emos
-FSFAMILY=""
-FSXDATA=/emos/data
-FSXBINS=/emos/$ARCH/bin
-
-#=======================================================================
-#
-#  The following is the configuration filled in by the SMS
-#
-#=======================================================================
-
-#EXPVER=%VERSION% # done further up...
-
-if [[ "%USE_YMD:false%" = true ]] ; then
-  BASETIME=%YMD%%EMOS_BASE%
-else
-  BASETIME=%YYYY%%MM%%DD%%EMOS_BASE%
-fi
-
-FSFAMILY=%FSFAMILY%
-
-ECF_PASS=%ECF_PASS%
-ECF_HOST=%ECF_HOST%
-ECF_NAME=%ECF_NAME%
-ECF_TRYNO=%ECF_TRYNO%
-
-ECF_HOSTFILE=$HOME/.smshostfile
-ECF_PORT=%ECF_PORT%
-ECF_JOBOUT=%ECF_JOBOUT%
-
-
-SUITE=%SUITE%
-FAMILY=%FAMILY:NOT_DEF%
-TASK=%TASK%
-
-DEBUG=0
-DISPLAY=0
-
-# INFORM_EMOS_AUTORESOL=1
-
-#
-#  For e-suites only
-#
-if [[ $EXPVER -eq 2 ]] ; then
-  BASEVER=0002
-fi
-
-#Multianalysis
-INIMA="%INIMA:ecmwf%"
-INIMACONS=%INIMACONS:0%
-INIORIG=mars
-MANNCEP=0
-MANMFR=0
-MANDWD=0
-MANUKM=0
-
-INIORIGIN=OFF
-MAORIGINS="CONS"
-MAMISSING="%MAMISSING:%"
-
-if [[ %STREAM% = "MAED" || %STREAM% = MAWV ]] ; then
-  WAMRESOL=global100
-  WAMNFRE=30
-  WAMNANG=24
-  INIOZONE=false
-  LOZONE=false
-  LOZONECH=false
-  RESOL=399
-  LEVELS=62
-
-  for xxx in $INIMA ; do
-  if [[ "$xxx" = ncep ]] ; then
-    MANNCEP=1
-    MAORIGINS="$MAORIGINS KWBC"
-  elif [[ "$xxx" = mfr ]] ; then
-    MANMFR=1
-    MAORIGINS="$MAORIGINS LFPW"
-  elif [[ "$xxx" = ukm ]] ; then
-    MANUKM=1
-    MAORIGINS="$MAORIGINS EGRR"
-  elif [[ "$xxx" = dwd ]] ; then
-    MANDWD=1
-    MAORIGINS="$MAORIGINS EDZW"
-  fi
-  done
-
-
-  # Find WMO centre number. Do this more cleverly
-  if [[ $INIMACONS -eq 1 ]] ; then
-    INIORIGIN=CONS
-  elif [[ $INIMA = mfr ]] ; then
-   INIORIGIN=LFPW
-  elif [[ $INIMA = ncep ]] ; then
-   INIORIGIN=KWBC
-  elif [[ $INIMA = ukm ]] ; then
-   INIORIGIN=EGRR
-  elif [[ $INIMA = dwd ]] ; then
-   INIORIGIN=EDZW
-  fi
-
-fi
-
-#=================================================
-# For mars compute. This will use model number found.
-# If not set, model number will be 255.
-export MARS_COMPUTE_FLAG=0
-
-# User for e-suite plots
-EPLOT_USER=mos
-
-set +a
-
-if [[ %DELTA_DAY% -ne 0 ]] ; then
-  delta=`expr %DELTA_DAY% \* 24`
-  BASETIME=`newdate $BASETIME $delta`
-fi
-
-if [[ $FSFAMILY = "refc" ]] ; then
-  HC_REFDATE=`echo $BASETIME | cut -c 1-8`
-  EPSTYPE=fc
-
-  export HC_REFDATE EPSTYPE
-
-  if [[ %YEAR:0% -ne 0 ]] ; then
-    YEAR=%YEAR:0%
-    YYYY=`echo $BASETIME | cut -c 1-4`
-    MM=`echo $BASETIME | cut -c 5-6`
-    DDHH=`echo $BASETIME | cut -c 7-10`
-    if [[ $MM$DDHH = 0229* ]] ; then
-      BASETIME=`newdate $(( $YEAR$MM$DDHH - 100 )) 24 `
-    else
-      BASETIME=$YEAR$MM$DDHH
-    fi
-  fi
-fi
-
-DELTA_YEAR=%DELTA_YEAR:0%
-YYYY=`echo $BASETIME | cut -c 1-4`
-YYYY=$(( $DELTA_YEAR + $YYYY ))
-if [[ $DELTA_YEAR -ne 0 ]] ; then
-  YYYY=`echo $BASETIME | cut -c 1-4`
-  DELTA_YEAR=%DELTA_YEAR:0%
-  MMDDHH=`echo $BASETIME | cut -c 5-10`
-  YYYY=$(( $DELTA_YEAR + $YYYY ))
-  BASETIME=$YYYY$MMDDHH
-  YMD=$(substring $BASETIME 1 8)
-fi
-
-DELTA_HOUR=%DELTA_HOUR:0%
-if [[ $DELTA_HOUR -ne 0 ]] ; then
-  BASETIME=`newdate $BASETIME $DELTA_HOUR`
-fi
-
-# remove when hpcf gone
-if [[ $HOST = hpc* ]] ; then
-  EMOSLIB="-qextname $EMOSLIB"
-fi
-
-if [[ $ARCH = linux ]] ; then
-  export LINK_C="pgf90 -tp k8-32 -g"
-  export LINK_F="pgf90 -tp k8-32 -g"
-fi
-
-if [[ "%OD_PROJ:od%" = no ]] ; then
-  ### TEPS project
-  EPSHEM=1
-  EPSGAMMA=0.016
-  EPSBASIS=10
-  EPSMEMBERS=21
-  EPSNENS=20
-  GRIBCLASS=113 # from http://www.ecmwf.int/publications/manuals/libraries/gribex/gribClass.html
-fi
-
-#=====================================================================
-# ocean model configuration
-#======================================================================
-export RUNVARFC=%RUNVARFC:0%
-export EPSLEG=%EPSLEG:1%
-if [[ $RUNHINDCAST = 1 ]] ; then
-  # export HC_REFDATE=%YMD%
-  export HC_REFDATE=$((YYYY -(DELTA_YEAR)))`echo $BASETIME | cut -c 5-8`
-
-INIMODISALB=false # if intial data was run with 32r1 or later
-
-#==========================================================
-# Variables configuring inidata
-#==========================================================
-INIPATH="/net/fujitsu/ifs/initial/t95r/ic_19r1_%YMD%"
-INISTREAM=DA
-INITYPE=an
-INISTEP=0
-INISPQ=no
-LFG=.true.
-INIOFFSET=0
-INISCHEME=lslag
-SAVINI=""
-SVRF=no
-IFRF=no
-FORCE_FP=no
-
-INICLASS=`oper_model -b $BASETIME -c`
-INIRESOL=`oper_model -b $BASETIME -r`
-INILEVELS=`oper_model -b $BASETIME -l`
-INIGTYPE=`oper_model -b $BASETIME -t`
-INIEXPVER=`oper_model -b $BASETIME -e`
-INITILES=`oper_model -b $BASETIME -T`
-INICLOUDAN=`oper_model -b $BASETIME -C`
-
-if [[ %RUNHINDCAST:0% = 0 ]] ; then
-  INILEVELS=91
-  INIRESOL=799
-
-if [[ $BASETIME -le %ERA40END:2002073100% ]] ; then
-  INICLASS=e4
-  INILEVELS=60
-  INIEXPVER=0001
-  INITILES=true
-  INICLOUDAN=true
-  INIMODISALB=false
-  EPSGAMMA=0.018
-fi
-
-else # HINDCAST mode
-  INICLASS=ei
-  INILEVELS=60
-
-  if [[ $BASETIME -lt 2008010100 ]] ; then
-    INIEXPVER=0001
-  else
-    INIEXPVER=1112 # temporary while Manuel is changing 1112 to 0001
-  fi
-  EPSGAMMA=0.016 # to be updated according to Martin Leutbecher
-  INIRESOL=255
-  INIMODISALB=true
-  INIHTESSEL=false
-  INITILES=true
-fi
-
-fi
-
-export MARS_CMD='mars'
-
-if [[ %RUNHINDCAST:0% = 1 ]] ; then
-  INIHTESSEL=`oper_model -b $BASETIME -I ${CLASSORIG:="er_ops"} -H`
-fi
-
-### check if MOFC-VarEps is to run
-  sim=`newdate -d -D $BASETIME`
-  real=`date +'%%Y%%m%%d'`
-  real=`newdate -d -D $real`
-  dow=`date +'%%u'`
-  res=$((($sim - $real + $dow) %% 7))
-
-  if [[ $((res)) -lt 0 ]] ; then res=$((res+7)); fi
-
-  RUN_VAREPS=0
-  if [[ $res = 4 ]] ; then # Thursday MOFC
-    RUN_VAREPS=1
-  fi
-  export EPSNLEGS=$((2+$RUN_VAREPS)) # do not refer to sms variables while this changes
-  # 35r2
-  export EPSCOUPL_A=no                    # 35r2
-  export EPSCOUPLE_A=0                    # 35r2
-  CC=`substring $BASETIME 9 10`           # later EMOS_BASE
-  export EPSCOUPLE_B=$((CC == 00))        # 35r2
-  export EPSCOUPLE_C=$RUN_VAREPS          # 35r2
-
-
-export RUN_VAREPS
-###########
-export OCNINDAT=$(substring $BASETIME 1 8) # 19900101
-
-if [[ $EPSLEG != 1 ]] || [[ $RUNVARFC = 1 ]] ; then
-set -a
-
-
-ENAMELIST=general
-FULL_POS=yes
-LPPL=1
-LPSU=1
-LPPV=0
-LPTH=0
-LPGZ=0
-PPSTEPS="0"
-ERF=408
-FRQRF=-1
-DATE_BRANCH=2005112409
-USEDATE_BRANCH=no
-VIEW=""
-VIEW_HOPE="hope_h2e20"
-OCEPS=no
-OCUSESV=no
-EPSLROT=no
-OCPATM=yes
-OCFCRESOL=255
-OCFCLEVELS=62
-OCFCGTYPE=l_2
-OCFCTSTEP=%TSTEP:1800%.0
-FCCHUNKTOT=1
-NEWSTREAMLIB=none
-SAVLIB=false
-OCEAN_BRANCH="neh_h2e20_enfo"
-OCEAN_CYCLE="h2e20"
-OCIAUFR=2
-if [[ $RUNHINDCAST = 1 ]] ; then
-
-GRIB_API_VERSION=1.7.0
-GRIB_API_INCLUDE="-I/usr/local/lib/metaps/lib/grib_api/jasper/include -I/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/include"
-GRIB_API_LIB="-L/usr/local/lib/metaps/lib/grib_api/jasper/lib -ljasper -L/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/lib -lgrib_api_f90 -lgrib_api"
-export GRIB_API=/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/bin   # change to fixed version
-export PATH=$GRIB_API:$PATH
-
-  if [[ $HC_REFDATE -lt 20080605 ]] ; then
-    OCINI="seas_0001_01_NN_${OCNINDAT}_od_02"
-  else
-    OCINI="ocea_0001_01_NN_$(substring $BASETIME 1 8)_od_03"
-  fi
-else
-  OCINI="ocea_0001_01_NN_$(substring $BASETIME 1 8)_od_03"
-fi
-OCNEWREST=false
-OCNMINI="00"
-CLASSORIG=e4_ops
-
-OCRUNCTRLAN=no
-OCRUNCTRLAC=no
-OCRUNCTRLFC=no
-OCRUNASSIMAN=no
-OCRUNASSIMAC=yes
-OCRUNASSIMFC=yes
-MEMBERSTATE=no
-%include <config.oc.h>
-
- OCINPUT=mars
- OCSUITE=vareps
- if [[ -n $OCINI ]] ;then
-    OCINPUT=$(substring $OCINI 1 4)
- fi
-
- if [[ $OCINPUT != 'ecfs' ]] ; then
-   OCSTREAM_INI=$OCINPUT
-    if [[ $OCINPUT = 'mars' ]];then
-      OCSTREAM_INI='ocea' # 'seas'
-    fi
-    if [[ $OCINPUT = 'seas' ]];then
-      OCINPUT='mars'
-    fi
-    if [[ $OCINPUT = 'mofc' ]];then
-     OCINPUT='mars'
-    fi
-   OCEXPVER_INI=0001 # $(substring $OCINI 6 9 )
-   OCMETHOD_INI=$(substring $OCINI 11 12 )
-   OCNUMBER_INI=$(substring $OCINI 14 15 )
-   OCDATE_INI=$(substring $OCINI 17 24 )
-   OCCLASS_INI=$(substring $OCINI 26 27 )
-   OCSYST_INI=$(substring $OCINI 29 30 )
- fi
-
-# For EPS runs only. Change of EPSNORM
-#
-   LASTERA40=%ERA40END:2000070100%
-
-  if [[ $OCEPS = "yes" ]] ; then
-     if [[ $BASETIME  -le 2001031400 ]] || [[ $BASETIME  -le $LASTERA40 ]] ;
-     then
-        EPSNORM=2.0
-        EPSNORMT=2.0
-     fi
-     EPSTROP=%EPSTROP:$EPSTROP%
-     EPSSVDIAB=%EPSSVDIAB:$EPSSVDIAB%
-     EPSSVNUM=%EPSSVNUM:$EPSSVNUM%
-  fi
-
-#=======================================================================
-#  special mofc variables
-#=======================================================================
-
-# pop/web/mofc
-
-MOFC_PROCESS=$WROOT/data/%SUITE%_process
-MOFC_PROCESS=`echo $MOFC_PROCESS | sed -e 's/var\/tmp\/tmpdir\/emos\/data/emos_data/'`
-Y=`echo $BASETIME | cut -c 1-4`
-STREAM=EF
-CLIMYEAR1=$((Y + - %NH_YEARS:18%))
-CLIMYEAR2=$((Y - 1))
-OCUTILS=$XBINS/$STREAM/$EXPVER
-
-export NH_ENSEMBLES=%NH_ENSEMBLES:4%
-export MOFC_PROCESS
-
-if [[ %RUNHINDCAST:0% = 1 ]] ; then
-  MOFCCLIM_VERIF=$WROOT/data/%SUITE%_clim
-  [[ -d $MOFCCLIM_VERIF ]] || mkdir -p $MOFCCLIM_VERIF
-  MOFC_VERIFY=/gpfs1/emos_verify/data/%SUITE%_verify
-  export PATH=$PATH:$HOME/bin/EF/verify
-  [[ -d $MOFC_VERIFY ]] || mkdir -p $MOFC_VERIFY
-
-  INIHTESSEL=`oper_model -b $BASETIME -I ${CLASSORIG:="er_ops"} -H`
-fi
-
-fi
-
-set -a
-
-if [[ %EPSTYPE:cf% = sv ]] ; then
-   INIMODISALB=false
-fi
-
-if [[ "%STREAM%" = EF ]] ; then
-  INIPERIOD_4D=%INIPERIOD_4D:12%
-else
-  INIPERIOD_4D=12
-fi
-
-if [[ "%FSFAMILY:0%" != refc ]] && [[ %RUNHINDCAST:0% != 1 ]] ; then
-  LVARBC=true
-else
-  LVARBC=false
-  INIMODISALB=false # if intial data was run with 32r1 or later
-
-  date4v12h=2000091200
-  # CHANGE date_dcda=2004062900
-  date_dcda=2004062912
-  if [ $BASETIME -ge $date4v12h ] ; then
-     INIPERIOD_4D=12
-  fi
-  if [ $BASETIME -ge $date_dcda ] ; then
-    INIPERIOD_4D=6
-  fi
-fi
-
-inidate=`echo $BASETIME | cut -c 1-8`
-if [ ${inidate} -ge 19971125 ] && [ $INICLASS = od ] && [ $INIPERIOD_4D = 6 ] ; then
-    INIOFFSET_4D=3
-elif [ $INICLASS = ei ] ; then
-    INIOFFSET_4D=9
-elif [ $INICLASS = e4 ] ; then
-    INIOFFSET_4D=3
-elif [ $INIPERIOD_4D = 12 ] ; then
-  if [[ %RUNHINDCAST:0% = 1 ]] || [[ %STREAM:UNDEF% = EF ]] ; then
-    INIOFFSET_4D=9
-  else
-    INIOFFSET_4D=3
-  fi
-elif [ $INIPERIOD_4D = 6 ] ; then
-    INIOFFSET_4D=3
-else
-    INIOFFSET_4D=0
-fi
-
-### SST ###
-CLMSST=no
-PERSST=%PERSST:false%
-FORCE_SST=no
-SSTLEN=%SSTLEN:240%
-SSTINT=%SSTINT:1%
-LOSTIA=%LOSTIA:true%              # 33r2
-
-NUMBER=%FCTOTAL:NOT_SET%
-VAR=%VAR:NOT_SET%
-CNUMBER=5
-
-if [[ "%SUITE%" = @(mc*|emc*|mofc*|emofc*|ma|tparc*|dts*) || $SUITE_TYPE = "eps" ]] ; then
-  LWEAK4DVAR=false
-  LEMISKF=false
-  LOZONE=false
-  INIOZONE=false
-  LOZONECH=false
-  LVARBC=false
-else
-  LWEAK4DVAR=true
-  LEMISKF=true
-fi
-
-
-set +a
-
-
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/config.oc.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/config.oc.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/config.oc.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/config.oc.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,197 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-# EXPVER=et34
-#==========================================================
-# Variables configuring emptyNamelist
-#==========================================================
-ENAMELIST=general
-#
-#==========================================================
-# Variables configuring wsconfig
-#==========================================================
-
-# WSHOST=metis
-# SCRATCH="/scratch/rd/rdx"
-#
-#==========================================================
-# Variables configuring ppgeneral
-#==========================================================
-
-IFSMODE=fc
-#PERIOD=6
-#PERIOD_4D=12
-
-FULL_POS=yes
-LPPL=1
-LPSU=1
-LPML=0
-LPPV=0
-LPTH=0
-LPGZ=0
-#PPFRQ=24
-PPSTEPS="0"
-#BRF=0
-ERF=408
-FRQRF=-1
-#
-#==========================================================
-# Variables configuring Ozone
-#==========================================================
-LOZONE=false
-LOZONECH=false
-#
-#==========================================================
-# Variables configuring clearcase
-#==========================================================
-#PROJECTS="none"
-DATE_BRANCH=2005112409
-USEDATE_BRANCH=no
-VIEW=""
-VIEW_HOPE="hope_h2e20"
-#
-#==========================================================
-# Variables configuring eps_svect
-#==========================================================
-OCEPS=no
-OCUSESV=no
-EPSLROT=no
-EPSNLEGS=%EPSNLEGS:3%
-EPSFCLEV_A=40
-EPSTSTEP_A=1800
-EPSFCLEV_B=40
-EPSTSTEP_B=%TSTEP:2700% # 2700
-EPSFCLEV_C=40
-EPSTSTEP_C=%TSTEP:2700% # 2700
-
-#
-#==========================================================
-# Variables configuring Dr_Hook
-#==========================================================
-#DR_HOOK=true
-#DR_HOOK_OPT="none"
-#DR_HOOK_PROFILE_LIMIT=-10
-#DR_HOOK_HASHBITS=15
-#DR_HOOK_CATCH_SIGNALS=0
-#DR_HOOK_IGNORE_SIGNALS=0
-#
-#==========================================================
-# Variables configuring wavgeneral
-#==========================================================
-#WAVE=yes
-#INIWAVE=yes
-#WAM2WAY=yes
-#WAMALT=no
-#WAMSAR=no
-#WAMSARASS=false
-#WGRIBIN=yes
-#WAMNSTPW=1
-#WAMRESOL=global100
-#WAMCOLDLENGTH=240
-WAMNFRE=%EPSWAMNFRE:25%
-WAMNANG=%EPSWAMNANG:12%
-#WAMFCPARAM="229/230/231/232/220/221/244/233/245"
-#
-#==========================================================
-# Variables configuring compile
-#==========================================================
-OCPATM=yes
-#LD="mpxlf90_r"
-#LDCC="xlc_r"
-#USE=standard
-#USECC=vac_6000
-#PARALLEL=4
-#NATIVE=true
-#F90_DEBUG=0
-#RUN_PARALLEL=true
-#EC_FILL_NANS=false
-#
-#==========================================================
-# Variables configuring system
-#==========================================================
-# ABO all comments
-#FSROOT="/RDX/prepIFS"
-#FSOROOT="/emos"
-#ABO FSXDATA="/ocx/data"
-#ABO FSXBINS="/ocx/$ARCH/bin"
-#ACCOUNT=ecrmoc
-#USER=ocx
-#GROUP=rd
-#FDB_GROUP=ecmwf
-#BASEVER=0001
-#CLASS=rd
-#GRIBCLASS=2
-#NOW=2005112409
-#MEMBERSTATE=no
-#
-#==========================================================
-# Variables configuring submit
-#==========================================================
-#SMS_NAME=ocx-prod
-#
-#==========================================================
-# Variables configuring general
-#==========================================================
-OCFCRESOL=255
-OCFCLEVELS=62
-OCFCGTYPE=l_2
-OCFCTSTEP=%TSTEP:1800%.0
-FCCHUNKTOT=1
-VERSION="fc"
-LESUITE=false
-#
-#==========================================================
-# Variables configuring libraries
-#==========================================================
-# IFS_CYCLE="31r1"
-# Q2USE=true
-# EMOS_CYCLE="000281"
-# Q2CREATE_NEWSTREAM=false
-# NEWSTREAM=none
-NEWSTREAMLIB=none
-# LIBRESOL=".R64.D64.I32"
-SAVLIB=false
-#GETLIB=false
-# MAKE_LIBS=yes
-# Q2CHANGELIST=0
-OCEAN_BRANCH="neh_h2e20_enfo"
-OCEAN_CYCLE="h2e20"
-#
-#==========================================================
-# Variables configuring inidata
-#==========================================================
-#OCNINDAT=$(substring $BASETIME 1 8) # 19900101
-#OCIAUFR=2
-#if [[ $RUNHINDCAST = 1 ]] ; then
-#OCINI="seas_0001_01_NN_${OCNINDAT}_od_02"
-#else
-#OCINI="ocea_0001_01_NN_$(substring $BASETIME 1 8)_od_03"
-## "seas_0001_01_NN_${OCNINDAT}_od_02"
-#fi
-#OCNEWREST=false
-#OCNMINI="00"
-#INIORIG=mars
-#CLASSORIG=e4_ops
-#INISCHEME=lslag
-SVRF=no
-IFRF=no
-#
-#==========================================================
-# Variables configuring ocgeneral
-#==========================================================
-OCRUNCTRLAN=no
-OCRUNCTRLAC=no
-OCRUNCTRLFC=no
-OCRUNASSIMAN=no
-OCRUNASSIMAC=yes
-OCRUNASSIMFC=yes
-#
-MEMBERSTATE=no
-#if [ $RUNVARFC -eq 1 ] ; then
-#  OCSUITE=vareps
-#fi
-
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/endt.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/endt.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/endt.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/endt.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-#==========================================================================
-#  End task (complete -> SMS)
-#  Clean up and exit
-#==========================================================================
-
-smscomplete ; trap 0 ; exit
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/head.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/head.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-#!/bin/ksh
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-set -e # stop the shell on first error
-set -u # fail when using an undefined variable
-set -x # echo script lines as they are executed
-
-# Defines the three variables that are needed for any
-# communication with ECF_
-
-export ECF_PORT=%ECF_PORT%    # The port on the ecflow server
-export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%
-fi
-
-# Tell ECF_ we have stated
-# The ECF_ variable ECF_RID will be set to parameter of smsinit
-# Here we give the current PID.
-
-#smsinit $$
-
-# Defined a error hanlder
-
-ERROR() {
-	set +e        # Clear -e flag, so we don't fail
-	#smsabort      # Notify ECF_ that something went wrong
-	trap 0        # Remove the trap
-	exit 0        # End the script
-}
-
-# Trap any calls to exit and errors caught by the -e flag
-
-trap ERROR 0
-
-# Trap any signal that may cause the script to fail
-
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/law.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/law.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/law.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/law.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,43 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-### start of law.h, normally included from config.h ####################
-
-# Override for local area wave model
-if [[ "%FSFAMILY%" = "euroshelf" ]] ; then
-  set -a
-  PPFRQ=6
-  WAMRESOL=medite10
-  WAMANLEN=12
-  WAMFCLEN=120
-  WAMSAR=yes
-  WAMIDELRES=6
-  INIWDEXPVER=%INIWDEXPVER:0001%     # expver for wind forcing
-  INIWDCLASS=%INIWDCLASS:od%
-  INIWDSTREAM=DA
-  WGRIBIN=yes
-  gflag=T
-  nsysnb=-1
-  nmetnb=-1
-
-  ALTIMETER=ers2
-  SAR=ers2
-  ERS=`echo $SAR | cut -c4`
-
-  model=medite
-  FSALT=$FSBASE/${ALTIMETER}/alt/$model
-  FSALT_B=$FSBASE/${ALTIMETER}_b/alt/$model
-  FSALT_S=$FSBASE/${ALTIMETER}_s/alt/$model
-  FSSAR=$FSBASE/${SAR}/sar/$model
-  FSSAR_B=$FSBASE/${SAR}_b/sar/$model
-  FSSAR_S=$FSBASE/${SAR}_s/sar/$model
-
-  WAVE_ROOT=$FDB_ROOT
-  WAVE_IROOT=$FDB_IROOT
-
-fi
-# end of law.h #################################
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/qsub.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/qsub.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/qsub.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/qsub.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-:
-# QSUB -q %QUEUE%
-# QSUB -u %USER%
-# QSUB -eo
-# QSUB -ro
-# QSUB -ko
-# QSUB -nr
-# QSUB -A %ACCOUNT%
-# QSUB -s /bin/ksh
-# QSUB -r %TASK%-%FAMILY1%
-# QSUB -o %LOGDIR%%SMSNAME%.%SMSTRYNO%
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/rcp.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/rcp.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/rcp.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/rcp.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-#  rcp.h
-
-SMSRCP() {
-  set -x
-  set +e
-  if [[ "${ARCH:=UNDEF}" = hppa || "${ARCH:=UNDEF}" = hpia64 ]] ; then
-    if [[ $PBS_JOBID = NOT_SET ]] ; then
-      rcp %LOGDIR%%SMSNAME%.%SMSTRYNO% \
-          emos@%SMSNODE%:%SMSOUT%%SMSNAME%.%SMSTRYNO%
-    else
-      rm -f %SMSJOBOUT% || : # remove link
-
-      # hardcoded to hanfs2 then mordred to release load on ablamor
-      rcp /var/spool/PBS/spool/${PBS_JOBID}.OU \
-        emos@hanfs2:/hanfs%SMSHOME%%SMSNAME%.%SMSTRYNO% || \
-      rcp /var/spool/PBS/spool/${PBS_JOBID}.OU \
-        emos@mordred:%SMSHOME%%SMSNAME%.%SMSTRYNO% || \
-      rcp /var/spool/PBS/spool/${PBS_JOBID}.OU \
-        emos@%SMSNODE%:%SMSHOME%%SMSNAME%.%SMSTRYNO%
-
-      link_name=`~emos/bin/subs_path.pl -f %SMSOUT% -t $TOPATH -n %SMSJOBOUT%`
-      rm -f $link_name || :
-
-    fi
-  fi
-
-  if [[ ${ARCH:=UNDEF} = ibm_power* ]] ; then
-    rcp %LOGDIR%%SMSNAME%.%SMSTRYNO% %SMSNODE%:%SMSHOME%%SMSNAME%.%SMSTRYNO%
-  fi
-
-}
-typeset -fx SMSRCP
-
-#  end of rcp.h
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/recursive_include.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/recursive_include.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/recursive_include.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/recursive_include.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-# test includeonce with a recursive include
-%includeonce <recursive_include.h>
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/set_traps.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/set_traps.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/set_traps.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/set_traps.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/setup.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/setup.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/setup.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/setup.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,535 +0,0 @@
-banner setup.h
-#=======================================================================
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-USER=${USER:=$LOGNAME}
-
-set -a
-
-#=======================================================================
-#  Get the prompt PS4 to be ok with -u option
-#=======================================================================
-
-typeset -Z2 _h _m _s
-if [[ $ARCH != linux ]] ; then
-SECONDS="$(date '+3600*%%H+60*%%M+%%S')"
-_x=""
-_time='${_x[(_h=(SECONDS/3600)%%24)==(_m=SECONDS/60%%60)==(_s=SECONDS%%60)]}$_h:$_m:$_s'
-PS4="$_time + "
-elif [[ $ARCH = linux ]] ; then
-  set +e
-  LKSH93=`isksh93 && echo "true" || echo "false"`
-  set -e
-  if [[ $ARCH = linux ]] && [[ "$LKSH93" = "true" ]] ; then
-# ksh93 syntax
-    _time='$((_h=(SECONDS/3600)%%24)):$((_m=(SECONDS/60)%%60)):$((_s=SECONDS%%60))'
-    PS4="$_time + "
-  fi
-fi
-
-unset _hh _mm || true
-#=======================================================================
-#
-#  Distinguish between OD and RD
-#
-#=======================================================================
-
-STREAM=%STREAM:DA%
-if [[ $STREAM = DA ]] ; then
-  stream=""
-else
-  stream="/${STREAM}"
-fi
-
-  # OD_MODE is set to false (default) for rd, e4 projects
-  #                   true for od and all od projects
-  OD_MODE=true
-  CLASS=%OD_PROJ:od%
-  OD_PROJ=%OD_PROJ:od%
-
-  #---------------------------------------------------------------------
-  #  EMOS specific setup
-  #---------------------------------------------------------------------
-
-  EMOS_YEAR=`substring $BASETIME 1 4`
-  EMOS_MONTH=`substring $BASETIME 5 6`
-  EMOS_DAY=`substring $BASETIME 7 8`
-  EMOS_BASE=`substring $BASETIME 9 10`
-  EMOS_VERSION=$EXPVER
-  EMOS_TIME_STEP_H=%EMOS_TIME_STEP_H%
-  EMOS_STREAM=$STREAM
-
-  if [[ $EXPVER -ne 1 && $EXPVER -ne 2 ]] ; then
-    alias -x gksplot="gksplot -u $EPLOT_USER"
-    alias -x magplot="magplot -u $EPLOT_USER"
-  fi
-
-#=======================================================================
-#
-#  Derive the disk variables
-#
-#=======================================================================
-
-export FWROOT=$FSROOT/${EXPVER} # this variable for similar path WITHOUT stream
-export FWBASE=$FSROOT/${EXPVER} # this variable for similar path WITHOUT stream
-
-if [[ %OD_PROJ:od% != od ]] ; then
-  BASE=$TROOT/$CLASS/$EXPVER
-  WORK=$WROOT/$CLASS/$EXPVER
-  LIBS=$BASE/lib
-  BINS=$BASE/bin
-  DATA=$BASE/data
-
-elif [[ $STREAM = MAED ]] ; then
-  TROOT=${TROOT}/${STREAM}
-  WROOT=${WROOT}/${STREAM}
-  FSROOT=${FSROOT}/${STREAM}
-  BASE=$TROOT/$EXPVER
-  WORK=$WROOT/$EXPVER
-  LIBS=$BASE/lib
-  BINS=$BASE/bin
-  DATA=$BASE/data
-
-elif [[ $STREAM = DCDA ]] ; then
-  # TBD TBD TBD ODIR configuration for operational mode
-
-  BASE=$TROOT/$EXPVER
-  LIBS=$BASE/lib
-  BINS=$BASE/bin
-  DATA=$BASE/data
-  TROOT=${TROOT}/${STREAM}
-  BASE=$TROOT/$EXPVER
-  WROOT=${WROOT}/${STREAM}
-  WORK=$WROOT/$EXPVER
-  FSROOT=${FSROOT}/${STREAM}
-  FSODB=${FSODB}/${STREAM}
-
-else
-  BASE=$TROOT/$EXPVER
-  WORK=$WROOT/$EXPVER
-  LIBS=$BASE/lib
-  BINS=$BASE/bin
-  DATA=$BASE/data
-fi
-
-
-if [[ $OD_MODE = true ]] ; then
-  LOGS=%LOGDIR%/$SUITE/$FAMILY
-else
-  LOGS=$TROOT/log/$SUITE/$FAMILY
-fi
-
-if [ "$FSFAMILY" != "" ] ; then
-  PATH=${XBINS}/${ARCH}/${IFS_CYCLE}/${FSFAMILY}:${XBINS}/${ARCH}/${IFS_CYCLE}:${XBINS}/${ARCH}/${IFS_CYCLE}/an:/${BINS}/${FSFAMILY}:${HOME}/bin/${FSFAMILY}:${XBINS}/${IFS_CYCLE}:${XBINS}/an:$PATH:$emosbin:${HOME}/bin/${ARCH}
-  FSFAMILY=/$FSFAMILY
-fi
-
-SUBFSFAMILY=%SUBFSFAMILY:""%
-
-XDIR=$XROOT/bin
-ADIR=$BASE/${BASETIME}${FSFAMILY}$SUBFSFAMILY
-WDIR=$WORK/${BASETIME}${FSFAMILY}$SUBFSFAMILY
-ODIR=$OROOT/0001/${BASETIME}
-
-
-if [[ "$STREAM" = MAED ]] ; then
- if [[ "$FSFAMILY" = "/fc" ]] ; then
-   if [[ $INIMACONS -eq 1 ]] ; then
-    ADIR="${ADIR}_cons"
-    WDIR="${WDIR}_cons"
-   elif [[ "$INIMA" != "" ]] ; then
-     ADIR="${ADIR}_$INIMA"
-     WDIR="${WDIR}_$INIMA"
-   fi
- fi
-fi
-
-PATH=$HOME/bin/ppdi:$TMPDIR:$BINS:$BINS/$WAMRESOL:$XROOT/bin/$EMOS_CYCLE:$PATH
-
-if [[ "$FSFAMILY" = /mc ]] && [[ $RUNHINDCAST != 1 ]] ; then
-  EMOS_STREAM=EF
-  STREAM=EF
-fi
-
-#=======================================================================
-#
-#  Suite specific fdb settings
-#
-#=======================================================================
-#=======================================================================
-#
-#  Derive the FileServer variables
-#
-#=======================================================================
-
-if [[ %OD_PROJ:od% = od ]] ; then
-  FSBASE=${FSROOT}${FSFAMILY}/${EXPVER}
-else
-  FSBASE=${FSROOT}${FSFAMILY}/${CLASS}/${EXPVER}
-fi
-
-FDBASE=$FSBASE
-
-FSHOST=${FSBASE}/${ARCH}
-
-FSLIBS=${FSHOST}/lib
-FSBINS=${FSHOST}/bin
-FSDATA=${FSHOST}/data
-FSODIR=${FSROOT}/0001/$(substring $BASETIME 1 6)/$(substring $BASETIME 7 10)
-
-DHSWAVE=${FSROOT}/${EXPVER}/wave
-
-if [[ "$FSFAMILY" = /euroshelf ]] ; then
- DHSWAVE=${FSROOT}/${EXPVER}/euroshelf
-fi
-
-if [[ $OD_MODE = true ]] ; then
-  FSDIR=${FSBASE}/${BASETIME}
-  FSLOG=${FSBASE}/log
-
-  DHSTIME=$(substring $BASETIME 1 6)/$(substring $BASETIME 7 10)
-
-  FSBDIR=$FSOROOT/$EXPVER/$DHSTIME
-else
-  FSDIR=$FSROOT/${EXPVER}/${BASETIME}
-  FSLOG=$FSROOT/${EXPVER}/log
-
-  DHSTIME=${BASETIME}
-fi
-FODBDIR=${FSODB}${FSFAMILY}/${EXPVER}${stream}/${BASETIME}
-
-PSDIR=/ws/scratch/ma/emos/ps
-
-#=======================================================================
-# Set variable to run metview macros on a different fs from normal users
-# Please see comments in web.h if you want to change it.
-#
-# On linux cluster we use the default one
-#=======================================================================
-
-
-
-#=======================================================================
-#  Model variables that depend on configuration
-#=======================================================================
-
-VPP_MBX_SIZE=1000000
-MBX_SIZE=1000000
-MPP_TYPE=2
-if [[ $ARCH = @(ibm_power*) ]] ; then
-  MBX_SIZE=64000000
-fi
-
-[[ $RESOL = 213 || $RESOL = 319 ]] && NRESOL=160
-[[ $RESOL = 106 || $RESOL = 159 ]] && NRESOL=80
-[[ $RESOL = 511 ]] && NRESOL=256
-[[ $RESOL = 799 ]] && NRESOL=400
-[[ $RESOL = 255 ]] && NRESOL=160
-[[ $RESOL = 399 ]] && NRESOL=200
-
-
-if [[ $ARCH = @(ibm_power*) ]] ; then
-  CC=xlc_r
-  FRT=xlf90
-  FRT77=xlf
-  LD=mpxlf90_r
-  LDCC=xlc_r
-  BUILDWS=true
-  WSUSE=xlf_7112
-  PARALLEL=4
-  NATIVE=true
-  F90_DEBUG=0
-  RUN_PARALLEL=true
-fi
-#==========================================================
-# New for 33r1
-#==========================================================
-
-if [[ $ARCH = ibm_power4 ]] ; then
-  USE=xlf_11102
-elif [[ $ARCH = @(ibm_power6) ]] ; then
-  USE=standard
-fi
-
-if [[ $TASK != exp_setup ]] ; then
-  USE=${USE:-standard}
-
-  if [[ $USE != standard ]] && [[ $ARCH = ibm_power* ]] ; then
-    use $USE
-#    addon1=`echo $PATH | cut -d: -f1`
-#    addon2=`echo $PATH | cut -d: -f2`
-#    REDUCED_PATH=$addon1:$addon2:$REDUCED_PATH
-  fi
-fi
-
-set +a
-
-#=======================================================================
-#
-#  Functions to manipulate the variables
-#
-#=======================================================================
-
-NEWADIR() {
-  set -xe
-  if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi
-    echo $BASE/$(newdate $BASETIME $1)/$(basename $ADIR)
-}
-
-NEWWDIR() {
-  set -xe
-  if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi
-    # echo $WORK/$(newdate $BASETIME $1)/$(basename $WDIR) # 29r2 TBD
-    echo `echo $WDIR | sed -e "s/$BASETIME/$(newdate $BASETIME $1)/g"`
-}
-
-NEWFSBDIR() {
-  set -x
-    if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi;
-    XX=`newdate ${BASETIME} $1`;
-    # used to define the location for PS_BIAS file
-    # shall contain DCDA stream within the path _but_ this would mean
-    # modifying FSBDIR variable. However, too many script use already
-    # this variable.
-      echo $FSOROOT/$EXPVER/$(substring $XX 1 6)/$(substring $XX 7 10);
-# ${FSBASE}/$STREAM/$(substring $XX 1 6)/$(substring $XX 7 10)
-}
-
-NEWFDIR() {
-  set -xe
-    if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi;
-    XX=`newdate ${BASETIME} $1`;
-    echo $FSBASE/$(substring $XX 1 6)/$(substring $XX 7 10)
-}
-
-CHECK_DIR(){
-  if [[ $ARCH = ibm_power* ]]  ; then
-    trap '{ echo "Error in function"; exit 1; }' 0 $SMS_SIGNAL_LIST
-  fi
-  set -xeu
-  if [[ ! "$ARCH" = "linux" ]] ; then
-    trap '{ echo "Error in function"; exit 1; }' 0 $SMS_SIGNAL_LIST
-  fi
-  if [[ $# -eq 0 ]]; then
-    return 1
-  fi
-
- if [[ $ARCH = ibm_power* ]] then
-   (umask 022;pmkdir $1 || exit )
- else
-    mkdir -p -m 755 $1 || exit
- fi
-  if [[ ! "$ARCH" = "linux" ]] ; then
-    trap 0
-  fi
-
-  return 0
-}
-
-
-PUT() {
-  set -xe
-  Ecp -o $1 ec:$FSDIR/$1 || return 1
-}
-
-GET() {
-  set -xe
-  Ecp ec:$FSDIR/$1 $1 || return 1
-}
-
-if [[ $OD_MODE = true ]] ; then
-
-  GETSV() {
-    set -xe
-    file=$(basename $2)
-    Ecp ec:$1/$file $2 || return 1
-  }
-
-else
-  GETSV() {
-       set -xe
-       Ecp ec:$1/$2 $2 || return 1
-  }
-
-fi
-
-typeset -fx NEWADIR NEWWDIR NEWFDIR CHECK_DIR PUT GET GETSV NEWFSBDIR
-
-if [[ $ARCH != fujitsu ]] ; then
-  function libselect { echo WARNING - dummy command : libselect $1 ;}
-  typeset -fx libselect
-fi
-
-export OLDADIR=`NEWADIR -$PERIOD`
-export OLDWDIR=`NEWWDIR -$PERIOD`
-export YESTERDIR=`NEWWDIR -24`
-
-#==========================================================================
-#  Copy postscript file into a scratch directory;
-#
-#  PSFILE [filename [countem [rename]]]
-#
-#  Default filename is "ps"
-#
-#  countem (set but can contain anything) means that there is more than
-#  one file from this task in which case the files are numbered.
-#
-#  If only one file is produced it is copied as
-#    ${_PSDIR}/${SUITE}${EMOS_BASE}${TASK}.ps
-#  otherwise it is copied as
-#    ${_PSDIR}/${SUITE}${EMOS_BASE}${TASK}.fileno.ps
-#  where fileno is counted automatically
-#
-#  If the third parameter is given the naming convention is not followed
-#  except that the file numbering is still being done (stupid if there's
-#  only one file, but what the hell...)
-#
-#  Old file is not saved
-#==========================================================================
-
-PSFILE() {
-  set +exv
-  if [ $# -ge 1 ] ; then _psfile="$1" ; else _psfile="ps" ; fi
-  if [ ! -f $_psfile ] ; then return 1; fi
-  if [ $# -ge 2 ] ; then _fileno=`expr ${_fileno:-0} + 1`; else _fileno=0; fi
-  if [ $# -ge 3 ] ; then _name=$3; else _name=${SUITE}${EMOS_BASE}${TASK}; fi
-
-  if [ ${_fileno} -gt 0 ] ; then
-    /bin/rm -f ${PSDIR}/${_name}.${_fileno}.ps
-    cp $_psfile ${PSDIR}/${_name}.${_fileno}.ps
-  else
-    /bin/rm -f ${PSDIR}/${_name}.ps
-    cp $_psfile ${PSDIR}/${_name}.ps
-  fi
-
-  set -ex
-}
-
-typeset -fx PSFILE
-
-#=======================================================================
-#  For FDB we need a different stream. Oh why can they not be the same?
-#=======================================================================
-
-set -a
-[[ $STREAM = DA   ]] && { WSTREAM=WV;   FDB_STREAM=oper; FDB_WSTREAM=wave; }
-[[ $STREAM = EF   ]] && { WSTREAM=WAEF; FDB_STREAM=enfo; FDB_WSTREAM=waef; }
-[[ $STREAM = SCDA ]] && { WSTREAM=SCWV; FDB_STREAM=scda; FDB_WSTREAM=scwv; }
-[[ $STREAM = MAED ]] && { WSTREAM=MAWV; FDB_STREAM=maed; FDB_WSTREAM=mawv; }
-[[ $STREAM = sens ]] && { WSTREAM=sens; FDB_STREAM=sens; FDB_WSTREAM=sens; }
-[[ $STREAM = SCDA ]] && unset FDB_SERVER_HOST || true
-[[ $STREAM = DCDA ]] && { WSTREAM=DCWV ; FDB_STREAM=dcda ;  FDB_WSTREAM=dcwv; }
-[[ $STREAM = EFHC ]] && { WSTREAM=EWHC ; FDB_STREAM=efhc ;  FDB_WSTREAM=ewhc; } # MC HINDCAST
-[[ $STREAM = ENFH ]] && { WSTREAM=ENWH; FDB_STREAM=enfh ;  FDB_WSTREAM=enwh; } # MC HINDCAST
-[[ $STREAM = DAHC ]] && { WSTREAM=WVHC ; FDB_STREAM=dahc ;  FDB_WSTREAM=wvhc; } # MC HINDCAST
-
-set +a
-
-#=======================================================================
-#  Check for day and date mask
-#=======================================================================
-
-echo checking for date mask
-
-datemask=$(echo '%DATEMASK%' | cut -f1 -d.)
-day=$(substring $BASETIME 7 8)
-weekday=%WEEKDAY:none%
-
-if [[ $weekday != "none" ]] ; then
-  jday=$(newdate -d $BASETIME)
-  jday=$(expr $jday %% 7) || true
-  if [[ $jday -eq 0 ]] ; then
-    dow=monday
-  elif [[ $jday -eq 1 ]] ; then
-    dow=tuesday
-  elif [[ $jday -eq 2 ]] ; then
-    dow=wednesday
-  elif [[ $jday -eq 3 ]] ; then
-    dow=thursday
-  elif [[ $jday -eq 4 ]] ; then
-    dow=friday
-  elif [[ $jday -eq 5 ]] ; then
-    dow=saturday
-  elif [[ $jday -eq 6 ]] ; then
-    dow=sunday
-  fi
-fi
-
-if [[ $datemask != "*" && $day -ne $datemask ]] || [[ $weekday != "none" && $weekday != $dow ]] ; then
-echo job should not run today ... setting it complete
-%include <endt.h>
-fi
-
-#=======================================================================
-#
-#  Check the directories
-#
-#=======================================================================
-
-CHECK_DIR $ADIR
-CHECK_DIR $WDIR
-
-if [[ $ARCH = ibm_power* ]];then
-  export PBIO_BUFSIZE=1048576
-fi
-
-#=======================================================================
-#
-#  Suite stopper
-#
-#=======================================================================
-
-if [[ %SUITE% = "e_35r3" && $BASETIME = "2012120500" ]] ; then
-  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
-  echo "Suite e_35r3 has been set up to stop now"
-  echo "Operators  You can suspend this suite and requeue failed tasks if you like!"
-  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
-  exit 1
-elif [[ %SUITE% = "emc_35r3" && $BASETIME = "2012022600" ]] ; then
-  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
-  echo "Suite emc_35r3 has been set up to stop now"
-  echo "Operators  You can suspend this suite and requeue failed tasks if you like!"
-  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
-  exit 1
-fi
-
-#=======================================================================
-# We use an operation only Magics version to be on the safe side.
-# This is of course only on the servers
-#=======================================================================
-MAGICS=%MAGICS:magics_emos%
-
-#=======================================================================
-# We use an operation only Metview version to be on the safe side.
-#=======================================================================
-
-if [[ $ARCH = linux ]] ; then
-  metview_cmd=%METVIEW:metview_emos%
-
-elif [[ $ARCH = ibm_power4 ]] ; then
-  METVIEW_TMPDIR=/home/ma/emos/metview/metview_tmpdir
-  metview_cmd=%METVIEW:/home/ma/emos/metview/MvRun_3.9.3%
-elif [[ $ARCH = ibm_power6 ]] ; then
-  METVIEW_TMPDIR=/home/ma/emos/metview/metview_tmpdir
-  metview_cmd=%METVIEW:/home/ma/emos/metview/MvRun_3.10%
-fi
-
-#=======================================================================
-# We use an operation only metpy version to be on the safe side.
-#=======================================================================
-metpy_cmd=%METPY:metpy_emos%
-
-echo setup complete
-
-# 20040720 add /home/rd/rdx/bin/filter/bufr_filter from hpcd
-#
-%include <law.h>
-
-export LEDFAMILY=%EDFAMILY:false%
-
-banner end setup.h
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/sms.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/sms.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/sms.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/sms.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-#==========================================================================
-#  Define environment variables and export them.
-#==========================================================================
-
-set -a
-
-ECF_PASS=%ECF_PASS%
-ECF_HOST=%ECF_HOST%
-ECF_NAME=%ECF_NAME%
-ECF_TRYNO=%ECF_TRYNO%
-ECF_RID=$(echo $QSUB_REQID | cut -f1 -d.)
-ECF_HOSTFILE=$HOME/.smshostfile
-ECF_PORT=%ECF_PORT%
-ECF_JOBOUT=%ECF_JOBOUT%
-
-SUITE=%SUITE%
-FAMILY=%FAMILY%
-TASK=%TASK%
-
-DEBUG=0
-DISPLAY=0
-
-#==========================================================================
-#  Initialize sms.
-#  Trap handling.
-#  Modify the ERROR function what to do in case of any error.
-#==========================================================================
-
-#if [[ $ARCH = sgimips && -f /usr/local/ecfs/prodn/.ecfs_k_env ]] ; then
-if [[ -f /usr/local/ecfs/prodn/.ecfs_k_env ]] ; then
-  . /usr/local/ecfs/prodn/.ecfs_k_env
-fi
-
-smsinit $ECF_RID &
-
-ERROR() {
-  smsabort; printenv; trap 0; exit
-}
-
-trap ERROR 0
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
-
-set -ex
-
-if [[ $ARCH = sgimips && -f /usr/local/ecfs/prodn/.ecfs_k_env ]] ; then
-  . /usr/local/ecfs/prodn/.ecfs_k_env
-fi
-
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/tail.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/tail.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-#smscomplete  # Notify SMS of a normal end
-trap 0       # Remove all traps
-exit 0       # End the shell
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/trap.h 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/trap.h
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/includes/trap.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/includes/trap.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,137 +0,0 @@
-banner trap.h
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-
-#==========================================================================
-#  Trap handling and ECF_ initialisation
-#
-#  Write into the ERROR function what to do in case of any error.
-#==========================================================================
-
-typeset -l ARCH
-
-if [[ "$ARCH" = hpia64 ]] ; then
-  rcp /home/ma/emos/data/dummy.output emos@%ECF_HOST%:%ECF_JOBOUT% || true
-fi
-
-set -a
-LOADL_STEP_ID=${LOADL_STEP_ID:=NOT_SET}
-QSUB_REQID=${QSUB_REQID:=NOT_SET}
-PBS_JOBID=${PBS_JOBID:=NOT_SET}
-
-if [[ $LOADL_STEP_ID != NOT_SET ]] ; then
-  ECF_RID=$(echo $LOADL_STEP_ID | cut -f1 -d.)
-  ECF_RID=$(substring $ECF_RID 6 8  )
-  ECF_RID=$(echo $LOADL_STEP_ID | cut -f2 -d.)${ECF_RID}
-  JOB_ID=$LOADL_STEP_ID
-elif [[ $QSUB_REQID != NOT_SET ]] ; then
-  ECF_RID=$(echo $QSUB_REQID | cut -f1 -d.)
-  JOB_ID=$QSUB_REQID
-elif [[ $PBS_JOBID != NOT_SET ]] ; then
-  ECF_RID=$(echo $PBS_JOBID | cut -f1 -d.)
-  JOB_ID=$PBS_JOBID
-
-  TOPATH=%TOPATH:/tmp/output%
-  link_name=`~emos/bin/subs_path.pl -f %ECF_OUT% -t $TOPATH -n %ECF_JOBOUT%`
-  mkdir -p `dirname $link_name` || :
-  ln -sf /var/spool/PBS/spool/${PBS_JOBID}.OU $link_name || :
-  rm -f %ECF_JOBOUT% || :
-  ln -sf /var/spool/PBS/spool/${PBS_JOBID}.OU %ECF_JOBOUT%
-else
-  ECF_RID=$$
-  JOB_ID=$ECF_RID
-fi
-
-ECF_PASS=%ECF_PASS%
-ECF_HOST=%ECF_HOST%
-ECF_NAME=%ECF_NAME%
-ECF_TRYNO=%ECF_TRYNO%
-ECF_HOSTFILE=$HOME/.smshostfile
-ECF_JOBOUT=%ECF_JOBOUT%
-
-set +a
-ARCHWDIR=${ARCHWDIR:=""}
-
-SMSCLEAN() {
-  set -x
-  set +e
-  STREAM=${STREAM:=""}
-  if [[ "$STREAM" = @(SEAS|MOFC|OCEA|mnfc|mnfh) ]] ; then
-    if [[ "%TASK%" = logfiles ]] ; then
-      n=0
-      while [[ -d $WDIR ]] ; do
-        # Forked processes could still be around, and 'rm -rf' fails
-        rm -rf $WDIR || true
-        ls -l $WDIR && sleep 2 || true
-        n=$((n+1))
-        [[ $n -gt 5 ]] && break
-      done || true
-    fi
-  fi
-  FSFAMILY=${FSFAMILY:=""}
-  if [[ "$FSFAMILY" = /mars || "%FAMILY1%" = archive ]] ; then
-    cd $TMPDIR
-    n=0
-    while [[ -d ${WDIR}$ECF_NAME ]] ; do
-      # Forked processes could still be around, and 'rm -rf' fails
-      rm -rf ${WDIR}$ECF_NAME || true
-      ls -l ${WDIR}$ECF_NAME && sleep 2 || true
-      n=$((n+1))
-      [[ $n -gt 5 ]] && break
-    done || true
-  fi
-
-  if [[ $ARCH = linux ]] ; then
-    . /usr/local/share/ecmwf/share/.epilog
-  fi
-}
-typeset -fx SMSCLEAN
-
-%include <rcp.h>
-
-ERROR() {
-  set -x
-  set +e
-  wait
-  smsabort
-  trap 0
-  date
-  times
-  echo "environment was:"
-  printenv | sort
-
-  SMSCLEAN
-
-  if [[ $$ARCH != "ibm_power*" ]] ; then
-    SMSRCP || :
-  fi
-  exit 1
-}
-
-if [[ $ARCH == hpia64 ]]; then
-  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 10 12 13 15 24 30 33'
-elif [[ $ARCH == ibm_power* ]]; then
-  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 10 12 13 15 24 30'
-elif [[ $ARCH == linux ]]; then
-  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
-else
-  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
-fi
-
-%include <set_traps.h>
-trap
-set -exu
-
-[[ -d $TMPDIR ]] && cd $TMPDIR
-
-smsinit $ECF_RID &
-smsmsg "#ID ECF_NAME=%ECF_NAME%;ECF_JOBOUT=%ECF_JOBOUT%;ECF_HOME=%ECF_HOME%;JOB_ID=${JOB_ID:-}"
-
-date
-
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/micro_in_comment.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/micro_in_comment.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/micro_in_comment.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/micro_in_comment.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-echo do %% some work
-
-# mismatched micro characters staring with a # are not reported as errors
-#BSUB -o /u/Carolyn.Pasti/ecf/out/test500/sleep2.o%J
-#BSUB -e /u/Carolyn.Pasti/ecf/out/test500/sleep2.o%J
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/SMSHOME2/good/operations.ecf 5.13.0-1/ANode/test/data/SMSHOME2/good/operations.ecf
--- 5.12.4-1/ANode/test/data/SMSHOME2/good/operations.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/SMSHOME2/good/operations.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-
-# Since we have comment out, this should not appear in the jobs file
-#%include <qsub.h>
-# QSUB -lT 3500
-# QSUB -lt 3500
-# QSUB -lM 50mb
-
-%include <config.h>
-
-%include <trap.h>
-%include <setup.h>
- 
-%include <endt.h>
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/common.h 5.13.0-1/ANode/test/data/common.h
--- 5.12.4-1/ANode/test/data/common.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/common.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-#
-# Used to test inclusion with angle brackets  <filename>
-# First look in %ECF_INCLUDE%/filename
-# If file not there then look at ECF_HOME/filename
-#
-# THIS ALLOWS USE TO PUT SPECIFIC FILES IN ECF_INCLUDE
-# AND COMMON FILE IN ECF_HOME
diff -pruN 5.12.4-1/ANode/test/data/includes/AA.h 5.13.0-1/ANode/test/data/includes/AA.h
--- 5.12.4-1/ANode/test/data/includes/AA.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/AA.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-#startAA
-%includeonce <BB.h>
-#endAA
diff -pruN 5.12.4-1/ANode/test/data/includes/BB.h 5.13.0-1/ANode/test/data/includes/BB.h
--- 5.12.4-1/ANode/test/data/includes/BB.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/BB.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-#startBB
-%includeonce <CC.h>
-#endBB
diff -pruN 5.12.4-1/ANode/test/data/includes/CC.h 5.13.0-1/ANode/test/data/includes/CC.h
--- 5.12.4-1/ANode/test/data/includes/CC.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/CC.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#CC
diff -pruN 5.12.4-1/ANode/test/data/includes/a.h 5.13.0-1/ANode/test/data/includes/a.h
--- 5.12.4-1/ANode/test/data/includes/a.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/a.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-#a.h
-%include <b.h>
diff -pruN 5.12.4-1/ANode/test/data/includes/b.h 5.13.0-1/ANode/test/data/includes/b.h
--- 5.12.4-1/ANode/test/data/includes/b.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/b.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#b.h
diff -pruN 5.12.4-1/ANode/test/data/includes/head.h 5.13.0-1/ANode/test/data/includes/head.h
--- 5.12.4-1/ANode/test/data/includes/head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,75 +0,0 @@
-#!/bin/ksh
-# ================================== start of head.h ================================
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-%manual
-#This is the manual from the head.h file
-%end
-
-%comment
-#This is the comment from the head.h file
-%end
-
-set -e # stop the shell on first error
-set -u # fail when using an undefined variable
-set -x # echo script lines as they are executed
-set -o pipefail # fail if last(rightmost) command exits with a non-zero status
-
-# Defines the three variables that are needed for any
-# communication with ECF
-
-export ECF_PORT=%ECF_PORT%    # The port number on the server
-export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%
-fi
-
-# to debug client communication with the server, enable this environment
-#export ECF_DEBUG_CLIENT=
-
-# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
-os_name=$(uname -s)
-if [[ $os_name = Linux ]] ; then
-   host %ECF_HOST%
-fi
-
-# Typically we dont set this, however the zombie automated test require this.
-# it allows us to disambiguate a zomie from a real job.
-export ECF_RID=$$
-
-# Tell ECF_ we have stated
-# The ECF_ variable ECF_RID will be set to parameter of smsinit
-# Here we give the current PID.
-
-
-# Defined a error hanlder
-ERROR() {
-	echo "ERROR() called"
-	set +e        # Clear -e flag, so we don't fail
-	wait          # wait for background process to stop
-	%ECF_CLIENT_EXE_PATH:ecflow_client% --abort # Notify ECF_ that something went wrong
-	trap 0        # Remove the trap
-	exit 0        # End the script
-}
-
-# Trap any calls to exit and errors caught by the -e flag
-
-trap ERROR 0
-
-# Trap any signal that may cause the script to fail
-
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
-
-
-#smsinit $$
-%ECF_CLIENT_EXE_PATH:ecflow_client% --init=$$
-echo $?
-# ================================== end of head.h ================================
diff -pruN 5.12.4-1/ANode/test/data/includes/manual.h 5.13.0-1/ANode/test/data/includes/manual.h
--- 5.12.4-1/ANode/test/data/includes/manual.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/manual.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-Test manual files are pre-processed
diff -pruN 5.12.4-1/ANode/test/data/includes/simple_head.h 5.13.0-1/ANode/test/data/includes/simple_head.h
--- 5.12.4-1/ANode/test/data/includes/simple_head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/simple_head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#head.h
diff -pruN 5.12.4-1/ANode/test/data/includes/simple_tail.h 5.13.0-1/ANode/test/data/includes/simple_tail.h
--- 5.12.4-1/ANode/test/data/includes/simple_tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/simple_tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-#tail.h
diff -pruN 5.12.4-1/ANode/test/data/includes/tail.h 5.13.0-1/ANode/test/data/includes/tail.h
--- 5.12.4-1/ANode/test/data/includes/tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-# ================================== start of tail.h ================================
-#smscomplete  # Notify ECF of a normal end
-%ECF_CLIENT_EXE_PATH:ecflow_client% --complete
-trap 0       # Remove all traps
-exit 0       # End the shell
-%manual
-#This is the manual from the tail.h file
-%end
-%comment
-#This is the comment from the tail.h file
-%end
-# ================================== end of tail.h ================================
diff -pruN 5.12.4-1/ANode/test/data/includes/used_variables.h 5.13.0-1/ANode/test/data/includes/used_variables.h
--- 5.12.4-1/ANode/test/data/includes/used_variables.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/used_variables.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite=%SUITE%
-suite=%FAMILY%
-suite=%FAMILY1%
-suite=%TASK%
-suite=%ECF_TRYNO%
-suite=%ECF_JOB%
-suite=%ECF_JOBOUT%
-suite=%ECF_PASS%
-suite=%ECF_PORT%
-suite=%ECF_HOST%
-suite=%ECF_NAME%
-suite=%ESUITE%
diff -pruN 5.12.4-1/ANode/test/data/includes/used_variables_with_comments.h 5.13.0-1/ANode/test/data/includes/used_variables_with_comments.h
--- 5.12.4-1/ANode/test/data/includes/used_variables_with_comments.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes/used_variables_with_comments.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-%comment
-suite = %ETASK%
-%end
-
-%manual
-suite = %ETASK%
-%end
-
-suite=%FRED%
diff -pruN 5.12.4-1/ANode/test/data/includes2/fred.h 5.13.0-1/ANode/test/data/includes2/fred.h
--- 5.12.4-1/ANode/test/data/includes2/fred.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/includes2/fred.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-#
-# Used to test inclusion with angle brackets  <filename>
-# First look in *ALL* the paths specfied in %ECF_INCLUDE%
-# If file not there then look at ECF_HOME/filename
-#
-# THIS ALLOWS USE TO PUT SPECIFIC FILES IN ECF_INCLUDE
-# AND COMMON FILE IN ECF_HOME
diff -pruN 5.12.4-1/ANode/test/data/migration/Family.def 5.13.0-1/ANode/test/data/migration/Family.def
--- 5.12.4-1/ANode/test/data/migration/Family.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/migration/Family.def	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"6Family":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"n_":""},"nodes_":[]}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/migration/Limit.def 5.13.0-1/ANode/test/data/migration/Limit.def
--- 5.12.4-1/ANode/test/data/migration/Limit.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/migration/Limit.def	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Limit":{"n_":"","lim_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/migration/Suite.def 5.13.0-1/ANode/test/data/migration/Suite.def
--- 5.12.4-1/ANode/test/data/migration/Suite.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/migration/Suite.def	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"5Suite":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"n_":""},"nodes_":[]},"cal_":{"cereal_class_version":0,"initTime_":{"ptime":"2018-Aug-21 08:38:58"}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/data/migration/Task.def 5.13.0-1/ANode/test/data/migration/Task.def
--- 5.12.4-1/ANode/test/data/migration/Task.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/data/migration/Task.def	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-{"4Task":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"n_":""}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/ParseOnly.cpp 5.13.0-1/ANode/test/parser/ParseOnly.cpp
--- 5.12.4-1/ANode/test/parser/ParseOnly.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/ParseOnly.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-#include <string>
-
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// leap42 boost_1_64_0 gcc-5.3.0 release mode
-//    time bin/gcc-5.3.0/release/perf_aparser_only ${ECF_TEST_DEFS_DIR}/vsms2.31415.def
-//    real    0m2.79s
-//    user    0m2.59s
-//    sys     0m0.18s
-
-int main(int argc, char* argv[]) {
-    //   cout << "argc = " << argc << "\n";
-    //   for(int i = 0; i < argc; i++) {
-    //      cout << "arg " << i << ":" << argv[i] << "\n";
-    //   }
-
-    if (argc != 2) {
-        cout << "Expect single argument which is path to a defs file\n";
-        return 1;
-    }
-
-    std::string path = argv[1];
-
-    Defs defs;
-    std::string errorMsg, warningMsg;
-    if (!defs.restore(path, errorMsg, warningMsg)) {
-        cout << errorMsg << "\n";
-        cout << warningMsg << "\n";
-        return 1;
-    }
-
-    //   // Determine average number of variables for nodes with variables
-    //   vector<Node*> nodes;
-    //   defs.getAllNodes(nodes);
-    //   cout << "Total number of nodes: " << nodes.size() << "\n";
-    //   size_t number_of_variables = 0;
-    //   size_t nodes_with_variables = 0;
-    //   for(const auto& n : nodes) {
-    //      // cout << n->variables().size() << "\n";
-    //      if (n->variables().size() > 0) {
-    //         number_of_variables +=  n->variables().size();
-    //         nodes_with_variables++;
-    //      }
-    //   }
-    //   cout << "number_of_variables " << number_of_variables << "\n";
-    //   cout << "nodes_with_variables  " <<  nodes_with_variables << "\n";
-    //   cout <<"Average number of variables per node " <<  (double)number_of_variables/nodes_with_variables  << "\n";
-
-    //   PrintStyle style(PrintStyle::MIGRATE);
-    //   cout << defs;
-    return 0;
-}
diff -pruN 5.12.4-1/ANode/test/parser/ParseTimer.cpp 5.13.0-1/ANode/test/parser/ParseTimer.cpp
--- 5.12.4-1/ANode/test/parser/ParseTimer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/ParseTimer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,249 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-#include <string>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/timer/timer.hpp>
-
-#include "PersistHelper.hpp"
-#include "TemporaryFile.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/NodeContainer.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::timer;
-
-// This test is used to find a task given a path of the form:
-//      suite/family/task
-//    suite/family/family/task
-void test_find_task_using_path(NodeContainer* f, const Defs& defs) {
-    if (f != defs.findAbsNode(f->absNodePath()).get())
-        cout << "Could not find path " << f->absNodePath() << "\n";
-
-    for (node_ptr t : f->nodeVec()) {
-        if (t.get() != defs.findAbsNode(t->absNodePath()).get())
-            cout << "Could not find path " << t->absNodePath() << "\n";
-        Family* family = t->isFamily();
-        if (family) {
-            test_find_task_using_path(family, defs);
-        }
-    }
-}
-
-// Create derived class, so that we can time the parse only
-// i.e ignore expression build/checking and limit checking
-class TestDefsStructureParser : public DefsStructureParser {
-public:
-    TestDefsStructureParser(Defs* defsfile, const std::string& file_name) : DefsStructureParser(defsfile, file_name) {}
-    bool do_parse_file(std::string& errorMsg) { return DefsStructureParser::do_parse_file(errorMsg); }
-};
-
-int main(int argc, char* argv[]) {
-    //   cout << "argc = " << argc << "\n";
-    //   for(int i = 0; i < argc; i++) {
-    //      cout << "arg " << i << ":" << argv[i] << "\n";
-    //   }
-
-    if (argc != 2) {
-        cout << "Expect single argument which is path to a defs file\n";
-        return 1;
-    }
-
-    std::string path = argv[1];
-
-    auto_cpu_timer t;
-    cpu_timer timer;
-
-    /// If this is moved below, we get some caching affect, with the persist and reload timing
-    Defs defs;
-    {
-        timer.start();
-        std::string errorMsg, warningMsg;
-        bool result = defs.restore(path, errorMsg, warningMsg);
-        cout << " Parsing Node tree & AST creation time parse(" << result
-             << ") = " << timer.format(3, Str::cpu_timer_format()) << endl;
-    }
-    {
-        Defs local_defs;
-        timer.start();
-        TestDefsStructureParser checkPtParser(&local_defs, path);
-        std::string errorMsg;
-        bool result = checkPtParser.do_parse_file(errorMsg);
-        cout << " Parsing Node tree *only* time         parse(" << result
-             << ") = " << timer.format(3, Str::cpu_timer_format()) << endl;
-    }
-    {
-        timer.start();
-        std::string defs_as_string;
-        defs.save_as_string(defs_as_string, PrintStyle::DEFS);
-        Defs newDefs;
-        std::string error_msg, warning_msg; // ignore error since some input defs have invalid triggers
-        newDefs.restore_from_string(defs_as_string, error_msg, warning_msg);
-        cout << " Save and restore as string(DEFS)               = " << timer.format(3, Str::cpu_timer_format())
-             << " -> string size(" << defs_as_string.size() << ")" << endl;
-    }
-    {
-        timer.start();
-        std::string defs_as_string;
-        defs.save_as_string(defs_as_string, PrintStyle::NET);
-        Defs newDefs;
-        std::string error_msg, warning_msg; // ignore error since some input defs have invalid triggers
-        newDefs.restore_from_string(defs_as_string, error_msg, warning_msg);
-        cout << " Save and restore as string(NET)                = " << timer.format(3, Str::cpu_timer_format())
-             << " -> string size(" << defs_as_string.size() << ") checks relaxed" << endl;
-    }
-    {
-        timer.start();
-        std::string defs_as_string;
-        defs.save_as_string(defs_as_string, PrintStyle::MIGRATE);
-        Defs newDefs;
-        std::string error_msg, warning_msg; // ignore error since some input defs have invalid triggers
-        newDefs.restore_from_string(defs_as_string, error_msg, warning_msg);
-        cout << " Save and restore as string(MIGRATE)            = " << timer.format(3, Str::cpu_timer_format())
-             << " -> string size(" << defs_as_string.size() << ")" << endl;
-    }
-    {
-        // Test time for persisting to defs file only
-        TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
-
-        timer.start();
-        defs.save_as_checkpt(temporary.path());
-        cout << " Save as DEFS checkpoint, time taken            = " << timer.format(3, Str::cpu_timer_format())
-             << endl;
-    }
-
-    {
-        // Test time for persisting to CEREAL checkpoint file only
-        fs::path fs_path(path);
-        //   std::cout << "parent path " << fs_path.parent_path() << "\n";
-        //   std::cout << "root path " << fs_path.root_path()  << "\n";
-        //   std::cout << "root name " << fs_path.root_name()  << "\n";
-        //   std::cout << "root directory " << fs_path.root_directory()  << "\n";
-        //   std::cout << "relative_path " << fs_path.relative_path()  << "\n";
-        //   std::cout << "filename " << fs_path.filename()  << "\n";
-        //   std::cout << "stem " << fs_path.stem()  << "\n";
-        //   std::cout << "extension " << fs_path.extension()  << "\n";
-
-        std::stringstream ss;
-#ifdef DEBUG
-        ss << "/var/tmp/ma0/JSON/debug_" << fs_path.stem() << ".json";
-#else
-        ss << "/var/tmp/ma0/JSON/" << fs_path.stem() << ".json";
-#endif
-
-        std::string json_filepath = ss.str();
-        Str::replaceall(json_filepath, "\"", ""); // fs_path.stem() seems to add ", so remove them
-        // cout << "  json_filepath: " << json_filepath << endl;
-
-        std::remove(json_filepath.c_str());
-        timer.start();
-        defs.cereal_save_as_checkpt(json_filepath);
-        cout << " Save as CEREAL checkpoint, time taken          = " << timer.format(3, Str::cpu_timer_format())
-             << endl;
-    }
-
-    {
-        // may need to comment out output for large differences. Will double the time.
-        bool do_compare = false;
-        timer.start();
-        PersistHelper helper;
-        bool result = helper.test_defs_checkpt_and_reload(defs, do_compare);
-        cout << " Checkpt(DEFS) and reload, time taken           = " << timer.format(3, Str::cpu_timer_format())
-             << " file_size(" << helper.file_size() << ")  result(" << result << ") msg(" << helper.errorMsg() << ")"
-             << endl;
-    }
-
-    {
-        bool do_compare = false;
-        timer.start();
-        PersistHelper helper;
-        bool result = helper.test_cereal_checkpt_and_reload(defs, do_compare);
-        cout << " Checkpt(CEREAL) and reload , time taken        = ";
-        cout << timer.format(3, Str::cpu_timer_format()) << " file_size(" << helper.file_size() << ")  result("
-             << result << ") msg(" << helper.errorMsg() << ")" << endl;
-    }
-
-    {
-        timer.start();
-        for (suite_ptr s : defs.suiteVec()) {
-            test_find_task_using_path(s.get(), defs);
-        }
-        cout << " Test all paths can be found. time taken        = " << timer.format(3, Str::cpu_timer_format())
-             << endl;
-    }
-    {
-        // Time how long it takes for job submission. Must call begin on all suites first.
-        timer.start();
-        defs.beginAll();
-        int count = 10;
-        JobsParam jobsParam; // default is not to create jobs, hence only used in testing
-        Jobs jobs(&defs);
-        for (int i = 0; i < count; i++) {
-            jobs.generate(jobsParam);
-        }
-        cout << " time for 10 jobSubmissions                     = " << timer.format(3, Str::cpu_timer_format())
-             << " jobs:" << jobsParam.submitted().size() << endl;
-    }
-    {
-        // Time how long it takes for post process
-        timer.start();
-        string errorMsg, warningMsg;
-        bool result = defs.check(errorMsg, warningMsg);
-        cout << " Time for Defs::check(inlimit resolution)       = " << timer.format(3, Str::cpu_timer_format())
-             << " result(" << result << ")" << endl;
-    }
-    {
-        // Time how long it takes to delete all nodes/ references. Delete all tasks and then suites/families.
-        timer.start();
-        std::vector<Task*> tasks;
-        defs.getAllTasks(tasks);
-        for (Task* ta : tasks) {
-            if (!defs.deleteChild(ta))
-                cout << "Failed to delete task\n";
-        }
-        tasks.clear();
-        defs.getAllTasks(tasks);
-        if (!tasks.empty())
-            cout << "Expected all tasks to be deleted but found " << tasks.size() << "\n";
-
-        std::vector<suite_ptr> vec = defs.suiteVec(); // make a copy, to avoid invalidating iterators
-        for (suite_ptr s : vec) {
-            std::vector<node_ptr> familyVec = s->nodeVec(); // make a copy, to avoid invalidating iterators
-            for (node_ptr f : familyVec) {
-                if (!defs.deleteChild(f.get()))
-                    cout << "Failed to delete family\n";
-            }
-            if (!s->nodeVec().empty())
-                cout << "Expected all Families to be deleted but found " << s->nodeVec().size() << "\n";
-            if (!defs.deleteChild(s.get()))
-                cout << "Failed to delete suite\n";
-        }
-        if (!defs.suiteVec().empty())
-            cout << "Expected all Suites to be deleted but found " << defs.suiteVec().size() << "\n";
-
-        cout << " time for deleting all nodes                    = " << timer.format(3, Str::cpu_timer_format())
-             << endl;
-    }
-}
diff -pruN 5.12.4-1/ANode/test/parser/PersistHelper.cpp 5.13.0-1/ANode/test/parser/PersistHelper.cpp
--- 5.12.4-1/ANode/test/parser/PersistHelper.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/PersistHelper.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,309 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "PersistHelper.hpp"
-
-#include <sstream>
-
-#include "TemporaryFile.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-
-bool PersistHelper::test_persist_and_reload(const Defs& theInMemoryDefs,
-                                            PrintStyle::Type_t file_type_on_disk,
-                                            bool do_compare) {
-    // Write parsed file to disk, and reload, then compare defs, they should be the same
-    errorMsg_.clear();
-    file_size_ = 0;
-
-    TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
-
-    {
-        // The file MUST be written in the *SAME* form that it was read, Otherwise they will not compare:
-        theInMemoryDefs.save_as_filename(temporary.path(), file_type_on_disk);
-    }
-
-    // Reload the file we just persisted and compare with in memory defs
-    Defs savedDef;
-    return reload_from_defs_file(theInMemoryDefs, savedDef, temporary.path(), do_compare);
-}
-
-bool PersistHelper::test_defs_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare) {
-    // Write parsed file to disk, and reload, then compare defs, they should be the same
-    errorMsg_.clear();
-    file_size_ = 0;
-
-    TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
-
-    {
-        // The file MUST be written in the *SAME* form that it was read, Otherwise they will not compare:
-        theInMemoryDefs.save_as_checkpt(temporary.path());
-    }
-
-    // Reload the file we just persisted and compare with in memory defs
-    Defs savedDef;
-    bool reload_result = reload_from_defs_file(theInMemoryDefs, savedDef, temporary.path(), do_compare);
-    if (reload_result)
-        return savedDef.checkInvariants(errorMsg_);
-    return false;
-}
-
-bool PersistHelper::test_cereal_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare) {
-    errorMsg_.clear();
-    file_size_ = 0;
-    if (!theInMemoryDefs.checkInvariants(errorMsg_)) {
-        return false;
-    }
-
-    // Save in memory defs as a check pt file, then restore and compare
-    Defs reloaded_defs;
-    bool reload_result = reload_from_cereal_checkpt_file(theInMemoryDefs, reloaded_defs, do_compare);
-    if (reload_result)
-        return reloaded_defs.checkInvariants(errorMsg_);
-    return false;
-}
-
-bool PersistHelper::test_state_persist_and_reload_with_checkpt(const Defs& theInMemoryDefs) {
-    // Write Defs to disk, and reload, then compare defs reloaded checkpt file, they should be the same
-    errorMsg_.clear();
-    file_size_ = 0;
-    if (!theInMemoryDefs.checkInvariants(errorMsg_)) {
-        return false;
-    }
-
-    DebugEquality debug_equality; // only as affect in DEBUG build
-
-    TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
-
-    {
-        // The file MUST be written in the *SAME* form that it was read, Otherwise they will not compare:
-        theInMemoryDefs.save_as_checkpt(temporary.path()); // will save edit history
-    }
-
-    Defs reload_strings_def;
-    {
-        // Open file, and parse as a string.
-        std::string defs_as_string;
-        if (!File::open(temporary.path(), defs_as_string)) {
-            errorMsg_ += "Could not file file: " + temporary.path();
-            return false;
-        }
-        std::string error_msg, warning;
-        if (!reload_strings_def.restore_from_string(defs_as_string, error_msg, warning)) {
-            errorMsg_ += error_msg;
-            return false;
-        }
-        if (!reload_strings_def.checkInvariants(errorMsg_)) {
-            return false;
-        }
-    }
-
-    // Reload the file we just persisted and compare with in memory defs
-    Defs reloaded_defs;
-    if (!reload_from_defs_file(theInMemoryDefs, reloaded_defs, temporary.path())) {
-        return false;
-    }
-    if (!reloaded_defs.checkInvariants(errorMsg_)) {
-        return false;
-    }
-
-    // Save in memory defs as a check pt file, then restore and compare
-    Defs reloaded_cereal_checkPt_defs;
-    if (!reload_from_cereal_checkpt_file(theInMemoryDefs, reloaded_cereal_checkPt_defs, true)) {
-        return false;
-    }
-    if (!reloaded_cereal_checkPt_defs.checkInvariants(errorMsg_)) {
-        return false;
-    }
-
-    // Make sure reloading def's file with state is same as the checkpt file
-    bool match = reloaded_defs == reloaded_cereal_checkPt_defs;
-
-    if (!match) {
-        std::stringstream ss;
-        ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt\n";
-        ss << "In reloaded_defs_file and reloaded_checkPt_defs don't match\n";
-        ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
-        PrintStyle style(PrintStyle::MIGRATE); // will save edit history
-        ss << theInMemoryDefs;
-        ss << "+++++++++++++ reloaded_defs  ++++++++++++++++++++++++++++\n";
-        ss << reloaded_defs;
-        ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
-        ss << reloaded_cereal_checkPt_defs;
-        errorMsg_ += ss.str();
-    }
-    else {
-        if (compare_edit_history_ && !reloaded_defs.compare_edit_history(reloaded_cereal_checkPt_defs)) {
-            std::stringstream ss;
-            ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt  compare_edit_history_\n";
-            ss << "In reloaded_defs_file and reloaded_checkPt_defs edit history don't match\n";
-            ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
-            PrintStyle style(PrintStyle::MIGRATE); // will save edit history
-            ss << theInMemoryDefs;
-            ss << "+++++++++++++ reloaded_defs  ++++++++++++++++++++++++++++\n";
-            ss << reloaded_defs;
-            ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
-            ss << reloaded_cereal_checkPt_defs;
-            errorMsg_ += ss.str();
-        }
-    }
-    if (!reloaded_defs.compare_change_no(reloaded_cereal_checkPt_defs)) {
-        errorMsg_ += "\nPersistHelper::test_state_persist_and_reload_with_checkpt: Change numbers don't compare "
-                     "between reloaded_defs and reloaded_cereal_checkPt_defs \n";
-    }
-
-    // Make sure reloading def's file with state is same as the checkpt file
-    match = reload_strings_def == reloaded_cereal_checkPt_defs;
-    if (!match) {
-        std::stringstream ss;
-        ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt\n";
-        ss << "In reloaded_defs file AS STRING and reloaded_checkPt_defs don't match\n";
-        ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
-        PrintStyle style(PrintStyle::MIGRATE); // will save edit history
-        ss << theInMemoryDefs;
-        ss << "+++++++++++++  reload_strings_def  ++++++++++++++++++++++++++++\n";
-        ss << reload_strings_def;
-        ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
-        ss << reloaded_cereal_checkPt_defs;
-        errorMsg_ += ss.str();
-    }
-    else {
-        if (compare_edit_history_ && !reload_strings_def.compare_edit_history(reloaded_cereal_checkPt_defs)) {
-            std::stringstream ss;
-            ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt  compare_edit_history_\n";
-            ss << "In reloaded_defs_file and reloaded_checkPt_defs edit history don't match\n";
-            ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
-            PrintStyle style(PrintStyle::MIGRATE); // will save edit history
-            ss << theInMemoryDefs;
-            ss << "+++++++++++++ reload_strings_def ++++++++++++++++++++++++++++\n";
-            ss << reload_strings_def;
-            ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
-            ss << reloaded_cereal_checkPt_defs;
-            errorMsg_ += ss.str();
-        }
-    }
-    if (!reload_strings_def.compare_change_no(reloaded_cereal_checkPt_defs)) {
-        errorMsg_ += "\nPersistHelper::test_state_persist_and_reload_with_checkpt: Change numbers don't compare "
-                     "between reload_strings_def and reloaded_cereal_checkPt_defs\n";
-    }
-
-    return errorMsg_.empty();
-}
-
-bool PersistHelper::reload_from_defs_file(const Defs& theInMemoryDefs,
-                                          Defs& reloaded_defs,
-                                          const std::string& tmpFilename,
-                                          bool do_compare) {
-    DebugEquality debug_equality; // only as affect in DEBUG build
-
-    std::string warningMsg;
-    if (!reloaded_defs.restore(tmpFilename, errorMsg_, warningMsg)) {
-        std::stringstream ss;
-        ss << "RE-PARSE failed for " << tmpFilename << "\n";
-        errorMsg_ += ss.str();
-        return false;
-    }
-
-    if (do_compare) {
-        // Make sure the file we just parsed match's the one we persisted
-        bool match = reloaded_defs == theInMemoryDefs;
-
-        if (!match) {
-            std::stringstream ss;
-            ss << "\nPersistHelper::reload_from_defs_file\n";
-            ss << "In memory and reloaded def's don't match\n";
-            ss << "+++++++++++++ Saved/reloaded_defs  ++++++++++++++++++++++++++++\n";
-            PrintStyle style(PrintStyle::STATE);
-            ss << reloaded_defs;
-            ss << "++++++++++++++ In memory def ++++++++++++++++++++++++++++\n";
-            ss << theInMemoryDefs;
-            errorMsg_ += ss.str();
-        }
-        else {
-            if (compare_edit_history_ && !reloaded_defs.compare_edit_history(theInMemoryDefs)) {
-                std::stringstream ss;
-                ss << "\nPersistHelper::reload_from_defs_file compare_edit_history_\n";
-                ss << "In memory and reloaded def's don't match\n";
-                ss << "+++++++++++++ Saved/reloaded_defs  ++++++++++++++++++++++++++++\n";
-                PrintStyle style(PrintStyle::MIGRATE);
-                ss << reloaded_defs;
-                ss << "++++++++++++++ In memory def ++++++++++++++++++++++++++++\n";
-                ss << theInMemoryDefs;
-                errorMsg_ += ss.str();
-            }
-        }
-        if (!reloaded_defs.compare_change_no(theInMemoryDefs)) {
-            errorMsg_ += "\nPersistHelper::reload_from_defs_file: Change numbers don't compare between reloaded_defs  "
-                         "and theInMemoryDefs  \n";
-        }
-    }
-
-    file_size_ = fs::file_size(tmpFilename);
-    std::remove(tmpFilename.c_str());
-    return errorMsg_.empty();
-}
-
-bool PersistHelper::reload_from_cereal_checkpt_file(const Defs& theInMemoryDefs, Defs& reloaded_defs, bool do_compare) {
-    // make sure edit history is stored
-    TemporaryFile temporary("tmp.check_%%%%-%%%%-%%%%-%%%%");
-
-    theInMemoryDefs.cereal_save_as_checkpt(temporary.path());
-
-    DebugEquality debug_equality; // only as effect in DEBUG build
-
-    try {
-        // Parse the file we just persisted and load the defs file into memory.
-        reloaded_defs.cereal_restore_from_checkpt(temporary.path());
-
-        if (do_compare) {
-            // Make sure the checkpoint the file we just parsed corresponds to the one we stored
-            bool match = reloaded_defs == theInMemoryDefs;
-            if (!match) {
-                std::stringstream ss;
-                ss << "\nPersistHelper::reload_from_cereal_checkpt_file\n";
-                ss << "In memory and reloaded def's don't match\n";
-                ss << "+++++++++++++ Saved/reloaded check pt file ++++++++++++++++++++++++++++\n";
-                PrintStyle style(PrintStyle::STATE);
-                ss << reloaded_defs;
-                ss << "++++++++++++++ In memory def ++++++++++++++++++++++++++++\n";
-                ss << theInMemoryDefs;
-                errorMsg_ += ss.str();
-            }
-            else {
-                if (compare_edit_history_ && !reloaded_defs.compare_edit_history(theInMemoryDefs)) {
-                    std::stringstream ss;
-                    ss << "\nPersistHelper::reload_from_cereal_checkpt_file  compare_edit_history_\n";
-                    ss << "In reloaded_defs_file and reloaded_checkPt_defs edit history don't match\n";
-                    ss << "+++++++++++++ Saved/reloaded check pt file ++++++++++++++++++++++++++++\n";
-                    PrintStyle style(PrintStyle::MIGRATE);
-                    ss << reloaded_defs;
-                    ss << "++++++++++++++ theInMemoryDefs  ++++++++++++++++++++++++++++\n";
-                    ss << theInMemoryDefs;
-                    errorMsg_ += ss.str();
-                }
-            }
-            if (!reloaded_defs.compare_change_no(theInMemoryDefs)) {
-                errorMsg_ += "\nPersistHelper::reload_from_cereal_checkpt_file: Change numbers don't compare between "
-                             "reloaded_defs and theInMemoryDefs  \n";
-            }
-        }
-    }
-    catch (std::exception& e) {
-        errorMsg_ = "PersistHelper::reload_from_cereal_checkpt_file: " + string(e.what());
-    }
-
-    file_size_ = temporary.size();
-
-    return errorMsg_.empty();
-}
diff -pruN 5.12.4-1/ANode/test/parser/PersistHelper.hpp 5.13.0-1/ANode/test/parser/PersistHelper.hpp
--- 5.12.4-1/ANode/test/parser/PersistHelper.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/PersistHelper.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_test_PersistHelper_HPP
-#define ecflow_node_parser_test_PersistHelper_HPP
-
-#include <string>
-
-#include "ecflow/core/PrintStyle.hpp"
-
-class Defs;
-
-/// Given a in memory defs file, this class will write it to disk
-/// and reload the definition file structure and will then make a comparison
-/// to ensure they are the same
-class PersistHelper {
-public:
-    explicit PersistHelper(bool compare_edit_history = false) : compare_edit_history_(compare_edit_history) {}
-
-    bool
-    test_persist_and_reload(const Defs& theInMemoryDefs, PrintStyle::Type_t file_type_on_disk, bool do_compare = true);
-    bool test_defs_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare = true);
-    bool test_cereal_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare = true);
-    bool test_state_persist_and_reload_with_checkpt(const Defs& theInMemoryDefs);
-    const std::string& errorMsg() const { return errorMsg_; }
-
-    /// returns the file size of the temporary file created by:
-    ///   test_persist_and_reload(..) or test_cereal_checkpt_and_reload(..)
-    size_t file_size() const { return file_size_; }
-
-private:
-    bool reload_from_defs_file(const Defs& theInMemoryDefs,
-                               Defs& reloaded_defs,
-                               const std::string& filename,
-                               bool do_compare = true);
-    bool reload_from_cereal_checkpt_file(const Defs& theInMemoryDefs, Defs& reloaded_defs, bool do_compare = true);
-
-private:
-    PersistHelper(const PersistHelper&)                  = delete;
-    const PersistHelper& operator=(const PersistHelper&) = delete;
-
-private:
-    std::string errorMsg_;
-    size_t file_size_{0};
-    bool compare_edit_history_;
-};
-
-#endif /* ecflow_node_parser_test_PersistHelper_HPP */
diff -pruN 5.12.4-1/ANode/test/parser/TemporaryFile.cpp 5.13.0-1/ANode/test/parser/TemporaryFile.cpp
--- 5.12.4-1/ANode/test/parser/TemporaryFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TemporaryFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "TemporaryFile.hpp"
-
-TemporaryFile::TemporaryFile() : path_{fs::unique_path("tmp_%%%%-%%%%-%%%%-%%%%")} {
-}
-
-TemporaryFile::TemporaryFile(const std::string& pattern) : path_{fs::unique_path(pattern)} {
-}
-
-TemporaryFile::~TemporaryFile() {
-    try {
-        fs::remove(path_);
-    }
-    catch (...) {
-        // Nothing to do...
-    }
-}
diff -pruN 5.12.4-1/ANode/test/parser/TemporaryFile.hpp 5.13.0-1/ANode/test/parser/TemporaryFile.hpp
--- 5.12.4-1/ANode/test/parser/TemporaryFile.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TemporaryFile.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_node_parser_test_TemporaryFile_HPP
-#define ecflow_node_parser_test_TemporaryFile_HPP
-
-#include <string>
-
-#include "ecflow/core/Filesystem.hpp"
-
-class TemporaryFile {
-public:
-    TemporaryFile();
-    explicit TemporaryFile(const std::string& pattern);
-
-    ~TemporaryFile();
-
-    [[nodiscard]] inline std::string path() const { return path_.string(); }
-    [[nodiscard]] inline size_t size() const { return fs::file_size(path_); }
-
-private:
-    fs::path path_;
-};
-
-#endif /* ecflow_node_parser_test_TemporaryFile_HPP */
diff -pruN 5.12.4-1/ANode/test/parser/TestAutoAddExterns.cpp 5.13.0-1/ANode/test/parser/TestAutoAddExterns.cpp
--- 5.12.4-1/ANode/test/parser/TestAutoAddExterns.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestAutoAddExterns.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Parser)
-
-BOOST_AUTO_TEST_SUITE(T_AutoAddExterns)
-
-// Test that automatic add of externs
-BOOST_AUTO_TEST_CASE(test_auto_add_externs) {
-    std::string path = File::test_data("ANode/test/parser/data/single_defs/test_auto_add_extern.def", "parser");
-
-    size_t mega_file_size = fs::file_size(path);
-    cout << "AParser:: ...test_auto_add_externs " << path << " file_size(" << mega_file_size << ")\n";
-
-    Defs defs;
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(defs.restore(path, errorMsg, warningMsg), "Expected no errors, but found " << errorMsg);
-    BOOST_REQUIRE_MESSAGE(warningMsg.empty(), "Expected no warnings but found:\n" << warningMsg);
-
-    // Check number of extrens read in: Duplicate should be ignore
-    BOOST_REQUIRE_MESSAGE(defs.externs().size() == 11,
-                          "Expected 11 externs as starting point but found " << defs.externs().size() << "\n"
-                                                                             << defs << "\n");
-
-    // Test auto extern generation. Don't remove existing extern's
-    defs.auto_add_externs(false /* remove_existing_externs_first*/);
-    BOOST_REQUIRE_MESSAGE(defs.externs().size() == 11,
-                          "Expected 11, auto_add_extern(false) gave: " << defs.externs().size() << "\n"
-                                                                       << defs << "\n");
-
-    // By removing the externs read, in we can determine the real number of extern;s from
-    // parsing all the trigger expressions, and inlimit references
-    defs.auto_add_externs(true /* remove_existing_externs_first*/);
-    BOOST_REQUIRE_MESSAGE(defs.externs().size() == 10,
-                          "Expected 10 externs, since redundant externs removed, auto_add_extern(true) gave: "
-                              << defs.externs().size() << "\n"
-                              << defs << "\n");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/parser/TestDefsStructurePersistAndReload.cpp 5.13.0-1/ANode/test/parser/TestDefsStructurePersistAndReload.cpp
--- 5.12.4-1/ANode/test/parser/TestDefsStructurePersistAndReload.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestDefsStructurePersistAndReload.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,91 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "PersistHelper.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Parser)
-
-BOOST_AUTO_TEST_SUITE(T_DefsStructurePersisteAndReload)
-
-//=============================================================================
-// This test case will save the defs file in old style format
-// and the parse it back in. As we add different types to our defs fixture
-// we can automatically check that what we save can be parsed back in.
-// Specifically written to test the parser.
-// Note: Aliases are *NOT* written in the defs file BUT are when in MIGRATE
-BOOST_AUTO_TEST_CASE(test_defs_structure_persistence_and_reload) {
-    cout << "AParser:: ...test_defs_structure_persistence_and_reload\n";
-
-    MyDefsFixture theDefsFixture;
-    PersistHelper helper;
-    BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(theDefsFixture.defsfile_), helper.errorMsg());
-
-    // Note: Aliases are *NOT* written in PrintStyle::DEFS file
-    // Hence in order for this test to pass, we must delete the alias first & reset task alias_no
-    std::vector<alias_ptr> alias_vec;
-    theDefsFixture.defsfile_.get_all_aliases(alias_vec);
-    for (alias_ptr al : alias_vec) {
-        al->parent()->isTask()->reset_alias_number();
-        al->remove();
-    }
-    BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(theDefsFixture.defsfile_, PrintStyle::DEFS), helper.errorMsg());
-}
-
-BOOST_AUTO_TEST_CASE(test_defs_checkpt_persistence_and_reload) {
-    cout << "AParser:: ...test_defs_checkpt_persistence_and_reload\n";
-
-    MyDefsFixture theDefsFixture;
-    PersistHelper helper;
-    BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(theDefsFixture.defsfile_), helper.errorMsg());
-    BOOST_CHECK_MESSAGE(helper.test_defs_checkpt_and_reload(theDefsFixture.defsfile_), helper.errorMsg());
-}
-
-// This test is used to find a task given a path of the form:
-// 	  suite/family/task
-//    suite/family/family/task
-//
-void test_find_task_using_path(NodeContainer* f, const Defs& defs) {
-    BOOST_CHECK_MESSAGE(f == defs.findAbsNode(f->absNodePath()).get(),
-                        "Could not find path " << f->absNodePath() << "\n");
-
-    for (node_ptr t : f->nodeVec()) {
-        BOOST_CHECK_MESSAGE(t.get() == defs.findAbsNode(t->absNodePath()).get(),
-                            "Could not find path " << t->absNodePath() << "\n");
-        Family* family = t->isFamily();
-        if (family) {
-            test_find_task_using_path(family, defs);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_find_task_using_paths) {
-    cout << "AParser:: ...test_find_task_using_paths\n";
-
-    MyDefsFixture theDefsFixture;
-
-    const std::vector<suite_ptr>& suiteVec = theDefsFixture.defsfile_.suiteVec();
-    for (suite_ptr s : suiteVec) {
-        test_find_task_using_path(s.get(), theDefsFixture.defsfile_);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/parser/TestMementoPersistAndReload.cpp 5.13.0-1/ANode/test/parser/TestMementoPersistAndReload.cpp
--- 5.12.4-1/ANode/test/parser/TestMementoPersistAndReload.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestMementoPersistAndReload.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,472 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "PersistHelper.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Memento.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// ********************************************************************
-// These test are used to check that MIGRATE is equivalent to check pt
-// MIGRATE will be used for migration from old to new release
-// MIGRATE is essentially the defs structure with state.
-// The state is written out as comments
-// It is loaded like a normal Defs, the parser detects MIGRATE
-// and loads the state in.
-//
-// By default  persistence/MIGRATE *ONLY* writes the state when it not the default.
-// Hence the defaults should *NOT* change. These test will change the state
-// to a non default value.
-//
-// Write the Defs with state and the compare with in memory defs
-// Write the Defs as check pt an then compare with in memory defs
-// Finally compare the two *RELOADED* defs file.
-// ********************************************************************
-
-BOOST_AUTO_TEST_SUITE(U_Parser)
-
-BOOST_AUTO_TEST_SUITE(T_MementoPersistAndReload)
-
-BOOST_AUTO_TEST_CASE(test_memento_persist_and_reload) {
-    std::vector<ecf::Aspect::Type> aspects;
-    bool aspect_only = false;
-    cout << "AParser:: ...test_memento_persist_and_reload\n";
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        StateMemento memento2(NState::ABORTED);
-        defs.set_memento(&memento2, aspects, aspect_only);
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "StateMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        std::pair<NState::State, boost::posix_time::time_duration> state;
-        state.first  = NState::ABORTED;
-        state.second = boost::posix_time::time_duration(1, 1, 1, 0);
-        NodeStateMemento memento(state);
-        t->set_memento(&memento, aspects, aspect_only);
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeStateMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        NodeDefStatusDeltaMemento memento(DState::ABORTED);
-        t->set_memento(&memento, aspects, aspect_only);
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeDefStatusDeltaMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        SuspendedMemento memento(true);
-        t->set_memento(&memento, aspects, aspect_only);
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "SuspendedMemento failed: " << helper.errorMsg());
-
-        SuspendedMemento memento1;
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "SuspendedMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Event event(1);
-        NodeEventMemento memento(event);
-        t->set_memento(&memento, aspects, aspect_only); // add event
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeEventMemento failed: " << helper.errorMsg());
-
-        event.set_value(true);
-        NodeEventMemento memento1(event); // set event
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeEventMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Meter meter("meter", 0, 100);
-
-        NodeMeterMemento memento(meter);
-        t->set_memento(&memento, aspects, aspect_only); // add meter
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeMeterMemento failed: " << helper.errorMsg());
-
-        meter.set_value(100);
-        NodeMeterMemento memento1(meter); // change meter
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeMeterMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Label label("label", "xxx");
-
-        NodeLabelMemento memento(label);
-        t->set_memento(&memento, aspects, aspect_only); // add label;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeLabelMemento failed: " << helper.errorMsg());
-
-        label.set_new_value("yyy");
-        NodeLabelMemento memento1(label); // change label
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeLabelMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Expression exp("1 == 0");
-
-        NodeTriggerMemento memento(exp);
-        t->set_memento(&memento, aspects, aspect_only); // add trigger;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeTriggerMemento failed: " << helper.errorMsg());
-
-        exp.setFree();
-        NodeTriggerMemento memento1(exp); // free trigger
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeTriggerMemento failed: " << helper.errorMsg());
-
-        exp.clearFree();
-        NodeTriggerMemento memento2(exp); // clear trigger
-        t->set_memento(&memento2, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeTriggerMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Expression exp("1 == 0");
-
-        NodeCompleteMemento memento(exp);
-        t->set_memento(&memento, aspects, aspect_only); // add trigger;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeCompleteMemento failed: " << helper.errorMsg());
-
-        exp.setFree();
-        NodeCompleteMemento memento1(exp); // free trigger
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeCompleteMemento failed: " << helper.errorMsg());
-
-        exp.clearFree();
-        NodeCompleteMemento memento2(exp); // clear trigger
-        t->set_memento(&memento2, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeCompleteMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Repeat repeat(RepeatDate("YMD", 20090916, 20090916, 1));
-
-        NodeRepeatMemento memento(repeat);
-        t->set_memento(&memento, aspects, aspect_only); // add repeat;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeRepeatMemento failed: " << helper.errorMsg());
-
-        repeat.increment();
-        NodeRepeatMemento memento1(repeat); // change repeat
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeRepeatMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Repeat repeat(RepeatDateList("YMD", {20090916, 20090916}));
-
-        NodeRepeatMemento memento(repeat);
-        t->set_memento(&memento, aspects, aspect_only); // add repeat;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeRepeatMemento failed: " << helper.errorMsg());
-
-        repeat.increment();
-        NodeRepeatMemento memento1(repeat); // change repeat
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeRepeatMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Limit limit("suiteLimit", 10);
-
-        NodeLimitMemento memento(limit);
-        t->set_memento(&memento, aspects, aspect_only); // add limit;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeLimitMemento failed: " << helper.errorMsg());
-
-        std::set<std::string> paths;
-        paths.insert("/s1/t1");
-
-        limit.set_state(20, 2, paths);
-        NodeLimitMemento memento1(limit); // change limit
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeLimitMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        InLimit inlimit("suiteLimit", "/path/to/node", 2);
-
-        NodeInLimitMemento memento(inlimit);
-        t->set_memento(&memento, aspects, aspect_only); // add inlimit only, no state
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeInLimitMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        Variable variable("name", "value");
-
-        NodeVariableMemento memento(variable);
-        t->set_memento(&memento, aspects, aspect_only); // add variable;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeVariableMemento failed: " << helper.errorMsg());
-
-        variable.set_value("new value");
-        NodeVariableMemento memento1(variable); // change variable
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeVariableMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        ecf::LateAttr lateAttr;
-        lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
-        lateAttr.addActive(ecf::TimeSlot(3, 12));
-        lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
-
-        NodeLateMemento memento(lateAttr);
-        t->set_memento(&memento, aspects, aspect_only); // add late;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeLateMemento failed: " << helper.errorMsg());
-
-        lateAttr.setLate(true);
-        NodeLateMemento memento1(lateAttr); // change late
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeLateMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        ecf::TodayAttr attr(ecf::TimeSlot(10, 12));
-
-        NodeTodayMemento memento(attr);
-        t->set_memento(&memento, aspects, aspect_only); // add today;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeTodayMemento failed: " << helper.errorMsg());
-
-        attr.setFree();
-        NodeTodayMemento memento1(attr); // change today
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeTodayMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        ecf::TimeAttr attr(ecf::TimeSlot(10, 12));
-
-        NodeTimeMemento memento(attr);
-        t->set_memento(&memento, aspects, aspect_only); // add time;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeTimeMemento failed: " << helper.errorMsg());
-
-        attr.setFree();
-        NodeTimeMemento memento1(attr); // change time
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeTimeMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        DayAttr attr(DayAttr::MONDAY);
-
-        NodeDayMemento memento(attr);
-        t->set_memento(&memento, aspects, aspect_only); // add day;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeDayMemento failed: " << helper.errorMsg());
-
-        attr.setFree();
-        NodeDayMemento memento1(attr); // change day
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeDayMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        DateAttr attr(1, 2, 2009);
-
-        NodeDateMemento memento(attr);
-        t->set_memento(&memento, aspects, aspect_only); // add date;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeDateMemento failed: " << helper.errorMsg());
-
-        attr.setFree();
-        NodeDateMemento memento1(attr); // change date
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeDateMemento failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        ecf::CronAttr attr;
-        ecf::TimeSlot start(0, 0);
-        ecf::TimeSlot finish(10, 0);
-        ecf::TimeSlot incr(0, 5);
-        std::vector<int> weekdays;
-        for (int i = 0; i < 7; ++i)
-            weekdays.push_back(i);
-        std::vector<int> daysOfMonth;
-        for (int i = 1; i < 32; ++i)
-            daysOfMonth.push_back(i);
-        std::vector<int> months;
-        for (int i = 1; i < 13; ++i)
-            months.push_back(i);
-        attr.addTimeSeries(start, finish, incr);
-        attr.addWeekDays(weekdays);
-        attr.addDaysOfMonth(daysOfMonth);
-        attr.addMonths(months);
-
-        NodeCronMemento memento(attr);
-        t->set_memento(&memento, aspects, aspect_only); // add cron;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeCronMemento failed: " << helper.errorMsg());
-
-        attr.setFree();
-        NodeCronMemento memento1(attr); // change cron
-        t->set_memento(&memento1, aspects, aspect_only);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeCronMemento failed: " << helper.errorMsg());
-    }
-
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        node_ptr t      = suite->add_task("t1");
-
-        std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
-
-        ZombieAttr attr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10);
-
-        NodeZombieMemento memento(attr);
-        t->set_memento(&memento, aspects, aspect_only); // add zombie;
-
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "NodeZombieMemento failed: " << helper.errorMsg());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/parser/TestMigration.cpp 5.13.0-1/ANode/test/parser/TestMigration.cpp
--- 5.12.4-1/ANode/test/parser/TestMigration.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,619 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "PersistHelper.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/Memento.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-
-// ********************************************************************
-// These test are used to check that MIGRATE is equivalent to check pt
-// MIGRATE will be used for migration from old to new release
-// MIGRATE is essentially the defs structure with state.
-// The state is written out as comments
-// It is loaded like a normal Defs, the parser detects MIGRATE
-// and loads the state in.
-//
-// By default  persistence/MIGRATE *ONLY* writes the state when it not the default.
-// Hence the defaults should *NOT* change. These test will change the state
-// to a non default value.
-//
-// Write the Defs with state and the compare with in memory defs
-// Write the Defs as check pt an then compare with in memory defs
-// Finally compare the two *RELOADED* defs file.
-// ********************************************************************
-
-BOOST_AUTO_TEST_SUITE(U_Parser)
-
-BOOST_AUTO_TEST_SUITE(T_Migration)
-
-BOOST_AUTO_TEST_CASE(test_state_parser) {
-    cout << "AParser:: ...test_state_parser\n";
-    // **** The persistence will NOT write the defaults, hence we need to change the states
-    // **** to test the persistence
-    PersistHelper helper;
-    std::vector<Flag::Type> flag_list = Flag::list();
-    {
-        Defs defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Empty Defs failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-
-        // Change state other the default
-        defs.beginAll();
-        suite->set_state(NState::ABORTED);
-        for (auto& i : flag_list)
-            suite->flag().set(i);
-        suite->suspend();
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Add one suite failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        family_ptr f1   = suite->add_family("f1");
-
-        // Change state other the default
-        f1->set_state(NState::COMPLETE);
-        for (auto& i : flag_list)
-            f1->flag().set(i);
-        f1->suspend();
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Add one family failed: " << helper.errorMsg());
-
-        // Test multiple
-        suite->add_family("f2");
-        suite->add_family("f3");
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Add one family failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        family_ptr f1 = defs.add_suite("s1")->add_family("f1");
-        task_ptr t1   = f1->add_task("t1");
-
-        for (auto& i : flag_list)
-            t1->flag().set(i);
-        t1->suspend();
-        t1->set_state(NState::COMPLETE);
-
-        // Use memento to modify task state
-        SubmittableMemento memento("Jobs_password", "the_rid", "the abort  reason with spaces", 12);
-        std::vector<ecf::Aspect::Type> aspects;
-        t1->set_memento(&memento, aspects, false);
-
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Add one task failed: " << helper.errorMsg());
-
-        // Test multiple
-        f1->add_task("t2");
-        f1->add_task("t3");
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Add one task failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        task_ptr task = defs.add_suite("s1")->add_family("f1")->add_task("t1");
-        alias_ptr t1  = task->add_alias_only();
-        for (auto& i : flag_list)
-            t1->flag().set(i);
-        t1->suspend();
-        t1->set_state(NState::COMPLETE);
-        // Use memento to modify alias state
-        SubmittableMemento memento("Jobs_password", "the_rid", "the abort  reason with spaces", 12);
-        std::vector<ecf::Aspect::Type> aspects;
-        t1->set_memento(&memento, aspects, false);
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Add one alias failed: " << helper.errorMsg());
-
-        // Test multiple
-        task->add_alias_only();
-        task->add_alias_only();
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Add multiple alias failed: " << helper.errorMsg());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_state_node_attributes) {
-    cout << "AParser:: ...test_state_node_attributes\n";
-    PersistHelper helper;
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        task_ptr task   = suite->add_task("t1");
-        ecf::LateAttr lateAttr;
-        lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
-        lateAttr.addActive(ecf::TimeSlot(3, 12));
-        lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
-        lateAttr.setLate(true);
-        task->addLate(lateAttr);
-
-        ecf::LateAttr lateAttr1;
-        lateAttr1.addSubmitted(ecf::TimeSlot(3, 12));
-        lateAttr1.addActive(ecf::TimeSlot(3, 12));
-        lateAttr1.addComplete(ecf::TimeSlot(4, 12), false);
-        lateAttr1.setLate(true);
-        task_ptr task1 = suite->add_task("t2");
-        task1->addLate(lateAttr1);
-
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Late state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        task_ptr task = defs.add_suite("s1")->add_task("t1");
-        Meter meter("meter", 0, 100, 100);
-        meter.set_value(10);
-        task->addMeter(meter);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Meter state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        task_ptr task = defs.add_suite("s1")->add_task("t1");
-        Event event("event");
-        event.set_value(true);
-        Event event2(10, "event");
-        event2.set_value(true);
-        Event event3(10);
-        event3.set_value(true);
-        Event event4(10, "event4", true /*init value*/, true /*value*/);
-        Event event5(10, "event5", true /*init value*/, false /*value*/);
-        task->addEvent(event);
-        task->addEvent(event2);
-        task->addEvent(event3);
-        task->addEvent(event4);
-        task->addEvent(event5);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Event state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        family_ptr fam  = suite->add_family("f1");
-        task_ptr t      = fam->add_task("t");
-        std::vector<std::string> queue_items;
-        queue_items.emplace_back("001");
-        queue_items.emplace_back("002");
-        queue_items.emplace_back("003");
-        QueueAttr queue("queue", queue_items);
-        queue.active();
-        queue.active();
-        QueueAttr queue1("queue1", queue_items);
-        queue1.active();
-        suite->add_queue(queue);
-        suite->add_queue(queue1);
-        fam->add_queue(queue);
-        fam->add_queue(queue1);
-        t->add_queue(queue);
-        t->add_queue(queue1);
-        // PrintStyle::setStyle(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Queue state: failed: " << helper.errorMsg());
-    }
-    {
-        {
-            Defs defs;
-            task_ptr task = defs.add_suite("s1")->add_task("t1");
-            Label label("name", "value");
-            label.set_new_value("new  value");
-            task->addLabel(label);
-            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                                "Label state: failed: " << helper.errorMsg());
-        }
-        {
-            Defs defs;
-            suite_ptr suite = defs.add_suite("s1");
-            Label label("name", "value");
-            label.set_new_value("new  value");
-            suite->addLabel(label);
-            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                                "Label state: failed: " << helper.errorMsg());
-        }
-        {
-            Defs defs;
-            suite_ptr suite = defs.add_suite("s1");
-            Label label("name", "value\nvalue");
-            suite->addLabel(label);
-            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                                "Label state: failed: " << helper.errorMsg());
-        }
-        {
-            Defs defs;
-            suite_ptr suite = defs.add_suite("s1");
-            Label label("name", "value\nvalue");
-            label.set_new_value("value\nwith\nmany\nnewlines");
-            suite->addLabel(label);
-            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                                "Label state: failed: " << helper.errorMsg());
-        }
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        task_ptr t1     = suite->add_task("t1");
-        task_ptr t2     = suite->add_task("t2");
-        task_ptr t3     = suite->add_task("t3");
-        task_ptr t4     = suite->add_task("t4");
-        Limit limit("limit", 10);
-        limit.increment(1, t1->absNodePath());
-        limit.increment(1, t2->absNodePath());
-        limit.increment(1, t3->absNodePath());
-        limit.increment(1, t4->absNodePath());
-        suite->addLimit(limit);
-        //       PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Limit state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        task_ptr t1     = suite->add_task("t1");
-        InLimit inlimit1("limit", "/s1", 10, true); // limit has state when 'limit this node only' is set
-        inlimit1.set_incremented(true);             // the state
-        InLimit inlimit2("limit2", "/s1", 10);
-        t1->addInLimit(inlimit1);
-        t1->addInLimit(inlimit2);
-
-        //       PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "InLimit state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        task_ptr t1     = suite->add_task("t1");
-        task_ptr t2     = suite->add_task("t2");
-        task_ptr t3     = suite->add_task("t3");
-        task_ptr t4     = suite->add_task("t4");
-        task_ptr t5     = suite->add_task("t5");
-        task_ptr t6     = suite->add_task("t6");
-
-        std::vector<std::string> stringList;
-        stringList.reserve(3);
-        stringList.emplace_back("20130101");
-        stringList.emplace_back("20130201");
-        stringList.emplace_back("20130301");
-
-        RepeatEnumerated rep("AEnum", stringList);
-        rep.increment();
-        t1->addRepeat(rep);
-
-        RepeatString rep2("AEnum", stringList);
-        rep2.increment();
-        t2->addRepeat(rep2);
-
-        RepeatDate rep3("YMD", 20090916, 20090916, 1);
-        rep3.increment();
-        t3->addRepeat(rep3);
-
-        RepeatInteger rep4("rep", 0, 100, 1);
-        rep4.increment();
-        t4->addRepeat(rep4);
-        t4->increment_repeat();
-
-        RepeatDay rep5(2);
-        rep5.increment();
-        t5->addRepeat(rep5);
-
-        RepeatDateList rep6("YMD", {20090916, 20090916});
-        rep6.increment();
-        t6->addRepeat(rep6);
-
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Repeat state: failed: " << helper.errorMsg());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_state_time_attributes) {
-    cout << "AParser:: ...test_state_time_attributes\n";
-    PersistHelper helper;
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        suite->begin();
-        task_ptr task = suite->add_task("t1");
-        TimeAttr time(10, 10);
-        time.setFree();
-        time.miss_next_time_slot();
-        TimeAttr time2(10, 10, true);
-        time2.calendarChanged(suite->calendar());
-        time2.setFree();
-        time2.miss_next_time_slot();
-        TimeAttr time3(TimeSlot(10, 10), TimeSlot(12, 10), TimeSlot(0, 10), true);
-        time3.calendarChanged(suite->calendar());
-        time3.setFree();
-        time3.miss_next_time_slot();
-
-        task->addTime(time);
-        task->addTime(time2);
-        task->addTime(time3);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Time state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        suite->begin();
-        task_ptr task = suite->add_task("t1");
-        TodayAttr time(10, 10);
-        time.setFree();
-        time.miss_next_time_slot();
-        TodayAttr time2(10, 10, true);
-        time2.calendarChanged(suite->calendar());
-        time2.setFree();
-        time2.miss_next_time_slot();
-        TodayAttr time3(TimeSlot(10, 10), TimeSlot(12, 10), TimeSlot(0, 10), true);
-        time3.calendarChanged(suite->calendar());
-        time3.setFree();
-        time3.miss_next_time_slot();
-        task->addToday(time);
-        task->addToday(time2);
-        task->addToday(time3);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Today state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        task_ptr task = defs.add_suite("s1")->add_task("t1");
-        DayAttr day;
-        DayAttr day1;
-        day1.setFree();
-        DayAttr day2(DayAttr::FRIDAY);
-        day2.setFree();
-        task->addDay(day);
-        task->addDay(day1);
-        task->addDay(day2);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Day state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        task_ptr task = defs.add_suite("s1")->add_task("t1");
-        DateAttr d;
-        DateAttr d1;
-        d1.setFree();
-        DateAttr d2(1, 1, 2012);
-        d2.setFree();
-        DateAttr d3(0, 0, 2012);
-        d3.setFree();
-        task->addDate(d);
-        task->addDate(d1);
-        task->addDate(d2);
-        task->addDate(d3);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Date state: failed: " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        suite_ptr suite = defs.add_suite("s1");
-        suite->begin();
-        task_ptr task  = suite->add_task("t1");
-        task_ptr task2 = suite->add_task("t2");
-
-        ecf::CronAttr cronAttr;
-        ecf::TimeSlot start(0, 0);
-        ecf::TimeSlot finish(10, 0);
-        ecf::TimeSlot incr(0, 5);
-        std::vector<int> weekdays;
-        for (int i = 0; i < 7; ++i)
-            weekdays.push_back(i);
-        std::vector<int> daysOfMonth;
-        for (int i = 1; i < 32; ++i)
-            daysOfMonth.push_back(i);
-        std::vector<int> months;
-        for (int i = 1; i < 13; ++i)
-            months.push_back(i);
-        cronAttr.addTimeSeries(start, finish, incr);
-        cronAttr.addWeekDays(weekdays);
-        cronAttr.addDaysOfMonth(daysOfMonth);
-        cronAttr.addMonths(months);
-        cronAttr.setFree();
-        task->addCron(cronAttr);
-
-        // Change TimeSeries state
-        TimeSeries ts(start, finish, incr, true);
-        ts.calendarChanged(suite->calendar());
-        ts.miss_next_time_slot();
-        cronAttr.addTimeSeries(ts);
-        task2->addCron(cronAttr);
-
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Date state: failed: " << helper.errorMsg());
-    }
-
-    // ZombieAttr do not have any changeable state
-}
-
-BOOST_AUTO_TEST_CASE(test_state_edit_history) {
-    cout << "AParser:: ...test_state_edit_history\n";
-    PersistHelper helper(true /* compare edit History */);
-    Defs defs;
-    suite_ptr suite = defs.add_suite("s1");
-    defs.add_edit_history(suite->absNodePath(), "request1 with single spaces");
-    defs.add_edit_history(suite->absNodePath(), "request2 with double  spaces");
-    defs.add_edit_history(suite->absNodePath(), "request3_with_no_spaces!|?<>$%^&*()_{}:@<>?");
-    suite_ptr suite2 = defs.add_suite("s2");
-    defs.add_edit_history(suite2->absNodePath(), "request1 with single spaces");
-    defs.add_edit_history(suite2->absNodePath(), "request2 with double  spaces");
-    defs.add_edit_history(suite2->absNodePath(), "request3_with_no_spaces!|?<>$%^&*()_{}:@<>?");
-    //   PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-    BOOST_REQUIRE_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                          "Edit history failed: " << helper.errorMsg());
-}
-
-static std::string dump_edit_history(const std::unordered_map<std::string, std::vector<std::string>>& edit_history) {
-    std::stringstream ss;
-    for (const auto& i : edit_history) {
-        ss << "node: " << i.first << "\n";
-        for (const auto& h : i.second) {
-            ss << "  " << h << "\n";
-        }
-    }
-    return ss.str();
-}
-
-BOOST_AUTO_TEST_CASE(test_state_edit_history_pruning) {
-    cout << "AParser:: ...test_state_edit_history_pruning\n";
-    Defs defs;
-    suite_ptr suite = defs.add_suite("s1");
-    defs.add_edit_history(suite->absNodePath(), "MSG:[07:36:05 10.3.2016] --requeue force /s1  :maj");
-    defs.add_edit_history(suite->absNodePath(), "MSG:[09:15:33 26.8.2016] --run /s1  :mab");
-    defs.add_edit_history(suite->absNodePath(), "MSG:[06:45:18 26.8.2017] --force=queued /s1  :ma0");
-    suite_ptr suite2 = defs.add_suite("s2");
-    defs.add_edit_history(suite2->absNodePath(), "MSG:[19:13:44 21.6.2016] --suspend /s2  :ma");
-    defs.add_edit_history(suite2->absNodePath(), "MSG:[11:28:12 6.10.2016] --requeue abort /s2  :ma");
-    defs.add_edit_history(suite2->absNodePath(), "MSG:[09:15:33 26.8.2016] --run /s2  :mab");
-    //   PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-    //   cout << dump_edit_history(defs.get_edit_history()) << "\n";
-
-    std::string tmpFilename = "test_state_edit_history_pruning.def";
-    defs.save_as_checkpt(tmpFilename);
-
-    {
-        // If any edit history is older than 1 day, then prune
-        Defs reloaded_defs;
-        reloaded_defs.ecf_prune_node_log(1);
-
-        std::string errorMsg, warningMsg;
-        BOOST_REQUIRE_MESSAGE(reloaded_defs.restore(tmpFilename, errorMsg, warningMsg),
-                              "RE-PARSE failed for " << tmpFilename);
-
-        const std::unordered_map<std::string, std::vector<std::string>>& edit_history =
-            reloaded_defs.get_edit_history();
-        BOOST_REQUIRE_MESSAGE(edit_history.empty(),
-                              "Expected no edit history after pruning, but found:\n"
-                                  << dump_edit_history(edit_history));
-    }
-
-    std::remove(tmpFilename.c_str());
-}
-
-BOOST_AUTO_TEST_CASE(test_state_edit_history_pruning2) {
-    cout << "AParser:: ...test_state_edit_history_pruning2\n";
-
-    // Create edit history for today, this should not be affected by pruning
-    date todays_date_in_utc = day_clock::universal_day();
-    std::string history     = "MSG:[07:36:05 ";
-    history += ecf::convert_to<std::string>(todays_date_in_utc.day());
-    history += ".";
-    history += ecf::convert_to<std::string>(todays_date_in_utc.month());
-    history += ".";
-    history += ecf::convert_to<std::string>(todays_date_in_utc.year());
-    history += "] --requeue force /s1  :maj";
-
-    Defs defs;
-    suite_ptr suite = defs.add_suite("s1");
-    defs.add_edit_history(suite->absNodePath(), history);
-    defs.add_edit_history(suite->absNodePath(), history);
-    defs.add_edit_history(suite->absNodePath(), history);
-    //   PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-    //   cout << dump_edit_history(defs.get_edit_history()) << "\n";
-
-    std::string tmpFilename = "test_state_edit_history_pruning2.def";
-    defs.save_as_checkpt(tmpFilename);
-
-    {
-        // Since the history is todays it should be preserved, and not affected by pruning
-        Defs reloaded_defs;
-        reloaded_defs.ecf_prune_node_log(1);
-
-        std::string errorMsg, warningMsg;
-        BOOST_REQUIRE_MESSAGE(reloaded_defs.restore(tmpFilename, errorMsg, warningMsg),
-                              "RE-PARSE failed for " << tmpFilename);
-
-        const std::unordered_map<std::string, std::vector<std::string>>& edit_history =
-            reloaded_defs.get_edit_history();
-        //      cout << dump_edit_history(defs.get_edit_history()) << "\n";
-
-        BOOST_REQUIRE_MESSAGE(!edit_history.empty(), "Expected edit history but found none");
-    }
-
-    std::remove(tmpFilename.c_str());
-}
-
-BOOST_AUTO_TEST_CASE(test_server_state) {
-    cout << "AParser:: ...test_server_state\n";
-    PersistHelper helper(true /* compare edit History */);
-    {
-        Defs defs;
-        defs.set_server().set_state(SState::HALTED);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Set server state failed " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        defs.set_server().set_state(SState::RUNNING);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Set server state failed " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        defs.set_server().set_state(SState::SHUTDOWN);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Set server state failed " << helper.errorMsg());
-    }
-    {
-        Defs defs;
-        std::vector<Variable> vec;
-        vec.emplace_back("name", "value1");
-        vec.emplace_back("name2", "val with 'spaces' ");
-        vec.emplace_back("name3", "");
-        defs.set_server().set_user_variables(vec);
-        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
-                            "Set server variables failed " << helper.errorMsg());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_state_fixture_defs) {
-    cout << "AParser:: ...test_state_fixture_defs\n";
-    PersistHelper helper;
-    MyDefsFixture theDefsFixture;
-    BOOST_REQUIRE_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(theDefsFixture.defsfile_),
-                          "Fixture failed: " << helper.errorMsg());
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/parser/TestParser.cpp 5.13.0-1/ANode/test/parser/TestParser.cpp
--- 5.12.4-1/ANode/test/parser/TestParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,233 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "PersistHelper.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-using namespace ecf;
-
-std::vector<std::string> defs_with_expected_warnings() {
-    return {"limit/limit3.def"};
-}
-
-BOOST_AUTO_TEST_SUITE(U_Parser)
-
-BOOST_AUTO_TEST_SUITE(T_Parser)
-
-void test_defs(const std::string& directory, bool pass) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-    DebugEquality debug_equality; // only as affect in DEBUG build
-
-    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (fs::is_directory(dir_itr->status())) {
-                test_defs(relPath.string(), pass);
-                continue;
-            }
-
-            // std::cout << "......Parsing file " << relPath.string() << "\n";
-
-            Defs defs;
-            DefsStructureParser parser(&defs, relPath.string());
-
-            std::string errorMsg, warningMsg;
-            bool parsedOk = parser.doParse(errorMsg, warningMsg);
-            if (pass) {
-                // Test expected to pass
-                BOOST_CHECK_MESSAGE(parsedOk, "Failed to parse file " << relPath << "\n" << errorMsg);
-
-                if (parsedOk) {
-                    // Check triggers and limits
-                    std::string err_msg, warn_msg;
-                    defs.check(err_msg, warn_msg);
-                    BOOST_CHECK_MESSAGE(err_msg.empty(),
-                                        "Expected no errors but found:" << err_msg << "File: " << relPath.string());
-
-                    // expect warnings for some file:
-                    bool ignore = false;
-                    for (auto path : defs_with_expected_warnings()) {
-                        if (relPath.string().find(path) != std::string::npos) {
-                            ignore = true;
-                            break;
-                        }
-                    }
-                    if (!ignore)
-                        BOOST_CHECK_MESSAGE(warn_msg.empty(),
-                                            "Expected no warnings but found:" << warn_msg
-                                                                              << "File: " << relPath.string());
-
-                    // Write parsed file to a temporary file on disk, and reload, then compare defs, should be the same
-                    PersistHelper helper;
-                    BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, parser.get_file_type()),
-                                        relPath.string() << " " << helper.errorMsg());
-                    BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(defs),
-                                        relPath.string() << " " << helper.errorMsg());
-
-                    // test copy constructor
-                    Defs copy_of_defs = Defs(defs);
-                    BOOST_CHECK_MESSAGE(copy_of_defs == defs, "Error copy constructor failed " << relPath);
-
-                    // Test parse by string is same as parsing by file:
-                    {
-                        std::string contents;
-                        BOOST_CHECK_MESSAGE(File::open(relPath.string(), contents),
-                                            "Error could not open file " << relPath);
-                        // cout << "parsing file " << relPath << " by string\n";
-
-                        Defs defs2;
-                        std::string errorMsg2, warningMsg2;
-                        BOOST_CHECK_MESSAGE(defs2.restore_from_string(contents, errorMsg2, warningMsg2),
-                                            "restore from string failed for file " << relPath << "\n"
-                                                                                   << errorMsg2);
-                        BOOST_CHECK_MESSAGE(defs2 == defs,
-                                            "Parse by string != parse by filename for file:\n"
-                                                << relPath);
-                    }
-
-                    // Make sure all nodes can be found
-                    std::vector<Node*> all_nodes;
-                    defs.getAllNodes(all_nodes);
-                    for (auto node : all_nodes) {
-                        node_ptr found_node = defs.findAbsNode(node->absNodePath());
-                        BOOST_CHECK_MESSAGE(found_node.get(), "Could not find node " << node->debugNodePath());
-                        BOOST_CHECK_MESSAGE(found_node.get() == node,
-                                            " Expected to find " << node->debugNodePath() << " but found "
-                                                                 << found_node->debugNodePath());
-                    }
-                }
-            }
-            else {
-                // test expected to fail
-                if (parsedOk) {
-                    // Check triggers and limits
-                    std::string err_msg, warn_msg;
-                    defs.check(err_msg, warn_msg);
-                    BOOST_CHECK_MESSAGE(!err_msg.empty() || !warn_msg.empty(),
-                                        "Expected problems with trigger/limits but found none for file" << relPath
-                                                                                                        << "\n");
-                }
-                else {
-                    BOOST_CHECK_MESSAGE(!parsedOk, "Parse expected to fail for " << relPath << "\n" << errorMsg);
-                }
-            }
-        }
-        catch (const std::exception& ex) {
-            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_for_good_defs) {
-    cout << "AParser:: ...test_parsing_for_good_defs\n";
-
-    std::string path = File::test_data("ANode/test/parser/data/good_defs", "parser");
-
-    // All the defs in this directory are expected to pass
-    test_defs(path, true);
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_for_bad_defs) {
-    cout << "AParser:: ...test_parsing_for_bad_defs\n";
-
-    std::string path = File::test_data("ANode/test/parser/data/bad_defs", "parser");
-
-    // All the defs in this directory are expected to fail
-    test_defs(path, false);
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_for_good_defs_state) {
-    cout << "AParser:: ...test_parsing_for_good_defs_state\n";
-
-    std::string path = File::test_data("ANode/test/parser/data/good_defs_state", "parser");
-
-    // All the defs in this directory are expected to pass
-    test_defs(path, true);
-}
-
-void test_node_defs(const std::string& directory, bool pass) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (fs::is_directory(dir_itr->status())) {
-                test_node_defs(relPath.string(), pass);
-                continue;
-            }
-
-            // std::cout << "......Parsing file " << relPath.string() << "\n";
-            std::string file_contents;
-            if (!ecf::File::open(relPath.string(), file_contents)) {
-                std::cout << "......Could not open file" << relPath.string() << "\n";
-                continue;
-            }
-
-            // Parse string as a standalone node.
-            DefsStructureParser parser(file_contents);
-            std::string errorMsg, warningMsg;
-            bool parsedOk = parser.doParse(errorMsg, warningMsg);
-            if (pass) {
-                // Test expected to pass
-                BOOST_CHECK_MESSAGE(parsedOk, "Failed to parse file " << relPath << "\n" << errorMsg);
-                BOOST_CHECK_MESSAGE(parser.the_node_ptr(), "Failed to parse file " << relPath << "\n" << errorMsg);
-                // PrintStyle print_style(PrintStyle::MIGRATE);
-                // parser.the_node_ptr()->print(cout);
-            }
-            else {
-                // test expected to fail
-                // std::cout << errorMsg << "\n";
-                BOOST_CHECK_MESSAGE(!parser.the_node_ptr(),
-                                    "Parse expected to fail for " << relPath << "\n"
-                                                                  << errorMsg);
-            }
-        }
-        catch (const std::exception& ex) {
-            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_parsing_node) {
-    cout << "AParser:: ...test_parsing_node\n";
-
-    std::string path = File::test_data("ANode/test/parser/data/good_node_defs", "parser");
-
-    // All the defs in this directory are expected to pass
-    test_node_defs(path, true);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/parser/TestParserPerformance_main.cpp 5.13.0-1/ANode/test/parser/TestParserPerformance_main.cpp
--- 5.12.4-1/ANode/test/parser/TestParserPerformance_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestParserPerformance_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_ParserPerformance
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/ANode/test/parser/TestParser_main.cpp 5.13.0-1/ANode/test/parser/TestParser_main.cpp
--- 5.12.4-1/ANode/test/parser/TestParser_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestParser_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Parser
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/ANode/test/parser/TestSingleDefsFile.cpp 5.13.0-1/ANode/test/parser/TestSingleDefsFile.cpp
--- 5.12.4-1/ANode/test/parser/TestSingleDefsFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestSingleDefsFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,325 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-#include <string>
-
-#include <boost/chrono.hpp>
-#include <boost/test/unit_test.hpp>
-#include <boost/timer/timer.hpp>
-
-#include "PersistHelper.hpp"
-#include "TemporaryFile.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/NodeContainer.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(U_Parser)
-
-BOOST_AUTO_TEST_SUITE(T_SingleDefsFile)
-
-// This test is used to find a task given a path of the form:
-//     suite/family/task
-//     suite/family/family/task
-void test_find_task_using_path(NodeContainer* f, const Defs& defs) {
-    BOOST_CHECK_MESSAGE(f == defs.findAbsNode(f->absNodePath()).get(),
-                        "Could not find path " << f->absNodePath() << "\n");
-
-    for (node_ptr t : f->nodeVec()) {
-        BOOST_CHECK_MESSAGE(t.get() == defs.findAbsNode(t->absNodePath()).get(),
-                            "Could not find path " << t->absNodePath() << "\n");
-        Family* family = t->isFamily();
-        if (family) {
-            test_find_task_using_path(family, defs);
-        }
-    }
-}
-
-// Create derived class, so that we can time the parse only
-// i.e ignore expression build/checking and limit checking
-class TestDefsStructureParser : public DefsStructureParser {
-public:
-    TestDefsStructureParser(Defs* defsfile, const std::string& file_name) : DefsStructureParser(defsfile, file_name) {}
-    bool do_parse_file(std::string& errorMsg) { return DefsStructureParser::do_parse_file(errorMsg); }
-};
-
-double get_seconds(const boost::timer::nanosecond_type& elapsed) {
-    return static_cast<double>(boost::chrono::nanoseconds(elapsed).count()) * boost::chrono::nanoseconds::period::num /
-           boost::chrono::nanoseconds::period::den;
-}
-
-BOOST_AUTO_TEST_CASE(test_single_defs) {
-    boost::timer::auto_cpu_timer auto_cpu_timer;
-
-    std::string path      = File::test_data("ANode/test/parser/data/single_defs/mega.def", "parser");
-    size_t mega_file_size = fs::file_size(path);
-    cout << "AParser:: ...test_single_defs " << path << " file_size(" << mega_file_size << ")\n";
-
-    // Time parse/resolve dependencies: This will need to be #defined depending on the platform
-    // Change for file_iterator to plain string halved the time taken to load operation suite
-    boost::timer::cpu_timer timer;
-
-#ifdef DEBUG
-    #if defined(HPUX) || defined(_AIX)
-    double expectedTimeForParse                   = 15.0;
-    double expectedTimeForParseOnly               = 10.0;
-    double expectedTimeForResolveDependencies     = 3.5; // this is time for 10 job submissions
-    double checkExprAndLimits                     = 1.0;
-    double expectedTimeForFindAllPaths            = 7.2;
-    double expectedTimeForDefsPersistOnly         = 6;
-    double expectedTimeForDefsPersistAndReload    = 24;
-    double expectedTimeForCheckPtPersistAndReload = 27;
-    #else
-    double expectedTimeForParse                   = 4.5;
-    double expectedTimeForParseOnly               = 2.0;
-    double expectedTimeForResolveDependencies     = 0.5; // this is time for 10 job submissions
-    double checkExprAndLimits                     = 0.5;
-    double expectedTimeForFindAllPaths            = 1.2;
-    double expectedTimeForDefsPersistOnly         = 2;
-    double expectedTimeForDefsPersistAndReload    = 4.5;
-    double expectedTimeForCheckPtPersistAndReload = 8.0;
-    #endif
-#else
-    #if defined(HPUX) || defined(_AIX)
-    double expectedTimeForParse                   = 7.8;
-    double expectedTimeForParseOnly               = 5.0;
-    double expectedTimeForResolveDependencies     = 3.5; // this is time for 10 job submissions
-    double checkExprAndLimits                     = 1.0;
-    double expectedTimeForFindAllPaths            = 4.5;
-    double expectedTimeForDefsPersistOnly         = 3.5;
-    double expectedTimeForDefsPersistAndReload    = 9.5;
-    double expectedTimeForCheckPtPersistAndReload = 11.5;
-    #else
-    double expectedTimeForParse                   = 1.2;
-    double expectedTimeForParseOnly               = 0.6;
-    double expectedTimeForResolveDependencies     = 0.2; // this is time for 10 job submissions
-    double checkExprAndLimits                     = 0.1;
-    double expectedTimeForFindAllPaths            = 0.58;
-    double expectedTimeForDefsPersistOnly         = 0.4;
-    double expectedTimeForDefsPersistAndReload    = 1.4;
-    double expectedTimeForCheckPtPersistAndReload = 1.6;
-    #endif
-#endif
-    // ****************************************************************************************
-    // Please note: that for Parsing: that the predominate time is taken in creating the AST/ and checking
-
-    /// If this is moved below, we get some caching affect, with the persist and reload timing
-    Defs defs;
-    {
-        timer.start();
-        std::string errorMsg, warningMsg;
-        BOOST_REQUIRE_MESSAGE(defs.restore(path, errorMsg, warningMsg), errorMsg);
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForParse,
-                            "Performance regression, expected < " << expectedTimeForParse
-                                                                  << " seconds for parse/node tree creation but found "
-                                                                  << timer.format(3, Str::cpu_timer_format()));
-        cout << " Parsing Node tree and AST creation time                = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << expectedTimeForParse << ")" << endl;
-    }
-    {
-        Defs local_defs;
-        timer.start();
-        TestDefsStructureParser checkPtParser(&local_defs, path);
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(checkPtParser.do_parse_file(errorMsg), errorMsg);
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForParse,
-                            "Performance regression, expected < " << expectedTimeForParseOnly
-                                                                  << " seconds for parse/node tree creation but found "
-                                                                  << timer.format(3, Str::cpu_timer_format()));
-        cout << " Parsing Node tree *only* time                          = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << expectedTimeForParseOnly << ")" << endl;
-    }
-    {
-        timer.start();
-        for (suite_ptr s : defs.suiteVec()) {
-            test_find_task_using_path(s.get(), defs);
-        }
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForFindAllPaths,
-                            "Performance regression, expected < " << expectedTimeForFindAllPaths
-                                                                  << " seconds to find all paths, but found "
-                                                                  << timer.format(3, Str::cpu_timer_format()));
-        cout << " Test all paths can be found. time taken                = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << expectedTimeForFindAllPaths << ")" << endl;
-    }
-
-    {
-        // Test time for persisting to defs file only
-        TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
-
-        timer.start();
-        PrintStyle style(PrintStyle::DEFS);
-        std::ofstream ofs(temporary.path());
-        ofs << defs;
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistOnly,
-                            "Performance regression, expected < " << expectedTimeForDefsPersistOnly
-                                                                  << " to persist defs file, but found "
-                                                                  << timer.format(3, Str::cpu_timer_format()));
-        cout << " Persist only, time taken                               = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << expectedTimeForDefsPersistOnly << ")" << endl;
-    }
-
-    {
-        // may need to comment out output for large differences. Will double the time.
-        timer.start();
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::DEFS), helper.errorMsg());
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistAndReload,
-                            "Performance regression, expected < " << expectedTimeForDefsPersistAndReload
-                                                                  << " seconds to persist and reload, but found "
-                                                                  << timer.format(3, Str::cpu_timer_format()));
-        cout << " Persist and reload(DEFS) and compare, time taken       = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << expectedTimeForDefsPersistAndReload << ")"
-             << " file_size(" << helper.file_size() << ")" << endl;
-    }
-    {
-        timer.start();
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::STATE), helper.errorMsg());
-        cout << " Persist and reload(STATE) and compare, time taken      = " << timer.format(3, Str::cpu_timer_format())
-             << " file_size(" << helper.file_size() << ")" << endl;
-    }
-    {
-        timer.start();
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::MIGRATE), helper.errorMsg());
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistAndReload,
-                            "Performance regression, expected < "
-                                << expectedTimeForDefsPersistAndReload
-                                << " seconds to persist and reload *state*, but found "
-                                << timer.format(3, Str::cpu_timer_format()));
-        cout << " Persist and reload(MIGRATE) and compare, time taken    = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << expectedTimeForDefsPersistAndReload << ")"
-             << " file_size(" << helper.file_size() << ")" << endl;
-
-        // each platform will have a slightly different size, since the server environment variables
-        // will be different, i.e host, pid, i.e check point etc, encompasses the host name, which will be different
-        BOOST_CHECK_MESSAGE(helper.file_size() <= 6679000,
-                            "File size regression expected <= 6679000 but found " << helper.file_size());
-    }
-    {
-        timer.start();
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::NET), helper.errorMsg());
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistAndReload,
-                            "Performance regression, expected < "
-                                << expectedTimeForDefsPersistAndReload
-                                << " seconds to persist and reload *state*, but found "
-                                << timer.format(3, Str::cpu_timer_format()));
-        cout << " Persist and reload(NET) and compare, time taken        = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << expectedTimeForDefsPersistAndReload << ")"
-             << " file_size(" << helper.file_size() << ")" << endl;
-
-        // each platform will have a slightly different size, since the server environment variables
-        // will be different, i.e host, pid, i.e check point etc, encompasses the host name, which will be different
-        BOOST_CHECK_MESSAGE(helper.file_size() <= 6679000,
-                            "File size regression expected <= 6679000 but found " << helper.file_size());
-    }
-
-    {
-        timer.start();
-        PersistHelper helper;
-        BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(defs, true), helper.errorMsg());
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForCheckPtPersistAndReload,
-                            "Performance regression, expected < " << expectedTimeForCheckPtPersistAndReload
-                                                                  << " seconds to persist and reload, but found "
-                                                                  << timer.format(3, Str::cpu_timer_format()));
-        cout << " Checkpt(CEREAL) and reload and compare, time taken     = ";
-        cout << timer.format(3, Str::cpu_timer_format()) << " < limit(" << expectedTimeForCheckPtPersistAndReload << ")"
-             << " file_size(" << helper.file_size() << ")" << endl;
-    }
-
-    {
-        // Time how long it takes for job submission. Must call begin on all suites first.
-        timer.start();
-        defs.beginAll();
-        int count = 10;
-        JobsParam jobsParam; // default is *not* to create jobs, and *not* to spawn jobs, hence only used in testing
-        Jobs jobs(&defs);
-        for (int i = 0; i < count; i++) {
-            jobs.generate(jobsParam);
-        }
-        cout << " " << count
-             << " jobSubmissions                                      = " << timer.format(3, Str::cpu_timer_format())
-             << "s jobs:" << jobsParam.submitted().size() << " < limit(" << expectedTimeForResolveDependencies << ")"
-             << endl;
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForResolveDependencies,
-                            "jobSubmission Performance regression, expected < "
-                                << expectedTimeForResolveDependencies
-                                << " seconds for resolving dependencies but found "
-                                << timer.format(3, Str::cpu_timer_format()));
-    }
-
-    {
-        // Time how long it takes for post process
-        timer.start();
-        string errorMsg, warningMsg;
-        BOOST_CHECK(defs.check(errorMsg, warningMsg));
-        cout << " Defs::check (inlimit resolution)                       = " << timer.format(3, Str::cpu_timer_format())
-             << " < limit(" << checkExprAndLimits << ")" << endl;
-        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < checkExprAndLimits,
-                            "Defs::check Performance regression, expected < "
-                                << checkExprAndLimits << " seconds for resolving dependencies but found "
-                                << timer.format(3, Str::cpu_timer_format()));
-    }
-
-    {
-        // Time how long it takes to delete all nodes/ references. Delete all tasks and then suites/families.
-        timer.start();
-        std::vector<Task*> tasks;
-        defs.getAllTasks(tasks);
-        BOOST_CHECK_MESSAGE(tasks.size() > 0, "Expected > 0 tasks but found " << tasks.size());
-        for (Task* t : tasks) {
-            BOOST_REQUIRE_MESSAGE(defs.deleteChild(t), " Failed to delete task");
-        }
-        tasks.clear();
-        defs.getAllTasks(tasks);
-        BOOST_REQUIRE_MESSAGE(tasks.empty(), "Expected all tasks to be deleted but found " << tasks.size());
-
-        std::vector<suite_ptr> vec = defs.suiteVec(); // make a copy, to avoid invalidating iterators
-        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 Suites but found " << vec.size());
-        for (suite_ptr s : vec) {
-            std::vector<node_ptr> familyVec = s->nodeVec(); // make a copy, to avoid invalidating iterators
-            for (node_ptr f : familyVec) {
-                BOOST_REQUIRE_MESSAGE(defs.deleteChild(f.get()), " Failed to delete family");
-            }
-            BOOST_REQUIRE_MESSAGE(s->nodeVec().empty(),
-                                  "Expected all Families to be deleted but found " << s->nodeVec().size());
-            BOOST_REQUIRE_MESSAGE(defs.deleteChild(s.get()), " Failed to delete suite");
-        }
-        BOOST_REQUIRE_MESSAGE(defs.suiteVec().empty(),
-                              "Expected all Suites to be deleted but found " << defs.suiteVec().size());
-
-        cout << " time for deleting all nodes                            = " << timer.format(3, Str::cpu_timer_format())
-             << endl;
-    }
-
-    // Explicitly destroy, To keep valgrind happy
-    Log::destroy();
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/parser/TestVariableParsing.cpp 5.13.0-1/ANode/test/parser/TestVariableParsing.cpp
--- 5.12.4-1/ANode/test/parser/TestVariableParsing.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/TestVariableParsing.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,75 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Parser)
-
-BOOST_AUTO_TEST_SUITE(T_VariableParsing)
-
-BOOST_AUTO_TEST_CASE(test_single_defs) {
-
-    cout << "AParser:: ...test_variable  \n";
-
-    std::string path = File::test_data("ANode/test/parser/data/good_defs/edit/edit.def", "parser");
-
-    Defs defs;
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(defs.restore(path, errorMsg, warningMsg), errorMsg);
-
-    // suite edit
-    //     edit ECF_INCLUDE /home/ma/map/sms/example/x                  # comment line
-    //     edit ECF_FILES   /home/ma/map/sms/example/x                  #comment line
-    //     edit EXPVER 'f8na'                                          #
-    //     edit USER 'ecgems'                                          #comment
-    //     edit USER2 "ecgems"                                         # comment
-    //     edit INT1 "10"                                             # comment
-    //     edit INT2 '11'                                             # comment
-    //     edit YMD  '20091012'                                        # comment
-    //     family family
-    //         edit var  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # comment line
-    //         edit var2 'smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%'  #comment line
-    //         task t2
-    //     endfamily
-    // endsuite
-    suite_ptr editSuite = defs.findSuite("edit");
-    BOOST_REQUIRE_MESSAGE(editSuite, "Could not find the edit suite");
-
-    const Variable& int1 = editSuite->findVariable("INT1");
-    BOOST_REQUIRE_MESSAGE(!int1.empty(), "Could not find variable INT1");
-    BOOST_REQUIRE_MESSAGE(int1.value() == 10, "Expected INT1 to have a value of 10, but found " << int1.value());
-
-    const Variable& int2 = editSuite->findVariable("INT2");
-    BOOST_REQUIRE_MESSAGE(!int2.empty(), "Could not find variable INT2");
-    BOOST_REQUIRE_MESSAGE(int2.value() == 11, "Expected INT2 to have a value of 11, but found " << int2.value());
-
-    const Variable& ymd = editSuite->findVariable("YMD");
-    BOOST_REQUIRE_MESSAGE(!ymd.empty(), "Could not find variable YMD");
-    BOOST_REQUIRE_MESSAGE(ymd.value() == 20091012,
-                          "Expected YMD to have a value of 20091012, but found " << ymd.value());
-
-    const Variable& user = editSuite->findVariable("USER");
-    BOOST_REQUIRE_MESSAGE(!user.empty(), "Could not find variable USER");
-    BOOST_REQUIRE_MESSAGE(user.value() == 0, "Expected user to have a value of 0, but found " << user.value());
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/autoarchive/autoarchive.def 5.13.0-1/ANode/test/parser/data/bad_defs/autoarchive/autoarchive.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/autoarchive/autoarchive.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/autoarchive/autoarchive.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite s
- family f1
-    autoarchive +01:00 # archive one hour after complete
-    autocancel +01:00  # cancel one hour after complete
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/autocancel/autocancel.def 5.13.0-1/ANode/test/parser/data/bad_defs/autocancel/autocancel.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/autocancel/autocancel.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/autocancel/autocancel.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite s
- family f1
-    autocancel +01:00  # cancel one hour after complete
-    autoarchive +01:00 # archive one hour after complete
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/autorestore.def 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/autorestore.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/autorestore.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/autorestore.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite s
- family f1
-    autorestore ./f2  # autorestore
-    autorestore ./f2  # can only have one
- endfamily
- family f2
-    task t1
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/bad_ref.def 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/bad_ref.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/bad_ref.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/bad_ref.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite s
- family f1
-    autorestore /s/f4   # reference to non existing node
- endfamily
- family f2
-    task t1
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref.def 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite s
- family f1
-    autorestore /s/f2 /s/f2   # multiple reference to same node
- endfamily
- family f2
-    task t1
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref2.def 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/multiple_ref2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite s
- family f1
-    autorestore ./f2 /s/f2   # multiple reference to same node
- endfamily
- family f2
-    task t1
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/ref_to_task.def 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/ref_to_task.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/autorestore/ref_to_task.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/autorestore/ref_to_task.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite s
- family f1
-    autorestore /s/f2/t1   # restore can only restore suite/family and not task
- endfamily
- family f2
-    task t1
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock1.def 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite s1
- clock real 0.1.2006 # clock date should not have wild carding
-endsuite
-
-suite s2
- clock real 1.0.2006 # clock date should not have wild carding
-endsuite
-
-suite s3
- clock real 1.12.0  # clock date should not have wild carding
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock2.def 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite s1
- clock real 99.1.2006   # day out of range
-endsuite
-suite s2
- clock real 1.15.2006   # month out of range
-endsuite
-suite s3
- clock real 1.15.0000   # 0 year out of range
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock3.def 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite suiteName
-  clock real 20.1.2006
-  endclock  19.1.2006    # endclock should be greater than clock start
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock4.def 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite s1
- clock real 400  #  
- endclock  300  #  # endclock should be greater than clock start
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock5.def 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock5.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite s1
- clock real 400  #  
- endclock  real 300  #   should not have real, clock end same type as clock start, or default to real
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock6.def 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock6.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock6.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock6.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite suiteName
-  endclock   19.1.2006  # endclock should be greater than clock start
-  clock real 19.1.2017
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock7.def 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock7.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/clock/clock7.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/clock/clock7.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite s1
- endclock  300  # endclock should be greater than clock start
- clock real 400  #  
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron1.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-	cron 36:00                              #  error should between hour 0-23
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron2.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-	cron 00:60                              #  error should   min 0-59
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron3.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
- 	cron -w 0,1,3,4,5,6,7,8 10:00           # Error should be range [0-6] where 0=sunday,1=monday,etc
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron4.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-	cron -d 10,11,12,35,36 12:00            # errors days of month should have range 1-31
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron5.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron5.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-	cron -m 1,2,3,13,14 12:00   #  Error month should have range 1-12
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron5_1.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron5_1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron5_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron5_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-    cron -m 0,1,2,3 12:00   #  Error month should have range 1-12
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron6.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron6.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron6.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron6.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-	cron -w -1,0,6 10:00                     #  weekdays should have range [0-6]
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron7.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron7.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron7.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron7.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-	cron -w 0 -m 5,6,7,8 10:00 20:00 25:00  # error in increment
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron8.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron8.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/cron8.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/cron8.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite cron
-    cron 10:00 27:00 01:00  #  max end time is 23:59
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/cron/repeat_with_cron.def 5.13.0-1/ANode/test/parser/data/bad_defs/cron/repeat_with_cron.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/cron/repeat_with_cron.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/cron/repeat_with_cron.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite suiteName
-    family f
-        cron 23:00                          # cant have repeat  & cron at same level
-        repeat date YMD 20090331 20121212 1 # status 0
-        task t
-        task t2
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/date/date.def 5.13.0-1/ANode/test/parser/data/bad_defs/date/date.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/date/date.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/date/date.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite suiteName
-   task a
-      date 100.*.2009   # day should be in range 1-31
-   endtask
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/date/date0.def 5.13.0-1/ANode/test/parser/data/bad_defs/date/date0.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/date/date0.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/date/date0.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite a
-   date 10.10.2009   # date should not be allowed on a suite, see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node 
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/date/date1.def 5.13.0-1/ANode/test/parser/data/bad_defs/date/date1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/date/date1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/date/date1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   task a
-      date 1.14.2009         # month should be in range 1-12
-   endtask
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/date/date2.def 5.13.0-1/ANode/test/parser/data/bad_defs/date/date2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/date/date2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/date/date2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite suiteName
-   task a
-      date 0.14.2009       # day is invalid, month is invalid
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/date/date3.def 5.13.0-1/ANode/test/parser/data/bad_defs/date/date3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/date/date3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/date/date3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite suiteName
-   task a
-      date 1.0.2009
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/date/date4.def 5.13.0-1/ANode/test/parser/data/bad_defs/date/date4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/date/date4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/date/date4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite suiteName
-   task b
-      date 1.1.200
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/date/date5.def 5.13.0-1/ANode/test/parser/data/bad_defs/date/date5.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/date/date5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/date/date5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite suiteName
-   task b
-      date 2.29.2002
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/day/day.def 5.13.0-1/ANode/test/parser/data/bad_defs/day/day.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/day/day.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/day/day.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite a
-  day wednesday  # do not allow day at suite level, see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node 
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/defstatus/defstatus.def 5.13.0-1/ANode/test/parser/data/bad_defs/defstatus/defstatus.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/defstatus/defstatus.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/defstatus/defstatus.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite suiteName
-   defstatus suspended
-   family familyName0
-      defstatus complete
-      task taskName0
-      	 defstatus complete  
-      	 defstatus complete  
-  		 edit VAR2 value2
-   endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_1.def 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suiteName
-   family familyName0
-      task taskName0
-         event name_1
-         event name_1
-     endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_2.def 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suiteName
-   family familyName0
-      task taskName0
-         event 0 
-         event 0
-     endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_3.def 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suiteName
-   family familyName0
-      task taskName0
-           event 1 eventName
-           event 1 eventName
-      endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_4.def 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suiteName
-   family familyName0
-      task taskName0
-           event 1  
-           event "1"
-      endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_state.def 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_state.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_state.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_state.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite s
-   family f
-      task t
-         event name_1 set
-         event name_1
-     endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_state2.def 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_state2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/event/event_state2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/event/event_state2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite s
-   family f
-      task t
-         event 0 name_1 set
-         event 0 name_1
-     endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/event/simple_event.txt 5.13.0-1/ANode/test/parser/data/bad_defs/event/simple_event.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/event/simple_event.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/event/simple_event.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   family familyName0
-      task taskName0
-         event //
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/extern/bad.def 5.13.0-1/ANode/test/parser/data/bad_defs/extern/bad.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/extern/bad.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/extern/bad.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-extern                    #extern without anything
-extern                    # extern without anything
-extern /limits:c1a
-extern /limits:linux_cluster;
-extern /limits:pdb
- 
-suite suiteName
-    limit sg1  10
-    limit mars 10
-endsuite
-
- 
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/extern/complete.def 5.13.0-1/ANode/test/parser/data/bad_defs/extern/complete.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/extern/complete.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/extern/complete.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-#
-# complete references to node path, not in externs is an error
-#
-suite suiteName
-   family familyName
-      task q
-            complete /a/b/c/d/e:event == set       # extern event path
-      task r
-            complete /a/b/c/d/e:meter le 30        # extern meter path   
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/extern/trigger1.def 5.13.0-1/ANode/test/parser/data/bad_defs/extern/trigger1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/extern/trigger1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/extern/trigger1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-#
-# Trigger references to node path, not in externs is an error
-#
-suite suiteName
-   family familyName
-      task q
-            trigger /a/b/c/d/e:event == set       # extern event path
-      task r
-            trigger /a/b/c/d/e:meter le 30        # extern meter path   
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/extern/trigger2.def 5.13.0-1/ANode/test/parser/data/bad_defs/extern/trigger2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/extern/trigger2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/extern/trigger2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-#
-# Trigger references to node path, not in externs is an error
-#
-suite bad_extern
-   family f1
-      task p
-            trigger /a/b/c/d == complete          # extern path
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/family/family.def 5.13.0-1/ANode/test/parser/data/bad_defs/family/family.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/family/family.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/family/family.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   family familyName0
-   endfamily
-   family familyName0             # duplicate family names
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/family/family_1.def 5.13.0-1/ANode/test/parser/data/bad_defs/family/family_1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/family/family_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/family/family_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-    suite suiteName
-       family familyName0
-          task taskName0
-          family heir_familyName0
-          endfamily
-          family heir_familyName0     # duplicate hierarchical familys
-          endfamily
-      endfamily
-      family familyName1
-      endfamily
-      family familyName2
-      endfamily
-   endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/family/missing_ends.def 5.13.0-1/ANode/test/parser/data/bad_defs/family/missing_ends.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/family/missing_ends.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/family/missing_ends.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   family familyName0    # missing endfamily and endsuite, should parse ok if its last family and suite
-
-suite suiteName
-   family familyName0    
-   endfamily
-endsuite 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/family/simple_family.txt 5.13.0-1/ANode/test/parser/data/bad_defs/family/simple_family.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/family/simple_family.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/family/simple_family.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite suiteName
-   family  
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/generic/generic.def 5.13.0-1/ANode/test/parser/data/bad_defs/generic/generic.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/generic/generic.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/generic/generic.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite a
-	generic a b c
-	generic a
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit.def 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-
-extern /limits:c1a
-extern /limits:linux_cluster
-extern /limits:pdb
-extern /limits:q2diss
-
-suite suiteName
-	limit sg1  10
-	limit mars 10
-endsuite
-
-suite obs
-    inlimit /limits:c1a
-    family limits
-    	limit hpcd 20
-    endfamily
-    
-    family anon    
-            inlimit /suiteName:sg1        #  
-    	task t1
-            inlimit /suiteName:sg1        #  
-            inlimit /suiteName:sg1        # duplicate inlimit
-   		task t2
-   		task t3
-     endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit3.def 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-extern /limits:c1a
-extern /limits:linux_cluster
-extern /limits:pdb
-extern /limits:q2diss
-
-suite obs
-    limit sg1
-    inlimit /limits:c1a
-    family limits
-    	limit hpcd 20
-    endfamily
-    
-    family anon    
-        inlimit -n -s sg1 # cant have -n(limit node only) and -s(limit submission) together       
-    	task t1
-   		task t2
-   		task t3
-     endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check.def 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite s
- family anon    
-   task t1
-    inlimit disk   # no path, find limit name up the tree, not found, should be warning
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check2.def 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite s
- family anon    
-   task t1
-     inlimit /s:disk        # absolute path to node defining the limit, limit missing
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check3.def 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite s
- family anon    
-   task t3
-     #limit rel_limit 1
-   task t4
-     inlimit t3:rel_limit   # relative limit (sibling) missing
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check4.def 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limit_check4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limit_check4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite s
- family anon    
-   task t6
-     inlimit ../anon:anon   # relative limit (parent)
-   task t7
-     inlimit ../../s:disk   # relative limit (parents/parent)
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limt2.def 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limt2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/inlimit/limt2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/inlimit/limt2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,22 +0,0 @@
-
-extern /limits:c1a
-extern /limits:linux_cluster
-extern /limits:pdb
-extern /limits:q2diss
-
-suite obs
-    limit sg1
-    inlimit /limits:c1a
-    family limits
-    	limit hpcd 20
-    endfamily
-    
-    family anon    
-            inlimit  sg1       
-    	task t1
-            inlimit  sg1        #  
-            inlimit  sg1        # duplicate inlimit
-   		task t2
-   		task t3
-     endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/late/late.def 5.13.0-1/ANode/test/parser/data/bad_defs/late/late.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/late/late.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/late/late.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   family familyName
-      task t1
-      	  late -s +00:15 -s 20:00 -c +02:00  # how to cope with duplivates ????????????
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/late/late2.def 5.13.0-1/ANode/test/parser/data/bad_defs/late/late2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/late/late2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/late/late2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   family familyName
-      task t1
-      		late -c +00:15 -s 20:00 -c +02:00  # how to cope with duplivates ????????????
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/late/late3.def 5.13.0-1/ANode/test/parser/data/bad_defs/late/late3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/late/late3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/late/late3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   family familyName
-      task t1
-      	  late  # oops no -s -a -c specified
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/late/late4.def 5.13.0-1/ANode/test/parser/data/bad_defs/late/late4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/late/late4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/late/late4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suiteName
-   family familyName
-      task t1
-      	  late -s +00:15 -c +02:00  #  Con only have one late per node
-      	  late -a 00:15 -c +02:00   #  Con only have one late per node
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/meter/meter.def 5.13.0-1/ANode/test/parser/data/bad_defs/meter/meter.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/meter/meter.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/meter/meter.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName
-      task taskName
-          meter myMeter  200 100 100  #  min val(200)  > max value(100)
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/meter/meter2.def 5.13.0-1/ANode/test/parser/data/bad_defs/meter/meter2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/meter/meter2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/meter/meter2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName
-      task taskName
-          meter myMeter  0 100 200  #  color change must be between min(0) and max(100)
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/meter/meter3.def 5.13.0-1/ANode/test/parser/data/bad_defs/meter/meter3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/meter/meter3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/meter/meter3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   family familyName
-      task taskName
-          meter myMeter  0 100 100  
-          meter myMeter  0 100 100  #  duplicate meters are not allowed
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/queue/bad_name.def 5.13.0-1/ANode/test/parser/data/bad_defs/queue/bad_name.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/queue/bad_name.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/queue/bad_name.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
-  queue .name 001 002 003 # status 0
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/queue/duplicate_name.def 5.13.0-1/ANode/test/parser/data/bad_defs/queue/duplicate_name.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/queue/duplicate_name.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/queue/duplicate_name.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite s1
-  queue name 001 002 003 # status 0
-  queue name 001 002 003 # status 0
-endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/queue/empty_queue.def 5.13.0-1/ANode/test/parser/data/bad_defs/queue/empty_queue.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/queue/empty_queue.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/queue/empty_queue.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite s1
-  queue name  # status 0
-endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/date_missing_name.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/date_missing_name.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/date_missing_name.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/date_missing_name.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
- repeat date 20090331 20121212 1  
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite s1
- repeat date YMD 20090331 20121212 1 # status 0
- repeat date YMD1 20090331 20121212 1 # status 0
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
- repeat date YMD 20091901 20091501   # should have format yyyymmdd  19 and 15 ar not valid months
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates_2.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates_2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates_2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/invalid_dates_2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
- repeat date YMD 20091099 20091501  # should have format yyyymmdd  invalid day of month
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date1.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
- repeat date YMD 20091001 20090901 1  #  start date is > end date, when delta > 0
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date2.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
-repeat date YMD 20090901 20091001 -1 # start date is < end date, when delta < 0
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date3.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
-repeat date YMD 20090901 20091010  0  # 0 is an invalid delta
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list.ecf 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list.ecf
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
- repeat datelist YMD 20091901 20091501   # should have format yyyymmdd  19 and 15 ar not valid months
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s1
- repeat datelist YMD  # empty list
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_integer.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_integer.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_integer.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_integer.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite s
- repeat integer VARIABLE 0 10 2 # comment
- repeat integer VARIABLE 0 10 # duplicate variable name
- repeat integer VARIABLE 0 10 # duplicate variable name
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_month.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_month.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_month.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_month.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite s
- repeat month 2   #111
-endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_with_cron.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_with_cron.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_with_cron.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_with_cron.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite s
- repeat date YMD 20090331 20121212 1 # status 0
- cron 10:00 23:00 00:10              # cant have repeat  & cron time series at same level
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_year.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_year.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/repeat_year.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/repeat_year.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s
- repeat year 3 20090331 20121212 1 # status 0
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/string_missing_name.def 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/string_missing_name.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/repeat/string_missing_name.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/repeat/string_missing_name.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite s
-    repeat string  
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/suite/clock.def 5.13.0-1/ANode/test/parser/data/bad_defs/suite/clock.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/suite/clock.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/suite/clock.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-    # only suites are allowed to have clocks
-    suite suiteName
-       family familyName0
-		 	clock real 20.1.2006
-      endfamily
-   endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/suite/clock1.def 5.13.0-1/ANode/test/parser/data/bad_defs/suite/clock1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/suite/clock1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/suite/clock1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-    # only suites are allowed to have clocks
-    suite suiteName
-       family familyName0
-       		task t1
-		 		clock real 20.1.2006
-      endfamily
-   endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/suite/family_and_task_same_name.def 5.13.0-1/ANode/test/parser/data/bad_defs/suite/family_and_task_same_name.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/suite/family_and_task_same_name.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/suite/family_and_task_same_name.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite  s1
-   task t1
-   family t1
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/suite/simple_suite.txt 5.13.0-1/ANode/test/parser/data/bad_defs/suite/simple_suite.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/suite/simple_suite.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/suite/simple_suite.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-suite  
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/task/simple_task.txt 5.13.0-1/ANode/test/parser/data/bad_defs/task/simple_task.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/task/simple_task.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/task/simple_task.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName0
-      task  
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/task/task.def 5.13.0-1/ANode/test/parser/data/bad_defs/task/task.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/task/task.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/task/task.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suiteName
-   family familyName0
-      task fred             # duplicate task names
-      task fred
-      endtask
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/task/task_1.def 5.13.0-1/ANode/test/parser/data/bad_defs/task/task_1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/task/task_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/task/task_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-   suite suiteName
-       family familyName0
-          family heir_familyName0      
-          		task fred                      # duplicate tasks within hier family
-          		task fred
-          endfamily
-      endfamily
-      family familyName1
-      endfamily
-      family familyName2
-      endfamily
-   endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite suiteName
-   family familyName0
-   		time 15:00 20:00   # ERROR should  time <start> <finish> <increment>
-   		time 19:00
-   		time +15:00
-   		time 10:00 20:00 01:00
-   		time +10:00 20:00 01:00
-		task t
-   			time 15:00
-   			time 19:00
-   			time +15:00
-   			time 10:00 20:00 01:00
-   			time +10:00 20:00 01:00		   		
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_1.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite a
-   time 19:00  # suites don't have a time, See see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_2.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite suiteName
-   family familyName0
-    	time 19:00
-   		time -15:00                  # minus not allowed
-   		time 10:00 20:00 01:00
-   		time +10:00 20:00 01:00
-		task t
-   			time 15:00
-   			time 19:00
-   			time +15:00
-   			time 10:00 20:00 01:00
-   			time +10:00 20:00 01:00		   		
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_3.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite suiteName
-   family familyName0
-   		time 15:000   # ERROR minutes should be limited to 2 digits
-   		time 19:00
-   		time +15:00
-   		time 10:00 20:00 01:00
-   		time +10:00 20:00 01:00
-		task t
-   			time 15:00
-   			time 19:00
-   			time +15:00
-   			time 10:00 20:00 01:00
-   			time +10:00 20:00 01:00		   		
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_4.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName0
-   		time 99:00        # bad hour range should be 00-23
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_5.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_5.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite suiteName
-   family familyName0
-   		time 23:76        # bad minutes range should be 00-59
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_6.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_6.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_6.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_6.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName0
-   		time  20:00 10:00 01:00          # invalid range start time > end time
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_7.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_7.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_7.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_7.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite suiteName
-   family familyName0
-   		time 15:00 20:00 00:00  # ERROR  increment cant be NULL
-   		time 19:00
-   		time +15:00
-   		time 10:00 20:00 01:00
-   		time +10:00 20:00 01:00
-		task t
-   			time 15:00
-   			time 19:00
-   			time +15:00
-   			time 10:00 20:00 01:00
-   			time +10:00 20:00 01:00		   		
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_8.def 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_8.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/time/time_8.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/time/time_8.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName0
-        time 00:00 01:00 10:00  # ERROR  increment duration is greater than duration between start/finish
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/today/today.def 5.13.0-1/ANode/test/parser/data/bad_defs/today/today.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/today/today.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/today/today.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName0
-   		today 15:00
-   		today 23:59 00:00  00:30     # start should be less than finish
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/today/today1.def 5.13.0-1/ANode/test/parser/data/bad_defs/today/today1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/today/today1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/today/today1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite a
-   today 19:00  # suites dont have a today, See  see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_relative.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_relative.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_relative.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_relative.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-# test node referencing in triggers
-#      o/ <node> == complete    i.e   a == complete   sibling    
-#      o/ ./<node> == complete  i.e  ./a == complete  sibling
-#      o/ ../<node> == complete i.e  ../a == complete means trigger nodes parent
-suite s1
-  family f1
-     family f2
-        family f3
-           family f4
-              task a
-                 trigger ../f4 == complete or ../f3 == complete  # cant have ../f4 and ../f3 at same level, should be ../../f3
-            endfamily   
-         endfamily
-      endfamily
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger2.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger2.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger2.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger2.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-    family familyName1
-		task a
-    	task b
-   			trigger z == complete   # reference to non existing sibling
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger3.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger3.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger3.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger3.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-    family familyName1
-		task a
-    	task b
-   			trigger /suiteName/ == complete   # incomplete absolute path
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger4.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger4.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger4.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger4.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-suite suite
-    family family
-    	task t1
-    	task t2
-    	task t3
-    	task t4
-    	task t5
-    	task t6
-    	task t7
-    	task t8
-    	task t9
-    	task t10
-		task a             
-         	event eventName 
-    	task b             
-   			trigger -a t2  == complete     # option -a and -o should be last
-   			trigger -o t3  == complete     # option -a and -o should be last
-   			trigger t1  == complete        # trigger with out options should be first
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger5.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger5.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger5.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/bad_trigger5.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-# here we have a trigger expression that references a meter and a node.
-# We should only except a string which is 'set' or 'clear'
-# i.e
-#    trigger /suite/family/m:var gt  0 or /suite/family/m:var eq set
-# here var could be an event
-
-suite suite
-    family family
-      task a             
-         trigger /suite/family/m:meter gt  0 or /suite/family/m:meter eq complete
-      task m
-         meter meter  0 100 100  # meter <name> <min> <max> [optional color change]
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/complex.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/complex.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/complex.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/complex.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite main
-  family dc00
-     task obs
-     task ref
-     family an
-         task forceinv
-     endfamily
-     family fc
-         # this should fail to find the referenced node, since .. means parents  i.e dc00
-         # since there is no family 'an' under main this should fail.
-         trigger ../an/forceinv == complete # this should really be ./an/forceinv == complete
-     endfamily    
-  endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/divide_by_zero.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/divide_by_zero.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/divide_by_zero.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/divide_by_zero.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite suiteName
-    family f1
-      task a
-      event event
-      task b
-            trigger ((/suiteName/f1/a:event / 0) == 0)   # divide by zero
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/ecflow_969.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/ecflow_969.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/ecflow_969.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/ecflow_969.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite suite
-    task pertinic
-        event 1
-    task eda_pert
-    task rot
-    family pert_ic
-             complete pertinic:1
-             trigger eda_pert
-             trigger -a rot==complete
-             trigger -a pertinic==complete and not pertinic:1
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/extern_trigger.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/extern_trigger.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/extern_trigger.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/extern_trigger.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-extern /a/b/c/d         
-extern /a/b/c/d/e:event        
-extern /a/b/c/d/e:meter        
-
-suite suiteName
-  family familyName
-  		task a
-   			trigger /a/b/c/d/e/f == complete  		   # non existing path, not even extern
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/modulo_by_zero.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/modulo_by_zero.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/modulo_by_zero.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/modulo_by_zero.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-      task a
-         meter meter 0 100 100
-      task b
-            trigger /suiteName/a:meter % 0 >= 0   # modulo by zero, should failed check
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite s1
-  family f1
-    task a
-    task b
-   	   trigger f1 == complete   # f1 is not a sibling but a parent, expect error
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger2.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/parent_trigger2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite s1
-  family f1
-    task a
-    task b
-   	   trigger ./f1 == complete   # f1 is not a sibling but a parent, expect error
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite suiteName
-  family familyNamea
-   		task a
-   		task b
-       endfamily
-   family familyName
-   		task a
-   		task b
-    			trigger ..//familyNamea\b == complete                      
-     endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/suite_with_trigger.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/suite_with_trigger.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/suite_with_trigger.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/suite_with_trigger.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suite_with_trigger_should_fail
-  trigger 1 == 0
-endsuite
-suite suite_with_complete_should_fail
-  complete 1 == 0
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/trigger.txt 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/trigger.txt
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/trigger.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/trigger.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite suiteName
-   family familyName
-   		task a
-   		task b
-   			trigger a == complete                       
-   			trigger b == complete               # duplicate task trigger        
-     endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/trigger_1.def 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/trigger_1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/trigger/trigger_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/trigger/trigger_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite suiteName
-   family familyName
-   		trigger familyName1 == complete                
-   		trigger familyName1 == complete    # duplicate family trigger
-   		task a
-   		task b
-   			trigger a == complete                       
-      endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad1.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad1.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit var
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad2.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit var # a comment
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad3.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit #comment
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad4.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit #var value
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad5.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad5.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/bad5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/bad5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit var#bad value
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/comment.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/comment.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/comment.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/comment.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit # comment
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/variable/comment2.def 5.13.0-1/ANode/test/parser/data/bad_defs/variable/comment2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/variable/comment2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/variable/comment2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite suiteName
-   edit comment # start of a comment,  this is an error since value starts with #
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verfiy3.def 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verfiy3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verfiy3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verfiy3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite  
-	verify complete:int        # correct format is <state>:int, ie verify complete:3
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verify.def 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verify.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verify.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verify.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite  
-	verify complete        # correct format is <state>:int
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verify2.def 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verify2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verify2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verify2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite  
-	verify complete:        # correct format is <state>:int
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verify4.def 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verify4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/verify/verify4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/verify/verify4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite  
-	verify complete:3        # cant have 2 verify completes, must be of different states
-	verify complete:4        #  
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad.def 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite suiteName
-   zombie ecf               # should be ecf:::0
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad2.def 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad2.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   zombie ecf:fob:init:100
-   zombie path:fail:event:100
-   zombie user:adopt:meter:100
-   zombie ecf:fob:init:100       # can only have one ecf
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad3.def 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad3.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite suiteName
-    zombie fred:adopt:meter:100    # fred is not a valid zombie type
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad4.def 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad4.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite suiteName
-    zombie user:fred:event,meter:100    # fred is not a valid user action
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad5.def 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad5.def
--- 5.12.4-1/ANode/test/parser/data/bad_defs/zombie/bad5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/bad_defs/zombie/bad5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite suiteName
-    zombie user:fob:fred:100    # fred is not a valid child cmd
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/JIRA/ecflow_1550.def 5.13.0-1/ANode/test/parser/data/good_defs/JIRA/ecflow_1550.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/JIRA/ecflow_1550.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/JIRA/ecflow_1550.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,101 +0,0 @@
-suite ecflow_1550
-  defstatus suspended
-  edit SLEEP 120
-  family barrier
-    repeat enumerated YMD 1 2 3 4 5 6 7 8 #sdsdsd
-    family start
-      complete start/0 == complete and start/1 == complete and start/2 == complete and start/3 == complete and start/4 == complete and start/5 == complete and start/6 == complete
-      family 0
-        time 23:59
-        day monday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 1
-        time 23:59
-        day tuesday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 2
-        time 23:59
-        day wednesday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 3
-        time 23:59
-        day thursday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 4
-        time 23:59
-        day friday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 5
-        time 23:59
-        day saturday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 6
-        time 23:59
-        day sunday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-    endfamily
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337.def 5.13.0-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,43 +0,0 @@
-suite ecflow_337
-  defstatus suspended
-  family barrier
-    repeat enumerated YMD "20150521" "20150525" "20150528" "20150601" "20150604" "20150608" "20150611" "20150615" "20150618" "20150622" "20150625" "20150629" "20150702" "20150706" "20150709" "20150713" "20150716" "20150720" "20150723" "20150727" "20150730" "20150803" "20150806" "20150810" "20150813" "20150817" "20150820" "20150824" "20150827" "20150831" "20150903" "20150907" "20150910" "20150914" "20150917" "20150921" "20150924" "20150928" "20151001" "20151005" "20151008" "20151012" "20151015" "20151019" "20151022" "20151026" "20151029" "20151102" "20151105" "20151109" "20151112" "20151116" "20151119" "20151123" "20151126" "20151130" "20151203" "20151207" "20151210" "20151214" "20151217" "20151221" "20151224" "20151228" "20151231" "20160104" "20160107" "20160111" "20160114" "20160118" "20160121" "20160125" "20160128" "20160201" "20160204" "20160208" "20160211" "20160215" "20160218" "20160222" "20160225" "20160229" "20160303" "20160307" "20160310" "20160314" "20160317" "20160321" "20160324" "20160328" "20160331" "20160404" "20160407" "20160411" "20160414" "20160418" "20160421" "20160425" "20160428" "20160502" "20160505" "20160509" "20160512" "20160516" "20160519" "20160523" "20160526" "20160530" "20160602" "20160606" "20160609" "20160613" "20160616" "20160620" "20160623" "20160627" "20160630" "20160704" "20160707" "20160711" "20160714" "20160718" "20160721" "20160725" "20160728" "20160801" "20160804" "20160808" "20160811" "20160815" "20160818" "20160822" "20160825" "20160829" "20160901" "20160905" "20160908" "20160912" "20160915" "20160919" "20160922" "20160926" "20160929" "20161003" "20161006" "20161010" "20161013" "20161017" "20161020" "20161024" "20161027" "20161031" "20161103" "20161107" "20161110" "20161114" "20161117" "20161121" "20161124" "20161128" "20161201" "20161205" "20161208" "20161212" "20161215" "20161219" "20161222" "20161226" "20161229" "20170102" "20170105" "20170109" "20170112" "20170116" "20170119" "20170123" "20170126" "20170130" "20170202" "20170206" "20170209" "20170213" "20170216" "20170220" "20170223" "20170227" "20170302" "20170306" "20170309" "20170313" "20170316" "20170320" "20170323" "20170327" "20170330" "20170403" "20170406" "20170410" "20170413" "20170417" "20170420" "20170424" "20170427" "20170501" "20170504" "20170508" "20170511" "20170515" "20170518" "20170522" "20170525" "20170529" "20170601" "20170605" "20170608" "20170612" "20170615" "20170619" "20170622" "20170626" "20170629" "20170703" "20170706" "20170710" "20170713" "20170717" "20170720" "20170724" "20170727" "20170731" "20170803" "20170807" "20170810" "20170814" "20170817" "20170821" "20170824" "20170828" "20170831" "20170904" "20170907" "20170911" "20170914" "20170918" "20170921" "20170925" "20170928" "20171002" "20171005" "20171009" "20171012" "20171016" "20171019" "20171023" "20171026" "20171030" "20171102" "20171106" "20171109" "20171113" "20171116" "20171120" "20171123" "20171127" "20171130" "20171204" "20171207" "20171211" "20171214" "20171218" "20171221" "20171225" "20171228" "20180101" "20180104" "20180108" "20180111" "20180115" "20180118" "20180122" "20180125" "20180129" "20180201" "20180205" "20180208" "20180212" "20180215" "20180219" "20180222" "20180226" "20180301" "20180305" "20180308" "20180312" "20180315" "20180319" "20180322" "20180326" "20180329" "20180402" "20180405" "20180409" "20180412" "20180416" "20180419" "20180423" "20180426" "20180430" "20180503" "20180507" "20180510" "20180514" "20180517" "20180521" "20180524" "20180528" "20180531" "20180604" "20180607" "20180611" "20180614" "20180618" "20180621" "20180625" "20180628" "20180702" "20180705" "20180709" "20180712" "20180716" "20180719" "20180723" "20180726" "20180730" "20180802" "20180806" "20180809" "20180813" "20180816" "20180820" "20180823" "20180827" "20180830" "20180903" "20180906" "20180910" "20180913" "20180917" "20180920" "20180924" "20180927" "20181001" "20181004" "20181008" "20181011" "20181015" "20181018" "20181022" "20181025" "20181029" "20181101" "20181105" "20181108" "20181112" "20181115" "20181119" "20181122" "20181126" "20181129" "20181203" "20181206" "20181210" "20181213" "20181217" "20181220" "20181224" "20181227" "20181231" "20190103" "20190107" "20190110" "20190114" "20190117" "20190121" "20190124" "20190128" "20190131" "20190204" "20190207" "20190211" "20190214" "20190218" "20190221" "20190225" "20190228" "20190304" "20190307" "20190311" "20190314" "20190318" "20190321" "20190325" "20190328" "20190401" "20190404" "20190408" "20190411" "20190415" "20190418" "20190422" "20190425" "20190429" "20190502" "20190506" "20190509" "20190513" "20190516" "20190520" "20190523" "20190527" "20190530" "20190603" "20190606" "20190610" "20190613" "20190617" "20190620" "20190624" "20190627" "20190701" "20190704" "20190708" "20190711" "20190715" "20190718" "20190722" "20190725" "20190729" "20190801" "20190805" "20190808" "20190812" "20190815" "20190819" "20190822" "20190826" "20190829" "20190902" "20190905" "20190909" "20190912" "20190916" "20190919" "20190923" "20190926" "20190930" "20191003" "20191007" "20191010" "20191014" "20191017" "20191021" "20191024" "20191028" "20191031" "20191104" "20191107" "20191111" "20191114" "20191118" "20191121" "20191125" "20191128" "20191202" "20191205" "20191209" "20191212" "20191216" "20191219" "20191223" "20191226" "20191230" "20200102" "20200106" "20200109" "20200113" "20200116" "20200120" "20200123" "20200127" "20200130" "20200203" "20200206" "20200210" "20200213" "20200217" "20200220" "20200224" "20200227" "20200302" "20200305" "20200309" "20200312" "20200316" "20200319" "20200323" "20200326" "20200330" "20200402" "20200406" "20200409" "20200413" "20200416" "20200420" "20200423" "20200427" "20200430" "20200504" "20200507" "20200511" "20200514" "20200518" "20200521" "20200525" "20200528" "20200601" "20200604" "20200608" "20200611" "20200615" "20200618" "20200622" "20200625" "20200629" "20200702" "20200706" "20200709" "20200713" "20200716" "20200720" "20200723" "20200727" "20200730" "20200803" "20200806" "20200810" "20200813" "20200817" "20200820" "20200824" "20200827" "20200831" "20200903" "20200907" "20200910" "20200914" "20200917" "20200921" "20200924" "20200928" "20201001" "20201005" "20201008" "20201012" "20201015" "20201019" "20201022" "20201026" "20201029" "20201102" "20201105" "20201109" "20201112" "20201116" "20201119" "20201123" "20201126" "20201130" "20201203" "20201207" "20201210" "20201214" "20201217" "20201221" "20201224" "20201228" "20201231" "20210104" "20210107" "20210111" "20210114" "20210118" "20210121" "20210125" "20210128" "20210201" "20210204" "20210208" "20210211" "20210215" "20210218" "20210222" "20210225" "20210301" "20210304" "20210308" "20210311" "20210315" "20210318" "20210322" "20210325" "20210329" "20210401" "20210405" "20210408" "20210412" "20210415" "20210419" "20210422" "20210426" "20210429" "20210503" "20210506" "20210510" "20210513" "20210517" "20210520" "20210524" "20210527" "20210531" "20210603" "20210607" "20210610" "20210614" "20210617" "20210621" "20210624" "20210628" "20210701" "20210705" "20210708" "20210712" "20210715" "20210719" "20210722" "20210726" "20210729" "20210802" "20210805" "20210809" "20210812" "20210816" "20210819" "20210823" "20210826" "20210830" "20210902" "20210906" "20210909" "20210913" "20210916" "20210920" "20210923" "20210927" "20210930" "20211004" "20211007" "20211011" "20211014" "20211018" "20211021" "20211025" "20211028" "20211101" "20211104" "20211108" "20211111" "20211115" "20211118" "20211122" "20211125" "20211129" "20211202" "20211206" "20211209" "20211213" "20211216" "20211220" "20211223" "20211227" "20211230"
-    family start
-      complete start/0 == complete or start/1 == complete
-      family 0
-        time 10:00
-        day monday
-        task dummy
-          complete 1==1
-          trigger 0==1
-      endfamily
-      family 1
-        time 10:00
-        day thursday
-        task dummy
-          complete 1==1
-          trigger 0==1
-      endfamily
-    endfamily
-    family last
-      trigger start == complete
-      family done
-        complete done/0 == complete or done/1 == complete
-        family 0
-          time 14:00
-          day monday
-          task dummy
-            complete 1==1
-            trigger 0==1
-        endfamily
-        family 1
-          time 14:00
-          day thursday
-          task dummy
-            complete 1==1
-            trigger 0==1
-        endfamily
-      endfamily
-    endfamily
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337_.def 5.13.0-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337_.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337_.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/JIRA/ecflow_337_.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-suite ecflow_337
-  defstatus suspended
-  family barrier
-    repeat enumerated YMD 1 2 3 4
-    family monday
-        time 10:00
-        day monday
-        task dummy
-          complete 1==1
-          trigger 0==1
-    endfamily
-    family tuesday
-        time 10:00
-        day tuesday
-        task dummy
-          complete 1==1
-          trigger 0==1
-    endfamily
-    family wednesday
-        time 10:00
-        day wednesday
-        task dummy
-          complete 1==1
-          trigger 0==1
-    endfamily
-    family thursday
-        time 10:00
-        day thursday
-        task dummy
-          complete 1==1
-          trigger 0==1
-    endfamily
-    family friday
-        time 10:00
-        day friday
-        task dummy
-          complete 1==1
-          trigger 0==1
-    endfamily
-    family saturday
-        time 10:00
-        day saturday
-        task dummy
-          complete 1==1
-          trigger 0==1
-    endfamily
-    family sunday
-        time 10:00
-        day sunday
-        task dummy
-          complete 1==1
-          trigger 0==1
-    endfamily
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive.def 5.13.0-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-suite autoarchive
- family f1
-    autoarchive +00:02  
-    task t1
- endfamily
- family f2
-     autoarchive 01:00 # archive at 1 am in morning after complete
-    task t1
- endfamily
- family f3
-    autoarchive 1     # archive 1 days after complete
-    task t1
- endfamily
- family f4
-    autoarchive 0      # archive immediately after complete
-    task t1
- endfamily
- family f5
-    autoarchive +00:01  #  archive after 1 minute, same as archive 0
-    task t1
- endfamily
- family f5_1
-    defstatus aborted
-    autoarchive +00:01  
-    task t1
- endfamily
- family f5_2
-    autoarchive 0  
-    task t1
-      trigger 1== 0
- endfamily
-  family f6
-    autoarchive +00:02 -i  
-    task t1
- endfamily
- family f7
-     autoarchive 01:00 -i  
-    task t1
- endfamily
- family f8
-    autoarchive 1 -i     
-    task t1
- endfamily
- family f9
-    autoarchive 0 -i     # archive immediately after complete,queued,abort
-    task t1
- endfamily
- family f10
-    autoarchive +00:01 -i #  archive after 1 minute, same as archive 0  ,queued,abort
-    task t1
- endfamily
- family f11
-    autoarchive +00:01 -i # archive after 1 minute, same as archive 0  ,queued,abort
-    task t1
-      trigger 1 == 0
- endfamily
- family f12
-    defstatus aborted
-    autoarchive 0 -i  
-    task t1
-       trigger 1 == 0
- endfamily
- family f13
-    defstatus aborted
-    autoarchive +00:01 -i 
-    task t1
-      trigger 1 == 0
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive2.def 5.13.0-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/autoarchive/autoarchive2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,39 +0,0 @@
-suite autoarchive_with_family_limit
- limit fam 1
- family f1
-     inlimit -n fam 
-     autoarchive 0      # archive immediately after complete
-     task t1
-     task t2
- endfamily
- family f2
-     inlimit -n fam 
-     autoarchive 0      # archive immediately after complete
-     task t1
-     task t2
- endfamily
- family f3
-     inlimit -n fam 
-     autoarchive 0      # archive immediately after complete
-     task t1
-     task t2
- endfamily
- family f4
-     inlimit -n fam 
-     autoarchive 0      # archive immediately after complete
-     task t1
-     task t2
- endfamily
- family f5
-     inlimit -n fam 
-     autoarchive 0      # archive immediately after complete
-     task t1
-     task t2
- endfamily
-endsuite
-
-#suite test2
-#  task t1
-#     trigger /test/f1<flag>late and /test/f2<flag>late
-#     autorestore /test/f1 /test/f2
-#endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/autocancel/autocancel.def 5.13.0-1/ANode/test/parser/data/good_defs/autocancel/autocancel.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/autocancel/autocancel.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/autocancel/autocancel.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,18 +0,0 @@
-suite autocancel
- family f1
-    autocancel +01:00 # cancel one hour after complete
-    task t1
- endfamily
- family f2
-     autocancel 01:00 # cancel at 1 am in morning after complete
-    task t1
- endfamily
- family f3
-    autocancel 10     # cancel 10 days after complete
-    task t1
- endfamily
- family f4
-    autocancel 0      # cancel immediately after complete
-    task t1
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/autorestore/autorestore.def 5.13.0-1/ANode/test/parser/data/good_defs/autorestore/autorestore.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/autorestore/autorestore.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/autorestore/autorestore.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-extern /s4
-extern /s4/f1
-extern /s4/f2
-
-suite autorestore
- family f1
-    autorestore ./f2 ./f3 ./f4 # autorestore
-    task t1
- endfamily
- family f2
-     autorestore /autorestore/f1 /autorestore/f3 /autorestore/f4 # autorestore
-     task t1
- endfamily
- family f3
-    autorestore /autorestore/f1  # autorestore
-    task t1
- endfamily
- family f4
-    autorestore /autorestore 
-    task t1
- endfamily
- family f5
-    autorestore /s4 /s4/f1 /s4/f2 # this is an extern so allow
-    task t1
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/autorestore/autorestore2.def 5.13.0-1/ANode/test/parser/data/good_defs/autorestore/autorestore2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/autorestore/autorestore2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/autorestore/autorestore2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite autorestore2
- family f1
-    trigger ./f2<flag>archived and ./f3<flag>archived
-    task t1
-        autorestore ../f2 ../f3  # autorestore
- endfamily
- family f2
-    autoarchive 0
-    task t1   
- endfamily
- family f3
-    autoarchive 0   
-    task t1   
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/autorestore/autorestore_test.def 5.13.0-1/ANode/test/parser/data/good_defs/autorestore/autorestore_test.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/autorestore/autorestore_test.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/autorestore/autorestore_test.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,22 +0,0 @@
-suite autorestore_test
- family farchive_now
-    autoarchive 0      # archive immediately after complete, may have to wait 60 seconds
-    task t1
- endfamily
- family farchive2_now
-    autoarchive 0      # archive immediately after complete, may have to wait 60 seconds
-    task t1
- endfamily
- family frestore_from_family_now
-    trigger ./farchive_now<flag>archived
-    autorestore ./farchive_now       
-    task t1
-       edit SLEEP 60
- endfamily
- family frestore_from_task_now
-    trigger ./frestore_from_family_now<flag>archived
-    task t1
-       edit SLEEP 60
-       autorestore ../farchive2_now       
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock.def 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite clock
- clock real 300
- endclock 400
- task t1
-endsuite
-
-suite clock_s1
- clock real 300
- task t1
-endsuite
-
-suite clock_s2; clock real 300; endclock 400; task t1 ; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock1.def 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock1.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite clock1
- clock real +01:00
- endclock   +02:00
- task t1
-endsuite
-
-suite clock1_s1; clock real +01:00; endclock +01:00; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock2.def 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite clock2
- clock real 01:00
- endclock  02:00
- task t1
-endsuite
-
-suite clock2_s1; clock real 01:00; endclock 10:00; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock3.def 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock3.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite clock3
- clock real 20.1.2006
- endclock  24.1.2006
- task t1;
-endsuite
-
-suite clock3_s1;clock real 20.1.2006;endclock 20.1.2017; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock4.def 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock4.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite clock4
- clock real 20.1.2006 +02:00
- endclock   23.1.2006 +04:14
- task t1
-endsuite
- 
-suite clock4_s1; clock real 20.1.2006 +02:00; endclock 23.1.2006 +02:00; task t1; endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock5.def 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock5.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/clock/clock5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/clock/clock5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite clock5
- clock real 01.01.2006 +02:00
- task t1
-endsuite
-
-suite clock5_s1;clock real 01.01.2006 +02:00; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/comment/comment.txt 5.13.0-1/ANode/test/parser/data/good_defs/comment/comment.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/comment/comment.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/comment/comment.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,33 +0,0 @@
-# # comment 
-# This is defs file that show use of comments
-# # comment 
-
-suite comment                       # comment 
-   family familyName0                # comment 
-      task taskName0                 # comment 
-         event 0                     # comment 
-         event 1 eventName           # comment 
-         meter myMeter 0 100         # comment 
-      family heir_familyName0        # comment 
-         task taskName0              # comment 
-            event 0                  # comment 
-            event 1 eventName        # comment 
-            meter myMeter 0 100      # comment 
-      endfamily                      # comment 
-   endfamily                         # comment 
-   family familyName1                # comment 
-      task taskName1                 # comment 
-         event 1                     # comment 
-         event 2 eventName           # comment 
-         meter myMeter 0 100         # comment 
-   endfamily                         # comment 
-   family familyName2                # comment 
-      task taskName2                 # comment 
-         event 2                     # comment 
-         event 3 eventName           # comment 
-         meter myMeter 0 100         # comment 
-   endfamily                         # comment 
-endsuite                             # comment 
-
-# Final comment  # comment 
-            
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/complete/complete.def 5.13.0-1/ANode/test/parser/data/good_defs/complete/complete.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/complete/complete.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/complete/complete.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite complete
- family f
-   task t
-   	meter step 0 5 4
-   task tt
-   	complete t:step ge 2
-   	trigger t == complete
- endfamily
-endsuite
-
-suite complete_s1; family f; task t;meter step 0 6 3;task tt;complete t:step ge 1;trigger t == complete
-endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/complete/complex.def 5.13.0-1/ANode/test/parser/data/good_defs/complete/complex.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/complete/complex.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/complete/complex.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-suite complete1
-    family f
-    	task t1
-    	task t2
-    	task t3
-    	task t4
-    	task t5
-    	task t6
-    	task t7
-    	task t8
-    	task t9
-    	task t10
-		task a             
-         	event eventName 
-    	task b  
-    	    trigger 1 == 0                  # impossible trigger, keeps task queued           
-   			complete t1  == complete        # a comment at end of trigger
-   			complete -a t2  == complete     # a comment at end of trigger
-   			complete -a t3  == complete     # a comment at end of trigger
-   			complete -a t4  == complete     # a comment at end of trigger
-   			complete -a t5  == complete     # a comment at end of trigger
-   			complete -o t6  == complete      # a comment at end of trigger
-   			complete -o t7  == complete      # a comment at end of trigger
-   			complete -o t8  == complete      # a comment at end of trigger
-   			complete -o t9  == complete      # a comment at end of trigger
-   			complete -o t10  == complete      # a comment at end of trigger
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/complete/why.def 5.13.0-1/ANode/test/parser/data/good_defs/complete/why.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/complete/why.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/complete/why.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite complete_why  
- family hold
-  defstatus queued
-  time 07:20
-  day tuesday
-  task dummy
-    trigger 1==0
-    complete 1==1 # ECFLOW-1629, why should not report on trigger since complete expression is true
- endfamily 
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron.def 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite cron
- task t1
-	cron 23:00                              # run every day at 23:00
-	cron 10:00 20:00 01:00                  # run every hour between 10am and 8pm
-	cron -w 0,1 10:00                       # run every sunday and monday at 10am
-	cron -d 10,11,12 12:00                  # run 10th, 11th and 12th of each month at noon
-	cron -m 1,2,3 12:00                     # run on Jan,Feb and March every day at noon.
-	cron -w 0,6 12:00
-	cron -w 0,1,2,3,4,5,6 12:00
-   cron -w 0 -m 5,6,7,8 10:00 20:00 01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
-   cron +00:00 23:59 00:01                 # relative cron
-   cron -w 0L,1L,2L,3L,4L,5L,6L -d 1,L 23:00  # run first and last day of month or last week of month
-endsuite
-
-suite cron_s1;cron 23:00 ;cron 10:00 20:00 01:00 ;cron -w 0,1 10:00 ;cron -d 10,11,12 12:00 ;cron -m 1,2,3 12:00 ; cron -w 0,6 12:00;cron -w 0,1,2,3,4,5,6 12:00;cron -w 0 -m 5,6,7,8 10:00 20:00 01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron1.def 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron1.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite cron1
- cron -w 0 , 1, 2 -m 5, 6, 7 , 8,9,10      10:00  20:00  01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
- task t
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron2.def 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite cron2
- cron -w 0,1,2 -d 1,20,24 -m 5,6,7,8 10:00 20:00 01:00  #  
- task t
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron_simple.def 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron_simple.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/cron/cron_simple.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/cron/cron_simple.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite cron_simple
- task t1
-      cron 00:00 17:59 00:01   
- task t2
-      cron 17:40               
- task t3
-      cron 17:55    
- task t4
-      cron 21:45    
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/cron/last.def 5.13.0-1/ANode/test/parser/data/good_defs/cron/last.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/cron/last.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/cron/last.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite cron3
- task t
-   cron -w 0L,1,2L,3L,4L,5L,6L 23:00  
-   cron -w 0L,1,2L,3L,4L,5L,6  23:00  
-   cron -w 0L,1,2L,3L,4L,5L,6L -d 25,L 23:00  
-   cron -w 1,3 -d 28,L 23:00  
-   cron -w 1,3 -d 28,L -m 1 23:00  
-   cron -d 1,L 23:00 
-   cron -d 1,L -m 2,3 23:00 
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/date/date.def 5.13.0-1/ANode/test/parser/data/good_defs/date/date.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/date/date.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/date/date.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,25 +0,0 @@
-suite date
-   task a
-      date *.*.2009
-   endtask
-   family familyName0
-   	  date 1.*.2009
-      task taskName0
-   	  		date 1.12.2009
-      task fred
-   	  		date 01.*.*
-      endtask
-   endfamily
-endsuite
-
-suite date_s1;
-   family familyName0
-   	  date 1.*.2009
-      task taskName0
-   	  		date 1.12.2009
-      task fred
-   	  		date 01.*.*
-      endtask
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/day/day.def 5.13.0-1/ANode/test/parser/data/good_defs/day/day.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/day/day.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/day/day.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-suite day
-   family f
-      task t1
-   	  		day wednesday
-      task f2
-            day monday
-            day tuesday
-            day wednesday
-            day thursday
-   	  		day friday
-   	  		day saturday
-   	  		day sunday
-       endtask
-   endfamily
-   family f2
-      repeat datelist YMD 20090331 20121212 20121212 20121213 20121214 20121215 
-      task t
-         day tuesday
-         time 13:00
-   endfamily
-   family f3
-      repeat date YMD 20090331 20121212 1  
-      task t
-         day wednesday
-         time 13:00
-         time 14:00
-   endfamily
-   family f4
-      repeat enumerated quotes "first" "second" "third" 
-      task t
-         day tuesday
-         time 00:00 23:59 00:30
-   endfamily
-   family f5
-      repeat integer VARIABLE_XX 0 10 2  
-      task t
-         day tuesday
-         today 09:00
-   endfamily
-   family f6
-      repeat string VARIABLE str1 str2 str3 str4 str5 str6 str7
-      task t
-         day tuesday
-         today 09:00
-   endfamily
-endsuite
-
-suite day_s1; family f ; day tuesday
-      task t1
-   	  		day wednesday
-      task t2
-   	  		day thursday
-   	  		day friday
-   	  		day saturday
-   	  		day sunday
-      endtask
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/defstatus/defstatus.txt 5.13.0-1/ANode/test/parser/data/good_defs/defstatus/defstatus.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/defstatus/defstatus.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/defstatus/defstatus.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-suite defstatus
-   defstatus suspended
-   family f
-      defstatus complete
-      task t
-  		  edit VAR2 value2
-        defstatus complete  # TODO defstatus ordering, if edit,event,meter first it wont parse
-   endfamily
-endsuite
-
-suite defstatus_s1;
-   defstatus suspended
-   family f
-      defstatus complete
-      task t
-  		  edit VAR2 value2
-        defstatus complete  # TODO defstatus ordering, if edit,event,meter first it wont parse
-   endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/edit/edit.def 5.13.0-1/ANode/test/parser/data/good_defs/edit/edit.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/edit/edit.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/edit/edit.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
- suite edit
-	edit ECF_INCLUDE /home/ma/map/sms/example/x                  # comment line
-	edit ECF_FILES   /home/ma/map/sms/example/x                  #comment line
-    edit EXPVER 'f8na'                                          #
-    edit USER 'ecgems'                                          #comment
-    edit USER2 "ecgems"                                         # comment
-    edit INT1 "10"                                             # comment
-    edit INT2 '11'                                             # comment
-    edit YMD  '20091012'                                        # comment
- 	family f
-		edit ECF_FETCH  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # comment line
-		edit ECF_FETCH2 'smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%'  #comment line
-		task t2
-	endfamily
-endsuite
-	
-suite edi1; edit ECF_INCLUDE /home/ma/map/sms/example/x ; edit INT2 '11'                                             # comment
-    edit YMD  '20091012'                                        # comment
- 	family f
-		edit ECF_FETCH  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%" ; edit ECF_FETCH2 'smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%'  #comment line
-		task t2 ; endfamily
-endsuite
-	
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/event/event_1.def 5.13.0-1/ANode/test/parser/data/good_defs/event/event_1.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/event/event_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/event/event_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite event_1
-   family f
-      task t
-         event 0 
-         event name
-         event 1 eventName
-         event 2 eventNamea
-     endfamily
-endsuite
-
-suite event_1s1;family f ; task t ; event 0  ;event name ;event 1 eventName
-   event 2 eventNamea ; endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/event/event_2.def 5.13.0-1/ANode/test/parser/data/good_defs/event/event_2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/event/event_2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/event/event_2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite event_2
-   family f
-      task t
-         event 0 
-         event 1
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/event/event_set.def 5.13.0-1/ANode/test/parser/data/good_defs/event/event_set.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/event/event_set.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/event/event_set.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite event_set
-   family f1
-      task t
-         event 0 set
-         event name set
-         event 1 eventName set
-         event 2 eventNamea set
-     endfamily
-endsuite
-
-suite event_set_s2;family f ; task t ; event 0 set ;event name set;event 1 eventName set
-         event 2 eventNamea set; endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/event/family_event.def 5.13.0-1/ANode/test/parser/data/good_defs/event/family_event.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/event/family_event.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/event/family_event.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite event_family_1
-   family f
-      # Events added to suite/family cannot be signaled by child commands
-      # However alter/force should allow events to set/cleared on Family/suite
-      event 0 
-      event name
-      event 1 eventName
-      event 2 eventNamea
-      task t
-   endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/event/spaces.def 5.13.0-1/ANode/test/parser/data/good_defs/event/spaces.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/event/spaces.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/event/spaces.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite event_spaces
-   family f
-      task t
-      
-         event 0 
-         
-         event name
-         
-         event 1 eventName
-         
-         event 2 eventNamea
-         
-     endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/event/suite_event.def 5.13.0-1/ANode/test/parser/data/good_defs/event/suite_event.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/event/suite_event.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/event/suite_event.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite event_suite
-   # Events added to suite/family cannot be signaled by child commands
-   # However alter/force should allow events to set/cleared on Family/suite
-   event 0 
-   event name
-   event 1 eventName
-   event 2 eventNamea
-   task t
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/extern/extern.def 5.13.0-1/ANode/test/parser/data/good_defs/extern/extern.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/extern/extern.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/extern/extern.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,52 +0,0 @@
-extern /o/main/12/an;extern /limits:c1a
-extern /limits:linux_cluster;extern /limits:pdb
-extern /limits:q2diss;extern /o/main:YMD
-extern /o/main/12/an/slwet
-extern /o/main/12/an/4dvar/ifstraj:finalwave
-extern /o/main/12/an/4dvar
-extern /o/main/12/an
-extern /o/main/12/fc/model
-extern /o/main/12/fc/model
-extern /o/main/12/an/4dvar/uptraj_0
-extern /o/main/12/an/4dvar/uptraj_0
-extern /o/main/12/fc/model
-extern /o/main/00dc/fc/model:step
-extern /o/main/00dc/fc/model
-extern /o/main/12/obs/get/get_stor
-extern /limits:prod
-extern /o/main/12/prod/240/prod_wparam
-extern /o/main:YMD
-extern /o/main/00/an
-extern /o/main/00/an/slwet
-extern /o/main/00/an/4dvar/ifstraj:finalwave
-extern /o/main/00/an/4dvar
-extern /o/main/00/an
-extern /o/main/00/fc/model
-extern /o/main/00/fc/model
-extern /o/main/00/an/4dvar/uptraj_0
-extern /o/main/00/an/4dvar/uptraj_0
-extern /o/main/00/fc/model
-extern /o/main/12dc/fc/model:step
-extern /o/main/12dc/fc/model
-extern /o/main/00/obs/get/get_stor
-extern /o/main/00/prod/240/prod_wparam
-extern /limits:mars
-extern /mofc/00/efi/swarm/sync_climate
-
-suite extern
-	limit sg1  10
-	limit mars 10
-endsuite
-
-suite extern_obs
-    family limits
-    	limit hpcd 20
-    endfamily
-    
-    family anon
-    	task t1
-    		inlimit /extern:sg1
-   		task t2
-   			inlimit /extern_obs/limits:hpcd         
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/extern/first.def 5.13.0-1/ANode/test/parser/data/good_defs/extern/first.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/extern/first.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/extern/first.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-#
-# This defines extern which are defined in second.def
-#
-extern /a/b/c/d         
-extern /a/b/c/d/e:event        
-extern /a/b/c/d/e:meter       
-
-extern /a/b/c/d/e/f/g/h/j     # this does not exist in second.def
-
-suite extern_first
-   family familyName
-   	task p
-   			trigger /a/b/c/d == complete  		  # extern path
-  		task q
-   			trigger /a/b/c/d/e:event == set  	  # extern event path
- 		task r
-   			trigger /a/b/c/d/e:meter le 30		  # extern meter path	
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/extern/plain.def 5.13.0-1/ANode/test/parser/data/good_defs/extern/plain.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/extern/plain.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/extern/plain.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-extern fred                             # allow non absolute paths
-extern /mofc/00/efi/swarm/sync_climate
-
-suite extern_plain
-    limit sg1  10
-    limit mars 10
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/extern/second.def 5.13.0-1/ANode/test/parser/data/good_defs/extern/second.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/extern/second.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/extern/second.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-#
-# The defs is used conjunction with first.def to test resolution of externs
-#
-suite event_second
-   family b
-   		family c
-   			family d
-   				task e
-   					event event
-           	    	meter meter  0 100 100  # meter <name> <min> <max> [optional color change]
-           	endfamily
-    	endfamily
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/extern/simple_extern.def 5.13.0-1/ANode/test/parser/data/good_defs/extern/simple_extern.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/extern/simple_extern.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/extern/simple_extern.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-extern /o/main/12/an
-extern /limits:c1a
-extern /limits:linux_cluster
-extern /limits:pdb
-extern /limits:q2diss
-extern /o/main:YMD
-extern /o/main/12/an/slwet
-extern /o/main/12/an/4dvar/ifstraj:finalwave
-extern /o/main/12/an/4dvar
-extern /o/main/12/an
-extern /o/main/12/fc/model
-extern /o/main/12/fc/model
-extern /o/main/12/an/4dvar/uptraj_0
-extern /o/main/12/an/4dvar/uptraj_0
-extern /o/main/12/fc/model
-extern /o/main/00dc/fc/model:step
-extern /o/main/00dc/fc/model
-extern /o/main/12/obs/get/get_stor
-extern /limits:prod
-extern /o/main/12/prod/240/prod_wparam
-extern /o/main:YMD
-extern /o/main/00/an
-extern /o/main/00/an/slwet
-extern /o/main/00/an/4dvar/ifstraj:finalwave
-extern /o/main/00/an/4dvar
-extern /o/main/00/an
-extern /o/main/00/fc/model
-extern /o/main/00/fc/model
-extern /o/main/00/an/4dvar/uptraj_0
-extern /o/main/00/an/4dvar/uptraj_0
-extern /o/main/00/fc/model
-extern /o/main/12dc/fc/model:step
-extern /o/main/12dc/fc/model
-extern /o/main/00/obs/get/get_stor
-extern /o/main/00/prod/240/prod_wparam
-extern /limits:mars
-extern /mofc/00/efi/swarm/sync_climate
-
-suite extern_simple1
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/family/hierarchical_family.txt 5.13.0-1/ANode/test/parser/data/good_defs/family/hierarchical_family.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/family/hierarchical_family.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/family/hierarchical_family.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-suite family_hier
-   edit VAR value
-   edit VAR1 "value"
-   family f
-      edit VAR value
-      task t
-         edit VAR1 "value"
-         event 0 
-         event 1 eventName
-         meter myMeter 0 100
-      family heir_f
-         edit VAR1 value
-         task taskName0
-            edit VAR1 value
-            event 0 
-            event 1 eventName
-            meter myMeter 0 100
-      endfamily
-   endfamily
-   family f1
-      edit VAR value
-      task t
-         edit VAR1 "value"
-         event 1 
-         event 2 eventName
-         meter myMeter 0 100
-   endfamily
-   family f2
-      edit VAR value
-      task t
-         trigger ../f1/t == complete
-         edit VAR1 "value"
-         event 2 
-         event 3 eventName
-         meter myMeter 0 100
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/family/missingEnds.txt 5.13.0-1/ANode/test/parser/data/good_defs/family/missingEnds.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/family/missingEnds.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/family/missingEnds.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-suite family_missing_ends
-   family f    # missing endfamily and endsuite, should parse ok if its last family and suite
- 
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/family/simple_family.txt 5.13.0-1/ANode/test/parser/data/good_defs/family/simple_family.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/family/simple_family.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/family/simple_family.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,18 +0,0 @@
-suite family_simple
-   family 3
-     task 3
-     task 1
-     task 2
-   endfamily
-   family 2
-     task 3
-     task 1
-     task 2
-   endfamily
-   family 1
-     task 3
-     task 1
-     task 2
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/generic/generic.def 5.13.0-1/ANode/test/parser/data/good_defs/generic/generic.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/generic/generic.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/generic/generic.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite generic
-  generic a #dddd
-  generic b c f #
-  family b
-    generic a #dddd
-    generic b c f #
-    task c
-    	generic a #dddd
-    	generic b c f #
-    	generic x #
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/label/label.txt 5.13.0-1/ANode/test/parser/data/good_defs/label/label.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/label/label.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/label/label.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-suite label
-   family f
-      task t
-      	label foo ""
-    endfamily
-endsuite
-
-suite label_s1
-   family f
-      task t ; label foo ""
-    endfamily
-endsuite
-
-suite label_s3
-   label foo ""
-   task t
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/label/multi_line_lables.def 5.13.0-1/ANode/test/parser/data/good_defs/label/multi_line_lables.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/label/multi_line_lables.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/label/multi_line_lables.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite label_multi_line
-   label error "This is an error"
-   label warning "This is an warning"
-   label Note "This is an note"
-   label Critical "This is an critical"
-   label info "This is an info"
-   label warning2 "value"
-   label note2 "value\\nvalue" #\\n should be converted to new line
-   label info2 "value\\nvalue  \\nfred fred2\\n" # \\n should be converted to new line
-   task t
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/label/semicolon.def 5.13.0-1/ANode/test/parser/data/good_defs/label/semicolon.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/label/semicolon.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/label/semicolon.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite label_semicolon
-  family f
-    label foo "a; b"
-    task t1
-       label label1 "fred ;  bill;  joe;  kate b"
-       label label2 ";;;;;;;;;;;"
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/label/spaces.def 5.13.0-1/ANode/test/parser/data/good_defs/label/spaces.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/label/spaces.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/label/spaces.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite label_spaces
-   family f
-      task t
-      
-      	label foo ""
-      	
-      	label fred ""
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/late/late.def 5.13.0-1/ANode/test/parser/data/good_defs/late/late.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/late/late.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/late/late.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite late
-   family f
-      task t1
-      		late -s +00:15 -a 20:00 -c +02:00
-      task t2
-      		late -a 20:00 -c +02:00 -s +00:15
-      task t3
-      		late -c +02:00 -a 20:00  -s +00:15
-      task t4
-            late  -s 00:02 -c +00:05
-      task t5
-            late  -s 00:01 -a 14:30 -c +00:01
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/lifecycle.txt 5.13.0-1/ANode/test/parser/data/good_defs/lifecycle.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/lifecycle.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/lifecycle.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite zombie_lifecycle
-  family family1
-   	task a
-        event 1 myEvent
-        meter myMeter 0 10
-   	task b
-   		trigger a == complete
-   endfamily
-   family family2
-   		task aa
-   			trigger ../family1/a:myMeter >= 3 and ../family1/a:myEvent 
-   		task bb
-   			trigger ../family1/a:myMeter >= 4  or  ../family1/a:myEvent
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/basic.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/basic.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/basic.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/basic.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite limit_basic
- limit disk 1
- family anon    
-   inlimit disk  
-   task t1
-   task t2
-   task t3
-   task t4
-   task t5
-   task t6
-   task t7
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/inlimit_all_types.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/inlimit_all_types.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/inlimit_all_types.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/inlimit_all_types.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,36 +0,0 @@
-suite limit_all_inlimit_types
- limit fam 2
- limit task 4
- inlimit task         
- family f1
-     limit sub 1
-     inlimit -n fam 
-     inlimit -s sub         
-     task t1
-     task t2
-     task t3
-     task t4
-     task t5
-     task t6
- endfamily
- family f2
-     limit sub 3
-     inlimit -s sub         
-     inlimit -n fam 
-     task t1
-     task t2
-     task t3
-     task t4
-     task t5
-     task t6
- endfamily
- family f3
-     inlimit -n fam 
-     task t1
-     task t2
-     task t3
-     task t4
-     task t5
-     task t6
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/inlimit_family.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/inlimit_family.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/inlimit_family.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/inlimit_family.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-suite limit_family
- limit fam 1
- family f1
-     inlimit -n fam 
-     task t1
-     task t2
- endfamily
- family f2
-     inlimit -n fam 
-     task t1
-     task t2
- endfamily
- family f3
-     inlimit -n fam 
-     task t1
-     task t2
- endfamily
- family f4
-     inlimit -n fam 
-     task t1
-     task t2
- endfamily
- family f5
-     inlimit -n fam 
-     task t1
-     task t2
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/inlimit_only.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/inlimit_only.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/inlimit_only.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/inlimit_only.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-extern /limits:c1a
-extern /limits:linux_cluster
-extern /limits:pdb
-extern /limits:q2diss
-
-suite limit
-    limit sg1  10
-    limit mars 10
-endsuite
-
-suite limit_with_node_inlimit
-    limit fred 1000
-    inlimit -n /limits:c1a
-    
-    family limits
-        limit hpcd 20
-    endfamily
-    
-    family X
-        inlimit -n fred 3
-        task t1
-    endfamily
-    
-    family anon    
-        inlimit -n fred      
-        task t1
-            inlimit -n /limit:sg1 3          # another suite limit
-            inlimit -n /limit_with_node_inlimit/limits:hpcd      # This suite limit
-            inlimit -n /limits:c1a           # extern suite limit
-        task t2
-            inlimit -n /limit_with_node_inlimit/limits:hpcd      # This suite limit
-        task t3
-            inlimit -n /limits:c1a           # extern suite limit
-        task t4
-            inlimit -n /limits:c1a  10       # extern suite limit
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,33 +0,0 @@
-extern /limits:c1a
-extern /limits:linux_cluster
-extern /limits:pdb
-extern /limits:q2diss
-suite suiteName
-	limit sg1  10
-	limit mars 10
-endsuite
-
-suite limit_s1
-	limit mars 10
-	limit sg1  10
-endsuite
-
-suite limit_with_externs
-    inlimit /limits:c1a
-    family limits
-    	limit hpcd 20
-    endfamily
-    
-    family anon    
-   		inlimit limits:hpcd       
-    	task t1
-    		inlimit /suiteName:sg1        # another suite limit
-    		inlimit /suiteName:mars       # another suite limit
-    		inlimit /limit_s1:mars              # another suite limit
-    		inlimit /limit_s1:sg1               # another suite limit
-   		task t2
-   			inlimit /limit_with_externs/limits:hpcd      # This suite limit
-  		task t3
-   			inlimit /limits:c1a           # extern suite limit
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit2.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite limit2
-  clock hybrid 0 # 24.02.2006 14:47
-  inlimit pop
-  limit pop 10
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit3.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit3.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-# ECFLOW-713, moved from bad_defs/limit to good_defs/limit
-# Allow Limit value of zero, i.e inlimit greater than limit, as a way of controlling job submission.
-suite limit_with_higher_inlimit
-    limit disk 50
-    family anon    
-    	inlimit /limit_with_higher_inlimit:disk 100    # inlimit value is greater than the LIMIT
-    	task t1
-    	task t2
-    endfamily
-endsuite
-
-suite limit_with_value_zero
-    limit disk 0
-    family anon    
-        inlimit /limit_with_value_zero:disk 100    # inlimit value is greater than the LIMIT
-        task t1
-        task t2
-    endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit_check.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit_check.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/limit_check.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/limit_check.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-suite limit_check_relative_paths_on_inlimits
- limit disk 1
- family anon    
-   inlimit disk             # no path, find limit name up the tree
-   limit anon 1
-   task t1
-     inlimit /limit_check_relative_paths_on_inlimits/anon:anon   # absolute path to node defining the limit
-   task t2
-     inlimit /limit_check_relative_paths_on_inlimits:disk        # absolute path to node defining the limit
-   task t3
-     limit rel_limit 1
-   task t4
-     inlimit t3:rel_limit   # relative limit (sibling)
-   task t5
-     inlimit ./t3:rel_limit # relative limit (sibling)
-   task t6
-     inlimit ../anon:anon   # relative limit (parent)
-   task t7
-     inlimit ../../limit_check_relative_paths_on_inlimits:disk   # relative limit (parents/parent)
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/sub_only.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/sub_only.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/sub_only.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/sub_only.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,33 +0,0 @@
-extern /limits:c1a
-extern /limits:linux_cluster
-extern /limits:pdb
-extern /limits:q2diss
-suite limit_suiteName
-	limit sg1  10
-	limit mars 10
-endsuite
-
-suite limit_s1
-	limit mars 10
-	limit sg1  10
-endsuite
-
-suite limit_extern_and_submission_limits
-    inlimit -s /limits:c1a
-    family limits
-    	limit hpcd 20
-    endfamily
-    
-    family anon    
-   		inlimit -s limits:hpcd       
-    	task t1
-    		inlimit -s /limit_suiteName:sg1        # another suite limit
-    		inlimit -s /limit_suiteName:mars       # another suite limit
-    		inlimit -s /limit_s1:mars              # another suite limit
-    		inlimit -s /limit_s1:sg1               # another suite limit
-   		task t2
-   			inlimit -s /limit_extern_and_submission_limits/limits:hpcd      # This suite limit
-  		task t3
-   			inlimit -s /limits:c1a           # extern suite limit
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/limit/sub_only1.def 5.13.0-1/ANode/test/parser/data/good_defs/limit/sub_only1.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/limit/sub_only1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/limit/sub_only1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,18 +0,0 @@
-suite limit_with_submission_limits
-    limit disk 2
-    family anon    
-    	inlimit -s disk   # Inlimit submission
-    	task t1
-    	task t2
-    	task t3
-    	task t4
-    	task t5
-    	task t6
-    	task t7
-    	task t8
-    	task t9
-    	task t10
-    	task t11
-    	task t12
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/meter/negative.def 5.13.0-1/ANode/test/parser/data/good_defs/meter/negative.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/meter/negative.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/meter/negative.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite meter_negative
-   family f
-      task t
-          meter myMeter  -1 10 10  # meter <name> <min> <max> [optional color change]
-     endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/meter/simple_meter.txt 5.13.0-1/ANode/test/parser/data/good_defs/meter/simple_meter.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/meter/simple_meter.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/meter/simple_meter.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite meter_simple
-   family f
-      task t
-          meter myMeter  0 10 10  # meter <name> <min> <max> [optional color change]
-          meter myMeter2 0 5      
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/meter/spaces.def 5.13.0-1/ANode/test/parser/data/good_defs/meter/spaces.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/meter/spaces.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/meter/spaces.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite meter_spaces
-   family f
-      task t
-      
-          meter myMeter  0 4 4  # meter <name> <min> <max> [optional color change]
-          
-          meter myMeter1 0 5      
-          
-          meter myMeter2 0 4      
-          
-          meter myMeter3 0 3     
-          
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/queue/queue.def 5.13.0-1/ANode/test/parser/data/good_defs/queue/queue.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/queue/queue.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/queue/queue.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite queue
-  queue name 001 002 003 # status 0
-  queue name1 001 002 003 # status 0
-  family f1
-    queue name 001 002 003 # status 0
-    queue name1 001 002 003 # status 0
-    task t
-       queue name 001   # status 0
-       queue name1 001  # status 0    
-  endfamily
-endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/queue/queue2.def 5.13.0-1/ANode/test/parser/data/good_defs/queue/queue2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/queue/queue2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/queue/queue2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite queue2
-  queue name 001 002 003 # status 0
-  queue name1 001 002 003 # status 0
-  family f1
-    task t
-  endfamily
-endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/queue/queue_string.def 5.13.0-1/ANode/test/parser/data/good_defs/queue/queue_string.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/queue/queue_string.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/queue/queue_string.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite queue_string
-  queue name red orange 002 003 blue green indigo  
-  family f1
-    task t
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_date.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_date.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_date.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_date.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite repeat_date
-  repeat date YMD 20090331 20121212 1 # status 0
-  task t1
-endsuite
-
-suite repeat_date_s2
-  repeat date YMD 20121212 20090331  -1 # status 0
-  task t1
-endsuite
-
-suite repeat_date_s3; repeat date YMD 20090331 20121212 1 # status 0
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_date_list.ecf 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_date_list.ecf
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_date_list.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_date_list.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite repeat_datelist_s1
-  repeat datelist YMD 20090331 20121212 20121212 # status 0
-  task t1
-endsuite
-
-suite repeat_datelist_s2
-  repeat datelist YMD 20121212 20090331 20090331 # status 0
-  task t1
-endsuite
-
-suite repeat_datelist_s3; repeat datelist YMD 20090331 20121212 20090331 # status 0
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_day.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_day.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_day.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_day.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite repeat_day
-  repeat day 1                             #status 0
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite repeat_enumerated1
-   
-  repeat enumerated quotes "first" "second" "third"  # sdsdsd 
-  task t1
-
-endsuite
-
-suite repeat_enumerated2
-   
- repeat enumerated quotes 'first' 'second' "third"  # sdsdsd 
-  task t1
-   
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerated.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerated.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerated.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_enumerated.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite repeat_enumnerate_s1
-   
-    repeat enumerated VARIABLE first second third #sdsdsd
-  task t1
-   
-endsuite
-
-suite repeat_enumnerate_s1s2
-   
-    repeat enumerated VARIABLE 20130101 20130102 20130103 #sdsdsd
-  task t1
-   
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_file.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_file.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_file.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_file.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite repeat_file
-  repeat file filename fred.txt   # comment
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_integer.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_integer.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_integer.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_integer.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite repeate_integer3
-  repeat integer VARIABLE3_XZ 0 10 #comment
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_1.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_1.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite repeate_integer
-  repeat integer VARIABLE_XX 0 10 2 # comment
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_2.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_integer_2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite repeat_integer2
-  repeat integer VARIABLE_XY 0 10 # comment
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_string.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_string.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_string.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_string.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite repeat_string
-  repeat string VARIABLE str1 str2              #comment
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_string_quotes.def 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_string_quotes.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/repeat/repeat_string_quotes.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/repeat/repeat_string_quotes.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite repeat_string_quotes
-  repeat string quotes "str1" "str2"  "str2" # comment
-  task t1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/suite/multi_statements_per_line.def 5.13.0-1/ANode/test/parser/data/good_defs/suite/multi_statements_per_line.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/suite/multi_statements_per_line.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/suite/multi_statements_per_line.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite suite_ml_empty_x;endsuite
-suite suite_ml_obs; endsuite
-
-suite suite_ml_fred; task a; task b; endsuite # a comment suite fred; task a; task b; endsuite
-
-suite suite_ml_s1; task t1; task t2;task t3;family f1;task f1_t1;task f1_t2;endfamily;task t4
-endsuite
-
-suite suite_ml_s2;task t1;task t2;task t3;family f1;task f1_t1;task f1_t2;endfamily; task t4 # comment,
-endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/suite/multi_suite.def 5.13.0-1/ANode/test/parser/data/good_defs/suite/multi_suite.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/suite/multi_suite.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/suite/multi_suite.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-
-suite suite_ml_empty
- 
-endsuite
-
-suite suite_ml_empty_obs
- 
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/suite/simple_suite.txt 5.13.0-1/ANode/test/parser/data/good_defs/suite/simple_suite.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/suite/simple_suite.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/suite/simple_suite.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-
-# this is comment
-  # this is another comment line
-suite suite_empty_1
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/suite/suite_with_hierarchy.def 5.13.0-1/ANode/test/parser/data/good_defs/suite/suite_with_hierarchy.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/suite/suite_with_hierarchy.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/suite/suite_with_hierarchy.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-suite suite_hier
-	task 4
-	task 1
-	task 2
-	task 3
-	family f1
-		task 1
-		task 2
-	endfamily
-endsuite
-suite suite_hier_s1
-	task 4
-	task 1
-	task 2
-	task 3
-	family f1
-		task f1_t1
-		task f1_t2
-	endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/suite/suite_with_task.def 5.13.0-1/ANode/test/parser/data/good_defs/suite/suite_with_task.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/suite/suite_with_task.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/suite/suite_with_task.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-suite suite_with_task
-   task a
-   task b
-   task c
-   task 1
-   task 2
-   task 3
-   task 4
-   task 5
-   task 6
-   task 7
-   task 9
-   task 10
-   task 11
-   task 20
-   task 21
-   task 30
-   task 100
-   task 101
-   task 200
-   task 400
-   task 1001
-   task 2001
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/task/simple_task.txt 5.13.0-1/ANode/test/parser/data/good_defs/task/simple_task.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/task/simple_task.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/task/simple_task.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-suite task1
-   family f
-      task t1
-      task t2
-      task t4
-      task t5
-      endtask
-   endfamily
-endsuite
-
-suite task1_s1
-   family f
-      task t1 ; task t2 ;task t4 ; task t5
-      endtask
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/task/spaces.def 5.13.0-1/ANode/test/parser/data/good_defs/task/spaces.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/task/spaces.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/task/spaces.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite task_spaces
-   family f
-   
-      task t
-      task 001
-      
-      task fred
-      
-      endtask
-      
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/task/task.def 5.13.0-1/ANode/test/parser/data/good_defs/task/task.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/task/task.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/task/task.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite task2
-   family f
-      task t1
-      endtask
-      task t2
-      endtask
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/time/time.def 5.13.0-1/ANode/test/parser/data/good_defs/time/time.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/time/time.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/time/time.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite time_time
-   family f
-		time 15:00
-		time 19:00
-		time +15:00
-		time 10:00 20:00 01:00
-		time +10:00 20:00 01:00
-	task t
-		time 15:00
-		time 19:00
-		time +15:00
-		time 10:00 20:00 01:00
-		time +10:00 20:00 01:00		   		
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/time/time_1.def 5.13.0-1/ANode/test/parser/data/good_defs/time/time_1.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/time/time_1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/time/time_1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-suite time_1
-   family f1
-      task t1
-   		time 15:00
-   		time 00:00 23:59 00:30
-         time 00:00 06:59 00:30
-      task t2
-         time 17:00
-      task t3
-         time 18:00
-         time 19:00
-         time 20:00
-   endfamily
-endsuite
-
-suite time_1s1 
-   family f
-   	time 15:00 ; time 00:00 23:59 00:30 ;time 00:00 06:59 00:30
-   task t
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/time/time_2.def 5.13.0-1/ANode/test/parser/data/good_defs/time/time_2.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/time/time_2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/time/time_2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite time_2
-   family f
-		task t
-			time 15:00
-			time 19:00
-			time +15:00
-			time 10:00 20:00 01:00
-			time +10:00 20:00 01:00		   		
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/today/today.def 5.13.0-1/ANode/test/parser/data/good_defs/today/today.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/today/today.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/today/today.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite today
-   family f
-   	today 15:00
-   	today 00:00 23:59 00:30
-      today 00:00 06:59 00:30
-      task t
-   endfamily
-endsuite
-
-suite today_s1
-   family f
-   	today 15:00 ; today 00:00 23:59 00:30
-      today 00:00 06:59 00:30
-      task t
-   endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/today/today1.def 5.13.0-1/ANode/test/parser/data/good_defs/today/today1.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/today/today1.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/today/today1.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite today1
-   family familyName0
-   		today 15:00            #comment
-   		today 19:00
-   		today 10:00 20:00 01:00
-   		today 11:00 20:00 01:00
-		task t
-   			today 15:00
-   			today 19:00
-   			today 10:00 20:00 01:00
-   			today 11:00 20:00 01:00		   		
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_1442.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_1442.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_1442.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_1442.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-# 4.11.1
-suite trigger_ecflow_1442
-  defstatus suspended
-  edit FIRE_YMD '19000101'
-  family setup
-    family build
-      task build_geff
-      task install_scripts
-    endfamily
-  endfamily
-  family timers
-    family start
-      task ymd
-        edit YMD '19781229'
-    endfamily
-  endfamily
-  family monthly
-    repeat enumerated YMD "19790101" "19790201" "19790301" "19790401" "19790501" "19790601" "19790701" "19790801" "19790901" "19791001" "19791101" "19791201" "19800101" "19800201" "19800301" "19800401" "19800501" "19800601" "19800701" "19800801" "19800901" "19801001" "19801101" "19801201" "19810101" "19810201" "19810301" "19810401" "19810501" "19810601" "19810701" "19810801" "19810901" "19811001" "19811101" "19811201" "19820101" "19820201" "19820301" "19820401" "19820501" "19820601" "19820701" "19820801" "19820901" "19821001" "19821101" "19821201" "19830101" "19830201" "19830301" "19830401" "19830501" "19830601" "19830701" "19830801" "19830901" "19831001" "19831101" "19831201" "19840101" "19840201" "19840301" "19840401" "19840501" "19840601" "19840701" "19840801" "19840901" "19841001" "19841101" "19841201" "19850101" "19850201" "19850301" "19850401" "19850501" "19850601" "19850701" "19850801" "19850901" "19851001" "19851101" "19851201" "19860101" "19860201" "19860301" "19860401" "19860501" "19860601" "19860701" "19860801" "19860901" "19861001" "19861101" "19861201" "19870101" "19870201" "19870301" "19870401" "19870501" "19870601" "19870701" "19870801" "19870901" "19871001" "19871101" "19871201" "19880101" "19880201" "19880301" "19880401" "19880501" "19880601" "19880701" "19880801" "19880901" "19881001" "19881101" "19881201" "19890101" "19890201" "19890301" "19890401" "19890501" "19890601" "19890701" "19890801" "19890901" "19891001" "19891101" "19891201" "19900101" "19900201" "19900301" "19900401" "19900501" "19900601" "19900701" "19900801" "19900901" "19901001" "19901101" "19901201" "19910101" "19910201" "19910301" "19910401" "19910501" "19910601" "19910701" "19910801" "19910901" "19911001" "19911101" "19911201" "19920101" "19920201" "19920301" "19920401" "19920501" "19920601" "19920701" "19920801" "19920901" "19921001" "19921101" "19921201" "19930101" "19930201" "19930301" "19930401" "19930501" "19930601" "19930701" "19930801" "19930901" "19931001" "19931101" "19931201" "19940101" "19940201" "19940301" "19940401" "19940501" "19940601" "19940701" "19940801" "19940901" "19941001" "19941101" "19941201" "19950101" "19950201" "19950301" "19950401" "19950501" "19950601" "19950701" "19950801" "19950901" "19951001" "19951101" "19951201" "19960101" "19960201" "19960301" "19960401" "19960501" "19960601" "19960701" "19960801" "19960901" "19961001" "19961101" "19961201" "19970101" "19970201" "19970301" "19970401" "19970501" "19970601" "19970701" "19970801" "19970901" "19971001" "19971101" "19971201" "19980101" "19980201" "19980301" "19980401" "19980501" "19980601" "19980701" "19980801" "19980901" "19981001" "19981101" "19981201" "19990101" "19990201" "19990301" "19990401" "19990501" "19990601" "19990701" "19990801" "19990901" "19991001" "19991101" "19991201" "20000101" "20000201" "20000301" "20000401" "20000501" "20000601" "20000701" "20000801" "20000901" "20001001" "20001101" "20001201" "20010101" "20010201" "20010301" "20010401" "20010501" "20010601" "20010701" "20010801" "20010901" "20011001" "20011101" "20011201" "20020101" "20020201" "20020301" "20020401" "20020501" "20020601" "20020701" "20020801" "20020901" "20021001" "20021101" "20021201" "20030101" "20030201" "20030301" "20030401" "20030501" "20030601" "20030701" "20030801" "20030901" "20031001" "20031101" "20031201" "20040101" "20040201" "20040301" "20040401" "20040501" "20040601" "20040701" "20040801" "20040901" "20041001" "20041101" "20041201" "20050101" "20050201" "20050301" "20050401" "20050501" "20050601" "20050701" "20050801" "20050901" "20051001" "20051101" "20051201" "20060101" "20060201" "20060301" "20060401" "20060501" "20060601" "20060701" "20060801" "20060901" "20061001" "20061101" "20061201" "20070101" "20070201" "20070301" "20070401" "20070501" "20070601" "20070701" "20070801" "20070901" "20071001" "20071101" "20071201" "20080101" "20080201" "20080301" "20080401" "20080501" "20080601" "20080701" "20080801" "20080901" "20081001" "20081101" "20081201" "20090101" "20090201" "20090301" "20090401" "20090501" "20090601" "20090701" "20090801" "20090901" "20091001" "20091101" "20091201" "20100101" "20100201" "20100301" "20100401" "20100501" "20100601" "20100701" "20100801" "20100901" "20101001" "20101101" "20101201" "20110101" "20110201" "20110301" "20110401" "20110501" "20110601" "20110701" "20110801" "20110901" "20111001" "20111101" "20111201" "20120101" "20120201" "20120301" "20120401" "20120501" "20120601" "20120701" "20120801" "20120901" "20121001" "20121101" "20121201" "20130101" "20130201" "20130301" "20130401" "20130501" "20130601" "20130701" "20130801" "20130901" "20131001" "20131101" "20131201" "20140101" "20140201" "20140301" "20140401" "20140501" "20140601" "20140701" "20140801" "20140901" "20141001" "20141101" "20141201" "20150101" "20150201" "20150301" "20150401" "20150501" "20150601" "20150701" "20150801" "20150901" "20151001" "20151101" "20151201" "20160101" "20160201" "20160301" "20160401" "20160501" "20160601" "20160701" "20160801" "20160901" "20161001" "20161101" "20161201" "20170101" "20170201" "20170301" "20170401" "20170501" "20170601" "20170701" "20170801" "20170901" "20171001" "20171101" "20171201" "20180101" "20180201" "20180301" "20180401" "20180501" "20180601" "20180701" "20180801" "20180901" "20181001" "20181101" "20181201" "20190101" "20190201" "20190301" "20190401" "20190501" "20190601" "20190701" "20190801" "20190901" "20191001" "20191101" "20191201" "20200101" "20200201" "20200301" "20200401" "20200501" "20200601" "20200701" "20200801" "20200901" "20201001" "20201101" "20201201" "20210101" "20210201" "20210301" "20210401" "20210501" "20210601" "20210701" "20210801" "20210901" "20211001" "20211101" "20211201" "20220101"
-    task ei_get_nwp
-      trigger ../timers/start/ymd:YMD >= ../monthly:YMD
-    family last
-      trigger ../timers/start/ymd:YMD > ../monthly:YMD and ../monthly:YMD <= ../daily:YMD + 2 and ei_get_nwp == complete
-    endfamily
-  endfamily
-  family daily
-    repeat date YMD 19790101 20220101 1
-    family init
-      trigger ../../trigger_ecflow_1442:FIRE_YMD >= ../daily:YMD
-      task const_prep
-    endfamily
-    task ic
-    family forcings
-      trigger init == complete and ic == complete
-      task ws
-      task rh
-      task tt
-      task pr
-      task sc
-      task cc
-    endfamily
-    task ecfire
-      trigger init == complete and forcings == complete
-    task update_latest
-      trigger ecfire == complete
-    task ei_tar
-      trigger ecfire == complete
-    task ei_arch
-      trigger ei_tar == complete
-    task ei_clean
-      trigger ei_arch == complete
-    family last
-      trigger ../../trigger_ecflow_1442:FIRE_YMD > ../daily:YMD and init == complete and ic == complete and forcings == complete and ecfire == complete and update_latest == complete and ei_tar == complete and ei_arch == complete and ei_clean == complete
-    endfamily
-  endfamily
-endsuite
-# enddef
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_867.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_867.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_867.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/ECFLOW_867.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite trigger_ecflow_867
-  family f1.1
-    task t1
-  endfamily
-  family f2
-    task t1
-      trigger ../f1.1/t1 eq complete
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/all_trigger_examples.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/all_trigger_examples.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/all_trigger_examples.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/all_trigger_examples.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-suite trigger_examples_all
-   limit top_level_limit 20
-   task a
-      event EVENT
-      meter METER 1 9 5
-      edit  VAR_DATE 20170701
-      edit  VAR_STRING "captain scarlett"      # This is not convertible to an integer, if referenced will use '0'
-      late -c +02:00                           # add late flag if task takes longer than 2 hours to complete
-  family f1
-      edit SLEEP 2
-      repeat string NAME a b c d e f              # This has values: a(0),b(1), c(3), d(4), e(5), f(6) i.e. index
-      family f2
-         repeat integer VALUE 5 10                # This has values: 5,6,7,8,9,10
-         family f3
-            repeat enumerated red green blue      # red(0), green(1), blue(2)
-            task t1
-               repeat date DATE 19991230 20000102  # This has values: 19991230,19991231,20000101,20000102
-               trigger :VALUE == 5 and :NAME == 0 and :SLEEP == 2 # references f2:VALUE,f1:NAME,f1:SLEEP new for 4.7.0 release
-         endfamily
-      endfamily
-   endfamily
-   family f2
-      inlimit /trigger_examples_all:top_level_limit
-      task event_meter
-          trigger /trigger_examples_all/a:EVENT == set and /trigger_examples_all/a:METER >= 6
-      task variable
-          trigger /trigger_examples_all/a:VAR_DATE >= 20170801 and /trigger_examples_all/a:VAR_STRING == 0
-      task repeat_string
-          trigger /trigger_examples_all/f1:NAME >= 4
-      task repeat_integer
-          trigger /trigger_examples_all/f1/f2:VALUE >= 7
-      task repeat_date
-          trigger /trigger_examples_all/f1/f2/f3/t1:DATE >= 19991231
-      task repeat_date_arithmitic
-          # Using plus/minus on a repeat DATE will use date arithmetic
-          # Since the starting value of DATE is 19991230, this task will run
-          # straight away
-          trigger /trigger_examples_all/f1/f2/f3/t1:DATE - 1 == 19991229
-      task use_repeat_date_yyyy
-          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_YYYY == 2000    # DATE_YYYY(year)is a generated variable for repeat date DATE 19991230 20000102
-      task use_repeat_date_generated_mm
-          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_MM == 2         # DATE_MM(month) is a generated variable for repeat date DATE 19991230 20000102
-      task use_repeat_date_generated_dd
-          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_DD == 30        # DATE_DD(day of the month) is a generated variable for repeat date DATE 19991230 20000102
-      task use_repeat_date_generated_dow
-          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_DOW == 0        # DATE_MM(day of week, 0-sunday,1-monday,etc) is a generated variable for repeat date DATE 19991230 20000102
-      task use_repeat_date_generated_julian
-          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_JULIAN > cal::date_to_julian(/trigger_examples_all/a:VAR_DATE)  # DATE_JULIAN(the julian of the date) is a generated variable for repeat date DATE 19991230 20000102
-      task with_trigger_that_ref_a_limit
-          trigger /trigger_examples_all:top_level_limit < 5        # low priority task, only valid when system is not loaded
-      task trigger_with_ref_to_late_flag
-          trigger /trigger_examples_all/a<flag>late                # Only triggers if task /trigger_examples_all/a is late
-      task trigger_with_ref_to_zombie_flag
-          trigger /trigger_examples_all/a<flag>zombie              # Only triggers if task /trigger_examples_all/a is a zombie
-      task trigger_with_ref_to_archived_flag
-          trigger /trigger_examples_all<flag>archived              # Only triggers if family /trigger_examples_all is archived -> only family/suite can be archived
-   endfamily
-   family time_trigger
-      trigger /trigger_examples_all:DOW == 0  or /trigger_examples_all:DOW == 1   # DOW is a generated variable on the suite representing DAY of the week. i.e Sundày and Monday in this case
-      task with_time
-         trigger /trigger_examples_all:TIME > 1330                 # TIME is a generated variable on the suite , same as time > 13:30
-   endfamily
- endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/anded_ored.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/anded_ored.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/anded_ored.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/anded_ored.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite trigger_anded
- family f
- 	task t1
- 	task t2
-	task a             
-      	event eventName 
- 	task b             
-			trigger t1  == complete       # a comment at end of trigger
-			trigger -a t2  == complete    # a comment at end of trigger
-			trigger -o a  == complete     # a comment at end of trigger
- endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/complex_hier.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/complex_hier.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/complex_hier.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/complex_hier.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-# test node referencing in triggers
-#      o/ <node> == complete    i.e   a == complete   sibling    
-#      o/ ./<node> == complete  i.e  ./a == complete  sibling
-#      o/ ../<node> == complete i.e  ../a == complete means trigger nodes parent
-suite trigger_s0
-  edit FIRE_YMD '19000101'
-  task t1
-endsuite
-suite trigger_s1
-  family f1
-     trigger f2/f3/f4/a == complete or ../trigger_s0:FIRE_YMD == 19000101  # allow relative suite access
-     family f2
-        family f3
-           family f4
-              task a
-                 event 1 theEventName
-                 meter myMeter 0 100
-                 trigger ./b == complete or c == complete or ../f4 == complete or ../../f3 == complete or ../../../f2 == aborted 
-               task b
-                  trigger ../../../../../trigger_s0 == complete or  ../../../../../trigger_s0/t1<flag>late
-               task c
-                  trigger ../../../../../trigger_s0:FIRE_YMD == 10 
-            endfamily   
-         endfamily
-      endfamily
-   endfamily
-   family f0
-      task c
-         # The initial .. means parents parent( i.e /trigger_s1 in this case)
-         # i.e task 'c' parents parent is suite 'trigger_s1'
-         trigger  ../f1/f2/f3/f4/a == complete
-         complete ../f1/f2/f3/f4/a:myMeter >= 10
-      family f1
-         family f2
-            family f3
-               family f4
-                  # ..             -> f3 level
-                  # ../..          -> f2 level
-                  # ../../..       -> f1 level
-                  # ../../../..    -> f0 level
-                  # ../../../../.. -> suite level
-                  trigger ../../../../f1/f2/f3/f4/a == complete or ../../../../../trigger_s1/f1/f2/f3/f4/a == complete or ../../../../../trigger_s0 == complete
-            endfamily
-         endfamily
-      endfamily
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/complex_trigger.txt 5.13.0-1/ANode/test/parser/data/good_defs/trigger/complex_trigger.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/complex_trigger.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/complex_trigger.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-extern /a/b/c/d         
-extern /a/b/c/d/e:event        
-extern /a/b/c/d/e:meter        
-
-suite trigger_complex
-  edit int_var 20
-  family familyName
-   		task a
-        	event 1 theEventName
-         	meter myMeter 0 100
-   		task b
-     	family heir_familyName
-         	task taskName0
-            	event 0 
-            	event 1 eventName
-            	meter myMeter 0 100
-      	endfamily
-   endfamily
-   family familyName1
-   		trigger familyName == complete                      # this is a comment
-        repeat date YMD 20090331 20121212 1 # status 0
-        task ref_parent_var_without_path
-        	trigger :YMD < 20121212 and :int_var < 40
-   		task a
-         	event 1 theEventName
-         	event aEvent
-         	meter myMeter 0 100
-   		task b
-   			trigger ./a == unknown
-   		task c
-   			trigger ../familyName/a == complete
-   		task d
-   			trigger ../familyName/b != aborted
-   		task e
-   			trigger (a == complete and b == complete)
-        task ee
-            trigger (a == complete AND b == complete)
-   		task f
-   			trigger (a == complete and b == complete OR ../familyName/a == complete)
-   		task g
-   			trigger a:theEventName and a:aEvent
-   		task h
-   			trigger a:myMeter >= 10
-   		task i
-   			trigger ../familyName/a:myMeter <= 30
-   		task j
-   			trigger a == complete                      # this is a comment
-   		task k
-   		    trigger (a == complete AND b == complete) or (c == complete && d == complete)
-   		task l
-   			trigger (a == complete and b == complete) OR ../familyName/a:theEventName == set
-        task ll
-            trigger (a == complete and b == complete) || ../familyName/a:theEventName == set
-   		task m
-   			trigger ../familyName/heir_familyName/taskName0 == complete
-   		task n
-   			trigger ../familyName/heir_familyName/taskName0:myMeter >= 10  	     # relative path
-  		task o
-   			trigger /trigger_complex/familyName/heir_familyName/taskName0:myMeter >= 10  # absolute path
-  		task p
-   			trigger /a/b/c/d == complete  		                                   # extern path
-  		task q
-   			trigger /a/b/c/d/e:event == set  		                                # extern event path
- 		task r
-   			trigger /a/b/c/d/e:meter le 30		                                   # extern meter path
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/extension.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/extension.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/extension.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/extension.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
- suite trigger_extension
-  family f
-  	    task b
-  	    task c
-   		task a
-   			trigger a == complete and \
-   			        b == complete and\
-   			        c == complete
-   endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/late.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/late.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/late.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/late.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite trigger_late_flag
-    family f1
-        task t
-        task t1
-            event event
-    endfamily
-    family anon    
-        task t1
-           trigger /trigger_late_flag/f1/t<flag>late
-        task t2
-           trigger /trigger_late_flag/f1/t1:event
-         task t3
-           trigger /<flag>late  # late flag set on Defs. Since defs is alawys there, does not need extern
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/limit.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/limit.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/limit.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/limit.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-extern /limits:c1a
-extern /limits:linux_cluster
-
-suite trigger_limit
-    limit sg1  100
-    limit mars 100
-endsuite
-
-suite trigger_limit_obs
-    inlimit /limits:c1a
-    family limits
-        limit hpcd 20
-    endfamily
-    
-    family anon    
-        inlimit limits:hpcd       
-        task t1
-            inlimit /trigger_limit:sg1        # another suite limit
-            trigger /trigger_limit:sg1 < 30
-        task t2
-            inlimit /trigger_limit_obs/limits:hpcd      # This suite limit
-            trigger /trigger_limit_obs/limits:hpcd > 10
-        task t3
-            inlimit /limits:c1a           # extern suite limit
-            trigger /limits:c1a > 10
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/relative.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/relative.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/relative.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/relative.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-# test node referencing in triggers
-#      o/ <node> == complete    i.e   a == complete   means sibling
-#      o/ ./<node> == complete  i.e  ./a == complete  means sibling
-#      o/ ../<node> == complete i.e  ../a == complete means trigger nodes parent
-suite trigger_relative_s
-endsuite
-suite trigger_relative
-  family f1
-     trigger f2/f3/f4/a == complete
-     family f2
-        trigger ../f1 == complete
-        family f3
-           trigger f4/a == complete
-           family f4
-              task a
-           endfamily   
-        endfamily
-     endfamily
-  endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/simple_trigger.txt 5.13.0-1/ANode/test/parser/data/good_defs/trigger/simple_trigger.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/simple_trigger.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/simple_trigger.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite trigger_simple
-    family f
-		task a             
-         	event eventName 
-    	task b             
-   			trigger a  == complete                  # a comment at end of trigger
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/trigger/trigger_references.def 5.13.0-1/ANode/test/parser/data/good_defs/trigger/trigger_references.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/trigger/trigger_references.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/trigger/trigger_references.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite trigger_reference
-  family acq
-    task data
-      trigger wait/wait:data
-    family wait
-      task wait
-        event data
-    endfamily
-  endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/variable/alias.def 5.13.0-1/ANode/test/parser/data/good_defs/variable/alias.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/variable/alias.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/variable/alias.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-#  
-defs_state MIGRATE
-
-# The file can be of different styles:
-#    DEFS: This is the structure only (default), 
-#          when we write out defs to disk, this will exclude aliases.
-#          Hence we use 
-#             defs_state MIGRATE
-#          So that when *testing*, we write out the defs in the state state in meant to be loaded
-#   STATE: structure + state
-#   MIGRATE: structure + state (No checking, and no externs )
-    
-# ===============================================================================
-# This will test that for alias we allow _variables_ names *without* checking
-# i.e for tasks EDACLASS:"od" would be an illegal variable name
-# ===============================================================================
-suite alias
-  task t1
-    alias alias0
-    
-         edit VAR  "value !£$%^&*() ~@: ?><,."   #comment
-   
-         edit VAR1 '123'
-   
-         edit VAR2 value2
-   
-         edit VAR3 ""
-         edit VAR55 ''
-         edit VAR56 '#'
-         edit VAR57 "#"
-         
-         # alias show allow variable names with invalid names
-         edit name:1 '1'
-         edit namx$1 '1'
-         
-         
-        edit DO_PUSH_TO_WEB:yes 'yes'
-        edit ECF_HOME:0 '/vol/emos_nc/output'
-        edit ECF_OUT:0 '/vol/emos_nc/output'
-        edit EDACLASS:"od" 'od'
-        edit EDACLASS:undef 'od'
-        edit EDAEXPVER:"0001" '0001'
-        
-    endalias
-endsuite
- 
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/variable/duplicate.def 5.13.0-1/ANode/test/parser/data/good_defs/variable/duplicate.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/variable/duplicate.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/variable/duplicate.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-suite edit_duplicate
-   edit VAR2 value2
-   edit VAR2 value3     # allow duplicates to update the last value
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/variable/variable.txt 5.13.0-1/ANode/test/parser/data/good_defs/variable/variable.txt
--- 5.12.4-1/ANode/test/parser/data/good_defs/variable/variable.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/variable/variable.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-suite edit_variable
- 
-   edit SMSURLCMD '${BROWSER:=firefox} -new-tab %SMSURLBASE%/%SMSURL%'
-   
-   edit VAR  "value !£$%^&*() ~@: ?><,."
-   
-   edit VAR1 '123'
-   
-   edit VAR2 value2
-   
-   edit VAR3 ""
-   edit VAR55 ''
-   edit VAR56 '#'
-   edit VAR57 "#"
-
-endsuite
-
-suite edit_variable_s1
- 
-   edit SMSURLCMD '${BROWSER:=firefox} -new-tab %SMSURLBASE%/%SMSURL%'; edit VAR  "value !£$%^&*() ~@: ?><,."
-   
-   edit VAR1 '123'; edit VAR2 value2
-   
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/verify/verify.def 5.13.0-1/ANode/test/parser/data/good_defs/verify/verify.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/verify/verify.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/verify/verify.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,31 +0,0 @@
-suite verify
-   verify complete:3 
-   verify unknown:3 
-   verify queued:3 
-   verify aborted:3 
-   verify submitted:3 
-    verify active:3 
-   family f
-    	verify complete:3 
-   		verify unknown:3 
-   		verify queued:3 
-   		verify aborted:3 
-   		verify submitted:3 
-   		verify active:3 
-      task t1
-    		verify complete:3 
-   			verify unknown:3 
-   			verify queued:3 
-   			verify aborted:3 
-   			verify submitted:3 
-    			verify active:3 
-      task t2
-    		verify complete:3 
-   			verify unknown:3 
-   			verify queued:3 
-   			verify aborted:3 
-   			verify submitted:3 
-   			verify active:3 
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs/zombie/zombie.def 5.13.0-1/ANode/test/parser/data/good_defs/zombie/zombie.def
--- 5.12.4-1/ANode/test/parser/data/good_defs/zombie/zombie.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs/zombie/zombie.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,33 +0,0 @@
-suite zombie
-   zombie ecf:fob:init:100
-   zombie ecf_pid:fob:init:100
-   zombie ecf_pid_passwd:fob:init:100
-   zombie ecf_passwd:fob:init:100
-   zombie path:fail:init:100
-   zombie user:adopt:meter:100
-
-   task t1
-     zombie ecf:remove::
-     zombie ecf_pid:remove::
-     zombie ecf_pid_passwd:remove::
-     zombie ecf_passwd:remove::
-     zombie path:block:wait:
-     zombie user:fob:complete:
-
-   task t2
-     zombie ecf:fob::
-     zombie ecf_pid:kill::
-     zombie ecf_pid_passwd:block::
-     zombie ecf_passwd:adopt::
-     zombie path:fail::
-     zombie user:adopt::
-    
-   task t3
-     zombie ecf:remove:init,event,meter,label,wait,queue,complete:2000     # comment
-     zombie ecf_pid:remove:init,event,meter,label,wait,queue,complete:2000     # comment
-     zombie ecf_pid_passwd:remove:init,event,meter,label,wait,queue,complete:2000     # comment
-     zombie ecf_passwd:remove:init,event,meter,label,wait,queue,complete:2000     # comment
-     zombie path:::0
-     zombie user:::0
-endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/good_defs_state/defs/defs_state.def 5.13.0-1/ANode/test/parser/data/good_defs_state/defs/defs_state.def
--- 5.12.4-1/ANode/test/parser/data/good_defs_state/defs/defs_state.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_defs_state/defs/defs_state.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-# 2.0.31 
-defs_state STATE state:unknown flag: state_change:17 modify_change:0 server_state:SHUTDOWN
-  edit ECF_MICRO '%'
-  edit ECF_HOME '/var/tmp/ma0/workspace'
diff -pruN 5.12.4-1/ANode/test/parser/data/good_node_defs/family/family.def 5.13.0-1/ANode/test/parser/data/good_node_defs/family/family.def
--- 5.12.4-1/ANode/test/parser/data/good_node_defs/family/family.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_node_defs/family/family.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-family test_local_actions # state:queued suspended:1
-   defstatus suspended
-   edit REMOTE_HOST 'eurydice'
-   edit WORKDIR ''
-   task action1 # state:queued suspended:1
-	  defstatus suspended
-   family f1 # state:queued suspended:1
-	  task a # state:queued suspended:1
-	  task b # state:queued suspended:1
-   endfamily
-endfamily
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_node_defs/suite/suite.def 5.13.0-1/ANode/test/parser/data/good_node_defs/suite/suite.def
--- 5.12.4-1/ANode/test/parser/data/good_node_defs/suite/suite.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_node_defs/suite/suite.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-# 
-suite suite #  begun:1 state:queued suspended:1
-	defstatus suspended
-	edit ECF_HOME '/scratch/ma/ma0/nightly'
-	task exp # state:queued
-		edit ECF_JOB_CMD 'python %ECF_JOB% 1> %ECF_JOBOUT% 2>&1'
-		label label_name "value"
-		meter meter 0 100 100
-		event event_fred
-	family test_local_actions # state:queued suspended:1
-		defstatus suspended
-		edit REMOTE_HOST 'eurydice'
-		edit WORKDIR ''
-		task action1 # state:queued suspended:1
-			defstatus suspended
-	endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/good_node_defs/task/task.def 5.13.0-1/ANode/test/parser/data/good_node_defs/task/task.def
--- 5.12.4-1/ANode/test/parser/data/good_node_defs/task/task.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/good_node_defs/task/task.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-task exp # state:queued
-  edit ECF_JOB_CMD 'python %ECF_JOB% 1> %ECF_JOBOUT% 2>&1'
-  label label_name "value"
-  meter meter 0 100 100
-  event event_fred
-  trigger 1 == 1
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/ECFLOW-417.def 5.13.0-1/ANode/test/parser/data/single_defs/ECFLOW-417.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/ECFLOW-417.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/ECFLOW-417.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite s1
-   repeat day 1
-   clock hybrid  
-   task t1
-      time 15:42
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/ealadin.def 5.13.0-1/ANode/test/parser/data/single_defs/ealadin.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/ealadin.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/ealadin.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,3671 +0,0 @@
-extern /limits:mars
-extern /limits:localhost
-extern /limits:c1b
-extern /limits:linux_cluster
-extern /limits:swarm
-extern /limits:ha_pp
-extern /limits:ecfs
-extern /limits:obs_get
-extern /limits:pdb
-extern /limits:q2diss
-extern /limits:pdb_bc
-extern /limits:q2diss_bc
-extern /limits:rebuild
-extern /o/main/12/fc
-extern /o/main/12/fc/model:step
-extern /o/main:YMD
-extern /o/main/18/fc
-extern /o/main/18/fc/model:step
-extern /o/main/00/fc
-extern /o/main/00/fc/model:step
-extern /o/main/06/fc
-extern /o/main/06/fc/model:step
-extern /o/main/12bc/fc
-extern /o/main/12bc/fc/model:step
-extern /o/main/18bc/fc
-extern /o/main/18bc/fc/model:step
-extern /o/main/00bc/fc
-extern /o/main/00bc/fc/model:step
-extern /o/main/06bc/fc
-extern /o/main/06bc/fc/model:step
-
-suite ealadin
-  #defstatus suspended
-  edit QUEUE 'ts'
-  edit QUEUE_EPILOG 'SC_QUEUE_EPILOG'
-  edit ECFCMD 'smssubmit %USER% %SCHOST% %ECFJOB% %ECFJOBOUT%'
-  edit ECFKILL 'smskill %USER% %SCHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
-  edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %ECFRID% %ECFJOB%'
-  edit LOGDIR '/s1a/emos_esuite/emos_data/0047/log'
-  edit ECFOUT '/s1a/emos_esuite/emos_data/0047/log'
-  edit THREADS_FRA '6'
-  edit THREADS_LBC '6'
-  edit EMOS_TIME_STEP_H 'undef'
-  edit STREAM 'undef'
-  edit ECF_URLBASE 'http://www.ecmwf.int'
-  edit NB_TASKS_FRA '38'
-  edit SCLOGDIR '/s1a/emos_esuite/emos_data/0047/log'
-  edit USER 'emos'
-  edit STHOST_BKUP '/s1b'
-  edit DATEMASK '*.*.*'
-  edit CALL_ECPDS 'false'
-  edit EXPVER '0047'
-  edit MEMBER '-1'
-  edit ECF_OUT '/vol/emos_nc/output'
-  edit FSFAMILY 'undef'
-  edit USE_YMD 'true'
-  edit ECF_URLCMD '${BROWSER:=firefox} -new-tab %ECF_URLBASE%/%ECF_URL%'
-  edit NB_TASKS_LBC '32'
-  edit DELTA_DAY '0'
-  edit STHOST '/s1a'
-  edit VERSION '%EXPVER%'
-  edit SCHOST_BKUP 'c1b'
-  edit ACCOUNT_FRA 'oesu'
-  edit MEM '2500'
-  edit EPSTYPE 'undef'
-  edit ACCOUNT_LBC 'oesu'
-  edit ALADIN_STEP '-1'
-  edit ECF_LOGHOST 'localhost'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit INIEXPVER '0001'
-  edit WSHOST 'localhost'
-  edit ECF_URL 'index.html'
-  edit THREADS '1'
-  edit SCHOST 'localhost'
-  edit ECF_LOGPORT '9316'
-  edit REAL_TIME '1'
-  edit FIRST_DAY '0'
-  inlimit /limits:localhost
-  family limits
-    defstatus complete
-    limit limiter 1
-    limit oper 7
-    limit bkup 7
-    limit clst 7
-    limit lbc 26
-    limit main 84
-    limit 927 21
-    limit subd 21
-    limit init 7
-  endfamily
-  family main
-    repeat date YMD 20100607 20201212 1
-    edit LOGTASK 'main'
-    edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-    edit ECPDS_STREAM 'JSN2'
-    edit DESTINATION 'FRA'
-    family 12
-      edit ACCOUNT '%ACCOUNT_FRA%'
-      edit NB_TASKS '%NB_TASKS_FRA%'
-      edit STREAM 'oper'
-      edit EMOS_BASE '1'
-      edit ECF_URL 'FRA/ALADIN/12'
-      inlimit /ealadin/limits:main
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/main:YMD
-        edit EMOS_BASE '1'
-        task external
-          defstatus complete
-          complete /o/main/12/fc eq complete or /o/main/12/fc/model:step gt 42
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 17:58
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 42 42
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 42 42
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 42 42
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../00/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 42 42
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 42 42
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 42 42
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../00/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../03/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 42 42
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 42 42
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 42 42
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../03/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 42 42
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '17:58'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '17:58'
-        limit mutex 1
-        inlimit prod:mutex
-        family fra
-          edit DESTINATION 'FRA'
-          edit ECF_URL 'FRA/ALADIN/12'
-          task ecpds
-            edit ECPDS_STREAM 'JSN2'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    family 18
-      edit ACCOUNT '%ACCOUNT_FRA%'
-      edit NB_TASKS '%NB_TASKS_FRA%'
-      edit STREAM 'scda'
-      edit EMOS_BASE '1'
-      edit ECF_URL 'FRA/ALADIN/18'
-      inlimit /ealadin/limits:main
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/main:YMD
-        edit EMOS_BASE '1'
-        task external
-          defstatus complete
-          complete /o/main/18/fc eq complete or /o/main/18/fc/model:step gt 60
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 00:00
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 60 60
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../00/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 60 60
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../00/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../03/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 60 60
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../03/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 42
-          edit ALADIN_STEP '42'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 45
-          edit ALADIN_STEP '45'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 48
-          edit ALADIN_STEP '48'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 51
-          edit ALADIN_STEP '51'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 54
-          edit ALADIN_STEP '54'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 57
-          edit ALADIN_STEP '57'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '00:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '00:00'
-        limit mutex 1
-        inlimit prod:mutex
-        family fra
-          edit DESTINATION 'FRA'
-          edit ECF_URL 'FRA/ALADIN/18'
-          task ecpds
-            edit ECPDS_STREAM 'JSN2'
-            edit ECPDS_OPER 'false'
-            edit CALL_ECPDS 'false'
-            edit TO_ECPDS 'false'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    family 00
-      edit ACCOUNT '%ACCOUNT_FRA%'
-      edit NB_TASKS '%NB_TASKS_FRA%'
-      edit DELTA_DAY '1'
-      edit STREAM 'oper'
-      edit EMOS_BASE '0'
-      edit ECF_URL 'FRA/ALADIN/00'
-      inlimit /ealadin/limits:main
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/main:YMD
-        edit EMOS_BASE '0'
-        task external
-          defstatus complete
-          complete /o/main/00/fc eq complete or /o/main/00/fc/model:step gt 54
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 06:01
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 54 54
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 54 54
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 54 54
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../00/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 54 54
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 54 54
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 54 54
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../00/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../03/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 54 54
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 54 54
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 54 54
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../03/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 42
-          edit ALADIN_STEP '42'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 45
-          edit ALADIN_STEP '45'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 48
-          edit ALADIN_STEP '48'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 51
-          edit ALADIN_STEP '51'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 54 54
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '06:01'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '06:01'
-        limit mutex 1
-        inlimit prod:mutex
-        family fra
-          edit DESTINATION 'FRA'
-          edit ECF_URL 'FRA/ALADIN/00'
-          task ecpds
-            edit ECPDS_STREAM 'JSN2'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    family 06
-      edit ACCOUNT '%ACCOUNT_FRA%'
-      edit NB_TASKS '%NB_TASKS_FRA%'
-      edit DELTA_DAY '1'
-      edit STREAM 'scda'
-      edit EMOS_BASE '0'
-      edit ECF_URL 'FRA/ALADIN/06'
-      inlimit /ealadin/limits:main
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/main:YMD
-        edit EMOS_BASE '0'
-        task external
-          defstatus complete
-          complete /o/main/06/fc eq complete or /o/main/06/fc/model:step gt 60
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 12:00
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 60 60
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../00/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 60 60
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../00/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../03/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-          family subd
-            trigger ./927 eq active or ./927 eq complete
-            inlimit /ealadin/limits:subd
-            family poly
-              edit DOM 'polyf'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family antg
-              edit DOM 'antig'
-              task 927
-                meter step -1 60 60
-            endfamily
-            family ncal
-              edit DOM 'ncal'
-              task 927
-                meter step -1 60 60
-            endfamily
-            task ecpds
-              defstatus complete
-              trigger ./poly==complete and ./antg==complete and ./ncal==complete
-              trigger -a ../../03/subd/ecpds eq complete
-              edit DOM 'polyf antig ncal'
-              label scheduled ""
-          endfamily
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 42
-          edit ALADIN_STEP '42'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 45
-          edit ALADIN_STEP '45'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 48
-          edit ALADIN_STEP '48'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 51
-          edit ALADIN_STEP '51'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 54
-          edit ALADIN_STEP '54'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-        family 57
-          edit ALADIN_STEP '57'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_FRA%'
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            inlimit /ealadin/limits:927
-            meter step -1 60 60
-          task ecpds
-            defstatus complete
-            trigger ./927 eq complete
-            trigger -a ../06/ecpds eq complete
-            edit ECPDS_AT '12:00'
-            edit DOM 'francecep'
-            label scheduled ""
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '12:00'
-        limit mutex 1
-        inlimit prod:mutex
-        family fra
-          edit DESTINATION 'FRA'
-          edit ECF_URL 'FRA/ALADIN/06'
-          task ecpds
-            edit ECPDS_STREAM 'JSN2'
-            edit ECPDS_OPER 'false'
-            edit CALL_ECPDS 'false'
-            edit TO_ECPDS 'false'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    task logfilestore
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit KEEPLOGS 'no'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
-      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
-      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit ECFOUT '/vol/emos_nc/output'
-    task logfiles
-      trigger ./12==complete and ./18==complete and ./00==complete and ./06==complete and ./logfilestore==complete
-      edit MOVE_TO_ECFS 'no'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
-      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
-      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit ECFOUT '/vol/emos_nc/output'
-      edit ACCOUNT 'oesu'
-      time 12:30
-  endfamily
-  family lbc
-    repeat date YMD 20100607 20201212 1
-    edit LOGTASK 'lbc'
-    family 12bc
-      task clean
-        edit ACCOUNT '%ACCOUNT_LBC%'
-        edit NB_TASKS '%NB_TASKS_LBC%'
-        edit STREAM 'oper'
-        edit EMOS_BASE '1'
-        inlimit /ealadin/limits:lbc
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/lbc:YMD
-        edit EMOS_BASE '1'
-        task external
-          defstatus complete
-          complete /o/main/12bc/fc eq complete or /o/main/12bc/fc/model:step gt 72
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 18:06
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 42
-          edit ALADIN_STEP '42'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 45
-          edit ALADIN_STEP '45'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 48
-          edit ALADIN_STEP '48'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 51
-          edit ALADIN_STEP '51'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 54
-          edit ALADIN_STEP '54'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 57
-          edit ALADIN_STEP '57'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 60
-          edit ALADIN_STEP '60'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 63
-          edit ALADIN_STEP '63'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 66
-          edit ALADIN_STEP '66'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 69
-          edit ALADIN_STEP '69'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '18:06'
-        limit mutex 1
-        inlimit prod:mutex
-        family hun
-          edit DESTINATION 'HUN'
-          edit ECF_URL 'HUN/ALADIN/1'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family czm
-          edit DESTINATION 'CZM'
-          edit ECF_URL 'CZM/ALADIN/1'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family sli
-          edit DESTINATION 'SLI'
-          edit ECF_URL 'SLI/ALADIN/1'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family aus
-          edit DESTINATION 'AUS'
-          edit ECF_URL 'AUS/ALADIN/1'
-          task ecpds
-            edit ECPDS_OPER 'false'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    family 18bc
-      task clean
-        edit ACCOUNT '%ACCOUNT_LBC%'
-        edit NB_TASKS '%NB_TASKS_LBC%'
-        edit STREAM 'SCDA'
-        edit EMOS_BASE '1'
-        inlimit /ealadin/limits:lbc
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/lbc:YMD
-        edit EMOS_BASE '1'
-        task external
-          defstatus complete
-          complete /o/main/18bc/fc eq complete or /o/main/18bc/fc/model:step gt 72
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 00:06
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 42
-          edit ALADIN_STEP '42'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 45
-          edit ALADIN_STEP '45'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 48
-          edit ALADIN_STEP '48'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 51
-          edit ALADIN_STEP '51'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 54
-          edit ALADIN_STEP '54'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 57
-          edit ALADIN_STEP '57'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 60
-          edit ALADIN_STEP '60'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 63
-          edit ALADIN_STEP '63'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 66
-          edit ALADIN_STEP '66'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 69
-          edit ALADIN_STEP '69'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '00:06'
-        limit mutex 1
-        inlimit prod:mutex
-        family hun
-          edit DESTINATION 'HUN'
-          edit ECF_URL 'HUN/ALADIN/1'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family czm
-          edit DESTINATION 'CZM'
-          edit ECF_URL 'CZM/ALADIN/1'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family sli
-          edit DESTINATION 'SLI'
-          edit ECF_URL 'SLI/ALADIN/1'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family aus
-          edit DESTINATION 'AUS'
-          edit ECF_URL 'AUS/ALADIN/1'
-          task ecpds
-            edit ECPDS_OPER 'false'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    family 00bc
-      task clean
-        edit ACCOUNT '%ACCOUNT_LBC%'
-        edit NB_TASKS '%NB_TASKS_LBC%'
-        edit DELTA_DAY '1'
-        edit STREAM 'oper'
-        edit EMOS_BASE '0'
-        inlimit /ealadin/limits:lbc
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/lbc:YMD
-        edit EMOS_BASE '0'
-        task external
-          defstatus complete
-          complete /o/main/00bc/fc eq complete or /o/main/00bc/fc/model:step gt 72
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 06:06
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 42
-          edit ALADIN_STEP '42'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 45
-          edit ALADIN_STEP '45'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 48
-          edit ALADIN_STEP '48'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 51
-          edit ALADIN_STEP '51'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 54
-          edit ALADIN_STEP '54'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 57
-          edit ALADIN_STEP '57'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 60
-          edit ALADIN_STEP '60'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 63
-          edit ALADIN_STEP '63'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 66
-          edit ALADIN_STEP '66'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 69
-          edit ALADIN_STEP '69'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '06:06'
-        limit mutex 1
-        inlimit prod:mutex
-        family hun
-          edit DESTINATION 'HUN'
-          edit ECF_URL 'HUN/ALADIN/0'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family czm
-          edit DESTINATION 'CZM'
-          edit ECF_URL 'CZM/ALADIN/0'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family sli
-          edit DESTINATION 'SLI'
-          edit ECF_URL 'SLI/ALADIN/0'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family aus
-          edit DESTINATION 'AUS'
-          edit ECF_URL 'AUS/ALADIN/0'
-          task ecpds
-            edit ECPDS_OPER 'false'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    family 06bc
-      task clean
-        edit ACCOUNT '%ACCOUNT_LBC%'
-        edit NB_TASKS '%NB_TASKS_LBC%'
-        edit DELTA_DAY '1'
-        edit STREAM 'SCDA'
-        edit EMOS_BASE '0'
-        inlimit /ealadin/limits:lbc
-      family ref
-        defstatus complete
-        complete /o/main:YMD gt /ealadin/lbc:YMD
-        edit EMOS_BASE '0'
-        task external
-          defstatus complete
-          complete /o/main/06bc/fc eq complete or /o/main/06bc/fc/model:step gt 72
-          trigger 0==1
-        family timed
-          complete /ealadin:REAL_TIME eq 0
-          time 12:06
-          task dummy
-            complete 1==1
-        endfamily
-      endfamily
-      family prl
-        trigger ref eq complete
-        family 00
-          edit ALADIN_STEP '00'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 03
-          edit ALADIN_STEP '03'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 06
-          edit ALADIN_STEP '06'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 09
-          edit ALADIN_STEP '09'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 12
-          edit ALADIN_STEP '12'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 15
-          edit ALADIN_STEP '15'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 18
-          edit ALADIN_STEP '18'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 21
-          edit ALADIN_STEP '21'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 24
-          edit ALADIN_STEP '24'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 27
-          edit ALADIN_STEP '27'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 30
-          edit ALADIN_STEP '30'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 33
-          edit ALADIN_STEP '33'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 36
-          edit ALADIN_STEP '36'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 39
-          edit ALADIN_STEP '39'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 42
-          edit ALADIN_STEP '42'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 45
-          edit ALADIN_STEP '45'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 48
-          edit ALADIN_STEP '48'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 51
-          edit ALADIN_STEP '51'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 54
-          edit ALADIN_STEP '54'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 57
-          edit ALADIN_STEP '57'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 60
-          edit ALADIN_STEP '60'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 63
-          edit ALADIN_STEP '63'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 66
-          edit ALADIN_STEP '66'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-        family 69
-          edit ALADIN_STEP '69'
-          task init
-            inlimit /ealadin/limits:init
-          task 901
-            trigger init ==complete
-            edit THREADS '%THREADS_LBC%'
-            meter step -1 72 72
-          task 927
-            trigger ./901==complete
-            edit DOM 'francecep'
-            meter step -1 72 72
-        endfamily
-      endfamily
-      family prod
-        defstatus complete
-        trigger prl eq complete
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit TO_ECFS 'false'
-        edit ECPDS_AT '12:06'
-        limit mutex 1
-        inlimit prod:mutex
-        family hun
-          edit DESTINATION 'HUN'
-          edit ECF_URL 'HUN/ALADIN/0'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family czm
-          edit DESTINATION 'CZM'
-          edit ECF_URL 'CZM/ALADIN/0'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family sli
-          edit DESTINATION 'SLI'
-          edit ECF_URL 'SLI/ALADIN/0'
-          task ecpds
-            label scheduled ""
-        endfamily
-        family aus
-          edit DESTINATION 'AUS'
-          edit ECF_URL 'AUS/ALADIN/0'
-          task ecpds
-            edit ECPDS_OPER 'false'
-            label scheduled ""
-        endfamily
-      endfamily
-    endfamily
-    task logfilestore
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit KEEPLOGS 'no'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
-      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
-      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit ECFOUT '/vol/emos_nc/output'
-    task logfiles
-      trigger ./12bc==complete and ./18bc==complete and ./00bc==complete and ./06bc==complete and ./logfilestore==complete
-      edit MOVE_TO_ECFS 'no'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
-      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
-      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit ECFOUT '/vol/emos_nc/output'
-      edit ACCOUNT 'oesu'
-      time 12:30
-  endfamily
-  family lag
-    repeat date YMD 20100607 20201212 1
-    edit LOGTASK 'lag'
-    family 12
-      task clean
-      task ecpds
-        trigger /ealadin/main/12 eq complete
-        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
-        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit ECPDS_STREAM 'JSN2'
-        edit DESTINATION 'FRA'
-        edit CALL_ECPDS 'false'
-        edit ECPDS_AT '12:06'
-        edit ECPDS_OPER 'false'
-        edit TO_ECFS 'true'
-        edit ECF_URL ' FRA/ALADIN/12'
-        edit TO_ECPDS 'false'
-        edit ACCOUNT '%ACCOUNT_FRA%'
-        edit NB_TASKS '%NB_TASKS_FRA%'
-        edit STREAM 'oper'
-        edit EMOS_BASE '1'
-        inlimit /ealadin/limits:main
-        label scheduled ""
-    endfamily
-    family 18
-      task clean
-      task ecpds
-        trigger /ealadin/main/18 eq complete
-        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
-        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit ECPDS_STREAM 'JSN2'
-        edit DESTINATION 'FRA'
-        edit CALL_ECPDS 'false'
-        edit ECPDS_AT '17:58'
-        edit ECPDS_OPER 'false'
-        edit TO_ECFS 'true'
-        edit ECF_URL ' FRA/ALADIN/18'
-        edit TO_ECPDS 'false'
-        edit ACCOUNT '%ACCOUNT_FRA%'
-        edit NB_TASKS '%NB_TASKS_FRA%'
-        edit STREAM 'scda'
-        edit EMOS_BASE '1'
-        inlimit /ealadin/limits:main
-        label scheduled ""
-    endfamily
-    family 00
-      task clean
-      task ecpds
-        trigger /ealadin/main/00 eq complete
-        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
-        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit ECPDS_STREAM 'JSN2'
-        edit DESTINATION 'FRA'
-        edit CALL_ECPDS 'false'
-        edit ECPDS_AT '00:00'
-        edit ECPDS_OPER 'false'
-        edit TO_ECFS 'true'
-        edit ECF_URL ' FRA/ALADIN/00'
-        edit TO_ECPDS 'false'
-        edit ACCOUNT '%ACCOUNT_FRA%'
-        edit NB_TASKS '%NB_TASKS_FRA%'
-        edit DELTA_DAY '1'
-        edit STREAM 'oper'
-        edit EMOS_BASE '0'
-        inlimit /ealadin/limits:main
-        label scheduled ""
-    endfamily
-    family 06
-      task clean
-      task ecpds
-        trigger /ealadin/main/06 eq complete
-        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
-        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
-        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-        edit ECPDS_STREAM 'JSN2'
-        edit DESTINATION 'FRA'
-        edit CALL_ECPDS 'false'
-        edit ECPDS_AT '06:01'
-        edit ECPDS_OPER 'false'
-        edit TO_ECFS 'true'
-        edit ECF_URL ' FRA/ALADIN/06'
-        edit TO_ECPDS 'false'
-        edit ACCOUNT '%ACCOUNT_FRA%'
-        edit NB_TASKS '%NB_TASKS_FRA%'
-        edit DELTA_DAY '1'
-        edit STREAM 'scda'
-        edit EMOS_BASE '0'
-        inlimit /ealadin/limits:main
-        label scheduled ""
-    endfamily
-    task logfilestore
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit KEEPLOGS 'no'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
-      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
-      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit ECFOUT '/vol/emos_nc/output'
-    task logfiles
-      trigger ./12==complete and ./18==complete and ./00==complete and ./06==complete and ./logfilestore==complete
-      edit MOVE_TO_ECFS 'no'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
-      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
-      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit ECFOUT '/vol/emos_nc/output'
-      edit ACCOUNT 'oesu'
-      time 12:30
-  endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/error.def 5.13.0-1/ANode/test/parser/data/single_defs/error.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/error.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/error.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,284 +0,0 @@
-
-suite ecflow_1182
- repeat day 1
- family hc00
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc01
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc02
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
- family hc03
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc04
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc05
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
- family hc06
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc07
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc08
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc09
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc10
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc11
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc12
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc13
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc14
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc15
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc16
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc17
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc18
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc19
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc20
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc21
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc22
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc23
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc24
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc25
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc26
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-   family hc27
-   defstatus queued
-   repeat integer HYEAR 1993 2015 1
-   time +00:01
-   task uk2fdb
-      defstatus queued
-   task extrafields_uk
-      defstatus complete
-      trigger uk2fdb==complete
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/mega.def 5.13.0-1/ANode/test/parser/data/single_defs/mega.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/mega.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/mega.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,194064 +0,0 @@
-# 4.0.6
-extern /e_36r1/main/00/an
-extern /e_36r1/main/00/an/4dvar
-extern /e_36r1/main/00/an/4dvar/ifstraj:finalwave
-extern /e_36r1/main/00/an/4dvar/uptraj_0
-extern /e_36r1/main/00/an/surf_anal/slwet
-extern /e_36r1/main/00/an/surf_anal/sst
-extern /e_36r1/main/00/fc/model
-extern /e_36r1/main/00/getreq
-extern /e_36r1/main/00/obs/get/get_stor
-extern /e_36r1/main/00/prod/240/prod_wparam
-extern /e_36r1/main/00dc/fc/model
-extern /e_36r1/main/00dc/fc/model:step
-extern /e_36r1/main/12/an
-extern /e_36r1/main/12/an/4dvar
-extern /e_36r1/main/12/an/4dvar/ifstraj:finalwave
-extern /e_36r1/main/12/an/4dvar/uptraj_0
-extern /e_36r1/main/12/an/surf_anal/slwet
-extern /e_36r1/main/12/an/surf_anal/sst
-extern /e_36r1/main/12/fc/model
-extern /e_36r1/main/12/getreq
-extern /e_36r1/main/12/obs/get/get_stor
-extern /e_36r1/main/12/prod/240/prod_wparam
-extern /e_36r1/main/12dc/fc/model
-extern /e_36r1/main/12dc/fc/model:step
-extern /e_36r1/main:YMD
-extern /ecgems/f93i/an/lag/00/archive
-extern /ecgems/f93i/an/lag:YMD
-extern /emc_36r1/main/00/legB/prod
-extern /emc_36r1/main/12/legB/prod
-extern /limits:c1a
-extern /limits:c1b
-extern /limits:hpce
-extern /limits:hpcf
-extern /limits:linux_cluster
-extern /limits:mars
-extern /limits:obs_get
-extern /limits:pdb
-extern /limits:pdb_bc
-extern /limits:prod
-extern /limits:q2diss
-extern /limits:q2diss_bc
-extern /limits:swarm
-extern /mc/main/00
-extern /mc/main/00/legA/fc
-extern /mc/main/00/legB/fc
-extern /mc/main/00/legB/postproc
-extern /mc/main/12/legA/fc
-extern /mc/main/12/legB/fc
-extern /mc/main/12/legB/postproc
-extern /mc/main:YMD
-extern /o/lag/00/archive/anml
-extern /o/lag/00/archive/anpl
-extern /o/lag/00/archive/ansfc
-extern /o/lag/00/archive/fc048
-extern /o/lag/00/archive/fc240
-extern /o/lag/00/archive/obs
-extern /o/lag/00/archive/sst
-extern /o/lag/00/fb/feedback/matchup
-extern /o/lag/00/satim
-extern /o/lag/00/verif
-extern /o/lag/00dc/archive
-extern /o/lag/00dc/fb/feedback/matchup
-extern /o/lag/06/archive
-extern /o/lag/06/fb/feedback/matchup
-extern /o/lag/06bc/archive
-extern /o/lag/06bc/fb/feedback/matchup
-extern /o/lag/12/archive/fc240
-extern /o/lag/12/archive/obs
-extern /o/lag/12/fb/feedback/matchup
-extern /o/lag/12/satim
-extern /o/lag/12/verif
-extern /o/lag/12dc/archive
-extern /o/lag/12dc/fb/feedback/matchup
-extern /o/lag/18/archive
-extern /o/lag/18/fb/feedback/matchup
-extern /o/lag/18bc/archive
-extern /o/lag/18bc/fb/feedback/matchup
-extern /o/lag:YMD
-extern /o/main/00/an
-extern /o/main/00/an/4dvar
-extern /o/main/00/an/surf_anal
-extern /o/main/00/fc
-extern /o/main/00/fc/clean
-extern /o/main/00/fc/model
-extern /o/main/00/fc/model:step
-extern /o/main/00/prod/18an/derived_param
-extern /o/main/00/prod2diss/oper
-extern /o/main/00/prod2diss/sched/240
-extern /o/main/00/prod2diss/wave
-extern /o/main/00dc/an/4dvar
-extern /o/main/00dc/an/surf_anal
-extern /o/main/00dc/fc/clean
-extern /o/main/00dc/fc/model
-extern /o/main/06bc/an/4dvar
-extern /o/main/06bc/an/surf_anal
-extern /o/main/06bc/fc/model
-extern /o/main/06bc/prod2diss/oper
-extern /o/main/06bc/prod2diss/sched/72
-extern /o/main/12/an
-extern /o/main/12/an/4dvar
-extern /o/main/12/an/surf_anal
-extern /o/main/12/fc
-extern /o/main/12/fc/model
-extern /o/main/12/fc/model:step
-extern /o/main/12/obs/get/get_stor
-extern /o/main/12/prod/06an/derived_param
-extern /o/main/12/prod2diss/oper
-extern /o/main/12/prod2diss/sched/240
-extern /o/main/12/prod2diss/wave
-extern /o/main/12dc/an/4dvar
-extern /o/main/12dc/an/surf_anal
-extern /o/main/12dc/fc/model
-extern /o/main/12dc/obs/get/get_stor
-extern /o/main/18bc/an/4dvar
-extern /o/main/18bc/an/surf_anal
-extern /o/main/18bc/fc/model
-extern /o/main/18bc/prod2diss/oper
-extern /o/main/18bc/prod2diss/sched/72
-extern /o/main:YMD
-extern /pp1/main/extractions/dc00/airs
-extern /pp1/main/extractions/dc00/amsr
-extern /pp1/main/extractions/dc00/atap
-extern /pp1/main/extractions/dc00/ateu
-extern /pp1/main/extractions/dc00/atov
-extern /pp1/main/extractions/dc00/bice
-extern /pp1/main/extractions/dc00/eas1
-extern /pp1/main/extractions/dc00/emer
-extern /pp1/main/extractions/dc00/ers1_ra
-extern /pp1/main/extractions/dc00/ers1_wa
-extern /pp1/main/extractions/dc00/ers1_wi
-extern /pp1/main/extractions/dc00/grad
-extern /pp1/main/extractions/dc00/grst
-extern /pp1/main/extractions/dc00/ice/ice_fdb_c1b
-extern /pp1/main/extractions/dc00/nonbin
-extern /pp1/main/extractions/dc00/qsca
-extern /pp1/main/extractions/dc00/rado
-extern /pp1/main/extractions/dc00/rtovs
-extern /pp1/main/extractions/dc00/sbuv
-extern /pp1/main/extractions/dc00/smin
-extern /pp1/main/extractions/dc00/snow
-extern /pp1/main/extractions/dc00/ssbt
-extern /pp1/main/extractions/dc00/sst/sst_fdb_c1b
-extern /pp1/main/extractions/dc00/stor
-extern /pp1/main/extractions/dc00/trmm
-extern /pp1/main/extractions/dc06/airs
-extern /pp1/main/extractions/dc06/amsr
-extern /pp1/main/extractions/dc06/atap
-extern /pp1/main/extractions/dc06/ateu
-extern /pp1/main/extractions/dc06/atov
-extern /pp1/main/extractions/dc06/bice
-extern /pp1/main/extractions/dc06/eas1
-extern /pp1/main/extractions/dc06/emer
-extern /pp1/main/extractions/dc06/ers1_ra
-extern /pp1/main/extractions/dc06/ers1_wa
-extern /pp1/main/extractions/dc06/ers1_wi
-extern /pp1/main/extractions/dc06/grad
-extern /pp1/main/extractions/dc06/grst
-extern /pp1/main/extractions/dc06/ice/ice_fdb_c1b
-extern /pp1/main/extractions/dc06/nonbin
-extern /pp1/main/extractions/dc06/qsca
-extern /pp1/main/extractions/dc06/rado
-extern /pp1/main/extractions/dc06/rtovs
-extern /pp1/main/extractions/dc06/sbuv
-extern /pp1/main/extractions/dc06/smin
-extern /pp1/main/extractions/dc06/snow
-extern /pp1/main/extractions/dc06/ssbt
-extern /pp1/main/extractions/dc06/sst/sst_fdb_c1b
-extern /pp1/main/extractions/dc06/stor
-extern /pp1/main/extractions/dc06/trmm
-extern /pp1/main/extractions/dc12/airs
-extern /pp1/main/extractions/dc12/amsr
-extern /pp1/main/extractions/dc12/atap
-extern /pp1/main/extractions/dc12/ateu
-extern /pp1/main/extractions/dc12/atov
-extern /pp1/main/extractions/dc12/bice
-extern /pp1/main/extractions/dc12/eas1
-extern /pp1/main/extractions/dc12/emer
-extern /pp1/main/extractions/dc12/ers1_ra
-extern /pp1/main/extractions/dc12/ers1_wa
-extern /pp1/main/extractions/dc12/ers1_wi
-extern /pp1/main/extractions/dc12/grad
-extern /pp1/main/extractions/dc12/grst
-extern /pp1/main/extractions/dc12/ice/ice_fdb_c1b
-extern /pp1/main/extractions/dc12/nonbin
-extern /pp1/main/extractions/dc12/qsca
-extern /pp1/main/extractions/dc12/rado
-extern /pp1/main/extractions/dc12/rtovs
-extern /pp1/main/extractions/dc12/sbuv
-extern /pp1/main/extractions/dc12/smin
-extern /pp1/main/extractions/dc12/snow
-extern /pp1/main/extractions/dc12/ssbt
-extern /pp1/main/extractions/dc12/sst/sst_fdb_c1b
-extern /pp1/main/extractions/dc12/stor
-extern /pp1/main/extractions/dc12/trmm
-extern /pp1/main/extractions/dc18/airs
-extern /pp1/main/extractions/dc18/amsr
-extern /pp1/main/extractions/dc18/atap
-extern /pp1/main/extractions/dc18/ateu
-extern /pp1/main/extractions/dc18/atov
-extern /pp1/main/extractions/dc18/bice
-extern /pp1/main/extractions/dc18/eas1
-extern /pp1/main/extractions/dc18/emer
-extern /pp1/main/extractions/dc18/ers1_ra
-extern /pp1/main/extractions/dc18/ers1_wa
-extern /pp1/main/extractions/dc18/ers1_wi
-extern /pp1/main/extractions/dc18/grad
-extern /pp1/main/extractions/dc18/grst
-extern /pp1/main/extractions/dc18/ice/ice_fdb_c1b
-extern /pp1/main/extractions/dc18/nonbin
-extern /pp1/main/extractions/dc18/qsca
-extern /pp1/main/extractions/dc18/rado
-extern /pp1/main/extractions/dc18/rtovs
-extern /pp1/main/extractions/dc18/sbuv
-extern /pp1/main/extractions/dc18/smin
-extern /pp1/main/extractions/dc18/snow
-extern /pp1/main/extractions/dc18/ssbt
-extern /pp1/main/extractions/dc18/sst/sst_fdb_c1b
-extern /pp1/main/extractions/dc18/stor
-extern /pp1/main/extractions/dc18/trmm
-extern /pp1/main/extractions/ex00/airs
-extern /pp1/main/extractions/ex00/amsr
-extern /pp1/main/extractions/ex00/atap
-extern /pp1/main/extractions/ex00/ateu
-extern /pp1/main/extractions/ex00/atov
-extern /pp1/main/extractions/ex00/bice
-extern /pp1/main/extractions/ex00/eas1
-extern /pp1/main/extractions/ex00/emer
-extern /pp1/main/extractions/ex00/ers1_ra
-extern /pp1/main/extractions/ex00/ers1_wa
-extern /pp1/main/extractions/ex00/ers1_wi
-extern /pp1/main/extractions/ex00/grad
-extern /pp1/main/extractions/ex00/grst
-extern /pp1/main/extractions/ex00/ice/ice_fdb_c1b
-extern /pp1/main/extractions/ex00/nonbin
-extern /pp1/main/extractions/ex00/qsca
-extern /pp1/main/extractions/ex00/rado
-extern /pp1/main/extractions/ex00/rtovs
-extern /pp1/main/extractions/ex00/sbuv
-extern /pp1/main/extractions/ex00/smin
-extern /pp1/main/extractions/ex00/snow
-extern /pp1/main/extractions/ex00/ssbt
-extern /pp1/main/extractions/ex00/sst/sst_fdb_c1b
-extern /pp1/main/extractions/ex00/stor
-extern /pp1/main/extractions/ex00/trmm
-extern /pp1/main/extractions/ex06/airs
-extern /pp1/main/extractions/ex06/amsr
-extern /pp1/main/extractions/ex06/atap
-extern /pp1/main/extractions/ex06/ateu
-extern /pp1/main/extractions/ex06/atov
-extern /pp1/main/extractions/ex06/bice
-extern /pp1/main/extractions/ex06/eas1
-extern /pp1/main/extractions/ex06/emer
-extern /pp1/main/extractions/ex06/ers1_ra
-extern /pp1/main/extractions/ex06/ers1_wa
-extern /pp1/main/extractions/ex06/ers1_wi
-extern /pp1/main/extractions/ex06/grad
-extern /pp1/main/extractions/ex06/grst
-extern /pp1/main/extractions/ex06/ice/ice_fdb_c1b
-extern /pp1/main/extractions/ex06/nonbin
-extern /pp1/main/extractions/ex06/qsca
-extern /pp1/main/extractions/ex06/rado
-extern /pp1/main/extractions/ex06/rtovs
-extern /pp1/main/extractions/ex06/sbuv
-extern /pp1/main/extractions/ex06/smin
-extern /pp1/main/extractions/ex06/snow
-extern /pp1/main/extractions/ex06/ssbt
-extern /pp1/main/extractions/ex06/sst/sst_fdb_c1b
-extern /pp1/main/extractions/ex06/stor
-extern /pp1/main/extractions/ex06/trmm
-extern /pp1/main/extractions/ex12/airs
-extern /pp1/main/extractions/ex12/amsr
-extern /pp1/main/extractions/ex12/atap
-extern /pp1/main/extractions/ex12/ateu
-extern /pp1/main/extractions/ex12/atov
-extern /pp1/main/extractions/ex12/bice
-extern /pp1/main/extractions/ex12/eas1
-extern /pp1/main/extractions/ex12/emer
-extern /pp1/main/extractions/ex12/ers1_ra
-extern /pp1/main/extractions/ex12/ers1_wa
-extern /pp1/main/extractions/ex12/ers1_wi
-extern /pp1/main/extractions/ex12/grad
-extern /pp1/main/extractions/ex12/grst
-extern /pp1/main/extractions/ex12/ice/ice_fdb_c1b
-extern /pp1/main/extractions/ex12/nonbin
-extern /pp1/main/extractions/ex12/qsca
-extern /pp1/main/extractions/ex12/rado
-extern /pp1/main/extractions/ex12/rtovs
-extern /pp1/main/extractions/ex12/sbuv
-extern /pp1/main/extractions/ex12/smin
-extern /pp1/main/extractions/ex12/snow
-extern /pp1/main/extractions/ex12/ssbt
-extern /pp1/main/extractions/ex12/sst/sst_fdb_c1b
-extern /pp1/main/extractions/ex12/stor
-extern /pp1/main/extractions/ex12/trmm
-extern /pp1/main/extractions/ex18/airs
-extern /pp1/main/extractions/ex18/amsr
-extern /pp1/main/extractions/ex18/atap
-extern /pp1/main/extractions/ex18/ateu
-extern /pp1/main/extractions/ex18/atov
-extern /pp1/main/extractions/ex18/bice
-extern /pp1/main/extractions/ex18/eas1
-extern /pp1/main/extractions/ex18/emer
-extern /pp1/main/extractions/ex18/ers1_ra
-extern /pp1/main/extractions/ex18/ers1_wa
-extern /pp1/main/extractions/ex18/ers1_wi
-extern /pp1/main/extractions/ex18/grad
-extern /pp1/main/extractions/ex18/grst
-extern /pp1/main/extractions/ex18/ice/ice_fdb_c1b
-extern /pp1/main/extractions/ex18/nonbin
-extern /pp1/main/extractions/ex18/qsca
-extern /pp1/main/extractions/ex18/rado
-extern /pp1/main/extractions/ex18/rtovs
-extern /pp1/main/extractions/ex18/sbuv
-extern /pp1/main/extractions/ex18/smin
-extern /pp1/main/extractions/ex18/snow
-extern /pp1/main/extractions/ex18/ssbt
-extern /pp1/main/extractions/ex18/sst/sst_fdb_c1b
-extern /pp1/main/extractions/ex18/stor
-extern /pp1/main/extractions/ex18/trmm
-extern /pp1/main/extractions/ma
-extern /pp2/main/extractions/dc00/amsa
-extern /pp2/main/extractions/dc00/asc2
-extern /pp2/main/extractions/dc00/ascs
-extern /pp2/main/extractions/dc00/asel
-extern /pp2/main/extractions/dc00/avhn
-extern /pp2/main/extractions/dc00/g2to
-extern /pp2/main/extractions/dc00/gras
-extern /pp2/main/extractions/dc00/hirs
-extern /pp2/main/extractions/dc00/iasi
-extern /pp2/main/extractions/dc00/j2eo
-extern /pp2/main/extractions/dc00/j2nb
-extern /pp2/main/extractions/dc00/mhsa
-extern /pp2/main/extractions/dc00/modw
-extern /pp2/main/extractions/dc06/amsa
-extern /pp2/main/extractions/dc06/asc2
-extern /pp2/main/extractions/dc06/ascs
-extern /pp2/main/extractions/dc06/asel
-extern /pp2/main/extractions/dc06/avhn
-extern /pp2/main/extractions/dc06/g2to
-extern /pp2/main/extractions/dc06/gras
-extern /pp2/main/extractions/dc06/hirs
-extern /pp2/main/extractions/dc06/iasi
-extern /pp2/main/extractions/dc06/j2eo
-extern /pp2/main/extractions/dc06/j2nb
-extern /pp2/main/extractions/dc06/mhsa
-extern /pp2/main/extractions/dc06/modw
-extern /pp2/main/extractions/dc12/amsa
-extern /pp2/main/extractions/dc12/asc2
-extern /pp2/main/extractions/dc12/ascs
-extern /pp2/main/extractions/dc12/asel
-extern /pp2/main/extractions/dc12/avhn
-extern /pp2/main/extractions/dc12/g2to
-extern /pp2/main/extractions/dc12/gras
-extern /pp2/main/extractions/dc12/hirs
-extern /pp2/main/extractions/dc12/iasi
-extern /pp2/main/extractions/dc12/j2eo
-extern /pp2/main/extractions/dc12/j2nb
-extern /pp2/main/extractions/dc12/mhsa
-extern /pp2/main/extractions/dc12/modw
-extern /pp2/main/extractions/dc18/amsa
-extern /pp2/main/extractions/dc18/asc2
-extern /pp2/main/extractions/dc18/ascs
-extern /pp2/main/extractions/dc18/asel
-extern /pp2/main/extractions/dc18/avhn
-extern /pp2/main/extractions/dc18/g2to
-extern /pp2/main/extractions/dc18/gras
-extern /pp2/main/extractions/dc18/hirs
-extern /pp2/main/extractions/dc18/iasi
-extern /pp2/main/extractions/dc18/j2eo
-extern /pp2/main/extractions/dc18/j2nb
-extern /pp2/main/extractions/dc18/mhsa
-extern /pp2/main/extractions/dc18/modw
-extern /pp2/main/extractions/ex00/amsa
-extern /pp2/main/extractions/ex00/asc2
-extern /pp2/main/extractions/ex00/ascs
-extern /pp2/main/extractions/ex00/asel
-extern /pp2/main/extractions/ex00/avhn
-extern /pp2/main/extractions/ex00/g2to
-extern /pp2/main/extractions/ex00/gras
-extern /pp2/main/extractions/ex00/hirs
-extern /pp2/main/extractions/ex00/iasi
-extern /pp2/main/extractions/ex00/j2eo
-extern /pp2/main/extractions/ex00/j2nb
-extern /pp2/main/extractions/ex00/mhsa
-extern /pp2/main/extractions/ex00/modw
-extern /pp2/main/extractions/ex06/amsa
-extern /pp2/main/extractions/ex06/asc2
-extern /pp2/main/extractions/ex06/ascs
-extern /pp2/main/extractions/ex06/asel
-extern /pp2/main/extractions/ex06/avhn
-extern /pp2/main/extractions/ex06/g2to
-extern /pp2/main/extractions/ex06/gras
-extern /pp2/main/extractions/ex06/hirs
-extern /pp2/main/extractions/ex06/iasi
-extern /pp2/main/extractions/ex06/j2eo
-extern /pp2/main/extractions/ex06/j2nb
-extern /pp2/main/extractions/ex06/mhsa
-extern /pp2/main/extractions/ex06/modw
-extern /pp2/main/extractions/ex12/amsa
-extern /pp2/main/extractions/ex12/asc2
-extern /pp2/main/extractions/ex12/ascs
-extern /pp2/main/extractions/ex12/asel
-extern /pp2/main/extractions/ex12/avhn
-extern /pp2/main/extractions/ex12/g2to
-extern /pp2/main/extractions/ex12/gras
-extern /pp2/main/extractions/ex12/hirs
-extern /pp2/main/extractions/ex12/iasi
-extern /pp2/main/extractions/ex12/j2eo
-extern /pp2/main/extractions/ex12/j2nb
-extern /pp2/main/extractions/ex12/mhsa
-extern /pp2/main/extractions/ex12/modw
-extern /pp2/main/extractions/ex18/amsa
-extern /pp2/main/extractions/ex18/asc2
-extern /pp2/main/extractions/ex18/ascs
-extern /pp2/main/extractions/ex18/asel
-extern /pp2/main/extractions/ex18/avhn
-extern /pp2/main/extractions/ex18/g2to
-extern /pp2/main/extractions/ex18/gras
-extern /pp2/main/extractions/ex18/hirs
-extern /pp2/main/extractions/ex18/iasi
-extern /pp2/main/extractions/ex18/j2eo
-extern /pp2/main/extractions/ex18/j2nb
-extern /pp2/main/extractions/ex18/mhsa
-extern /pp2/main/extractions/ex18/modw
-suite limits
-  defstatus complete
-  edit SLEEPTIME '1'
-  limit mars 16
-  limit ha_pp 10
-  limit ha_pp2 10
-  limit swarm 40
-  limit linux_cluster 40
-  limit obs_get 20
-  limit hpcf 150
-  limit c1a 150
-  limit c1b 150
-  limit prod 25
-  limit prod2diss 6
-  limit prod2ecpds 6
-  limit pdb 10
-  limit q2diss 10
-  limit pdb_bc 6
-  limit q2diss_bc 6
-  clock hybrid 
-endsuite
-suite pp1
-  edit ECF_DATE '20080711'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family main
-    edit YMD '20100114'
-    family extractions
-      family ex00
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task buoy
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task smiu
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task cmwn
-        task ap19
-      endfamily
-      family ex06
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task mtsat
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task smiu
-        task cmwn
-        task ap19
-      endfamily
-      family ex12
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task mtsat
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task smiu
-        task cmwn
-        task ap19
-      endfamily
-      family ex18
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task mtsat
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task smiu
-        task cmwn
-        task ap19
-      endfamily
-      family dc00
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task mtsat
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task smiu
-        task cmwn
-        task ap19
-      endfamily
-      family dc06
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task mtsat
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task smiu
-        task cmwn
-        task ap19
-      endfamily
-      family dc12
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task mtsat
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task smiu
-        task cmwn
-        task ap19
-      endfamily
-      family dc18
-        task nonbin
-        task airs
-        task amsr
-        task at18
-        task at19
-        task atap
-        task ateu
-        task atov
-        task avhr
-        task bice
-        task bssh
-        task btem
-        task cmwi
-        task csrj
-        task eas1
-        task eas2
-        task emer
-        task erad
-        task ers1_at
-        task ers1_ra
-        task ers1_wa
-        task ers1_wi
-        task esck
-        task goes
-        task gomw
-        task grad
-        task grst
-        family ice
-          task ice_ex
-          task ice_fdb_hpcf
-          task ice_fdb_c1a
-          task ice_fdb_c1b
-        endfamily
-        task jaso
-        task masr
-        family metop_a
-          task amsa
-          task asca
-          task hirs
-          task iasi
-          task mhsa
-        endfamily
-        task mtsat
-        task nomi
-        task qsca
-        task rado
-        task rtovs
-        task sb19
-        task sbuv
-        task smin
-        task smis
-        task snow
-        task ssbt
-        family sst
-          task sst_ex
-          task sst_fdb_hpcf
-          task sst_fdb_c1a
-          task sst_fdb_c1b
-        endfamily
-        task stor
-        task tozo
-        task trmm
-        task trmr
-        task wavb
-        task smiu
-        task cmwn
-        task ap19
-      endfamily
-      family ma
-        family egrr
-          task extract
-          task fdb_c1a
-          task fdb_c1b
-          task fdb_hpcf
-        endfamily
-        family edzw
-          task extract
-          task fdb_c1a
-          task fdb_c1b
-          task fdb_hpcf
-        endfamily
-        family lfpw
-          task extract
-          task fdb_c1a
-          task fdb_c1b
-          task fdb_hpcf
-        endfamily
-        family kwbc
-          task extract
-          task fdb_c1a
-          task fdb_c1b
-          task fdb_hpcf
-        endfamily
-      endfamily
-    endfamily
-  endfamily
-endsuite
-suite o
-  edit SMSFILES '/home/ma/emos/def/sync'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family main
-    edit YMD '20100114'
-    family 00
-      family an
-        task 4dvar
-        task surf_anal
-      endfamily
-      family prod
-        family 18an
-          task derived_param
-        endfamily
-      endfamily
-      family prod2diss
-        task oper
-        task wave
-        family sched
-          task 240
-        endfamily
-      endfamily
-      family fc
-        task model
-        task clean
-      endfamily
-    endfamily
-    family 12
-      family an
-        task 4dvar
-        task surf_anal
-      endfamily
-      family prod
-        family 06an
-          task derived_param
-        endfamily
-      endfamily
-      family prod2diss
-        task oper
-        task wave
-        family sched
-          task 240
-        endfamily
-      endfamily
-      family fc
-        task model
-      endfamily
-      family obs
-        family get
-          task get_stor
-        endfamily
-      endfamily
-    endfamily
-    family 00dc
-      family an
-        task 4dvar
-        task surf_anal
-      endfamily
-      family fc
-        task model
-        task clean
-      endfamily
-    endfamily
-    family 12dc
-      family an
-        task 4dvar
-        task surf_anal
-      endfamily
-      family fc
-        task model
-      endfamily
-      family obs
-        family get
-          task get_stor
-        endfamily
-      endfamily
-    endfamily
-    family 06bc
-      family an
-        task 4dvar
-        task surf_anal
-      endfamily
-      family prod2diss
-        task oper
-        family sched
-          task 72
-        endfamily
-      endfamily
-      family fc
-        task model
-      endfamily
-    endfamily
-    family 18bc
-      family an
-        task 4dvar
-        task surf_anal
-      endfamily
-      family prod2diss
-        task oper
-        family sched
-          task 72
-        endfamily
-      endfamily
-      family fc
-        task model
-      endfamily
-    endfamily
-  endfamily
-  family lag
-    edit YMD '20100114'
-    family 00dc
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task archive
-    endfamily
-    family 06
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task archive
-    endfamily
-    family 12
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task satim
-      task verif
-      family archive
-        task obs
-        task fc240
-      endfamily
-    endfamily
-    family 12dc
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task archive
-    endfamily
-    family 18
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task archive
-    endfamily
-    family 00
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task satim
-      task verif
-      family archive
-        task obs
-        task anml
-        task anpl
-        task ansfc
-        task sst
-        task fc048
-        task fc240
-      endfamily
-    endfamily
-    family 18bc
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task archive
-    endfamily
-    family 06bc
-      family fb
-        family feedback
-          task matchup
-        endfamily
-      endfamily
-      task archive
-    endfamily
-  endfamily
-endsuite
-suite pp2
-  edit ECF_DATE '20091117'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family main
-    edit YMD '20100114'
-    family extractions
-      family ex00
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-      family ex06
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-      family ex12
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-      family ex18
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-      family dc00
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-      family dc06
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-      family dc12
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-      family dc18
-        task amsa
-        task amse
-        task asc2
-        task asca
-        task ascs
-        task asch
-        task aseh
-        task asel
-        task ashs
-        task avhn
-        task cori
-        task earn
-        task emsg
-        task er19
-        task g2to
-        task gras
-        task hirs
-        task iasi
-        task ias1
-        task ias2
-        task ias3
-        task ias4
-        task itwt
-        task j2eo
-        task j2nb
-        task mhsa
-        task mhse
-        task mloz
-        task modw
-      endfamily
-    endfamily
-  endfamily
-endsuite
-suite pp3
-  edit ECF_DATE '20121212'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family limits
-  endfamily
-  family first
-    task log
-      event tar
-    task clean
-    task clean_stat
-    task clean_err_db
-    task pp_src
-    task chktasks
-  endfamily
-  family meb
-    task restore
-    task clean
-    task stat
-    task feed
-  endfamily
-  family reb
-    task restore
-    task clean
-      event deqc
-    task stat
-  endfamily
-  family bkup
-    family meb
-      task strhandle
-      task MAER
-    endfamily
-    family reb
-      task strhandle
-      task MAER
-    endfamily
-  endfamily
-  family deqc
-    task MAER
-  endfamily
-  family ex00
-    task maer
-      event 1 
-  endfamily
-  family ex06
-    task maer
-      event 1 
-  endfamily
-  family ex12
-    task maer
-      event 1 
-  endfamily
-  family ex18
-    task maer
-      event 1 
-  endfamily
-  family dc00
-    task maer
-      event 1 
-  endfamily
-  family dc06
-    task maer
-      event 1 
-  endfamily
-  family dc12
-    task maer
-      event 1 
-  endfamily
-  family dc18
-    task maer
-      event 1 
-  endfamily
-  family last
-    task stop
-    task chksuite
-  endfamily
-endsuite
-suite mc
-  edit SMSFILES '/home/ma/emos/def/sync'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family main
-    edit YMD '20100114'
-    family 00
-      family sv
-        task svsh
-        task svnh
-        task sv1
-        task sv2
-        task sv3
-        task sv4
-        task sv5
-        task sv6
-      endfamily
-      family legA
-        family fc
-          task pert_ic
-          task pf
-          task cf
-        endfamily
-        task postproc
-      endfamily
-      family legB
-        task postproc
-      endfamily
-    endfamily
-    family 12
-      family legA
-        family fc
-          task pf
-          task cf
-        endfamily
-        task postproc
-      endfamily
-      family legB
-        task postproc
-      endfamily
-    endfamily
-  endfamily
-endsuite
-suite esync
-  edit USER 'emos'
-  edit QUEUE 'emos-exp'
-  edit ACCOUNT 'oosu'
-  edit WSHOST 'localhost'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-  edit SMSOUT '/vol/emos/output'
-  edit LOGDIR '/vol/emos/output'
-  edit SMSHOME '/vol/emos/output'
-  edit SMSFILES '/home/ma/emos/def/esync'
-  edit SMSINCLUDE '/home/ma/emos/def/esync/include'
-  edit SMSTRIES '1'
-  edit SYNC_HOSTS 'marhaus percard marhaus percard ibis'
-  edit SYNC_PORTS ' 314122 314111 314288 314155 314159 314159'
-  edit SYNC_SUITES 'o pp1'
-  edit SLEEPTIME '1'
-  inlimit /esync/limits:sync
-  clock hybrid 
-  family limits
-    limit sync 3
-  endfamily
-  family o
-    family o
-      edit SMSFILES '/home/ma/emos/def/sync'
-      family main
-        edit YMD '20100114'
-        family 00
-          family an
-            family 4dvar
-              task sync
-                trigger /o/main/00/an/4dvar eq complete
-                edit SYNC_NODE '/o/main/00/an/4dvar'
-            endfamily
-            family surf_anal
-              task sync
-                trigger /o/main/00/an/surf_anal eq complete
-                edit SYNC_NODE '/o/main/00/an/surf_anal'
-            endfamily
-          endfamily
-          family prod
-            family 18an
-              family derived_param
-                task sync
-                  trigger /o/main/00/prod/18an/derived_param eq complete
-                  edit SYNC_NODE '/o/main/00/prod/18an/derived_param'
-              endfamily
-            endfamily
-          endfamily
-          family prod2diss
-            family oper
-              task sync
-                trigger /o/main/00/prod2diss/oper eq complete
-                edit SYNC_NODE '/o/main/00/prod2diss/oper'
-            endfamily
-            family wave
-              task sync
-                trigger /o/main/00/prod2diss/wave eq complete
-                edit SYNC_NODE '/o/main/00/prod2diss/wave'
-            endfamily
-            family sched
-              family 240
-                task sync
-                  trigger /o/main/00/prod2diss/sched/240 eq complete
-                  edit SYNC_NODE '/o/main/00/prod2diss/sched/240'
-              endfamily
-            endfamily
-          endfamily
-          family fc
-            family model
-              task sync
-                trigger /o/main/00/fc/model eq complete
-                edit SYNC_NODE '/o/main/00/fc/model'
-            endfamily
-            family clean
-              task sync
-                trigger /o/main/00/fc/clean eq complete
-                edit SYNC_NODE '/o/main/00/fc/clean'
-            endfamily
-          endfamily
-        endfamily
-        family 12
-          family an
-            family 4dvar
-              task sync
-                trigger /o/main/12/an/4dvar eq complete
-                edit SYNC_NODE '/o/main/12/an/4dvar'
-            endfamily
-            family surf_anal
-              task sync
-                trigger /o/main/12/an/surf_anal eq complete
-                edit SYNC_NODE '/o/main/12/an/surf_anal'
-            endfamily
-          endfamily
-          family prod
-            family 06an
-              family derived_param
-                task sync
-                  trigger /o/main/12/prod/06an/derived_param eq complete
-                  edit SYNC_NODE '/o/main/12/prod/06an/derived_param'
-              endfamily
-            endfamily
-          endfamily
-          family prod2diss
-            family oper
-              task sync
-                trigger /o/main/12/prod2diss/oper eq complete
-                edit SYNC_NODE '/o/main/12/prod2diss/oper'
-            endfamily
-            family wave
-              task sync
-                trigger /o/main/12/prod2diss/wave eq complete
-                edit SYNC_NODE '/o/main/12/prod2diss/wave'
-            endfamily
-            family sched
-              family 240
-                task sync
-                  trigger /o/main/12/prod2diss/sched/240 eq complete
-                  edit SYNC_NODE '/o/main/12/prod2diss/sched/240'
-              endfamily
-            endfamily
-          endfamily
-          family fc
-            family model
-              task sync
-                trigger /o/main/12/fc/model eq complete
-                edit SYNC_NODE '/o/main/12/fc/model'
-            endfamily
-          endfamily
-          family obs
-            family get
-              family get_stor
-                task sync
-                  trigger /o/main/12/obs/get/get_stor eq complete
-                  edit SYNC_NODE '/o/main/12/obs/get/get_stor'
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family 00dc
-          family an
-            family 4dvar
-              task sync
-                trigger /o/main/00dc/an/4dvar eq complete
-                edit SYNC_NODE '/o/main/00dc/an/4dvar'
-            endfamily
-            family surf_anal
-              task sync
-                trigger /o/main/00dc/an/surf_anal eq complete
-                edit SYNC_NODE '/o/main/00dc/an/surf_anal'
-            endfamily
-          endfamily
-          family fc
-            family model
-              task sync
-                trigger /o/main/00dc/fc/model eq complete
-                edit SYNC_NODE '/o/main/00dc/fc/model'
-            endfamily
-            family clean
-              task sync
-                trigger /o/main/00dc/fc/clean eq complete
-                edit SYNC_NODE '/o/main/00dc/fc/clean'
-            endfamily
-          endfamily
-        endfamily
-        family 12dc
-          family an
-            family 4dvar
-              task sync
-                trigger /o/main/12dc/an/4dvar eq complete
-                edit SYNC_NODE '/o/main/12dc/an/4dvar'
-            endfamily
-            family surf_anal
-              task sync
-                trigger /o/main/12dc/an/surf_anal eq complete
-                edit SYNC_NODE '/o/main/12dc/an/surf_anal'
-            endfamily
-          endfamily
-          family fc
-            family model
-              task sync
-                trigger /o/main/12dc/fc/model eq complete
-                edit SYNC_NODE '/o/main/12dc/fc/model'
-            endfamily
-          endfamily
-          family obs
-            family get
-              family get_stor
-                task sync
-                  trigger /o/main/12dc/obs/get/get_stor eq complete
-                  edit SYNC_NODE '/o/main/12dc/obs/get/get_stor'
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family 06bc
-          family an
-            family 4dvar
-              task sync
-                trigger /o/main/06bc/an/4dvar eq complete
-                edit SYNC_NODE '/o/main/06bc/an/4dvar'
-            endfamily
-            family surf_anal
-              task sync
-                trigger /o/main/06bc/an/surf_anal eq complete
-                edit SYNC_NODE '/o/main/06bc/an/surf_anal'
-            endfamily
-          endfamily
-          family prod2diss
-            family oper
-              task sync
-                trigger /o/main/06bc/prod2diss/oper eq complete
-                edit SYNC_NODE '/o/main/06bc/prod2diss/oper'
-            endfamily
-            family sched
-              family 72
-                task sync
-                  trigger /o/main/06bc/prod2diss/sched/72 eq complete
-                  edit SYNC_NODE '/o/main/06bc/prod2diss/sched/72'
-              endfamily
-            endfamily
-          endfamily
-          family fc
-            family model
-              task sync
-                trigger /o/main/06bc/fc/model eq complete
-                edit SYNC_NODE '/o/main/06bc/fc/model'
-            endfamily
-          endfamily
-        endfamily
-        family 18bc
-          family an
-            family 4dvar
-              task sync
-                trigger /o/main/18bc/an/4dvar eq complete
-                edit SYNC_NODE '/o/main/18bc/an/4dvar'
-            endfamily
-            family surf_anal
-              task sync
-                trigger /o/main/18bc/an/surf_anal eq complete
-                edit SYNC_NODE '/o/main/18bc/an/surf_anal'
-            endfamily
-          endfamily
-          family prod2diss
-            family oper
-              task sync
-                trigger /o/main/18bc/prod2diss/oper eq complete
-                edit SYNC_NODE '/o/main/18bc/prod2diss/oper'
-            endfamily
-            family sched
-              family 72
-                task sync
-                  trigger /o/main/18bc/prod2diss/sched/72 eq complete
-                  edit SYNC_NODE '/o/main/18bc/prod2diss/sched/72'
-              endfamily
-            endfamily
-          endfamily
-          family fc
-            family model
-              task sync
-                trigger /o/main/18bc/fc/model eq complete
-                edit SYNC_NODE '/o/main/18bc/fc/model'
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family lag
-        edit YMD '20100114'
-        family 00dc
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/00dc/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/00dc/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family archive
-            task sync
-              trigger /o/lag/00dc/archive eq complete
-              edit SYNC_NODE '/o/lag/00dc/archive'
-          endfamily
-        endfamily
-        family 06
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/06/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/06/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family archive
-            task sync
-              trigger /o/lag/06/archive eq complete
-              edit SYNC_NODE '/o/lag/06/archive'
-          endfamily
-        endfamily
-        family 12
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/12/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/12/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family satim
-            task sync
-              trigger /o/lag/12/satim eq complete
-              edit SYNC_NODE '/o/lag/12/satim'
-          endfamily
-          family verif
-            task sync
-              trigger /o/lag/12/verif eq complete
-              edit SYNC_NODE '/o/lag/12/verif'
-          endfamily
-          family archive
-            family obs
-              task sync
-                trigger /o/lag/12/archive/obs eq complete
-                edit SYNC_NODE '/o/lag/12/archive/obs'
-            endfamily
-            family fc240
-              task sync
-                trigger /o/lag/12/archive/fc240 eq complete
-                edit SYNC_NODE '/o/lag/12/archive/fc240'
-            endfamily
-          endfamily
-        endfamily
-        family 12dc
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/12dc/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/12dc/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family archive
-            task sync
-              trigger /o/lag/12dc/archive eq complete
-              edit SYNC_NODE '/o/lag/12dc/archive'
-          endfamily
-        endfamily
-        family 18
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/18/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/18/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family archive
-            task sync
-              trigger /o/lag/18/archive eq complete
-              edit SYNC_NODE '/o/lag/18/archive'
-          endfamily
-        endfamily
-        family 00
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/00/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/00/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family satim
-            task sync
-              trigger /o/lag/00/satim eq complete
-              edit SYNC_NODE '/o/lag/00/satim'
-          endfamily
-          family verif
-            task sync
-              trigger /o/lag/00/verif eq complete
-              edit SYNC_NODE '/o/lag/00/verif'
-          endfamily
-          family archive
-            family obs
-              task sync
-                trigger /o/lag/00/archive/obs eq complete
-                edit SYNC_NODE '/o/lag/00/archive/obs'
-            endfamily
-            family anml
-              task sync
-                trigger /o/lag/00/archive/anml eq complete
-                edit SYNC_NODE '/o/lag/00/archive/anml'
-            endfamily
-            family anpl
-              task sync
-                trigger /o/lag/00/archive/anpl eq complete
-                edit SYNC_NODE '/o/lag/00/archive/anpl'
-            endfamily
-            family ansfc
-              task sync
-                trigger /o/lag/00/archive/ansfc eq complete
-                edit SYNC_NODE '/o/lag/00/archive/ansfc'
-            endfamily
-            family sst
-              task sync
-                trigger /o/lag/00/archive/sst eq complete
-                edit SYNC_NODE '/o/lag/00/archive/sst'
-            endfamily
-            family fc048
-              task sync
-                trigger /o/lag/00/archive/fc048 eq complete
-                edit SYNC_NODE '/o/lag/00/archive/fc048'
-            endfamily
-            family fc240
-              task sync
-                trigger /o/lag/00/archive/fc240 eq complete
-                edit SYNC_NODE '/o/lag/00/archive/fc240'
-            endfamily
-          endfamily
-        endfamily
-        family 18bc
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/18bc/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/18bc/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family archive
-            task sync
-              trigger /o/lag/18bc/archive eq complete
-              edit SYNC_NODE '/o/lag/18bc/archive'
-          endfamily
-        endfamily
-        family 06bc
-          family fb
-            family feedback
-              family matchup
-                task sync
-                  trigger /o/lag/06bc/fb/feedback/matchup eq complete
-                  edit SYNC_NODE '/o/lag/06bc/fb/feedback/matchup'
-              endfamily
-            endfamily
-          endfamily
-          family archive
-            task sync
-              trigger /o/lag/06bc/archive eq complete
-              edit SYNC_NODE '/o/lag/06bc/archive'
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-    task restart
-      trigger ( ( /o/lag:YMD gt /esync/o/o/lag:YMD) or ( /o/main:YMD gt /esync/o/o/main:YMD) or 1 eq 0) and /esync/o ne active and /esync/o ne submitted
-      edit SMSPASS 'stripped'
-  endfamily
-endsuite
-suite admin3
-  repeat day 1
-  edit USER 'emos'
-  edit ACCOUNT 'oosu'
-  edit SCHOST 'hpce'
-  edit VERSION '0011'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '12'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY ''
-  edit STREAM 'TMP'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit INIMA ''
-  edit INIMACONS '0'
-  edit WSHOST 'swarm'
-  edit QUEUE 'emos-e'
-  edit QUEUE_EPILOG 'emos-exp'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-  edit LOGDIR '/vol/emos/output'
-  edit SMSOUT '/vol/emos/output'
-  edit SMSHOME '/vol/emos/output'
-  edit SMSINCLUDE '/home/ma/emos/def/o/include'
-  edit SMSFILES '/home/ma/emos/def/o/admin'
-  edit SERVER_HOME '/var/tmp/emos/sms'
-  edit CLASS 'od'
-  edit DATEMASK '*.*.*'
-  edit SLEEPTIME '1'
-  inlimit /limits:swarm
-  clock hybrid 
-  family daily
-    repeat date YMD 20070115 20121212 1
-    edit USE_YMD 'true'
-    edit LOGTASK 'daily'
-    family check
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      task rcp
-        time 00:00 23:59 00:10
-        time 00:00 06:59 00:10
-      task ecfs
-        edit SMSTRIES '3'
-        time 00:00 23:59 00:30
-        time 00:00 06:59 00:30
-    endfamily
-    family files
-      task usr_edt
-      task smslog
-        trigger usr_edt eq complete or usr_edt eq aborted
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-        edit LOGDIR '/vol/emos/output'
-        edit SMSOUT '/vol/emos/output'
-      task no_jobs
-        trigger smslog eq complete or smslog eq aborted
-      task tar
-        trigger no_jobs eq complete or no_jobs eq aborted
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      edit SMSFILES '/home/ma/emos/def/admin'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'daily'
-    task logfiles
-      trigger ( check eq complete and files eq complete)
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      edit KEEPLOGS 'no'
-      edit MOVE_TO_ECFS 'no'
-      edit SMSFILES '/home/ma/emos/def/o'
-      time 06:45
-  endfamily
-endsuite
-suite new_monitor
-  edit SMSOUT '/vol/emos_nc/output'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/new_monitor'
-  edit SMSINCLUDE '/home/ma/emos/def/new_monitor/include'
-  edit WSHOST 'bilbo'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/vol/emos_nc/output'
-  edit EMPDIR '/usr/local/apps/empress/v8.60'
-  edit EMPTMPDIR '/acq/tmp/empress'
-  edit EDBPATH 'not_used'
-  edit EPSTYPE 'not_used'
-  edit MEMBER '0'
-  edit FIRST_DAY '0'
-  edit VERSION '0001'
-  edit YMD 'not_used'
-  edit DELTA_DAY '0'
-  edit WDIR 'not_used'
-  edit PACKAGE 'not_used'
-  edit SCHOST 'not_used'
-  edit HAACQ 'not_used'
-  edit AN_TIME 'not_used'
-  edit EDBNAME 'not_used'
-  edit PP_BASE 'not_used'
-  edit EXPVER 'not_used'
-  edit STREAM 'not_used'
-  edit USEEXTRACTED 'not_used'
-  edit SMSHOST 'not_used'
-  edit USER 'emos'
-  edit QUEUE 'emos'
-  edit ACCOUNT 'not_used'
-  edit FSFAMILY 'disk_space'
-  edit EMOS_BASE '00'
-  edit EMOS_TIME_STEP_H '0000'
-  edit DATEMASK '*.*.*'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family admin
-    task display_seaice
-      edit WSHOST 'swarm'
-      edit SMSLOG '/vol/emos/output/monitor'
-      edit MCSLOG '/vol/emos/output'
-      edit FSFAMILY 'undef'
-      edit EMOS_BASE '12'
-      edit SMSURLBASE 'http://w3ec2.ecmwf.int/metapps/preprocessing/Monitoring'
-      edit SMSURL 'seaice.html'
-      edit YMD '20071025'
-      edit METVIEW 'metview'
-      edit EMOS_TYPE 'undef'
-      edit MARS_DB 'mars_od'
-  endfamily
-  family disk_space
-    edit SMSOUT '/vol/emos_nc/output'
-    edit SMSHOME '/vol/emos_nc/output'
-    edit SMSLOG '/vol/emos_nc/output'
-    edit LOGDIR '/vol/emos_nc/output'
-    task chkspace
-      edit WSHOST 'swarm'
-      edit SMSPASS 'stripped'
-      cron 00:00 23:00 00:30
-    task chkspace_img
-      edit WSHOST 'bilbo'
-      edit SMSCMD '/home/ma/emos/bin/smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      cron 00:05 23:05 00:30
-    task chkspace_img_copy
-      edit WSHOST 'localhost'
-      cron 00:10 23:10 00:30
-    task rd_chkspace
-      edit WSHOST 'swarm'
-      cron 00:15 23:15 00:30
-    task rd_chkspace_img
-      edit WSHOST 'bilbo'
-      cron 00:20 23:20 00:30
-    task rd_chkspace_img_copy
-      edit WSHOST 'localhost'
-      cron 00:25 23:25 00:30
-    task chkfeed
-      cron 00:00 23:00 00:30
-  endfamily
-  family stats
-    edit FSFAMILY 'stats'
-    edit ODBCINIFILE '/home/ma/emos/maw/stats2/odbc.ini'
-    task chk_stats_meb
-      label info ""
-      cron 07:00
-    task chk_stats_reb
-      label info ""
-      cron 07:30
-    task chk_stats_reb2
-      label info ""
-      cron 07:35
-    task chk_grib_meb
-      cron 09:30
-    task chk_grib_reb
-      cron 09:30
-    task copy_stats_to_intra
-      edit WSHOST 'localhost'
-      cron 09:45
-  endfamily
-  family acq2
-    edit WSHOST 'localhost'
-    edit WARNINGMAIL 'true'
-    family emc1
-      task amsua
-        edit WARNINGMAIL 'true'
-        cron 00:05 23:05 00:30
-      task mhs
-        edit WARNINGMAIL 'false'
-        cron 00:05 23:05 00:30
-      task hirs
-        edit WARNINGMAIL 'false'
-        cron 00:05 23:05 00:30
-    endfamily
-    family emc2
-      task amsua
-        edit WARNINGMAIL 'false'
-        cron 00:08 23:08 00:30
-      task mhs
-        edit WARNINGMAIL 'false'
-        cron 00:08 23:08 00:30
-      task hirs
-        edit WARNINGMAIL 'false'
-        cron 00:08 23:08 00:30
-    endfamily
-  endfamily
-  family radar
-    task get_radar
-      edit WSHOST 'localhost'
-      edit SMSLOG '/vol/emos/output/monitor'
-      edit MCSLOG '/vol/emos/output'
-      edit FSFAMILY 'radar'
-      cron 00:00 23:00 00:15
-    task get_img
-      edit WSHOST 'bilbo'
-      edit SMSLOG '/vol/emos/output/monitor'
-      edit MCSLOG '/vol/emos/output'
-      edit FSFAMILY 'radar'
-      cron 00:05 23:05 00:15
-  endfamily
-  family db_locks
-    edit SMSOUT '/vol/emos_nc/output'
-    edit SMSHOME '/vol/emos_nc/output'
-    edit SMSLOG '/vol/emos_nc/output'
-    edit LOGDIR '/vol/emos_nc/output'
-    task lockinfo_meb
-      edit WSHOST 'pp1'
-      cron 09:00 15:00 00:02
-    task lockinfo_reb
-      edit WSHOST 'pp1'
-      cron 09:01 15:01 00:02
-    task lockinfo_graph
-      edit WSHOST 'bilbo'
-      cron 09:05 15:05 00:02
-    task lockinfo_img_copy
-      edit WSHOST 'localhost'
-      cron 09:06 15:06 00:02
-  endfamily
-endsuite
-suite preview
-  edit USER 'emos'
-  edit SCHOST 'c1a'
-  edit SCHOST_BKUP 'c1b'
-  edit WSHOST 'swarm'
-  edit WSLOGDIR '/vol/emos/output'
-  edit SCLOGDIR '/emos_dir/0001/log'
-  edit USE_YMD 'true'
-  edit YMD '20070712'
-  edit DATEMASK '*.*.*'
-  edit VERSION '0001'
-  edit INIEXPVER '0001'
-  edit TCINIEXPVER '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '00'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'tc'
-  edit USER_PRIORITY '70'
-  edit REINITIALIZE 'false'
-  edit SMSHOME '/vol/emos/output'
-  edit SMSFILES '/home/ma/emos/def/preview/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/preview/include'
-  edit ACCOUNT 'oosu'
-  edit STREAM 'DA'
-  edit EMOS_STREAM 'EF'
-  edit ENSEMBLES '50'
-  edit ENS_SIZE '50'
-  edit MARS_DB 'marsod'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit SMSLOGHOST 'c1a'
-  edit SMSLOGPORT '9316'
-  edit OD_PROJ 'od'
-  edit SUITE_START '20070602'
-  edit QUEUE 'emos-e'
-  edit QUEUE_EPILOG 'emos-exp'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/vol/emos/output'
-  edit SMSOUT '/vol/emos/output'
-  edit METPY 'metpy_new'
-  edit SLEEPTIME '1'
-  inlimit /limits:swarm
-  clock hybrid 
-  family pop
-    repeat date YMD 20070712 20201215 1
-    limit plots 3
-    family 00
-      edit PLOT_AREAS 'Preview'
-      edit EMOS_BASE '00'
-      edit UPDATE_WEB_NOW 'yes'
-      inlimit plots
-      family deterministic
-        edit SMSFILES '/home/ma/emos/def/preview/pop/web'
-        edit PLOT_STEPS '60,72,84,96,108,120'
-        edit STREAM 'DA'
-        task delay
-          time 07:20
-        family data
-          trigger delay eq complete
-          edit SMSFILES '/home/ma/emos/def/preview/pop/data/fields'
-          edit STEP_LIST '60/to/120/by/12'
-          task mslp
-          task rain
-          task rh
-          task t2m
-          task t850
-          task z500
-          task w30m
-          task wind
-          task wr
-          task wbpt
-        endfamily
-        family web
-          trigger data eq complete
-          task w_msl_uv200
-          task w_mslrain
-          task w_t2m30mw
-          task w_uv_rh
-          task w_z500t850
-          task w_wr850_700
-          task w_wbpt_msl
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/preview/pop'
-      endfamily
-      family eps
-        edit SMSFILES '/home/ma/emos/def/preview/pop/web'
-        edit STREAM 'EF'
-        edit PLOT_STEPS '60/72/84/96/108/120'
-        task delay
-          time 08:50
-        family data
-          trigger delay eq complete
-          edit SMSFILES '/home/ma/emos/def/preview/pop/data/fields'
-          task efi
-          task lsmoro
-            edit STEP_LIST '0/to/48/by/12'
-          task proba
-            edit PLOT_STEPS_RANGE '48-72/60-84/72-96/84-108/96-120/108-132'
-            edit PLOT_STEPS '60/72/84/96/108/120'
-            edit RANGE 'legA'
-        endfamily
-        family web
-          trigger data eq complete
-          edit SMSFILES '/home/ma/emos/def/preview/pop/web'
-          edit STEP_RANGE 'legA'
-          family probabilities
-            task pb_2t
-            task pb_ff
-            task pb_tp
-              edit PLOT_STEPS '48-72/60-84/72-96/84-108/96-120/108-132'
-            task w_proba_gusts
-              edit PLOT_STEPS '48-72/60-84/72-96/84-108/96-120/108-132'
-          endfamily
-          family efi
-            family efi_tpi
-              task w_efi
-                edit PARAMETER 'tpi'
-            endfamily
-            family efi_10wsi
-              task w_efi
-                edit PARAMETER '10wsi'
-            endfamily
-            family efi_2ti
-              task w_efi
-                edit PARAMETER '2ti'
-            endfamily
-            family efi_10fgi
-              task w_efi
-                edit PARAMETER '10fgi'
-            endfamily
-          endfamily
-          family others
-            edit PLOT_STEPS '60,72,84,96,108,120'
-            task w_msl_mean_spread
-            task w_z500_mean_spread
-            task w_z200_mean_spread
-            task w_t850_mean_spread
-          endfamily
-          family quartiles
-            edit AREA_TO_PLOT '-5/-50/60/80'
-            edit MAP_VERT_LONG '0'
-            edit MAP_PROJECTION 'POLAR_STEREOGRAPHIC'
-            edit STEP_LIST '54/TO/126/by/12'
-            edit STEP_PLOT '60/TO/120/by/12'
-            task w_tp_quartiles
-            task w_wind_quartiles
-            task w_wgust_quartiles
-            task w_wind925_quartiles
-            task w_cape_quartiles
-          endfamily
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/preview/pop'
-      endfamily
-    endfamily
-    family ukmo
-      edit SMSFILES '/home/ma/emos/def/preview/pop/mogreps'
-      edit PLOT_AREAS 'Preview'
-      edit EMOS_BASE '00'
-      edit STREAM 'EF'
-      edit UPDATE_WEB_NOW 'yes'
-      inlimit plots
-      task delay
-        time 08:55
-      family mogreps
-        trigger delay eq complete
-        edit PLOT_STEPS '60,72,84,96,108,120'
-        family web
-          family en_mean_spread
-            task m_msl_mean_spread
-            task m_z500_mean_spread
-            task m_z200_mean_spread
-            task m_t850_mean_spread
-          endfamily
-          family quartiles
-            edit AREA_TO_PLOT '-5/-50/60/80'
-            edit MAP_VERT_LONG '0'
-            edit MAP_PROJECTION 'POLAR_STEREOGRAPHIC'
-            edit STEP_LIST '54/TO/126/by/12'
-            task m_tp_quartiles
-            task m_wind_quartiles
-            task m_wind925_quartiles
-          endfamily
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/preview/pop'
-      endfamily
-    endfamily
-    task restart
-      trigger ./00 eq complete
-      time 15:00
-  endfamily
-endsuite
-suite gems
-  edit USER 'emos'
-  edit SCHOST 'hpce'
-  edit SCHOST_BKUP 'hpcf'
-  edit WSHOST 'swarm'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/emos_dir/evnj/log'
-  edit USE_YMD 'true'
-  edit YMD '20071217'
-  edit DATEMASK '*.*.*'
-  edit VERSION 'evnj'
-  edit INIEXPVER '0001'
-  edit TCINIEXPVER '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '1'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '00'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'tc'
-  edit USER_PRIORITY '70'
-  edit REINITIALIZE 'false'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/gems/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/gems/include'
-  edit ACCOUNT 'oosu'
-  edit STREAM 'EF'
-  edit EMOS_STREAM 'EF'
-  edit ENSEMBLES '50'
-  edit ENS_SIZE '50'
-  edit MARS_DB 'marsod'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit SMSLOGHOST 'c1a'
-  edit SMSLOGPORT '9316'
-  edit OD_PROJ 'od'
-  edit SUITE_START '20061126'
-  edit QUEUE 'emos-e'
-  edit QUEUE_EPILOG 'emos-exp'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/vol/emos_nc/output'
-  edit SMSOUT '/vol/emos_nc/output'
-  edit SLEEPTIME '1'
-  inlimit /limits:swarm
-  clock hybrid 
-  family limits
-    limit linux_cluster 8
-    limit raq_ensemble 3
-    limit calchas 4
-  endfamily
-  family grg
-    inlimit /gems/limits:linux_cluster
-    family plot
-      edit METPY 'metpy_dev'
-      edit UPDATE_WEB_NOW 'yes'
-      edit DO_PUSH_TO_WEB 'yes'
-      family realtime
-        repeat date YMD 20081223 20120924 1
-        edit VERSION 'f7kn'
-        edit METPY 'metpy_new'
-        edit PARAMETERS 'co,go3'
-        edit LEVELS '850,500,300,50'
-        family deps
-          task dummy
-            time 01:00
-        endfamily
-        task daily_fields
-          trigger deps eq complete
-        task daily_totalcolumns
-          trigger daily_fields eq complete
-          edit PARAMETERS 'tcco,gtco3'
-        task daily_zonalmean
-          trigger daily_totalcolumns eq complete
-        task daily_crosssection
-          trigger daily_zonalmean eq complete
-      endfamily
-      family realtime_da
-        repeat date YMD 20081223 20120924 1
-        edit METPY 'metpy_new'
-        edit VERSION 'f8na'
-        edit PARAMETERS 'co,go3'
-        edit LEVELS '850,500,300,50'
-        family deps
-          task dummy
-            time 12:00
-        endfamily
-        task daily_fields_da
-          trigger deps eq complete
-        task daily_totalcolumns_da
-          trigger daily_fields_da eq complete
-          edit PARAMETERS 'tcco,gtco3'
-        task daily_zonalmean_da
-          trigger daily_totalcolumns_da eq complete
-        task daily_crosssection_da
-          trigger daily_zonalmean_da eq complete
-      endfamily
-      family uv
-        repeat date YMD 20081223 20090924 1
-        edit VERSION 'ewsf'
-        edit PARAMETERS '82'
-        family deps
-          task dummy
-            time 16:00
-        endfamily
-        task uv_dose
-          trigger deps eq complete
-          edit METPY 'metpy_new'
-      endfamily
-      family reanalysis
-        repeat integer month 200301 200312
-        edit VERSION 'eyih'
-        edit LEVELS '850,500,300,50'
-        edit PARAMETERS 'co,go3,hcho,nox'
-        task monthly_fields
-        task monthly_totalcolumns
-          edit PARAMETERS 'tcco,gtco3,tchcho'
-        task monthly_zonalmean
-          trigger monthly_totalcolumns eq complete
-        task monthly_crosssection
-          trigger monthly_zonalmean eq complete
-      endfamily
-      task logfilestore
-        trigger realtime eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit KEEPLOGS 'no'
-        edit LOGSTOECFS 'no'
-        edit MOVE_TO_ECFS 'yes'
-      task logfiles
-        trigger logfilestore eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit MOVE_TO_ECFS 'no'
-      family polarcat
-        repeat date YMD 20081223 20120924 1
-        edit VERSION 'f7kn'
-        edit OWNER 'nal'
-        family deps
-          task dummy
-            time 11:00
-        endfamily
-        task polarcat_retrieve_and_process
-          trigger deps eq complete
-        task polarcat_make_latlon_plots
-          trigger polarcat_retrieve_and_process eq complete
-        task polarcat_make_polar_plots
-          trigger polarcat_make_latlon_plots eq complete
-        task polarcat_make_xs_plots
-          trigger polarcat_make_polar_plots eq complete
-        task polarcat_cleanup
-          trigger polarcat_make_xs_plots eq complete
-      endfamily
-    endfamily
-  endfamily
-  family ghg
-    inlimit /gems/limits:linux_cluster
-    family plot
-      edit METPY 'metpy_new'
-      edit UPDATE_WEB_NOW 'yes'
-      edit DO_PUSH_TO_WEB 'yes'
-      family reanalysis
-        edit PARAMETERS 'tcco2'
-        task tcco2_mean
-      endfamily
-      family ch4_reanalysis
-        repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712"
-        edit VERSION 'f46b'
-        edit PARAMETERS 'tcch4'
-        task ch4_monthly_totalcolumns
-      endfamily
-      family iasi_plots
-        repeat enumerated month "200801" "200802" "200803" "200804" "200805" "200806" "200807" "200808" "200809" "200810" "200811" "200812"
-        task iasi
-      endfamily
-      family ch4_flux_inversion
-        repeat enumerated month "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412"
-        task plot_ch4_flux
-      endfamily
-    endfamily
-  endfamily
-  family aer
-    edit UPDATE_WEB_NOW 'yes'
-    edit DO_PUSH_TO_WEB 'yes'
-    edit METPY 'metpy_dev'
-    inlimit /gems/limits:linux_cluster
-    family realtime
-      repeat date YMD 20080507 20081224 1
-      edit VERSION 'f0dm'
-      edit AERTYPES 'total,natural,anthropogenic'
-      edit METPY 'metpy_new'
-      family deps
-        task dummy
-          time 08:30
-      endfamily
-      task optical_depth
-        trigger deps eq complete
-    endfamily
-    family realtime_da
-      repeat date YMD 20080506 20091224 1
-      edit VERSION 'f8na'
-      edit AERTYPES 'total,natural,anthropogenic'
-      edit METPY 'metpy_new'
-      family deps
-        task dummy
-          time 12:00
-      endfamily
-      task optical_depth_da
-        trigger deps eq complete
-    endfamily
-    family verif
-      repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412"
-      task aer_station_plots_exlz_ezub
-      task aer_stat_plots_exlz_ezub
-        trigger aer_station_plots_exlz_ezub eq complete
-    endfamily
-    family fire_products
-      repeat date YMD 20080506 20091224 1
-      edit METPY 'metpy_new'
-      family deps
-        task dummy
-          time 07:00
-      endfamily
-      task fire_radiative_power
-        trigger deps eq complete
-    endfamily
-    family verif_f1kd
-      repeat enumerated month "200807" "200808" "200809" "200810" "200811" "200812" "200901" "200902" "200903" "200904" "200905" "200906" "200907" "200908" "200909" "200910" "200911" "200912"
-      task aer_station_plots_f1kd
-      task aer_stat_plots_f1kd
-        trigger aer_station_plots_f1kd eq complete
-    endfamily
-  endfamily
-  family raq
-    edit SMSTRIES '5'
-    edit UPDATE_WEB_NOW 'yes'
-    edit DO_PUSH_TO_WEB 'yes'
-    edit METPY 'metpy_new'
-    edit VERSION 'gems'
-    inlimit /gems/limits:linux_cluster
-    family obs
-      repeat date YMD 20081223 20111001 1
-      edit METPY 'metpy_new'
-      edit FIRST_HOUR '0'
-      edit FINAL_HOUR '23'
-      edit STEP '1'
-      edit PARAMETERS 'o3,no2,so2,co,pm10'
-      edit COUNTRIES 'pl,fi,se,nl,fr'
-      edit ARCHIVED_COUNTRIES 'uk,es,de'
-      family deps
-        task dummy
-          time 11:35
-      endfamily
-      task plot_obs
-        trigger deps eq complete
-    endfamily
-    family ensemble
-      repeat date YMD 20081223 20111001 1
-      edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
-      family deps
-        task dummy
-          time 10:00
-      endfamily
-      task regrid_models
-        trigger deps eq complete
-        edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
-      family plot_ensemble
-        inlimit /gems/limits:raq_ensemble
-        task plot_ensemble_o3
-          trigger ../regrid_models eq complete
-          edit PARAMETER 'o3'
-          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH'
-        task plot_ensemble_no2
-          trigger ../regrid_models eq complete
-          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
-          edit PARAMETER 'no2'
-        task plot_ensemble_so2
-          trigger ../regrid_models eq complete
-          edit PARAMETER 'so2'
-          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
-        task plot_ensemble_co
-          trigger ../regrid_models eq complete
-          edit PARAMETER 'co'
-          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
-        task plot_ensemble_pm10
-          trigger ../regrid_models eq complete
-          edit PARAMETER 'pm10'
-          edit MODELS 'CHI,EMP,FMI,NKU,RIU,SMH,UKN'
-        task plot_epsgram
-          trigger ../regrid_models eq complete
-        task plot_ensemble_aqi
-          trigger ./plot_ensemble_o3 eq complete and ./plot_ensemble_no2 eq complete and ./plot_ensemble_so2 eq complete and ./plot_ensemble_pm10 eq complete
-          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,NKU,RIU,SMH'
-      endfamily
-      task compute_hourly_ensemble
-        trigger plot_ensemble eq complete
-        edit PARAMETERS 'o3,no2,so2,co,pm10'
-      task cleanup_models
-        trigger compute_hourly_ensemble eq complete
-        time 15:30
-    endfamily
-    family verif
-      edit METPY 'metpy_new'
-      family scores
-        repeat date YMD 20080731 20100716 1
-        family deps
-          task dummy
-            time 11:35
-        endfamily
-        family compute_scores
-          edit PARAMETERS 'o3,no2,so2,pm10'
-          task verify_RAQ
-            trigger ../deps eq complete
-            label status ""
-        endfamily
-        family plot_scores
-          edit PARAMETERS 'o3,no2,so2,co,pm10'
-          edit COUNTRIES 'pl,fi,se,nl,fr'
-          edit ARCHIVED_COUNTRIES 'uk,es,de'
-          task plot_RAQ_mean_scores
-            trigger ../compute_scores eq complete
-          task plot_RAQ_ts_scores
-            trigger ../compute_scores eq complete
-          task plot_RAQ_taylor_plots
-            trigger ../compute_scores eq complete
-        endfamily
-      endfamily
-      family obs_model
-        family values
-          repeat date YMD 20080731 20100716 1
-          edit COUNTRIES 'pl,fi,se,nl,fr'
-          edit ARCHIVED_COUNTRIES 'uk,es,de'
-          task plot_obs_model_o3
-            trigger ( /gems/raq/verif/scores:YMD gt /gems/raq/verif/obs_model/values:YMD) or ../../scores eq complete
-            edit PARAMETER 'o3'
-            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH'
-          task plot_obs_model_no2
-            trigger plot_obs_model_o3 eq complete
-            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
-            edit PARAMETER 'no2'
-          task plot_obs_model_so2
-            trigger plot_obs_model_no2 eq complete
-            edit PARAMETER 'so2'
-            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,NKU,RIU,SMH,UKN'
-          task plot_obs_model_co
-            trigger plot_obs_model_so2 eq complete
-            edit PARAMETER 'co'
-            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH'
-          task plot_obs_model_pm10
-            trigger plot_obs_model_co eq complete
-            edit PARAMETER 'pm10'
-            edit MODELS 'CHI,EMP,FMI,NKU,RIU,SMH,UKN'
-        endfamily
-      endfamily
-      family plot_OMI
-        repeat date YMD 20080731 20100716 1
-        family deps
-          task dummy
-            time 11:00
-        endfamily
-        task plot_OMI_tc
-          trigger deps eq complete
-          edit MODELS 'CHI,CNR,DMI,EMP,FMI,NKU,RIU,SMH'
-      endfamily
-      family rescore_fam
-        family rescore_1
-          repeat date YMD 20080601 20081031 1
-          task rescore_RAQ_1
-            label status ""
-        endfamily
-        family rescore_2
-          repeat date YMD 20080601 20081031 1
-          task rescore_RAQ_2
-            label status ""
-        endfamily
-        family rescore_3
-          repeat date YMD 20080601 20081031 1
-          task rescore_RAQ_3
-            label status ""
-        endfamily
-        family rescore_4
-          repeat date YMD 20080601 20081031 1
-          task rescore_RAQ_4
-            label status ""
-        endfamily
-        family rescore_5
-          repeat date YMD 20080601 20081031 1
-          task rescore_RAQ_5
-            label status ""
-        endfamily
-      endfamily
-    endfamily
-    family models
-      edit FIRST_STEP '0'
-      edit FINAL_STEP '72'
-      edit STEP '1'
-      edit DEADLINE '1500'
-      edit LEVELS '500,1000,3000'
-      edit PARAMETERS 'o3,no,no2'
-      family CHI
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'CHI'
-        family plot
-          complete plot/finish eq complete
-          task plot_CHI
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_CHI:done or plot_CHI eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family CNR
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'CNR'
-        family plot
-          complete plot/finish eq complete
-          task plot_CNR
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_CNR:done or plot_CNR eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family DMI
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'DMI'
-        family plot
-          complete plot/finish eq complete
-          task plot_DMI
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_DMI:done or plot_DMI eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family EMP
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'EMP'
-        family plot
-          complete plot/finish eq complete
-          task plot_EMP
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_EMP:done or plot_EMP eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family FMI
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'FMI'
-        edit PARAMETERS 'o3,no,no2'
-        family plot
-          complete plot/finish eq complete
-          task plot_FMI
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_FMI:done or plot_FMI eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family KNM
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'KNM'
-        family plot
-          complete plot/finish eq complete
-          task plot_KNM
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_KNM:done or plot_KNM eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family MFM
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'MFM'
-        family plot
-          complete plot/finish eq complete
-          task plot_MFM
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_MFM:done or plot_MFM eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family MOZ
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'MOZ'
-        edit FIRST_STEP '1'
-        family plot
-          complete plot/finish eq complete
-          task plot_MOZ
-            label status "nothing yet"
-            event done
-            cron 10:00 16:00 00:30
-          task finish
-            complete plot_MOZ:done or plot_MOZ eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 16:15
-      endfamily
-      family NKU
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'NKU'
-        family plot
-          complete plot/finish eq complete
-          task plot_NKU
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_NKU:done or plot_NKU eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family RIU
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'RIU'
-        family plot
-          complete plot/finish eq complete
-          task plot_RIU
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_RIU:done or plot_RIU eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family SMH
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'SMH'
-        family plot
-          complete plot/finish eq complete
-          task plot_SMH
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_SMH:done or plot_SMH eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-      family UKN
-        repeat date YMD 20081223 20111001 1
-        edit MODEL 'UKN'
-        edit FINAL_STEP '71'
-        edit PARAMETERS 'no,no2'
-        family plot
-          complete plot/finish eq complete
-          task plot_UKN
-            label status "nothing yet"
-            event done
-            cron 00:00 15:00 00:30
-          task finish
-            complete plot_UKN:done or plot_UKN eq complete
-            trigger 1 eq 0
-        endfamily
-        task dummy
-          trigger plot eq complete
-          time 15:15
-      endfamily
-    endfamily
-    family etc
-      task cleanup_ftp
-        cron 23:55
-    endfamily
-  endfamily
-  family combined
-    inlimit /gems/limits:linux_cluster
-    family reanalysis
-      repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712" "200801"
-      edit VERSION 'f026'
-      edit LEVELS '850,500,300,50'
-      edit PARAMETERS 'co,go3,hcho,ch4,nox'
-      task gems_monthly_fields
-      task gems_monthly_zonalmean
-      task gems_monthly_totalcolumns
-        edit PARAMETERS 'tcco2,tcco,gtco3,tchcho,tcch4'
-    endfamily
-    family reanalysis_update
-      repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712" "200801"
-      edit VERSION 'ey2o'
-      task gems_monthly_totalcolumns
-        edit PARAMETERS 'tcco2'
-    endfamily
-  endfamily
-endsuite
-suite tparc
-  edit USER 'emos'
-  edit SCHOST 'hpce'
-  edit SCHOST_BKUP 'hpcf'
-  edit WSHOST 'swarm'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/emos_dir/0001/log'
-  edit USE_YMD 'true'
-  edit YMD '20100105'
-  edit DATEMASK '*.*.*'
-  edit VERSION '0001'
-  edit INIEXPVER '0015'
-  edit TCINIEXPVER '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '00'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'tc'
-  edit USER_PRIORITY '70'
-  edit REINITIALIZE 'false'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/tparc/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/tparc/include'
-  edit ACCOUNT 'oosu'
-  edit STREAM 'DA'
-  edit EMOS_STREAM 'EF'
-  edit ENSEMBLES '50'
-  edit ENS_SIZE '50'
-  edit MARS_DB 'marsod'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit SMSLOGHOST 'hpce'
-  edit SMSLOGPORT '9316'
-  edit OD_PROJ 'od'
-  edit SUITE_START '20080611'
-  edit QUEUE 'emos-e'
-  edit QUEUE_EPILOG 'emos-exp'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/vol/emos_nc/output'
-  edit SMSOUT '/vol/emos_nc/output'
-  edit METPY 'metpy_new'
-  edit SLEEPTIME '1'
-  inlimit /limits:swarm
-  clock hybrid 
-  family pop
-    repeat date YMD 20100105 20120410 1
-    limit plots 5
-    family 00
-      edit DELTA_DAY '1'
-      edit PLOT_AREAS 'Tparc_winter'
-      edit EMOS_BASE '00'
-      edit UPDATE_WEB_NOW 'yes'
-      inlimit plots
-      family deterministic
-        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
-        edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
-        edit STREAM 'DA'
-        task delay
-          time 07:30
-        family data
-          trigger delay eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
-          edit STEP_LIST '12/to/144/by/12'
-          task mslp
-          task rain
-          task rh
-          task t2m
-          task t850
-          task z500
-          task w30m
-          task wind
-          task wr
-          task wbpt
-        endfamily
-        family web
-          trigger data eq complete
-          task w_msl_uv200
-          task w_mslrain
-          task w_t2m30mw
-          task w_uv_rh
-          task w_z500t850
-          task w_wr850_700
-          task w_wbpt_msl
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop'
-      endfamily
-      family interactive_chart
-        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
-        family interactive_ghost
-          time 00:01
-          task w_msl_mean_spread_ghost
-            edit PLOT_STEPS '36,48,60,72,84,96,108,120,132,144'
-            edit DELTA_VALUE '-1'
-        endfamily
-        family interactive_real
-          time 08:55
-          task w_msl_mean_spread_ghost
-            edit PLOT_STEPS '36,48,60,72,84,96,108,120,132,144'
-            edit DELTA_VALUE '0'
-        endfamily
-      endfamily
-      family eps
-        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
-        edit STREAM 'EF'
-        edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
-        task delay
-          time 08:55
-        family data
-          trigger delay eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
-          task efi
-          task lsmoro
-            edit STEP_LIST '0/to/48/by/12'
-          task proba
-            edit PLOT_STEPS_RANGE '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
-            edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
-            edit RANGE 'legA'
-        endfamily
-        family web
-          trigger data eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
-          edit STEP_RANGE 'legA'
-          family probabilities
-            task pb_2t
-            task pb_ff
-            task pb_tp
-              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
-            task w_proba_gusts
-              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
-          endfamily
-          family efi
-            family efi_tpi
-              task w_efi
-                edit PARAMETER 'tpi'
-            endfamily
-            family efi_10wsi
-              task w_efi
-                edit PARAMETER '10wsi'
-            endfamily
-            family efi_2ti
-              task w_efi
-                edit PARAMETER '2ti'
-            endfamily
-            family efi_10fgi
-              task w_efi
-                edit PARAMETER '10fgi'
-            endfamily
-          endfamily
-          family others
-            edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
-            task w_msl_mean_spread
-            task w_z500_mean_spread
-            task w_z200_mean_spread
-            task w_t850_mean_spread
-          endfamily
-          family quartiles
-            edit AREA_TO_PLOT '-10/100/90/300'
-            edit AREA_TO_PLOT_ZOOM '20/140/90/280'
-            edit MAP_VERT_LONG '160'
-            edit MAP_VERT_LONG_ZOOM '160'
-            edit MAP_PROJECTION 'CYLINDRICAL'
-            edit STEP_LIST '6/TO/150/by/12'
-            edit STEP_PLOT '12/TO/144/by/12'
-            task w_tp_quartiles
-            task w_wind_quartiles
-            task w_wgust_quartiles
-            task w_wind925_quartiles
-            task w_cape_quartiles
-          endfamily
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop'
-      endfamily
-    endfamily
-    family 12
-      edit PLOT_AREAS 'Tparc_winter'
-      edit EMOS_BASE '12'
-      edit UPDATE_WEB_NOW 'yes'
-      inlimit plots
-      family deterministic
-        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
-        edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
-        edit STREAM 'DA'
-        task delay
-          time 19:20
-        family data
-          trigger delay eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
-          edit STEP_LIST '12/to/144/by/12'
-          task mslp
-          task rain
-          task rh
-          task t2m
-          task t850
-          task z500
-          task w30m
-          task wind
-          task wr
-          task wbpt
-        endfamily
-        family web
-          trigger data eq complete
-          task w_msl_uv200
-          task w_mslrain
-          task w_t2m30mw
-          task w_uv_rh
-          task w_z500t850
-          task w_wr850_700
-          task w_wbpt_msl
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop'
-      endfamily
-      family eps
-        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
-        edit STREAM 'EF'
-        edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
-        task delay
-          time 20:50
-        family data
-          trigger delay eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
-          task efi
-          task lsmoro
-            edit STEP_LIST '0/to/48/by/12'
-          task proba
-            edit PLOT_STEPS_RANGE '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
-            edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
-            edit RANGE 'legA'
-        endfamily
-        family web
-          trigger data eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
-          edit STEP_RANGE 'legA'
-          family probabilities
-            task pb_2t
-            task pb_ff
-            task pb_tp
-              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
-            task w_proba_gusts
-              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
-          endfamily
-          family efi
-            family efi_tpi
-              task w_efi
-                edit PARAMETER 'tpi'
-            endfamily
-            family efi_10wsi
-              task w_efi
-                edit PARAMETER '10wsi'
-            endfamily
-            family efi_2ti
-              task w_efi
-                edit PARAMETER '2ti'
-            endfamily
-            family efi_10fgi
-              task w_efi
-                edit PARAMETER '10fgi'
-            endfamily
-          endfamily
-          family others
-            edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
-            task w_msl_mean_spread
-            task w_z500_mean_spread
-            task w_z200_mean_spread
-            task w_t850_mean_spread
-          endfamily
-          family quartiles
-            edit AREA_TO_PLOT '-10/100/90/300'
-            edit AREA_TO_PLOT_ZOOM '20/140/90/280'
-            edit MAP_VERT_LONG '160'
-            edit MAP_VERT_LONG_ZOOM '160'
-            edit MAP_PROJECTION 'CYLINDRICAL'
-            edit STEP_LIST '6/TO/150/by/12'
-            edit STEP_PLOT '12/TO/144/by/12'
-            task w_tp_quartiles
-            task w_wind_quartiles
-            task w_wgust_quartiles
-            task w_wind925_quartiles
-            task w_cape_quartiles
-          endfamily
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop'
-      endfamily
-    endfamily
-    family ukmo
-      edit DELTA_DAY '1'
-      edit SMSFILES '/home/ma/emos/def/tparc/pop/mogreps'
-      edit PLOT_AREAS 'Tparc_winter'
-      edit EMOS_BASE '00'
-      edit STREAM 'EF'
-      edit UPDATE_WEB_NOW 'yes'
-      inlimit plots
-      task delay
-        time 09:00
-      family mogreps
-        trigger delay eq complete
-        edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
-        family web
-          family en_mean_spread
-            task m_msl_mean_spread
-            task m_z500_mean_spread
-            task m_z200_mean_spread
-            task m_t850_mean_spread
-          endfamily
-          family quartiles
-            edit AREA_TO_PLOT '-10/100/90/300'
-            edit AREA_TO_PLOT_ZOOM '20/140/90/280'
-            edit MAP_VERT_LONG '160'
-            edit MAP_VERT_LONG_ZOOM '160'
-            edit MAP_PROJECTION 'CYLINDRICAL'
-            edit STEP_LIST '6/TO/150/by/12'
-            edit STEP_PLOT '12/TO/144/by/12'
-            task m_tp_quartiles
-            task m_wind_quartiles
-            task m_wind925_quartiles
-          endfamily
-        endfamily
-        task cleanup
-          trigger web eq complete
-          edit SMSFILES '/home/ma/emos/def/tparc/pop'
-      endfamily
-    endfamily
-    task restart
-      trigger ./00 eq complete and ukmo eq complete and ./12 eq complete
-      time 11:00
-  endfamily
-endsuite
-suite tparc_dts
-  edit USER 'emos'
-  edit SCHOST 'hpcf'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/emos_esuite/emos_data/0015/log'
-  edit EMOS_TYPE '1'
-  edit DTS '1'
-  edit USE_YMD 'true'
-  edit YMD '20090327'
-  edit DATEMASK '*.*.*'
-  edit VERSION '0015'
-  edit INIEXPVER '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'mc'
-  edit USER_PRIORITY '70'
-  edit PRIORITY '70'
-  edit ININPES '16'
-  edit NPROCA '16'
-  edit NPROCB '1'
-  edit SVMODE 'dts'
-  edit SVPROJVERT 'lower_troposphere'
-  edit REINITIALIZE 'false'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
-  edit SMSINCLUDE '/home/ma/emos/def/tparc_33r1/include'
-  edit ACCOUNT 'oodts'
-  edit STREAM 'EF'
-  edit EMOS_STREAM 'EF'
-  edit MARS_DB 'marser'
-  edit EPSTYPE 'sv'
-  edit MEMBER '0'
-  edit INILEVELS '91'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit FCGROUP 'fc0'
-  edit SMSLOGHOST 'hpcf'
-  edit SMSLOGPORT '9316'
-  edit SVTHREADS '2'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/emos_esuite/emos_data/0015/log'
-  edit SMSOUT '/emos_esuite/emos_data/0015/log'
-  edit SLEEPTIME '1'
-  inlimit /limits:hpcf
-  clock hybrid 
-  family limits
-    limit hpce 5
-    limit hpcf 5
-    limit mars 3
-    limit webplots 3
-    limit linux_cluster 3
-  endfamily
-  family main
-    repeat date YMD 20090327 20190101 1
-    family make
-      edit EMOS_BASE '00'
-      task setup
-      task links
-        trigger setup eq complete
-      task datalinks
-        trigger links eq complete and setup eq complete
-      family bins
-        trigger datalinks eq complete
-        task ifs
-        task prepdata
-        task mc_tools
-      endfamily
-    endfamily
-    family 00
-      edit EMOS_BASE '00'
-      task concordiasi_control
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        time 10:00
-      family case1
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '1'
-        edit INISTEP '42'
-        edit FCLENGTH '30'
-        edit FSFAMILY 'mc/case1'
-        edit ALAT1 '20'
-        edit ALON1 '0'
-        edit ALAT3 '-20'
-        edit ALON3 '359'
-        edit DELTA_HOUR '42'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case2
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '2'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case2'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case3
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '3'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case3'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case4
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '4'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case4'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case5
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '5'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case5'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case6
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '6'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case6'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case7
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '7'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case7'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case8
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '8'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case8'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case9
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '9'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case9'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case10
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
-        edit REGIONNR '10'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit FSFAMILY 'mc/case10'
-        inlimit /tparc_dts/limits:hpcf
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '4'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit EMOS_BASE '00'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'main'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'main'
-      time 19:00
-  endfamily
-  family lag
-    trigger ( main:YMD ge lag:YMD)
-    repeat date YMD 20090327 20190101 1
-    inlimit /tparc_dts/limits:mars
-    family 00
-      edit EMOS_BASE '00'
-      edit SUBFSFAMILY ''
-      task concordiasi_archivecontrol
-        trigger /tparc_dts/main/00/concordiasi_control eq complete
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-      family case1
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case1 eq complete
-        edit FSFAMILY 'mc/case1'
-        edit REGIONNR '1'
-        edit INISTEP '42'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '42'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case2
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case2 eq complete
-        edit FSFAMILY 'mc/case2'
-        edit REGIONNR '2'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case3
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case3 eq complete
-        edit FSFAMILY 'mc/case3'
-        edit REGIONNR '3'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case4
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case4 eq complete
-        edit FSFAMILY 'mc/case4'
-        edit REGIONNR '4'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case5
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case5 eq complete
-        edit FSFAMILY 'mc/case5'
-        edit REGIONNR '5'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case6
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case6 eq complete
-        edit FSFAMILY 'mc/case6'
-        edit REGIONNR '6'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case7
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case7 eq complete
-        edit FSFAMILY 'mc/case7'
-        edit REGIONNR '7'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case8
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case8 eq complete
-        edit FSFAMILY 'mc/case8'
-        edit REGIONNR '8'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case9
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case9 eq complete
-        edit FSFAMILY 'mc/case9'
-        edit REGIONNR '9'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-      family case10
-        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case10 eq complete
-        edit FSFAMILY 'mc/case10'
-        edit REGIONNR '10'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave_concordiasi
-        task svsave
-        task archive_sv
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGTASK 'lag'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'lag'
-      time 19:00
-  endfamily
-  family pop
-    trigger ( main:YMD ge pop:YMD)
-    repeat date YMD 20090327 20190101 1
-    edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
-    edit EMOS_BASE '00'
-    inlimit /tparc_dts/limits:webplots
-    family 00
-      edit SUBFSFAMILY ''
-      edit HOUR '0'
-      task concordiasi_plotcontrol
-        trigger /tparc_dts/main/00/concordiasi_control eq complete
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-      task getobslist
-        trigger concordiasi_plotcontrol eq complete
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-      family case1
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case1 eq complete
-        edit FSFAMILY 'mc/case1'
-        edit INISTEP '42'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '42'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case2
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case2 eq complete
-        edit FSFAMILY 'mc/case2'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case3
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case3 eq complete
-        edit FSFAMILY 'mc/case3'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case4
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case4 eq complete
-        edit FSFAMILY 'mc/case4'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case5
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case5 eq complete
-        edit FSFAMILY 'mc/case5'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case6
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case6 eq complete
-        edit FSFAMILY 'mc/case6'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case7
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case7 eq complete
-        edit FSFAMILY 'mc/case7'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case8
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case8 eq complete
-        edit FSFAMILY 'mc/case8'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case9
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case9 eq complete
-        edit FSFAMILY 'mc/case9'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-      family case10
-        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case10 eq complete
-        edit FSFAMILY 'mc/case10'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /tparc_dts/limits:linux_cluster
-      endfamily
-    endfamily
-    task cases2ftp
-      trigger /tparc_dts/main/00/concordiasi_control eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      inlimit /tparc_dts/limits:linux_cluster
-    task cases2web
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      inlimit /tparc_dts/limits:linux_cluster
-    task clean
-      trigger ./00 eq complete and cases2web eq complete
-    task clean_ws
-      trigger ./00 eq complete and cases2web eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      inlimit /tparc_dts/limits:linux_cluster
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'pop'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete and ./clean eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'pop'
-      time 22:00
-  endfamily
-  family sap_other_centres
-    trigger ( main:YMD ge pop:YMD)
-    repeat date YMD 20090327 20190101 1
-    edit EMOS_BASE '00'
-    family 00
-      family ukmo
-        edit CENTRE 'metoffice'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'egrr'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task getdata
-          time 17:00
-        task plotftg_other
-          trigger getdata eq complete
-        task sap_other2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_other2web eq complete
-      endfamily
-      family ncep
-        edit CENTRE 'ncep'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'kwbc'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task getdata
-          time 17:00
-        task getfields
-          trigger getdata eq complete
-        task plotftg_other
-          trigger getfields eq complete
-        task sap_ncep2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task others2cfs
-          trigger sap_ncep2web eq complete
-        task archive_other
-          trigger others2cfs eq complete
-      endfamily
-      family nrl
-        edit CENTRE 'nrl'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'fnmoc'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'sv'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task get_some_data
-          time 18:20
-        task get_some_fields
-          trigger get_some_data eq complete
-        task plotftg_other
-          trigger get_some_fields eq complete
-        task sap_nrl2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task others2cfs
-          trigger sap_nrl2web eq complete
-        task archive_other
-          trigger others2cfs eq complete
-      endfamily
-      family jma
-        edit CENTRE 'jma'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'jma'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task get_some_data
-          time 12:00
-        task get_some_fields
-          trigger get_some_data eq complete
-        task grib_mod_jma
-          trigger get_some_fields eq complete
-        task plotftg_other
-          trigger grib_mod_jma eq complete
-        task sap_jma2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task others2cfs
-          trigger sap_jma2web eq complete
-        task archive_other
-          trigger sap_jma2web eq complete
-      endfamily
-      family ntu
-        edit CENTRE 'ntu'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'ntu'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task getdata
-          time 10:00
-        task getfields
-          trigger getdata eq complete
-        task plotftg_other
-          trigger getfields eq complete
-        task sap_ntu2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_ntu2web eq complete
-      endfamily
-      family UYonsei
-        edit CENTRE 'UYonsei'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'UYonsei'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task get_some_data
-          time 15:45
-        task get_some_fields
-          trigger get_some_data eq complete
-        task plotftg_other
-          trigger get_some_fields eq complete
-        task sap_UYonsei2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task others2cfs
-          trigger sap_UYonsei2web eq complete
-        task archive_other
-          trigger others2cfs eq complete
-      endfamily
-      family UWash
-        edit CENTRE 'UWash'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'UWash'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task get_some_data
-          time 10:00
-        task get_some_fields
-          trigger get_some_data eq complete
-        task plotftg_other
-          trigger get_some_fields eq complete
-        task sap_UWash2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_UWash2web eq complete
-      endfamily
-      family noaa_hrd
-        edit CENTRE 'noaa_hrd'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'noaa_hrd'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /tparc_dts/limits:linux_cluster
-        task getdata
-          time 10:00
-        task getfields
-          trigger getdata eq complete
-        task plotftg_other
-          trigger getfields eq complete
-        task sap_noaa_hrd2web
-          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_noaa_hrd2web eq complete
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'sap_other_centres'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'sap_other_centres'
-      time 22:00
-  endfamily
-  family post_process
-    trigger ( main:YMD ge pop:YMD)
-    repeat date YMD 20090327 20190101 1
-    edit EMOS_BASE '00'
-    edit QUEUE 'emos'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit SMSOUT '/vol/emos_nc/output'
-    inlimit /tparc_dts/limits:linux_cluster
-    task fixed_cases
-      time 10:00
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'post_process'
-    task logfiles
-      late -s +00:05 -c +00:15
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'post_process'
-      time 19:00
-  endfamily
-endsuite
-suite dts
-  edit USER 'emos'
-  edit SCHOST 'c1b'
-  edit WSHOST 'swarm'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0014/log'
-  edit EMOS_TYPE '1'
-  edit USE_YMD 'true'
-  edit YMD '20080901'
-  edit DATEMASK '*.*.*'
-  edit VERSION '0014'
-  edit INIEXPVER '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'mc'
-  edit USER_PRIORITY '70'
-  edit PRIORITY '70'
-  edit ININPES '16'
-  edit NPROCA '16'
-  edit NPROCB '1'
-  edit SVMODE 'tg'
-  edit REINITIALIZE 'false'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/dts/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/dts/include'
-  edit ACCOUNT 'oodts'
-  edit STREAM 'EF'
-  edit EMOS_STREAM 'EF'
-  edit MARS_DB 'marser'
-  edit EPSTYPE 'sv'
-  edit MEMBER '0'
-  edit INILEVELS '91'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit FCGROUP 'fc0'
-  edit SMSLOGHOST 'c1b'
-  edit SMSLOGPORT '9316'
-  edit SVTHREADS '2'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/s1b/emos_esuite/emos_data/0014/log'
-  edit SMSOUT '/s1b/emos_esuite/emos_data/0014/log'
-  edit SLEEPTIME '1'
-  inlimit /limits:c1b
-  clock hybrid 
-  family limits
-    limit c1b 5
-    limit mars 3
-    limit webplots 3
-    limit swarm 3
-  endfamily
-  family main
-    repeat date YMD 20080901 20121212 1
-    family make
-      edit EMOS_BASE '00'
-      task setup
-      task links
-        trigger setup eq complete
-      task datalinks
-        trigger links eq complete and setup eq complete
-      family bins
-        trigger datalinks eq complete
-        task ifs
-        task prepdata
-        task mc_tools
-      endfamily
-    endfamily
-    family 00
-      edit EMOS_BASE '00'
-      task control
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-        time 10:35
-      family case1
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case1'
-        edit REGIONNR '1'
-        edit INISTEP '42'
-        edit FCLENGTH '30'
-        edit ALAT1 '47.3'
-        edit ALON1 '13.5'
-        edit ALAT3 '27.8'
-        edit ALON3 '37.7'
-        edit DELTA_HOUR '42'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case2
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case2'
-        edit REGIONNR '2'
-        edit INISTEP '54'
-        edit FCLENGTH '30'
-        edit ALAT1 '46.3'
-        edit ALON1 '342.9'
-        edit ALAT3 '26.9'
-        edit ALON3 '7.2'
-        edit DELTA_HOUR '54'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case3
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case3'
-        edit REGIONNR '3'
-        edit INISTEP '66'
-        edit FCLENGTH '30'
-        edit ALAT1 '49.5'
-        edit ALON1 '353.7'
-        edit ALAT3 '30.1'
-        edit ALON3 '18'
-        edit DELTA_HOUR '66'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case4
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case4'
-        edit REGIONNR '4'
-        edit INISTEP '42'
-        edit FCLENGTH '42'
-        edit ALAT1 '48.1'
-        edit ALON1 '353.6'
-        edit ALAT3 '28.6'
-        edit ALON3 '17.8'
-        edit DELTA_HOUR '42'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case5
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case5'
-        edit REGIONNR '5'
-        edit INISTEP '54'
-        edit FCLENGTH '30'
-        edit ALAT1 '48.9'
-        edit ALON1 '356.5'
-        edit ALAT3 '29.4'
-        edit ALON3 '20.8'
-        edit DELTA_HOUR '54'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case6
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case6'
-        edit REGIONNR '6'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case7
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case7'
-        edit REGIONNR '7'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case8
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case8'
-        edit REGIONNR '8'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case9
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case9'
-        edit REGIONNR '9'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-      family case10
-        trigger /dts/main/make eq complete and ./control eq complete
-        edit FSFAMILY 'mc/case10'
-        edit REGIONNR '10'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        inlimit /dts/limits:c1b
-        task getini
-        task inidata_sv
-          trigger getini eq complete
-          edit NPES '16'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit CPUTIME '1000'
-          edit STACK '450'
-        task sv
-          trigger inidata_sv eq complete
-          edit MEM '890'
-          edit NPES '42'
-          edit THREADS '2'
-          edit CPUTIME '20000'
-        task sv2gg
-          trigger sv eq complete
-          edit EMOS_TYPE '0'
-        task sv_te
-          trigger sv2gg eq complete
-        task sv2fdb
-          trigger sv_te eq complete
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit EMOS_BASE '00'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'main'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'main'
-      time 15:00
-  endfamily
-  family lag
-    trigger ( main:YMD ge lag:YMD)
-    repeat date YMD 20080901 20121212 1
-    inlimit /dts/limits:mars
-    family 00
-      edit EMOS_BASE '00'
-      edit SUBFSFAMILY ''
-      task archivecontrol
-        trigger /dts/main/00/control eq complete
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-      family case1
-        trigger ./archivecontrol eq complete and /dts/main/00/case1 eq complete
-        edit FSFAMILY 'mc/case1'
-        edit REGIONNR '1'
-        edit INISTEP '42'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '42'
-        task svsave
-        task archive_sv
-      endfamily
-      family case2
-        trigger ./archivecontrol eq complete and /dts/main/00/case2 eq complete
-        edit FSFAMILY 'mc/case2'
-        edit REGIONNR '2'
-        edit INISTEP '54'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '54'
-        task svsave
-        task archive_sv
-      endfamily
-      family case3
-        trigger ./archivecontrol eq complete and /dts/main/00/case3 eq complete
-        edit FSFAMILY 'mc/case3'
-        edit REGIONNR '3'
-        edit INISTEP '66'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '66'
-        task svsave
-        task archive_sv
-      endfamily
-      family case4
-        trigger ./archivecontrol eq complete and /dts/main/00/case4 eq complete
-        edit FSFAMILY 'mc/case4'
-        edit REGIONNR '4'
-        edit INISTEP '42'
-        edit FCLENGTH '42'
-        edit DELTA_HOUR '42'
-        task svsave
-        task archive_sv
-      endfamily
-      family case5
-        trigger ./archivecontrol eq complete and /dts/main/00/case5 eq complete
-        edit FSFAMILY 'mc/case5'
-        edit REGIONNR '5'
-        edit INISTEP '54'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '54'
-        task svsave
-        task archive_sv
-      endfamily
-      family case6
-        trigger ./archivecontrol eq complete and /dts/main/00/case6 eq complete
-        edit FSFAMILY 'mc/case6'
-        edit REGIONNR '6'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave
-        task archive_sv
-      endfamily
-      family case7
-        trigger ./archivecontrol eq complete and /dts/main/00/case7 eq complete
-        edit FSFAMILY 'mc/case7'
-        edit REGIONNR '7'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave
-        task archive_sv
-      endfamily
-      family case8
-        trigger ./archivecontrol eq complete and /dts/main/00/case8 eq complete
-        edit FSFAMILY 'mc/case8'
-        edit REGIONNR '8'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave
-        task archive_sv
-      endfamily
-      family case9
-        trigger ./archivecontrol eq complete and /dts/main/00/case9 eq complete
-        edit FSFAMILY 'mc/case9'
-        edit REGIONNR '9'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave
-        task archive_sv
-      endfamily
-      family case10
-        trigger ./archivecontrol eq complete and /dts/main/00/case10 eq complete
-        edit FSFAMILY 'mc/case10'
-        edit REGIONNR '10'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task svsave
-        task archive_sv
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGTASK 'lag'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'lag'
-      time 13:00
-  endfamily
-  family pop
-    trigger ( main:YMD ge pop:YMD)
-    repeat date YMD 20080901 20121212 1
-    edit EMOS_BASE '00'
-    inlimit /dts/limits:webplots
-    family 00
-      edit SUBFSFAMILY ''
-      edit HOUR '0'
-      task plotcontrol
-        trigger /dts/main/00/control eq complete
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-      task getobslist
-        trigger plotcontrol eq complete
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-      family case1
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case1 eq complete
-        edit FSFAMILY 'mc/case1'
-        edit INISTEP '42'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '42'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case2
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case2 eq complete
-        edit FSFAMILY 'mc/case2'
-        edit INISTEP '54'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '54'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case3
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case3 eq complete
-        edit FSFAMILY 'mc/case3'
-        edit INISTEP '66'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '66'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case4
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case4 eq complete
-        edit FSFAMILY 'mc/case4'
-        edit INISTEP '42'
-        edit FCLENGTH '42'
-        edit DELTA_HOUR '42'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case5
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case5 eq complete
-        edit FSFAMILY 'mc/case5'
-        edit INISTEP '54'
-        edit FCLENGTH '30'
-        edit DELTA_HOUR '54'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case6
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case6 eq complete
-        edit FSFAMILY 'mc/case6'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case7
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case7 eq complete
-        edit FSFAMILY 'mc/case7'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case8
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case8 eq complete
-        edit FSFAMILY 'mc/case8'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case9
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case9 eq complete
-        edit FSFAMILY 'mc/case9'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-      family case10
-        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case10 eq complete
-        edit FSFAMILY 'mc/case10'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        task plotftg
-          edit QUEUE 'emos'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /dts/limits:swarm
-      endfamily
-    endfamily
-    task cases2ftp
-      trigger /dts/main/00/control eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      inlimit /dts/limits:swarm
-    task cases2web
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      inlimit /dts/limits:swarm
-    task clean
-      trigger ./00 eq complete and cases2web eq complete
-    task clean_ws
-      trigger ./00 eq complete and cases2web eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      inlimit /dts/limits:swarm
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'pop'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete and ./clean eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'pop'
-      time 15:00
-  endfamily
-  family sap_other_centres
-    trigger ( main:YMD ge pop:YMD)
-    repeat date YMD 20080901 20121212 1
-    edit EMOS_BASE '00'
-    family 00
-      family ukmo
-        edit CENTRE 'metoffice'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'egrr'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-        task getdata
-          time 11:00
-        task plotftg_other
-          trigger getdata eq complete
-        task sap_other2web
-          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_other2web eq complete
-      endfamily
-      family meteofrance
-        edit CENTRE 'meteofrance'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'lfpw'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-        task getdata
-          time 11:00
-        task getfields
-          trigger getdata eq complete
-        task plotftg_other
-          trigger getfields eq complete
-        task sap_meteofrance2web
-          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_meteofrance2web eq complete
-      endfamily
-      family uib
-        edit CENTRE 'uib'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'uib'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-        task getdata
-          time 11:00
-        task getfields
-          trigger getdata eq complete
-        task plotftg_other
-          trigger getfields eq complete
-          edit SMSPASS 'stripped'
-        task sap_uib2web
-          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_uib2web eq complete
-      endfamily
-      family cnrm
-        edit CENTRE 'cnrm'
-        edit SUBFSFAMILY ''
-        edit FSFAMILY 'mc/%CENTRE%'
-        edit HOUR '0'
-        edit INISTEP '48'
-        edit FCLENGTH '24'
-        edit CENTRE_ORIGIN 'cnrm'
-        edit SAP_METHOD '0'
-        edit SAP_TYPE 'svar'
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /dts/limits:swarm
-        task getdata
-          time 11:00
-        task getfields
-          trigger getdata eq complete
-        task plotftg_other
-          trigger getfields eq complete
-        task sap_cnrm2web
-          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
-        task archive_other
-          trigger sap_cnrm2web eq complete
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'sap_other_centres'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'sap_other_centres'
-      time 15:00
-  endfamily
-  family post_process
-    trigger ( main:YMD ge pop:YMD)
-    repeat date YMD 20080901 20121212 1
-    edit EMOS_BASE '00'
-    edit QUEUE 'emos'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit SMSOUT '/vol/emos_nc/output'
-    inlimit /dts/limits:swarm
-    task monitor
-      time 07:00
-    task extraobs
-      time 14:05
-    task sendrequest
-      trigger extraobs eq complete
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'post_process'
-    task logfiles
-      late -s +00:05 -c +00:15
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'post_process'
-      time 15:00
-  endfamily
-endsuite
-suite seas_fr3_back
-  edit VERSION '0001'
-  edit EXPVER '0001'
-  edit SCHOST 'hpce'
-  edit WSHOST 'swarm'
-  edit WSLOGDIR '/vol/emos/output'
-  edit SCLOGDIR '/hpce/emos_dir/0001/log'
-  edit STREAM 'MMSF'
-  edit REINITIALIZE 'false'
-  edit EPSTYPE 'fc'
-  edit EMOS_BASE '00'
-  edit DATEMASK '*.*.*'
-  edit START_DAY '19781101'
-  edit END_DAY '20071201'
-  edit YMD '19781101'
-  edit USE_YMD 'true'
-  edit FCLENGTH '5160'
-  edit FCTOTAL '11'
-  edit OCTOTAL '1'
-  edit OCGROUP 'an0'
-  edit RUNCOUPLE '1'
-  edit OCSYSTEM '0'
-  edit OCMETHOD '1'
-  edit ORIGIN 'LFPW'
-  edit FDB_ROOT_FR '/fdb'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit USER_PRIORITY '50'
-  edit FIRST_DAY '0'
-  edit EMOS_TYPE 'fc'
-  edit EMOS_TIME_STEP_H '0000'
-  edit EMOS_STREAM 'DA'
-  edit MARS_DB 'marsod'
-  edit FCNPES '1'
-  edit ANNPES '1'
-  edit SMSHOME '/vol/emos/output'
-  edit SMSFILES '/home/ma/emos/def/seas_fr3_back/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/seas_fr3_back/include'
-  edit ACCOUNT 'oosu'
-  edit USER 'emos'
-  edit MEMBER '0'
-  edit RUNBACK '1'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/hpce/emos_dir/0001/log'
-  edit SMSOUT '/hpce/emos_dir/0001/log'
-  edit SMSLOGHOST 'hpce-batch'
-  edit SMSLOGPORT '9316'
-  edit HOUR '00'
-  edit FSFAMILY 'seas'
-  edit SLEEPTIME '1'
-  inlimit /limits:hpce
-  clock hybrid 
-  family limits
-    limit retrieve 2
-    limit mars 2
-    limit ws 6
-  endfamily
-  family make
-    task setup
-    task mmsf_tools
-      trigger setup eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      inlimit /limits:swarm
-      inlimit /seas_fr3_back/limits:ws
-    task sc_tools
-      trigger setup eq complete
-    task logfiles
-      trigger setup eq complete and sc_tools eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      edit LOGTASK 'make'
-  endfamily
-  family main
-    trigger make eq complete
-    repeat enumerated YMD "19790101" "19800101" "19810101" "19820101" "19830101" "19840101" "19850101" "19860101" "19870101" "19880101" "19890101" "19900101" "19910101" "19920101" "19930101" "19940101" "19950101" "19960101" "19970101" "19980101" "19990101" "20000101" "20010101" "20020101" "20030101" "20040101" "20050101" "20060101" "20070101" "19790201" "19800201" "19810201" "19820201" "19830201" "19840201" "19850201" "19860201" "19870201" "19880201" "19890201" "19900201" "19910201" "19920201" "19930201" "19940201" "19950201" "19960201" "19970201" "19980201" "19990201" "20000201" "20010201" "20020201" "20030201" "20040201" "20050201" "20060201" "20070201" "19790301" "19800301" "19810301" "19820301" "19830301" "19840301" "19850301" "19860301" "19870301" "19880301" "19890301" "19900301" "19910301" "19920301" "19930301" "19940301" "19950301" "19960301" "19970301" "19980301" "19990301" "20000301" "20010301" "20020301" "20030301" "20040301" "20050301" "20060301" "20070301" "19790401" "19800401" "19810401" "19820401" "19830401" "19840401" "19850401" "19860401" "19870401" "19880401" "19890401" "19900401" "19910401" "19920401" "19930401" "19940401" "19950401" "19960401" "19970401" "19980401" "19990401" "20000401" "20010401" "20020401" "20030401" "20040401" "20050401" "20060401" "20070401" "19790501" "19800501" "19810501" "19820501" "19830501" "19840501" "19850501" "19860501" "19870501" "19880501" "19890501" "19900501" "19910501" "19920501" "19930501" "19940501" "19950501" "19960501" "19970501" "19980501" "19990501" "20000501" "20010501" "20020501" "20030501" "20040501" "20050501" "20060501" "20070501" "19790601" "19800601" "19810601" "19820601" "19830601" "19840601" "19850601" "19860601" "19870601" "19880601" "19890601" "19900601" "19910601" "19920601" "19930601" "19940601" "19950601" "19960601" "19970601" "19980601" "19990601" "20000601" "20010601" "20020601" "20030601" "20040601" "20050601" "20060601" "20070601" "19790701" "19800701" "19810701" "19820701" "19830701" "19840701" "19850701" "19860701" "19870701" "19880701" "19890701" "19900701" "19910701" "19920701" "19930701" "19940701" "19950701" "19960701" "19970701" "19980701" "19990701" "20000701" "20010701" "20020701" "20030701" "20040701" "20050701" "20060701" "20070701" "19790801" "19800801" "19810801" "19820801" "19830801" "19840801" "19850801" "19860801" "19870801" "19880801" "19890801" "19900801" "19910801" "19920801" "19930801" "19940801" "19950801" "19960801" "19970801" "19980801" "19990801" "20000801" "20010801" "20020801" "20030801" "20040801" "20050801" "20060801" "20070801" "19790901" "19800901" "19810901" "19820901" "19830901" "19840901" "19850901" "19860901" "19870901" "19880901" "19890901" "19900901" "19910901" "19920901" "19930901" "19940901" "19950901" "19960901" "19970901" "19980901" "19990901" "20000901" "20010901" "20020901" "20030901" "20040901" "20050901" "20060901" "20070901" "19791001" "19801001" "19811001" "19821001" "19831001" "19841001" "19851001" "19861001" "19871001" "19881001" "19891001" "19901001" "19911001" "19921001" "19931001" "19941001" "19951001" "19961001" "19971001" "19981001" "19991001" "20001001" "20011001" "20021001" "20031001" "20041001" "20051001" "20061001" "20071001" "19781101" "19791101" "19801101" "19811101" "19821101" "19831101" "19841101" "19851101" "19861101" "19871101" "19881101" "19891101" "19901101" "19911101" "19921101" "19931101" "19941101" "19951101" "19961101" "19971101" "19981101" "19991101" "20001101" "20011101" "20021101" "20031101" "20041101" "20051101" "20061101" "20071101" "19781201" "19791201" "19801201" "19811201" "19821201" "19831201" "19841201" "19851201" "19861201" "19871201" "19881201" "19891201" "19901201" "19911201" "19921201" "19931201" "19941201" "19951201" "19961201" "19971201" "19981201" "19991201" "20001201" "20011201" "20021201" "20031201" "20041201" "20051201" "20061201" "20071201"
-    edit LOGTASK 'main'
-    family fc
-      family fc0
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc0'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc1
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc1'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc2
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc2'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc3
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc3'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc4
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc4'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc5
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc5'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc6
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc6'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc7
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc7'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc8
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc8'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc9
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc9'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-      family fc10
-        edit FCNUM 'fcnum'
-        edit FCGROUP 'fc10'
-        task fr2fdb
-          inlimit /seas_fr3_back/limits:retrieve
-        task extrafields_fr
-          trigger fr2fdb eq complete
-        task mm_sfc_fr
-          trigger fr2fdb eq complete and extrafields_fr eq complete
-        task mm_ua_fr
-          trigger fr2fdb eq complete and mm_sfc_fr eq complete
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      trigger fc eq complete and logfilestore eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-  family lag
-    trigger make eq complete
-    repeat enumerated YMD "19790101" "19800101" "19810101" "19820101" "19830101" "19840101" "19850101" "19860101" "19870101" "19880101" "19890101" "19900101" "19910101" "19920101" "19930101" "19940101" "19950101" "19960101" "19970101" "19980101" "19990101" "20000101" "20010101" "20020101" "20030101" "20040101" "20050101" "20060101" "20070101" "19790201" "19800201" "19810201" "19820201" "19830201" "19840201" "19850201" "19860201" "19870201" "19880201" "19890201" "19900201" "19910201" "19920201" "19930201" "19940201" "19950201" "19960201" "19970201" "19980201" "19990201" "20000201" "20010201" "20020201" "20030201" "20040201" "20050201" "20060201" "20070201" "19790301" "19800301" "19810301" "19820301" "19830301" "19840301" "19850301" "19860301" "19870301" "19880301" "19890301" "19900301" "19910301" "19920301" "19930301" "19940301" "19950301" "19960301" "19970301" "19980301" "19990301" "20000301" "20010301" "20020301" "20030301" "20040301" "20050301" "20060301" "20070301" "19790401" "19800401" "19810401" "19820401" "19830401" "19840401" "19850401" "19860401" "19870401" "19880401" "19890401" "19900401" "19910401" "19920401" "19930401" "19940401" "19950401" "19960401" "19970401" "19980401" "19990401" "20000401" "20010401" "20020401" "20030401" "20040401" "20050401" "20060401" "20070401" "19790501" "19800501" "19810501" "19820501" "19830501" "19840501" "19850501" "19860501" "19870501" "19880501" "19890501" "19900501" "19910501" "19920501" "19930501" "19940501" "19950501" "19960501" "19970501" "19980501" "19990501" "20000501" "20010501" "20020501" "20030501" "20040501" "20050501" "20060501" "20070501" "19790601" "19800601" "19810601" "19820601" "19830601" "19840601" "19850601" "19860601" "19870601" "19880601" "19890601" "19900601" "19910601" "19920601" "19930601" "19940601" "19950601" "19960601" "19970601" "19980601" "19990601" "20000601" "20010601" "20020601" "20030601" "20040601" "20050601" "20060601" "20070601" "19790701" "19800701" "19810701" "19820701" "19830701" "19840701" "19850701" "19860701" "19870701" "19880701" "19890701" "19900701" "19910701" "19920701" "19930701" "19940701" "19950701" "19960701" "19970701" "19980701" "19990701" "20000701" "20010701" "20020701" "20030701" "20040701" "20050701" "20060701" "20070701" "19790801" "19800801" "19810801" "19820801" "19830801" "19840801" "19850801" "19860801" "19870801" "19880801" "19890801" "19900801" "19910801" "19920801" "19930801" "19940801" "19950801" "19960801" "19970801" "19980801" "19990801" "20000801" "20010801" "20020801" "20030801" "20040801" "20050801" "20060801" "20070801" "19790901" "19800901" "19810901" "19820901" "19830901" "19840901" "19850901" "19860901" "19870901" "19880901" "19890901" "19900901" "19910901" "19920901" "19930901" "19940901" "19950901" "19960901" "19970901" "19980901" "19990901" "20000901" "20010901" "20020901" "20030901" "20040901" "20050901" "20060901" "20070901" "19791001" "19801001" "19811001" "19821001" "19831001" "19841001" "19851001" "19861001" "19871001" "19881001" "19891001" "19901001" "19911001" "19921001" "19931001" "19941001" "19951001" "19961001" "19971001" "19981001" "19991001" "20001001" "20011001" "20021001" "20031001" "20041001" "20051001" "20061001" "20071001" "19781101" "19791101" "19801101" "19811101" "19821101" "19831101" "19841101" "19851101" "19861101" "19871101" "19881101" "19891101" "19901101" "19911101" "19921101" "19931101" "19941101" "19951101" "19961101" "19971101" "19981101" "19991101" "20001101" "20011101" "20021101" "20031101" "20041101" "20051101" "20061101" "20071101" "19781201" "19791201" "19801201" "19811201" "19821201" "19831201" "19841201" "19851201" "19861201" "19871201" "19881201" "19891201" "19901201" "19911201" "19921201" "19931201" "19941201" "19951201" "19961201" "19971201" "19981201" "19991201" "20001201" "20011201" "20021201" "20031201" "20041201" "20051201" "20061201" "20071201"
-    edit LOGTASK 'lag'
-    family archive
-      trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc eq complete)
-      edit SMSFILES '/home/ma/emos/def/seas_fr3_back/smsfiles/archive'
-      inlimit /limits:mars
-      inlimit /seas_fr3_back/limits:mars
-      task daily_sfc_fr
-        label files ""
-        event fdb
-      task daily_ua_fr
-        trigger daily_sfc_fr eq complete
-        label files ""
-        event fdb
-      task mm_sfc_fr
-        label files ""
-        event fdb
-      task mm_ua_fr
-        label files ""
-        event fdb
-    endfamily
-    family process
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      inlimit /limits:swarm
-      inlimit /seas_fr3_back/limits:ws
-      family fc0
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc0 eq complete)
-        edit FCGROUP 'fc0'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc1
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc1 eq complete)
-        edit FCGROUP 'fc1'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc2
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc2 eq complete)
-        edit FCGROUP 'fc2'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc3
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc3 eq complete)
-        edit FCGROUP 'fc3'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc4
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc4 eq complete)
-        edit FCGROUP 'fc4'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc5
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc5 eq complete)
-        edit FCGROUP 'fc5'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc6
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc6 eq complete)
-        edit FCGROUP 'fc6'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc7
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc7 eq complete)
-        edit FCGROUP 'fc7'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc8
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc8 eq complete)
-        edit FCGROUP 'fc8'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc9
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc9 eq complete)
-        edit FCGROUP 'fc9'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-      family fc10
-        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc10 eq complete)
-        edit FCGROUP 'fc10'
-        edit FCNUM 'fcnum'
-        task nino_sst_fr
-        task nino_atmos_fr
-          trigger nino_sst_fr eq complete
-        task tcyc_fr
-          trigger nino_atmos_fr eq complete
-      endfamily
-    endfamily
-    family clean
-      trigger archive eq complete and process eq complete
-      task postclean_fdb
-      task clean_sc
-      task clean_ws
-        edit QUEUE 'emos'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-        edit LOGDIR '/vol/emos/output'
-        edit SMSOUT '/vol/emos/output'
-        inlimit /limits:swarm
-        inlimit /seas_fr3_back/limits:ws
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      trigger archive eq complete and process eq complete and clean eq complete and logfilestore eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
-      edit LOGDIR '/vol/emos/output'
-      edit SMSOUT '/vol/emos/output'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-endsuite
-suite cweb
-  edit USER 'emos'
-  edit SCHOST 'c1a'
-  edit SCHOST_BKUP 'c1b'
-  edit STHOST '/s1a'
-  edit STHOST_BKUP '/s1b'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/s1a/emos_esuite/emos_data/9001/log'
-  edit DATEMASK '*.*.*'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSLOGHOST 'c1a'
-  edit SMSLOGPORT '9316'
-  edit ACCOUNT 'oocweb'
-  edit VERSION '9001'
-  edit EPSVERSION '0001'
-  edit RFVERSION '0001'
-  edit SMSTRIES '1'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '00'
-  edit FIRST_DAY '0'
-  edit USE_YMD 'true'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/cweb'
-  edit SMSINCLUDE '/home/ma/emos/def/cweb/include'
-  edit FSFAMILY '/'
-  edit XBINS '/home/ma/emos/bin'
-  edit STREAM 'undef'
-  edit EPSTYPE 'undef'
-  edit MEMBER '0'
-  edit EMOS_TIME_STEP_H '00'
-  edit SUITE_START '20091001'
-  edit LOW_RESOLUTION '1.5'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family limits
-    limit retrieve 10
-    limit purge 1
-  endfamily
-  family o
-    repeat date YMD 20091001 20121212 1
-    edit STREAM 'oper'
-    family 00
-      trigger ( /cweb/o:YMD lt /o/main:YMD) or ( /cweb/o:YMD eq /o/main:YMD and /o/main/00/fc eq complete)
-      edit QUEUE 'ns'
-      edit QUEUE_EPILOG 'ns'
-      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
-      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
-      edit DELTA_DAY '1'
-      edit EMOS_BASE '00'
-      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
-      inlimit /limits:c1a
-      task purge
-        inlimit /cweb/limits:purge
-        label info ""
-      family feed
-        trigger purge eq complete
-        inlimit /cweb/limits:retrieve
-        task an_sfc
-          label info ""
-          label grid ""
-        task an_pl
-          label info ""
-          label grid ""
-        task an_ml
-          label info ""
-          label grid ""
-        task fc_sfc
-          label info ""
-          label grid ""
-        task fc_pl
-          label info ""
-          label grid ""
-        task fc_ml
-          label info ""
-          label grid ""
-        task fc_wave
-          label info ""
-          label grid ""
-        task sim
-          trigger ( /o/lag:YMD gt /cweb/o:YMD) or ( /o/lag:YMD eq /cweb/o:YMD and /o/lag/00/satim eq complete)
-          label info ""
-          label grid ""
-      endfamily
-      task check
-        trigger feed eq complete
-        label info ""
-      task ready
-        trigger check eq complete
-        label info ""
-    endfamily
-    family 12
-      trigger ( /cweb/o:YMD lt /o/main:YMD) or ( /cweb/o:YMD eq /o/main:YMD and /o/main/12/fc eq complete)
-      edit QUEUE 'ns'
-      edit QUEUE_EPILOG 'ns'
-      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
-      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
-      edit DELTA_DAY '0'
-      edit EMOS_BASE '12'
-      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
-      inlimit /limits:c1a
-      task purge
-        inlimit /cweb/limits:purge
-        label info ""
-      family feed
-        trigger purge eq complete
-        inlimit /cweb/limits:retrieve
-        task an_sfc
-          label info ""
-          label grid ""
-        task an_pl
-          label info ""
-          label grid ""
-        task an_ml
-          label info ""
-          label grid ""
-        task fc_sfc
-          label info ""
-          label grid ""
-        task fc_pl
-          label info ""
-          label grid ""
-        task fc_ml
-          label info ""
-          label grid ""
-        task fc_wave
-          label info ""
-          label grid ""
-        task sim
-          trigger ( /o/lag:YMD gt /cweb/o:YMD) or ( /o/lag:YMD eq /cweb/o:YMD and /o/lag/12/satim eq complete)
-          label info ""
-          label grid ""
-      endfamily
-      task check
-        trigger feed eq complete
-        label info ""
-      task ready
-        trigger check eq complete
-        label info ""
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/cweb'
-      edit LOGTASK 'o'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete and ./12 eq complete and logfilestore eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/cweb'
-      edit LOGTASK 'o'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-  family mc
-    repeat date YMD 20091001 20121212 1
-    edit STREAM 'enfo'
-    family 00
-      trigger ( /cweb/mc:YMD lt /mc/main:YMD) or ( /cweb/mc:YMD eq /mc/main:YMD and /mc/main/00/legB/postproc eq complete)
-      edit QUEUE 'ns'
-      edit QUEUE_EPILOG 'ns'
-      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
-      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
-      edit DELTA_DAY '1'
-      edit EMOS_BASE '00'
-      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
-      inlimit /limits:c1a
-      task purge
-        inlimit /cweb/limits:purge
-        label info ""
-      family feed
-        trigger purge eq complete
-        inlimit /cweb/limits:retrieve
-        family leg_A
-          edit LEG 'A'
-          task cf_sfc
-            label info ""
-            label grid ""
-          task cf_pl
-            label info ""
-            label grid ""
-          task cf_wave_sfc
-            label info ""
-            label grid ""
-          task pf_sfc
-            label info ""
-            label grid ""
-          task pf_pl
-            label info ""
-            label grid ""
-          task pf_wave_sfc
-            label info ""
-            label grid ""
-          task efi_sfc
-            label info ""
-            label grid ""
-        endfamily
-        family leg_B
-          edit LEG 'B'
-          task cf_sfc
-            label info ""
-            label grid ""
-          task cf_pl
-            label info ""
-            label grid ""
-          task cf_wave_sfc
-            label info ""
-            label grid ""
-          task pf_sfc
-            label info ""
-            label grid ""
-          task pf_pl
-            label info ""
-            label grid ""
-          task pf_wave_sfc
-            label info ""
-            label grid ""
-        endfamily
-        family leg_C
-          edit LEG 'C'
-          task cf_sfc
-            label info ""
-            label grid ""
-          task cf_pl
-            label info ""
-            label grid ""
-          task cf_wave_sfc
-            label info ""
-            label grid ""
-          task pf_sfc
-            label info ""
-            label grid ""
-          task pf_pl
-            label info ""
-            label grid ""
-          task pf_wave_sfc
-            label info ""
-            label grid ""
-        endfamily
-      endfamily
-      task check
-        trigger feed eq complete
-        label info ""
-      task ready
-        trigger check eq complete
-        label info ""
-    endfamily
-    family 12
-      trigger ( /cweb/mc:YMD lt /mc/main:YMD) or ( /cweb/mc:YMD eq /mc/main:YMD and /mc/main/12/legB/postproc eq complete)
-      edit QUEUE 'ns'
-      edit QUEUE_EPILOG 'ns'
-      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
-      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
-      edit DELTA_DAY '0'
-      edit EMOS_BASE '12'
-      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
-      inlimit /limits:c1a
-      task purge
-        inlimit /cweb/limits:purge
-        label info ""
-      family feed
-        trigger purge eq complete
-        inlimit /cweb/limits:retrieve
-        family leg_A
-          edit LEG 'A'
-          task cf_sfc
-            label info ""
-            label grid ""
-          task cf_pl
-            label info ""
-            label grid ""
-          task cf_wave_sfc
-            label info ""
-            label grid ""
-          task pf_sfc
-            label info ""
-            label grid ""
-          task pf_pl
-            label info ""
-            label grid ""
-          task pf_wave_sfc
-            label info ""
-            label grid ""
-          task efi_sfc
-            label info ""
-            label grid ""
-        endfamily
-        family leg_B
-          edit LEG 'B'
-          task cf_sfc
-            label info ""
-            label grid ""
-          task cf_pl
-            label info ""
-            label grid ""
-          task cf_wave_sfc
-            label info ""
-            label grid ""
-          task pf_sfc
-            label info ""
-            label grid ""
-          task pf_pl
-            label info ""
-            label grid ""
-          task pf_wave_sfc
-            label info ""
-            label grid ""
-        endfamily
-        family leg_C
-          edit LEG 'C'
-          task cf_sfc
-            label info ""
-            label grid ""
-          task cf_pl
-            label info ""
-            label grid ""
-          task cf_wave_sfc
-            label info ""
-            label grid ""
-          task pf_sfc
-            label info ""
-            label grid ""
-          task pf_pl
-            label info ""
-            label grid ""
-          task pf_wave_sfc
-            label info ""
-            label grid ""
-        endfamily
-      endfamily
-      task check
-        trigger feed eq complete
-        label info ""
-      task ready
-        trigger check eq complete
-        label info ""
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/cweb'
-      edit LOGTASK 'mc'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete and ./12 eq complete and logfilestore eq complete
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/cweb'
-      edit LOGTASK 'mc'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-endsuite
-suite emc_33r1
-  edit USER 'emos'
-  edit SCHOST 'c1a'
-  edit SCHOST_BKUP 'hpcf'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/emos_esuite/emos_data/0039/log'
-  edit USE_YMD 'true'
-  edit YMD '20080203'
-  edit DATEMASK '*.*.*'
-  edit VERSION '0039'
-  edit INIEXPVER '0039'
-  edit TCINIEXPVER '0039'
-  edit FIRST_DAY '1'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '12'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'mc'
-  edit IMPL_DATE '2012123112'
-  edit EVERSION '0001'
-  edit USER_PRIORITY '70'
-  edit ININPES '16'
-  edit FCNPES '16'
-  edit PGNPES '32'
-  edit ANNPES '4'
-  edit REINITIALIZE 'false'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/emc_33r1'
-  edit SMSINCLUDE '/home/ma/emos/def/emc_33r1/include'
-  edit ACCOUNT 'oeenfo'
-  edit STREAM 'EF'
-  edit EMOS_STREAM 'EF'
-  edit ENSEMBLES '50'
-  edit ENS_SIZE '50'
-  edit MARS_DB 'marsod'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit INILEVELS '91'
-  edit INIPERIOD_4D '6'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit RUNHINDCAST '0'
-  edit ERA40END '2002073100'
-  edit NH_YEARS '18'
-  edit NH_WEEKS '2'
-  edit DELTA_DAY_M '-15'
-  edit DELTA_DAY_P '25'
-  edit FCGTYPE 'l_2'
-  edit EPSFCGTYPE 'l_2'
-  edit LUSE_RSTRHBIAS 'true'
-  edit FCGROUP 'fc0'
-  edit SMSLOGHOST 'c1a'
-  edit SMSLOGPORT '9316'
-  edit OCNPES_OC '4'
-  edit OCNPES_IFS '28'
-  edit OD_PROJ 'od'
-  edit SMSURLBASE 'http://datasvc.ecmwf.int/twiki/bin/view/Main'
-  edit SMSURL 'CurrentAndOldESuites'
-  edit SUITE_START '20080204'
-  edit PRODUCE_EPS_ML '0'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit.35r3 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/s1a/emos_esuite/emos_data/0039/log'
-  edit SMSOUT '/s1a/emos_esuite/emos_data/0039/log'
-  edit STHOST '/s1a'
-  edit COURTESY '0'
-  edit SLEEPTIME '1'
-  inlimit /limits:hpce
-  clock hybrid 
-  family efi_curop
-    edit SMSFILES '/home/ma/emos/def/o/mc/efi_hdc'
-    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-    edit SMSURL 'GENFO/00'
-    limit ext 30
-    inlimit ext
-    family hind
-      repeat date YMD 20080403 20121212 1
-      edit EMOS_BASE '00'
-      family op
-        family stage
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit ACC '24'
-          edit EFI_STEP1 '00'
-          edit EFI_STEP2 '24'
-          edit RETRIEVE 'stage'
-          inlimit /limits:linux_cluster
-          family all
-            edit RF_NAME 'all'
-            task prep
-          endfamily
-        endfamily
-        family d0105_24
-          edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
-          edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
-          edit ACC '24'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-        endfamily
-        family d0610_24
-          edit EFI_STEP1 '108 120 132 144 168 192 216'
-          edit EFI_STEP2 '132 144 156 168 192 216 240'
-          edit ACC '24'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-        endfamily
-      endfamily
-      family nop
-        family stage
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit ACC '24'
-          edit EFI_STEP1 '00'
-          edit EFI_STEP2 '24'
-          edit RETRIEVE 'stage'
-          inlimit /limits:linux_cluster
-          family all
-            edit RF_NAME 'all'
-            task prep
-          endfamily
-        endfamily
-        family d0105_24
-          edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
-          edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
-          edit ACC '24'
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-        family d0610_24
-          edit EFI_STEP1 '108 120 132 144 168 192 216'
-          edit EFI_STEP2 '132 144 156 168 192 216 240'
-          edit ACC '24'
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-        family d1115_24
-          edit EFI_STEP1 '240 264 288 312 336'
-          edit EFI_STEP2 '264 288 312 336 360'
-          edit ACC '24'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-        family d0102_06
-          edit EFI_STEP1 '006 012 018 024 030 036 042 048'
-          edit EFI_STEP2 '006 012 018 024 030 036 042 048'
-          edit ACC '0'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-        family d0304_06
-          edit EFI_STEP1 '054 060 066 072 078 084 090 096'
-          edit EFI_STEP2 '054 060 066 072 078 084 090 096'
-          edit ACC '0'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-        family d0506_06
-          edit EFI_STEP1 '102 108 114 120 126 132 138 144'
-          edit EFI_STEP2 '102 108 114 120 126 132 138 144'
-          edit ACC '0'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-        family d0708_06
-          edit EFI_STEP1 '150 156 162 168 174 180 186 192'
-          edit EFI_STEP2 '150 156 162 168 174 180 186 192'
-          edit ACC '0'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-        family d0910_06
-          edit EFI_STEP1 '198 204 210 216 222 228 234 240'
-          edit EFI_STEP2 '198 204 210 216 222 228 234 240'
-          edit ACC '0'
-          family 2t
-            edit RF_NAME '2t'
-            task prep
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-    family clim
-      trigger ./clim:YMD lt ./hind:YMD
-      repeat date YMD 20080403 20121212 1
-      edit EMOS_BASE '00'
-      family op
-        family steps24
-          family 000_024
-            edit ACC '24'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '24'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '24'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '24'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '24'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '24'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '24'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '24'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '24'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '24'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '24'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 000_120
-          edit ACC '120'
-          edit EFI_STEP1 '000'
-          edit EFI_STEP2 '120'
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-        endfamily
-        family 024_144
-          edit ACC '120'
-          edit EFI_STEP1 '024'
-          edit EFI_STEP2 '144'
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-        endfamily
-        family 000_240
-          edit ACC '240'
-          edit EFI_STEP1 '000'
-          edit EFI_STEP2 '240'
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-        endfamily
-      endfamily
-      family nop
-        family steps24
-          family 000_024
-            edit ACC '24'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '24'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '24'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '24'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '24'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '24'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '24'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '24'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '24'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '24'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '24'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '24'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '24'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '24'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '24'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_264
-            edit ACC '24'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '264'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 264_288
-            edit ACC '24'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '288'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 288_312
-            edit ACC '24'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '312'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 312_336
-            edit ACC '24'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 336_360
-            edit ACC '24'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '360'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family steps06
-          family 006_006
-            edit ACC '0'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '006'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_012
-            edit ACC '0'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '012'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 018_018
-            edit ACC '0'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '018'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_024
-            edit ACC '0'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 030_030
-            edit ACC '0'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '030'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_036
-            edit ACC '0'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 042_042
-            edit ACC '0'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '042'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_048
-            edit ACC '0'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 054_054
-            edit ACC '0'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '054'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_060
-            edit ACC '0'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 066_066
-            edit ACC '0'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '066'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_072
-            edit ACC '0'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 078_078
-            edit ACC '0'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '078'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_084
-            edit ACC '0'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 090_090
-            edit ACC '0'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '090'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_096
-            edit ACC '0'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 102_102
-            edit ACC '0'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '102'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_108
-            edit ACC '0'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 114_114
-            edit ACC '0'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '114'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_120
-            edit ACC '0'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 126_126
-            edit ACC '0'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '126'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 132_132
-            edit ACC '0'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 138_138
-            edit ACC '0'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '138'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_144
-            edit ACC '0'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 150_150
-            edit ACC '0'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '150'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 156_156
-            edit ACC '0'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '156'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 162_162
-            edit ACC '0'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '162'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_168
-            edit ACC '0'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 174_174
-            edit ACC '0'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '174'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 180_180
-            edit ACC '0'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '180'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 186_186
-            edit ACC '0'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '186'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_192
-            edit ACC '0'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '192'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 198_198
-            edit ACC '0'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '198'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 204_204
-            edit ACC '0'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '204'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 210_210
-            edit ACC '0'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '210'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_216
-            edit ACC '0'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '216'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 222_222
-            edit ACC '0'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '222'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 228_228
-            edit ACC '0'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '228'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 234_234
-            edit ACC '0'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '234'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_240
-            edit ACC '0'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 120_168
-          trigger ./steps24 eq complete
-          edit ACC '48'
-          edit EFI_STEP1 '120'
-          edit EFI_STEP2 '168'
-          family 2t
-            edit RF_NAME '2t'
-            task prep_sort
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep_sort
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep_sort
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep_sort
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep_sort
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep_sort
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep_sort
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep_sort
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep_sort
-          endfamily
-        endfamily
-        family 168_240
-          trigger ./steps24 eq complete
-          edit ACC '72'
-          edit EFI_STEP1 '168'
-          edit EFI_STEP2 '240'
-          family 2t
-            edit RF_NAME '2t'
-            task prep_sort
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep_sort
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep_sort
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep_sort
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep_sort
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep_sort
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep_sort
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep_sort
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep_sort
-          endfamily
-        endfamily
-        family 000_168
-          trigger ./steps24 eq complete
-          edit ACC '168'
-          edit EFI_STEP1 '000'
-          edit EFI_STEP2 '168'
-          family 2t
-            edit RF_NAME '2t'
-            task prep_sort
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep_sort
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep_sort
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep_sort
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep_sort
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep_sort
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep_sort
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep_sort
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep_sort
-          endfamily
-        endfamily
-        family 240_336
-          trigger ./steps24 eq complete
-          edit ACC '96'
-          edit EFI_STEP1 '240'
-          edit EFI_STEP2 '336'
-          family 2t
-            edit RF_NAME '2t'
-            task prep_sort
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep_sort
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep_sort
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep_sort
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep_sort
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep_sort
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep_sort
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep_sort
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep_sort
-          endfamily
-        endfamily
-        family 168_336
-          trigger ./steps24 eq complete
-          edit ACC '168'
-          edit EFI_STEP1 '168'
-          edit EFI_STEP2 '336'
-          family 2t
-            edit RF_NAME '2t'
-            task prep_sort
-          endfamily
-          family 10ff
-            edit RF_NAME '10ff'
-            task prep_sort
-          endfamily
-          family 10fg
-            edit RF_NAME '10fg'
-            task prep_sort
-          endfamily
-          family tp
-            edit RF_NAME 'tp'
-            task prep_sort
-          endfamily
-          family 2tmin
-            edit RF_NAME '2tmin'
-            task prep_sort
-          endfamily
-          family 2tmax
-            edit RF_NAME '2tmax'
-            task prep_sort
-          endfamily
-          family 10dd
-            edit RF_NAME '10dd'
-            task prep_sort
-          endfamily
-          family ts
-            edit RF_NAME 'ts'
-            task prep_sort
-          endfamily
-          family tcc
-            edit RF_NAME 'tcc'
-            task prep_sort
-          endfamily
-          family hsttmax
-            edit RF_NAME 'hsttmax'
-            task prep_sort
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-    family mn
-      trigger ./mn:YMD lt ./clim:YMD
-      repeat date YMD 20080221 20121212 1
-      family 12
-        edit EMOS_BASE '12'
-        family op
-          task stage
-            edit NC_DAYS '31'
-          family 000_120
-            trigger ./stage eq complete
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 024_144
-            trigger ./stage eq complete
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 000_240
-            trigger ./stage eq complete
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 012_036
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 036_060
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 060_084
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 084_108
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 108_132
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-        endfamily
-        family nop
-          task stage
-            edit NC_DAYS '31'
-          family 228_324
-            trigger ./stage eq complete
-            edit ACC '96'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '324'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 168_336
-            trigger ./stage eq complete
-            edit ACC '168'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 000_024
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 024_048
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 048_072
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 072_096
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 096_120
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 120_144
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 108_156
-            trigger ./stage eq complete
-            edit ACC '48'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '156'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 156_228
-            trigger ./stage eq complete
-            edit ACC '72'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '228'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 000_168
-            trigger ./stage eq complete
-            edit ACC '168'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 012_036
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 036_060
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 060_084
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 084_108
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 108_132
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-        endfamily
-        family arch_op
-          trigger op eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family pf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'pf'
-            edit EFI_TYPE 'efi'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-          family cf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'cf'
-            edit EFI_TYPE 'efic'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-        endfamily
-        family arch_nop
-          trigger nop eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family pf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'pf'
-            edit EFI_TYPE 'efi'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-          family cf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'cf'
-            edit EFI_TYPE 'efic'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family 00
-        edit EMOS_BASE '00'
-        edit DELTA_DAY '1'
-        family op
-          task stage
-            edit NC_DAYS '31'
-          family 000_120
-            trigger ./stage eq complete
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 024_144
-            trigger ./stage eq complete
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 000_240
-            trigger ./stage eq complete
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 000_024
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 024_048
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 048_072
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 072_096
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-          family 096_120
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-          endfamily
-        endfamily
-        family nop
-          task stage
-            edit NC_DAYS '31'
-          family 240_336
-            trigger ./stage eq complete
-            edit ACC '96'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 168_336
-            trigger ./stage eq complete
-            edit ACC '168'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 012_036
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 036_060
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 060_084
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 084_108
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 108_132
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 120_144
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 120_168
-            trigger ./stage eq complete
-            edit ACC '48'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 168_240
-            trigger ./stage eq complete
-            edit ACC '72'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 000_168
-            trigger ./stage eq complete
-            edit ACC '168'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task extindex
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task extindex
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task extindex
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task extindex
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 000_024
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 024_048
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 048_072
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 072_096
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-          family 096_120
-            trigger ./stage eq complete
-            edit ACC '24'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task extindex
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task extindex
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task extindex
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task extindex
-            endfamily
-          endfamily
-        endfamily
-        family arch_op
-          trigger op eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family pf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'pf'
-            edit EFI_TYPE 'efi'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-          family cf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'cf'
-            edit EFI_TYPE 'efic'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-        endfamily
-        family arch_nop
-          trigger nop eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family pf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'pf'
-            edit EFI_TYPE 'efi'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-          family cf
-            trigger ./efi2fdb eq complete
-            edit EMOS_TYPE 'cf'
-            edit EFI_TYPE 'efic'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-  endfamily
-  family efi_next
-    edit VERSION '0039'
-    edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi'
-    edit EVERSION '0001'
-    edit IMPL_DATE '2012121212'
-    edit EMOS_BASE '00'
-    edit MARS_DB 'marsod'
-    edit EMOS_TYPE 'undef'
-    edit EPS_VERSION '0001'
-    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-    edit SMSURL 'GENFO/00'
-    edit MARS_NEW '0'
-    edit UPDATE_WEB_NOW 'yes'
-    edit SCHOST 'c1a'
-    edit STHOST '/s1a'
-    edit SCHOST_BKUP 'c1b'
-    edit SCLOGDIR '/s1a/emos_esuite/emos_data/0039/log'
-    edit LOGDIR '/s1a/emos_esuite/emos_data/0039/log'
-    edit SMSOUT '/s1a/emos_esuite/emos_data/0039/log'
-    edit SMSLOGHOST 'c1a'
-    limit ext 35
-    inlimit ext
-    family mn
-      trigger ./mn:YMD lt ./clim:YMD
-      repeat date YMD 20080221 20121212 1
-      edit EFINENS '50'
-      family deps
-        edit SMSFILES '/home/ma/emos/def/emc_33r1/ref'
-        family 00
-          time 09:30
-          task dummy
-            edit SMSPASS 'stripped'
-        endfamily
-        family 12
-          time 21:30
-          task dummy
-        endfamily
-      endfamily
-      family 12
-        trigger ./deps/12 eq complete
-        edit EMOS_BASE '12'
-        family op
-          edit EPSLEG '1'
-          task stage
-          family 024
-            family 012_036
-              edit ACC '024'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_060
-              edit ACC '024'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_084
-              edit ACC '024'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_108
-              edit ACC '024'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_132
-              edit ACC '024'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '024'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '024'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '024'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            trigger ./024 eq complete
-            family 000_120
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_144
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            trigger ./024 eq complete
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family nop
-          edit EPSLEG '2'
-          task stage
-          family 024
-            family 012_036
-              edit ACC '024'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_060
-              edit ACC '024'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_084
-              edit ACC '024'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_108
-              edit ACC '024'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_132
-              edit ACC '024'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 132_156
-              edit ACC '024'
-              edit EFI_STEP1 '132'
-              edit EFI_STEP2 '156'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 156_180
-              edit ACC '024'
-              edit EFI_STEP1 '156'
-              edit EFI_STEP2 '180'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 180_204
-              edit ACC '024'
-              edit EFI_STEP1 '180'
-              edit EFI_STEP2 '204'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 204_228
-              edit ACC '024'
-              edit EFI_STEP1 '204'
-              edit EFI_STEP2 '228'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '24'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '24'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '24'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 240_264
-              edit ACC '24'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '264'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 264_288
-              edit ACC '24'
-              edit EFI_STEP1 '264'
-              edit EFI_STEP2 '288'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 288_312
-              edit ACC '24'
-              edit EFI_STEP1 '288'
-              edit EFI_STEP2 '312'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 312_336
-              edit ACC '24'
-              edit EFI_STEP1 '312'
-              edit EFI_STEP2 '336'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 336_360
-              edit ACC '24'
-              edit EFI_STEP1 '336'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 072
-            family 012_084
-              edit ACC '072'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '084'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_108
-              edit ACC '072'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '108'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_132
-              edit ACC '072'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '132'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_156
-              edit ACC '072'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '156'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_180
-              edit ACC '072'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '180'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 132_204
-              edit ACC '072'
-              edit EFI_STEP1 '132'
-              edit EFI_STEP2 '204'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 156_228
-              edit ACC '072'
-              edit EFI_STEP1 '156'
-              edit EFI_STEP2 '228'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            family 012_132
-              edit ACC '120'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '132'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_156
-              edit ACC '120'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '156'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_180
-              edit ACC '120'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '180'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_204
-              edit ACC '120'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '204'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_228
-              edit ACC '120'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '228'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 240_360
-              edit ACC '120'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 360
-            family 000_360
-              edit ACC '360'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_op
-          trigger op eq complete
-          edit EPSLEG '1'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_nop
-          trigger nop eq complete
-          edit EPSLEG '2'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmin
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family ts
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family hsttmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family data
-          trigger ./op eq complete and ./nop eq complete and ./arch_nop eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efidata
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efidata
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efidata
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efidata
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efidata
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efidata
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efidata
-          endfamily
-          family hsstmax
-            edit PARAM 'hsttmax'
-            task efidata
-          endfamily
-        endfamily
-        family plot
-          trigger ./op eq complete and ./nop eq complete and data eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
-          edit METVIEW 'metview_new'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efiplot
-              edit SMSPASS 'stripped'
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efiplot
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efiplot
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efiplot
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efiplot
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efiplot
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efiplot
-          endfamily
-          family hsttmax
-            edit PARAM 'hsttmax'
-            task efiplot
-          endfamily
-        endfamily
-      endfamily
-      family 00
-        trigger ./deps/00 eq complete and ./12 eq complete
-        edit EMOS_BASE '00'
-        edit DELTA_DAY '1'
-        family op
-          edit EPSLEG '1'
-          task stage
-          family 024
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '024'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '024'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '024'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            trigger ./024 eq complete
-            family 000_120
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_144
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            trigger ./024 eq complete
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family nop
-          edit EPSLEG '2'
-          task stage
-          family 024
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family reproc
-              family 120_144
-                edit ACC '024'
-                edit EFI_STEP1 '120'
-                edit EFI_STEP2 '144'
-                family tp
-                  edit RF_NAME 'tp'
-                  task extindex
-                endfamily
-              endfamily
-              family 144_168
-                edit ACC '024'
-                edit EFI_STEP1 '144'
-                edit EFI_STEP2 '168'
-                family tp
-                  edit RF_NAME 'tp'
-                  task extindex
-                endfamily
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '24'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '24'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '24'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 240_264
-              edit ACC '24'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '264'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 264_288
-              edit ACC '24'
-              edit EFI_STEP1 '264'
-              edit EFI_STEP2 '288'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 288_312
-              edit ACC '24'
-              edit EFI_STEP1 '288'
-              edit EFI_STEP2 '312'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 312_336
-              edit ACC '24'
-              edit EFI_STEP1 '312'
-              edit EFI_STEP2 '336'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 336_360
-              edit ACC '24'
-              edit EFI_STEP1 '336'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 072
-            family 000_072
-              edit ACC '072'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '072'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_096
-              edit ACC '072'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '096'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_120
-              edit ACC '072'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_144
-              edit ACC '072'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_168
-              edit ACC '072'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 120_192
-              edit ACC '072'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 144_216
-              edit ACC '072'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            family 000_120
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_144
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_168
-              edit ACC '120'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_192
-              edit ACC '120'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_216
-              edit ACC '120'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 240_360
-              edit ACC '120'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 360
-            family 000_360
-              edit ACC '360'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_op
-          trigger op eq complete
-          edit EPSLEG '1'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_nop
-          trigger nop eq complete
-          edit EPSLEG '2'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmin
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family ts
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family hsttmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family data
-          trigger ./op eq complete and ./nop eq complete and ./arch_nop eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efidata
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efidata
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efidata
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efidata
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efidata
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efidata
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efidata
-          endfamily
-          family hsstmax
-            edit PARAM 'hsttmax'
-            task efidata
-          endfamily
-        endfamily
-        family plot
-          trigger ./op eq complete and ./nop eq complete and data eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
-          edit METVIEW 'metview_new'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efiplot
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efiplot
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efiplot
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efiplot
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efiplot
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efiplot
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efiplot
-          endfamily
-          family hsttmax
-            edit PARAM 'hsttmax'
-            task efiplot
-          endfamily
-        endfamily
-      endfamily
-      task efi_cleaner
-        trigger ./12 eq complete and ./00 eq complete
-    endfamily
-    family hind
-      repeat date YMD 20080717 20121212 7
-      edit DELTA_DAY '0'
-      time 09:30
-      family stage
-        edit RF_NAME 'all'
-        edit RETRIEVE 'stage'
-        task prep
-      endfamily
-      family op
-        trigger ./stage eq complete
-        edit EPSLEG '1'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-                edit SMSPASS 'stripped'
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-                edit SMSPASS 'stripped'
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-                edit SMSPASS 'stripped'
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          trigger ./024 eq complete
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          trigger ./024 eq complete
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family nop
-        trigger ./stage eq complete
-        edit EPSLEG '2'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 240_264
-            edit ACC '024'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '264'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 264_288
-            edit ACC '024'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '288'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 288_312
-            edit ACC '024'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '312'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 312_336
-            edit ACC '024'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 336_360
-            edit ACC '024'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '360'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 000
-          family 006_006
-            edit ACC '000'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '006'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 012_012
-            edit ACC '000'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '012'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 018_018
-            edit ACC '000'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '018'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 024_024
-            edit ACC '000'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '024'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 030_030
-            edit ACC '000'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '030'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 036_036
-            edit ACC '000'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '036'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 042_042
-            edit ACC '000'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '042'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 048_048
-            edit ACC '000'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '048'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 054_054
-            edit ACC '000'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '054'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 060_060
-            edit ACC '000'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '060'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 066_066
-            edit ACC '000'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '066'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 072_072
-            edit ACC '000'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '072'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 078_078
-            edit ACC '000'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '078'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 084_084
-            edit ACC '000'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '084'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 090_090
-            edit ACC '000'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '090'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 096_096
-            edit ACC '000'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '096'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 102_102
-            edit ACC '000'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '102'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 108_108
-            edit ACC '000'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '108'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 114_114
-            edit ACC '000'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '114'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_120
-            edit ACC '000'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '120'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 126_126
-            edit ACC '000'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '126'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 132_132
-            edit ACC '000'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '132'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 138_138
-            edit ACC '000'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '138'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 144_144
-            edit ACC '000'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '144'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 150_150
-            edit ACC '000'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '150'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 156_156
-            edit ACC '000'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '156'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 162_162
-            edit ACC '000'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '162'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 168_168
-            edit ACC '000'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '168'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 174_174
-            edit ACC '000'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '174'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 180_180
-            edit ACC '000'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '180'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 186_186
-            edit ACC '000'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '186'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 192_192
-            edit ACC '000'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '192'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 198_198
-            edit ACC '000'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '198'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 204_204
-            edit ACC '000'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '204'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 210_210
-            edit ACC '000'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '210'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 216_216
-            edit ACC '000'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '216'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 222_222
-            edit ACC '000'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '222'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 228_228
-            edit ACC '000'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '228'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 234_234
-            edit ACC '000'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '234'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 240_240
-            edit ACC '000'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '240'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 252_252
-            edit ACC '000'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '252'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 264_264
-            edit ACC '000'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '264'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 276_276
-            edit ACC '000'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '276'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 288_288
-            edit ACC '000'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '288'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 300_300
-            edit ACC '000'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '300'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 312_312
-            edit ACC '000'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '312'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 324_324
-            edit ACC '000'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '324'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 336_336
-            edit ACC '000'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '336'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 348_348
-            edit ACC '000'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '348'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 360_360
-            edit ACC '000'
-            edit EFI_STEP1 '360'
-            edit EFI_STEP2 '360'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 006
-          family 000_006
-            edit ACC '006'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '006'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 006_012
-            edit ACC '006'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 012_018
-            edit ACC '006'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '018'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 018_024
-            edit ACC '006'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 024_030
-            edit ACC '006'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '030'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 030_036
-            edit ACC '006'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 036_042
-            edit ACC '006'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '042'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 042_048
-            edit ACC '006'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 048_054
-            edit ACC '006'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '054'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 054_060
-            edit ACC '006'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 060_066
-            edit ACC '006'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '066'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 066_072
-            edit ACC '006'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 072_078
-            edit ACC '006'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '078'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 078_084
-            edit ACC '006'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 084_090
-            edit ACC '006'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '090'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 090_096
-            edit ACC '006'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 096_102
-            edit ACC '006'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '102'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 102_108
-            edit ACC '006'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 108_114
-            edit ACC '006'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '114'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 114_120
-            edit ACC '006'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 120_126
-            edit ACC '006'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '126'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 126_132
-            edit ACC '006'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 132_138
-            edit ACC '006'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '138'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 138_144
-            edit ACC '006'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 144_150
-            edit ACC '006'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '150'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 150_156
-            edit ACC '006'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 156_162
-            edit ACC '006'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '162'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 162_168
-            edit ACC '006'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 168_174
-            edit ACC '006'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '174'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 174_180
-            edit ACC '006'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 180_186
-            edit ACC '006'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '186'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 186_192
-            edit ACC '006'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 192_198
-            edit ACC '006'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '198'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 198_204
-            edit ACC '006'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 204_210
-            edit ACC '006'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '210'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 210_216
-            edit ACC '006'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 216_222
-            edit ACC '006'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '222'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 222_228
-            edit ACC '006'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 228_234
-            edit ACC '006'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '234'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 234_240
-            edit ACC '006'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 012
-          family 000_012
-            edit ACC '012'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 012_024
-            edit ACC '012'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 024_036
-            edit ACC '012'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 036_048
-            edit ACC '012'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 048_060
-            edit ACC '012'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 060_072
-            edit ACC '012'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 072_084
-            edit ACC '012'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 084_096
-            edit ACC '012'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 096_108
-            edit ACC '012'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 108_120
-            edit ACC '012'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 120_132
-            edit ACC '012'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 132_144
-            edit ACC '012'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 144_156
-            edit ACC '012'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 156_168
-            edit ACC '012'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 168_180
-            edit ACC '012'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 180_192
-            edit ACC '012'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 192_204
-            edit ACC '012'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 204_216
-            edit ACC '012'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 216_228
-            edit ACC '012'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 228_240
-            edit ACC '012'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 240_252
-            edit ACC '012'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '252'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 252_264
-            edit ACC '012'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '264'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 264_276
-            edit ACC '012'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '276'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 276_288
-            edit ACC '012'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '288'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 288_300
-            edit ACC '012'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '300'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 300_312
-            edit ACC '012'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '312'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 312_324
-            edit ACC '012'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '324'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 324_336
-            edit ACC '012'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '336'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 336_348
-            edit ACC '012'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '348'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 348_360
-            edit ACC '012'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 072
-          trigger ./024 eq complete
-          family 000_072
-            edit ACC '072'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 024_096
-            edit ACC '072'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 048_120
-            edit ACC '072'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 072_144
-            edit ACC '072'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 096_168
-            edit ACC '072'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_192
-            edit ACC '072'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 144_216
-            edit ACC '072'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 168_240
-            edit ACC '072'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          trigger ./024 eq complete
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 048_168
-            edit ACC '120'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 072_192
-            edit ACC '120'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 096_216
-            edit ACC '120'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_240
-            edit ACC '120'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 240_360
-            edit ACC '120'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          trigger ./024 eq complete
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_360
-            edit ACC '240'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 360
-          trigger ./024 eq complete
-          family 000_360
-            edit ACC '360'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family check_nrt
-        complete ./check_nrt/go eq complete
-        edit REFPATH '/mofc/hc2'
-        family catchup
-          task check_nrt
-            event ok
-        endfamily
-        family rt
-          trigger catchup eq complete
-          task check_nrt
-            event ok
-            cron -w 1 08:00
-        endfamily
-        task go
-          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
-          trigger 0 eq 1
-      endfamily
-    endfamily
-    family clim
-      trigger ./clim:YMD lt ./hind:YMD
-      repeat date YMD 20080717 20121212 7
-      edit EFI_REMOVE_GRIB 'echo'
-      edit DELTA_DAY '-7'
-      time 09:30
-      family op
-        edit EPSLEG '1'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family op2fdb
-        trigger op eq complete
-        edit EPSLEG '1'
-        task efi2fdb
-          edit KIND 'clim1'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-      endfamily
-      family nop
-        edit EPSLEG '2'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_264
-            edit ACC '024'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '264'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 264_288
-            edit ACC '024'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '288'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 288_312
-            edit ACC '024'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '312'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 312_336
-            edit ACC '024'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 336_360
-            edit ACC '024'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '360'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 000
-          family 006_006
-            edit ACC '000'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '006'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_012
-            edit ACC '000'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '012'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 018_018
-            edit ACC '000'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '018'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_024
-            edit ACC '000'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '024'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 030_030
-            edit ACC '000'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '030'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_036
-            edit ACC '000'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '036'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 042_042
-            edit ACC '000'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '042'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_048
-            edit ACC '000'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '048'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 054_054
-            edit ACC '000'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '054'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_060
-            edit ACC '000'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '060'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 066_066
-            edit ACC '000'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '066'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_072
-            edit ACC '000'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '072'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 078_078
-            edit ACC '000'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '078'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_084
-            edit ACC '000'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '084'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 090_090
-            edit ACC '000'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '090'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_096
-            edit ACC '000'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '096'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 102_102
-            edit ACC '000'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '102'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_108
-            edit ACC '000'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '108'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 114_114
-            edit ACC '000'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '114'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_120
-            edit ACC '000'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '120'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 126_126
-            edit ACC '000'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '126'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 132_132
-            edit ACC '000'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '132'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 138_138
-            edit ACC '000'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '138'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_144
-            edit ACC '000'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '144'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 150_150
-            edit ACC '000'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '150'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 156_156
-            edit ACC '000'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '156'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 162_162
-            edit ACC '000'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '162'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_168
-            edit ACC '000'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '168'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 174_174
-            edit ACC '000'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '174'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 180_180
-            edit ACC '000'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '180'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 186_186
-            edit ACC '000'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '186'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_192
-            edit ACC '000'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '192'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 198_198
-            edit ACC '000'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '198'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 204_204
-            edit ACC '000'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '204'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 210_210
-            edit ACC '000'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '210'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_216
-            edit ACC '000'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '216'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 222_222
-            edit ACC '000'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '222'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 228_228
-            edit ACC '000'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '228'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 234_234
-            edit ACC '000'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '234'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_240
-            edit ACC '000'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '240'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 252_252
-            edit ACC '000'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '252'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 264_264
-            edit ACC '000'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '264'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 276_276
-            edit ACC '000'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '276'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 288_288
-            edit ACC '000'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '288'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 300_300
-            edit ACC '000'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '300'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 312_312
-            edit ACC '000'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '312'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 324_324
-            edit ACC '000'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '324'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 336_336
-            edit ACC '000'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '336'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 348_348
-            edit ACC '000'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '348'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 360_360
-            edit ACC '000'
-            edit EFI_STEP1 '360'
-            edit EFI_STEP2 '360'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 006
-          family 000_006
-            edit ACC '006'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '006'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 006_012
-            edit ACC '006'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_018
-            edit ACC '006'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '018'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 018_024
-            edit ACC '006'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_030
-            edit ACC '006'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '030'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 030_036
-            edit ACC '006'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_042
-            edit ACC '006'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '042'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 042_048
-            edit ACC '006'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_054
-            edit ACC '006'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '054'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 054_060
-            edit ACC '006'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_066
-            edit ACC '006'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '066'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 066_072
-            edit ACC '006'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_078
-            edit ACC '006'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '078'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 078_084
-            edit ACC '006'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_090
-            edit ACC '006'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '090'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 090_096
-            edit ACC '006'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_102
-            edit ACC '006'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '102'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 102_108
-            edit ACC '006'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_114
-            edit ACC '006'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '114'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 114_120
-            edit ACC '006'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_126
-            edit ACC '006'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '126'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 126_132
-            edit ACC '006'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 132_138
-            edit ACC '006'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '138'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 138_144
-            edit ACC '006'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_150
-            edit ACC '006'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '150'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 150_156
-            edit ACC '006'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 156_162
-            edit ACC '006'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '162'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 162_168
-            edit ACC '006'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_174
-            edit ACC '006'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '174'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 174_180
-            edit ACC '006'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 180_186
-            edit ACC '006'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '186'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 186_192
-            edit ACC '006'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_198
-            edit ACC '006'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '198'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 198_204
-            edit ACC '006'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 204_210
-            edit ACC '006'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '210'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 210_216
-            edit ACC '006'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_222
-            edit ACC '006'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '222'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 222_228
-            edit ACC '006'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 228_234
-            edit ACC '006'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '234'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 234_240
-            edit ACC '006'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 012
-          family 000_012
-            edit ACC '012'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_024
-            edit ACC '012'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_036
-            edit ACC '012'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_048
-            edit ACC '012'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_060
-            edit ACC '012'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_072
-            edit ACC '012'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_084
-            edit ACC '012'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_096
-            edit ACC '012'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_108
-            edit ACC '012'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_120
-            edit ACC '012'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_132
-            edit ACC '012'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 132_144
-            edit ACC '012'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_156
-            edit ACC '012'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 156_168
-            edit ACC '012'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_180
-            edit ACC '012'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 180_192
-            edit ACC '012'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_204
-            edit ACC '012'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 204_216
-            edit ACC '012'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_228
-            edit ACC '012'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 228_240
-            edit ACC '012'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_252
-            edit ACC '012'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '252'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 252_264
-            edit ACC '012'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '264'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 264_276
-            edit ACC '012'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '276'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 276_288
-            edit ACC '012'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '288'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 288_300
-            edit ACC '012'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '300'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 300_312
-            edit ACC '012'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '312'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 312_324
-            edit ACC '012'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '324'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 324_336
-            edit ACC '012'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '336'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 336_348
-            edit ACC '012'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '348'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 348_360
-            edit ACC '012'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 072
-          family 000_072
-            edit ACC '072'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_096
-            edit ACC '072'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_120
-            edit ACC '072'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_144
-            edit ACC '072'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_168
-            edit ACC '072'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_192
-            edit ACC '072'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_216
-            edit ACC '072'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_240
-            edit ACC '072'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_168
-            edit ACC '120'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_192
-            edit ACC '120'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_216
-            edit ACC '120'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_240
-            edit ACC '120'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_360
-            edit ACC '120'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_360
-            edit ACC '240'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 360
-          family 000_360
-            edit ACC '360'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family nop2fdb
-        trigger nop eq complete and ./op2fdb eq complete
-        edit EPSLEG '2'
-        task efi2fdb
-          edit KIND 'clim2'
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
-      endfamily
-      family arch_nop
-        trigger nop2fdb eq complete
-        edit EPSLEG '2'
-        edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
-        family 2t
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '2t'
-          task eficlim
-            label info ""
-        endfamily
-        family 10ff
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '10ff'
-          task eficlim
-            label info ""
-        endfamily
-        family 10fg
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '10fg'
-          task eficlim
-            label info ""
-        endfamily
-        family tp
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'tp'
-          task eficlim
-            label info ""
-        endfamily
-        family 2tmin
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '2tmin'
-          task eficlim
-            label info ""
-        endfamily
-        family 2tmax
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '2tmax'
-          task eficlim
-            label info ""
-        endfamily
-        family ts
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'ts'
-          task eficlim
-            label info ""
-        endfamily
-        family hsttmax
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'hsttmax'
-          task eficlim
-            label info ""
-        endfamily
-        family 10dd
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '10dd'
-          task eficlim
-            label info ""
-        endfamily
-        family 850t
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '850t'
-          task eficlim
-            label info ""
-        endfamily
-        family 500z
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '500z'
-          task eficlim
-            label info ""
-        endfamily
-        family 2tmean
-          edit step2 '24'
-          edit RF_NAME '2t'
-          edit step1 '0'
-          task eficlim
-            label info ""
-        endfamily
-        family 10ffmean
-          edit step2 '24'
-          edit RF_NAME '10ff'
-          edit step1 '0'
-          task eficlim
-            label info ""
-        endfamily
-        family tcc
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'tcc'
-          task eficlim
-            label info ""
-        endfamily
-        family tccmean
-          edit step2 '24'
-          edit RF_NAME 'tcc'
-          edit step1 '0'
-          task eficlim
-            label info ""
-        endfamily
-      endfamily
-      task efi_cleaner
-        trigger arch_nop eq complete and op eq complete and nop eq complete and op2fdb eq complete and nop2fdb eq complete
-        edit DELTA_DAY '-43'
-      family gdb
-        trigger ( op eq complete and nop eq complete) and ( arch_nop eq complete)
-        edit RHOST 'epsgrams'
-        edit RDIR '/webapps/epsgrams/data/'
-        edit KIND 'clim_15_days'
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /limits:linux_cluster
-        task sync_climate
-        task gclean
-          trigger sync_climate eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/pop/data/epsgrams/grams'
-          edit KEEP_DAYS '14'
-          edit REMOTE_KEEP_DAYS '14'
-        task gdb
-          trigger gclean eq complete and ( /mc/main:YMD ge /emc_33r1/efi_next/mn:YMD and /mc/main/00 eq complete)
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/pop/data/epsgrams/grams'
-          label files "="
-          label info "="
-          label local "="
-          label remote "="
-          event fdb
-        task glink
-          trigger gdb eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_33r1/pop/data/epsgrams/grams'
-      endfamily
-      family check_nrt
-        complete ./check_nrt/go eq complete
-        edit REFPATH '/mofc/hc2'
-        family catchup
-          task check_nrt
-            event ok
-        endfamily
-        family rt
-          trigger catchup eq complete
-          task check_nrt
-            event ok
-            cron -w 3 06:30
-        endfamily
-        task go
-          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
-          trigger 0 eq 1
-      endfamily
-    endfamily
-  endfamily
-  family limits
-    limit mars 4
-    limit pftotal 20
-    limit pertic 13
-    limit modelepsA 13
-    limit modelepsB 15
-    limit pl 3
-    limit sfc 2
-    limit prodeps 5
-    limit prodwave 4
-    limit pdb 5
-    limit q2diss 5
-    limit efi 13
-    limit efih 13
-    limit refc 10
-    limit tc 5
-    limit webplots 10
-    limit dp 16
-    limit hind 14
-    limit pesh 20
-  endfamily
-endsuite
-suite metops_test
-  repeat date YMD 20090401 20191210 1
-  edit USER 'emos'
-  edit SCHOST 'c1a'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/c1a/emos_dir/0001/log'
-  edit USE_YMD 'true'
-  edit VERSION '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '00'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY ''
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit PGNPES '3'
-  edit SVNPES '8'
-  edit REINITIALIZE 'false'
-  edit DATEMASK '*.*.*'
-  edit REMOVE_ADIR 'false'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/metops_test/include'
-  edit SMSURLBASE 'http://www.ecmwf.int'
-  edit SMSURL 'publications/manuals/sms'
-  edit ACCOUNT 'oosu'
-  edit STREAM 'DA'
-  edit EMOS_STREAM 'DA'
-  edit FAMILY 'metops_test'
-  edit MARS_DB 'marsod'
-  edit OBSHOST 'dummy'
-  edit SUITE_START '2000022100'
-  edit QUEUE 'plots-medium'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-  edit LOGDIR '/vol/emos_nc/output'
-  edit SMSOUT '/vol/emos_nc/output'
-  edit SLEEPTIME '1'
-  inlimit /limits:linux_cluster
-  clock hybrid 
-  family 00
-    edit EMOS_BASE '00'
-    family web
-      family quartiles
-        edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia'
-        edit STEP_LIST '18/TO/126/by/12'
-        edit STEP_PLOT '12/TO/120/by/12'
-        edit ENSEMBLES '50'
-        time 10:00
-        task w_tp_quartiles
-        task w_wind_quartiles
-        task w_wgust_quartiles
-        task w_wind925_quartiles
-        task w_cape_quartiles
-      endfamily
-      family genesis
-        task w_tc_genesis
-          edit UPDATE_WEB_NOW 'yes'
-          time 10:00
-      endfamily
-      family swfdp_pacific
-        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swfdp_pacific'
-        edit PLOTDOM '-40/150/10/-120'
-        edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-        edit UPDATE_WEB_NOW 'yes'
-        edit SMSINCLUDE '/home/ma/emos/def/o/include'
-        edit PLOT_STEPS '12/to/144/by/12'
-        time 10:00
-        family proba
-          task swfdp_pacific_proba
-          task swfdp_pacific_tp
-            trigger swfdp_pacific_proba eq complete
-          task swfdp_pacific_ff
-            trigger swfdp_pacific_proba eq complete
-          task swfdp_pacific_tp24
-            trigger swfdp_pacific_proba eq complete
-            edit STEPS '24/48/72/96/120'
-          task swfdp_pacific_proba_clean
-            trigger swfdp_pacific_tp eq complete and swfdp_pacific_ff eq complete and swfdp_pacific_tp24 eq complete
-        endfamily
-        family efi
-          edit QUEUE 'plots-medium'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSINCLUDE '/home/ma/emos/def/o/include'
-          inlimit /limits:linux_cluster
-          family swfdp_pacific_tpi
-            task w_efi
-              edit PARAMETER 'tpi'
-          endfamily
-          family swfdp_pacific_10wsi
-            task w_efi
-              edit PARAMETER '10wsi'
-          endfamily
-          family swfdp_pacific_2ti
-            task w_efi
-              edit PARAMETER '2ti'
-          endfamily
-          family swfdp_pacific_10fgi
-            task w_efi
-              edit PARAMETER '10fgi'
-          endfamily
-        endfamily
-        task pb_swh
-        task pb_mwp
-        task swfdp_pacific_wavegrams
-          edit SMSINCLUDE '/home/ma/emos/def/metops_test/include'
-        family maps
-          edit PLOT_LOCATION '/webplots_e/data/swfdp_pacific/maps'
-          edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-          task swfdp_pacific_maps
-          task swfdp_pacific_toweb1
-            trigger swfdp_pacific_maps eq complete
-          task swfdp_pacific_toweb2
-            trigger swfdp_pacific_maps eq complete
-          task swfdp_pacific_toweb3
-            trigger swfdp_pacific_maps eq complete
-          task swfdp_pacific_clean
-            trigger swfdp_pacific_toweb1 eq complete and swfdp_pacific_toweb2 eq complete and swfdp_pacific_toweb3 eq complete
-        endfamily
-        family waves
-          edit PLOT_LEGS '1'
-          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-          task wave_data
-          family plots
-            task swfdp_pacific_swh
-              trigger ../wave_data eq complete
-            task swfdp_pacific_mwp
-              trigger ../wave_data eq complete
-            task swfdp_pacific_wwsh
-              trigger ../wave_data eq complete
-            task swfdp_pacific_wwmp
-              trigger ../wave_data eq complete
-            task swfdp_pacific_tssh
-              trigger ../wave_data eq complete
-            task swfdp_pacific_tsmp
-              trigger ../wave_data eq complete
-          endfamily
-          task swfdp_pacific_wave_clean
-            trigger ./plots eq complete
-        endfamily
-      endfamily
-      family swdfp
-        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swdfp'
-        edit PLOTDOM '-45/-10/6/62'
-        edit UPDATE_WEB_NOW 'yes'
-        edit SMSINCLUDE '/home/ma/emos/def/o/include'
-        edit PLOT_STEPS '12/to/144/by/12'
-        time 10:00
-        family waves
-          edit SMSINCLUDE '/home/ma/emos/def/o/include'
-          edit PLOT_LEGS '1'
-          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-          task wave_data
-          family plots
-            task swdfp_swh
-              trigger ../wave_data eq complete
-            task swdfp_mwp
-              trigger ../wave_data eq complete
-            task swdfp_wwsh
-              trigger ../wave_data eq complete
-            task swdfp_wwmp
-              trigger ../wave_data eq complete
-            task swdfp_tssh
-              trigger ../wave_data eq complete
-            task swdfp_tsmp
-              trigger ../wave_data eq complete
-          endfamily
-          task swdfp_wave_clean
-            trigger ./plots eq complete
-        endfamily
-        task pb_swdfp_swh
-        task pb_swdfp_mwp
-      endfamily
-      family wave_verif
-        edit UPDATE_WEB_NOW 'yes'
-        time 10:00
-        task w_wave_timeseries
-        task w_wave_annualscores
-        task w_wave_intercomparison
-      endfamily
-      family newcluster
-        task cluster_plot
-          edit UPDATE_WEB_NOW 'yes'
-          time 10:00
-      endfamily
-    endfamily
-  endfamily
-  family 12
-    edit EMOS_BASE '12'
-    family web
-      family quartiles
-        edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia'
-        edit STEP_LIST '18/TO/126/by/12'
-        edit STEP_PLOT '12/TO/120/by/12'
-        edit ENSEMBLES '50'
-        time 20:45
-        task w_tp_quartiles
-        task w_wind_quartiles
-        task w_wgust_quartiles
-        task w_wind925_quartiles
-        task w_cape_quartiles
-      endfamily
-      family genesis
-        task w_tc_genesis
-          edit UPDATE_WEB_NOW 'yes'
-          time 20:45
-      endfamily
-      family swfdp_pacific
-        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swfdp_pacific'
-        edit PLOTDOM '-40/150/10/-120'
-        edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-        edit UPDATE_WEB_NOW 'yes'
-        edit SMSINCLUDE '/home/ma/emos/def/o/include'
-        edit PLOT_STEPS '12/to/144/by/12'
-        time 20:45
-        family proba
-          task swfdp_pacific_proba
-          task swfdp_pacific_tp
-            trigger swfdp_pacific_proba eq complete
-          task swfdp_pacific_ff
-            trigger swfdp_pacific_proba eq complete
-          task swfdp_pacific_tp24
-            trigger swfdp_pacific_proba eq complete
-            edit STEPS '24/48/72/96/120'
-          task swfdp_pacific_proba_clean
-            trigger swfdp_pacific_tp eq complete and swfdp_pacific_ff eq complete and swfdp_pacific_tp24 eq complete
-        endfamily
-        family efi
-          edit QUEUE 'plots-medium'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSINCLUDE '/home/ma/emos/def/o/include'
-          inlimit /limits:linux_cluster
-          family swfdp_pacific_tpi
-            task w_efi
-              edit PARAMETER 'tpi'
-          endfamily
-          family swfdp_pacific_10wsi
-            task w_efi
-              edit PARAMETER '10wsi'
-          endfamily
-          family swfdp_pacific_2ti
-            task w_efi
-              edit PARAMETER '2ti'
-          endfamily
-          family swfdp_pacific_10fgi
-            task w_efi
-              edit PARAMETER '10fgi'
-          endfamily
-        endfamily
-        task pb_swh
-        task pb_mwp
-        task swfdp_pacific_wavegrams
-          edit SMSINCLUDE '/home/ma/emos/def/metops_test/include'
-        family maps
-          edit PLOT_LOCATION '/webplots_e/data/swfdp_pacific/maps'
-          edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-          task swfdp_pacific_maps
-          task swfdp_pacific_toweb1
-            trigger swfdp_pacific_maps eq complete
-          task swfdp_pacific_toweb2
-            trigger swfdp_pacific_maps eq complete
-          task swfdp_pacific_toweb3
-            trigger swfdp_pacific_maps eq complete
-          task swfdp_pacific_clean
-            trigger swfdp_pacific_toweb1 eq complete and swfdp_pacific_toweb2 eq complete and swfdp_pacific_toweb3 eq complete
-        endfamily
-        family waves
-          edit PLOT_LEGS '1'
-          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-          task wave_data
-          family plots
-            task swfdp_pacific_swh
-              trigger ../wave_data eq complete
-            task swfdp_pacific_mwp
-              trigger ../wave_data eq complete
-            task swfdp_pacific_wwsh
-              trigger ../wave_data eq complete
-            task swfdp_pacific_wwmp
-              trigger ../wave_data eq complete
-            task swfdp_pacific_tssh
-              trigger ../wave_data eq complete
-            task swfdp_pacific_tsmp
-              trigger ../wave_data eq complete
-          endfamily
-          task swfdp_pacific_wave_clean
-            trigger ./plots eq complete
-        endfamily
-      endfamily
-      family swdfp
-        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swdfp'
-        edit PLOTDOM '-45/-10/6/62'
-        edit UPDATE_WEB_NOW 'yes'
-        time 20:45
-        family waves
-          edit PLOT_LEGS '1'
-          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-          task wave_data
-          family plots
-            task swdfp_wwsh
-              trigger ../wave_data eq complete
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-  endfamily
-endsuite
-suite verify
-  edit METPY_VERSION '3.4.2.emos'
-  edit METPY 'metpy_001'
-  edit VERIFY 'metpy_001'
-  edit FIRST_DATE '20091008'
-  edit LAST_DATE '20111031'
-  edit DATE_INCREMENT '1'
-  edit RUNS_PER_DAY '1'
-  edit OPERATIONAL 'yes'
-  edit USER 'emos'
-  edit SCHOST 'c1a'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/c1a/emos_dir/0001/log'
-  edit USE_YMD 'true'
-  edit VERSION '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '1'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '12'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY ''
-  edit STHOST_BKUP 'toto'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit PGNPES '3'
-  edit SVNPES '8'
-  edit REINITIALIZE 'false'
-  edit DATEMASK '*.*.*'
-  edit YMD 'dummy'
-  edit REMOVE_ADIR 'false'
-  edit ANNPES '18'
-  edit ANMEM '3584'
-  edit ANSTACK '700'
-  edit ANMRFS '160'
-  edit FCNPES '24'
-  edit FCMEM '3584'
-  edit FCSTACK '690'
-  edit FCMRFS '32'
-  edit PERIOD_4D '12'
-  edit WINDOW_LENGTH_4D '12'
-  edit WINDOW_OFFSET_4D '12'
-  edit MKCMANPES '6'
-  edit MKCMAMEM '3284'
-  edit MKCMASTACK '600'
-  edit MKCMAMRFS '600'
-  edit SMSHOME '/home/ma/emos/def/verify'
-  edit SMSFILES '/home/ma/emos/def/verify'
-  edit SMSINCLUDE '/home/ma/emos/def/verify/include'
-  edit ACCOUNT 'oosu'
-  edit STREAM 'DA'
-  edit EMOS_STREAM 'DA'
-  edit MARS_DB 'marsod'
-  edit OBSHOST 'ha_pp'
-  edit SUITE_START '19971117'
-  edit SCRIPTFILES '/home/ma/emos/def/verify/scripts'
-  edit VERIFY_CACHE '/var/tmp/verify'
-  edit WSHOST 'swarm'
-  edit QUEUE 'verify'
-  edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-  edit LOGDIR '/vol/emos_nc/output'
-  edit SMSOUT '/vol/emos_nc/output'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family 00
-    repeat date YMD 20091009 20111031 1
-    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
-    edit EMOS_BASE '00'
-    family hr
-      trigger /o/lag/00/archive/fc240 eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'oper'
-      limit count 3
-      inlimit count
-      task hr_retrieve
-        edit SMSTRIES '2'
-      family z
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'z'
-        task hr_upperair
-      endfamily
-      family t
-        trigger hr_retrieve eq complete
-        edit PARAMETER 't'
-        task hr_upperair
-      endfamily
-      family u_v_ff
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'u,v,ff'
-        task hr_upperair
-          edit SMSPASS 'stripped'
-      endfamily
-      family r
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'r'
-        task hr_upperair
-      endfamily
-      family q
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'q'
-        task hr_upperair
-      endfamily
-      family o3
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'o3'
-        task hr_upperair
-      endfamily
-      task hr_sfc
-        trigger hr_retrieve eq complete
-      task hr_to_ct
-        trigger hr_retrieve eq complete
-      task hr_from_ct
-        trigger hr_to_ct eq complete
-      task hr_to_ct_wind_850
-        trigger hr_retrieve eq complete
-      task hr_from_ct_wind_850
-        trigger hr_to_ct_wind_850 eq complete
-      task hr_to_ct_wind_250
-        trigger hr_retrieve eq complete
-      task hr_from_ct_wind_250
-        trigger hr_to_ct_wind_250 eq complete
-    endfamily
-    family hrobs
-      trigger ./hr eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores1'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FDB_HOST 'scores1'
-      edit STREAM 'oper'
-      edit DELTA_DAY '-2'
-      limit count 2
-      inlimit count
-      task hrobs_retrieve1
-        edit SMSTRIES '2'
-      task hrobs_retrieve2
-        edit SMSTRIES '2'
-      family z
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'z'
-        task hrobs
-      endfamily
-      family t
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 't'
-        task hrobs
-      endfamily
-      family u_v_ff
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'u,v,ff'
-        task hrobs
-      endfamily
-      family r
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'r'
-        task hrobs
-      endfamily
-      family q
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'q'
-        task hrobs
-      endfamily
-    endfamily
-    family ctrl
-      trigger /mc/main/00/legB/postproc eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'enfo'
-      limit count 2
-      inlimit count
-      task ctrl_retrieve
-      family z
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'z'
-        task ctrl_upperair
-      endfamily
-      family t
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 't'
-        task ctrl_upperair
-      endfamily
-      family u_v_ff
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'u,v,ff'
-        task ctrl_upperair
-      endfamily
-      family r
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'r'
-        task ctrl_upperair
-      endfamily
-      family q
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'q'
-        task ctrl_upperair
-      endfamily
-      task ctrl_sfc
-        trigger ctrl_retrieve eq complete
-      task ctrl_to_ct
-        trigger ctrl_retrieve eq complete
-      task ctrl_from_ct
-        trigger ctrl_to_ct eq complete
-      task ctrl_to_ct_wind_850
-        trigger ctrl_retrieve eq complete
-      task ctrl_from_ct_wind_850
-        trigger ctrl_to_ct_wind_850 eq complete
-      task ctrl_to_ct_wind_250
-        trigger ctrl_retrieve eq complete
-      task ctrl_from_ct_wind_250
-        trigger ctrl_to_ct_wind_250 eq complete
-    endfamily
-    family ctrlobs
-      trigger ./ctrl eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores1'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FDB_HOST 'scores1'
-      edit STREAM 'enfo'
-      edit DELTA_DAY '-2'
-      limit count 2
-      inlimit count
-      task ctrlobs_retrieve1
-        edit SMSTRIES '2'
-      task ctrlobs_retrieve2
-        edit SMSTRIES '2'
-      family z
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'z'
-        task ctrlobs
-      endfamily
-      family t
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 't'
-        task ctrlobs
-      endfamily
-      family r
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'r'
-        task ctrlobs
-      endfamily
-      family q
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'q'
-        task ctrlobs
-      endfamily
-      family u_v_ff
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'u,v,ff'
-        task ctrlobs
-      endfamily
-    endfamily
-    family eps
-      trigger /mc/main/00/legB/postproc eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'enfo'
-      limit count 4
-      inlimit count
-      task eps_retrieve
-        edit SMSTRIES '2'
-      task eps_to_ct_z
-        trigger eps_retrieve eq complete
-      task eps_to_ct_msl
-        trigger eps_retrieve eq complete
-      task eps_to_ct_t
-        trigger eps_retrieve eq complete
-      task eps_from_ct
-        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
-      task eps_to_ct_wind_850
-        trigger eps_retrieve eq complete
-      task eps_from_ct_wind_850
-        trigger eps_to_ct_wind_850 eq complete
-      task eps_to_ct_wind_250
-        trigger eps_retrieve eq complete
-      task eps_from_ct_wind_250
-        trigger eps_to_ct_wind_250 eq complete
-      task eps_spread_score1
-        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
-      task eps_spread_score2
-        trigger eps_to_ct_wind_850 eq complete and eps_to_ct_wind_250 eq complete
-      task eps_cal_val
-      task eps_mean_spread_z
-        trigger eps_to_ct_z eq complete
-      task eps_mean_spread_t
-        trigger eps_to_ct_t eq complete
-      task eps_mean_spread_msl
-        trigger eps_to_ct_msl eq complete
-      task eps_mean_spread_wind_850
-        trigger eps_to_ct_wind_850 eq complete
-      task eps_mean_spread_wind_250
-        trigger eps_to_ct_wind_250 eq complete
-    endfamily
-    family clim
-      trigger /o/main/00/an eq complete
-      edit STREAM 'oper'
-      limit count 1
-      inlimit count
-      task clim_z
-      task clim_msl
-      task clim_t
-      task clim_wind_850
-      task clim_wind_250
-      task clim_waves_mwp
-      task clim_waves_swh
-    endfamily
-    family waves
-      trigger /mc/main/00/legB/postproc eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      limit count 4
-      inlimit count
-      task waves_retrieve
-        edit SMSTRIES '2'
-      task waves_retrieve_ff
-        edit SMSTRIES '2'
-      task waves_eps_retrieve
-        edit SMSTRIES '2'
-      task waves_ctrl_retrieve
-        edit SMSTRIES '2'
-      task waves
-        trigger waves_retrieve eq complete
-      task waves_ff
-        trigger waves_retrieve_ff eq complete
-      task waves_ff_sea
-        trigger waves_ff eq complete
-      task waves_to_ct
-        trigger waves eq complete
-      task waves_from_ct
-        trigger waves_to_ct eq complete
-      task waves_ctrl
-        trigger waves_ctrl_retrieve eq complete
-      task waves_ctrl_to_ct
-        trigger waves_ctrl eq complete
-      task waves_ctrl_from_ct
-        trigger waves_ctrl_to_ct eq complete
-      task waves_eps_to_ct
-        trigger waves_eps_retrieve eq complete
-      task waves_eps_from_ct
-        trigger waves_eps_to_ct eq complete
-      task waves_eps_mean_spread
-        trigger waves_eps_to_ct eq complete
-      task waves_eps_spread_score
-        trigger waves_eps_to_ct eq complete
-    endfamily
-    family other
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'oper'
-      limit count 3
-      inlimit count
-      time 08:00
-      task other_ukmo_fc
-      task other_ukmo_an
-      task other_ncep_fc
-      task other_ncep_an
-      task other_dwd_fc
-      task other_dwd_an
-      task other_metfr_fc
-      task other_metfr_an
-      task other_jma_fc
-      task other_jma_an
-      task other_cmc_fc
-      task other_cmc_an
-      task other_bom_fc
-      task other_bom_an
-    endfamily
-    task restart
-      time 17:00
-  endfamily
-  family 12
-    repeat date YMD 20091008 20111031 1
-    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
-    edit EMOS_BASE '12'
-    edit OVERWRITE 'yes'
-    family hr
-      trigger /o/lag/12/archive/fc240 eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'oper'
-      limit count 3
-      inlimit count
-      task hr_retrieve
-        edit SMSTRIES '2'
-      family z
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'z'
-        task hr_upperair
-      endfamily
-      family t
-        trigger hr_retrieve eq complete
-        edit PARAMETER 't'
-        task hr_upperair
-      endfamily
-      family u_v_ff
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'u,v,ff'
-        task hr_upperair
-      endfamily
-      family r
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'r'
-        task hr_upperair
-      endfamily
-      family q
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'q'
-        task hr_upperair
-      endfamily
-      family o3
-        trigger hr_retrieve eq complete
-        edit PARAMETER 'o3'
-        task hr_upperair
-      endfamily
-      task hr_sfc
-        trigger hr_retrieve eq complete
-      task hr_to_ct
-        trigger hr_retrieve eq complete
-      task hr_from_ct
-        trigger hr_to_ct eq complete
-      task hr_to_ct_wind_850
-        trigger hr_retrieve eq complete
-      task hr_from_ct_wind_850
-        trigger hr_to_ct_wind_850 eq complete
-      task hr_to_ct_wind_250
-        trigger hr_retrieve eq complete
-      task hr_from_ct_wind_250
-        trigger hr_to_ct_wind_250 eq complete
-    endfamily
-    family hrobs
-      trigger ./hr eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores1'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FDB_HOST 'scores1'
-      edit STREAM 'oper'
-      edit DELTA_DAY '-2'
-      edit OVERWRITE 'yes'
-      limit count 2
-      inlimit count
-      task hrobs_retrieve1
-        edit SMSTRIES '2'
-      task hrobs_retrieve2
-        edit SMSTRIES '2'
-      family z
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'z'
-        task hrobs
-      endfamily
-      family t
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 't'
-        task hrobs
-      endfamily
-      family u_v_ff
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'u,v,ff'
-        task hrobs
-      endfamily
-      family r
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'r'
-        task hrobs
-      endfamily
-      family q
-        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
-        edit PARAMETER 'q'
-        task hrobs
-      endfamily
-    endfamily
-    family ctrl
-      trigger /mc/main/12/legB/postproc eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'enfo'
-      limit count 2
-      inlimit count
-      task ctrl_retrieve
-        edit SMSTRIES '2'
-      family z
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'z'
-        task ctrl_upperair
-      endfamily
-      family t
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 't'
-        task ctrl_upperair
-      endfamily
-      family u_v_ff
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'u,v,ff'
-        task ctrl_upperair
-      endfamily
-      family r
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'r'
-        task ctrl_upperair
-      endfamily
-      family q
-        trigger ctrl_retrieve eq complete
-        edit PARAMETER 'q'
-        task ctrl_upperair
-      endfamily
-      task ctrl_sfc
-        trigger ctrl_retrieve eq complete
-      task ctrl_to_ct
-        trigger ctrl_retrieve eq complete
-      task ctrl_from_ct
-        trigger ctrl_to_ct eq complete
-      task ctrl_to_ct_wind_850
-        trigger ctrl_retrieve eq complete
-      task ctrl_from_ct_wind_850
-        trigger ctrl_to_ct_wind_850 eq complete
-      task ctrl_to_ct_wind_250
-        trigger ctrl_retrieve eq complete
-      task ctrl_from_ct_wind_250
-        trigger ctrl_to_ct_wind_250 eq complete
-    endfamily
-    family ctrlobs
-      trigger ./ctrl eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores1'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FDB_HOST 'scores1'
-      edit STREAM 'enfo'
-      edit DELTA_DAY '-2'
-      edit OVERWRITE 'yes'
-      limit count 2
-      inlimit count
-      task ctrlobs_retrieve1
-        edit SMSTRIES '2'
-      task ctrlobs_retrieve2
-        edit SMSTRIES '2'
-      family z
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'z'
-        task ctrlobs
-      endfamily
-      family t
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 't'
-        task ctrlobs
-      endfamily
-      family r
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'r'
-        task ctrlobs
-      endfamily
-      family q
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'q'
-        task ctrlobs
-      endfamily
-      family u_v_ff
-        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
-        edit PARAMETER 'u,v,ff'
-        task ctrlobs
-      endfamily
-    endfamily
-    family eps
-      trigger /mc/main/12/legB/postproc eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'enfo'
-      limit count 2
-      inlimit count
-      task eps_retrieve
-        edit SMSTRIES '2'
-      task eps_to_ct_z
-        trigger eps_retrieve eq complete
-      task eps_to_ct_msl
-        trigger eps_retrieve eq complete
-      task eps_to_ct_t
-        trigger eps_retrieve eq complete
-      task eps_from_ct
-        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
-      task eps_to_ct_wind_850
-        trigger eps_retrieve eq complete
-      task eps_from_ct_wind_850
-        trigger eps_to_ct_wind_850 eq complete
-      task eps_to_ct_wind_250
-        trigger eps_retrieve eq complete
-      task eps_from_ct_wind_250
-        trigger eps_to_ct_wind_250 eq complete
-      task eps_spread_score1
-        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
-      task eps_spread_score2
-        trigger eps_to_ct_wind_850 eq complete and eps_to_ct_wind_250 eq complete
-      task eps_cal_val
-      task eps_mean_spread_z
-        trigger eps_to_ct_z eq complete
-      task eps_mean_spread_t
-        trigger eps_to_ct_t eq complete
-      task eps_mean_spread_msl
-        trigger eps_to_ct_msl eq complete
-      task eps_mean_spread_wind_850
-        trigger eps_to_ct_wind_850 eq complete
-      task eps_mean_spread_wind_250
-        trigger eps_to_ct_wind_250 eq complete
-    endfamily
-    family clim
-      trigger /o/main/12/an eq complete
-      edit STREAM 'oper'
-      limit count 1
-      inlimit count
-      task clim_z
-      task clim_msl
-      task clim_t
-      task clim_wind_850
-      task clim_wind_250
-      task clim_waves_mwp
-      task clim_waves_swh
-    endfamily
-    family waves
-      trigger /mc/main/12/legB/postproc eq complete
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit OVERWRITE 'yes'
-      limit count 4
-      inlimit count
-      task waves_retrieve
-        edit SMSTRIES '2'
-      task waves_retrieve_ff
-        edit SMSTRIES '2'
-      task waves_eps_retrieve
-        edit SMSTRIES '2'
-      task waves_ctrl_retrieve
-        edit SMSTRIES '2'
-      task waves
-        trigger waves_retrieve eq complete
-        edit SMSSTATUS '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      task waves_ff
-        trigger waves_retrieve_ff eq complete
-      task waves_ff_sea
-        trigger waves_ff eq complete
-      task waves_to_ct
-        trigger waves eq complete
-      task waves_from_ct
-        trigger waves_to_ct eq complete
-      task waves_ctrl
-        trigger waves_ctrl_retrieve eq complete
-      task waves_ctrl_to_ct
-        trigger waves_ctrl eq complete
-      task waves_ctrl_from_ct
-        trigger waves_ctrl_to_ct eq complete
-      task waves_eps_to_ct
-        trigger waves_eps_retrieve eq complete
-      task waves_eps_from_ct
-        trigger waves_eps_to_ct eq complete
-      task waves_eps_mean_spread
-        trigger waves_eps_to_ct eq complete
-      task waves_eps_spread_score
-        trigger waves_eps_to_ct eq complete
-    endfamily
-    family other
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'oper'
-      limit count 3
-      inlimit count
-      time 22:00
-      task other_ukmo_fc
-      task other_ukmo_an
-      task other_ncep_fc
-      task other_ncep_an
-      task other_dwd_fc
-      task other_dwd_an
-      task other_metfr_fc
-      task other_metfr_an
-      task other_jma_fc
-      task other_jma_an
-      task other_cmc_fc
-      task other_cmc_an
-      task other_bom_fc
-      task other_bom_an
-    endfamily
-    task restart
-      time 17:30
-  endfamily
-  family 06
-    repeat date YMD 20091008 20111031 1
-    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
-    edit EMOS_BASE '06'
-    family bc
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'scda'
-      limit count 1
-      inlimit count
-      task bc_upperair
-      task bc_sfc
-    endfamily
-    task restart
-      time 17:00
-  endfamily
-  family 18
-    repeat date YMD 20091008 20111031 1
-    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
-    edit EMOS_BASE '18'
-    family bc
-      edit WSHOST 'swarm'
-      edit QUEUE 'verify@scores2'
-      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'scda'
-      limit count 1
-      inlimit count
-      task bc_upperair
-      task bc_sfc
-    endfamily
-    task restart
-      time 09:00
-  endfamily
-endsuite
-suite macc
-  edit USER 'emos'
-  edit SCHOST 'bee01'
-  edit SCHOST_BKUP 'drn01'
-  edit WSHOST 'swarm'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/emos_dir/f93i/log'
-  edit USE_YMD 'true'
-  edit YMD '20090601'
-  edit DATEMASK '*.*.*'
-  edit VERSION 'f93i'
-  edit INIEXPVER '0001'
-  edit TCINIEXPVER '0001'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '00'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'tc'
-  edit USER_PRIORITY '70'
-  edit REINITIALIZE 'false'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/macc/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/macc/include'
-  edit ACCOUNT 'oosu'
-  edit STREAM 'EF'
-  edit EMOS_STREAM 'EF'
-  edit ENSEMBLES '50'
-  edit ENS_SIZE '50'
-  edit MARS_DB 'marsod'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit SMSLOGHOST 'c1a'
-  edit SMSLOGPORT '9316'
-  edit OD_PROJ 'od'
-  edit SUITE_START '20090602'
-  edit QUEUE 'emos-e'
-  edit QUEUE_EPILOG 'emos-exp'
-  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
-  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/vol/emos_nc/output'
-  edit SMSOUT '/vol/emos_nc/output'
-  edit SLEEPTIME '1'
-  inlimit /limits:swarm
-  clock hybrid 
-  family limits
-    limit linux_cluster 8
-    limit raq_ensemble 2
-    limit calchas 4
-  endfamily
-  family gac
-    inlimit /macc/limits:linux_cluster
-    family plot
-      edit METPY 'metpy'
-      edit UPDATE_WEB_NOW 'yes'
-      edit DO_PUSH_TO_WEB 'yes'
-      family nrt
-        repeat date YMD 20090928 20111215 1
-        edit METPY 'metpy'
-        edit VERSION 'f93i'
-        edit PARAMETERS 'co,go3'
-        edit LEVELS '850,500,300,50'
-        task nrt_fields
-          trigger ( /ecgems/f93i/an/lag:YMD gt /macc/gac/plot/nrt:YMD) or ( /ecgems/f93i/an/lag:YMD eq /macc/gac/plot/nrt:YMD and /ecgems/f93i/an/lag/00/archive eq complete)
-        task nrt_totalcolumns
-          trigger nrt_fields eq complete
-          edit PARAMETERS 'tcco,gtco3'
-        task nrt_zonalmean
-          trigger nrt_totalcolumns eq complete
-          edit METPY 'metpy_new'
-        task nrt_opticaldepth
-          trigger nrt_zonalmean eq complete
-          edit AERTYPES 'total,natural,anthropogenic'
-          edit METPY 'metpy_new'
-        task nrt_uvindex
-          trigger nrt_opticaldepth eq complete
-      endfamily
-      family fcampaign
-        repeat date YMD 20090928 20111215 1
-        edit VERSION 'f7kn'
-        edit OWNER 'nal'
-        family deps
-          task dummy
-            time 09:00
-        endfamily
-        task fcampaign_retrieve_and_process
-          trigger deps eq complete
-        task fcampaign_make_horiz_plots
-          trigger fcampaign_retrieve_and_process eq complete
-        task fcampaign_make_xs_plots
-          trigger fcampaign_make_horiz_plots eq complete
-        task fcampaign_cleanup
-          trigger fcampaign_make_xs_plots eq complete
-      endfamily
-      family gems_reanalysis
-        repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712" "200801" "200802" "200803" "200804" "200805" "200806" "200807" "200808" "200809" "200810" "200811" "200812" "200901" "200902" "200903" "200904"
-        edit VERSION 'f026'
-        edit LEVELS '850,500,300,50'
-        edit title 'GEMS_Reanalysis'
-        edit PARAMETERS 'co,go3,hcho,ch4,nox'
-        task gems_monthly_fields
-        task gems_monthly_zonalmean
-          trigger gems_monthly_fields eq complete
-          edit METPY 'metpy_new'
-        task gems_monthly_totalcolumns
-          trigger gems_monthly_zonalmean eq complete
-          edit PARAMETERS 'tcco,gtco3,tchcho,tcch4'
-      endfamily
-      family fire_products
-        repeat date YMD 20090928 20111215 1
-        edit METPY 'metpy_new'
-        family deps
-          task dummy
-            time 07:00
-        endfamily
-        task fire_radiative_power
-          trigger deps eq complete
-      endfamily
-    endfamily
-    family verif
-      family aer
-        family nrt
-          repeat date YMD 20090928 20111215 1
-          edit OWNER 'nal'
-          task aerover_nrt_make_plots
-            trigger ( /ecgems/f93i/an/lag:YMD gt /macc/gac/verif/aer/nrt:YMD) or ( /ecgems/f93i/an/lag:YMD eq /macc/gac/verif/aer/nrt:YMD and /ecgems/f93i/an/lag/00/archive eq complete)
-          family publish
-            repeat integer imonth 1 0 -1
-            task aerover_nrt_push_statistic_plots
-              trigger ../aerover_nrt_make_plots eq complete
-            task aerover_nrt_push_station_plots
-              trigger aerover_nrt_push_statistic_plots eq complete
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-  endfamily
-  family diss
-    task fcampaign_diss
-      trigger ( /macc/gac/plot/fcampaign:YMD gt /macc/diss/fcampaign_diss:YMD) or ( /macc/gac/plot/fcampaign:YMD eq /macc/diss/fcampaign_diss:YMD and /macc/gac/plot/fcampaign eq complete)
-      repeat date YMD 20090928 20111215 1
-    task nrt_diss
-      trigger ( /macc/gac/plot/nrt:YMD gt /macc/diss/nrt_diss:YMD) or ( /macc/gac/plot/nrt:YMD eq /macc/diss/nrt_diss:YMD and /macc/gac/plot/nrt eq complete)
-      repeat date YMD 20090928 20111215 1
-  endfamily
-endsuite
-suite ecgems
-  edit SMSFILES '/home/ma/emos/def/sync'
-  edit SLEEPTIME '1'
-  clock hybrid 
-  family f93i
-    family an
-      family lag
-        edit YMD '20100114'
-        family 00
-          task archive
-        endfamily
-        family 12
-          task archive
-        endfamily
-      endfamily
-    endfamily
-  endfamily
-  family f8na
-    family an
-      family lag
-        edit YMD '20010101'
-        family 00
-          task archive
-        endfamily
-        family 12
-          task archive
-        endfamily
-      endfamily
-    endfamily
-  endfamily
-endsuite
-suite e_36r1
-  edit CALC_PSBIAS 'true'
-  edit CALC_RSTRHBIAS 'false'
-  edit OBREALTIME 'true'
-  edit LFULL_IASI 'true'
-  edit USER 'emos'
-  edit SCHOST 'c1b'
-  edit STHOST '/s1b'
-  edit SCHOST_BKUP 'c1a'
-  edit STHOST_BKUP '/s1a'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit SMSLOGHOST 'c1b'
-  edit SMSLOGPORT '9316'
-  edit RESERVATION_ON '0'
-  edit VERSION '0046'
-  edit INIEXPVER '0045'
-  edit INISTREAM 'DCDA'
-  edit INIOFFSET_4D '3'
-  edit INICLASS 'od'
-  edit INILEVELS '91'
-  edit INIRESOL '1279'
-  edit FIRST_DAY '0'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '12'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY ''
-  edit INITIME '2009111800'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit PGNPES '64'
-  edit SVNPES '8'
-  edit ININPES '64'
-  edit REINITIALIZE 'false'
-  edit REINIEXPVER '0046'
-  edit REINIPERIOD_4D '12'
-  edit REINISTREAM 'DCDA'
-  edit REINIOFFSET '6'
-  edit REINI_NOT_ED 'false'
-  edit DATEMASK '*.*.*'
-  edit YMD '20091118'
-  edit USE_YMD 'true'
-  edit PARALLEL '4'
-  edit USER_PRIORITY '70'
-  edit FC_USER_PRIORITY '90'
-  edit ANNPES '192'
-  edit NPES_CCMA '%ANNPES%'
-  edit ANMEM '3584'
-  edit ANSTACK '700'
-  edit ANMRFS '160'
-  edit FCNPES '192'
-  edit FCMEM '3584'
-  edit FCSTACK '690'
-  edit FCMRFS '32'
-  edit PERIOD_4D '12'
-  edit WINDOW_LENGTH_4D '12'
-  edit WINDOW_OFFSET_4D '3'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/e_36r1'
-  edit SMSINCLUDE '/home/ma/emos/def/e_36r1/include'
-  edit ACCOUNT 'oesu'
-  edit STREAM 'DA'
-  edit EMOS_STREAM 'DA'
-  edit PGEN_BINDIR '/home/ma/emos/bin/diss'
-  edit PGEN_OBJDIR '/home/ma/emos/bin/diss'
-  edit DISS_REQDB_ROOT '/diss/requirements'
-  edit DISS_BINDIR '/diss/bin/DISS'
-  edit MARS_DB 'marsod'
-  edit OBSHOST 'pp1'
-  edit OBS_USER 'emos'
-  edit OBS_BASE '/pp1'
-  edit LANONLY 'true'
-  edit LAR_4V_EF 'true'
-  edit LFC_DIR_FREQ 'true'
-  edit SMSLOGTIMEOUT '10'
-  edit INIVARBC 'true'
-  edit RUN_3HOURS_PP '1'
-  edit VERIFY 'verify'
-  edit SUITE_START '2009100212'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit.36r1 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-  edit SLEEPTIME '1'
-  inlimit /limits:c1b
-  clock hybrid 
-  family limits
-    limit mars 7
-    limit obs 1
-    limit ml 3
-    limit prod 20
-    limit q2diss 8
-    limit w2diss 2
-    limit pdb 8
-    limit prod_bc 6
-    limit prod_bc2 6
-    limit q2diss_bc 5
-    limit pdb_bc 2
-    limit prodcheck 1
-    limit backupprod 4
-    limit dissbackup 4
-    limit webplots 4
-    limit satmon 7
-    limit smon 3
-    limit obs_get 5
-    limit sync_fdb 1
-    limit sync_data 1
-    limit reservation 1
-    limit satimsim 20
-    limit satimsim_ret 5
-  endfamily
-  family main
-    trigger ( main:YMD le ( lag:YMD + 3))
-    repeat date YMD 20091118 20121212 1
-    family make
-      edit DELTA_DAY '-1'
-      edit EMOS_BASE '18'
-      edit STREAM 'DCDA'
-      task setup
-      task links
-        trigger setup eq complete
-        edit FSFAMILY 'an'
-        edit WSHOST 'bee01'
-      task datalinks
-        trigger setup eq complete and links eq complete
-        edit FSFAMILY 'an'
-      family bins
-        trigger ./links eq complete and ./datalinks eq complete
-        edit SMSFILES '/home/ma/emos/def/e_36r1/make'
-        task odbsql
-        task odbtools
-          trigger odbsql eq complete
-        task b2otools
-          trigger odbtools eq complete
-        task black
-          edit FSFAMILY 'an'
-        task ifs
-          trigger black eq complete and b2otools eq complete
-          edit FSFAMILY 'an'
-        task ssaabs
-          trigger ifs eq complete
-          edit FSFAMILY 'surf_anal'
-        task wamabs
-        task satrad
-          trigger ifs eq complete
-        task scat
-        task obstat
-          trigger odbsql eq complete
-        task satmon
-          trigger odbtools eq complete
-        task prepdata
-          trigger b2otools eq complete
-        task satimbin
-      endfamily
-      family const
-        edit SMSFILES '/home/ma/emos/def/e_36r1/make'
-        task wconst
-          trigger ../bins/wamabs eq complete
-        task wavini
-          trigger wconst eq complete
-          edit FSFAMILY 'fc'
-      endfamily
-      task obstat_ws
-        trigger links eq complete and datalinks eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSTRIES '1'
-        inlimit /limits:linux_cluster
-      task sync_basedir
-      task getini
-        trigger links eq complete and datalinks eq complete and ./bins/prepdata eq complete
-        edit FSFAMILY 'fc'
-      task inidata
-        trigger ./bins/ifs eq complete and getini eq complete
-        edit THREADS '8'
-        edit FSFAMILY 'fc'
-      family fc
-        trigger inidata eq complete and const eq complete
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task model
-          trigger getfcdata eq complete
-          edit FCLENGTH '15'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          meter step -1 15 15
-        task clean
-          trigger model eq complete
-          edit DELTA_DAY '-2'
-      endfamily
-      family prod
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod/make'
-        edit EMOS_DOMAIN 'g'
-        edit EMOS_TYPE 'fc'
-        edit EMOS_STREAM 'OPER'
-        task wparam
-          edit EMOS_TYPE 'wp'
-        task tf
-          edit EMOS_TYPE 'tf'
-        task sortreq
-        task bitmap
-        task clima
-        task disssch
-        task tools
-        task oper
-        task wave
-          edit EMOS_STREAM 'WAVE'
-      endfamily
-      task plotdb
-        trigger links eq complete and datalinks eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /limits:linux_cluster
-    endfamily
-    family 00dc
-      trigger make eq complete
-      edit EMOS_BASE '00'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/dc00/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc00/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc00/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        family getplus6
-          edit EMOS_BASE '06'
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/dc06/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc06/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc06/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete and ./getplus6 eq complete
-        family prepare_obs
-          trigger ./get eq complete and ./getplus6 eq complete
-          task preobs
-            edit mode 'not1crad'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-        family reservation
-          late -c +00:03
-          trigger ./get/get_stor eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task adv_res
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '30'
-            edit RESERVE_IN '30'
-            edit RESERVED_NODES '48'
-            edit RESERVATION_LABEL 'emos00dcA'
-            label info ""
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit PERIOD_4D '12'
-        edit WINDOW_LENGTH_4D '12'
-        edit WINDOW_OFFSET_4D '3'
-        edit ACCOUNT 'oedcdaan'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          event hires
-        task fetcherr
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-        task emiskf
-          trigger ./4dvar/uptraj_0/ifstraj eq complete
-          edit THREADS '1'
-        task update_psbias
-          trigger ./4dvar/ifstraj:finalwave
-        task update_rstrhbias
-          trigger ./4dvar/ifstraj:finalwave
-        task dcda_to_da
-          trigger ./4dvar eq complete and surf_anal eq complete
-          edit EMOS_TYPE 'an'
-          edit OPHOST 'c1b'
-        family reservation1
-          late -c +00:03
-          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:02 -c +00:02
-            edit RESERVED_CPUS '3328'
-            edit RESERVE_FOR '65'
-            label info ""
-          task rm_res
-            late -s +00:02 -c +00:02
-            edit RESERVATION_LABEL 'emos00'
-            label info ""
-          task set_class
-            late -s +00:02 -c +00:02
-            edit RESERVATION_DEFINITION 'default_nodiag'
-            label info ""
-        endfamily
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit EMOS_BASE '06'
-        edit ACCOUNT 'oedcdafc'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task model
-          late -s +00:02
-          trigger getfcdata eq complete
-          edit FCLENGTH '15'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          meter step -1 15 15
-        task ddh
-          trigger model eq complete
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./getfcdata eq active or ./getfcdata eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '3072'
-            edit RESERVE_FOR '4'
-            label info ""
-        endfamily
-        family reservation2
-          late -c +00:03
-          trigger ./model eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reset_cpu
-            late -s +00:03 -c +00:02
-            complete /e_36r1/main/12/an/vardata eq active or /e_36r1/main/12/an/vardata eq complete
-            edit RESERVED_CPUS '0'
-            label info ""
-        endfamily
-      endfamily
-    endfamily
-    family 06
-      trigger make eq complete
-      edit EMOS_BASE '06'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DA'
-      edit LAR_4V_EF 'false'
-      edit LFC_DIR_FREQ 'false'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/ex06/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete
-        family prepare_obs
-          trigger ./get eq complete
-          task preobs
-            edit mode 'not1crad'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit ACCOUNT 'oeoperan'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          trigger ../../00dc/fc/model:step ge 6 or ../../00dc/fc/model eq complete
-          event hires
-        task fetcherr
-          trigger ../../00dc/an eq complete
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit ACCOUNT 'oeoperfc'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task getpersSST
-          trigger getfcdata eq complete
-          edit SSTLEN '9'
-          edit SSTINT '1'
-          edit THREADS '2'
-          edit NPES '16'
-          edit MEM '1000'
-          edit CPUTIME '960'
-        task model
-          late -s +00:02
-          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
-          edit PERSST 'true'
-          edit FCLENGTH '9'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          meter step -1 9 9
-        task ddh
-          trigger model eq complete
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete
-      endfamily
-    endfamily
-    family 12bc
-      edit EMOS_BASE '12'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '0'
-      edit ACCOUNT 'opebcpg'
-      edit SMSURL 'GSCDA/12'
-      edit USER_PRIORITY '91'
-      family getreq
-        trigger ( /e_36r1/main/12/an/4dvar eq active or /e_36r1/main/12/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit PROD_TASK '1'
-        edit EMOS_DOMAIN 'G'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_PROJECT '12'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'SCDA'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '12'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger collectreq eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete and ( req:001 or req eq complete)
-          label info ""
-          event 1 
-      endfamily
-      family prod
-        trigger ( getreq/req:001 or getreq/req eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit EMOS_PROJECT '12'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        family an
-          trigger /e_36r1/main/12/an/surf_anal eq complete and ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar/ifstraj eq complete) and 0 eq 0
-          edit EMOS_TYPE 'an'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ../090/prodgen eq complete and ../../prod eq queued and /e_36r1/main/12/prod eq complete
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 000
-          trigger ( /e_36r1/main/12/fc/model:step ge 000 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0000'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 12 or /e_36r1/main/12/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 003
-          trigger ( /e_36r1/main/12/fc/model:step ge 003 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 15 or /e_36r1/main/12/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 006
-          trigger ( /e_36r1/main/12/fc/model:step ge 006 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 18 or /e_36r1/main/12/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 009
-          trigger ( /e_36r1/main/12/fc/model:step ge 009 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 21 or /e_36r1/main/12/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 012
-          trigger ( /e_36r1/main/12/fc/model:step ge 012 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 24 or /e_36r1/main/12/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 015
-          trigger ( /e_36r1/main/12/fc/model:step ge 015 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 27 or /e_36r1/main/12/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 018
-          trigger ( /e_36r1/main/12/fc/model:step ge 018 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 30 or /e_36r1/main/12/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 021
-          trigger ( /e_36r1/main/12/fc/model:step ge 021 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 33 or /e_36r1/main/12/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 024
-          trigger ( /e_36r1/main/12/fc/model:step ge 024 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 36 or /e_36r1/main/12/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 027
-          trigger ( /e_36r1/main/12/fc/model:step ge 027 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 39 or /e_36r1/main/12/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 030
-          trigger ( /e_36r1/main/12/fc/model:step ge 030 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 42 or /e_36r1/main/12/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 033
-          trigger ( /e_36r1/main/12/fc/model:step ge 033 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 45 or /e_36r1/main/12/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 036
-          trigger ( /e_36r1/main/12/fc/model:step ge 036 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0036'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 48 or /e_36r1/main/12/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 039
-          trigger ( /e_36r1/main/12/fc/model:step ge 039 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0039'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 51 or /e_36r1/main/12/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 042
-          trigger ( /e_36r1/main/12/fc/model:step ge 042 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0042'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 54 or /e_36r1/main/12/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 045
-          trigger ( /e_36r1/main/12/fc/model:step ge 045 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0045'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 57 or /e_36r1/main/12/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 048
-          trigger ( /e_36r1/main/12/fc/model:step ge 048 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0048'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 60 or /e_36r1/main/12/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 051
-          trigger ( /e_36r1/main/12/fc/model:step ge 051 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0051'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 63 or /e_36r1/main/12/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 054
-          trigger ( /e_36r1/main/12/fc/model:step ge 054 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0054'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 66 or /e_36r1/main/12/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 057
-          trigger ( /e_36r1/main/12/fc/model:step ge 057 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0057'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 69 or /e_36r1/main/12/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 060
-          trigger ( /e_36r1/main/12/fc/model:step ge 060 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0060'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 72 or /e_36r1/main/12/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 063
-          trigger ( /e_36r1/main/12/fc/model:step ge 063 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0063'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 75 or /e_36r1/main/12/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 066
-          trigger ( /e_36r1/main/12/fc/model:step ge 066 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0066'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 78 or /e_36r1/main/12/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 069
-          trigger ( /e_36r1/main/12/fc/model:step ge 069 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0069'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 81 or /e_36r1/main/12/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 072
-          trigger ( /e_36r1/main/12/fc/model:step ge 072 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0072'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 84 or /e_36r1/main/12/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 075
-          trigger ( /e_36r1/main/12/fc/model:step ge 075 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0075'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 87 or /e_36r1/main/12/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 078
-          trigger ( /e_36r1/main/12/fc/model:step ge 078 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0078'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/12/fc/model:step ge 90 or /e_36r1/main/12/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 081
-          trigger ( /e_36r1/main/12/fc/model:step ge 081 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0081'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-        family 084
-          trigger ( /e_36r1/main/12/fc/model:step ge 084 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0084'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-        family 087
-          trigger ( /e_36r1/main/12/fc/model:step ge 087 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0087'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-        family 090
-          trigger ( /e_36r1/main/12/fc/model:step ge 090 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0090'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        task operation_is_late
-          event yes
-        family oper
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '92'
-          edit SMSURL 'GSCDA/12'
-          edit EMOS_PROJECT '12'
-          family an
-            task pdb
-              trigger ../../../prod/an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event 1 
-          endfamily
-          family 000
-            edit EMOS_TIME_STEP_H '0000'
-            task pdb
-              trigger ../../../prod/000/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ../an/q2diss eq complete
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 003
-            edit EMOS_TIME_STEP_H '0003'
-            task pdb
-              trigger ../../../prod/003/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/003/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 006
-            edit EMOS_TIME_STEP_H '0006'
-            task pdb
-              trigger ../../../prod/006/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/006/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 009
-            edit EMOS_TIME_STEP_H '0009'
-            task pdb
-              trigger ../../../prod/009/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/009/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 012
-            edit EMOS_TIME_STEP_H '0012'
-            task pdb
-              trigger ../../../prod/012/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/012/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 015
-            edit EMOS_TIME_STEP_H '0015'
-            task pdb
-              trigger ../../../prod/015/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/015/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 018
-            edit EMOS_TIME_STEP_H '0018'
-            task pdb
-              trigger ../../../prod/018/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/018/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 021
-            edit EMOS_TIME_STEP_H '0021'
-            task pdb
-              trigger ../../../prod/021/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/021/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 024
-            edit EMOS_TIME_STEP_H '0024'
-            task pdb
-              trigger ../../../prod/024/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/024/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 027
-            edit EMOS_TIME_STEP_H '0027'
-            task pdb
-              trigger ../../../prod/027/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/027/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 030
-            edit EMOS_TIME_STEP_H '0030'
-            task pdb
-              trigger ../../../prod/030/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/030/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 033
-            edit EMOS_TIME_STEP_H '0033'
-            task pdb
-              trigger ../../../prod/033/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/033/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 036
-            edit EMOS_TIME_STEP_H '0036'
-            task pdb
-              trigger ../../../prod/036/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/036/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 039
-            edit EMOS_TIME_STEP_H '0039'
-            task pdb
-              trigger ../../../prod/039/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/039/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 042
-            edit EMOS_TIME_STEP_H '0042'
-            task pdb
-              trigger ../../../prod/042/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/042/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 045
-            edit EMOS_TIME_STEP_H '0045'
-            task pdb
-              trigger ../../../prod/045/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/045/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 048
-            edit EMOS_TIME_STEP_H '0048'
-            task pdb
-              trigger ../../../prod/048/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/048/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 051
-            edit EMOS_TIME_STEP_H '0051'
-            task pdb
-              trigger ../../../prod/051/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/051/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 054
-            edit EMOS_TIME_STEP_H '0054'
-            task pdb
-              trigger ../../../prod/054/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/054/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 057
-            edit EMOS_TIME_STEP_H '0057'
-            task pdb
-              trigger ../../../prod/057/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/057/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 060
-            edit EMOS_TIME_STEP_H '0060'
-            task pdb
-              trigger ../../../prod/060/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/060/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 063
-            edit EMOS_TIME_STEP_H '0063'
-            task pdb
-              trigger ../../../prod/063/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/063/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 066
-            edit EMOS_TIME_STEP_H '0066'
-            task pdb
-              trigger ../../../prod/066/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/066/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 069
-            edit EMOS_TIME_STEP_H '0069'
-            task pdb
-              trigger ../../../prod/069/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/069/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 072
-            edit EMOS_TIME_STEP_H '0072'
-            task pdb
-              trigger ../../../prod/072/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/072/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 075
-            edit EMOS_TIME_STEP_H '0075'
-            task pdb
-              trigger ../../../prod/075/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/075/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 078
-            edit EMOS_TIME_STEP_H '0078'
-            task pdb
-              trigger ../../../prod/078/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/078/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 081
-            edit EMOS_TIME_STEP_H '0081'
-            task pdb
-              trigger ../../../prod/081/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 084
-            edit EMOS_TIME_STEP_H '0084'
-            task pdb
-              trigger ../../../prod/084/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 087
-            edit EMOS_TIME_STEP_H '0087'
-            task pdb
-              trigger ../../../prod/087/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 090
-            edit EMOS_TIME_STEP_H '0090'
-            task pdb
-              trigger ../../../prod/090/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          task check
-            trigger ./078 eq complete
-        endfamily
-      endfamily
-    endfamily
-    family 12
-      trigger make eq complete
-      edit EMOS_BASE '12'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      edit ACCOUNT 'oeoperpg'
-      edit SMSURL 'GOPER/12'
-      edit USER_PRIORITY '90'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/ex12/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex12/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex12/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete
-        family prepare_obs
-          trigger ./get eq complete
-          task preobs
-            trigger /e_36r1/main/00dc/an/update_psbias eq complete and /e_36r1/main/00dc/an/update_rstrhbias eq complete
-            edit mode 'not1crad'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-        family reservation
-          late -c +00:03
-          trigger ./get/get_stor eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task adv_res
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '30'
-            edit RESERVE_IN '60'
-            edit RESERVED_NODES '45'
-            edit RESERVATION_LABEL 'emos12XP'
-            label info ""
-          task adv_resA
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '80'
-            edit RESERVE_IN '11'
-            edit RESERVED_NODES '48'
-            edit RESERVATION_LABEL 'emos12A'
-            label info ""
-          task adv_resB
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '30'
-            edit RESERVE_IN '48'
-            edit RESERVED_NODES '48'
-            edit RESERVATION_LABEL 'emos12B'
-            label info ""
-          task adv_resC
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '50'
-            edit RESERVE_IN '55'
-            edit RESERVED_NODES '132'
-            edit RESERVATION_LABEL 'emos12C'
-            label info ""
-          task loadl_cycle_limit
-            late -s +00:03 -c +00:02
-            edit LOADL_CYCLE '65'
-            label info ""
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit PERIOD_4D '6'
-        edit WINDOW_LENGTH_4D '6'
-        edit WINDOW_OFFSET_4D '3'
-        edit ACCOUNT 'oeoperan'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          trigger ( ../../00dc/fc/model:step ge 6 or ../../00dc/fc/model eq complete) and ../../06/an eq complete
-          event hires
-        task fetcherr
-          trigger ../../06/an eq complete and ../../00dc/an eq complete
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '3328'
-            edit RESERVE_FOR '80'
-            label info ""
-          task rm_res
-            late -s +00:03 -c +00:02
-            edit RESERVATION_LABEL 'emos12A'
-            label info ""
-          task ms_cpu
-            late -s +00:03 -c +00:02
-            edit MS_CPUS '$((64*30))'
-            label info ""
-        endfamily
-        family reservation3
-          late -c +00:03
-          trigger ./4dvar/uptraj_1 eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task set_class
-            late -s +00:03 -c +00:02
-            edit RESERVATION_DEFINITION 'default'
-            label info ""
-        endfamily
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit ACCOUNT 'oeoperfc'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task getpersSST
-          trigger getfcdata eq complete
-          edit SSTLEN '240'
-          edit SSTINT '1'
-          edit THREADS '2'
-          edit NPES '16'
-          edit MEM '1000'
-          edit CPUTIME '960'
-        task model
-          late -s +00:02
-          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
-          edit PERSST 'true'
-          edit FCLENGTH '240'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          meter step -1 240 240
-        task ddh
-          trigger model eq complete
-        task imet
-          trigger ddh eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task ddh_arm
-          trigger ddh eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete and ../../00dc/fc eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./getfcdata eq active or ./getfcdata eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          family xp
-            task set_xp
-              late -s +00:03 -c +00:02
-              edit RESERVATION_LABEL 'emos12XP'
-              label info ""
-            task rm_res
-              late -s +00:03 -c +00:02
-              trigger ./set_xp eq complete
-              edit RESERVATION_LABEL 'emos12XP'
-              label info ""
-          endfamily
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '12160'
-            edit RESERVE_FOR '2'
-            label info ""
-          task rm_res
-            late -s +00:03 -c +00:02
-            edit RESERVATION_LABEL 'emos12B'
-            label info ""
-        endfamily
-      endfamily
-      family getreq
-        trigger ( /e_36r1/main/12/an/4dvar eq active or /e_36r1/main/12/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit PROD_TASK '1'
-        edit EMOS_DOMAIN 'G'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_PROJECT '12'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'OPER'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '12'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger collectreq eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete and ( req:001 or req eq complete)
-          label info ""
-          event 1 
-        task collectwave
-          trigger ./collectbitmap eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '12'
-          edit EMOS_STREAM 'WAVE'
-        task wavereq
-          late -s +00:03 -c +00:10
-          trigger ./collectwave eq complete
-          edit EMOS_STREAM 'WAVE'
-          label info ""
-          event 1 
-        task pgclima
-          late -s +00:03 -c +00:10
-          event 1 
-        task cleanpdb
-      endfamily
-      family prod
-        trigger ( getreq/req:001 or getreq/req eq complete) and ( getreq/bitmap:001 or getreq/bitmap eq complete) and ( getreq/wavereq:001 or getreq/wavereq eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit EMOS_PROJECT '12'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        family 06an
-          trigger /e_36r1/main/00dc/an/dcda_to_da eq complete
-          edit EMOS_TYPE 'an'
-          edit EMOS_BASE '06'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 12an
-          trigger /e_36r1/main/12/an/surf_anal eq complete and ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar/ifstraj eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TYPE 'an'
-          edit PGNPES '90'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            edit SMSPASS 'stripped'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ( ./derived_param:SMOS or ./derived_param eq complete) and ( ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar/ifstraj eq complete))
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 000
-          trigger ( /e_36r1/main/12/fc/model:step ge 000 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0000'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '000'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 003
-          trigger ( /e_36r1/main/12/fc/model:step ge 003 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '003'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 006
-          trigger ( /e_36r1/main/12/fc/model:step ge 006 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '006'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 009
-          trigger ( /e_36r1/main/12/fc/model:step ge 009 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '009'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 012
-          trigger ( /e_36r1/main/12/fc/model:step ge 012 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '012'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 015
-          trigger ( /e_36r1/main/12/fc/model:step ge 015 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '015'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 018
-          trigger ( /e_36r1/main/12/fc/model:step ge 018 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '018'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 021
-          trigger ( /e_36r1/main/12/fc/model:step ge 021 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '021'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 024
-          trigger ( /e_36r1/main/12/fc/model:step ge 024 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '024'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 027
-          trigger ( /e_36r1/main/12/fc/model:step ge 027 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '027'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 030
-          trigger ( /e_36r1/main/12/fc/model:step ge 030 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '030'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 033
-          trigger ( /e_36r1/main/12/fc/model:step ge 033 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '033'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 036
-          trigger ( /e_36r1/main/12/fc/model:step ge 036 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0036'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '036'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 039
-          trigger ( /e_36r1/main/12/fc/model:step ge 039 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0039'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '039'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 042
-          trigger ( /e_36r1/main/12/fc/model:step ge 042 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0042'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '042'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 045
-          trigger ( /e_36r1/main/12/fc/model:step ge 045 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0045'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '045'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 048
-          trigger ( /e_36r1/main/12/fc/model:step ge 048 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0048'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '048'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 051
-          trigger ( /e_36r1/main/12/fc/model:step ge 051 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0051'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '051'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 054
-          trigger ( /e_36r1/main/12/fc/model:step ge 054 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0054'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '054'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 057
-          trigger ( /e_36r1/main/12/fc/model:step ge 057 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0057'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '057'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 060
-          trigger ( /e_36r1/main/12/fc/model:step ge 060 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0060'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '060'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 063
-          trigger ( /e_36r1/main/12/fc/model:step ge 063 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0063'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '063'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 066
-          trigger ( /e_36r1/main/12/fc/model:step ge 066 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0066'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '066'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 069
-          trigger ( /e_36r1/main/12/fc/model:step ge 069 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0069'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '069'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 072
-          trigger ( /e_36r1/main/12/fc/model:step ge 072 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0072'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '072'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 075
-          trigger ( /e_36r1/main/12/fc/model:step ge 075 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0075'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '075'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 078
-          trigger ( /e_36r1/main/12/fc/model:step ge 078 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0078'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '078'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 081
-          trigger ( /e_36r1/main/12/fc/model:step ge 081 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0081'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '081'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 084
-          trigger ( /e_36r1/main/12/fc/model:step ge 084 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0084'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '084'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 087
-          trigger ( /e_36r1/main/12/fc/model:step ge 087 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0087'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '087'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 090
-          trigger ( /e_36r1/main/12/fc/model:step ge 090 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0090'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '090'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 093
-          trigger ( /e_36r1/main/12/fc/model:step ge 093 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0093'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../090/derived_param:SMOS or ../090/derived_param eq complete) or ( ../090/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '093'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 096
-          trigger ( /e_36r1/main/12/fc/model:step ge 096 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0096'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../093/derived_param:SMOS or ../093/derived_param eq complete) or ( ../093/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '096'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 099
-          trigger ( /e_36r1/main/12/fc/model:step ge 099 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0099'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../096/derived_param:SMOS or ../096/derived_param eq complete) or ( ../096/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '099'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 102
-          trigger ( /e_36r1/main/12/fc/model:step ge 102 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0102'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../099/derived_param:SMOS or ../099/derived_param eq complete) or ( ../099/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '102'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 105
-          trigger ( /e_36r1/main/12/fc/model:step ge 105 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0105'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../102/derived_param:SMOS or ../102/derived_param eq complete) or ( ../102/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '105'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 108
-          trigger ( /e_36r1/main/12/fc/model:step ge 108 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0108'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../105/derived_param:SMOS or ../105/derived_param eq complete) or ( ../105/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '108'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 111
-          trigger ( /e_36r1/main/12/fc/model:step ge 111 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0111'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../108/derived_param:SMOS or ../108/derived_param eq complete) or ( ../108/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '111'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 114
-          trigger ( /e_36r1/main/12/fc/model:step ge 114 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0114'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../111/derived_param:SMOS or ../111/derived_param eq complete) or ( ../111/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '114'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 117
-          trigger ( /e_36r1/main/12/fc/model:step ge 117 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0117'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../114/derived_param:SMOS or ../114/derived_param eq complete) or ( ../114/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '117'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 120
-          trigger ( /e_36r1/main/12/fc/model:step ge 120 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0120'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../117/derived_param:SMOS or ../117/derived_param eq complete) or ( ../117/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '120'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 123
-          trigger ( /e_36r1/main/12/fc/model:step ge 123 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0123'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../120/derived_param:SMOS or ../120/derived_param eq complete) or ( ../120/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '123'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 126
-          trigger ( /e_36r1/main/12/fc/model:step ge 126 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0126'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../123/derived_param:SMOS or ../123/derived_param eq complete) or ( ../123/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '126'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 129
-          trigger ( /e_36r1/main/12/fc/model:step ge 129 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0129'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../126/derived_param:SMOS or ../126/derived_param eq complete) or ( ../126/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '129'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 132
-          trigger ( /e_36r1/main/12/fc/model:step ge 132 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0132'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../129/derived_param:SMOS or ../129/derived_param eq complete) or ( ../129/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '132'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 135
-          trigger ( /e_36r1/main/12/fc/model:step ge 135 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0135'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../132/derived_param:SMOS or ../132/derived_param eq complete) or ( ../132/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '135'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 138
-          trigger ( /e_36r1/main/12/fc/model:step ge 138 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0138'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../135/derived_param:SMOS or ../135/derived_param eq complete) or ( ../135/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '138'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 141
-          trigger ( /e_36r1/main/12/fc/model:step ge 141 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0141'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../138/derived_param:SMOS or ../138/derived_param eq complete) or ( ../138/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '141'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 144
-          trigger ( /e_36r1/main/12/fc/model:step ge 144 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0144'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../141/derived_param:SMOS or ../141/derived_param eq complete) or ( ../141/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '144'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 150
-          trigger ( /e_36r1/main/12/fc/model:step ge 150 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0150'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../144/derived_param:SMOS or ../144/derived_param eq complete) or ( ../144/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '150'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 156
-          trigger ( /e_36r1/main/12/fc/model:step ge 156 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0156'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../150/derived_param:SMOS or ../150/derived_param eq complete) or ( ../150/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '156'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 162
-          trigger ( /e_36r1/main/12/fc/model:step ge 162 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0162'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../156/derived_param:SMOS or ../156/derived_param eq complete) or ( ../156/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '162'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 168
-          trigger ( /e_36r1/main/12/fc/model:step ge 168 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0168'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../162/derived_param:SMOS or ../162/derived_param eq complete) or ( ../162/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '168'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 174
-          trigger ( /e_36r1/main/12/fc/model:step ge 174 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0174'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../168/derived_param:SMOS or ../168/derived_param eq complete) or ( ../168/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '174'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 180
-          trigger ( /e_36r1/main/12/fc/model:step ge 180 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0180'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../174/derived_param:SMOS or ../174/derived_param eq complete) or ( ../174/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '180'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 186
-          trigger ( /e_36r1/main/12/fc/model:step ge 186 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0186'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../180/derived_param:SMOS or ../180/derived_param eq complete) or ( ../180/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '186'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 192
-          trigger ( /e_36r1/main/12/fc/model:step ge 192 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0192'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../186/derived_param:SMOS or ../186/derived_param eq complete) or ( ../186/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '192'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 198
-          trigger ( /e_36r1/main/12/fc/model:step ge 198 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0198'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../192/derived_param:SMOS or ../192/derived_param eq complete) or ( ../192/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '198'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 204
-          trigger ( /e_36r1/main/12/fc/model:step ge 204 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0204'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../198/derived_param:SMOS or ../198/derived_param eq complete) or ( ../198/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '204'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 210
-          trigger ( /e_36r1/main/12/fc/model:step ge 210 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0210'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../204/derived_param:SMOS or ../204/derived_param eq complete) or ( ../204/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '210'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 216
-          trigger ( /e_36r1/main/12/fc/model:step ge 216 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0216'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../210/derived_param:SMOS or ../210/derived_param eq complete) or ( ../210/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '216'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 222
-          trigger ( /e_36r1/main/12/fc/model:step ge 222 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0222'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../216/derived_param:SMOS or ../216/derived_param eq complete) or ( ../216/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '222'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 228
-          trigger ( /e_36r1/main/12/fc/model:step ge 228 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0228'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../222/derived_param:SMOS or ../222/derived_param eq complete) or ( ../222/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '228'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 234
-          trigger ( /e_36r1/main/12/fc/model:step ge 234 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0234'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../228/derived_param:SMOS or ../228/derived_param eq complete) or ( ../228/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '234'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 240
-          trigger ( /e_36r1/main/12/fc/model:step ge 240 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
-          edit EMOS_TIME_STEP_H '0240'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodmet
-            late -s +00:05 -c +00:15
-            edit PROD_TASK '5'
-            edit PGNPES '1'
-            edit EMOS_TYPE 'mt'
-            inlimit /e_36r1/limits:prod
-          task prod_wparam
-            late -s +00:05 -c +00:15
-            trigger ./derived_param eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TYPE 'wp'
-            edit PGNPES '64'
-            edit INIMEM '800'
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../234/derived_param:SMOS or ../234/derived_param eq complete) or ( ../234/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '240'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family reservation1
-          late -c +00:03
-          trigger /e_36r1/main/12bc/prod/078/prodgen eq active or /e_36r1/main/12bc/prod/078/prodgen eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task set_xp
-            late -s +00:03 -c +00:02
-            edit RESERVATION_NODES '45'
-            label info ""
-        endfamily
-        family reservation2
-          late -c +00:03
-          trigger /e_36r1/main/12/prod/240/prodgen eq active or /e_36r1/main/12/prod/240/prodgen eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task set_xp
-            late -s +00:03 -c +00:02
-            edit RESERVATION_NODES '20'
-            label info ""
-        endfamily
-        family reservation3
-          late -c +00:03
-          trigger /e_36r1/main/12/prod/240/prodgen eq active or /e_36r1/main/12/prod/240/prodgen eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reset_xp
-            late -s +00:03 -c +00:02
-            trigger /emc_36r1/main/12/legB/prod eq complete
-            edit RESERVATION_NODES '0'
-            label info ""
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        task operation_is_late
-          event yes
-        family oper
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '92'
-          edit EMOS_PROJECT '12'
-          edit SMSURL 'GSCDA/12'
-          family 06an
-            edit EMOS_BASE '06'
-            edit EMOS_TYPE 'an'
-            edit SMSURL 'GOPER/06'
-            task pdb
-              trigger ../../../prod/06an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 12an
-            edit EMOS_TYPE 'an'
-            edit SMSURL 'GOPER/12'
-            task pdb
-              trigger ../../../prod/12an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 000
-            edit EMOS_TIME_STEP_H '0000'
-            task pdb
-              trigger ../../../prod/000/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../12an/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 003
-            edit EMOS_TIME_STEP_H '0003'
-            task pdb
-              trigger ../../../prod/003/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 006
-            edit EMOS_TIME_STEP_H '0006'
-            task pdb
-              trigger ../../../prod/006/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 009
-            edit EMOS_TIME_STEP_H '0009'
-            task pdb
-              trigger ../../../prod/009/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 012
-            edit EMOS_TIME_STEP_H '0012'
-            task pdb
-              trigger ../../../prod/012/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 015
-            edit EMOS_TIME_STEP_H '0015'
-            task pdb
-              trigger ../../../prod/015/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 018
-            edit EMOS_TIME_STEP_H '0018'
-            task pdb
-              trigger ../../../prod/018/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 021
-            edit EMOS_TIME_STEP_H '0021'
-            task pdb
-              trigger ../../../prod/021/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 024
-            edit EMOS_TIME_STEP_H '0024'
-            task pdb
-              trigger ../../../prod/024/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 027
-            edit EMOS_TIME_STEP_H '0027'
-            task pdb
-              trigger ../../../prod/027/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 030
-            edit EMOS_TIME_STEP_H '0030'
-            task pdb
-              trigger ../../../prod/030/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 033
-            edit EMOS_TIME_STEP_H '0033'
-            task pdb
-              trigger ../../../prod/033/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 036
-            edit EMOS_TIME_STEP_H '0036'
-            task pdb
-              trigger ../../../prod/036/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 039
-            edit EMOS_TIME_STEP_H '0039'
-            task pdb
-              trigger ../../../prod/039/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 042
-            edit EMOS_TIME_STEP_H '0042'
-            task pdb
-              trigger ../../../prod/042/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 045
-            edit EMOS_TIME_STEP_H '0045'
-            task pdb
-              trigger ../../../prod/045/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 048
-            edit EMOS_TIME_STEP_H '0048'
-            task pdb
-              trigger ../../../prod/048/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 051
-            edit EMOS_TIME_STEP_H '0051'
-            task pdb
-              trigger ../../../prod/051/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 054
-            edit EMOS_TIME_STEP_H '0054'
-            task pdb
-              trigger ../../../prod/054/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 057
-            edit EMOS_TIME_STEP_H '0057'
-            task pdb
-              trigger ../../../prod/057/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 060
-            edit EMOS_TIME_STEP_H '0060'
-            task pdb
-              trigger ../../../prod/060/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 063
-            edit EMOS_TIME_STEP_H '0063'
-            task pdb
-              trigger ../../../prod/063/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 066
-            edit EMOS_TIME_STEP_H '0066'
-            task pdb
-              trigger ../../../prod/066/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 069
-            edit EMOS_TIME_STEP_H '0069'
-            task pdb
-              trigger ../../../prod/069/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 072
-            edit EMOS_TIME_STEP_H '0072'
-            task pdb
-              trigger ../../../prod/072/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 075
-            edit EMOS_TIME_STEP_H '0075'
-            task pdb
-              trigger ../../../prod/075/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 078
-            edit EMOS_TIME_STEP_H '0078'
-            task pdb
-              trigger ../../../prod/078/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 081
-            edit EMOS_TIME_STEP_H '0081'
-            task pdb
-              trigger ../../../prod/081/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 084
-            edit EMOS_TIME_STEP_H '0084'
-            task pdb
-              trigger ../../../prod/084/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 087
-            edit EMOS_TIME_STEP_H '0087'
-            task pdb
-              trigger ../../../prod/087/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 090
-            edit EMOS_TIME_STEP_H '0090'
-            task pdb
-              trigger ../../../prod/090/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 093
-            edit EMOS_TIME_STEP_H '0093'
-            task pdb
-              trigger ../../../prod/093/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../090/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 096
-            edit EMOS_TIME_STEP_H '0096'
-            task pdb
-              trigger ../../../prod/096/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../093/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 099
-            edit EMOS_TIME_STEP_H '0099'
-            task pdb
-              trigger ../../../prod/099/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../096/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 102
-            edit EMOS_TIME_STEP_H '0102'
-            task pdb
-              trigger ../../../prod/102/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../099/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 105
-            edit EMOS_TIME_STEP_H '0105'
-            task pdb
-              trigger ../../../prod/105/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../102/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 108
-            edit EMOS_TIME_STEP_H '0108'
-            task pdb
-              trigger ../../../prod/108/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../105/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 111
-            edit EMOS_TIME_STEP_H '0111'
-            task pdb
-              trigger ../../../prod/111/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../108/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 114
-            edit EMOS_TIME_STEP_H '0114'
-            task pdb
-              trigger ../../../prod/114/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../111/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 117
-            edit EMOS_TIME_STEP_H '0117'
-            task pdb
-              trigger ../../../prod/117/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../114/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 120
-            edit EMOS_TIME_STEP_H '0120'
-            task pdb
-              trigger ../../../prod/120/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../117/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 123
-            edit EMOS_TIME_STEP_H '0123'
-            task pdb
-              trigger ../../../prod/123/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../120/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 126
-            edit EMOS_TIME_STEP_H '0126'
-            task pdb
-              trigger ../../../prod/126/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../123/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 129
-            edit EMOS_TIME_STEP_H '0129'
-            task pdb
-              trigger ../../../prod/129/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../126/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 132
-            edit EMOS_TIME_STEP_H '0132'
-            task pdb
-              trigger ../../../prod/132/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../129/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 135
-            edit EMOS_TIME_STEP_H '0135'
-            task pdb
-              trigger ../../../prod/135/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../132/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 138
-            edit EMOS_TIME_STEP_H '0138'
-            task pdb
-              trigger ../../../prod/138/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../135/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 141
-            edit EMOS_TIME_STEP_H '0141'
-            task pdb
-              trigger ../../../prod/141/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../138/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 144
-            edit EMOS_TIME_STEP_H '0144'
-            task pdb
-              trigger ../../../prod/144/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../141/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 150
-            edit EMOS_TIME_STEP_H '0150'
-            task pdb
-              trigger ../../../prod/150/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../144/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 156
-            edit EMOS_TIME_STEP_H '0156'
-            task pdb
-              trigger ../../../prod/156/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../150/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 162
-            edit EMOS_TIME_STEP_H '0162'
-            task pdb
-              trigger ../../../prod/162/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../156/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 168
-            edit EMOS_TIME_STEP_H '0168'
-            task pdb
-              trigger ../../../prod/168/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../162/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 174
-            edit EMOS_TIME_STEP_H '0174'
-            task pdb
-              trigger ../../../prod/174/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../168/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 180
-            edit EMOS_TIME_STEP_H '0180'
-            task pdb
-              trigger ../../../prod/180/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../174/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 186
-            edit EMOS_TIME_STEP_H '0186'
-            task pdb
-              trigger ../../../prod/186/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../180/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 192
-            edit EMOS_TIME_STEP_H '0192'
-            task pdb
-              trigger ../../../prod/192/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../186/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 198
-            edit EMOS_TIME_STEP_H '0198'
-            task pdb
-              trigger ../../../prod/198/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../192/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 204
-            edit EMOS_TIME_STEP_H '0204'
-            task pdb
-              trigger ../../../prod/204/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../198/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 210
-            edit EMOS_TIME_STEP_H '0210'
-            task pdb
-              trigger ../../../prod/210/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../204/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 216
-            edit EMOS_TIME_STEP_H '0216'
-            task pdb
-              trigger ../../../prod/216/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../210/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 222
-            edit EMOS_TIME_STEP_H '0222'
-            task pdb
-              trigger ../../../prod/222/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../216/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 228
-            edit EMOS_TIME_STEP_H '0228'
-            task pdb
-              trigger ../../../prod/228/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../222/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 234
-            edit EMOS_TIME_STEP_H '0234'
-            task pdb
-              trigger ../../../prod/234/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../228/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 240
-            edit EMOS_TIME_STEP_H '0240'
-            task pdb
-              trigger ../../../prod/240/prodgen eq complete and ../../../prod/240/prodmet eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../234/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-            task diss_wparam
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/240/prod_wparam eq complete
-              edit PROD_TASK 'w'
-              edit EMOS_TYPE 'wp'
-              label info ""
-              event pdb
-          endfamily
-          task check
-            trigger ./240 eq complete
-        endfamily
-        family wave
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit EMOS_PROJECT '12'
-          edit EMOS_STREAM 'WV'
-          edit SMSURL 'GWAVE/12'
-          inlimit /e_36r1/limits:w2diss
-          inlimit /limits:q2diss
-          family 06an
-            edit EMOS_TYPE 'an'
-            edit EMOS_BASE '06'
-            task diss
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/06an/prodwave eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event pdb
-          endfamily
-          family 12an
-            edit EMOS_TYPE 'an'
-            task diss
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/12an/prodwave eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event pdb
-          endfamily
-          family 000
-            trigger ../../prod/000/prodwave eq complete and ./06an eq complete and ./12an eq complete
-            edit EMOS_TIME_STEP_H '0000'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 003
-            trigger ../../prod/003/prodwave eq complete and ( ./000/diss:pdb or ./000 eq complete)
-            edit EMOS_TIME_STEP_H '0003'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 006
-            trigger ../../prod/006/prodwave eq complete and ( ./003/diss:pdb or ./003 eq complete)
-            edit EMOS_TIME_STEP_H '0006'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 009
-            trigger ../../prod/009/prodwave eq complete and ( ./006/diss:pdb or ./006 eq complete)
-            edit EMOS_TIME_STEP_H '0009'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 012
-            trigger ../../prod/012/prodwave eq complete and ( ./009/diss:pdb or ./009 eq complete)
-            edit EMOS_TIME_STEP_H '0012'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 015
-            trigger ../../prod/015/prodwave eq complete and ( ./012/diss:pdb or ./012 eq complete)
-            edit EMOS_TIME_STEP_H '0015'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 018
-            trigger ../../prod/018/prodwave eq complete and ( ./015/diss:pdb or ./015 eq complete)
-            edit EMOS_TIME_STEP_H '0018'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 021
-            trigger ../../prod/021/prodwave eq complete and ( ./018/diss:pdb or ./018 eq complete)
-            edit EMOS_TIME_STEP_H '0021'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 024
-            trigger ../../prod/024/prodwave eq complete and ( ./021/diss:pdb or ./021 eq complete)
-            edit EMOS_TIME_STEP_H '0024'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 027
-            trigger ../../prod/027/prodwave eq complete and ( ./024/diss:pdb or ./024 eq complete)
-            edit EMOS_TIME_STEP_H '0027'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 030
-            trigger ../../prod/030/prodwave eq complete and ( ./027/diss:pdb or ./027 eq complete)
-            edit EMOS_TIME_STEP_H '0030'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 033
-            trigger ../../prod/033/prodwave eq complete and ( ./030/diss:pdb or ./030 eq complete)
-            edit EMOS_TIME_STEP_H '0033'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 036
-            trigger ../../prod/036/prodwave eq complete and ( ./033/diss:pdb or ./033 eq complete)
-            edit EMOS_TIME_STEP_H '0036'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 039
-            trigger ../../prod/039/prodwave eq complete and ( ./036/diss:pdb or ./036 eq complete)
-            edit EMOS_TIME_STEP_H '0039'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 042
-            trigger ../../prod/042/prodwave eq complete and ( ./039/diss:pdb or ./039 eq complete)
-            edit EMOS_TIME_STEP_H '0042'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 045
-            trigger ../../prod/045/prodwave eq complete and ( ./042/diss:pdb or ./042 eq complete)
-            edit EMOS_TIME_STEP_H '0045'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 048
-            trigger ../../prod/048/prodwave eq complete and ( ./045/diss:pdb or ./045 eq complete)
-            edit EMOS_TIME_STEP_H '0048'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 051
-            trigger ../../prod/051/prodwave eq complete and ( ./048/diss:pdb or ./048 eq complete)
-            edit EMOS_TIME_STEP_H '0051'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 054
-            trigger ../../prod/054/prodwave eq complete and ( ./051/diss:pdb or ./051 eq complete)
-            edit EMOS_TIME_STEP_H '0054'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 057
-            trigger ../../prod/057/prodwave eq complete and ( ./054/diss:pdb or ./054 eq complete)
-            edit EMOS_TIME_STEP_H '0057'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 060
-            trigger ../../prod/060/prodwave eq complete and ( ./057/diss:pdb or ./057 eq complete)
-            edit EMOS_TIME_STEP_H '0060'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 063
-            trigger ../../prod/063/prodwave eq complete and ( ./060/diss:pdb or ./060 eq complete)
-            edit EMOS_TIME_STEP_H '0063'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 066
-            trigger ../../prod/066/prodwave eq complete and ( ./063/diss:pdb or ./063 eq complete)
-            edit EMOS_TIME_STEP_H '0066'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 069
-            trigger ../../prod/069/prodwave eq complete and ( ./066/diss:pdb or ./066 eq complete)
-            edit EMOS_TIME_STEP_H '0069'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 072
-            trigger ../../prod/072/prodwave eq complete and ( ./069/diss:pdb or ./069 eq complete)
-            edit EMOS_TIME_STEP_H '0072'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 075
-            trigger ../../prod/075/prodwave eq complete and ( ./072/diss:pdb or ./072 eq complete)
-            edit EMOS_TIME_STEP_H '0075'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 078
-            trigger ../../prod/078/prodwave eq complete and ( ./075/diss:pdb or ./075 eq complete)
-            edit EMOS_TIME_STEP_H '0078'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 081
-            trigger ../../prod/081/prodwave eq complete and ( ./078/diss:pdb or ./078 eq complete)
-            edit EMOS_TIME_STEP_H '0081'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 084
-            trigger ../../prod/084/prodwave eq complete and ( ./081/diss:pdb or ./081 eq complete)
-            edit EMOS_TIME_STEP_H '0084'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 087
-            trigger ../../prod/087/prodwave eq complete and ( ./084/diss:pdb or ./084 eq complete)
-            edit EMOS_TIME_STEP_H '0087'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 090
-            trigger ../../prod/090/prodwave eq complete and ( ./087/diss:pdb or ./087 eq complete)
-            edit EMOS_TIME_STEP_H '0090'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 093
-            trigger ../../prod/093/prodwave eq complete and ( ./090/diss:pdb or ./090 eq complete)
-            edit EMOS_TIME_STEP_H '0093'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 096
-            trigger ../../prod/096/prodwave eq complete and ( ./093/diss:pdb or ./093 eq complete)
-            edit EMOS_TIME_STEP_H '0096'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 099
-            trigger ../../prod/099/prodwave eq complete and ( ./096/diss:pdb or ./096 eq complete)
-            edit EMOS_TIME_STEP_H '0099'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 102
-            trigger ../../prod/102/prodwave eq complete and ( ./099/diss:pdb or ./099 eq complete)
-            edit EMOS_TIME_STEP_H '0102'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 105
-            trigger ../../prod/105/prodwave eq complete and ( ./102/diss:pdb or ./102 eq complete)
-            edit EMOS_TIME_STEP_H '0105'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 108
-            trigger ../../prod/108/prodwave eq complete and ( ./105/diss:pdb or ./105 eq complete)
-            edit EMOS_TIME_STEP_H '0108'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 111
-            trigger ../../prod/111/prodwave eq complete and ( ./108/diss:pdb or ./108 eq complete)
-            edit EMOS_TIME_STEP_H '0111'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 114
-            trigger ../../prod/114/prodwave eq complete and ( ./111/diss:pdb or ./111 eq complete)
-            edit EMOS_TIME_STEP_H '0114'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 117
-            trigger ../../prod/117/prodwave eq complete and ( ./114/diss:pdb or ./114 eq complete)
-            edit EMOS_TIME_STEP_H '0117'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 120
-            trigger ../../prod/120/prodwave eq complete and ( ./117/diss:pdb or ./117 eq complete)
-            edit EMOS_TIME_STEP_H '0120'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 123
-            trigger ../../prod/123/prodwave eq complete and ( ./120/diss:pdb or ./120 eq complete)
-            edit EMOS_TIME_STEP_H '0123'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 126
-            trigger ../../prod/126/prodwave eq complete and ( ./123/diss:pdb or ./123 eq complete)
-            edit EMOS_TIME_STEP_H '0126'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 129
-            trigger ../../prod/129/prodwave eq complete and ( ./126/diss:pdb or ./126 eq complete)
-            edit EMOS_TIME_STEP_H '0129'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 132
-            trigger ../../prod/132/prodwave eq complete and ( ./129/diss:pdb or ./129 eq complete)
-            edit EMOS_TIME_STEP_H '0132'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 135
-            trigger ../../prod/135/prodwave eq complete and ( ./132/diss:pdb or ./132 eq complete)
-            edit EMOS_TIME_STEP_H '0135'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 138
-            trigger ../../prod/138/prodwave eq complete and ( ./135/diss:pdb or ./135 eq complete)
-            edit EMOS_TIME_STEP_H '0138'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 141
-            trigger ../../prod/141/prodwave eq complete and ( ./138/diss:pdb or ./138 eq complete)
-            edit EMOS_TIME_STEP_H '0141'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 144
-            trigger ../../prod/144/prodwave eq complete and ( ./141/diss:pdb or ./141 eq complete)
-            edit EMOS_TIME_STEP_H '0144'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 150
-            trigger ../../prod/150/prodwave eq complete and ( ./144/diss:pdb or ./144 eq complete)
-            edit EMOS_TIME_STEP_H '0150'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 156
-            trigger ../../prod/156/prodwave eq complete and ( ./150/diss:pdb or ./150 eq complete)
-            edit EMOS_TIME_STEP_H '0156'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 162
-            trigger ../../prod/162/prodwave eq complete and ( ./156/diss:pdb or ./156 eq complete)
-            edit EMOS_TIME_STEP_H '0162'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 168
-            trigger ../../prod/168/prodwave eq complete and ( ./162/diss:pdb or ./162 eq complete)
-            edit EMOS_TIME_STEP_H '0168'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 174
-            trigger ../../prod/174/prodwave eq complete and ( ./168/diss:pdb or ./168 eq complete)
-            edit EMOS_TIME_STEP_H '0174'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 180
-            trigger ../../prod/180/prodwave eq complete and ( ./174/diss:pdb or ./174 eq complete)
-            edit EMOS_TIME_STEP_H '0180'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 186
-            trigger ../../prod/186/prodwave eq complete and ( ./180/diss:pdb or ./180 eq complete)
-            edit EMOS_TIME_STEP_H '0186'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 192
-            trigger ../../prod/192/prodwave eq complete and ( ./186/diss:pdb or ./186 eq complete)
-            edit EMOS_TIME_STEP_H '0192'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 198
-            trigger ../../prod/198/prodwave eq complete and ( ./192/diss:pdb or ./192 eq complete)
-            edit EMOS_TIME_STEP_H '0198'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 204
-            trigger ../../prod/204/prodwave eq complete and ( ./198/diss:pdb or ./198 eq complete)
-            edit EMOS_TIME_STEP_H '0204'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 210
-            trigger ../../prod/210/prodwave eq complete and ( ./204/diss:pdb or ./204 eq complete)
-            edit EMOS_TIME_STEP_H '0210'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 216
-            trigger ../../prod/216/prodwave eq complete and ( ./210/diss:pdb or ./210 eq complete)
-            edit EMOS_TIME_STEP_H '0216'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 222
-            trigger ../../prod/222/prodwave eq complete and ( ./216/diss:pdb or ./216 eq complete)
-            edit EMOS_TIME_STEP_H '0222'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 228
-            trigger ../../prod/228/prodwave eq complete and ( ./222/diss:pdb or ./222 eq complete)
-            edit EMOS_TIME_STEP_H '0228'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 234
-            trigger ../../prod/234/prodwave eq complete and ( ./228/diss:pdb or ./228 eq complete)
-            edit EMOS_TIME_STEP_H '0234'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 240
-            trigger ../../prod/240/prodwave eq complete and ( ./234/diss:pdb or ./234 eq complete)
-            edit EMOS_TIME_STEP_H '0240'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          task check
-            trigger ./240 eq complete
-        endfamily
-      endfamily
-    endfamily
-    family 18bc
-      trigger ( ./make eq complete) and ( /e_36r1/main/12/fc eq complete)
-      edit EMOS_BASE '18'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '0'
-      edit ACCOUNT 'opebcpg'
-      edit SMSURL 'GSCDA/18'
-      edit USER_PRIORITY '91'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/ex18/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete
-        family prepare_obs
-          trigger ./get eq complete
-          task preobs
-            trigger /e_36r1/main/00dc/an/update_psbias eq complete and /e_36r1/main/00dc/an/update_rstrhbias eq complete
-            edit mode 'not1crad'
-            edit REINITIALIZE 'true'
-            edit REINIPERIOD_4D '6'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-        family reservation
-          late -c +00:03
-          trigger ./get/get_stor eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task adv_res
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '30'
-            edit RESERVE_IN '11'
-            edit RESERVED_NODES '32'
-            edit RESERVATION_LABEL 'emos18A'
-            label info ""
-          task loadl_cycle_limit
-            late -s +00:03 -c +00:02
-            edit LOADL_CYCLE '65'
-            label info ""
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit PERIOD_4D '6'
-        edit WINDOW_LENGTH_4D '6'
-        edit WINDOW_OFFSET_4D '3'
-        edit ACCOUNT 'opebcan'
-        edit REINITIALIZE 'true'
-        edit ANNPES '144'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          trigger ( ../../12/fc/model:step ge 9 or ../../12/fc/model eq complete)
-          event hires
-        task fetcherr
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '2432'
-            edit RESERVE_FOR '35'
-            label info ""
-          task rm_res
-            late -s +00:03 -c +00:02
-            edit RESERVATION_LABEL 'emos18A'
-            label info ""
-        endfamily
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit ACCOUNT 'opebcfc'
-        edit REINITIALIZE 'true'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task getpersSST
-          trigger getfcdata eq complete
-          edit SSTLEN '90'
-          edit SSTINT '1'
-          edit THREADS '2'
-          edit NPES '16'
-          edit MEM '1000'
-          edit CPUTIME '960'
-        task model
-          late -s +00:02
-          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
-          edit PERSST 'true'
-          edit FCLENGTH '90'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          edit FCNPES '144'
-          meter step -1 90 90
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./getfcdata eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '3072'
-            edit RESERVE_FOR '20'
-            label info ""
-        endfamily
-        family reservation2
-          late -c +00:03
-          trigger ./model eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reset_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '0'
-            label info ""
-        endfamily
-      endfamily
-      family getreq
-        trigger ( /e_36r1/main/18bc/an/4dvar eq active or /e_36r1/main/18bc/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit PROD_TASK '1'
-        edit EMOS_DOMAIN 'G'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_PROJECT '12'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'SCDA'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '18'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger collectreq eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete and ( req:001 or req eq complete)
-          label info ""
-          event 1 
-      endfamily
-      family prod
-        trigger ( getreq/req:001 or getreq/req eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit EMOS_PROJECT '12'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        family an
-          trigger /e_36r1/main/18bc/an/surf_anal eq complete and ( /e_36r1/main/18bc/an/4dvar/ifstraj:finalwave or /e_36r1/main/18bc/an/4dvar/ifstraj eq complete) and 0 eq 0
-          edit EMOS_TYPE 'an'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ../090/prodgen eq complete and ( /e_36r1/main/18bc/fc/model:step ge 12 or /e_36r1/main/18bc/fc/model eq complete)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 000
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 000 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0000'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 12 or /e_36r1/main/18bc/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '000'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 003
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 003 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 15 or /e_36r1/main/18bc/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '003'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 006
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 006 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 18 or /e_36r1/main/18bc/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '006'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 009
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 009 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 21 or /e_36r1/main/18bc/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '009'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 012
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 012 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 24 or /e_36r1/main/18bc/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '012'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 015
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 015 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 27 or /e_36r1/main/18bc/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '015'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 018
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 018 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 30 or /e_36r1/main/18bc/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '018'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 021
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 021 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 33 or /e_36r1/main/18bc/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '021'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 024
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 024 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 36 or /e_36r1/main/18bc/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '024'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 027
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 027 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 39 or /e_36r1/main/18bc/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '027'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 030
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 030 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 42 or /e_36r1/main/18bc/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '030'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 033
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 033 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 45 or /e_36r1/main/18bc/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '033'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 036
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 036 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0036'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 48 or /e_36r1/main/18bc/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '036'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 039
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 039 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0039'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 51 or /e_36r1/main/18bc/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '039'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 042
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 042 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0042'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 54 or /e_36r1/main/18bc/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '042'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 045
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 045 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0045'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 57 or /e_36r1/main/18bc/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '045'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 048
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 048 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0048'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 60 or /e_36r1/main/18bc/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '048'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 051
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 051 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0051'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 63 or /e_36r1/main/18bc/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '051'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 054
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 054 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0054'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 66 or /e_36r1/main/18bc/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '054'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 057
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 057 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0057'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 69 or /e_36r1/main/18bc/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '057'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 060
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 060 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0060'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 72 or /e_36r1/main/18bc/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '060'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 063
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 063 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0063'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 75 or /e_36r1/main/18bc/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '063'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 066
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 066 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0066'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 78 or /e_36r1/main/18bc/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '066'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 069
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 069 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0069'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 81 or /e_36r1/main/18bc/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '069'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 072
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 072 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0072'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 84 or /e_36r1/main/18bc/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '072'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 075
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 075 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0075'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 87 or /e_36r1/main/18bc/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '075'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 078
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 078 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0078'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/18bc/fc/model:step ge 90 or /e_36r1/main/18bc/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '078'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 081
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 081 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0081'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '081'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 084
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 084 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0084'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '084'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 087
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 087 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0087'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '087'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 090
-          trigger ( /e_36r1/main/18bc/fc/model:step ge 090 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0090'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '090'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        task operation_is_late
-          event yes
-        family oper
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '92'
-          edit SMSURL 'GSCDA/18'
-          edit EMOS_PROJECT '12'
-          family an
-            task pdb
-              trigger ../../../prod/an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event 1 
-          endfamily
-          family 000
-            edit EMOS_TIME_STEP_H '0000'
-            task pdb
-              trigger ../../../prod/000/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ../an/q2diss eq complete
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 003
-            edit EMOS_TIME_STEP_H '0003'
-            task pdb
-              trigger ../../../prod/003/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/003/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 006
-            edit EMOS_TIME_STEP_H '0006'
-            task pdb
-              trigger ../../../prod/006/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/006/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 009
-            edit EMOS_TIME_STEP_H '0009'
-            task pdb
-              trigger ../../../prod/009/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/009/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 012
-            edit EMOS_TIME_STEP_H '0012'
-            task pdb
-              trigger ../../../prod/012/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/012/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 015
-            edit EMOS_TIME_STEP_H '0015'
-            task pdb
-              trigger ../../../prod/015/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/015/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 018
-            edit EMOS_TIME_STEP_H '0018'
-            task pdb
-              trigger ../../../prod/018/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/018/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 021
-            edit EMOS_TIME_STEP_H '0021'
-            task pdb
-              trigger ../../../prod/021/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/021/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 024
-            edit EMOS_TIME_STEP_H '0024'
-            task pdb
-              trigger ../../../prod/024/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/024/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 027
-            edit EMOS_TIME_STEP_H '0027'
-            task pdb
-              trigger ../../../prod/027/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/027/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 030
-            edit EMOS_TIME_STEP_H '0030'
-            task pdb
-              trigger ../../../prod/030/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/030/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 033
-            edit EMOS_TIME_STEP_H '0033'
-            task pdb
-              trigger ../../../prod/033/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/033/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 036
-            edit EMOS_TIME_STEP_H '0036'
-            task pdb
-              trigger ../../../prod/036/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/036/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 039
-            edit EMOS_TIME_STEP_H '0039'
-            task pdb
-              trigger ../../../prod/039/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/039/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 042
-            edit EMOS_TIME_STEP_H '0042'
-            task pdb
-              trigger ../../../prod/042/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/042/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 045
-            edit EMOS_TIME_STEP_H '0045'
-            task pdb
-              trigger ../../../prod/045/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/045/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 048
-            edit EMOS_TIME_STEP_H '0048'
-            task pdb
-              trigger ../../../prod/048/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/048/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 051
-            edit EMOS_TIME_STEP_H '0051'
-            task pdb
-              trigger ../../../prod/051/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/051/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 054
-            edit EMOS_TIME_STEP_H '0054'
-            task pdb
-              trigger ../../../prod/054/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/054/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 057
-            edit EMOS_TIME_STEP_H '0057'
-            task pdb
-              trigger ../../../prod/057/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/057/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 060
-            edit EMOS_TIME_STEP_H '0060'
-            task pdb
-              trigger ../../../prod/060/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/060/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 063
-            edit EMOS_TIME_STEP_H '0063'
-            task pdb
-              trigger ../../../prod/063/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/063/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 066
-            edit EMOS_TIME_STEP_H '0066'
-            task pdb
-              trigger ../../../prod/066/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/066/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 069
-            edit EMOS_TIME_STEP_H '0069'
-            task pdb
-              trigger ../../../prod/069/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/069/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 072
-            edit EMOS_TIME_STEP_H '0072'
-            task pdb
-              trigger ../../../prod/072/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/072/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 075
-            edit EMOS_TIME_STEP_H '0075'
-            task pdb
-              trigger ../../../prod/075/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/075/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 078
-            edit EMOS_TIME_STEP_H '0078'
-            task pdb
-              trigger ../../../prod/078/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/078/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 081
-            edit EMOS_TIME_STEP_H '0081'
-            task pdb
-              trigger ../../../prod/081/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 084
-            edit EMOS_TIME_STEP_H '0084'
-            task pdb
-              trigger ../../../prod/084/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 087
-            edit EMOS_TIME_STEP_H '0087'
-            task pdb
-              trigger ../../../prod/087/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 090
-            edit EMOS_TIME_STEP_H '0090'
-            task pdb
-              trigger ../../../prod/090/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          task check
-            trigger ./078 eq complete
-        endfamily
-      endfamily
-    endfamily
-    family 12dc
-      trigger make eq complete
-      edit EMOS_BASE '12'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/dc12/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc12/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc12/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        family getplus6
-          edit EMOS_BASE '18'
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/dc18/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/dc18/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/dc18/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete and ./getplus6 eq complete
-        family prepare_obs
-          trigger ./get eq complete and ./getplus6 eq complete
-          task preobs
-            trigger /e_36r1/main/00dc/an/update_psbias eq complete and /e_36r1/main/00dc/an/update_rstrhbias eq complete
-            edit mode 'not1crad'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-        family reservation
-          late -c +00:03
-          trigger ./get/get_stor eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task adv_res
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '30'
-            edit RESERVE_IN '30'
-            edit RESERVED_NODES '48'
-            edit RESERVATION_LABEL 'emos12dcA'
-            label info ""
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit PERIOD_4D '12'
-        edit WINDOW_LENGTH_4D '12'
-        edit WINDOW_OFFSET_4D '3'
-        edit ACCOUNT 'oedcdaan'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          trigger ( ../../00dc/fc/model:step ge 9 or ../../00dc/fc/model eq complete)
-          event hires
-        task fetcherr
-          trigger ../../00dc/an eq complete
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-        task emiskf
-          trigger ./4dvar/uptraj_0/ifstraj eq complete
-          edit THREADS '1'
-        task update_psbias
-          trigger ./4dvar/ifstraj:finalwave
-        task update_rstrhbias
-          trigger ./4dvar/ifstraj:finalwave
-        task dcda_to_da
-          trigger ./4dvar eq complete and surf_anal eq complete
-          edit EMOS_TYPE 'an'
-          edit OPHOST 'c1b'
-        family reservation1
-          late -c +00:03
-          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:02 -c +00:02
-            edit RESERVED_CPUS '3328'
-            edit RESERVE_FOR '65'
-            label info ""
-          task rm_res
-            late -s +00:02 -c +00:02
-            edit RESERVATION_LABEL 'emos12'
-            label info ""
-          task set_class
-            late -s +00:02 -c +00:02
-            edit RESERVATION_DEFINITION 'default_nodiag'
-            label info ""
-        endfamily
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit EMOS_BASE '18'
-        edit ACCOUNT 'oedcdafc'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task model
-          late -s +00:02
-          trigger getfcdata eq complete
-          edit FCLENGTH '15'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          meter step -1 15 15
-        task ddh
-          trigger model eq complete
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete and ../../12/fc eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./getfcdata eq active or ./getfcdata eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '3072'
-            edit RESERVE_FOR '4'
-            label info ""
-        endfamily
-        family reservation2
-          late -c +00:03
-          trigger ./model eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reset_cpu
-            late -s +00:03 -c +00:02
-            complete /e_36r1/main/00/an/vardata eq active or /e_36r1/main/00/an/vardata eq complete
-            edit RESERVED_CPUS '0'
-            label info ""
-        endfamily
-      endfamily
-    endfamily
-    family 18
-      trigger make eq complete
-      edit EMOS_BASE '18'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DA'
-      edit LAR_4V_EF 'false'
-      edit LFC_DIR_FREQ 'false'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/ex18/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex18/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex18/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete
-        family prepare_obs
-          trigger ./get eq complete
-          task preobs
-            edit mode 'not1crad'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-        family reservation
-          late -c +00:03
-          trigger ./get/get_stor eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit ACCOUNT 'oeoperan'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          trigger ../../12dc/fc/model:step ge 6 or ../../12dc/fc/model eq complete
-          event hires
-        task fetcherr
-          trigger ../../12dc/an eq complete
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-        endfamily
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit ACCOUNT 'oeoperfc'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task getpersSST
-          trigger getfcdata eq complete
-          edit SSTLEN '9'
-          edit SSTINT '1'
-          edit THREADS '2'
-          edit NPES '16'
-          edit MEM '1000'
-          edit CPUTIME '960'
-        task model
-          late -s +00:02
-          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
-          edit PERSST 'true'
-          edit FCLENGTH '9'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          meter step -1 9 9
-        task ddh
-          trigger model eq complete
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete
-        family reservation1
-          late -c +00:03
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-        endfamily
-      endfamily
-    endfamily
-    family 00bc
-      edit EMOS_BASE '00'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '1'
-      edit ACCOUNT 'opebcpg'
-      edit SMSURL 'GSCDA/00'
-      edit USER_PRIORITY '91'
-      family getreq
-        trigger ( /e_36r1/main/00/an/4dvar eq active or /e_36r1/main/00/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit PROD_TASK '1'
-        edit EMOS_DOMAIN 'G'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_PROJECT '12'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'SCDA'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '00'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger collectreq eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete and ( req:001 or req eq complete)
-          label info ""
-          event 1 
-      endfamily
-      family prod
-        trigger ( getreq/req:001 or getreq/req eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit EMOS_PROJECT '12'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit EMOS_BASE '00'
-        family an
-          trigger /e_36r1/main/00/an/surf_anal eq complete and ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar/ifstraj eq complete) and 0 eq 0
-          edit EMOS_TYPE 'an'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ../090/prodgen eq complete and ../../prod eq queued and /e_36r1/main/00/prod eq complete
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 000
-          trigger ( /e_36r1/main/00/fc/model:step ge 000 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0000'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 12 or /e_36r1/main/00/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 003
-          trigger ( /e_36r1/main/00/fc/model:step ge 003 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 15 or /e_36r1/main/00/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 006
-          trigger ( /e_36r1/main/00/fc/model:step ge 006 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 18 or /e_36r1/main/00/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 009
-          trigger ( /e_36r1/main/00/fc/model:step ge 009 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 21 or /e_36r1/main/00/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 012
-          trigger ( /e_36r1/main/00/fc/model:step ge 012 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 24 or /e_36r1/main/00/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 015
-          trigger ( /e_36r1/main/00/fc/model:step ge 015 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 27 or /e_36r1/main/00/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 018
-          trigger ( /e_36r1/main/00/fc/model:step ge 018 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 30 or /e_36r1/main/00/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 021
-          trigger ( /e_36r1/main/00/fc/model:step ge 021 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 33 or /e_36r1/main/00/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 024
-          trigger ( /e_36r1/main/00/fc/model:step ge 024 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 36 or /e_36r1/main/00/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 027
-          trigger ( /e_36r1/main/00/fc/model:step ge 027 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 39 or /e_36r1/main/00/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 030
-          trigger ( /e_36r1/main/00/fc/model:step ge 030 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 42 or /e_36r1/main/00/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 033
-          trigger ( /e_36r1/main/00/fc/model:step ge 033 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 45 or /e_36r1/main/00/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 036
-          trigger ( /e_36r1/main/00/fc/model:step ge 036 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0036'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 48 or /e_36r1/main/00/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 039
-          trigger ( /e_36r1/main/00/fc/model:step ge 039 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0039'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 51 or /e_36r1/main/00/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 042
-          trigger ( /e_36r1/main/00/fc/model:step ge 042 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0042'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 54 or /e_36r1/main/00/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 045
-          trigger ( /e_36r1/main/00/fc/model:step ge 045 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0045'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 57 or /e_36r1/main/00/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 048
-          trigger ( /e_36r1/main/00/fc/model:step ge 048 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0048'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 60 or /e_36r1/main/00/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 051
-          trigger ( /e_36r1/main/00/fc/model:step ge 051 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0051'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 63 or /e_36r1/main/00/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 054
-          trigger ( /e_36r1/main/00/fc/model:step ge 054 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0054'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 66 or /e_36r1/main/00/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 057
-          trigger ( /e_36r1/main/00/fc/model:step ge 057 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0057'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 69 or /e_36r1/main/00/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 060
-          trigger ( /e_36r1/main/00/fc/model:step ge 060 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0060'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 72 or /e_36r1/main/00/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 063
-          trigger ( /e_36r1/main/00/fc/model:step ge 063 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0063'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 75 or /e_36r1/main/00/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 066
-          trigger ( /e_36r1/main/00/fc/model:step ge 066 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0066'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 78 or /e_36r1/main/00/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 069
-          trigger ( /e_36r1/main/00/fc/model:step ge 069 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0069'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 81 or /e_36r1/main/00/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 072
-          trigger ( /e_36r1/main/00/fc/model:step ge 072 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0072'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 84 or /e_36r1/main/00/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 075
-          trigger ( /e_36r1/main/00/fc/model:step ge 075 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0075'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 87 or /e_36r1/main/00/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 078
-          trigger ( /e_36r1/main/00/fc/model:step ge 078 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0078'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/00/fc/model:step ge 90 or /e_36r1/main/00/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-        endfamily
-        family 081
-          trigger ( /e_36r1/main/00/fc/model:step ge 081 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0081'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-        family 084
-          trigger ( /e_36r1/main/00/fc/model:step ge 084 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0084'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-        family 087
-          trigger ( /e_36r1/main/00/fc/model:step ge 087 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0087'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-        family 090
-          trigger ( /e_36r1/main/00/fc/model:step ge 090 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0090'
-          task prodgen
-            late -s +00:05 -c +00:15
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        task operation_is_late
-          event yes
-        family oper
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '92'
-          edit SMSURL 'GSCDA/00'
-          edit EMOS_BASE '00'
-          edit EMOS_PROJECT '12'
-          family an
-            task pdb
-              trigger ../../../prod/an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event 1 
-          endfamily
-          family 000
-            edit EMOS_TIME_STEP_H '0000'
-            task pdb
-              trigger ../../../prod/000/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ../an/q2diss eq complete
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 003
-            edit EMOS_TIME_STEP_H '0003'
-            task pdb
-              trigger ../../../prod/003/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/003/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 006
-            edit EMOS_TIME_STEP_H '0006'
-            task pdb
-              trigger ../../../prod/006/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/006/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 009
-            edit EMOS_TIME_STEP_H '0009'
-            task pdb
-              trigger ../../../prod/009/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/009/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 012
-            edit EMOS_TIME_STEP_H '0012'
-            task pdb
-              trigger ../../../prod/012/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/012/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 015
-            edit EMOS_TIME_STEP_H '0015'
-            task pdb
-              trigger ../../../prod/015/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/015/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 018
-            edit EMOS_TIME_STEP_H '0018'
-            task pdb
-              trigger ../../../prod/018/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/018/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 021
-            edit EMOS_TIME_STEP_H '0021'
-            task pdb
-              trigger ../../../prod/021/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/021/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 024
-            edit EMOS_TIME_STEP_H '0024'
-            task pdb
-              trigger ../../../prod/024/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/024/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 027
-            edit EMOS_TIME_STEP_H '0027'
-            task pdb
-              trigger ../../../prod/027/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/027/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 030
-            edit EMOS_TIME_STEP_H '0030'
-            task pdb
-              trigger ../../../prod/030/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/030/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 033
-            edit EMOS_TIME_STEP_H '0033'
-            task pdb
-              trigger ../../../prod/033/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/033/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 036
-            edit EMOS_TIME_STEP_H '0036'
-            task pdb
-              trigger ../../../prod/036/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/036/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 039
-            edit EMOS_TIME_STEP_H '0039'
-            task pdb
-              trigger ../../../prod/039/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/039/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 042
-            edit EMOS_TIME_STEP_H '0042'
-            task pdb
-              trigger ../../../prod/042/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/042/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 045
-            edit EMOS_TIME_STEP_H '0045'
-            task pdb
-              trigger ../../../prod/045/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/045/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 048
-            edit EMOS_TIME_STEP_H '0048'
-            task pdb
-              trigger ../../../prod/048/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/048/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 051
-            edit EMOS_TIME_STEP_H '0051'
-            task pdb
-              trigger ../../../prod/051/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/051/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 054
-            edit EMOS_TIME_STEP_H '0054'
-            task pdb
-              trigger ../../../prod/054/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/054/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 057
-            edit EMOS_TIME_STEP_H '0057'
-            task pdb
-              trigger ../../../prod/057/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/057/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 060
-            edit EMOS_TIME_STEP_H '0060'
-            task pdb
-              trigger ../../../prod/060/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/060/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 063
-            edit EMOS_TIME_STEP_H '0063'
-            task pdb
-              trigger ../../../prod/063/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/063/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 066
-            edit EMOS_TIME_STEP_H '0066'
-            task pdb
-              trigger ../../../prod/066/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/066/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 069
-            edit EMOS_TIME_STEP_H '0069'
-            task pdb
-              trigger ../../../prod/069/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/069/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 072
-            edit EMOS_TIME_STEP_H '0072'
-            task pdb
-              trigger ../../../prod/072/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/072/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 075
-            edit EMOS_TIME_STEP_H '0075'
-            task pdb
-              trigger ../../../prod/075/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/075/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 078
-            edit EMOS_TIME_STEP_H '0078'
-            task pdb
-              trigger ../../../prod/078/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/078/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 081
-            edit EMOS_TIME_STEP_H '0081'
-            task pdb
-              trigger ../../../prod/081/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 084
-            edit EMOS_TIME_STEP_H '0084'
-            task pdb
-              trigger ../../../prod/084/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 087
-            edit EMOS_TIME_STEP_H '0087'
-            task pdb
-              trigger ../../../prod/087/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 090
-            edit EMOS_TIME_STEP_H '0090'
-            task pdb
-              trigger ../../../prod/090/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          task check
-            trigger ./078 eq complete
-        endfamily
-      endfamily
-    endfamily
-    family 00
-      trigger make eq complete
-      edit EMOS_BASE '00'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '1'
-      edit ACCOUNT 'oeoperpg'
-      edit SMSURL 'GOPER/00'
-      edit USER_PRIORITY '90'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/ex00/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex00/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex00/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete
-        family prepare_obs
-          trigger ./get eq complete
-          task preobs
-            trigger /e_36r1/main/12dc/an/update_psbias eq complete and /e_36r1/main/12dc/an/update_rstrhbias eq complete
-            edit mode 'not1crad'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-        family reservation
-          late -c +00:03
-          trigger ./get/get_stor eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task adv_res
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '40'
-            edit RESERVE_IN '60'
-            edit RESERVED_NODES '24'
-            edit RESERVATION_LABEL 'emos00XP'
-            label info ""
-          task adv_resA
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '100'
-            edit RESERVE_IN '11'
-            edit RESERVED_NODES '48'
-            edit RESERVATION_LABEL 'emos00A'
-            label info ""
-          task adv_resB
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '30'
-            edit RESERVE_IN '48'
-            edit RESERVED_NODES '48'
-            edit RESERVATION_LABEL 'emos00B'
-            label info ""
-          task adv_resC
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '80'
-            edit RESERVE_IN '60'
-            edit RESERVED_NODES '120'
-            edit RESERVATION_LABEL 'emos00C'
-            label info ""
-          task loadl_cycle_limit
-            late -s +00:03 -c +00:02
-            edit LOADL_CYCLE '65'
-            label info ""
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit PERIOD_4D '6'
-        edit WINDOW_LENGTH_4D '6'
-        edit WINDOW_OFFSET_4D '3'
-        edit ACCOUNT 'oeoperan'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          trigger ( ../../12dc/fc/model:step ge 6 or ../../12dc/fc/model eq complete) and ../../18/an eq complete
-          event hires
-        task fetcherr
-          trigger ../../18/an eq complete and ../../12dc/an eq complete
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '3072'
-            edit RESERVE_FOR '100'
-            label info ""
-          task rm_res
-            late -s +00:03 -c +00:02
-            edit RESERVATION_LABEL 'emos00A'
-            label info ""
-          task ms_cpu
-            late -s +00:03 -c +00:02
-            edit MS_CPUS '$((64*30))'
-            label info ""
-        endfamily
-        family reservation3
-          late -c +00:03
-          trigger ./4dvar/uptraj_1 eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task set_class
-            late -s +00:03 -c +00:02
-            edit RESERVATION_DEFINITION 'default'
-            label info ""
-        endfamily
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit ACCOUNT 'oeoperfc'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task getpersSST
-          trigger getfcdata eq complete
-          edit SSTLEN '240'
-          edit SSTINT '1'
-          edit THREADS '2'
-          edit NPES '16'
-          edit MEM '1000'
-          edit CPUTIME '960'
-        task model
-          late -s +00:02
-          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
-          edit PERSST 'true'
-          edit FCLENGTH '240'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          meter step -1 240 240
-        task ddh
-          trigger model eq complete
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete and ../../12dc/fc eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./getfcdata eq active or ./getfcdata eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          family xp
-            task set_xp
-              late -s +00:03 -c +00:02
-              edit RESERVATION_LABEL 'emos00XP'
-              label info ""
-            task rm_res
-              late -s +00:03 -c +00:02
-              trigger ./set_xp eq complete
-              edit RESERVATION_LABEL 'emos00XP'
-              label info ""
-          endfamily
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '12160'
-            edit RESERVE_FOR '2'
-            label info ""
-          task rm_res
-            late -s +00:03 -c +00:02
-            edit RESERVATION_LABEL 'emos00B'
-            label info ""
-        endfamily
-      endfamily
-      family getreq
-        trigger ( /e_36r1/main/00/an/4dvar eq active or /e_36r1/main/00/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit PROD_TASK '1'
-        edit EMOS_DOMAIN 'G'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_PROJECT '12'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'OPER'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '00'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger collectreq eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete and ( req:001 or req eq complete)
-          label info ""
-          event 1 
-        task collectwave
-          trigger ./collectbitmap eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '00'
-          edit EMOS_STREAM 'WAVE'
-        task wavereq
-          late -s +00:03 -c +00:10
-          trigger ./collectwave eq complete
-          edit EMOS_STREAM 'WAVE'
-          label info ""
-          event 1 
-        task pgclima
-          late -s +00:03 -c +00:10
-          event 1 
-      endfamily
-      family prod
-        trigger ( getreq/req:001 or getreq/req eq complete) and ( getreq/bitmap:001 or getreq/bitmap eq complete) and ( getreq/wavereq:001 or getreq/wavereq eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit EMOS_PROJECT '12'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit EMOS_BASE '00'
-        family 18an
-          trigger /e_36r1/main/12dc/an/dcda_to_da eq complete
-          edit EMOS_TYPE 'an'
-          edit EMOS_BASE '18'
-          edit DELTA_DAY '0'
-          edit SMSURL 'GOPER/18'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 00an
-          trigger /e_36r1/main/00/an/surf_anal eq complete and ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar/ifstraj eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TYPE 'an'
-          edit PGNPES '90'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ( ./derived_param:SMOS or ./derived_param eq complete) and ( ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar/ifstraj eq complete))
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 000
-          trigger ( /e_36r1/main/00/fc/model:step ge 000 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0000'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '000'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 003
-          trigger ( /e_36r1/main/00/fc/model:step ge 003 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '003'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 006
-          trigger ( /e_36r1/main/00/fc/model:step ge 006 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '006'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 009
-          trigger ( /e_36r1/main/00/fc/model:step ge 009 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '009'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 012
-          trigger ( /e_36r1/main/00/fc/model:step ge 012 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '012'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 015
-          trigger ( /e_36r1/main/00/fc/model:step ge 015 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '015'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 018
-          trigger ( /e_36r1/main/00/fc/model:step ge 018 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '018'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 021
-          trigger ( /e_36r1/main/00/fc/model:step ge 021 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '021'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 024
-          trigger ( /e_36r1/main/00/fc/model:step ge 024 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '024'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 027
-          trigger ( /e_36r1/main/00/fc/model:step ge 027 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '027'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 030
-          trigger ( /e_36r1/main/00/fc/model:step ge 030 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '030'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 033
-          trigger ( /e_36r1/main/00/fc/model:step ge 033 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '033'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 036
-          trigger ( /e_36r1/main/00/fc/model:step ge 036 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0036'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '036'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 039
-          trigger ( /e_36r1/main/00/fc/model:step ge 039 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0039'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '039'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 042
-          trigger ( /e_36r1/main/00/fc/model:step ge 042 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0042'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '042'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 045
-          trigger ( /e_36r1/main/00/fc/model:step ge 045 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0045'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '045'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 048
-          trigger ( /e_36r1/main/00/fc/model:step ge 048 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0048'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '048'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 051
-          trigger ( /e_36r1/main/00/fc/model:step ge 051 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0051'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '051'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 054
-          trigger ( /e_36r1/main/00/fc/model:step ge 054 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0054'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '054'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 057
-          trigger ( /e_36r1/main/00/fc/model:step ge 057 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0057'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '057'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 060
-          trigger ( /e_36r1/main/00/fc/model:step ge 060 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0060'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '060'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 063
-          trigger ( /e_36r1/main/00/fc/model:step ge 063 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0063'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '063'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 066
-          trigger ( /e_36r1/main/00/fc/model:step ge 066 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0066'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '066'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 069
-          trigger ( /e_36r1/main/00/fc/model:step ge 069 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0069'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '069'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 072
-          trigger ( /e_36r1/main/00/fc/model:step ge 072 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0072'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '072'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 075
-          trigger ( /e_36r1/main/00/fc/model:step ge 075 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0075'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '075'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 078
-          trigger ( /e_36r1/main/00/fc/model:step ge 078 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0078'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '078'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 081
-          trigger ( /e_36r1/main/00/fc/model:step ge 081 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0081'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '081'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 084
-          trigger ( /e_36r1/main/00/fc/model:step ge 084 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0084'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '084'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 087
-          trigger ( /e_36r1/main/00/fc/model:step ge 087 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0087'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '087'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 090
-          trigger ( /e_36r1/main/00/fc/model:step ge 090 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0090'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '090'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 093
-          trigger ( /e_36r1/main/00/fc/model:step ge 093 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0093'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../090/derived_param:SMOS or ../090/derived_param eq complete) or ( ../090/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '093'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 096
-          trigger ( /e_36r1/main/00/fc/model:step ge 096 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0096'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../093/derived_param:SMOS or ../093/derived_param eq complete) or ( ../093/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '096'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 099
-          trigger ( /e_36r1/main/00/fc/model:step ge 099 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0099'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../096/derived_param:SMOS or ../096/derived_param eq complete) or ( ../096/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '099'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 102
-          trigger ( /e_36r1/main/00/fc/model:step ge 102 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0102'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../099/derived_param:SMOS or ../099/derived_param eq complete) or ( ../099/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '102'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 105
-          trigger ( /e_36r1/main/00/fc/model:step ge 105 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0105'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../102/derived_param:SMOS or ../102/derived_param eq complete) or ( ../102/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '105'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 108
-          trigger ( /e_36r1/main/00/fc/model:step ge 108 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0108'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../105/derived_param:SMOS or ../105/derived_param eq complete) or ( ../105/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '108'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 111
-          trigger ( /e_36r1/main/00/fc/model:step ge 111 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0111'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../108/derived_param:SMOS or ../108/derived_param eq complete) or ( ../108/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '111'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 114
-          trigger ( /e_36r1/main/00/fc/model:step ge 114 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0114'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../111/derived_param:SMOS or ../111/derived_param eq complete) or ( ../111/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '114'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 117
-          trigger ( /e_36r1/main/00/fc/model:step ge 117 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0117'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../114/derived_param:SMOS or ../114/derived_param eq complete) or ( ../114/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '117'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 120
-          trigger ( /e_36r1/main/00/fc/model:step ge 120 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0120'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../117/derived_param:SMOS or ../117/derived_param eq complete) or ( ../117/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '120'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 123
-          trigger ( /e_36r1/main/00/fc/model:step ge 123 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0123'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../120/derived_param:SMOS or ../120/derived_param eq complete) or ( ../120/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '123'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 126
-          trigger ( /e_36r1/main/00/fc/model:step ge 126 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0126'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../123/derived_param:SMOS or ../123/derived_param eq complete) or ( ../123/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '126'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 129
-          trigger ( /e_36r1/main/00/fc/model:step ge 129 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0129'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../126/derived_param:SMOS or ../126/derived_param eq complete) or ( ../126/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '129'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 132
-          trigger ( /e_36r1/main/00/fc/model:step ge 132 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0132'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../129/derived_param:SMOS or ../129/derived_param eq complete) or ( ../129/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '132'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 135
-          trigger ( /e_36r1/main/00/fc/model:step ge 135 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0135'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../132/derived_param:SMOS or ../132/derived_param eq complete) or ( ../132/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '135'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 138
-          trigger ( /e_36r1/main/00/fc/model:step ge 138 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0138'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../135/derived_param:SMOS or ../135/derived_param eq complete) or ( ../135/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '138'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 141
-          trigger ( /e_36r1/main/00/fc/model:step ge 141 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0141'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../138/derived_param:SMOS or ../138/derived_param eq complete) or ( ../138/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '141'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 144
-          trigger ( /e_36r1/main/00/fc/model:step ge 144 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0144'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../141/derived_param:SMOS or ../141/derived_param eq complete) or ( ../141/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '144'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 150
-          trigger ( /e_36r1/main/00/fc/model:step ge 150 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0150'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../144/derived_param:SMOS or ../144/derived_param eq complete) or ( ../144/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '150'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 156
-          trigger ( /e_36r1/main/00/fc/model:step ge 156 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0156'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../150/derived_param:SMOS or ../150/derived_param eq complete) or ( ../150/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '156'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 162
-          trigger ( /e_36r1/main/00/fc/model:step ge 162 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0162'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../156/derived_param:SMOS or ../156/derived_param eq complete) or ( ../156/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '162'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 168
-          trigger ( /e_36r1/main/00/fc/model:step ge 168 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0168'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../162/derived_param:SMOS or ../162/derived_param eq complete) or ( ../162/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '168'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 174
-          trigger ( /e_36r1/main/00/fc/model:step ge 174 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0174'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../168/derived_param:SMOS or ../168/derived_param eq complete) or ( ../168/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '174'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 180
-          trigger ( /e_36r1/main/00/fc/model:step ge 180 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0180'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../174/derived_param:SMOS or ../174/derived_param eq complete) or ( ../174/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '180'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 186
-          trigger ( /e_36r1/main/00/fc/model:step ge 186 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0186'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../180/derived_param:SMOS or ../180/derived_param eq complete) or ( ../180/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '186'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 192
-          trigger ( /e_36r1/main/00/fc/model:step ge 192 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0192'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../186/derived_param:SMOS or ../186/derived_param eq complete) or ( ../186/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '192'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 198
-          trigger ( /e_36r1/main/00/fc/model:step ge 198 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0198'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../192/derived_param:SMOS or ../192/derived_param eq complete) or ( ../192/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '198'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 204
-          trigger ( /e_36r1/main/00/fc/model:step ge 204 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0204'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../198/derived_param:SMOS or ../198/derived_param eq complete) or ( ../198/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '204'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 210
-          trigger ( /e_36r1/main/00/fc/model:step ge 210 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0210'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../204/derived_param:SMOS or ../204/derived_param eq complete) or ( ../204/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '210'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 216
-          trigger ( /e_36r1/main/00/fc/model:step ge 216 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0216'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../210/derived_param:SMOS or ../210/derived_param eq complete) or ( ../210/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '216'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 222
-          trigger ( /e_36r1/main/00/fc/model:step ge 222 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0222'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../216/derived_param:SMOS or ../216/derived_param eq complete) or ( ../216/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '222'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 228
-          trigger ( /e_36r1/main/00/fc/model:step ge 228 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0228'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../222/derived_param:SMOS or ../222/derived_param eq complete) or ( ../222/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '228'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 234
-          trigger ( /e_36r1/main/00/fc/model:step ge 234 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0234'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../228/derived_param:SMOS or ../228/derived_param eq complete) or ( ../228/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '234'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 240
-          trigger ( /e_36r1/main/00/fc/model:step ge 240 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
-          edit EMOS_TIME_STEP_H '0240'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '91'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task prod_wparam
-            late -s +00:05 -c +00:15
-            trigger ./derived_param eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TYPE 'wp'
-            edit PGNPES '64'
-            edit INIMEM '800'
-            inlimit /e_36r1/limits:prod
-          task prodwave
-            late -s +00:05 -c +00:15
-            edit EMOS_STREAM 'WV'
-            edit PGNPES '2'
-            inlimit /limits:prod
-            inlimit /e_36r1/limits:prod
-          task derived_param
-            trigger ( ../234/derived_param:SMOS or ../234/derived_param eq complete) or ( ../234/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '240'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family reservation1
-          late -c +00:03
-          trigger /e_36r1/main/00bc/prod/078/prodgen eq active or /e_36r1/main/00bc/prod/078/prodgen eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task set_xp
-            late -s +00:03 -c +00:02
-            edit RESERVATION_NODES '18'
-            label info ""
-        endfamily
-        family reservation2
-          late -c +00:03
-          trigger /e_36r1/main/00/prod/240/prodgen eq active or /e_36r1/main/00/prod/240/prodgen eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task set_xp
-            late -s +00:03 -c +00:02
-            edit RESERVATION_NODES '18'
-            label info ""
-        endfamily
-        family reservation3
-          late -c +00:03
-          trigger /e_36r1/main/00/prod/240/prodgen eq active or /e_36r1/main/00/prod/240/prodgen eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reset_xp
-            late -s +00:03 -c +00:02
-            trigger /emc_36r1/main/00/legB/prod eq complete
-            edit RESERVATION_NODES '0'
-            label info ""
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        task operation_is_late
-          event yes
-        family oper
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '92'
-          edit EMOS_PROJECT '12'
-          edit SMSURL 'GOPER/00'
-          edit EMOS_BASE '00'
-          family 18an
-            edit EMOS_TYPE 'an'
-            edit EMOS_BASE '18'
-            edit SMSURL 'GOPER/18'
-            edit DELTA_DAY '0'
-            task pdb
-              trigger ../../../prod/18an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 00an
-            edit EMOS_TYPE 'an'
-            task pdb
-              trigger ../../../prod/00an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 000
-            edit EMOS_TIME_STEP_H '0000'
-            task pdb
-              trigger ../../../prod/000/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../00an/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 003
-            edit EMOS_TIME_STEP_H '0003'
-            task pdb
-              trigger ../../../prod/003/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 006
-            edit EMOS_TIME_STEP_H '0006'
-            task pdb
-              trigger ../../../prod/006/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 009
-            edit EMOS_TIME_STEP_H '0009'
-            task pdb
-              trigger ../../../prod/009/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 012
-            edit EMOS_TIME_STEP_H '0012'
-            task pdb
-              trigger ../../../prod/012/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 015
-            edit EMOS_TIME_STEP_H '0015'
-            task pdb
-              trigger ../../../prod/015/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 018
-            edit EMOS_TIME_STEP_H '0018'
-            task pdb
-              trigger ../../../prod/018/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 021
-            edit EMOS_TIME_STEP_H '0021'
-            task pdb
-              trigger ../../../prod/021/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 024
-            edit EMOS_TIME_STEP_H '0024'
-            task pdb
-              trigger ../../../prod/024/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 027
-            edit EMOS_TIME_STEP_H '0027'
-            task pdb
-              trigger ../../../prod/027/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 030
-            edit EMOS_TIME_STEP_H '0030'
-            task pdb
-              trigger ../../../prod/030/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 033
-            edit EMOS_TIME_STEP_H '0033'
-            task pdb
-              trigger ../../../prod/033/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 036
-            edit EMOS_TIME_STEP_H '0036'
-            task pdb
-              trigger ../../../prod/036/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 039
-            edit EMOS_TIME_STEP_H '0039'
-            task pdb
-              trigger ../../../prod/039/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 042
-            edit EMOS_TIME_STEP_H '0042'
-            task pdb
-              trigger ../../../prod/042/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 045
-            edit EMOS_TIME_STEP_H '0045'
-            task pdb
-              trigger ../../../prod/045/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 048
-            edit EMOS_TIME_STEP_H '0048'
-            task pdb
-              trigger ../../../prod/048/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 051
-            edit EMOS_TIME_STEP_H '0051'
-            task pdb
-              trigger ../../../prod/051/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 054
-            edit EMOS_TIME_STEP_H '0054'
-            task pdb
-              trigger ../../../prod/054/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 057
-            edit EMOS_TIME_STEP_H '0057'
-            task pdb
-              trigger ../../../prod/057/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 060
-            edit EMOS_TIME_STEP_H '0060'
-            task pdb
-              trigger ../../../prod/060/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 063
-            edit EMOS_TIME_STEP_H '0063'
-            task pdb
-              trigger ../../../prod/063/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 066
-            edit EMOS_TIME_STEP_H '0066'
-            task pdb
-              trigger ../../../prod/066/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 069
-            edit EMOS_TIME_STEP_H '0069'
-            task pdb
-              trigger ../../../prod/069/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 072
-            edit EMOS_TIME_STEP_H '0072'
-            task pdb
-              trigger ../../../prod/072/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 075
-            edit EMOS_TIME_STEP_H '0075'
-            task pdb
-              trigger ../../../prod/075/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 078
-            edit EMOS_TIME_STEP_H '0078'
-            task pdb
-              trigger ../../../prod/078/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 081
-            edit EMOS_TIME_STEP_H '0081'
-            task pdb
-              trigger ../../../prod/081/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 084
-            edit EMOS_TIME_STEP_H '0084'
-            task pdb
-              trigger ../../../prod/084/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 087
-            edit EMOS_TIME_STEP_H '0087'
-            task pdb
-              trigger ../../../prod/087/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 090
-            edit EMOS_TIME_STEP_H '0090'
-            task pdb
-              trigger ../../../prod/090/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 093
-            edit EMOS_TIME_STEP_H '0093'
-            task pdb
-              trigger ../../../prod/093/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../090/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 096
-            edit EMOS_TIME_STEP_H '0096'
-            task pdb
-              trigger ../../../prod/096/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../093/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 099
-            edit EMOS_TIME_STEP_H '0099'
-            task pdb
-              trigger ../../../prod/099/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../096/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 102
-            edit EMOS_TIME_STEP_H '0102'
-            task pdb
-              trigger ../../../prod/102/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../099/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 105
-            edit EMOS_TIME_STEP_H '0105'
-            task pdb
-              trigger ../../../prod/105/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../102/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 108
-            edit EMOS_TIME_STEP_H '0108'
-            task pdb
-              trigger ../../../prod/108/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../105/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 111
-            edit EMOS_TIME_STEP_H '0111'
-            task pdb
-              trigger ../../../prod/111/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../108/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 114
-            edit EMOS_TIME_STEP_H '0114'
-            task pdb
-              trigger ../../../prod/114/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../111/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 117
-            edit EMOS_TIME_STEP_H '0117'
-            task pdb
-              trigger ../../../prod/117/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../114/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 120
-            edit EMOS_TIME_STEP_H '0120'
-            task pdb
-              trigger ../../../prod/120/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../117/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 123
-            edit EMOS_TIME_STEP_H '0123'
-            task pdb
-              trigger ../../../prod/123/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../120/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 126
-            edit EMOS_TIME_STEP_H '0126'
-            task pdb
-              trigger ../../../prod/126/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../123/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 129
-            edit EMOS_TIME_STEP_H '0129'
-            task pdb
-              trigger ../../../prod/129/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../126/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 132
-            edit EMOS_TIME_STEP_H '0132'
-            task pdb
-              trigger ../../../prod/132/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../129/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 135
-            edit EMOS_TIME_STEP_H '0135'
-            task pdb
-              trigger ../../../prod/135/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../132/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 138
-            edit EMOS_TIME_STEP_H '0138'
-            task pdb
-              trigger ../../../prod/138/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../135/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 141
-            edit EMOS_TIME_STEP_H '0141'
-            task pdb
-              trigger ../../../prod/141/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../138/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 144
-            edit EMOS_TIME_STEP_H '0144'
-            task pdb
-              trigger ../../../prod/144/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../141/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 150
-            edit EMOS_TIME_STEP_H '0150'
-            task pdb
-              trigger ../../../prod/150/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../144/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 156
-            edit EMOS_TIME_STEP_H '0156'
-            task pdb
-              trigger ../../../prod/156/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../150/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 162
-            edit EMOS_TIME_STEP_H '0162'
-            task pdb
-              trigger ../../../prod/162/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../156/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 168
-            edit EMOS_TIME_STEP_H '0168'
-            task pdb
-              trigger ../../../prod/168/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../162/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 174
-            edit EMOS_TIME_STEP_H '0174'
-            task pdb
-              trigger ../../../prod/174/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../168/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 180
-            edit EMOS_TIME_STEP_H '0180'
-            task pdb
-              trigger ../../../prod/180/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../174/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 186
-            edit EMOS_TIME_STEP_H '0186'
-            task pdb
-              trigger ../../../prod/186/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../180/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 192
-            edit EMOS_TIME_STEP_H '0192'
-            task pdb
-              trigger ../../../prod/192/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../186/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 198
-            edit EMOS_TIME_STEP_H '0198'
-            task pdb
-              trigger ../../../prod/198/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../192/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 204
-            edit EMOS_TIME_STEP_H '0204'
-            task pdb
-              trigger ../../../prod/204/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../198/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 210
-            edit EMOS_TIME_STEP_H '0210'
-            task pdb
-              trigger ../../../prod/210/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../204/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 216
-            edit EMOS_TIME_STEP_H '0216'
-            task pdb
-              trigger ../../../prod/216/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../210/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 222
-            edit EMOS_TIME_STEP_H '0222'
-            task pdb
-              trigger ../../../prod/222/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../216/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 228
-            edit EMOS_TIME_STEP_H '0228'
-            task pdb
-              trigger ../../../prod/228/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../222/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 234
-            edit EMOS_TIME_STEP_H '0234'
-            task pdb
-              trigger ../../../prod/234/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../228/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family 240
-            edit EMOS_TIME_STEP_H '0240'
-            task pdb
-              trigger ../../../prod/240/prodgen eq complete
-              inlimit /e_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../234/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-            task diss_wparam
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/240/prod_wparam eq complete
-              edit PROD_TASK 'w'
-              edit EMOS_TYPE 'wp'
-              label info ""
-              event pdb
-          endfamily
-          task check
-            trigger ./240 eq complete
-        endfamily
-        family wave
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit EMOS_PROJECT '12'
-          edit EMOS_STREAM 'WV'
-          edit SMSURL 'GWAVE/00'
-          inlimit /e_36r1/limits:w2diss
-          inlimit /limits:q2diss
-          family 18an
-            edit EMOS_TYPE 'an'
-            edit EMOS_BASE '18'
-            edit SMSURL 'GWAVE/18'
-            edit DELTA_DAY '0'
-            task diss
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/18an/prodwave eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event pdb
-          endfamily
-          family 00an
-            edit EMOS_TYPE 'an'
-            task diss
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/00an/prodwave eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event pdb
-          endfamily
-          family 000
-            trigger ../../prod/000/prodwave eq complete and ./18an eq complete and ./00an eq complete
-            edit EMOS_TIME_STEP_H '0000'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 003
-            trigger ../../prod/003/prodwave eq complete and ( ./000/diss:pdb or ./000 eq complete)
-            edit EMOS_TIME_STEP_H '0003'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 006
-            trigger ../../prod/006/prodwave eq complete and ( ./003/diss:pdb or ./003 eq complete)
-            edit EMOS_TIME_STEP_H '0006'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 009
-            trigger ../../prod/009/prodwave eq complete and ( ./006/diss:pdb or ./006 eq complete)
-            edit EMOS_TIME_STEP_H '0009'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 012
-            trigger ../../prod/012/prodwave eq complete and ( ./009/diss:pdb or ./009 eq complete)
-            edit EMOS_TIME_STEP_H '0012'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 015
-            trigger ../../prod/015/prodwave eq complete and ( ./012/diss:pdb or ./012 eq complete)
-            edit EMOS_TIME_STEP_H '0015'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 018
-            trigger ../../prod/018/prodwave eq complete and ( ./015/diss:pdb or ./015 eq complete)
-            edit EMOS_TIME_STEP_H '0018'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 021
-            trigger ../../prod/021/prodwave eq complete and ( ./018/diss:pdb or ./018 eq complete)
-            edit EMOS_TIME_STEP_H '0021'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 024
-            trigger ../../prod/024/prodwave eq complete and ( ./021/diss:pdb or ./021 eq complete)
-            edit EMOS_TIME_STEP_H '0024'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 027
-            trigger ../../prod/027/prodwave eq complete and ( ./024/diss:pdb or ./024 eq complete)
-            edit EMOS_TIME_STEP_H '0027'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 030
-            trigger ../../prod/030/prodwave eq complete and ( ./027/diss:pdb or ./027 eq complete)
-            edit EMOS_TIME_STEP_H '0030'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 033
-            trigger ../../prod/033/prodwave eq complete and ( ./030/diss:pdb or ./030 eq complete)
-            edit EMOS_TIME_STEP_H '0033'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 036
-            trigger ../../prod/036/prodwave eq complete and ( ./033/diss:pdb or ./033 eq complete)
-            edit EMOS_TIME_STEP_H '0036'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 039
-            trigger ../../prod/039/prodwave eq complete and ( ./036/diss:pdb or ./036 eq complete)
-            edit EMOS_TIME_STEP_H '0039'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 042
-            trigger ../../prod/042/prodwave eq complete and ( ./039/diss:pdb or ./039 eq complete)
-            edit EMOS_TIME_STEP_H '0042'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 045
-            trigger ../../prod/045/prodwave eq complete and ( ./042/diss:pdb or ./042 eq complete)
-            edit EMOS_TIME_STEP_H '0045'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 048
-            trigger ../../prod/048/prodwave eq complete and ( ./045/diss:pdb or ./045 eq complete)
-            edit EMOS_TIME_STEP_H '0048'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 051
-            trigger ../../prod/051/prodwave eq complete and ( ./048/diss:pdb or ./048 eq complete)
-            edit EMOS_TIME_STEP_H '0051'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 054
-            trigger ../../prod/054/prodwave eq complete and ( ./051/diss:pdb or ./051 eq complete)
-            edit EMOS_TIME_STEP_H '0054'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 057
-            trigger ../../prod/057/prodwave eq complete and ( ./054/diss:pdb or ./054 eq complete)
-            edit EMOS_TIME_STEP_H '0057'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 060
-            trigger ../../prod/060/prodwave eq complete and ( ./057/diss:pdb or ./057 eq complete)
-            edit EMOS_TIME_STEP_H '0060'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 063
-            trigger ../../prod/063/prodwave eq complete and ( ./060/diss:pdb or ./060 eq complete)
-            edit EMOS_TIME_STEP_H '0063'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 066
-            trigger ../../prod/066/prodwave eq complete and ( ./063/diss:pdb or ./063 eq complete)
-            edit EMOS_TIME_STEP_H '0066'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 069
-            trigger ../../prod/069/prodwave eq complete and ( ./066/diss:pdb or ./066 eq complete)
-            edit EMOS_TIME_STEP_H '0069'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 072
-            trigger ../../prod/072/prodwave eq complete and ( ./069/diss:pdb or ./069 eq complete)
-            edit EMOS_TIME_STEP_H '0072'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 075
-            trigger ../../prod/075/prodwave eq complete and ( ./072/diss:pdb or ./072 eq complete)
-            edit EMOS_TIME_STEP_H '0075'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 078
-            trigger ../../prod/078/prodwave eq complete and ( ./075/diss:pdb or ./075 eq complete)
-            edit EMOS_TIME_STEP_H '0078'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 081
-            trigger ../../prod/081/prodwave eq complete and ( ./078/diss:pdb or ./078 eq complete)
-            edit EMOS_TIME_STEP_H '0081'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 084
-            trigger ../../prod/084/prodwave eq complete and ( ./081/diss:pdb or ./081 eq complete)
-            edit EMOS_TIME_STEP_H '0084'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 087
-            trigger ../../prod/087/prodwave eq complete and ( ./084/diss:pdb or ./084 eq complete)
-            edit EMOS_TIME_STEP_H '0087'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 090
-            trigger ../../prod/090/prodwave eq complete and ( ./087/diss:pdb or ./087 eq complete)
-            edit EMOS_TIME_STEP_H '0090'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 093
-            trigger ../../prod/093/prodwave eq complete and ( ./090/diss:pdb or ./090 eq complete)
-            edit EMOS_TIME_STEP_H '0093'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 096
-            trigger ../../prod/096/prodwave eq complete and ( ./093/diss:pdb or ./093 eq complete)
-            edit EMOS_TIME_STEP_H '0096'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 099
-            trigger ../../prod/099/prodwave eq complete and ( ./096/diss:pdb or ./096 eq complete)
-            edit EMOS_TIME_STEP_H '0099'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 102
-            trigger ../../prod/102/prodwave eq complete and ( ./099/diss:pdb or ./099 eq complete)
-            edit EMOS_TIME_STEP_H '0102'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 105
-            trigger ../../prod/105/prodwave eq complete and ( ./102/diss:pdb or ./102 eq complete)
-            edit EMOS_TIME_STEP_H '0105'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 108
-            trigger ../../prod/108/prodwave eq complete and ( ./105/diss:pdb or ./105 eq complete)
-            edit EMOS_TIME_STEP_H '0108'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 111
-            trigger ../../prod/111/prodwave eq complete and ( ./108/diss:pdb or ./108 eq complete)
-            edit EMOS_TIME_STEP_H '0111'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 114
-            trigger ../../prod/114/prodwave eq complete and ( ./111/diss:pdb or ./111 eq complete)
-            edit EMOS_TIME_STEP_H '0114'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 117
-            trigger ../../prod/117/prodwave eq complete and ( ./114/diss:pdb or ./114 eq complete)
-            edit EMOS_TIME_STEP_H '0117'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 120
-            trigger ../../prod/120/prodwave eq complete and ( ./117/diss:pdb or ./117 eq complete)
-            edit EMOS_TIME_STEP_H '0120'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 123
-            trigger ../../prod/123/prodwave eq complete and ( ./120/diss:pdb or ./120 eq complete)
-            edit EMOS_TIME_STEP_H '0123'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 126
-            trigger ../../prod/126/prodwave eq complete and ( ./123/diss:pdb or ./123 eq complete)
-            edit EMOS_TIME_STEP_H '0126'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 129
-            trigger ../../prod/129/prodwave eq complete and ( ./126/diss:pdb or ./126 eq complete)
-            edit EMOS_TIME_STEP_H '0129'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 132
-            trigger ../../prod/132/prodwave eq complete and ( ./129/diss:pdb or ./129 eq complete)
-            edit EMOS_TIME_STEP_H '0132'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 135
-            trigger ../../prod/135/prodwave eq complete and ( ./132/diss:pdb or ./132 eq complete)
-            edit EMOS_TIME_STEP_H '0135'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 138
-            trigger ../../prod/138/prodwave eq complete and ( ./135/diss:pdb or ./135 eq complete)
-            edit EMOS_TIME_STEP_H '0138'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 141
-            trigger ../../prod/141/prodwave eq complete and ( ./138/diss:pdb or ./138 eq complete)
-            edit EMOS_TIME_STEP_H '0141'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 144
-            trigger ../../prod/144/prodwave eq complete and ( ./141/diss:pdb or ./141 eq complete)
-            edit EMOS_TIME_STEP_H '0144'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 150
-            trigger ../../prod/150/prodwave eq complete and ( ./144/diss:pdb or ./144 eq complete)
-            edit EMOS_TIME_STEP_H '0150'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 156
-            trigger ../../prod/156/prodwave eq complete and ( ./150/diss:pdb or ./150 eq complete)
-            edit EMOS_TIME_STEP_H '0156'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 162
-            trigger ../../prod/162/prodwave eq complete and ( ./156/diss:pdb or ./156 eq complete)
-            edit EMOS_TIME_STEP_H '0162'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 168
-            trigger ../../prod/168/prodwave eq complete and ( ./162/diss:pdb or ./162 eq complete)
-            edit EMOS_TIME_STEP_H '0168'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 174
-            trigger ../../prod/174/prodwave eq complete and ( ./168/diss:pdb or ./168 eq complete)
-            edit EMOS_TIME_STEP_H '0174'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 180
-            trigger ../../prod/180/prodwave eq complete and ( ./174/diss:pdb or ./174 eq complete)
-            edit EMOS_TIME_STEP_H '0180'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 186
-            trigger ../../prod/186/prodwave eq complete and ( ./180/diss:pdb or ./180 eq complete)
-            edit EMOS_TIME_STEP_H '0186'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 192
-            trigger ../../prod/192/prodwave eq complete and ( ./186/diss:pdb or ./186 eq complete)
-            edit EMOS_TIME_STEP_H '0192'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 198
-            trigger ../../prod/198/prodwave eq complete and ( ./192/diss:pdb or ./192 eq complete)
-            edit EMOS_TIME_STEP_H '0198'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 204
-            trigger ../../prod/204/prodwave eq complete and ( ./198/diss:pdb or ./198 eq complete)
-            edit EMOS_TIME_STEP_H '0204'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 210
-            trigger ../../prod/210/prodwave eq complete and ( ./204/diss:pdb or ./204 eq complete)
-            edit EMOS_TIME_STEP_H '0210'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 216
-            trigger ../../prod/216/prodwave eq complete and ( ./210/diss:pdb or ./210 eq complete)
-            edit EMOS_TIME_STEP_H '0216'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 222
-            trigger ../../prod/222/prodwave eq complete and ( ./216/diss:pdb or ./216 eq complete)
-            edit EMOS_TIME_STEP_H '0222'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 228
-            trigger ../../prod/228/prodwave eq complete and ( ./222/diss:pdb or ./222 eq complete)
-            edit EMOS_TIME_STEP_H '0228'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 234
-            trigger ../../prod/234/prodwave eq complete and ( ./228/diss:pdb or ./228 eq complete)
-            edit EMOS_TIME_STEP_H '0234'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 240
-            trigger ../../prod/240/prodwave eq complete and ( ./234/diss:pdb or ./234 eq complete)
-            edit EMOS_TIME_STEP_H '0240'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          task check
-            trigger ./240 eq complete
-        endfamily
-      endfamily
-    endfamily
-    family 06bc
-      trigger ( ( ./make eq complete) and ( /e_36r1/main/00/fc eq complete)) and ( /e_36r1/main/18bc/fc eq complete)
-      edit EMOS_BASE '06'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '1'
-      edit ACCOUNT 'opebcpg'
-      edit SMSURL 'GSCDA/06'
-      edit USER_PRIORITY '91'
-      family obs
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
-        family get
-          inlimit /e_36r1/limits:obs_get
-          inlimit /limits:obs_get
-          task get_nonbin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/nonbin eq complete
-            edit OBSFILE_OBSHOST 'BUFR'
-            edit OBSFILE_HPCF 'bufr'
-          task get_ers1_wa
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ers1_wa eq complete
-            edit OBSFILE_OBSHOST 'UWAX'
-            edit OBSFILE_HPCF 'wavescat'
-          task get_eas1
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/eas1 eq complete
-            edit OBSFILE_OBSHOST 'EAS1'
-            edit OBSFILE_HPCF 'wavesar'
-          task get_ers1_wi
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ers1_wi eq complete
-            edit OBSFILE_OBSHOST 'UWIX'
-            edit OBSFILE_HPCF 'scat'
-          task get_ers1_ra
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ers1_ra eq complete
-            edit OBSFILE_OBSHOST 'URAX'
-            edit OBSFILE_HPCF 'ralt'
-          task get_rtovs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/rtovs eq complete
-            edit OBSFILE_OBSHOST 'TOVH'
-            edit OBSFILE_HPCF 'tovh'
-          task get_ssbt
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ssbt eq complete
-            edit OBSFILE_OBSHOST 'SSBT'
-            edit OBSFILE_HPCF 'ssbt'
-          task get_sst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/sst/sst_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_atov
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/atov eq complete
-            edit OBSFILE_OBSHOST 'ATOV'
-            edit OBSFILE_HPCF 'atov'
-          task get_grad
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/grad eq complete
-            edit OBSFILE_OBSHOST 'GRAD'
-            edit OBSFILE_HPCF 'grad'
-          task get_stor
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/stor eq complete
-            edit OBSFILE_OBSHOST 'STOR'
-            edit OBSFILE_HPCF 'storm'
-          task get_trmm
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/trmm eq complete
-            edit OBSFILE_OBSHOST 'TRMM'
-            edit OBSFILE_HPCF 'tmi'
-          task get_qsca
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/qsca eq complete
-            edit OBSFILE_OBSHOST 'QSCA'
-            edit OBSFILE_HPCF 'qsca'
-          task get_sbuv
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/sbuv eq complete
-            edit OBSFILE_OBSHOST 'SBUV'
-            edit OBSFILE_HPCF 'reo3'
-          task get_airs
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/airs eq complete
-            edit OBSFILE_OBSHOST 'AIRS'
-            edit OBSFILE_HPCF 'airs'
-          task get_ice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ice/ice_fdb_c1b eq complete
-            edit OBSFILE_OBSHOST 'nil'
-            edit OBSFILE_HPCF 'nil'
-          task get_snow
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/snow eq complete
-            edit OBSFILE_OBSHOST 'SNOW'
-            edit OBSFILE_HPCF 'imssnow'
-          task get_ateu
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/ateu eq complete
-            edit OBSFILE_OBSHOST 'ATEU'
-            edit OBSFILE_HPCF 'amsu_ears'
-          task get_bice
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/bice eq complete
-            edit OBSFILE_OBSHOST 'BICE'
-            edit OBSFILE_HPCF 'baltic_ci'
-          task get_amsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/amsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AMSA'
-            edit OBSFILE_HPCF 'amsa'
-          task get_mhsa
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/mhsa eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MHSA'
-            edit OBSFILE_HPCF 'mhsa'
-          task get_hirs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/hirs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'HIRS'
-            edit OBSFILE_HPCF 'hirs'
-          task get_amsr
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/amsr eq complete
-            edit OBSFILE_OBSHOST 'AMSR'
-            edit OBSFILE_HPCF 'amsre_aq'
-          task get_rado
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/rado eq complete
-            edit OBSFILE_OBSHOST 'RADO'
-            edit OBSFILE_HPCF 'gpsro'
-          task get_smin
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/smin eq complete
-            edit OBSFILE_OBSHOST 'SMIN'
-            edit OBSFILE_HPCF 'ssmisbt'
-          task get_iasi
-            late -s +00:02 -c +00:07
-            trigger /pp2/main/extractions/ex06/iasi eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'IASI'
-            edit OBSFILE_HPCF 'iasi'
-          task get_gras
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/gras eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'GRAS'
-            edit OBSFILE_HPCF 'gras'
-          task get_modw
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/modw eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'MODW'
-            edit OBSFILE_HPCF 'dbmodiswinds'
-          task get_avhn
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/avhn eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'AVHN'
-            edit OBSFILE_HPCF 'avhrrwinds'
-          task get_atap
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/atap eq complete
-            edit OBSFILE_OBSHOST 'ATAP'
-            edit OBSFILE_HPCF 'amsu_pacrars'
-          task get_g2to
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/g2to eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'G2TO'
-            edit OBSFILE_HPCF 'reo3_gome2'
-          task get_grst
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/grst eq complete
-            edit OBSFILE_OBSHOST 'GRST'
-            edit OBSFILE_HPCF 'ostia'
-          task get_emer
-            late -s +00:02 -c +00:04
-            trigger /pp1/main/extractions/ex06/emer eq complete
-            edit OBSFILE_OBSHOST 'EMER'
-            edit OBSFILE_HPCF 'envisat_meris'
-          task get_j2nb
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/j2nb eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2NB'
-            edit OBSFILE_HPCF 'j2nb'
-          task get_j2eo
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/j2eo eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'J2EO'
-            edit OBSFILE_HPCF 'j2eo'
-          task get_asc2
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/asc2 eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASC2'
-            edit OBSFILE_HPCF 'ascat_l2'
-          task get_asel
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/asel eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASEL'
-            edit OBSFILE_HPCF 'ascat_ears'
-          task get_ascs
-            late -s +00:02 -c +00:04
-            trigger /pp2/main/extractions/ex06/ascs eq complete
-            edit OBSHOST 'pp2'
-            edit OBS_BASE '/pp2'
-            edit OBSFILE_OBSHOST 'ASCS'
-            edit OBSFILE_HPCF 'ascat_sm'
-          task atovairs
-            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
-          task snowlinks
-            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
-          task ro_combine
-            trigger get_rado eq complete and get_gras eq complete
-          task reo3_combine
-            trigger get_sbuv eq complete and get_g2to eq complete
-          task bufr_combine
-            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
-          task jason2_combine
-            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
-          task ascat_combine
-            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
-        endfamily
-        task fetchmars
-          trigger ./get eq complete
-        family prepare_obs
-          trigger ./get eq complete
-          task preobs
-            trigger /e_36r1/main/12dc/an/update_psbias eq complete and /e_36r1/main/12dc/an/update_rstrhbias eq complete
-            edit mode 'not1crad'
-            edit REINITIALIZE 'true'
-            edit REINIPERIOD_4D '6'
-          task premwimg
-          task preobs_wave
-            edit mode 'wave'
-          task pre1crad_prepare
-            edit mode '1crad'
-          task pre1crad_airs
-            trigger pre1crad_prepare eq complete
-          family pre1crad_iasi
-            trigger pre1crad_prepare eq complete
-            edit CPUTIME '1500'
-            edit MAXTASK '16'
-            task pre1crad_iasi_split_1
-              edit TASKNO '1'
-            task pre1crad_iasi_split_2
-              edit TASKNO '2'
-            task pre1crad_iasi_1
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '1'
-            task pre1crad_iasi_2
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '2'
-            task pre1crad_iasi_3
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '3'
-            task pre1crad_iasi_4
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '4'
-            task pre1crad_iasi_5
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '5'
-            task pre1crad_iasi_6
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '6'
-            task pre1crad_iasi_7
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '7'
-            task pre1crad_iasi_8
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '8'
-            task pre1crad_iasi_9
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '9'
-            task pre1crad_iasi_10
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '10'
-            task pre1crad_iasi_11
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '11'
-            task pre1crad_iasi_12
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '12'
-            task pre1crad_iasi_13
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '13'
-            task pre1crad_iasi_14
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '14'
-            task pre1crad_iasi_15
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '15'
-            task pre1crad_iasi_16
-              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
-              edit TASKNO '16'
-          endfamily
-          task pre1crad_hirs
-            trigger pre1crad_prepare eq complete
-          task pre1crad_msu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_ssu
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsua
-            trigger pre1crad_prepare eq complete
-          task pre1crad_amsub
-            trigger pre1crad_prepare eq complete
-          task pre1crad_mhs
-            trigger pre1crad_prepare eq complete
-          task pregeos
-          task prereo3
-          task prescat
-        endfamily
-        family reservation
-          late -c +00:03
-          trigger ./get/get_stor eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task adv_res
-            late -s +00:03 -c +00:02
-            edit RESERVE_FOR '30'
-            edit RESERVE_IN '11'
-            edit RESERVED_NODES '32'
-            edit RESERVATION_LABEL 'emos06A'
-            label info ""
-          task loadl_cycle_limit
-            late -s +00:03 -c +00:02
-            edit LOADL_CYCLE '65'
-            label info ""
-        endfamily
-      endfamily
-      family an
-        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-        edit PERIOD_4D '6'
-        edit WINDOW_LENGTH_4D '6'
-        edit WINDOW_OFFSET_4D '3'
-        edit ACCOUNT 'opebcan'
-        edit REINITIALIZE 'true'
-        edit ANNPES '144'
-        family makeodb
-          edit NPES '16'
-          task cleanodb
-          family bufr2odb
-            trigger cleanodb eq complete
-            edit THREADS '1'
-            edit NPOOLS '%ANNPES%'
-            edit THINFAC '1'
-            edit SENSOR '-1'
-            edit REBALANCE '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task b2o_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit USER_PRIORITY '90'
-            task b2o_surf_conv
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-            task b2o_airs
-              late -s +00:05 -c +00:15
-              edit THREADS '2'
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '57'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_iasi
-              late -s +00:05 -c +00:15
-              edit SENSOR '993'
-              edit SUBTYPES_INCLUDE '240'
-              edit THREADS '4'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_hirs
-              late -s +00:05 -c +00:15
-              edit SENSOR '0'
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPOOLS '$((2* %ANNPES%))'
-            task b2o_msu
-              late -s +00:05 -c +00:15
-              edit SENSOR '1'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_ssu
-              late -s +00:05 -c +00:15
-              edit SENSOR '2'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsua
-              late -s +00:05 -c +00:15
-              edit SENSOR '3'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_amsub
-              late -s +00:05 -c +00:15
-              edit SENSOR '4'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_mhs
-              late -s +00:05 -c +00:15
-              edit SENSOR '11'
-              edit SUBTYPES_INCLUDE '54 55'
-            task b2o_satob
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '82 83 87'
-            task b2o_reo3
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-            task b2o_ssmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '6'
-              edit SUBTYPES_INCLUDE '55 127'
-            task b2o_ssmis
-              late -s +00:05 -c +00:15
-              edit SENSOR '10'
-              edit SUBTYPES_INCLUDE '49'
-            task b2o_amsre
-              late -s +00:05 -c +00:15
-              edit SENSOR '17'
-              edit SUBTYPES_INCLUDE '59'
-            task b2o_tmi
-              late -s +00:05 -c +00:15
-              edit SENSOR '9'
-              edit SUBTYPES_INCLUDE '129'
-            task b2o_scatt
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task b2o_geos
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-            task b2o_gpsro
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '250'
-            task b2o_meris
-              late -s +00:05 -c +00:15
-              edit SENSOR '-1'
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergeodb
-            trigger bufr2odb eq complete
-          task mergeodb_surf
-            trigger ./bufr2odb/b2o_surf_conv eq complete
-            edit NPES '16'
-            edit THREADS '1'
-        endfamily
-        task restartodb
-          trigger makeodb eq complete
-        task preCleanFDB
-        task vardata
-          trigger ( ../../00/fc/model:step ge 9 or ../../00/fc/model eq complete)
-          event hires
-        task fetcherr
-        task lowres
-          trigger vardata:hires
-          edit THREADS '4'
-          edit ININPES '32'
-        family surf_anal
-          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          edit FSFAMILY 'surf_anal'
-          task t2ana
-            edit mode 't2m'
-          task rh2ana
-            trigger t2ana eq complete
-            edit mode 'rh2m'
-          task snow
-            trigger rh2ana eq complete
-            edit mode 'snow'
-          task sst
-            edit THREADS '4'
-          task slwet
-            trigger sst eq complete and snow eq complete
-        endfamily
-        family 4dvar
-          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
-          edit THREADS '8'
-          edit VAR_DELAY '00'
-          edit EMOS_SLEEP '00'
-          family uptraj_0
-            edit uptraj '0'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '91'
-              edit SMSTRIES '1'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '92'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '93'
-          endfamily
-          family uptraj_1
-            trigger uptraj_0 eq complete
-            edit uptraj '1'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '93'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '94'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '95'
-          endfamily
-          family uptraj_2
-            trigger uptraj_1 eq complete
-            edit uptraj '2'
-            task ifstraj
-              late -s +00:02
-              edit mode 'traj'
-              edit USER_PRIORITY '95'
-            task ifsmin
-              late -s +00:02
-              trigger ifstraj eq complete
-              edit mode 'min'
-              edit USER_PRIORITY '96'
-            task ifstsave
-              trigger ifstraj eq complete
-              edit THREADS '1'
-              edit USER_PRIORITY '97'
-          endfamily
-          task ifstraj
-            late -s +00:02
-            trigger uptraj_2 eq complete
-            edit uptraj '3'
-            edit mode 'traj'
-            edit USER_PRIORITY '97'
-            event finaltraj
-            event finalwave
-        endfamily
-        task forceinv
-          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '2432'
-            edit RESERVE_FOR '35'
-            label info ""
-          task rm_res
-            late -s +00:03 -c +00:02
-            edit RESERVATION_LABEL 'emos06A'
-            label info ""
-        endfamily
-      endfamily
-      family fc
-        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
-        edit ACCOUNT 'opebcfc'
-        edit REINITIALIZE 'true'
-        edit FSFAMILY 'fc'
-        task getfcdata
-        task getpersSST
-          trigger getfcdata eq complete
-          edit SSTLEN '90'
-          edit SSTINT '1'
-          edit THREADS '2'
-          edit NPES '16'
-          edit MEM '1000'
-          edit CPUTIME '960'
-        task model
-          late -s +00:02
-          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
-          edit PERSST 'true'
-          edit FCLENGTH '90'
-          edit THREADS '8'
-          edit USER_PRIORITY '94'
-          edit FCNPES '144'
-          meter step -1 90 90
-        task clean
-          trigger ../an eq complete and getfcdata eq complete and model eq complete and ../../18bc/fc eq complete
-        family reservation1
-          late -c +00:03
-          trigger ./getfcdata eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reserve_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '3072'
-            edit RESERVE_FOR '20'
-            label info ""
-        endfamily
-        family reservation2
-          late -c +00:03
-          trigger ./model eq complete
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-          inlimit /e_36r1/limits:reservation
-          task reset_cpu
-            late -s +00:03 -c +00:02
-            edit RESERVED_CPUS '0'
-            label info ""
-        endfamily
-      endfamily
-      family getreq
-        trigger ( /e_36r1/main/06bc/an/4dvar eq active or /e_36r1/main/06bc/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit PROD_TASK '1'
-        edit EMOS_DOMAIN 'G'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_PROJECT '12'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'SCDA'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '06'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger collectreq eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete and ( req:001 or req eq complete)
-          label info ""
-          event 1 
-      endfamily
-      family prod
-        trigger ( getreq/req:001 or getreq/req eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit EMOS_PROJECT '12'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        family an
-          trigger /e_36r1/main/06bc/an/surf_anal eq complete and ( /e_36r1/main/06bc/an/4dvar/ifstraj:finalwave or /e_36r1/main/06bc/an/4dvar/ifstraj eq complete) and 0 eq 0
-          edit EMOS_TYPE 'an'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ../090/prodgen eq complete and ( /e_36r1/main/06bc/fc/model:step ge 12 or /e_36r1/main/06bc/fc/model eq complete)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 000
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 000 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0000'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 12 or /e_36r1/main/06bc/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            edit MEMBER 'off'
-            edit STEPS '000'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 003
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 003 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 15 or /e_36r1/main/06bc/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '003'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 006
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 006 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 18 or /e_36r1/main/06bc/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '006'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 009
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 009 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 21 or /e_36r1/main/06bc/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '009'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 012
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 012 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 24 or /e_36r1/main/06bc/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '012'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 015
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 015 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 27 or /e_36r1/main/06bc/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '015'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 018
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 018 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 30 or /e_36r1/main/06bc/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '018'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 021
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 021 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 33 or /e_36r1/main/06bc/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '021'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 024
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 024 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 36 or /e_36r1/main/06bc/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '024'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 027
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 027 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 39 or /e_36r1/main/06bc/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '027'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 030
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 030 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 42 or /e_36r1/main/06bc/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '030'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 033
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 033 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 45 or /e_36r1/main/06bc/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '033'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 036
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 036 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0036'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 48 or /e_36r1/main/06bc/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '036'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 039
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 039 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0039'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 51 or /e_36r1/main/06bc/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '039'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 042
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 042 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0042'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 54 or /e_36r1/main/06bc/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '042'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 045
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 045 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0045'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 57 or /e_36r1/main/06bc/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '045'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 048
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 048 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0048'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 60 or /e_36r1/main/06bc/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '048'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 051
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 051 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0051'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 63 or /e_36r1/main/06bc/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '051'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 054
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 054 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0054'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 66 or /e_36r1/main/06bc/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '054'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 057
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 057 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0057'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 69 or /e_36r1/main/06bc/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '057'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 060
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 060 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0060'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 72 or /e_36r1/main/06bc/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '060'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 063
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 063 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0063'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 75 or /e_36r1/main/06bc/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '063'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 066
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 066 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0066'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 78 or /e_36r1/main/06bc/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '066'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 069
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 069 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0069'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 81 or /e_36r1/main/06bc/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '069'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 072
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 072 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0072'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 84 or /e_36r1/main/06bc/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '072'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 075
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 075 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0075'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 87 or /e_36r1/main/06bc/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '075'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 078
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 078 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0078'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task backupprod
-            late -s +00:05 -c +00:20
-            trigger ( /e_36r1/main/06bc/fc/model:step ge 90 or /e_36r1/main/06bc/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
-            edit PGNPES '16'
-            inlimit /e_36r1/limits:backupprod
-          task derived_param
-            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '078'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 081
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 081 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0081'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '081'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 084
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 084 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0084'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '084'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 087
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 087 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0087'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '087'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-        family 090
-          trigger ( /e_36r1/main/06bc/fc/model:step ge 090 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
-          edit EMOS_TIME_STEP_H '0090'
-          task prodgen
-            late -s +00:05 -c +00:15
-            trigger ./derived_param:SMOS or ./derived_param eq complete
-            edit USER_PRIORITY '92'
-            inlimit /e_36r1/limits:prod
-            inlimit /e_36r1/limits:prod_bc2
-          task derived_param
-            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
-            edit MEMBER 'off'
-            edit STEPS '090'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
-            event SMOS
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
-        task operation_is_late
-          event yes
-        family oper
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'fc'
-          edit FSFAMILY 'ppdi'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '92'
-          edit SMSURL 'GSCDA/06'
-          edit EMOS_PROJECT '12'
-          family an
-            task pdb
-              trigger ../../../prod/an/prodgen eq complete
-              edit EMOS_TYPE 'an'
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit EMOS_TYPE 'an'
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
-              edit EMOS_TYPE 'an'
-              label info ""
-              event 1 
-          endfamily
-          family 000
-            edit EMOS_TIME_STEP_H '0000'
-            task pdb
-              trigger ../../../prod/000/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ../an/q2diss eq complete
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 003
-            edit EMOS_TIME_STEP_H '0003'
-            task pdb
-              trigger ../../../prod/003/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/003/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 006
-            edit EMOS_TIME_STEP_H '0006'
-            task pdb
-              trigger ../../../prod/006/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/006/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 009
-            edit EMOS_TIME_STEP_H '0009'
-            task pdb
-              trigger ../../../prod/009/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/009/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 012
-            edit EMOS_TIME_STEP_H '0012'
-            task pdb
-              trigger ../../../prod/012/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/012/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 015
-            edit EMOS_TIME_STEP_H '0015'
-            task pdb
-              trigger ../../../prod/015/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/015/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 018
-            edit EMOS_TIME_STEP_H '0018'
-            task pdb
-              trigger ../../../prod/018/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/018/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 021
-            edit EMOS_TIME_STEP_H '0021'
-            task pdb
-              trigger ../../../prod/021/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/021/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 024
-            edit EMOS_TIME_STEP_H '0024'
-            task pdb
-              trigger ../../../prod/024/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/024/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 027
-            edit EMOS_TIME_STEP_H '0027'
-            task pdb
-              trigger ../../../prod/027/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/027/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 030
-            edit EMOS_TIME_STEP_H '0030'
-            task pdb
-              trigger ../../../prod/030/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/030/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 033
-            edit EMOS_TIME_STEP_H '0033'
-            task pdb
-              trigger ../../../prod/033/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/033/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 036
-            edit EMOS_TIME_STEP_H '0036'
-            task pdb
-              trigger ../../../prod/036/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/036/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 039
-            edit EMOS_TIME_STEP_H '0039'
-            task pdb
-              trigger ../../../prod/039/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/039/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 042
-            edit EMOS_TIME_STEP_H '0042'
-            task pdb
-              trigger ../../../prod/042/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/042/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 045
-            edit EMOS_TIME_STEP_H '0045'
-            task pdb
-              trigger ../../../prod/045/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/045/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 048
-            edit EMOS_TIME_STEP_H '0048'
-            task pdb
-              trigger ../../../prod/048/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/048/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 051
-            edit EMOS_TIME_STEP_H '0051'
-            task pdb
-              trigger ../../../prod/051/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/051/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 054
-            edit EMOS_TIME_STEP_H '0054'
-            task pdb
-              trigger ../../../prod/054/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/054/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 057
-            edit EMOS_TIME_STEP_H '0057'
-            task pdb
-              trigger ../../../prod/057/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/057/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 060
-            edit EMOS_TIME_STEP_H '0060'
-            task pdb
-              trigger ../../../prod/060/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/060/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 063
-            edit EMOS_TIME_STEP_H '0063'
-            task pdb
-              trigger ../../../prod/063/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/063/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 066
-            edit EMOS_TIME_STEP_H '0066'
-            task pdb
-              trigger ../../../prod/066/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/066/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 069
-            edit EMOS_TIME_STEP_H '0069'
-            task pdb
-              trigger ../../../prod/069/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/069/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 072
-            edit EMOS_TIME_STEP_H '0072'
-            task pdb
-              trigger ../../../prod/072/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/072/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 075
-            edit EMOS_TIME_STEP_H '0075'
-            task pdb
-              trigger ../../../prod/075/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/075/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 078
-            edit EMOS_TIME_STEP_H '0078'
-            task pdb
-              trigger ../../../prod/078/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-            task dissbackup
-              late -s +00:05 -c +00:15
-              trigger ../../../prod/078/backupprod eq complete
-              inlimit /e_36r1/limits:dissbackup
-              label info ""
-              event 1 
-          endfamily
-          family 081
-            edit EMOS_TIME_STEP_H '0081'
-            task pdb
-              trigger ../../../prod/081/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 084
-            edit EMOS_TIME_STEP_H '0084'
-            task pdb
-              trigger ../../../prod/084/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 087
-            edit EMOS_TIME_STEP_H '0087'
-            task pdb
-              trigger ../../../prod/087/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          family 090
-            edit EMOS_TIME_STEP_H '0090'
-            task pdb
-              trigger ../../../prod/090/prodgen eq complete
-              inlimit /e_36r1/limits:pdb_bc
-              inlimit /limits:pdb_bc
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
-              edit USER_PRIORITY '93'
-              inlimit /e_36r1/limits:q2diss_bc
-              inlimit /limits:q2diss_bc
-              label info ""
-              event 1 
-          endfamily
-          task check
-            trigger ./078 eq complete
-        endfamily
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'main'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger make eq complete and ./00dc eq complete and ./06 eq complete and ./12 eq complete and ./12dc eq complete and ./18 eq complete and ./00 eq complete and ./12bc eq complete and ./18bc eq complete and ./00bc eq complete and ./06bc eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'main'
-      edit MOVE_TO_ECFS 'no'
-      time 12:00
-  endfamily
-  family lag
-    repeat date YMD 20091118 20121212 1
-    edit MARS_DB 'marsod'
-    family 00dc
-      edit EMOS_BASE '00'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      family ddh
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/fc eq complete)
-        edit EMOS_BASE '06'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
-        task ddh
-      endfamily
-      family sync
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/an eq complete)
-        edit EMOS_TYPE 'an'
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
-        task dcda_to_da_bk
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit OPHOST 'c1b'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_satmon
-          trigger ../satmon eq complete
-        task sync_bias
-        task sync_fc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00dc/fc/model:step gt 6 or /e_36r1/main/00dc/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit EMOS_BASE '06'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_an
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit EMOS_BASE '06'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00dc/fc/model:step gt 3 or /e_36r1/main/00dc/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit EMOS_BASE '06'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_clean
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-      endfamily
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/00dc/an eq complete and ( ../../main/00dc/fc/model:step ge 15 or ../../main/00dc/fc/model eq complete))
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task sp2fdb
-          edit STEPS '3/6/9/12/18'
-          label files ""
-          label info ""
-          event fdb
-        task ansfc
-          trigger sp2fdb eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '15'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ./ansfc eq complete
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00dc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/00dc/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc015
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/fc/model:step ge 21 or /e_36r1/main/00dc/fc/model eq complete)
-          edit STEPS '3/6/9/12/15'
-          edit EMOS_BASE '06'
-          edit EMOS_TYPE 'fc'
-          task sp2fdb
-            label files ""
-            label info ""
-            event fdb
-          task fcsfc
-            trigger sp2fdb eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/fc/model eq complete)
-          edit STEPS_SPECTRAL '6/12'
-          edit EMOS_BASE '06'
-          edit STEPS '0/3/6/9/12/15'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'oedcdaan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00dc/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      family traj
-        task feed
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00dc/fc eq complete)
-        task cp_to_other
-          trigger feed eq complete
-      endfamily
-      family satmon
-        edit FSFAMILY 'an'
-        inlimit /e_36r1/limits:smon
-        task getsmon
-          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
-        task smon_meris
-          trigger getsmon eq complete
-          edit smon_smsmode 'MERIS'
-        task smon_amsre
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMSRE'
-        task smon_ssmis
-          trigger getsmon eq complete
-          edit smon_smsmode 'SSMIS'
-        task smon_tmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'TMI'
-        task smon_gpsro
-          trigger getsmon eq complete
-          edit smon_smsmode 'GPSRO'
-        task smon_pacrars
-          trigger getsmon eq complete
-          edit smon_smsmode 'PACRARS'
-        task smon_ears
-          trigger getsmon eq complete
-          edit smon_smsmode 'EARS'
-        task smon_o3msg
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3MSG'
-        task smon_o3knmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3KNMI'
-        task smon_pwc
-          trigger getsmon eq complete
-          edit smon_smsmode 'PWC'
-        task smon_temp
-          trigger getsmon eq complete
-          edit smon_smsmode 'TEMP'
-        task smon_iasi
-          trigger getsmon eq complete
-          edit smon_smsmode 'IASI'
-        task smon_airs
-          trigger getsmon eq complete
-          edit smon_smsmode 'AIRS'
-        task smon_dbamv
-          trigger getsmon eq complete
-          edit smon_smsmode 'DBAMV'
-        task smon_amv
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMV'
-        task smon_o3
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3'
-        task smon_dmsp
-          trigger getsmon eq complete
-          edit smon_smsmode 'DMSP'
-        task smon_noaa
-          trigger getsmon eq complete
-          edit smon_smsmode 'NOAA'
-        task smon_geos
-          trigger getsmon eq complete
-          edit smon_smsmode 'GEOS'
-        task smon_scatt
-          trigger getsmon eq complete
-          edit smon_smsmode 'SCATT'
-        task smon_slmoist
-          trigger getsmon eq complete
-          edit smon_smsmode 'SLMOIST'
-        task smon_clean
-          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
-      endfamily
-      task clean
-        trigger fb eq complete and satmon eq complete
-        edit FSFAMILY 'an'
-      task cleanplus6
-        trigger clean eq complete
-        edit EMOS_BASE '06'
-        edit FSFAMILY 'an'
-      family verif
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
-        edit DELTA_DAY '1'
-        inlimit /limits:linux_cluster
-        family fc
-          task v12li1
-          task v12li2
-          task v12up1
-            trigger v12li1 eq complete
-          task v12up2
-            trigger v12up1 eq complete and v12li2 eq complete
-          task v12pl
-            trigger v12up2 eq complete
-          task v12memv
-            trigger v12up2 eq complete
-            edit DATEMASK '02.*.*'
-          task v12memb
-            trigger v12up2 eq complete
-            edit DATEMASK '11.*.*'
-          task v12upmv
-            trigger v12memv eq complete
-            edit DATEMASK '02.*.*'
-          task v12upmb
-            trigger v12memb eq complete
-            edit DATEMASK '11.*.*'
-          task v12crmv
-            edit DATEMASK '28.*.*'
-          task v12crmb
-            edit DATEMASK '28.*.*'
-          task v12crd
-            edit DATEMASK '28.*.*'
-        endfamily
-        family oc
-          trigger ./fc eq complete or ./fc eq aborted
-          task mk_dummy_fields
-            edit QUEUE 'emos'
-            edit USER 'emos'
-            edit PP_BASE '/pp1'
-            edit WSHOST 'pp1'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit LOGDIR '/pp1/log'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit SMSOUT '/vol/emos_nc/output'
-          task insert_fields
-            trigger mk_dummy_fields eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit PP_BASE '/pp1'
-            inlimit /limits:linux_cluster
-          task vbrli1
-            trigger insert_fields eq complete
-          task vbrli2
-            trigger vbrli1 eq complete
-          task vwali1
-            trigger insert_fields eq complete
-          task vwali2
-            trigger vwali1 eq complete
-          task vwali3
-            trigger vwali2 eq complete
-          task vofli
-            trigger insert_fields eq complete
-          task vtlli
-            trigger insert_fields eq complete
-          task vtoli
-            trigger insert_fields eq complete
-          task vmoli
-            trigger insert_fields eq complete
-          task vbrup1
-            trigger vbrli1 eq complete
-          task vbrup2
-            trigger vbrup1 eq complete and vbrli2 eq complete
-          task vwaup1
-            trigger vwali1 eq complete
-          task vwaup2
-            trigger vwaup1 eq complete and vwali2 eq complete
-          task vwaup3
-            trigger vwaup2 eq complete and vwali3 eq complete
-          task vofup
-            trigger vofli eq complete
-          task vtlup
-            trigger vtlli eq complete
-          task vtoup
-            trigger vtoli eq complete
-          task vmoup
-            trigger vmoli eq complete
-          task vmeli
-            trigger insert_fields eq complete
-          task vmeup
-            trigger vmeli eq complete
-          task voccrd
-            edit DATEMASK '28.*.*'
-          task voccrm
-            edit DATEMASK '28.*.*'
-          task vocmem
-            edit DATEMASK '11.*.*'
-          task vocupm
-            trigger vocmem eq complete
-            edit DATEMASK '11.*.*'
-          task cleanup
-            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-        endfamily
-        family cf
-          trigger oc eq complete or oc eq aborted
-          task vcnli1
-            late -c +02:00
-          task vcnli2
-          task vcnup1
-            trigger vcnli1 eq complete
-          task vcnup2
-            trigger vcnup1 eq complete and vcnli2 eq complete
-          task vcnpl
-            trigger vcnup2 eq complete
-          task vcncrd
-          task vcncrm
-            edit DATEMASK '28.*.*'
-          task vcnmem
-            trigger vcnup2 eq complete
-            edit DATEMASK '11.*.*'
-          task vcnupm
-            trigger vcnmem eq complete
-            edit DATEMASK '11.*.*'
-          task vcnli3
-          task vcnli4
-          task vcnup3
-            trigger vcnup2 eq complete and vcnli3 eq complete
-          task vcnup4
-            trigger vcnup3 eq complete and vcnli4 eq complete
-          task vcnmem2
-            trigger vcnup4 eq complete
-            edit DATEMASK '22.*.*'
-          task vcnupm2
-            trigger vcnmem2 eq complete
-            edit DATEMASK '22.*.*'
-        endfamily
-        family ob
-          trigger oc eq complete or oc eq aborted
-          time 05:00
-          family stage1
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          family stage2
-            trigger ./stage1 eq complete
-            edit EMOS_BASE '00'
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          task vobcrd
-            edit DATEMASK '28.*.*'
-          task vobcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family em
-          task vemli
-            late -c +02:00
-          task vemup
-            trigger vemli eq complete
-          task vemcrd
-            edit DATEMASK '28.*.*'
-          task vemcrm
-            edit DATEMASK '28.*.*'
-          task vemmem
-            trigger vemup eq complete
-            edit DATEMASK '11.*.*'
-          task vemupm
-            trigger vemmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family es
-          trigger em eq complete
-          task vesli
-            late -c +02:00
-          task vesup
-            trigger vesli eq complete
-          task vescrd
-            edit DATEMASK '28.*.*'
-          task vescrm
-            edit DATEMASK '28.*.*'
-          task vesmem
-            trigger vesup eq complete
-            edit DATEMASK '11.*.*'
-          task vesupm
-            trigger vesmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family cv
-          trigger es eq complete
-          task vcvli
-            late -c +02:00
-          task vcvup
-            trigger vcvli eq complete
-          task vcvcrd
-            edit DATEMASK '28.*.*'
-          task vcvcrm
-            edit DATEMASK '28.*.*'
-          task vcvmem
-            trigger vcvup eq complete
-            edit DATEMASK '11.*.*'
-          task vcvupm
-            trigger vcvmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00dc/fc/model eq complete)
-          task glver
-          task glupr
-            trigger glver eq complete
-          task glcrr
-            edit DATEMASK '28.*.*'
-          task ff10ver
-            trigger glver eq complete
-          task ff10upr
-            trigger ff10ver eq complete and glupr eq complete
-          task glmem
-            trigger ff10upr eq complete
-            edit DATEMASK '11.*.*'
-          task glupm
-            trigger glmem eq complete
-            edit DATEMASK '11.*.*'
-          task glcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family sf
-          trigger fc eq complete or fc eq aborted
-          task vseli1
-          task vseli2
-          task vseup1
-            trigger vseli1 eq complete
-          task vseup2
-            trigger vseup1 eq complete and vseli2 eq complete
-          task vsecrd
-            edit DATEMASK '28.*.*'
-          task vsecrm
-            edit DATEMASK '28.*.*'
-          task vsemem
-            trigger vseup2 eq complete
-            edit DATEMASK '12.*.*'
-          task vseupm
-            trigger vsemem eq complete
-            edit DATEMASK '12.*.*'
-        endfamily
-      endfamily
-    endfamily
-    family 06
-      edit EMOS_BASE '06'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DA'
-      edit LAR_4V_EF 'false'
-      edit LFC_DIR_FREQ 'false'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/12/prod/06an eq complete)
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task ansfc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod/06an/derived_param eq complete))
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '6'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod/06an/derived_param eq complete))
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task highres
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/06/an/4dvar/ifstraj:finaltraj or /e_36r1/main/06/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc015
-          edit STEPS '3/6/9/12/15'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06/fc/model eq complete)
-          edit STEPS '0/3/6/9/12/15'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'oeoperan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      family traj
-        task feed
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06/fc eq complete)
-        task cp_to_other
-          trigger feed eq complete
-      endfamily
-      family satmon
-        trigger ../00dc/satmon eq complete
-        edit FSFAMILY 'an'
-        inlimit /e_36r1/limits:smon
-        task getsmon
-          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
-        task smon_meris
-          trigger getsmon eq complete
-          edit smon_smsmode 'MERIS'
-        task smon_amsre
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMSRE'
-        task smon_ssmis
-          trigger getsmon eq complete
-          edit smon_smsmode 'SSMIS'
-        task smon_tmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'TMI'
-        task smon_gpsro
-          trigger getsmon eq complete
-          edit smon_smsmode 'GPSRO'
-        task smon_pacrars
-          trigger getsmon eq complete
-          edit smon_smsmode 'PACRARS'
-        task smon_ears
-          trigger getsmon eq complete
-          edit smon_smsmode 'EARS'
-        task smon_o3msg
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3MSG'
-        task smon_o3knmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3KNMI'
-        task smon_pwc
-          trigger getsmon eq complete
-          edit smon_smsmode 'PWC'
-        task smon_temp
-          trigger getsmon eq complete
-          edit smon_smsmode 'TEMP'
-        task smon_iasi
-          trigger getsmon eq complete
-          edit smon_smsmode 'IASI'
-        task smon_airs
-          trigger getsmon eq complete
-          edit smon_smsmode 'AIRS'
-        task smon_dbamv
-          trigger getsmon eq complete
-          edit smon_smsmode 'DBAMV'
-        task smon_amv
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMV'
-        task smon_o3
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3'
-        task smon_dmsp
-          trigger getsmon eq complete
-          edit smon_smsmode 'DMSP'
-        task smon_noaa
-          trigger getsmon eq complete
-          edit smon_smsmode 'NOAA'
-        task smon_geos
-          trigger getsmon eq complete
-          edit smon_smsmode 'GEOS'
-        task smon_scatt
-          trigger getsmon eq complete
-          edit smon_smsmode 'SCATT'
-        task smon_slmoist
-          trigger getsmon eq complete
-          edit smon_smsmode 'SLMOIST'
-        task smon_clean
-          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
-      endfamily
-      task clean
-        trigger fb eq complete and ../00dc/clean eq complete
-        edit FSFAMILY 'an'
-      family verif
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
-        edit DELTA_DAY '1'
-        inlimit /limits:linux_cluster
-        family fc
-          task v12li1
-          task v12li2
-          task v12up1
-            trigger v12li1 eq complete
-          task v12up2
-            trigger v12up1 eq complete and v12li2 eq complete
-          task v12pl
-            trigger v12up2 eq complete
-          task v12memv
-            trigger v12up2 eq complete
-            edit DATEMASK '02.*.*'
-          task v12memb
-            trigger v12up2 eq complete
-            edit DATEMASK '11.*.*'
-          task v12upmv
-            trigger v12memv eq complete
-            edit DATEMASK '02.*.*'
-          task v12upmb
-            trigger v12memb eq complete
-            edit DATEMASK '11.*.*'
-          task v12crmv
-            edit DATEMASK '28.*.*'
-          task v12crmb
-            edit DATEMASK '28.*.*'
-          task v12crd
-            edit DATEMASK '28.*.*'
-        endfamily
-        family oc
-          trigger ./fc eq complete or ./fc eq aborted
-          task mk_dummy_fields
-            edit QUEUE 'emos'
-            edit USER 'emos'
-            edit PP_BASE '/pp1'
-            edit WSHOST 'pp1'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit LOGDIR '/pp1/log'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit SMSOUT '/vol/emos_nc/output'
-          task insert_fields
-            trigger mk_dummy_fields eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit PP_BASE '/pp1'
-            inlimit /limits:linux_cluster
-          task vbrli1
-            trigger insert_fields eq complete
-          task vbrli2
-            trigger vbrli1 eq complete
-          task vwali1
-            trigger insert_fields eq complete
-          task vwali2
-            trigger vwali1 eq complete
-          task vwali3
-            trigger vwali2 eq complete
-          task vofli
-            trigger insert_fields eq complete
-          task vtlli
-            trigger insert_fields eq complete
-          task vtoli
-            trigger insert_fields eq complete
-          task vmoli
-            trigger insert_fields eq complete
-          task vbrup1
-            trigger vbrli1 eq complete
-          task vbrup2
-            trigger vbrup1 eq complete and vbrli2 eq complete
-          task vwaup1
-            trigger vwali1 eq complete
-          task vwaup2
-            trigger vwaup1 eq complete and vwali2 eq complete
-          task vwaup3
-            trigger vwaup2 eq complete and vwali3 eq complete
-          task vofup
-            trigger vofli eq complete
-          task vtlup
-            trigger vtlli eq complete
-          task vtoup
-            trigger vtoli eq complete
-          task vmoup
-            trigger vmoli eq complete
-          task vmeli
-            trigger insert_fields eq complete
-          task vmeup
-            trigger vmeli eq complete
-          task voccrd
-            edit DATEMASK '28.*.*'
-          task voccrm
-            edit DATEMASK '28.*.*'
-          task vocmem
-            edit DATEMASK '11.*.*'
-          task vocupm
-            trigger vocmem eq complete
-            edit DATEMASK '11.*.*'
-          task cleanup
-            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-        endfamily
-        family cf
-          trigger oc eq complete or oc eq aborted
-          task vcnli1
-            late -c +02:00
-          task vcnli2
-          task vcnup1
-            trigger vcnli1 eq complete
-          task vcnup2
-            trigger vcnup1 eq complete and vcnli2 eq complete
-          task vcnpl
-            trigger vcnup2 eq complete
-          task vcncrd
-          task vcncrm
-            edit DATEMASK '28.*.*'
-          task vcnmem
-            trigger vcnup2 eq complete
-            edit DATEMASK '11.*.*'
-          task vcnupm
-            trigger vcnmem eq complete
-            edit DATEMASK '11.*.*'
-          task vcnli3
-          task vcnli4
-          task vcnup3
-            trigger vcnup2 eq complete and vcnli3 eq complete
-          task vcnup4
-            trigger vcnup3 eq complete and vcnli4 eq complete
-          task vcnmem2
-            trigger vcnup4 eq complete
-            edit DATEMASK '22.*.*'
-          task vcnupm2
-            trigger vcnmem2 eq complete
-            edit DATEMASK '22.*.*'
-        endfamily
-        family ob
-          trigger oc eq complete or oc eq aborted
-          time 05:00
-          family stage1
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          family stage2
-            trigger ./stage1 eq complete
-            edit EMOS_BASE '00'
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          task vobcrd
-            edit DATEMASK '28.*.*'
-          task vobcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family em
-          task vemli
-            late -c +02:00
-          task vemup
-            trigger vemli eq complete
-          task vemcrd
-            edit DATEMASK '28.*.*'
-          task vemcrm
-            edit DATEMASK '28.*.*'
-          task vemmem
-            trigger vemup eq complete
-            edit DATEMASK '11.*.*'
-          task vemupm
-            trigger vemmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family es
-          trigger em eq complete
-          task vesli
-            late -c +02:00
-          task vesup
-            trigger vesli eq complete
-          task vescrd
-            edit DATEMASK '28.*.*'
-          task vescrm
-            edit DATEMASK '28.*.*'
-          task vesmem
-            trigger vesup eq complete
-            edit DATEMASK '11.*.*'
-          task vesupm
-            trigger vesmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family cv
-          trigger es eq complete
-          task vcvli
-            late -c +02:00
-          task vcvup
-            trigger vcvli eq complete
-          task vcvcrd
-            edit DATEMASK '28.*.*'
-          task vcvcrm
-            edit DATEMASK '28.*.*'
-          task vcvmem
-            trigger vcvup eq complete
-            edit DATEMASK '11.*.*'
-          task vcvupm
-            trigger vcvmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06/fc/model eq complete)
-          task glver
-          task glupr
-            trigger glver eq complete
-          task glcrr
-            edit DATEMASK '28.*.*'
-          task ff10ver
-            trigger glver eq complete
-          task ff10upr
-            trigger ff10ver eq complete and glupr eq complete
-          task glmem
-            trigger ff10upr eq complete
-            edit DATEMASK '11.*.*'
-          task glupm
-            trigger glmem eq complete
-            edit DATEMASK '11.*.*'
-          task glcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family sf
-          trigger fc eq complete or fc eq aborted
-          task vseli1
-          task vseli2
-          task vseup1
-            trigger vseli1 eq complete
-          task vseup2
-            trigger vseup1 eq complete and vseli2 eq complete
-          task vsecrd
-            edit DATEMASK '28.*.*'
-          task vsecrm
-            edit DATEMASK '28.*.*'
-          task vsemem
-            trigger vseup2 eq complete
-            edit DATEMASK '12.*.*'
-          task vseupm
-            trigger vsemem eq complete
-            edit DATEMASK '12.*.*'
-        endfamily
-      endfamily
-    endfamily
-    family 12
-      edit EMOS_BASE '12'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      family ddh
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/fc eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
-        task ddh
-      endfamily
-      family sync
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/an eq complete)
-        edit EMOS_TYPE 'an'
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
-        task sync_bias
-          edit CALC_PSBIAS 'false'
-        task sync_fc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/fc/model:step gt 6 or /e_36r1/main/12/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_an
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/fc/model:step gt 3 or /e_36r1/main/12/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_clean
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-      endfamily
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/12/an eq complete and ( ../../main/12/fc/model:step ge 9 or ../../main/12/fc/model eq complete))
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task ansfc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/000 eq complete and /e_36r1/main/12/prod/12an eq complete)
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '240'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ./ansfc eq complete
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/an/4dvar/ifstraj:finaltraj or /e_36r1/main/12/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc024
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/024 eq complete)
-          edit STEPS '0/3/006/009/012/015/018/021/024'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc048
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/048 eq complete)
-          edit STEPS '027/030/033/036/039/042/045/048'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc072
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/072 eq complete)
-          edit STEPS '051/054/057/060/063/066/069/072'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc096
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/096 eq complete)
-          edit STEPS '075/078/081/084/087/090/093/096'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc120
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/120 eq complete)
-          edit STEPS '099/102/105/108/111/114/117/120'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc144
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/144 eq complete)
-          edit STEPS '123/126/129/132/135/138/141/144'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc192
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/192 eq complete)
-          edit STEPS '150/156/162/168/174/180/186/192'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc240
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/240 eq complete)
-          edit STEPS '198/204/210/216/222/228/234/240'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family satim1
-          task satim
-            trigger ../../satim eq complete
-            edit STEPS '0/to/48/by/3'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family satim2
-          task satim
-            trigger ../../satim eq complete
-            edit STEPS '54/to/120/by/6'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/fc/model eq complete)
-          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
-          edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task rmfdb
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/obs eq complete)
-        task flush
-          edit STREAM 'oper'
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'oeoperan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      family traj
-        task feed
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12/fc eq complete)
-        task cp_to_other
-          trigger feed eq complete
-      endfamily
-      family satim
-        edit QUEUE 'ns'
-        edit QUEUE_EPILOG 'ns'
-        edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-        edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-        edit MEM '11000'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-        edit SMSURLBASE 'http://intra.ecmwf.int/publications/cms/get/metapps'
-        inlimit /limits:c1b
-        task display_seaice
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/an eq complete)
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/admin'
-          edit FSFAMILY 'undef'
-          edit METVIEW 'metview_emos'
-          edit SMSURL 'seaice'
-          inlimit /limits:linux_cluster
-        task display_sst
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FSFAMILY 'undef'
-          edit SMSURL 'sst'
-          inlimit /limits:linux_cluster
-        family satim_0
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '0'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_3
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '3'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_6
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '6'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_9
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '9'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_12
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '12'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_15
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '15'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_18
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '18'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_21
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '21'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_24
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '24'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_27
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '27'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_30
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '30'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_33
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '33'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_36
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '36'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_39
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '39'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_42
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '42'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_45
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '45'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_48
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '48'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_54
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '54'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_60
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '60'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_66
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '66'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_72
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '72'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_78
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '78'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_84
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '84'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_90
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '90'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_96
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '96'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_102
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '102'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_108
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '108'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_114
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '114'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_120
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
-          edit IMAGETIME '120'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-      endfamily
-      family satmon
-        trigger ../00dc/satmon eq complete
-        edit FSFAMILY 'an'
-        inlimit /e_36r1/limits:smon
-        task getsmon
-          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
-        task smon_meris
-          trigger getsmon eq complete
-          edit smon_smsmode 'MERIS'
-        task smon_amsre
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMSRE'
-        task smon_ssmis
-          trigger getsmon eq complete
-          edit smon_smsmode 'SSMIS'
-        task smon_tmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'TMI'
-        task smon_gpsro
-          trigger getsmon eq complete
-          edit smon_smsmode 'GPSRO'
-        task smon_pacrars
-          trigger getsmon eq complete
-          edit smon_smsmode 'PACRARS'
-        task smon_ears
-          trigger getsmon eq complete
-          edit smon_smsmode 'EARS'
-        task smon_o3msg
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3MSG'
-        task smon_o3knmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3KNMI'
-        task smon_pwc
-          trigger getsmon eq complete
-          edit smon_smsmode 'PWC'
-        task smon_temp
-          trigger getsmon eq complete
-          edit smon_smsmode 'TEMP'
-        task smon_iasi
-          trigger getsmon eq complete
-          edit smon_smsmode 'IASI'
-        task smon_airs
-          trigger getsmon eq complete
-          edit smon_smsmode 'AIRS'
-        task smon_dbamv
-          trigger getsmon eq complete
-          edit smon_smsmode 'DBAMV'
-        task smon_amv
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMV'
-        task smon_o3
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3'
-        task smon_dmsp
-          trigger getsmon eq complete
-          edit smon_smsmode 'DMSP'
-        task smon_noaa
-          trigger getsmon eq complete
-          edit smon_smsmode 'NOAA'
-        task smon_geos
-          trigger getsmon eq complete
-          edit smon_smsmode 'GEOS'
-        task smon_scatt
-          trigger getsmon eq complete
-          edit smon_smsmode 'SCATT'
-        task smon_slmoist
-          trigger getsmon eq complete
-          edit smon_smsmode 'SLMOIST'
-        task smon_clean
-          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
-      endfamily
-      task clean
-        trigger fb eq complete and ../06/clean eq complete
-        edit FSFAMILY 'an'
-      family verif
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
-        edit DELTA_DAY '1'
-        inlimit /limits:linux_cluster
-        time 02:00
-        family fc
-          task v12li1
-          task v12li2
-          task v12up1
-            trigger v12li1 eq complete
-          task v12up2
-            trigger v12up1 eq complete and v12li2 eq complete
-          task v12pl
-            trigger v12up2 eq complete
-          task v12memv
-            trigger v12up2 eq complete
-            edit DATEMASK '02.*.*'
-          task v12memb
-            trigger v12up2 eq complete
-            edit DATEMASK '11.*.*'
-          task v12upmv
-            trigger v12memv eq complete
-            edit DATEMASK '02.*.*'
-          task v12upmb
-            trigger v12memb eq complete
-            edit DATEMASK '11.*.*'
-          task v12crmv
-            edit DATEMASK '28.*.*'
-          task v12crmb
-            edit DATEMASK '28.*.*'
-          task v12crd
-            edit DATEMASK '28.*.*'
-        endfamily
-        family oc
-          trigger ./fc eq complete or ./fc eq aborted
-          task mk_dummy_fields
-            edit QUEUE 'emos'
-            edit USER 'emos'
-            edit PP_BASE '/pp1'
-            edit WSHOST 'pp1'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit LOGDIR '/pp1/log'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit SMSOUT '/vol/emos_nc/output'
-          task insert_fields
-            trigger mk_dummy_fields eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit PP_BASE '/pp1'
-            inlimit /limits:linux_cluster
-          task vbrli1
-            trigger insert_fields eq complete
-          task vbrli2
-            trigger vbrli1 eq complete
-          task vwali1
-            trigger insert_fields eq complete
-          task vwali2
-            trigger vwali1 eq complete
-          task vwali3
-            trigger vwali2 eq complete
-          task vofli
-            trigger insert_fields eq complete
-          task vtlli
-            trigger insert_fields eq complete
-          task vtoli
-            trigger insert_fields eq complete
-          task vmoli
-            trigger insert_fields eq complete
-          task vbrup1
-            trigger vbrli1 eq complete
-          task vbrup2
-            trigger vbrup1 eq complete and vbrli2 eq complete
-          task vwaup1
-            trigger vwali1 eq complete
-          task vwaup2
-            trigger vwaup1 eq complete and vwali2 eq complete
-          task vwaup3
-            trigger vwaup2 eq complete and vwali3 eq complete
-          task vofup
-            trigger vofli eq complete
-          task vtlup
-            trigger vtlli eq complete
-          task vtoup
-            trigger vtoli eq complete
-          task vmoup
-            trigger vmoli eq complete
-          task vmeli
-            trigger insert_fields eq complete
-          task vmeup
-            trigger vmeli eq complete
-          task voccrd
-            edit DATEMASK '28.*.*'
-          task voccrm
-            edit DATEMASK '28.*.*'
-          task vocmem
-            edit DATEMASK '11.*.*'
-          task vocupm
-            trigger vocmem eq complete
-            edit DATEMASK '11.*.*'
-          task cleanup
-            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-        endfamily
-        family cf
-          trigger oc eq complete or oc eq aborted
-          task vcnli1
-            late -c +02:00
-          task vcnli2
-          task vcnup1
-            trigger vcnli1 eq complete
-          task vcnup2
-            trigger vcnup1 eq complete and vcnli2 eq complete
-          task vcnpl
-            trigger vcnup2 eq complete
-          task vcncrd
-          task vcncrm
-            edit DATEMASK '28.*.*'
-          task vcnmem
-            trigger vcnup2 eq complete
-            edit DATEMASK '11.*.*'
-          task vcnupm
-            trigger vcnmem eq complete
-            edit DATEMASK '11.*.*'
-          task vcnli3
-          task vcnli4
-          task vcnup3
-            trigger vcnup2 eq complete and vcnli3 eq complete
-          task vcnup4
-            trigger vcnup3 eq complete and vcnli4 eq complete
-          task vcnmem2
-            trigger vcnup4 eq complete
-            edit DATEMASK '22.*.*'
-          task vcnupm2
-            trigger vcnmem2 eq complete
-            edit DATEMASK '22.*.*'
-        endfamily
-        family ob
-          trigger oc eq complete or oc eq aborted
-          time 05:00
-          family stage1
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          family stage2
-            trigger ./stage1 eq complete
-            edit EMOS_BASE '00'
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          task vobcrd
-            edit DATEMASK '28.*.*'
-          task vobcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family em
-          task vemli
-            late -c +02:00
-          task vemup
-            trigger vemli eq complete
-          task vemcrd
-            edit DATEMASK '28.*.*'
-          task vemcrm
-            edit DATEMASK '28.*.*'
-          task vemmem
-            trigger vemup eq complete
-            edit DATEMASK '11.*.*'
-          task vemupm
-            trigger vemmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family es
-          trigger em eq complete
-          task vesli
-            late -c +02:00
-          task vesup
-            trigger vesli eq complete
-          task vescrd
-            edit DATEMASK '28.*.*'
-          task vescrm
-            edit DATEMASK '28.*.*'
-          task vesmem
-            trigger vesup eq complete
-            edit DATEMASK '11.*.*'
-          task vesupm
-            trigger vesmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family cv
-          trigger es eq complete
-          task vcvli
-            late -c +02:00
-          task vcvup
-            trigger vcvli eq complete
-          task vcvcrd
-            edit DATEMASK '28.*.*'
-          task vcvcrm
-            edit DATEMASK '28.*.*'
-          task vcvmem
-            trigger vcvup eq complete
-            edit DATEMASK '11.*.*'
-          task vcvupm
-            trigger vcvmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12/fc/model eq complete)
-          task glver
-          task glupr
-            trigger glver eq complete
-          task glcrr
-            edit DATEMASK '28.*.*'
-          task ff10ver
-            trigger glver eq complete
-          task ff10upr
-            trigger ff10ver eq complete and glupr eq complete
-          task glmem
-            trigger ff10upr eq complete
-            edit DATEMASK '11.*.*'
-          task glupm
-            trigger glmem eq complete
-            edit DATEMASK '11.*.*'
-          task glcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family sf
-          trigger fc eq complete or fc eq aborted
-          task vseli1
-          task vseli2
-          task vseup1
-            trigger vseli1 eq complete
-          task vseup2
-            trigger vseup1 eq complete and vseli2 eq complete
-          task vsecrd
-            edit DATEMASK '28.*.*'
-          task vsecrm
-            edit DATEMASK '28.*.*'
-          task vsemem
-            trigger vseup2 eq complete
-            edit DATEMASK '12.*.*'
-          task vseupm
-            trigger vsemem eq complete
-            edit DATEMASK '12.*.*'
-        endfamily
-      endfamily
-    endfamily
-    family 12dc
-      edit EMOS_BASE '12'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      family ddh
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/fc eq complete)
-        edit EMOS_BASE '18'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
-        task ddh
-      endfamily
-      family sync
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/an eq complete)
-        edit EMOS_TYPE 'an'
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
-        task dcda_to_da_bk
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit OPHOST 'c1b'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_satmon
-          trigger ../satmon eq complete
-        task sync_bias
-        task sync_fc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12dc/fc/model:step gt 6 or /e_36r1/main/12dc/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit EMOS_BASE '18'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_an
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit EMOS_BASE '18'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12dc/fc/model:step gt 3 or /e_36r1/main/12dc/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          edit EMOS_BASE '18'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_clean
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-      endfamily
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/12dc/an eq complete and ( ../../main/12dc/fc/model:step ge 15 or ../../main/12dc/fc/model eq complete))
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task sp2fdb
-          edit STEPS '3/6/9/12/18'
-          label files ""
-          label info ""
-          event fdb
-        task ansfc
-          trigger sp2fdb eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '15'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ./ansfc eq complete
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12dc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/12dc/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc015
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/fc/model:step ge 21 or /e_36r1/main/12dc/fc/model eq complete)
-          edit STEPS '3/6/9/12/15'
-          edit EMOS_BASE '18'
-          edit EMOS_TYPE 'fc'
-          task sp2fdb
-            label files ""
-            label info ""
-            event fdb
-          task fcsfc
-            trigger sp2fdb eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/fc/model eq complete)
-          edit STEPS_SPECTRAL '6/12'
-          edit EMOS_BASE '18'
-          edit STEPS '0/3/6/9/12/15'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task rmfdb
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/obs eq complete)
-        task flush
-          edit STREAM 'oper'
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'oedcdaan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12dc/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      family traj
-        task feed
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12dc/fc eq complete)
-        task cp_to_other
-          trigger feed eq complete
-      endfamily
-      family satmon
-        trigger ../00dc/satmon eq complete
-        edit FSFAMILY 'an'
-        inlimit /e_36r1/limits:smon
-        task getsmon
-          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
-        task smon_meris
-          trigger getsmon eq complete
-          edit smon_smsmode 'MERIS'
-        task smon_amsre
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMSRE'
-        task smon_ssmis
-          trigger getsmon eq complete
-          edit smon_smsmode 'SSMIS'
-        task smon_tmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'TMI'
-        task smon_gpsro
-          trigger getsmon eq complete
-          edit smon_smsmode 'GPSRO'
-        task smon_pacrars
-          trigger getsmon eq complete
-          edit smon_smsmode 'PACRARS'
-        task smon_ears
-          trigger getsmon eq complete
-          edit smon_smsmode 'EARS'
-        task smon_o3msg
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3MSG'
-        task smon_o3knmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3KNMI'
-        task smon_pwc
-          trigger getsmon eq complete
-          edit smon_smsmode 'PWC'
-        task smon_temp
-          trigger getsmon eq complete
-          edit smon_smsmode 'TEMP'
-        task smon_iasi
-          trigger getsmon eq complete
-          edit smon_smsmode 'IASI'
-        task smon_airs
-          trigger getsmon eq complete
-          edit smon_smsmode 'AIRS'
-        task smon_dbamv
-          trigger getsmon eq complete
-          edit smon_smsmode 'DBAMV'
-        task smon_amv
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMV'
-        task smon_o3
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3'
-        task smon_dmsp
-          trigger getsmon eq complete
-          edit smon_smsmode 'DMSP'
-        task smon_noaa
-          trigger getsmon eq complete
-          edit smon_smsmode 'NOAA'
-        task smon_geos
-          trigger getsmon eq complete
-          edit smon_smsmode 'GEOS'
-        task smon_scatt
-          trigger getsmon eq complete
-          edit smon_smsmode 'SCATT'
-        task smon_slmoist
-          trigger getsmon eq complete
-          edit smon_smsmode 'SLMOIST'
-        task smon_clean
-          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
-      endfamily
-      task clean
-        trigger fb eq complete and ../12/clean eq complete
-        edit FSFAMILY 'an'
-      task cleanplus6
-        trigger clean eq complete
-        edit EMOS_BASE '18'
-        edit FSFAMILY 'an'
-      family verif
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
-        edit DELTA_DAY '1'
-        inlimit /limits:linux_cluster
-        family fc
-          task v12li1
-          task v12li2
-          task v12up1
-            trigger v12li1 eq complete
-          task v12up2
-            trigger v12up1 eq complete and v12li2 eq complete
-          task v12pl
-            trigger v12up2 eq complete
-          task v12memv
-            trigger v12up2 eq complete
-            edit DATEMASK '02.*.*'
-          task v12memb
-            trigger v12up2 eq complete
-            edit DATEMASK '11.*.*'
-          task v12upmv
-            trigger v12memv eq complete
-            edit DATEMASK '02.*.*'
-          task v12upmb
-            trigger v12memb eq complete
-            edit DATEMASK '11.*.*'
-          task v12crmv
-            edit DATEMASK '28.*.*'
-          task v12crmb
-            edit DATEMASK '28.*.*'
-          task v12crd
-            edit DATEMASK '28.*.*'
-        endfamily
-        family oc
-          trigger ./fc eq complete or ./fc eq aborted
-          task mk_dummy_fields
-            edit QUEUE 'emos'
-            edit USER 'emos'
-            edit PP_BASE '/pp1'
-            edit WSHOST 'pp1'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit LOGDIR '/pp1/log'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit SMSOUT '/vol/emos_nc/output'
-          task insert_fields
-            trigger mk_dummy_fields eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit PP_BASE '/pp1'
-            inlimit /limits:linux_cluster
-          task vbrli1
-            trigger insert_fields eq complete
-          task vbrli2
-            trigger vbrli1 eq complete
-          task vwali1
-            trigger insert_fields eq complete
-          task vwali2
-            trigger vwali1 eq complete
-          task vwali3
-            trigger vwali2 eq complete
-          task vofli
-            trigger insert_fields eq complete
-          task vtlli
-            trigger insert_fields eq complete
-          task vtoli
-            trigger insert_fields eq complete
-          task vmoli
-            trigger insert_fields eq complete
-          task vbrup1
-            trigger vbrli1 eq complete
-          task vbrup2
-            trigger vbrup1 eq complete and vbrli2 eq complete
-          task vwaup1
-            trigger vwali1 eq complete
-          task vwaup2
-            trigger vwaup1 eq complete and vwali2 eq complete
-          task vwaup3
-            trigger vwaup2 eq complete and vwali3 eq complete
-          task vofup
-            trigger vofli eq complete
-          task vtlup
-            trigger vtlli eq complete
-          task vtoup
-            trigger vtoli eq complete
-          task vmoup
-            trigger vmoli eq complete
-          task vmeli
-            trigger insert_fields eq complete
-          task vmeup
-            trigger vmeli eq complete
-          task voccrd
-            edit DATEMASK '28.*.*'
-          task voccrm
-            edit DATEMASK '28.*.*'
-          task vocmem
-            edit DATEMASK '11.*.*'
-          task vocupm
-            trigger vocmem eq complete
-            edit DATEMASK '11.*.*'
-          task cleanup
-            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-        endfamily
-        family cf
-          trigger oc eq complete or oc eq aborted
-          task vcnli1
-            late -c +02:00
-          task vcnli2
-          task vcnup1
-            trigger vcnli1 eq complete
-          task vcnup2
-            trigger vcnup1 eq complete and vcnli2 eq complete
-          task vcnpl
-            trigger vcnup2 eq complete
-          task vcncrd
-          task vcncrm
-            edit DATEMASK '28.*.*'
-          task vcnmem
-            trigger vcnup2 eq complete
-            edit DATEMASK '11.*.*'
-          task vcnupm
-            trigger vcnmem eq complete
-            edit DATEMASK '11.*.*'
-          task vcnli3
-          task vcnli4
-          task vcnup3
-            trigger vcnup2 eq complete and vcnli3 eq complete
-          task vcnup4
-            trigger vcnup3 eq complete and vcnli4 eq complete
-          task vcnmem2
-            trigger vcnup4 eq complete
-            edit DATEMASK '22.*.*'
-          task vcnupm2
-            trigger vcnmem2 eq complete
-            edit DATEMASK '22.*.*'
-        endfamily
-        family ob
-          trigger oc eq complete or oc eq aborted
-          time 05:00
-          family stage1
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          family stage2
-            trigger ./stage1 eq complete
-            edit EMOS_BASE '00'
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          task vobcrd
-            edit DATEMASK '28.*.*'
-          task vobcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family em
-          task vemli
-            late -c +02:00
-          task vemup
-            trigger vemli eq complete
-          task vemcrd
-            edit DATEMASK '28.*.*'
-          task vemcrm
-            edit DATEMASK '28.*.*'
-          task vemmem
-            trigger vemup eq complete
-            edit DATEMASK '11.*.*'
-          task vemupm
-            trigger vemmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family es
-          trigger em eq complete
-          task vesli
-            late -c +02:00
-          task vesup
-            trigger vesli eq complete
-          task vescrd
-            edit DATEMASK '28.*.*'
-          task vescrm
-            edit DATEMASK '28.*.*'
-          task vesmem
-            trigger vesup eq complete
-            edit DATEMASK '11.*.*'
-          task vesupm
-            trigger vesmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family cv
-          trigger es eq complete
-          task vcvli
-            late -c +02:00
-          task vcvup
-            trigger vcvli eq complete
-          task vcvcrd
-            edit DATEMASK '28.*.*'
-          task vcvcrm
-            edit DATEMASK '28.*.*'
-          task vcvmem
-            trigger vcvup eq complete
-            edit DATEMASK '11.*.*'
-          task vcvupm
-            trigger vcvmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12dc/fc/model eq complete)
-          task glver
-          task glupr
-            trigger glver eq complete
-          task glcrr
-            edit DATEMASK '28.*.*'
-          task ff10ver
-            trigger glver eq complete
-          task ff10upr
-            trigger ff10ver eq complete and glupr eq complete
-          task glmem
-            trigger ff10upr eq complete
-            edit DATEMASK '11.*.*'
-          task glupm
-            trigger glmem eq complete
-            edit DATEMASK '11.*.*'
-          task glcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family sf
-          trigger fc eq complete or fc eq aborted
-          task vseli1
-          task vseli2
-          task vseup1
-            trigger vseli1 eq complete
-          task vseup2
-            trigger vseup1 eq complete and vseli2 eq complete
-          task vsecrd
-            edit DATEMASK '28.*.*'
-          task vsecrm
-            edit DATEMASK '28.*.*'
-          task vsemem
-            trigger vseup2 eq complete
-            edit DATEMASK '12.*.*'
-          task vseupm
-            trigger vsemem eq complete
-            edit DATEMASK '12.*.*'
-        endfamily
-      endfamily
-    endfamily
-    family 18
-      edit EMOS_BASE '18'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DA'
-      edit LAR_4V_EF 'false'
-      edit LFC_DIR_FREQ 'false'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/00/prod/18an eq complete)
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task ansfc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod/18an/derived_param eq complete))
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '6'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod/18an/derived_param eq complete))
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/18/an/4dvar/ifstraj:finaltraj or /e_36r1/main/18/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc015
-          edit STEPS '3/6/9/12/15'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18/fc/model eq complete)
-          edit STEPS '0/3/6/9/12/15'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'oeoperan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      family traj
-        task feed
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18/fc eq complete)
-        task cp_to_other
-          trigger feed eq complete
-      endfamily
-      family satmon
-        trigger ../00dc/satmon eq complete
-        edit FSFAMILY 'an'
-        inlimit /e_36r1/limits:smon
-        task getsmon
-          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
-        task smon_meris
-          trigger getsmon eq complete
-          edit smon_smsmode 'MERIS'
-        task smon_amsre
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMSRE'
-        task smon_ssmis
-          trigger getsmon eq complete
-          edit smon_smsmode 'SSMIS'
-        task smon_tmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'TMI'
-        task smon_gpsro
-          trigger getsmon eq complete
-          edit smon_smsmode 'GPSRO'
-        task smon_pacrars
-          trigger getsmon eq complete
-          edit smon_smsmode 'PACRARS'
-        task smon_ears
-          trigger getsmon eq complete
-          edit smon_smsmode 'EARS'
-        task smon_o3msg
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3MSG'
-        task smon_o3knmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3KNMI'
-        task smon_pwc
-          trigger getsmon eq complete
-          edit smon_smsmode 'PWC'
-        task smon_temp
-          trigger getsmon eq complete
-          edit smon_smsmode 'TEMP'
-        task smon_iasi
-          trigger getsmon eq complete
-          edit smon_smsmode 'IASI'
-        task smon_airs
-          trigger getsmon eq complete
-          edit smon_smsmode 'AIRS'
-        task smon_dbamv
-          trigger getsmon eq complete
-          edit smon_smsmode 'DBAMV'
-        task smon_amv
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMV'
-        task smon_o3
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3'
-        task smon_dmsp
-          trigger getsmon eq complete
-          edit smon_smsmode 'DMSP'
-        task smon_noaa
-          trigger getsmon eq complete
-          edit smon_smsmode 'NOAA'
-        task smon_geos
-          trigger getsmon eq complete
-          edit smon_smsmode 'GEOS'
-        task smon_scatt
-          trigger getsmon eq complete
-          edit smon_smsmode 'SCATT'
-        task smon_slmoist
-          trigger getsmon eq complete
-          edit smon_smsmode 'SLMOIST'
-        task smon_clean
-          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
-      endfamily
-      task clean
-        trigger fb eq complete and ../12dc/clean eq complete
-        edit FSFAMILY 'an'
-      family verif
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
-        edit DELTA_DAY '1'
-        inlimit /limits:linux_cluster
-        family fc
-          task v12li1
-          task v12li2
-          task v12up1
-            trigger v12li1 eq complete
-          task v12up2
-            trigger v12up1 eq complete and v12li2 eq complete
-          task v12pl
-            trigger v12up2 eq complete
-          task v12memv
-            trigger v12up2 eq complete
-            edit DATEMASK '02.*.*'
-          task v12memb
-            trigger v12up2 eq complete
-            edit DATEMASK '11.*.*'
-          task v12upmv
-            trigger v12memv eq complete
-            edit DATEMASK '02.*.*'
-          task v12upmb
-            trigger v12memb eq complete
-            edit DATEMASK '11.*.*'
-          task v12crmv
-            edit DATEMASK '28.*.*'
-          task v12crmb
-            edit DATEMASK '28.*.*'
-          task v12crd
-            edit DATEMASK '28.*.*'
-        endfamily
-        family oc
-          trigger ./fc eq complete or ./fc eq aborted
-          task mk_dummy_fields
-            edit QUEUE 'emos'
-            edit USER 'emos'
-            edit PP_BASE '/pp1'
-            edit WSHOST 'pp1'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit LOGDIR '/pp1/log'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit SMSOUT '/vol/emos_nc/output'
-          task insert_fields
-            trigger mk_dummy_fields eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit PP_BASE '/pp1'
-            inlimit /limits:linux_cluster
-          task vbrli1
-            trigger insert_fields eq complete
-          task vbrli2
-            trigger vbrli1 eq complete
-          task vwali1
-            trigger insert_fields eq complete
-          task vwali2
-            trigger vwali1 eq complete
-          task vwali3
-            trigger vwali2 eq complete
-          task vofli
-            trigger insert_fields eq complete
-          task vtlli
-            trigger insert_fields eq complete
-          task vtoli
-            trigger insert_fields eq complete
-          task vmoli
-            trigger insert_fields eq complete
-          task vbrup1
-            trigger vbrli1 eq complete
-          task vbrup2
-            trigger vbrup1 eq complete and vbrli2 eq complete
-          task vwaup1
-            trigger vwali1 eq complete
-          task vwaup2
-            trigger vwaup1 eq complete and vwali2 eq complete
-          task vwaup3
-            trigger vwaup2 eq complete and vwali3 eq complete
-          task vofup
-            trigger vofli eq complete
-          task vtlup
-            trigger vtlli eq complete
-          task vtoup
-            trigger vtoli eq complete
-          task vmoup
-            trigger vmoli eq complete
-          task vmeli
-            trigger insert_fields eq complete
-          task vmeup
-            trigger vmeli eq complete
-          task voccrd
-            edit DATEMASK '28.*.*'
-          task voccrm
-            edit DATEMASK '28.*.*'
-          task vocmem
-            edit DATEMASK '11.*.*'
-          task vocupm
-            trigger vocmem eq complete
-            edit DATEMASK '11.*.*'
-          task cleanup
-            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-        endfamily
-        family cf
-          trigger oc eq complete or oc eq aborted
-          task vcnli1
-            late -c +02:00
-          task vcnli2
-          task vcnup1
-            trigger vcnli1 eq complete
-          task vcnup2
-            trigger vcnup1 eq complete and vcnli2 eq complete
-          task vcnpl
-            trigger vcnup2 eq complete
-          task vcncrd
-          task vcncrm
-            edit DATEMASK '28.*.*'
-          task vcnmem
-            trigger vcnup2 eq complete
-            edit DATEMASK '11.*.*'
-          task vcnupm
-            trigger vcnmem eq complete
-            edit DATEMASK '11.*.*'
-          task vcnli3
-          task vcnli4
-          task vcnup3
-            trigger vcnup2 eq complete and vcnli3 eq complete
-          task vcnup4
-            trigger vcnup3 eq complete and vcnli4 eq complete
-          task vcnmem2
-            trigger vcnup4 eq complete
-            edit DATEMASK '22.*.*'
-          task vcnupm2
-            trigger vcnmem2 eq complete
-            edit DATEMASK '22.*.*'
-        endfamily
-        family ob
-          trigger oc eq complete or oc eq aborted
-          time 05:00
-          family stage1
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          family stage2
-            trigger ./stage1 eq complete
-            edit EMOS_BASE '00'
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          task vobcrd
-            edit DATEMASK '28.*.*'
-          task vobcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family em
-          task vemli
-            late -c +02:00
-          task vemup
-            trigger vemli eq complete
-          task vemcrd
-            edit DATEMASK '28.*.*'
-          task vemcrm
-            edit DATEMASK '28.*.*'
-          task vemmem
-            trigger vemup eq complete
-            edit DATEMASK '11.*.*'
-          task vemupm
-            trigger vemmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family es
-          trigger em eq complete
-          task vesli
-            late -c +02:00
-          task vesup
-            trigger vesli eq complete
-          task vescrd
-            edit DATEMASK '28.*.*'
-          task vescrm
-            edit DATEMASK '28.*.*'
-          task vesmem
-            trigger vesup eq complete
-            edit DATEMASK '11.*.*'
-          task vesupm
-            trigger vesmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family cv
-          trigger es eq complete
-          task vcvli
-            late -c +02:00
-          task vcvup
-            trigger vcvli eq complete
-          task vcvcrd
-            edit DATEMASK '28.*.*'
-          task vcvcrm
-            edit DATEMASK '28.*.*'
-          task vcvmem
-            trigger vcvup eq complete
-            edit DATEMASK '11.*.*'
-          task vcvupm
-            trigger vcvmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18/fc/model eq complete)
-          task glver
-          task glupr
-            trigger glver eq complete
-          task glcrr
-            edit DATEMASK '28.*.*'
-          task ff10ver
-            trigger glver eq complete
-          task ff10upr
-            trigger ff10ver eq complete and glupr eq complete
-          task glmem
-            trigger ff10upr eq complete
-            edit DATEMASK '11.*.*'
-          task glupm
-            trigger glmem eq complete
-            edit DATEMASK '11.*.*'
-          task glcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family sf
-          trigger fc eq complete or fc eq aborted
-          task vseli1
-          task vseli2
-          task vseup1
-            trigger vseli1 eq complete
-          task vseup2
-            trigger vseup1 eq complete and vseli2 eq complete
-          task vsecrd
-            edit DATEMASK '28.*.*'
-          task vsecrm
-            edit DATEMASK '28.*.*'
-          task vsemem
-            trigger vseup2 eq complete
-            edit DATEMASK '12.*.*'
-          task vseupm
-            trigger vsemem eq complete
-            edit DATEMASK '12.*.*'
-        endfamily
-      endfamily
-    endfamily
-    family 00
-      edit EMOS_BASE '00'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '1'
-      family ddh
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/fc eq complete)
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
-        task ddh
-      endfamily
-      family sync
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/an eq complete)
-        edit EMOS_TYPE 'an'
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
-        task sync_bias
-          edit CALC_PSBIAS 'false'
-        task sync_fc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/fc/model:step gt 6 or /e_36r1/main/00/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_an
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/fc/model:step gt 3 or /e_36r1/main/00/fc/model eq complete))
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-          label files ""
-          label info ""
-          event fdb
-        task sync_clean
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SCHOST 'c1a'
-          edit STHOST '/s1a'
-          edit SCHOST_BKUP 'c1b'
-          edit STHOST_BKUP '/s1b'
-          edit SMSLOGHOST 'c1a'
-          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1a
-      endfamily
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/00/an eq complete and ( ../../main/00/fc/model:step ge 9 or ../../main/00/fc/model eq complete))
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task ansfc
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/000 eq complete and /e_36r1/main/00/prod/00an eq complete)
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '240'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ./ansfc eq complete
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/an/4dvar/ifstraj:finaltraj or /e_36r1/main/00/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc024
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/024 eq complete)
-          edit STEPS '0/3/006/009/012/015/018/021/024'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc048
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/048 eq complete)
-          edit STEPS '027/030/033/036/039/042/045/048'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc072
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/072 eq complete)
-          edit STEPS '051/054/057/060/063/066/069/072'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc096
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/096 eq complete)
-          edit STEPS '075/078/081/084/087/090/093/096'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc120
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/120 eq complete)
-          edit STEPS '099/102/105/108/111/114/117/120'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc144
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/144 eq complete)
-          edit STEPS '123/126/129/132/135/138/141/144'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc192
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/192 eq complete)
-          edit STEPS '150/156/162/168/174/180/186/192'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc240
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/240 eq complete)
-          edit STEPS '198/204/210/216/222/228/234/240'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family satim1
-          task satim
-            trigger ../../satim eq complete
-            edit STEPS '0/to/48/by/3'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family satim2
-          task satim
-            trigger ../../satim eq complete
-            edit STEPS '54/to/120/by/6'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/fc/model eq complete)
-          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
-          edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'oeoperan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      family traj
-        task feed
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00/fc eq complete)
-        task cp_to_other
-          trigger feed eq complete
-      endfamily
-      family satim
-        edit QUEUE 'ns'
-        edit QUEUE_EPILOG 'ns'
-        edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-        edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-        edit MEM '11000'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-        edit SMSURLBASE 'http://intra.ecmwf.int/publications/cms/get/metapps'
-        inlimit /limits:c1b
-        task display_seaice
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/an eq complete)
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/admin'
-          edit FSFAMILY 'undef'
-          edit METVIEW 'metview_emos'
-          edit SMSURL 'seaice'
-          inlimit /limits:linux_cluster
-        task display_sst
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FSFAMILY 'undef'
-          edit SMSURL 'sst'
-          inlimit /limits:linux_cluster
-        family satim_0
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '0'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_3
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '3'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_6
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '6'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_9
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '9'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_12
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '12'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_15
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '15'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_18
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '18'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_21
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '21'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_24
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '24'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_27
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '27'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_30
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '30'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_33
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '33'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_36
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '36'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_39
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '39'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_42
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '42'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_45
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '45'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_48
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '48'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_54
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '54'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_60
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '60'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_66
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '66'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_72
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '72'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_78
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '78'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_84
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '84'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_90
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '90'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_96
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '96'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_102
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '102'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_108
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '108'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_114
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '114'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-        family satim_120
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
-          edit IMAGETIME '120'
-          edit WMOID 'undef'
-          family retr
-            edit SATIM_MODE '1'
-            inlimit /e_36r1/limits:satimsim_ret
-            task satimsim
-              edit MEM '781'
-          endfamily
-          family sat
-            trigger ./retr eq complete
-            edit SATIM_MODE '2'
-            inlimit /e_36r1/limits:satimsim
-            family sat_54
-              edit WMOID '54'
-              task satimsim
-            endfamily
-            family sat_56
-              edit WMOID '56'
-              task satimsim
-            endfamily
-            family sat_171
-              edit WMOID '171'
-              task satimsim
-            endfamily
-            family sat_255
-              edit WMOID '255'
-              task satimsim
-            endfamily
-            family sat_256
-              edit WMOID '256'
-              task satimsim
-            endfamily
-          endfamily
-          family satim_flush
-            trigger ./sat eq complete
-            edit SATIM_MODE '3'
-            task satimsim
-              edit MEM '781'
-          endfamily
-        endfamily
-      endfamily
-      family satmon
-        trigger ../00dc/satmon eq complete
-        edit FSFAMILY 'an'
-        inlimit /e_36r1/limits:smon
-        task getsmon
-          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
-        task smon_meris
-          trigger getsmon eq complete
-          edit smon_smsmode 'MERIS'
-        task smon_amsre
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMSRE'
-        task smon_ssmis
-          trigger getsmon eq complete
-          edit smon_smsmode 'SSMIS'
-        task smon_tmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'TMI'
-        task smon_gpsro
-          trigger getsmon eq complete
-          edit smon_smsmode 'GPSRO'
-        task smon_pacrars
-          trigger getsmon eq complete
-          edit smon_smsmode 'PACRARS'
-        task smon_ears
-          trigger getsmon eq complete
-          edit smon_smsmode 'EARS'
-        task smon_o3msg
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3MSG'
-        task smon_o3knmi
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3KNMI'
-        task smon_pwc
-          trigger getsmon eq complete
-          edit smon_smsmode 'PWC'
-        task smon_temp
-          trigger getsmon eq complete
-          edit smon_smsmode 'TEMP'
-        task smon_iasi
-          trigger getsmon eq complete
-          edit smon_smsmode 'IASI'
-        task smon_airs
-          trigger getsmon eq complete
-          edit smon_smsmode 'AIRS'
-        task smon_dbamv
-          trigger getsmon eq complete
-          edit smon_smsmode 'DBAMV'
-        task smon_amv
-          trigger getsmon eq complete
-          edit smon_smsmode 'AMV'
-        task smon_o3
-          trigger getsmon eq complete
-          edit smon_smsmode 'O3'
-        task smon_dmsp
-          trigger getsmon eq complete
-          edit smon_smsmode 'DMSP'
-        task smon_noaa
-          trigger getsmon eq complete
-          edit smon_smsmode 'NOAA'
-        task smon_geos
-          trigger getsmon eq complete
-          edit smon_smsmode 'GEOS'
-        task smon_scatt
-          trigger getsmon eq complete
-          edit smon_smsmode 'SCATT'
-        task smon_slmoist
-          trigger getsmon eq complete
-          edit smon_smsmode 'SLMOIST'
-        task smon_clean
-          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
-      endfamily
-      task clean
-        trigger fb eq complete and ../18/clean eq complete
-        edit FSFAMILY 'an'
-      family verif
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
-        edit DELTA_DAY '1'
-        inlimit /limits:linux_cluster
-        time 09:00
-        family fc
-          task v12li1
-          task v12li2
-          task v12up1
-            trigger v12li1 eq complete
-          task v12up2
-            trigger v12up1 eq complete and v12li2 eq complete
-          task v12pl
-            trigger v12up2 eq complete
-          task v12memv
-            trigger v12up2 eq complete
-            edit DATEMASK '02.*.*'
-          task v12memb
-            trigger v12up2 eq complete
-            edit DATEMASK '11.*.*'
-          task v12upmv
-            trigger v12memv eq complete
-            edit DATEMASK '02.*.*'
-          task v12upmb
-            trigger v12memb eq complete
-            edit DATEMASK '11.*.*'
-          task v12crmv
-            edit DATEMASK '28.*.*'
-          task v12crmb
-            edit DATEMASK '28.*.*'
-          task v12crd
-            edit DATEMASK '28.*.*'
-        endfamily
-        family oc
-          trigger ./fc eq complete or ./fc eq aborted
-          task mk_dummy_fields
-            edit QUEUE 'emos'
-            edit USER 'emos'
-            edit PP_BASE '/pp1'
-            edit WSHOST 'pp1'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit LOGDIR '/pp1/log'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit SMSOUT '/vol/emos_nc/output'
-          task insert_fields
-            trigger mk_dummy_fields eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit PP_BASE '/pp1'
-            inlimit /limits:linux_cluster
-          task vbrli1
-            trigger insert_fields eq complete
-          task vbrli2
-            trigger vbrli1 eq complete
-          task vwali1
-            trigger insert_fields eq complete
-          task vwali2
-            trigger vwali1 eq complete
-          task vwali3
-            trigger vwali2 eq complete
-          task vofli
-            trigger insert_fields eq complete
-          task vtlli
-            trigger insert_fields eq complete
-          task vtoli
-            trigger insert_fields eq complete
-          task vmoli
-            trigger insert_fields eq complete
-          task vbrup1
-            trigger vbrli1 eq complete
-          task vbrup2
-            trigger vbrup1 eq complete and vbrli2 eq complete
-          task vwaup1
-            trigger vwali1 eq complete
-          task vwaup2
-            trigger vwaup1 eq complete and vwali2 eq complete
-          task vwaup3
-            trigger vwaup2 eq complete and vwali3 eq complete
-          task vofup
-            trigger vofli eq complete
-          task vtlup
-            trigger vtlli eq complete
-          task vtoup
-            trigger vtoli eq complete
-          task vmoup
-            trigger vmoli eq complete
-          task vmeli
-            trigger insert_fields eq complete
-          task vmeup
-            trigger vmeli eq complete
-          task voccrd
-            edit DATEMASK '28.*.*'
-          task voccrm
-            edit DATEMASK '28.*.*'
-          task vocmem
-            edit DATEMASK '11.*.*'
-          task vocupm
-            trigger vocmem eq complete
-            edit DATEMASK '11.*.*'
-          task cleanup
-            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-        endfamily
-        family cf
-          trigger oc eq complete or oc eq aborted
-          task vcnli1
-            late -c +02:00
-          task vcnli2
-          task vcnup1
-            trigger vcnli1 eq complete
-          task vcnup2
-            trigger vcnup1 eq complete and vcnli2 eq complete
-          task vcnpl
-            trigger vcnup2 eq complete
-          task vcncrd
-          task vcncrm
-            edit DATEMASK '28.*.*'
-          task vcnmem
-            trigger vcnup2 eq complete
-            edit DATEMASK '11.*.*'
-          task vcnupm
-            trigger vcnmem eq complete
-            edit DATEMASK '11.*.*'
-          task vcnli3
-          task vcnli4
-          task vcnup3
-            trigger vcnup2 eq complete and vcnli3 eq complete
-          task vcnup4
-            trigger vcnup3 eq complete and vcnli4 eq complete
-          task vcnmem2
-            trigger vcnup4 eq complete
-            edit DATEMASK '22.*.*'
-          task vcnupm2
-            trigger vcnmem2 eq complete
-            edit DATEMASK '22.*.*'
-        endfamily
-        family ob
-          trigger oc eq complete or oc eq aborted
-          time 05:00
-          family stage1
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          family stage2
-            trigger ./stage1 eq complete
-            edit EMOS_BASE '00'
-            task vobli1
-            task vobli2
-            task vobup1
-              trigger vobli1 eq complete
-            task vobup2
-              trigger vobup1 eq complete and vobli2 eq complete
-            task vobnobs
-              trigger vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobmem
-              trigger ./vobup2 eq complete
-              edit DATEMASK '03.*.*'
-            task vobupm
-              trigger vobmem eq complete
-              edit DATEMASK '03.*.*'
-          endfamily
-          task vobcrd
-            edit DATEMASK '28.*.*'
-          task vobcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family em
-          task vemli
-            late -c +02:00
-          task vemup
-            trigger vemli eq complete
-          task vemcrd
-            edit DATEMASK '28.*.*'
-          task vemcrm
-            edit DATEMASK '28.*.*'
-          task vemmem
-            trigger vemup eq complete
-            edit DATEMASK '11.*.*'
-          task vemupm
-            trigger vemmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family es
-          trigger em eq complete
-          task vesli
-            late -c +02:00
-          task vesup
-            trigger vesli eq complete
-          task vescrd
-            edit DATEMASK '28.*.*'
-          task vescrm
-            edit DATEMASK '28.*.*'
-          task vesmem
-            trigger vesup eq complete
-            edit DATEMASK '11.*.*'
-          task vesupm
-            trigger vesmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family cv
-          trigger es eq complete
-          task vcvli
-            late -c +02:00
-          task vcvup
-            trigger vcvli eq complete
-          task vcvcrd
-            edit DATEMASK '28.*.*'
-          task vcvcrm
-            edit DATEMASK '28.*.*'
-          task vcvmem
-            trigger vcvup eq complete
-            edit DATEMASK '11.*.*'
-          task vcvupm
-            trigger vcvmem eq complete
-            edit DATEMASK '11.*.*'
-        endfamily
-        family wv
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00/fc/model eq complete)
-          task glver
-          task glupr
-            trigger glver eq complete
-          task glcrr
-            edit DATEMASK '28.*.*'
-          task ff10ver
-            trigger glver eq complete
-          task ff10upr
-            trigger ff10ver eq complete and glupr eq complete
-          task glmem
-            trigger ff10upr eq complete
-            edit DATEMASK '11.*.*'
-          task glupm
-            trigger glmem eq complete
-            edit DATEMASK '11.*.*'
-          task glcrm
-            edit DATEMASK '28.*.*'
-        endfamily
-        family sf
-          trigger fc eq complete or fc eq aborted
-          task vseli1
-          task vseli2
-          task vseup1
-            trigger vseli1 eq complete
-          task vseup2
-            trigger vseup1 eq complete and vseli2 eq complete
-          task vsecrd
-            edit DATEMASK '28.*.*'
-          task vsecrm
-            edit DATEMASK '28.*.*'
-          task vsemem
-            trigger vseup2 eq complete
-            edit DATEMASK '12.*.*'
-          task vseupm
-            trigger vsemem eq complete
-            edit DATEMASK '12.*.*'
-        endfamily
-      endfamily
-    endfamily
-    family 12bc
-      edit EMOS_BASE '12'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '0'
-      family verif
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/fc eq complete)
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
-        edit SCORE_STREAM 'BC_0046'
-        inlimit /limits:linux_cluster
-        task create_daily
-        task create_monthly
-          edit DATEMASK '28.*.*'
-        task clim
-          trigger create_daily eq complete
-        task non_clim
-          trigger create_daily eq complete
-        task clim_update
-          trigger clim eq complete
-        task non_clim_update
-          trigger non_clim eq complete and clim eq complete
-        task plot
-          trigger non_clim_update eq complete
-        task mean
-          trigger non_clim_update eq complete
-          edit DATEMASK '10.*.*'
-        task mean_update
-          trigger mean eq complete
-          edit DATEMASK '10.*.*'
-      endfamily
-    endfamily
-    family 18bc
-      edit EMOS_BASE '18'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '0'
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/18bc/an eq complete and ( ../../main/18bc/fc/model:step ge 90 or ../../main/18bc/fc/model eq complete))
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task ansfc
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          edit EDFAMILY 'true'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '9'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ./ansfc eq complete
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/18bc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/18bc/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc024
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/024 eq complete)
-          edit STEPS '0/3/06/09/12/15/18/21/24'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc048
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/048 eq complete)
-          edit STEPS '27/30/33/36/39/42/45/48'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc072
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/072 eq complete)
-          edit STEPS '51/54/57/60/63/66/69/72'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc090
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/090 eq complete)
-          edit STEPS '75/78/81/84/87/90'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/fc/model eq complete)
-          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
-          edit STEPS '0/6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'opebcan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18bc/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      task clean
-        trigger fb eq complete
-        edit FSFAMILY 'an'
-      family verif
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/fc eq complete)
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
-        edit SCORE_STREAM 'BC_0046'
-        inlimit /limits:linux_cluster
-        task create_daily
-        task create_monthly
-          edit DATEMASK '28.*.*'
-        task clim
-          trigger create_daily eq complete
-        task non_clim
-          trigger create_daily eq complete
-        task clim_update
-          trigger clim eq complete
-        task non_clim_update
-          trigger non_clim eq complete and clim eq complete
-        task plot
-          trigger non_clim_update eq complete
-        task mean
-          trigger non_clim_update eq complete
-          edit DATEMASK '10.*.*'
-        task mean_update
-          trigger mean eq complete
-          edit DATEMASK '10.*.*'
-      endfamily
-    endfamily
-    family 00bc
-      edit EMOS_BASE '00'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '1'
-      family verif
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/fc eq complete)
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
-        edit SCORE_STREAM 'BC_0046'
-        inlimit /limits:linux_cluster
-        task create_daily
-        task create_monthly
-          edit DATEMASK '28.*.*'
-        task clim
-          trigger create_daily eq complete
-        task non_clim
-          trigger create_daily eq complete
-        task clim_update
-          trigger clim eq complete
-        task non_clim_update
-          trigger non_clim eq complete and clim eq complete
-        task plot
-          trigger non_clim_update eq complete
-        task mean
-          trigger non_clim_update eq complete
-          edit DATEMASK '10.*.*'
-        task mean_update
-          trigger mean eq complete
-          edit DATEMASK '10.*.*'
-      endfamily
-    endfamily
-    family 06bc
-      edit EMOS_BASE '06'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '6'
-      edit WINDOW_OFFSET_4D '3'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '1'
-      family archive
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/06bc/an eq complete and ( ../../main/06bc/fc/model:step ge 90 or ../../main/06bc/fc/model eq complete))
-        edit FSFAMILY 'mars'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
-        edit EMOS_TYPE 'an'
-        inlimit /limits:mars
-        inlimit /e_36r1/limits:mars
-        task ansfc
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anml
-          trigger ansfc:fdb or ansfc eq complete
-          edit EDFAMILY 'true'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          inlimit /e_36r1/limits:ml
-          label files ""
-          label info ""
-          event fdb
-        task anpl
-          trigger anml:fdb or anml eq complete
-          edit FCLENGTH '9'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anwave
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task anil
-          trigger anpl:fdb or anpl eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task derivedp
-          trigger ./ansfc eq complete
-          edit STEPS '0'
-          label files ""
-          label info ""
-          event fdb
-        family obs
-          edit FSFAMILY 'an'
-          inlimit /e_36r1/limits:obs
-          task highres
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            inlimit /limits:linux_cluster
-          task ai
-            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/06bc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/06bc/an/4dvar eq complete))
-            edit TYPE 'ai'
-            label files ""
-            label info ""
-            event fdb
-          task af
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'af'
-            label files ""
-            label info ""
-            event fdb
-          task fb
-            trigger ../../fb/feedback eq complete
-            edit TYPE 'fb'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task ice_nmc
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task sst
-          trigger ansfc:fdb or ansfc eq complete
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        family fc024
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/024 eq complete)
-          edit STEPS '0/3/06/09/12/15/18/21/24'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc048
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/048 eq complete)
-          edit STEPS '27/30/33/36/39/42/45/48'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc072
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/072 eq complete)
-          edit STEPS '51/54/57/60/63/66/69/72'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family fc090
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/090 eq complete)
-          edit STEPS '75/78/81/84/87/90'
-          edit EMOS_TYPE 'fc'
-          task fcsfc
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcml
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            inlimit /e_36r1/limits:ml
-            label files ""
-            label info ""
-            event fdb
-          task fcpl
-            trigger fcsfc:fdb or fcsfc eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task fcil
-            trigger fcpl:fdb or fcpl eq complete
-            inlimit /limits:mars
-            inlimit /e_36r1/limits:mars
-            label files ""
-            label info ""
-            event fdb
-          task derivedp
-            trigger fcil:fdb or fcil eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        task fc12g
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/fc/model eq complete)
-          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
-          edit STEPS '0/6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
-          inlimit /limits:mars
-          inlimit /e_36r1/limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task rmfdb
-          trigger ansfc eq complete and anml eq complete and anpl eq complete and anwave eq complete and obs eq complete
-      endfamily
-      family fb
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/an eq complete)
-        edit FSFAMILY 'an'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
-        task sync_rstrhbias
-          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
-        task biassave
-          trigger sync_rstrhbias eq complete
-        family feedback
-          edit ACCOUNT 'opebcan'
-          edit NPES '8'
-          edit FBNEW2OLD '1'
-          edit LCONV '1'
-          edit LSATOB '1'
-          edit LREO3 '1'
-          edit LAEOLUS '0'
-          edit LSSMI '1'
-          edit LSSMIS '1'
-          edit LAMSRE '1'
-          edit LTMI '1'
-          edit LHIRS '1'
-          edit LMSU '1'
-          edit LSSU '1'
-          edit LAMSUA '1'
-          edit LAMSUB '1'
-          edit LMHS '1'
-          edit LGEOS '1'
-          edit LSCAT '1'
-          edit LAIRS '1'
-          edit LVTPR1 '0'
-          edit LVTPR2 '0'
-          edit LGPSRO '1'
-          edit LIASI '1'
-          edit LMERIS '1'
-          task revmatchup
-            edit NPES '128'
-            edit THREADS '2'
-          task matchup
-            trigger revmatchup eq complete
-            edit NPES '128'
-            edit THREADS '2'
-          task odbcmp_prepare
-            edit THREADS '1'
-            edit NPES '1'
-            edit MEM '1000'
-            edit CPUTIME '1000'
-            edit PRIORITY '90'
-          family odb_compress
-            trigger odbcmp_prepare eq complete and matchup eq complete
-            edit THREADS '2'
-            edit NPES '1'
-            task odbcmp_conv
-            task odbcmp_surf_conv
-            task odbcmp_airs
-            task odbcmp_iasi
-            task odbcmp_hirs
-            task odbcmp_msu
-            task odbcmp_ssu
-            task odbcmp_amsua
-            task odbcmp_amsub
-            task odbcmp_mhs
-            task odbcmp_satob
-            task odbcmp_reo3
-            task odbcmp_ssmi
-            task odbcmp_ssmis
-            task odbcmp_amsre
-            task odbcmp_tmi
-            task odbcmp_scatt
-            task odbcmp_geos
-            task odbcmp_gpsro
-            task odbcmp_meris
-          endfamily
-          family odb2bufr
-            trigger matchup eq complete
-            edit NPES '1'
-            edit SUBTYPES_INCLUDE ''
-            edit SUBTYPES_EXCLUDE ''
-            task o2b_conv
-              edit SUBTYPES_EXCLUDE '85 82 83 87'
-              edit NPES '2'
-            task o2b_surf_conv
-              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
-              edit NPES '2'
-            task o2b_airs
-              edit SUBTYPES_INCLUDE '57'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_iasi
-              edit SUBTYPES_INCLUDE '240'
-              edit NPES '8'
-              edit THREADS '2'
-            task o2b_hirs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_msu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_ssu
-              edit SUBTYPES_INCLUDE '54 55'
-            task o2b_amsua
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_amsub
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_mhs
-              edit SUBTYPES_INCLUDE '54 55'
-              edit NPES '2'
-            task o2b_satob
-              edit SUBTYPES_INCLUDE '82 83 87'
-              edit NPES '2'
-            task o2b_reo3
-              edit SUBTYPES_INCLUDE '205 206 207 208 215'
-              edit NPES '4'
-              edit THREADS '2'
-            task o2b_ssmi
-              edit SUBTYPES_INCLUDE '55 127'
-            task o2b_ssmis
-              edit SUBTYPES_INCLUDE '49'
-            task o2b_amsre
-              edit SUBTYPES_INCLUDE '59'
-            task o2b_tmi
-              edit SUBTYPES_INCLUDE '129'
-            task o2b_scatt
-              edit SUBTYPES_INCLUDE '122 137 139'
-            task o2b_geos
-              edit SUBTYPES_INCLUDE '189 89 76 77 78'
-              edit NPES '2'
-            task o2b_gpsro
-              edit SUBTYPES_INCLUDE '250'
-            task o2b_meris
-              edit SUBTYPES_INCLUDE '212'
-          endfamily
-          task mergebufr
-            trigger odb2bufr eq complete
-        endfamily
-        family obstat
-          trigger feedback/odb2bufr eq complete
-          edit NPES '1'
-          task obstat_conv
-          task obstat_surf_conv
-          task obstat_airs
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_iasi
-            edit NPES '8'
-            edit THREADS '2'
-          task obstat_hirs
-            edit NPES '4'
-          task obstat_msu
-          task obstat_ssu
-          task obstat_amsua
-            edit NPES '2'
-          task obstat_amsub
-          task obstat_mhs
-          task obstat_satob
-          task obstat_reo3
-          task obstat_ssmi
-            edit NPES '2'
-          task obstat_ssmis
-            edit NPES '2'
-          task obstat_amsre
-            edit NPES '2'
-          task obstat_tmi
-            edit NPES '2'
-          task obstat_scatt
-          task obstat_geos
-            edit NPES '2'
-          task obstat_gpsro
-            edit NPES '2'
-          task obstat_meris
-            edit NPES '2'
-        endfamily
-        task fdbksave
-          trigger feedback eq complete and obstat eq complete
-        task clean_odbcmp
-          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
-        task wavesave
-          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06bc/an/4dvar eq complete)
-        task obstat_merge
-          trigger obstat eq complete
-          edit WSHOST 'bee01'
-          edit PRIORITY '51'
-      endfamily
-      task clean
-        trigger fb eq complete
-        edit FSFAMILY 'an'
-      family verif
-        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/fc eq complete)
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
-        edit SCORE_STREAM 'BC_0046'
-        inlimit /limits:linux_cluster
-        task create_daily
-        task create_monthly
-          edit DATEMASK '28.*.*'
-        task clim
-          trigger create_daily eq complete
-        task non_clim
-          trigger create_daily eq complete
-        task clim_update
-          trigger clim eq complete
-        task non_clim_update
-          trigger non_clim eq complete and clim eq complete
-        task plot
-          trigger non_clim_update eq complete
-        task mean
-          trigger non_clim_update eq complete
-          edit DATEMASK '10.*.*'
-        task mean_update
-          trigger mean eq complete
-          edit DATEMASK '10.*.*'
-      endfamily
-    endfamily
-    task checkarchive
-      trigger ./06 eq complete and ./12 eq complete and ./12dc eq complete and ./18 eq complete and ./00 eq complete and ./00dc eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FSFAMILY 'mars'
-      edit EMOS_TYPE 'an'
-      edit OSTREAN 'DCDA DCWV'
-      edit WSHOST 'linux_cluster'
-      inlimit /limits:linux_cluster
-    task checkarchivebc
-      trigger ./18bc eq complete and ./06bc eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit STREAM 'SCDA'
-      edit FSFAMILY 'mars'
-      edit EMOS_TYPE 'an'
-      edit WSTREAN 'DCDA DCWV'
-      edit WSHOST 'linux_cluster'
-      inlimit /limits:linux_cluster
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'lag'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger /e_36r1/main/make eq complete and ./00dc eq complete and ./06 eq complete and ./12 eq complete and ./12dc eq complete and ./18 eq complete and ./00 eq complete and ./12bc eq complete and ./18bc eq complete and ./00bc eq complete and ./06bc eq complete and checkarchive eq complete and checkarchivebc eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'lag'
-      edit MOVE_TO_ECFS 'no'
-      time 11:45
-  endfamily
-  family verify
-    repeat date YMD 20091118 20121212 1
-    edit VERIFY 'verify_test'
-    edit UPDATE_WEB_NOW 'yes'
-    edit SMSFILES '/home/ma/emos/def/e_36r1/verify'
-    edit FORECAST_DELTA '1'
-    edit RUN_PARALLEL '0'
-    edit EXPVERV '0046'
-    edit EXPVERP '0046'
-    edit EXPVERF '0046'
-    edit CLASSV 'od'
-    edit CLASSP 'od'
-    edit CLASSF 'od'
-    edit QUEUE 'emos-e'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit SMSOUT '/vol/emos_nc/output'
-    inlimit /limits:mars
-    inlimit /limits:linux_cluster
-    family 12
-      edit EMOS_BASE '12'
-      family forecast
-        trigger ( /e_36r1/lag:YMD gt /e_36r1/verify:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/verify:YMD and ../../lag/12/archive eq complete)
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SCORE_STREAM '36r1_0046'
-        edit OPER_STREAM 'OPER'
-        edit INDEX_SIZE '102400'
-        inlimit /limits:linux_cluster
-        task create_score
-        family clim_levels
-          trigger create_score eq complete
-          task fc_clim_levels
-          task update_score
-            trigger fc_clim_levels eq complete
-        endfamily
-        family non_clim_levels
-          trigger create_score eq complete
-          task fc_non_clim_levels
-          task update_score
-            trigger fc_non_clim_levels eq complete and ../clim_levels eq complete
-        endfamily
-        family others
-          trigger create_score eq complete
-          task fc_others
-          task update_score
-            trigger fc_others eq complete and ../non_clim_levels eq complete
-        endfamily
-      endfamily
-      family observations
-        trigger forecast eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit FORECAST_DELTA '3'
-        edit SCORE_STREAM '36r1_0046_OB'
-        edit OPER_STREAM 'O_ECMWF'
-        edit INDEX_SIZE '102400'
-        inlimit /limits:linux_cluster
-        task create_score
-        family clim_levels
-          trigger create_score eq complete
-          task ob_clim_levels
-          task update_score
-            trigger ob_clim_levels eq complete
-        endfamily
-        family non_clim_levels
-          trigger create_score eq complete
-          task ob_non_clim_levels
-          task update_score
-            trigger ob_non_clim_levels eq complete and ../clim_levels eq complete
-        endfamily
-      endfamily
-      family waves
-        trigger forecast eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit INDEX_SIZE '102400'
-        edit SCORE_STREAM '36r1_0046_WV'
-        edit OPER_STREAM 'WAVE_G'
-        inlimit /limits:linux_cluster
-        family height
-          edit STREAM 'WV'
-          task create_score
-          task wv_height
-            trigger create_score eq complete
-          task update_score
-            trigger wv_height eq complete
-        endfamily
-        family wind
-          trigger height eq complete
-          task wv_wind_all
-          task update_score
-            trigger wv_wind_all eq complete
-        endfamily
-        family wind_over_sea
-          trigger wind eq complete
-          edit INDEX_SIZE '102400'
-          edit SCORE_STREAM '36r1_0046_WV_SEA'
-          task create_score
-          task wv_wind_sea
-            trigger create_score eq complete
-          task update_score
-            trigger wv_wind_sea eq complete
-        endfamily
-      endfamily
-    endfamily
-    family 00
-      trigger ./12 eq complete
-      edit EMOS_BASE '00'
-      family forecast
-        trigger ( /e_36r1/lag:YMD gt /e_36r1/verify:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/verify:YMD and ../../lag/00/archive eq complete)
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SCORE_STREAM '36r1_0046'
-        edit OPER_STREAM 'OPER'
-        edit INDEX_SIZE '102400'
-        inlimit /limits:linux_cluster
-        task create_score
-        family clim_levels
-          trigger create_score eq complete
-          task fc_clim_levels
-          task update_score
-            trigger fc_clim_levels eq complete
-        endfamily
-        family non_clim_levels
-          trigger create_score eq complete
-          task fc_non_clim_levels
-          task update_score
-            trigger fc_non_clim_levels eq complete and ../clim_levels eq complete
-        endfamily
-        family others
-          trigger create_score eq complete
-          task fc_others
-          task update_score
-            trigger fc_others eq complete and ../non_clim_levels eq complete
-        endfamily
-      endfamily
-      family observations
-        trigger forecast eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit FORECAST_DELTA '3'
-        edit SCORE_STREAM '36r1_0046_OB'
-        edit OPER_STREAM 'O_ECMWF'
-        edit INDEX_SIZE '102400'
-        inlimit /limits:linux_cluster
-        task create_score
-        family clim_levels
-          trigger create_score eq complete
-          task ob_clim_levels
-          task update_score
-            trigger ob_clim_levels eq complete
-        endfamily
-        family non_clim_levels
-          trigger create_score eq complete
-          task ob_non_clim_levels
-          task update_score
-            trigger ob_non_clim_levels eq complete and ../clim_levels eq complete
-        endfamily
-      endfamily
-      family waves
-        trigger forecast eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit INDEX_SIZE '102400'
-        edit SCORE_STREAM '36r1_0046_WV'
-        edit OPER_STREAM 'WAVE_G'
-        inlimit /limits:linux_cluster
-        family height
-          edit STREAM 'WV'
-          task create_score
-          task wv_height
-            trigger create_score eq complete
-          task update_score
-            trigger wv_height eq complete
-        endfamily
-        family wind
-          trigger height eq complete
-          task wv_wind_all
-          task update_score
-            trigger wv_wind_all eq complete
-        endfamily
-        family wind_over_sea
-          trigger wind eq complete
-          edit INDEX_SIZE '102400'
-          edit SCORE_STREAM '36r1_0046_WV_SEA'
-          task create_score
-          task wv_wind_sea
-            trigger create_score eq complete
-          task update_score
-            trigger wv_wind_sea eq complete
-        endfamily
-      endfamily
-    endfamily
-    family plot
-      trigger ./00 eq complete and ./12 eq complete
-      edit WSHOST 'linux_cluster'
-      edit QUEUE 'serial'
-      limit plot 3
-      inlimit plot
-      family forecast
-        edit SCORE_STREAM '36r1_0046'
-        edit OPER_STREAM 'OPER'
-        edit FORECAST_DELTA '1'
-        task fc_scocom
-        task fc_scocat
-        task fc_pltime
-        task fc_error
-      endfamily
-      family observations
-        edit SCORE_STREAM '36r1_0046_OB'
-        edit OPER_STREAM 'O_ECMWF'
-        edit FORECAST_DELTA '3'
-        task ob_scocom
-        task ob_scocat
-        task ob_pltime
-        task ob_error
-      endfamily
-      family waves
-        edit SCORE_STREAM '36r1_0046_WV'
-        edit OPER_STREAM 'WAVE_G'
-        edit FORECAST_DELTA '1'
-        task wv_scocom
-        task wv_scocat
-        task wv_pltime
-        task wv_error
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'verify'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./00 eq complete and ./12 eq complete and plot eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'verify'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGSTOECFS 'no'
-      time 11:45
-  endfamily
-  family pop
-    repeat date YMD 20091118 20121212 1
-    edit VERIFY 'verify_test'
-    edit QUEUE 'emos-e'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit SMSOUT '/vol/emos_nc/output'
-    edit METVIEW '/usr/local/share/metview'
-    inlimit /limits:linux_cluster
-    family 00
-      edit EMOS_BASE '00'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '1'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
-      family data
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
-        family fields
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit STEP_LIST '12/to/240/by/12'
-          inlimit /e_36r1/limits:webplots
-          task z500
-          task mslp
-          task mslp_gg
-          task t850
-          task rain
-          task t2m
-          task w30m
-          task cloud
-          task waves
-          task rainp
-          task w10m
-          task wind
-            edit STEP_LIST '24/to/240/by/24'
-          task rh
-            edit STEP_LIST '24/to/240/by/24'
-          task vorticity
-            edit STEP_LIST '24/to/240/by/24'
-          task divergence
-            edit STEP_LIST '24/to/240/by/24'
-        endfamily
-        family metgram
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete and /mc/main/00/legA/fc eq complete)
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit RHOST 'epsgrams'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/plot/metgram'
-          inlimit /limits:linux_cluster
-          task metret
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete )
-          task metclean
-            trigger metret eq complete
-            edit DELTA_DAY '-2'
-          family fc
-            edit KIND 'metgram_fc'
-            edit ENSEMBLES '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/epsgrams/grams'
-            task gclean
-              edit REMOTE_KEEP_DAYS '3'
-              edit KEEP_DAYS '3'
-            task gdb
-              trigger gclean eq complete
-              label files ""
-              label info ""
-              event 1 
-              event fdb
-            task glink
-              trigger gdb eq complete
-          endfamily
-        endfamily
-        family bufr
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task feedback
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00/archive/obs eq complete)
-        endfamily
-      endfamily
-      family web
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-        family fc
-          trigger ../data/fields eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          inlimit /e_36r1/limits:webplots
-          family members
-            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa'
-            edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168,180,192,204,216,228,240'
-            edit PLOT_LEGS '1'
-            task w_z500t850
-            task w_mslrain
-            task w_t2m30mw
-            task w_clouds
-            task w_waves
-              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-            task w_mwp
-              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-          endfamily
-          family additional
-            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
-            edit PLOT_STEPS '0,24,48,72,96,120,144,168'
-            task w_uv_rh
-            task w_msl_uv200
-            task w_z500t850_gts
-              edit PLOT_STEPS '0,24,48,72,96,120,144,168,192,216,240'
-            task w_vordir
-              edit PLOT_STEPS '0,24,48,72,96,120,144'
-            family wmo_swh_dir
-              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
-              edit PLOT_AREAS 'Global'
-              edit PLOT_TYPE '_wmo'
-              task w_waves
-            endfamily
-            family wmo_mwp_dir
-              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
-              edit PLOT_AREAS 'Global'
-              edit PLOT_TYPE '_wmo'
-              task w_mwp
-            endfamily
-          endfamily
-          family essential
-            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
-            edit PLOT_STEPS '72,96,120,144,168,192,216,240'
-            task public_plots
-          endfamily
-          task web_update
-            trigger members eq complete and additional eq complete and essential eq complete
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            edit PACKAGES 'esuite'
-            inlimit /e_36r1/limits:webplots
-        endfamily
-        family satim
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-          edit UPDATE_WEB_NOW 'no'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit PLOT_AREAS 'Europe,North_America,South_America,Africa,Indian_Ocean,Australia,West_Pacific,East_Pacific'
-          task w_simulated
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00/satim eq complete)
-          task web_update
-            trigger ./w_simulated eq complete and ../fc eq complete
-            edit PACKAGES 'esuite'
-        endfamily
-        family an
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
-          edit SMSFILES '/home/ma/emos/def/e_36r1/plot/plot240'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          inlimit /e_36r1/limits:webplots
-          task w_albedo
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete and ../../data/fields eq complete)
-            edit WEEKDAY 'tuesday'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/'
-          task psst
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            inlimit /e_36r1/limits:webplots
-          task psw123
-          task web_update
-            trigger w_albedo eq complete and psst eq complete and psw123 eq complete
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            edit PACKAGES 'esuite'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/'
-            inlimit /e_36r1/limits:webplots
-        endfamily
-        family monitoring
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task w_coverage
-            trigger /e_36r1/pop/00/data/bufr eq complete
-          task w_tscover
-            time 07:10
-          task w_guan
-            edit DATEMASK '03.*.*'
-        endfamily
-        family cloudsat
-          trigger fc eq complete
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit PLOT_AREAS 'South_Atlantic,Pacific,Indian'
-          edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168'
-          task csat_clouds
-          task csat_waves
-          task csat_wind
-        endfamily
-        family amma
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/amma'
-          family monitoring
-            edit UPDATE_WEB_NOW 'yes'
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit WSHOST 'linux_cluster'
-            inlimit /limits:linux_cluster
-            time 10:00
-            task amma_cover
-              edit DATEMASK '03.*.*'
-            task amma_pilot
-              edit DATEMASK '03.*.*'
-            task amma_rs
-              edit DATEMASK '03.*.*'
-            task amma_tephigram
-              edit METVIEW '/usr/local/share/metview_old'
-          endfamily
-          family fc
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
-            edit UPDATE_WEB_NOW 'yes'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'serial'
-            edit PLOTDOM '-30/-35/45/40'
-            time 09:30
-            task satplot
-              edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
-            task maps
-              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
-            task tephi
-              edit METVIEW '/usr/local/share/metview_old'
-              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
-            task trajectories
-              edit STEPS '24/48/72'
-            task cross
-              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
-            task hovm
-              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-            task obs_mslp
-            task metgram
-            task prob
-              edit STEPS '60/72/84/96/108/120/132/144/156/168/180/192/204/216/228/240'
-          endfamily
-        endfamily
-        family swdfp
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/swdfp'
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'serial'
-          edit PLOTDOM '-45/-10/6/62'
-          time 10:30
-          family maps
-            edit PLOT_LOCATION '/webplots_e/data/swdfp/maps'
-            edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-            task swdfp_maps
-            task smaps_toweb1
-              trigger swdfp_maps eq complete
-            task smaps_toweb2
-              trigger swdfp_maps eq complete
-            task smaps_toweb3
-              trigger swdfp_maps eq complete
-            task swdfp_clean
-              trigger smaps_toweb1 eq complete and smaps_toweb2 eq complete and smaps_toweb3 eq complete
-          endfamily
-          task swdfp_satplot
-            edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
-          task swdfp_tephi
-            edit METVIEW '/usr/local/share/metview_old'
-            edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
-          task swdfp_obs_mslp
-            edit PLOTDOM '-37/3/-3/55'
-          task swdfp_metgram
-        endfamily
-      endfamily
-      family paper
-        task pobstat
-          trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00/fb/obstat_merge eq complete)
-          edit FSFAMILY 'an'
-          edit WSHOST 'linux_cluster'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-      endfamily
-      task cleanup
-        trigger web eq complete
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        inlimit /e_36r1/limits:webplots
-    endfamily
-    family 12
-      edit EMOS_BASE '12'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
-      family proc
-        edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-        task buoycol
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/obs eq complete)
-          edit FSFAMILY 'fc'
-      endfamily
-      family data
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
-        family fields
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete)
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit STEP_LIST '12/to/240/by/12'
-          inlimit /e_36r1/limits:webplots
-          task z500
-          task mslp
-          task mslp_gg
-          task t850
-          task rain
-          task t2m
-          task w30m
-          task cloud
-          task waves
-          task rainp
-          task w10m
-          task wind
-            edit STEP_LIST '24/to/240/by/24'
-          task rh
-            edit STEP_LIST '24/to/240/by/24'
-          task vorticity
-            edit STEP_LIST '24/to/240/by/24'
-          task divergence
-            edit STEP_LIST '24/to/240/by/24'
-        endfamily
-        family metgram
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete and /mc/main/12/legA/fc eq complete)
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit RHOST 'epsgrams'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/plot/metgram'
-          inlimit /limits:linux_cluster
-          task metret
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete )
-          task metclean
-            trigger metret eq complete
-            edit DELTA_DAY '-3'
-          family fc
-            edit KIND 'metgram_fc'
-            edit ENSEMBLES '0'
-            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/epsgrams/grams'
-            task gclean
-              edit REMOTE_KEEP_DAYS '3'
-              edit KEEP_DAYS '3'
-            task gdb
-              trigger gclean eq complete
-              label files ""
-              label info ""
-              event 1 
-              event fdb
-            task glink
-              trigger gdb eq complete
-          endfamily
-        endfamily
-        family bufr
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task feedback
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12/archive/obs eq complete)
-        endfamily
-      endfamily
-      family web
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-        family fc
-          trigger ../data/fields eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          inlimit /e_36r1/limits:webplots
-          family members
-            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa'
-            edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168,180,192,204,216,228,240'
-            edit PLOT_LEGS '1'
-            task w_z500t850
-            task w_mslrain
-            task w_t2m30mw
-            task w_clouds
-            task w_waves
-              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-            task w_mwp
-              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-          endfamily
-          family additional
-            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
-            edit PLOT_STEPS '0,24,48,72,96,120,144,168'
-            task w_uv_rh
-            task w_msl_uv200
-            task w_z500t850_gts
-              edit PLOT_STEPS '0,24,48,72,96,120,144,168,192,216,240'
-            task w_vordir
-              edit PLOT_STEPS '0,24,48,72,96,120,144'
-            family wmo_swh_dir
-              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
-              edit PLOT_AREAS 'Global'
-              edit PLOT_TYPE '_wmo'
-              task w_waves
-            endfamily
-            family wmo_mwp_dir
-              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
-              edit PLOT_AREAS 'Global'
-              edit PLOT_TYPE '_wmo'
-              task w_mwp
-            endfamily
-          endfamily
-          family essential
-            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
-            edit PLOT_STEPS '72,96,120,144,168,192,216,240'
-            task public_plots
-          endfamily
-          task web_update
-            trigger members eq complete and additional eq complete and essential eq complete
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            edit PACKAGES 'esuite'
-            inlimit /e_36r1/limits:webplots
-        endfamily
-        family satim
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-          edit UPDATE_WEB_NOW 'no'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit PLOT_AREAS 'Europe,North_America,South_America,Africa,Indian_Ocean,Australia,West_Pacific,East_Pacific'
-          task w_simulated
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12/satim eq complete)
-          task web_update
-            trigger ./w_simulated eq complete and ../fc eq complete
-            edit PACKAGES 'esuite'
-        endfamily
-        family verification
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/verification'
-          edit UPDATE_WEB_NOW 'yes'
-          family monthly
-            edit DATEMASK '11.*.*'
-            task w_2t
-            task w_cloud_humid
-            task w_preci
-            task w_scores
-            task w_scores_mean
-            task w_wmomeans
-            task w_pltime_waves
-          endfamily
-          family daily
-            trigger /e_36r1/lag/12/verif/oc eq complete
-            task w_allcentres
-            task w_weekly_centres
-              trigger w_allcentres eq complete
-              edit WEEKDAY 'monday'
-          endfamily
-        endfamily
-        family monitoring
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task w_coverage
-            trigger /e_36r1/pop/12/data/bufr eq complete
-        endfamily
-        family cloudsat
-          trigger fc eq complete
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit PLOT_AREAS 'South_Atlantic,Pacific,Indian'
-          edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168'
-          task csat_clouds
-          task csat_waves
-          task csat_wind
-        endfamily
-        family amma
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/amma'
-          family fc
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete)
-            edit UPDATE_WEB_NOW 'yes'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'serial'
-            edit PLOTDOM '-30/-35/45/40'
-            time 00:30
-            task satplot
-              edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
-            task maps
-              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
-            task tephi
-              edit METVIEW '/usr/local/share/metview_old'
-              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
-            task trajectories
-              edit STEPS '24/48/72'
-            task cross
-              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
-            task hovm
-              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-            task obs_mslp
-            task metgram
-            task prob
-              edit STEPS '60/72/84/96/108/120/132/144/156/168/180/192/204/216/228/240'
-          endfamily
-        endfamily
-        family swdfp
-          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete)
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/swdfp'
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'serial'
-          edit PLOTDOM '-45/-10/6/62'
-          time 01:30
-          family maps
-            edit PLOT_LOCATION '/webplots_e/data/swdfp/maps'
-            edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-            task swdfp_maps
-            task smaps_toweb1
-              trigger swdfp_maps eq complete
-            task smaps_toweb2
-              trigger swdfp_maps eq complete
-            task smaps_toweb3
-              trigger swdfp_maps eq complete
-            task swdfp_clean
-              trigger smaps_toweb1 eq complete and smaps_toweb2 eq complete and smaps_toweb3 eq complete
-          endfamily
-          task swdfp_satplot
-            edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
-          task swdfp_tephi
-            edit METVIEW '/usr/local/share/metview_old'
-            edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
-          task swdfp_obs_mslp
-            edit PLOTDOM '-37/3/-3/55'
-          task swdfp_metgram
-        endfamily
-      endfamily
-      family paper
-        task pobstat
-          trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12/fb/obstat_merge eq complete)
-          edit FSFAMILY 'an'
-          edit WSHOST 'linux_cluster'
-          edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-      endfamily
-      family verify
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/verify'
-        family consistency
-          edit ECFS_OPTIONS '-o'
-          edit ECMWF 'ECMWF24'
-          edit BRACKNELL 'BRAKL24'
-          edit OFFENBACH 'OFFNB24'
-          edit WASHINGTON 'WASHN24'
-          edit DATEMASK '02.*.*'
-          task create_daily_files
-            edit DATEMASK '02.*.*'
-          task create_monthly_files
-            trigger create_daily_files eq complete
-            edit DATEMASK '02.01.*'
-          task ecmwf
-            trigger create_monthly_files eq complete
-            edit DATEMASK '02.*.*'
-          task bracknell
-            trigger create_monthly_files eq complete
-            edit DATEMASK '02.*.*'
-          task offenbach
-            trigger create_monthly_files eq complete
-            edit DATEMASK '02.*.*'
-          task washington
-            trigger create_monthly_files eq complete
-            edit DATEMASK '02.*.*'
-        endfamily
-      endfamily
-      task cleanup
-        trigger web eq complete
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        inlimit /e_36r1/limits:webplots
-    endfamily
-    family 00dc
-      edit EMOS_BASE '00'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
-      family web
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-        family an
-          task pincr
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00dc/an eq complete)
-            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-            edit UPDATE_WEB_NOW 'yes'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            inlimit /e_36r1/limits:webplots
-        endfamily
-        family monitoring
-          edit UPDATE_WEB_NOW 'yes'
-          family satmon
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            inlimit /limits:linux_cluster
-            task satmon
-              trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00dc/satmon eq complete)
-            family airs
-              trigger satmon eq complete
-              edit SATELLITE 'airs'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family noaa
-              trigger satmon eq complete
-              edit SATELLITE 'noaa'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family ears
-              trigger satmon eq complete
-              edit SATELLITE 'ears'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family geos
-              trigger satmon eq complete
-              edit SATELLITE 'geos'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family o3
-              trigger satmon eq complete
-              edit SATELLITE 'o3'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family o3knmi
-              trigger satmon eq complete
-              edit SATELLITE 'o3knmi'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family temp
-              trigger satmon eq complete
-              edit SATELLITE 'temp'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family pwc
-              trigger satmon eq complete
-              edit SATELLITE 'pwc'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family amv_speed
-              trigger satmon eq complete
-              edit SATELLITE 'amv_speed'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family dmsp
-              trigger satmon eq complete
-              edit SATELLITE 'dmsp'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family gpsro
-              trigger satmon eq complete
-              edit SATELLITE 'gpsro'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family tmi
-              trigger satmon eq complete
-              edit SATELLITE 'tmi'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family ssmis
-              trigger satmon eq complete
-              edit SATELLITE 'ssmis'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family amsre
-              trigger satmon eq complete
-              edit SATELLITE 'amsre'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family iasi
-              trigger satmon eq complete
-              edit SATELLITE 'iasi'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family pacrars
-              trigger satmon eq complete
-              edit SATELLITE 'pacrars'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family dbamv_speed
-              trigger satmon eq complete
-              edit SATELLITE 'dbamv_speed'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family meris
-              trigger satmon eq complete
-              edit SATELLITE 'meris'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family scatt_speed
-              trigger satmon eq complete
-              edit SATELLITE 'scatt_speed'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            family slmoist
-              trigger satmon eq complete
-              edit SATELLITE 'slmoist'
-              inlimit /e_36r1/limits:satmon
-              task w_satmon
-                edit PLOTALL 'true'
-                edit PLOTGEO 'false'
-              task w_satmon_geo
-                edit WEEKDAY 'saturday'
-                edit PLOTALL 'false'
-                edit PLOTGEO 'true'
-            endfamily
-            task web_daily
-              trigger airs eq complete and noaa eq complete and ears eq complete and geos eq complete and o3 eq complete and o3knmi eq complete and temp eq complete and pwc eq complete and amv_speed eq complete and dmsp eq complete and gpsro eq complete and tmi eq complete and ssmis eq complete and amsre eq complete and iasi eq complete and pacrars eq complete and dbamv_speed eq complete and meris eq complete and scatt_speed eq complete and slmoist eq complete
-            task web_weekly
-              trigger airs eq complete and noaa eq complete and ears eq complete and geos eq complete and o3 eq complete and o3knmi eq complete and temp eq complete and pwc eq complete and amv_speed eq complete and dmsp eq complete and gpsro eq complete and tmi eq complete and ssmis eq complete and amsre eq complete and iasi eq complete and pacrars eq complete and dbamv_speed eq complete and meris eq complete and scatt_speed eq complete and slmoist eq complete
-              edit WEEKDAY 'saturday'
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-    family 06dc
-      edit EMOS_BASE '06'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
-      family data
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
-        family bufr
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task feedback
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00dc/archive/obs eq complete)
-        endfamily
-      endfamily
-      family web
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-        family an
-          task pincr
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00dc/an eq complete and /e_36r1/pop/00dc/web/an/pincr eq complete)
-            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-            edit UPDATE_WEB_NOW 'yes'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            inlimit /e_36r1/limits:webplots
-        endfamily
-        family monitoring
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task w_coverage
-            trigger /e_36r1/pop/06dc/data/bufr eq complete
-        endfamily
-      endfamily
-      task cleanup
-        trigger web eq complete
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        inlimit /e_36r1/limits:webplots
-    endfamily
-    family 12dc
-      edit EMOS_BASE '12'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
-      family web
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-        family an
-          task pincr
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12dc/an eq complete)
-            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-            edit UPDATE_WEB_NOW 'yes'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            inlimit /e_36r1/limits:webplots
-        endfamily
-      endfamily
-    endfamily
-    family 18dc
-      edit EMOS_BASE '18'
-      edit MXUP_TRAJ '3'
-      edit STREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '3'
-      edit EDFAMILY 'false'
-      edit PERIOD_4D '12'
-      edit FCLENGTH '15'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
-      family data
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
-        family bufr
-          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task feedback
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12dc/archive/obs eq complete)
-        endfamily
-      endfamily
-      family web
-        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
-        family an
-          task pincr
-            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12dc/an eq complete and /e_36r1/pop/12dc/web/an/pincr eq complete)
-            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-            edit UPDATE_WEB_NOW 'yes'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            inlimit /e_36r1/limits:webplots
-        endfamily
-        family monitoring
-          edit UPDATE_WEB_NOW 'yes'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          task w_coverage
-            trigger /e_36r1/pop/18dc/data/bufr eq complete
-        endfamily
-      endfamily
-      task cleanup
-        trigger web eq complete
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        inlimit /e_36r1/limits:webplots
-    endfamily
-    family 18bc
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '12'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-      edit EMOS_BASE '18'
-      family paper
-        family an
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FSFAMILY 'an'
-          inlimit /limits:linux_cluster
-          task pobstat
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/18bc/fb/obstat_merge eq complete)
-            edit PRIORITY '51'
-        endfamily
-      endfamily
-      task prod_2t
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'serial'
-        edit SMSFILES '/home/mo/moz/sms/other_smsfiles/global_efi/daily'
-        edit REFDATE '0'
-        edit EFI_PARAM '2t'
-    endfamily
-    family 06bc
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '12'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '1'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
-      edit EMOS_BASE '06'
-      family paper
-        family an
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FSFAMILY 'an'
-          inlimit /limits:linux_cluster
-          task pobstat
-            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/06bc/fb/obstat_merge eq complete)
-            edit PRIORITY '51'
-        endfamily
-      endfamily
-      task prod_2t
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'serial'
-        edit SMSFILES '/home/mo/moz/sms/other_smsfiles/global_efi/daily'
-        edit REFDATE '0'
-        edit EFI_PARAM '2t'
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'pop'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ../main/make eq complete and ./00 eq complete and ./12 eq complete and ./00dc eq complete and ./06dc eq complete and ./12dc eq complete and ./18dc eq complete and ./18bc eq complete and ./06bc eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'pop'
-      edit MOVE_TO_ECFS 'no'
-      time 14:15
-  endfamily
-  family msjobs
-    complete ( /e_36r1/msjobs:YMD le /e_36r1/main:YMD) and /e_36r1/main/logfiles eq active
-    trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD or ( /e_36r1/lag:YMD gt /e_36r1/msjobs:YMD)) or ( /e_36r1/lag:YMD eq /e_36r1/msjobs:YMD or ( /e_36r1/pop:YMD gt /e_36r1/msjobs:YMD)) or ( /e_36r1/pop:YMD eq /e_36r1/msjobs:YMD)
-    repeat date YMD 20091118 20121212 1
-    edit SMSURLBASE 'http://ecgate.ecmwf.int:9080/'
-    edit SMSURL 'do/events'
-    family 12
-      edit EMOS_BASE '12'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '-1'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
-      edit SMSTRYNO '1'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'ecgate'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGDIR '/vol/emos_nc/output'
-      family mstraj
-        trigger ( /e_36r1/lag:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/msjobs:YMD and /e_36r1/lag/12/traj/cp_to_other eq complete)
-        edit MSJ_DIR 'tr12h000'
-        time 18:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms_an06
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/12/an eq complete and ( ../../main/12/fc/model:step gt 000 or ../../main/12/fc/model eq complete))
-        edit MSJ_DIR 'an06h000'
-        edit EMOS_BASE '06'
-        time 17:40
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms000
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/12/an eq complete and ( ../../main/12/fc/model:step gt 009 or ../../main/12/fc/model eq complete))
-        edit MSJ_DIR 'an12h000'
-        time 17:40
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms036
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 036 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/036/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0036'
-        edit MSJ_DIR 'fc12h036'
-        time 17:56
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms072
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 072 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/072/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0072'
-        edit MSJ_DIR 'fc12h072'
-        time 18:06
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms144
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 144 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/144/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0144'
-        edit MSJ_DIR 'fc12h144'
-        time 18:27
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms240
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 240 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/240/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0240'
-        edit MSJ_DIR 'fc12h240'
-        time 18:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family mswave
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/12/fc/model eq complete)
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'wg12h240'
-        time 18:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family msmetgram
-        trigger ( /e_36r1/pop:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/pop:YMD eq /e_36r1/msjobs:YMD and /e_36r1/pop/12/data/metgram eq complete)
-        edit MSJ_DIR 'fc12hmetgram'
-        time 18:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      task test_ll
-        edit MSJ_DIR 'test_ll'
-        edit USE_NEW_MSJ 'true'
-    endfamily
-    family 00
-      edit EMOS_BASE '00'
-      edit MXUP_TRAJ '3'
-      edit REINISTREAM 'DCDA'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit REINITIALIZE 'true'
-      edit EDFAMILY 'true'
-      edit PERIOD_4D '6'
-      edit FCLENGTH '9'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
-      edit SMSTRYNO '1'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'ecgate'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGDIR '/vol/emos_nc/output'
-      family mstraj
-        trigger ( /e_36r1/lag:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/msjobs:YMD and /e_36r1/lag/00/traj/cp_to_other eq complete)
-        edit MSJ_DIR 'tr12h000'
-        time 06:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms_an18
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/00/an eq complete and ( ../../main/00/fc/model:step gt 000 or ../../main/00/fc/model eq complete))
-        edit DELTA_DAY '0'
-        edit EMOS_BASE '18'
-        edit MSJ_DIR 'an18h000'
-        time 05:40
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms000
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/00/an eq complete and ( ../../main/00/fc/model:step gt 009 or ../../main/00/fc/model eq complete))
-        edit MSJ_DIR 'an00h000'
-        time 05:40
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms036
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 036 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/036/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0036'
-        edit MSJ_DIR 'fc00h036'
-        time 05:56
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms072
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 072 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/072/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0072'
-        edit MSJ_DIR 'fc00h072'
-        time 06:06
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms144
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 144 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/144/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0144'
-        edit MSJ_DIR 'fc00h144'
-        time 06:27
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms240
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 240 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/240/derived_param eq complete)
-        edit EMOS_TIME_STEP_H '0240'
-        edit MSJ_DIR 'fc00h240'
-        time 06:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family mswave
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/00/fc/model eq complete)
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'wg00h240'
-        time 06:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family msmetgram
-        trigger ( /e_36r1/pop:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/pop:YMD eq /e_36r1/msjobs:YMD and /e_36r1/pop/00/data/metgram eq complete)
-        edit MSJ_DIR 'fc00hmetgram'
-        time 06:55
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      task test_ll
-        edit MSJ_DIR 'test_ll'
-        edit USE_NEW_MSJ 'true'
-    endfamily
-    family 12bc
-      edit EMOS_BASE '12'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '-1'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
-      edit SMSTRYNO '1'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'ecgate'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGDIR '/vol/emos_nc/output'
-      family ms012
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc eq complete or /e_36r1/main/12/fc/model:step gt 012))
-        edit EMOS_TIME_STEP_H '0012'
-        edit MSJ_DIR 'bc12h012'
-        time 17:49
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms072
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc eq complete or /e_36r1/main/12/fc/model:step gt 072))
-        edit EMOS_TIME_STEP_H '0072'
-        edit MSJ_DIR 'bc12h072'
-        time 18:06
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-    endfamily
-    family 18bc
-      edit EMOS_BASE '18'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '-1'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
-      edit SMSTRYNO '1'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'ecgate'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGDIR '/vol/emos_nc/output'
-      family ms012
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/18bc/fc eq complete or /e_36r1/main/18bc/fc/model:step gt 012))
-        edit EMOS_TIME_STEP_H '0012'
-        edit MSJ_DIR 'bc18h012'
-        time 23:49
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms072
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/18bc/fc eq complete or /e_36r1/main/18bc/fc/model:step gt 072))
-        edit EMOS_TIME_STEP_H '0072'
-        edit MSJ_DIR 'bc18h072'
-        time 00:06
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-    endfamily
-    family 00bc
-      edit EMOS_BASE '00'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
-      edit SMSTRYNO '1'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'ecgate'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGDIR '/vol/emos_nc/output'
-      family ms012
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc eq complete or /e_36r1/main/00/fc/model:step gt 012))
-        edit EMOS_TIME_STEP_H '0012'
-        edit MSJ_DIR 'bc00h012'
-        time 05:49
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms072
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc eq complete or /e_36r1/main/00/fc/model:step gt 072))
-        edit EMOS_TIME_STEP_H '0072'
-        edit MSJ_DIR 'bc00h072'
-        time 06:06
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-    endfamily
-    family 06bc
-      edit EMOS_BASE '06'
-      edit EDFAMILY 'false'
-      edit INISTREAM 'DA'
-      edit REINITIALIZE 'false'
-      edit REINIEXPVER '0046'
-      edit INIEXPVER '0045'
-      edit REINIPERIOD_4D '6'
-      edit REINISTREAM 'DA'
-      edit REINIOFFSET '6'
-      edit RUN_HOURLY_PP '0'
-      edit PERIOD_4D '6'
-      edit WINDOW_LENGTH_4D '12'
-      edit WINDOW_OFFSET_4D '9'
-      edit MXUP_TRAJ '3'
-      edit PARALLEL '4'
-      edit LANONLY 'false'
-      edit ACCOUNT 'opebcmis'
-      edit STREAM 'SCDA'
-      edit EMOS_STREAM 'SCDA'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
-      edit SMSTRYNO '1'
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'ecgate'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGDIR '/vol/emos_nc/output'
-      family ms012
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/06bc/fc eq complete or /e_36r1/main/06bc/fc/model:step gt 012))
-        edit EMOS_TIME_STEP_H '0012'
-        edit MSJ_DIR 'bc06h012'
-        time 11:49
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-      family ms072
-        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/06bc/fc eq complete or /e_36r1/main/06bc/fc/model:step gt 072))
-        edit EMOS_TIME_STEP_H '0072'
-        edit MSJ_DIR 'bc06h072'
-        time 12:06
-        task ms_ec
-          edit SMSTRIES '1'
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'msjobs'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger ./12 eq complete and ./00 eq complete and ./12bc eq complete and ./18bc eq complete and ./00bc eq complete and ./06bc eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit SMSFILES '/home/ma/emos/def/e_36r1'
-      edit LOGTASK 'msjobs'
-      edit MOVE_TO_ECFS 'no'
-      time 14:20
-  endfamily
-endsuite
-suite emc_36r1
-  edit USER 'emos'
-  edit SCHOST 'c1b'
-  edit STHOST '/s1b'
-  edit SCHOST_BKUP 'c1a'
-  edit STHOST_BKUP '/s1a'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit USE_YMD 'true'
-  edit YMD '20091003'
-  edit DATEMASK '*.*.*'
-  edit VERSION '0046'
-  edit INIEXPVER '0046'
-  edit TCINIEXPVER '0046'
-  edit FIRST_DAY '1'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '12'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY 'mc'
-  edit IMPL_DATE '2012123112'
-  edit EVERSION '0001'
-  edit USER_PRIORITY '70'
-  edit ININPES '24'
-  edit FCNPES '32'
-  edit PGNPES '32'
-  edit ANNPES '4'
-  edit REINITIALIZE 'false'
-  edit RESERVATION_ON '0'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/emc_36r1'
-  edit SMSINCLUDE '/home/ma/emos/def/emc_36r1/include'
-  edit ACCOUNT 'oeenfo'
-  edit STREAM 'EF'
-  edit EMOS_STREAM 'EF'
-  edit ENSEMBLES '50'
-  edit ENS_SIZE '50'
-  edit MARS_DB 'marsod'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit INILEVELS '91'
-  edit INIPERIOD_4D '6'
-  edit IS_REAL_TIME 'is_real_time'
-  edit RUN_3HOURS_PP '1'
-  edit RUNHINDCAST '0'
-  edit ERA40END '2002073100'
-  edit NH_YEARS '18'
-  edit NH_WEEKS '2'
-  edit PGEN_BINDIR '/home/ma/emos/bin/diss'
-  edit PGEN_OBJDIR '/home/ma/emos/bin/diss'
-  edit DISS_REQDB_ROOT '/diss/requirements'
-  edit DISS_BINDIR '/diss/bin/DISS'
-  edit DELTA_DAY_M '-15'
-  edit DELTA_DAY_P '25'
-  edit FCGTYPE 'l_2'
-  edit EPSFCGTYPE 'l_2'
-  edit LUSE_RSTRHBIAS 'true'
-  edit FCGROUP 'fc0'
-  edit SMSLOGHOST 'c1b'
-  edit SMSLOGPORT '9316'
-  edit COURTESY '0'
-  edit OCNPES_OC '8'
-  edit OCNPES_IFS '56'
-  edit OD_PROJ 'od'
-  edit SMSURLBASE 'http://datasvc.ecmwf.int/twiki/bin/view/Main'
-  edit SMSURL 'CurrentAndOldESuites'
-  edit SUITE_START '20091004'
-  edit PRODUCE_EPS_ML '1'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit.map %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-  edit NOEFI '0'
-  edit SLEEPTIME '1'
-  inlimit /limits:c1b
-  clock hybrid 
-  family hc0
-    repeat date YMD 20091008 20121212 7
-    edit ACCOUNT 'oeenfo'
-    edit LOGTASK 'hc0'
-    edit QUEUE 'ns'
-    edit QUEUE_EPILOG 'ns'
-    edit ENSEMBLES '4'
-    edit ENS_SIZE '4'
-    edit RUNHINDCAST '1'
-    edit STREAM 'ENFH'
-    edit EMOS_STREAM 'ENFH'
-    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-    edit EMOS_BASE '00'
-    edit INICLASS 'EI'
-    edit INIEXPVER '0001'
-    edit INILEVELS '60'
-    edit DELETE_FAMILY 'true'
-    family back
-      trigger /emc_36r1/main/make eq complete
-      edit RUNVARFC '1'
-      edit YMD '20091217'
-      inlimit /emc_36r1/limits:hind
-      task stage_hc
-        edit RUNVARFC '1'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-      task rmfdb
-        trigger stage_hc eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-        edit NH_WEEKS_KEPT '1'
-      task lock_fam
-        trigger 0 eq 1
-      task lock_1701
-        complete ./18 eq complete
-        trigger 0 eq 1
-      family 18
-        trigger ./rmfdb eq complete
-        edit DELTA_YEAR '-18'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 17
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-17'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 16
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-16'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 15
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-15'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 14
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-14'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 13
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-13'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 12
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-12'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 11
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-11'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 10
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-10'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 09
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-09'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 08
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-08'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 07
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-07'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 06
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-06'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 05
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-05'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 04
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-04'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 03
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-03'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 02
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-02'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-      family 01
-        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
-        edit DELTA_YEAR '-01'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      endfamily
-    endfamily
-    family arch
-      edit EMOS_TYPE 'an'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-      edit FSFAMILY 'mars'
-      edit OVERLAP '0'
-      edit YMD '20100121'
-      limit mutex 1
-      inlimit /emc_36r1/limits:mars
-      inlimit /limits:mars
-      family 18
-        trigger ( ../back/18 eq complete)
-        edit DELTA_YEAR '-18'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/18/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 17
-        trigger ( ../back/17 eq complete)
-        edit DELTA_YEAR '-17'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/17/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 16
-        trigger ( ../back/16 eq complete)
-        edit DELTA_YEAR '-16'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/16/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 15
-        trigger ( ../back/15 eq complete)
-        edit DELTA_YEAR '-15'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/15/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 14
-        trigger ( ../back/14 eq complete)
-        edit DELTA_YEAR '-14'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/14/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 13
-        trigger ( ../back/13 eq complete)
-        edit DELTA_YEAR '-13'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/13/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 12
-        trigger ( ../back/12 eq complete)
-        edit DELTA_YEAR '-12'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/12/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 11
-        trigger ( ../back/11 eq complete)
-        edit DELTA_YEAR '-11'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/11/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 10
-        trigger ( ../back/10 eq complete)
-        edit DELTA_YEAR '-10'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/10/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 09
-        trigger ( ../back/09 eq complete)
-        edit DELTA_YEAR '-09'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/09/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 08
-        trigger ( ../back/08 eq complete)
-        edit DELTA_YEAR '-08'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/08/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 07
-        trigger ( ../back/07 eq complete)
-        edit DELTA_YEAR '-07'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/07/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 06
-        trigger ( ../back/06 eq complete)
-        edit DELTA_YEAR '-06'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/06/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 05
-        trigger ( ../back/05 eq complete)
-        edit DELTA_YEAR '-05'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/05/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 04
-        trigger ( ../back/04 eq complete)
-        edit DELTA_YEAR '-04'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/04/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 03
-        trigger ( ../back/03 eq complete)
-        edit DELTA_YEAR '-03'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/03/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 02
-        trigger ( ../back/02 eq complete)
-        edit DELTA_YEAR '-02'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/02/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 01
-        trigger ( ../back/01 eq complete)
-        edit DELTA_YEAR '-01'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-    endfamily
-    family postproc
-      trigger ./back eq complete and ( ../hc2:YMD gt ../hc0:YMD or ( ../hc2:YMD eq ../hc0:YMD and ../hc2/back eq complete))
-      edit EMOS_TYPE '00'
-      edit FCCHUNK '1'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-      inlimit /emc_36r1/limits:postproc
-      task stage_hc
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-      family legA
-        trigger ./stage_hc eq complete
-        edit FCLENGTH0 '0'
-        edit FCLENGTH '240'
-        edit EPSFCRES '399'
-        edit FCCHUNK '1'
-        edit STEP1 '0'
-        edit STEP2 '240'
-        task ensm
-        family reord
-          edit EPSCOUPLE '1'
-          edit EMOS_TYPE 'pf'
-          edit FCLENGTH0 '0'
-          edit FCLENGTH '240'
-          edit EPSFCRES '399'
-          edit FCCHUNK '1'
-          edit STEP1 '0'
-          edit STEP2 '240'
-          edit STEPS '-1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-          edit RUNVARFC '1'
-          limit reord 1
-          inlimit reord
-          label info ""
-          family 130
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '130.128'
-            task reord
-              label info ""
-          endfamily
-          family 228
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '228.128'
-            task reord
-              label info ""
-          endfamily
-          family 207
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '207.128'
-            task reord
-              label info ""
-          endfamily
-          family 167
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '167.128'
-            task reord
-              label info ""
-          endfamily
-          family 164
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '164.128'
-            task reord
-              label info ""
-          endfamily
-          family arch
-            trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
-            edit GENERATE '0'
-            edit ARCHIVE '1'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task reord
-              label info ""
-          endfamily
-        endfamily
-      endfamily
-      family legB
-        trigger legA eq complete
-        edit FCLENGTH0 '240'
-        edit FCLENGTH '768'
-        edit EPSFCRES '255'
-        edit FCCHUNK '1'
-        edit STEP1 '240'
-        edit STEP2 '768'
-        task ensm
-        family reord
-          edit EPSCOUPLE '1'
-          edit EMOS_TYPE 'pf'
-          edit FCLENGTH0 '240'
-          edit FCLENGTH '768'
-          edit EPSFCRES '255'
-          edit FCCHUNK '1'
-          edit STEP1 '240'
-          edit STEP2 '768'
-          edit STEPS '-1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-          edit RUNVARFC '1'
-          limit reord 1
-          inlimit reord
-          label info ""
-          family 130
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '130.128'
-            task reord
-              label info ""
-          endfamily
-          family 228
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '228.128'
-            task reord
-              label info ""
-          endfamily
-          family 207
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '207.128'
-            task reord
-              label info ""
-          endfamily
-          family 167
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '167.128'
-            task reord
-              label info ""
-          endfamily
-          family 164
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '164.128'
-            task reord
-              label info ""
-          endfamily
-          family arch
-            trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
-            edit GENERATE '0'
-            edit ARCHIVE '1'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task reord
-              label info ""
-          endfamily
-        endfamily
-      endfamily
-      task wmem_veps
-        trigger legA eq complete and legB eq complete
-        edit EMOS_TYPE 'UNDEF'
-        edit FCCHUNK '1'
-        edit FCLENGTH '768'
-      task wmem_archive
-        trigger wmem_veps eq complete and ./legA eq complete and ./legB eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-        edit FCLENGTH '768'
-        label info ""
-      family clim
-        trigger ../arch eq complete and ./stage_hc eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg/clim'
-        edit CLIM_FC_YEARS '0'
-        edit OCSUITE 'vareps'
-        edit ERA40 'YES'
-        edit START_DAY '20091008'
-        edit END_DAY '20121213'
-        edit RUNVARFC '1'
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /limits:linux_cluster
-        family init
-          task listclim
-          task getdata
-            trigger listclim eq complete
-          task getobsclim
-            trigger getdata eq complete
-        endfamily
-        family bias
-          trigger init eq complete
-          task cal_bias
-          task plot_bias
-            trigger cal_bias eq complete
-          task plot_clim
-            trigger plot_bias eq complete
-          task cal_zondia
-            trigger plot_clim eq complete
-          task plot_zondia
-            trigger cal_zondia eq complete
-          task migrate_bias
-            trigger plot_zondia eq complete
-          task clean_bias
-            trigger migrate_bias eq complete
-          task clean
-            trigger clean_bias eq complete
-        endfamily
-      endfamily
-    endfamily
-    family prod
-      trigger ./back eq complete and ./postproc eq complete
-      edit SMSFILES '/home/ma/emos/def/mc/prod'
-      edit EMOS_DOMAIN 'G'
-      edit EMOS_TYPE 'FC'
-      edit PROD_TASK '1'
-      edit EMOS_PROJECT '00'
-      edit EMOS_BASE '00'
-      edit PGNPES '32'
-      edit EMOS_STREAM 'ENFH'
-      family getreq
-        trigger ../back eq complete
-        edit EMOS_TYPE 'cm'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_PROJECT '12'
-        edit PROD_TASK '1'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'ENFH'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_BASE '00'
-        task eps
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectwave
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit EMOS_STREAM 'ENWH'
-        task wave_eps
-          trigger collectwave eq complete
-          edit EMOS_STREAM 'ENWH'
-          label info ""
-          event 1 
-      endfamily
-      family eps
-        trigger ../back eq complete and ( ./getreq/eps eq complete or ./getreq/eps:001)
-        edit EMOS_STREAM 'ENFH'
-        family day01
-          edit EMOS_TIME_STEP_H '0001'
-          task prodgen
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ./pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day02
-          edit EMOS_TIME_STEP_H '0002'
-          task prodgen
-            trigger ../day01/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day01/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day03
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            trigger ../day02/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day02/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day04
-          edit EMOS_TIME_STEP_H '0004'
-          task prodgen
-            trigger ../day03/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day03/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day05
-          edit EMOS_TIME_STEP_H '0005'
-          task prodgen
-            trigger ../day04/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day04/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day06
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            trigger ../day05/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day05/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day07
-          edit EMOS_TIME_STEP_H '0007'
-          task prodgen
-            trigger ../day06/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day06/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day08
-          edit EMOS_TIME_STEP_H '0008'
-          task prodgen
-            trigger ../day07/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day07/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day09
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            trigger ../day08/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day08/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day10
-          edit EMOS_TIME_STEP_H '0010'
-          task prodgen
-            trigger ../day09/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day09/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day11
-          edit EMOS_TIME_STEP_H '0011'
-          task prodgen
-            trigger ../day10/prodgen eq complete
-            edit MEM '1900'
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day10/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day12
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            trigger ../day11/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day11/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day13
-          edit EMOS_TIME_STEP_H '0013'
-          task prodgen
-            trigger ../day12/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day12/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day14
-          edit EMOS_TIME_STEP_H '0014'
-          task prodgen
-            trigger ../day13/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day13/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day15
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            trigger ../day14/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day14/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day16
-          edit EMOS_TIME_STEP_H '0016'
-          task prodgen
-            trigger ../day15/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day15/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day17
-          edit EMOS_TIME_STEP_H '0017'
-          task prodgen
-            trigger ../day16/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day16/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day18
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            trigger ../day17/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day17/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day19
-          edit EMOS_TIME_STEP_H '0019'
-          task prodgen
-            trigger ../day18/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day18/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day20
-          edit EMOS_TIME_STEP_H '0020'
-          task prodgen
-            trigger ../day19/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day19/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day21
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            trigger ../day20/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day20/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day22
-          edit EMOS_TIME_STEP_H '0022'
-          task prodgen
-            trigger ../day21/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day21/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day23
-          edit EMOS_TIME_STEP_H '0023'
-          task prodgen
-            trigger ../day22/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day22/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day24
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            trigger ../day23/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day23/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day25
-          edit EMOS_TIME_STEP_H '0025'
-          task prodgen
-            trigger ../day24/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day24/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day26
-          edit EMOS_TIME_STEP_H '0026'
-          task prodgen
-            trigger ../day25/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day25/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day27
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            trigger ../day26/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day26/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day28
-          edit EMOS_TIME_STEP_H '0028'
-          task prodgen
-            trigger ../day27/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day27/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day29
-          edit EMOS_TIME_STEP_H '0029'
-          task prodgen
-            trigger ../day28/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day28/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day30
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            trigger ../day29/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day29/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day31
-          edit EMOS_TIME_STEP_H '0031'
-          task prodgen
-            trigger ../day30/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day30/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day32
-          edit EMOS_TIME_STEP_H '0032'
-          task prodgen
-            trigger ../day31/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day31/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day33
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            trigger ../day32/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day32/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-      endfamily
-      family wave
-        trigger ../back eq complete and ( ./getreq/wave_eps eq complete or ./getreq/eps:001)
-        edit PGNPES '4'
-        edit EMOS_STREAM 'ENWH'
-        family day01
-          edit EMOS_TIME_STEP_H '0001'
-          task prodgen
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ./pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day02
-          edit EMOS_TIME_STEP_H '0002'
-          task prodgen
-            trigger ../day01/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day01/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day03
-          edit EMOS_TIME_STEP_H '0003'
-          task prodgen
-            trigger ../day02/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day02/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day04
-          edit EMOS_TIME_STEP_H '0004'
-          task prodgen
-            trigger ../day03/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day03/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day05
-          edit EMOS_TIME_STEP_H '0005'
-          task prodgen
-            trigger ../day04/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day04/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day06
-          edit EMOS_TIME_STEP_H '0006'
-          task prodgen
-            trigger ../day05/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day05/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day07
-          edit EMOS_TIME_STEP_H '0007'
-          task prodgen
-            trigger ../day06/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day06/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day08
-          edit EMOS_TIME_STEP_H '0008'
-          task prodgen
-            trigger ../day07/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day07/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day09
-          edit EMOS_TIME_STEP_H '0009'
-          task prodgen
-            trigger ../day08/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day08/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day10
-          edit EMOS_TIME_STEP_H '0010'
-          task prodgen
-            trigger ../day09/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day09/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day11
-          edit EMOS_TIME_STEP_H '0011'
-          task prodgen
-            trigger ../day10/prodgen eq complete
-            edit MEM '1900'
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day10/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day12
-          edit EMOS_TIME_STEP_H '0012'
-          task prodgen
-            trigger ../day11/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day11/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day13
-          edit EMOS_TIME_STEP_H '0013'
-          task prodgen
-            trigger ../day12/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day12/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day14
-          edit EMOS_TIME_STEP_H '0014'
-          task prodgen
-            trigger ../day13/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day13/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day15
-          edit EMOS_TIME_STEP_H '0015'
-          task prodgen
-            trigger ../day14/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day14/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day16
-          edit EMOS_TIME_STEP_H '0016'
-          task prodgen
-            trigger ../day15/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day15/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day17
-          edit EMOS_TIME_STEP_H '0017'
-          task prodgen
-            trigger ../day16/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day16/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day18
-          edit EMOS_TIME_STEP_H '0018'
-          task prodgen
-            trigger ../day17/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day17/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day19
-          edit EMOS_TIME_STEP_H '0019'
-          task prodgen
-            trigger ../day18/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day18/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day20
-          edit EMOS_TIME_STEP_H '0020'
-          task prodgen
-            trigger ../day19/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day19/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day21
-          edit EMOS_TIME_STEP_H '0021'
-          task prodgen
-            trigger ../day20/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day20/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day22
-          edit EMOS_TIME_STEP_H '0022'
-          task prodgen
-            trigger ../day21/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day21/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day23
-          edit EMOS_TIME_STEP_H '0023'
-          task prodgen
-            trigger ../day22/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day22/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day24
-          edit EMOS_TIME_STEP_H '0024'
-          task prodgen
-            trigger ../day23/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day23/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day25
-          edit EMOS_TIME_STEP_H '0025'
-          task prodgen
-            trigger ../day24/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day24/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day26
-          edit EMOS_TIME_STEP_H '0026'
-          task prodgen
-            trigger ../day25/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day25/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day27
-          edit EMOS_TIME_STEP_H '0027'
-          task prodgen
-            trigger ../day26/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day26/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day28
-          edit EMOS_TIME_STEP_H '0028'
-          task prodgen
-            trigger ../day27/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day27/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day29
-          edit EMOS_TIME_STEP_H '0029'
-          task prodgen
-            trigger ../day28/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day28/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day30
-          edit EMOS_TIME_STEP_H '0030'
-          task prodgen
-            trigger ../day29/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day29/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day31
-          edit EMOS_TIME_STEP_H '0031'
-          task prodgen
-            trigger ../day30/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day30/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day32
-          edit EMOS_TIME_STEP_H '0032'
-          task prodgen
-            trigger ../day31/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day31/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-        family day33
-          edit EMOS_TIME_STEP_H '0033'
-          task prodgen
-            trigger ../day32/prodgen eq complete
-          task pdb
-            trigger prodgen eq complete
-            inlimit /emc_36r1/limits:pdb
-            inlimit /limits:pdb
-            label info ""
-            event 1 
-          task q2diss
-            late -s +00:05 -c +00:15
-            trigger ../day32/q2diss eq complete and pdb eq complete
-            edit USER_PRIORITY '93'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event 1 
-        endfamily
-      endfamily
-    endfamily
-    family adm
-      task hindsync
-        trigger ../back eq complete and ../arch eq complete and ../postproc eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-        edit NH_WEEKS_KEPT '3'
-        edit BACKUP_HCFDB '0'
-      family fri
-        complete ./fri/compl eq complete and ./fri/dummy eq queued
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-        task dummy
-          cron -w 5 09:00
-        task compl
-          complete dummy eq active or dummy eq submitted or dummy eq complete
-          trigger 1 eq 0
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:25
-      trigger logfilestore eq complete and back eq complete and arch eq complete and postproc eq complete and prod eq complete and adm eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-  family 00
-    repeat date YMD 20091007 20121212 7
-    edit DELTA_DAY '1'
-    edit ACCOUNT 'oeenfo'
-    edit LOGTASK '00'
-    edit EMOS_BASE '00'
-    edit QUEUE 'os'
-    family ref
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-      family thu1000
-        complete ./thu1000/compl eq complete and ./thu1000/dummy eq queued
-        task dummy
-        task compl
-          complete ./dummy eq active or ./dummy eq submitted
-          trigger 1 eq 0
-      endfamily
-      family thu2200
-        complete ./thu2200/compl eq complete and ./thu2200/dummy eq queued
-        task dummy
-        task compl
-          complete ./dummy eq active or ./dummy eq submitted
-          trigger 1 eq 0
-      endfamily
-      family wed
-        complete ./wed/compl eq complete and ./wed/dummy eq queued
-        task dummy
-          cron -w 3 18:30
-        task compl
-          complete ./dummy eq active or ./dummy eq submitted
-          trigger 1 eq 0
-      endfamily
-      family tue
-        complete ./tue/compl eq complete and ./tue/dummy eq queued
-        task dummy
-          cron -w 2 08:00
-        task compl
-          complete ./dummy eq active or ./dummy eq submitted
-          trigger 1 eq 0
-      endfamily
-    endfamily
-    family legC
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete and /emc_36r1/main/make eq complete)
-      edit EPSCOUPLE '1'
-      edit RUNCOUPLE '1'
-      edit EPSLEG '3'
-      edit EPSFCLENGTH_C '408'
-      family fc
-        edit FCMEM '2240'
-        edit FCSTACK '700'
-        edit FCMRFS '0'
-        edit PRIORITY '69'
-        edit USER_PRIORITY '69'
-        edit N_PERT_AN '10'
-        edit EPSWAMNFRE '25'
-        edit EPSWAMNANG '12'
-        edit TSTEP '2700'
-        edit EPSFCRES '639'
-        edit RESOL '639'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-        edit CPUTIME '1000'
-        edit MEM '960'
-        edit THREADS '8'
-        edit NPES '8'
-        edit EPSLEG '3'
-        family pf
-          complete /emc_36r1/main/ref/00/events:cf
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit EPSTYPE 'pf'
-          edit EMOS_TYPE 'pf'
-          edit USER_PRIORITY '69'
-          edit PRIORITY '69'
-          edit FCNPES '32'
-          edit EPSNLEGS '3'
-          edit EPSFCLEV '62'
-          edit EPSWAMNSTPW '1'
-          edit EPSINISTEP_PREVIOUS '0'
-          edit EPSWAMRESOL 'global50'
-          edit EPSFCRES '639'
-          edit EPSWAMNFRE '30'
-          edit EPSWAMNANG '24'
-          edit FCLENGTH '240'
-          edit TSTEP '1200'
-          edit EPSLEG '3'
-          edit CLASS 'od'
-          edit THREADS '2'
-          edit RUNVARFC '1'
-          inlimit /emc_36r1/limits:pftotal
-          meter step -1 408 408
-          family 01
-            edit EPSMEMBER '1'
-            edit MEMBER '1'
-            edit SUBFSFAMILY '/pf001'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/01 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 02
-            edit EPSMEMBER '2'
-            edit MEMBER '2'
-            edit SUBFSFAMILY '/pf002'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/02 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 03
-            edit EPSMEMBER '3'
-            edit MEMBER '3'
-            edit SUBFSFAMILY '/pf003'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/03 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 04
-            edit EPSMEMBER '4'
-            edit MEMBER '4'
-            edit SUBFSFAMILY '/pf004'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/04 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 05
-            edit EPSMEMBER '5'
-            edit MEMBER '5'
-            edit SUBFSFAMILY '/pf005'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/05 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 06
-            edit EPSMEMBER '6'
-            edit MEMBER '6'
-            edit SUBFSFAMILY '/pf006'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/06 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 07
-            edit EPSMEMBER '7'
-            edit MEMBER '7'
-            edit SUBFSFAMILY '/pf007'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/07 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 08
-            edit EPSMEMBER '8'
-            edit MEMBER '8'
-            edit SUBFSFAMILY '/pf008'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/08 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 09
-            edit EPSMEMBER '9'
-            edit MEMBER '9'
-            edit SUBFSFAMILY '/pf009'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/09 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 10
-            edit EPSMEMBER '10'
-            edit MEMBER '10'
-            edit SUBFSFAMILY '/pf010'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/10 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 11
-            edit EPSMEMBER '11'
-            edit MEMBER '11'
-            edit SUBFSFAMILY '/pf011'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/11 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 12
-            edit EPSMEMBER '12'
-            edit MEMBER '12'
-            edit SUBFSFAMILY '/pf012'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/12 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 13
-            edit EPSMEMBER '13'
-            edit MEMBER '13'
-            edit SUBFSFAMILY '/pf013'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/13 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 14
-            edit EPSMEMBER '14'
-            edit MEMBER '14'
-            edit SUBFSFAMILY '/pf014'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/14 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 15
-            edit EPSMEMBER '15'
-            edit MEMBER '15'
-            edit SUBFSFAMILY '/pf015'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/15 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 16
-            edit EPSMEMBER '16'
-            edit MEMBER '16'
-            edit SUBFSFAMILY '/pf016'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/16 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 17
-            edit EPSMEMBER '17'
-            edit MEMBER '17'
-            edit SUBFSFAMILY '/pf017'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/17 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 18
-            edit EPSMEMBER '18'
-            edit MEMBER '18'
-            edit SUBFSFAMILY '/pf018'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/18 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 19
-            edit EPSMEMBER '19'
-            edit MEMBER '19'
-            edit SUBFSFAMILY '/pf019'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/19 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 20
-            edit EPSMEMBER '20'
-            edit MEMBER '20'
-            edit SUBFSFAMILY '/pf020'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/20 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 21
-            edit EPSMEMBER '21'
-            edit MEMBER '21'
-            edit SUBFSFAMILY '/pf021'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/21 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 22
-            edit EPSMEMBER '22'
-            edit MEMBER '22'
-            edit SUBFSFAMILY '/pf022'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/22 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 23
-            edit EPSMEMBER '23'
-            edit MEMBER '23'
-            edit SUBFSFAMILY '/pf023'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/23 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 24
-            edit EPSMEMBER '24'
-            edit MEMBER '24'
-            edit SUBFSFAMILY '/pf024'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/24 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 25
-            edit EPSMEMBER '25'
-            edit MEMBER '25'
-            edit SUBFSFAMILY '/pf025'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/25 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 26
-            edit EPSMEMBER '26'
-            edit MEMBER '26'
-            edit SUBFSFAMILY '/pf026'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/26 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 27
-            edit EPSMEMBER '27'
-            edit MEMBER '27'
-            edit SUBFSFAMILY '/pf027'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/27 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 28
-            edit EPSMEMBER '28'
-            edit MEMBER '28'
-            edit SUBFSFAMILY '/pf028'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/28 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 29
-            edit EPSMEMBER '29'
-            edit MEMBER '29'
-            edit SUBFSFAMILY '/pf029'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/29 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 30
-            edit EPSMEMBER '30'
-            edit MEMBER '30'
-            edit SUBFSFAMILY '/pf030'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/30 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 31
-            edit EPSMEMBER '31'
-            edit MEMBER '31'
-            edit SUBFSFAMILY '/pf031'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/31 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 32
-            edit EPSMEMBER '32'
-            edit MEMBER '32'
-            edit SUBFSFAMILY '/pf032'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/32 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 33
-            edit EPSMEMBER '33'
-            edit MEMBER '33'
-            edit SUBFSFAMILY '/pf033'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/33 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 34
-            edit EPSMEMBER '34'
-            edit MEMBER '34'
-            edit SUBFSFAMILY '/pf034'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/34 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 35
-            edit EPSMEMBER '35'
-            edit MEMBER '35'
-            edit SUBFSFAMILY '/pf035'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/35 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 36
-            edit EPSMEMBER '36'
-            edit MEMBER '36'
-            edit SUBFSFAMILY '/pf036'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/36 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 37
-            edit EPSMEMBER '37'
-            edit MEMBER '37'
-            edit SUBFSFAMILY '/pf037'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/37 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 38
-            edit EPSMEMBER '38'
-            edit MEMBER '38'
-            edit SUBFSFAMILY '/pf038'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/38 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 39
-            edit EPSMEMBER '39'
-            edit MEMBER '39'
-            edit SUBFSFAMILY '/pf039'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/39 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 40
-            edit EPSMEMBER '40'
-            edit MEMBER '40'
-            edit SUBFSFAMILY '/pf040'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/40 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 41
-            edit EPSMEMBER '41'
-            edit MEMBER '41'
-            edit SUBFSFAMILY '/pf041'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/41 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 42
-            edit EPSMEMBER '42'
-            edit MEMBER '42'
-            edit SUBFSFAMILY '/pf042'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/42 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 43
-            edit EPSMEMBER '43'
-            edit MEMBER '43'
-            edit SUBFSFAMILY '/pf043'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/43 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 44
-            edit EPSMEMBER '44'
-            edit MEMBER '44'
-            edit SUBFSFAMILY '/pf044'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/44 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 45
-            edit EPSMEMBER '45'
-            edit MEMBER '45'
-            edit SUBFSFAMILY '/pf045'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/45 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 46
-            edit EPSMEMBER '46'
-            edit MEMBER '46'
-            edit SUBFSFAMILY '/pf046'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/46 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 47
-            edit EPSMEMBER '47'
-            edit MEMBER '47'
-            edit SUBFSFAMILY '/pf047'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/47 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 48
-            edit EPSMEMBER '48'
-            edit MEMBER '48'
-            edit SUBFSFAMILY '/pf048'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/48 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 49
-            edit EPSMEMBER '49'
-            edit MEMBER '49'
-            edit SUBFSFAMILY '/pf049'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/49 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-          family 50
-            edit EPSMEMBER '50'
-            edit MEMBER '50'
-            edit SUBFSFAMILY '/pf050'
-            task getvarepsdata
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/50 eq complete)
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSFCRESN '319'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit THREADS '8'
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '1200'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '360'
-              edit EPSFCRES '319'
-              edit EPSLEG '3'
-              edit NPES '1'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '3'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '408'
-              edit EPSINISTEP_PREVIOUS '360'
-              edit FCLENGTH '408'
-              edit MEM '1600'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit EPSFCRESN '255'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNSTPW '1'
-              edit EPSFCLENGTH_B '360'
-              edit TSTEP '2700'
-              edit EPSFCLENGTH_A '240'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 408 408
-          endfamily
-        endfamily
-        family cf
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit MEMBER '0'
-          edit EPSMEMBER '0'
-          edit SUBFSFAMILY '/cf000'
-          edit EPSTYPE 'cf'
-          edit EMOS_TYPE 'cf'
-          edit USER_PRIORITY '70'
-          edit EPSNLEGS '3'
-          edit EPSFCLEV '62'
-          edit EPSWAMNSTPW '1'
-          edit EPSINISTEP_PREVIOUS '0'
-          edit EPSWAMRESOL 'global50'
-          edit EPSFCRES '639'
-          edit EPSWAMNFRE '30'
-          edit EPSWAMNANG '24'
-          edit TSTEP '1200'
-          edit EPSLEG '3'
-          edit CLASS 'od'
-          edit OCGROUP 'an0'
-          edit FCGROUP 'fc0'
-          edit FCCHUNK '1'
-          edit OCTOTAL '5'
-          edit FCTOTAL '51'
-          edit DAILY '0'
-          edit RUNVARFC '1'
-          edit FCLENGTH '408'
-          edit FCLENGTH1 '360'
-          task getvarepsdata
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/cf eq complete)
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit TSTEP '1200'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit EPSLEG '3'
-            edit EPSINISTEP '360'
-            edit EPSFCRES '319'
-            edit EPSFCRESN '319'
-            edit EPSWAMNSTPW '1'
-            edit EPSFCLENGTH_B '360'
-            edit CLASS 'od'
-          task intHtoL
-            trigger getvarepsdata eq complete
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit TSTEP '1200'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit EPSINISTEP '360'
-            edit EPSFCRES '319'
-            edit EPSLEG '3'
-            edit NPES '1'
-            edit CLASS 'od'
-          task modeleps
-            trigger ./intHtoL eq complete and ./getvarepsdata eq complete
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit EPSLEG '3'
-            edit EPSFCRES '319'
-            edit EPSINISTEP '408'
-            edit EPSINISTEP_PREVIOUS '360'
-            edit FCLENGTH '408'
-            edit MEM '1600'
-            edit MRF '10'
-            edit STACK '350'
-            edit FCCHUNK '1'
-            edit EPSFCRESN '255'
-            edit EPSWAMRESOL 'global50'
-            edit EPSWAMNSTPW '1'
-            edit EPSFCLENGTH_B '360'
-            edit TSTEP '2700'
-            edit EPSFCLENGTH_A '240'
-            edit SMSTRIES '1'
-            edit NPES '1'
-            edit THREADS '64'
-            edit FCNPES '1'
-            edit CLASS 'od'
-            inlimit /emc_36r1/limits:modelepsB
-            meter step -1 408 408
-        endfamily
-      endfamily
-      family postproc
-        trigger ./fc eq active or ./fc eq complete
-        edit STEPS '372/768/12/24 768/768/12/120'
-        edit FCCHUNK '1'
-        edit OCTOTAL '5'
-        edit FCTOTAL '51'
-        edit DAILY '0'
-        edit RUNVARFC '1'
-        edit FCLENGTH1 '360'
-        edit FCLENGTH '768'
-        edit FCGROUP 'fc0'
-        inlimit /emc_36r1/limits:postproc
-        family dp
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit STEPS '366:768:6'
-          inlimit /emc_36r1/limits:dp
-          family cf
-            trigger ../../fc/cf eq complete
-            edit EMOS_TYPE 'cf'
-            task derived_param
-              edit MEMBER 'off'
-          endfamily
-          family pf
-            complete /emc_36r1/main/ref/00/events:cf
-            edit EMOS_TYPE 'pf'
-            family 01
-              trigger ../../../fc/pf/01 eq complete
-              edit EPSMEMBER '1'
-              edit MEMBER '1'
-              edit SUBFSFAMILY '/pf001'
-              task derived_param
-            endfamily
-            family 02
-              trigger ../../../fc/pf/02 eq complete
-              edit EPSMEMBER '2'
-              edit MEMBER '2'
-              edit SUBFSFAMILY '/pf002'
-              task derived_param
-            endfamily
-            family 03
-              trigger ../../../fc/pf/03 eq complete
-              edit EPSMEMBER '3'
-              edit MEMBER '3'
-              edit SUBFSFAMILY '/pf003'
-              task derived_param
-            endfamily
-            family 04
-              trigger ../../../fc/pf/04 eq complete
-              edit EPSMEMBER '4'
-              edit MEMBER '4'
-              edit SUBFSFAMILY '/pf004'
-              task derived_param
-            endfamily
-            family 05
-              trigger ../../../fc/pf/05 eq complete
-              edit EPSMEMBER '5'
-              edit MEMBER '5'
-              edit SUBFSFAMILY '/pf005'
-              task derived_param
-            endfamily
-            family 06
-              trigger ../../../fc/pf/06 eq complete
-              edit EPSMEMBER '6'
-              edit MEMBER '6'
-              edit SUBFSFAMILY '/pf006'
-              task derived_param
-            endfamily
-            family 07
-              trigger ../../../fc/pf/07 eq complete
-              edit EPSMEMBER '7'
-              edit MEMBER '7'
-              edit SUBFSFAMILY '/pf007'
-              task derived_param
-            endfamily
-            family 08
-              trigger ../../../fc/pf/08 eq complete
-              edit EPSMEMBER '8'
-              edit MEMBER '8'
-              edit SUBFSFAMILY '/pf008'
-              task derived_param
-            endfamily
-            family 09
-              trigger ../../../fc/pf/09 eq complete
-              edit EPSMEMBER '9'
-              edit MEMBER '9'
-              edit SUBFSFAMILY '/pf009'
-              task derived_param
-            endfamily
-            family 10
-              trigger ../../../fc/pf/10 eq complete
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              edit SUBFSFAMILY '/pf010'
-              task derived_param
-            endfamily
-            family 11
-              trigger ../../../fc/pf/11 eq complete
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              edit SUBFSFAMILY '/pf011'
-              task derived_param
-            endfamily
-            family 12
-              trigger ../../../fc/pf/12 eq complete
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              edit SUBFSFAMILY '/pf012'
-              task derived_param
-            endfamily
-            family 13
-              trigger ../../../fc/pf/13 eq complete
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              edit SUBFSFAMILY '/pf013'
-              task derived_param
-            endfamily
-            family 14
-              trigger ../../../fc/pf/14 eq complete
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              edit SUBFSFAMILY '/pf014'
-              task derived_param
-            endfamily
-            family 15
-              trigger ../../../fc/pf/15 eq complete
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              edit SUBFSFAMILY '/pf015'
-              task derived_param
-            endfamily
-            family 16
-              trigger ../../../fc/pf/16 eq complete
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              edit SUBFSFAMILY '/pf016'
-              task derived_param
-            endfamily
-            family 17
-              trigger ../../../fc/pf/17 eq complete
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              edit SUBFSFAMILY '/pf017'
-              task derived_param
-            endfamily
-            family 18
-              trigger ../../../fc/pf/18 eq complete
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              edit SUBFSFAMILY '/pf018'
-              task derived_param
-            endfamily
-            family 19
-              trigger ../../../fc/pf/19 eq complete
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              edit SUBFSFAMILY '/pf019'
-              task derived_param
-            endfamily
-            family 20
-              trigger ../../../fc/pf/20 eq complete
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              edit SUBFSFAMILY '/pf020'
-              task derived_param
-            endfamily
-            family 21
-              trigger ../../../fc/pf/21 eq complete
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              edit SUBFSFAMILY '/pf021'
-              task derived_param
-            endfamily
-            family 22
-              trigger ../../../fc/pf/22 eq complete
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              edit SUBFSFAMILY '/pf022'
-              task derived_param
-            endfamily
-            family 23
-              trigger ../../../fc/pf/23 eq complete
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              edit SUBFSFAMILY '/pf023'
-              task derived_param
-            endfamily
-            family 24
-              trigger ../../../fc/pf/24 eq complete
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              edit SUBFSFAMILY '/pf024'
-              task derived_param
-            endfamily
-            family 25
-              trigger ../../../fc/pf/25 eq complete
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              edit SUBFSFAMILY '/pf025'
-              task derived_param
-            endfamily
-            family 26
-              trigger ../../../fc/pf/26 eq complete
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              edit SUBFSFAMILY '/pf026'
-              task derived_param
-            endfamily
-            family 27
-              trigger ../../../fc/pf/27 eq complete
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              edit SUBFSFAMILY '/pf027'
-              task derived_param
-            endfamily
-            family 28
-              trigger ../../../fc/pf/28 eq complete
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              edit SUBFSFAMILY '/pf028'
-              task derived_param
-            endfamily
-            family 29
-              trigger ../../../fc/pf/29 eq complete
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              edit SUBFSFAMILY '/pf029'
-              task derived_param
-            endfamily
-            family 30
-              trigger ../../../fc/pf/30 eq complete
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              edit SUBFSFAMILY '/pf030'
-              task derived_param
-            endfamily
-            family 31
-              trigger ../../../fc/pf/31 eq complete
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              edit SUBFSFAMILY '/pf031'
-              task derived_param
-            endfamily
-            family 32
-              trigger ../../../fc/pf/32 eq complete
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              edit SUBFSFAMILY '/pf032'
-              task derived_param
-            endfamily
-            family 33
-              trigger ../../../fc/pf/33 eq complete
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              edit SUBFSFAMILY '/pf033'
-              task derived_param
-            endfamily
-            family 34
-              trigger ../../../fc/pf/34 eq complete
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              edit SUBFSFAMILY '/pf034'
-              task derived_param
-            endfamily
-            family 35
-              trigger ../../../fc/pf/35 eq complete
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              edit SUBFSFAMILY '/pf035'
-              task derived_param
-            endfamily
-            family 36
-              trigger ../../../fc/pf/36 eq complete
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              edit SUBFSFAMILY '/pf036'
-              task derived_param
-            endfamily
-            family 37
-              trigger ../../../fc/pf/37 eq complete
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              edit SUBFSFAMILY '/pf037'
-              task derived_param
-            endfamily
-            family 38
-              trigger ../../../fc/pf/38 eq complete
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              edit SUBFSFAMILY '/pf038'
-              task derived_param
-            endfamily
-            family 39
-              trigger ../../../fc/pf/39 eq complete
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              edit SUBFSFAMILY '/pf039'
-              task derived_param
-            endfamily
-            family 40
-              trigger ../../../fc/pf/40 eq complete
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              edit SUBFSFAMILY '/pf040'
-              task derived_param
-            endfamily
-            family 41
-              trigger ../../../fc/pf/41 eq complete
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              edit SUBFSFAMILY '/pf041'
-              task derived_param
-            endfamily
-            family 42
-              trigger ../../../fc/pf/42 eq complete
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              edit SUBFSFAMILY '/pf042'
-              task derived_param
-            endfamily
-            family 43
-              trigger ../../../fc/pf/43 eq complete
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              edit SUBFSFAMILY '/pf043'
-              task derived_param
-            endfamily
-            family 44
-              trigger ../../../fc/pf/44 eq complete
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              edit SUBFSFAMILY '/pf044'
-              task derived_param
-            endfamily
-            family 45
-              trigger ../../../fc/pf/45 eq complete
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              edit SUBFSFAMILY '/pf045'
-              task derived_param
-            endfamily
-            family 46
-              trigger ../../../fc/pf/46 eq complete
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              edit SUBFSFAMILY '/pf046'
-              task derived_param
-            endfamily
-            family 47
-              trigger ../../../fc/pf/47 eq complete
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              edit SUBFSFAMILY '/pf047'
-              task derived_param
-            endfamily
-            family 48
-              trigger ../../../fc/pf/48 eq complete
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              edit SUBFSFAMILY '/pf048'
-              task derived_param
-            endfamily
-            family 49
-              trigger ../../../fc/pf/49 eq complete
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              edit SUBFSFAMILY '/pf049'
-              task derived_param
-            endfamily
-            family 50
-              trigger ../../../fc/pf/50 eq complete
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              edit SUBFSFAMILY '/pf050'
-              task derived_param
-            endfamily
-          endfamily
-        endfamily
-        family extra
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit STEPS '366:768:6'
-          inlimit /emc_36r1/limits:extra
-          family cf
-            trigger ../dp/cf eq complete
-            edit EMOS_TYPE 'cf'
-            task extrafields
-              edit EPSFCRES '319'
-              edit FCLENGTH '768'
-              edit FCLENGTH0 '360'
-            task wm_sfc
-              trigger extrafields eq complete
-              edit FCLENGTH '768'
-            task wm_ua
-              trigger wm_sfc eq complete
-              edit FCLENGTH '768'
-          endfamily
-          family pf
-            complete /emc_36r1/main/ref/00/events:cf
-            edit EMOS_TYPE 'pf'
-            family 01
-              trigger ../../dp/pf/01 eq complete
-              edit EPSMEMBER '1'
-              edit MEMBER '1'
-              edit SUBFSFAMILY '/pf001'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 02
-              trigger ../../dp/pf/02 eq complete
-              edit EPSMEMBER '2'
-              edit MEMBER '2'
-              edit SUBFSFAMILY '/pf002'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 03
-              trigger ../../dp/pf/03 eq complete
-              edit EPSMEMBER '3'
-              edit MEMBER '3'
-              edit SUBFSFAMILY '/pf003'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 04
-              trigger ../../dp/pf/04 eq complete
-              edit EPSMEMBER '4'
-              edit MEMBER '4'
-              edit SUBFSFAMILY '/pf004'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 05
-              trigger ../../dp/pf/05 eq complete
-              edit EPSMEMBER '5'
-              edit MEMBER '5'
-              edit SUBFSFAMILY '/pf005'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 06
-              trigger ../../dp/pf/06 eq complete
-              edit EPSMEMBER '6'
-              edit MEMBER '6'
-              edit SUBFSFAMILY '/pf006'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 07
-              trigger ../../dp/pf/07 eq complete
-              edit EPSMEMBER '7'
-              edit MEMBER '7'
-              edit SUBFSFAMILY '/pf007'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 08
-              trigger ../../dp/pf/08 eq complete
-              edit EPSMEMBER '8'
-              edit MEMBER '8'
-              edit SUBFSFAMILY '/pf008'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 09
-              trigger ../../dp/pf/09 eq complete
-              edit EPSMEMBER '9'
-              edit MEMBER '9'
-              edit SUBFSFAMILY '/pf009'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 10
-              trigger ../../dp/pf/10 eq complete
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              edit SUBFSFAMILY '/pf010'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 11
-              trigger ../../dp/pf/11 eq complete
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              edit SUBFSFAMILY '/pf011'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 12
-              trigger ../../dp/pf/12 eq complete
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              edit SUBFSFAMILY '/pf012'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 13
-              trigger ../../dp/pf/13 eq complete
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              edit SUBFSFAMILY '/pf013'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 14
-              trigger ../../dp/pf/14 eq complete
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              edit SUBFSFAMILY '/pf014'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 15
-              trigger ../../dp/pf/15 eq complete
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              edit SUBFSFAMILY '/pf015'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 16
-              trigger ../../dp/pf/16 eq complete
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              edit SUBFSFAMILY '/pf016'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 17
-              trigger ../../dp/pf/17 eq complete
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              edit SUBFSFAMILY '/pf017'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 18
-              trigger ../../dp/pf/18 eq complete
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              edit SUBFSFAMILY '/pf018'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 19
-              trigger ../../dp/pf/19 eq complete
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              edit SUBFSFAMILY '/pf019'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 20
-              trigger ../../dp/pf/20 eq complete
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              edit SUBFSFAMILY '/pf020'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 21
-              trigger ../../dp/pf/21 eq complete
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              edit SUBFSFAMILY '/pf021'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 22
-              trigger ../../dp/pf/22 eq complete
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              edit SUBFSFAMILY '/pf022'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 23
-              trigger ../../dp/pf/23 eq complete
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              edit SUBFSFAMILY '/pf023'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 24
-              trigger ../../dp/pf/24 eq complete
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              edit SUBFSFAMILY '/pf024'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 25
-              trigger ../../dp/pf/25 eq complete
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              edit SUBFSFAMILY '/pf025'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 26
-              trigger ../../dp/pf/26 eq complete
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              edit SUBFSFAMILY '/pf026'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 27
-              trigger ../../dp/pf/27 eq complete
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              edit SUBFSFAMILY '/pf027'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 28
-              trigger ../../dp/pf/28 eq complete
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              edit SUBFSFAMILY '/pf028'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 29
-              trigger ../../dp/pf/29 eq complete
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              edit SUBFSFAMILY '/pf029'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 30
-              trigger ../../dp/pf/30 eq complete
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              edit SUBFSFAMILY '/pf030'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 31
-              trigger ../../dp/pf/31 eq complete
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              edit SUBFSFAMILY '/pf031'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 32
-              trigger ../../dp/pf/32 eq complete
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              edit SUBFSFAMILY '/pf032'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 33
-              trigger ../../dp/pf/33 eq complete
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              edit SUBFSFAMILY '/pf033'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 34
-              trigger ../../dp/pf/34 eq complete
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              edit SUBFSFAMILY '/pf034'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 35
-              trigger ../../dp/pf/35 eq complete
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              edit SUBFSFAMILY '/pf035'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 36
-              trigger ../../dp/pf/36 eq complete
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              edit SUBFSFAMILY '/pf036'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 37
-              trigger ../../dp/pf/37 eq complete
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              edit SUBFSFAMILY '/pf037'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 38
-              trigger ../../dp/pf/38 eq complete
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              edit SUBFSFAMILY '/pf038'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 39
-              trigger ../../dp/pf/39 eq complete
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              edit SUBFSFAMILY '/pf039'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 40
-              trigger ../../dp/pf/40 eq complete
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              edit SUBFSFAMILY '/pf040'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 41
-              trigger ../../dp/pf/41 eq complete
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              edit SUBFSFAMILY '/pf041'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 42
-              trigger ../../dp/pf/42 eq complete
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              edit SUBFSFAMILY '/pf042'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 43
-              trigger ../../dp/pf/43 eq complete
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              edit SUBFSFAMILY '/pf043'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 44
-              trigger ../../dp/pf/44 eq complete
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              edit SUBFSFAMILY '/pf044'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 45
-              trigger ../../dp/pf/45 eq complete
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              edit SUBFSFAMILY '/pf045'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 46
-              trigger ../../dp/pf/46 eq complete
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              edit SUBFSFAMILY '/pf046'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 47
-              trigger ../../dp/pf/47 eq complete
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              edit SUBFSFAMILY '/pf047'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 48
-              trigger ../../dp/pf/48 eq complete
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              edit SUBFSFAMILY '/pf048'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 49
-              trigger ../../dp/pf/49 eq complete
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              edit SUBFSFAMILY '/pf049'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-            family 50
-              trigger ../../dp/pf/50 eq complete
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              edit SUBFSFAMILY '/pf050'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '768'
-                edit FCLENGTH0 '360'
-              task wm_sfc
-                trigger extrafields eq complete
-                edit FCLENGTH '768'
-              task wm_ua
-                trigger wm_sfc eq complete
-                edit FCLENGTH '768'
-            endfamily
-          endfamily
-        endfamily
-        family mofc
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-          edit EMOS_TYPE '00'
-          edit EXPVER_ENFH '0046'
-          edit EXPVER_EFHS '0046'
-          edit NH_ENSEMBLES '4'
-          task wmem_veps
-            trigger ../dp eq complete and ../extra eq complete and ../ensms eq complete
-          family wmanom
-            trigger ( /emc_36r1/hc0:YMD gt /emc_36r1/00:YMD or ( /emc_36r1/hc0:YMD eq /emc_36r1/00:YMD and /emc_36r1/hc0/postproc/wmem_veps eq complete)) and wmem_veps eq complete and ../ensms eq complete
-            edit WRITE_FDB '0'
-            family fcmean
-              edit TYPES 'fcmean'
-              family 129
-                edit PARAMS '129'
-                task wmanom
-              endfamily
-              family all
-                edit PARAMS '130 133 001 078 228'
-                task wmanom
-              endfamily
-            endfamily
-            family em
-              edit TYPES 'em'
-              family all
-                edit PARAMS 'all'
-                task wmanom
-              endfamily
-            endfamily
-            task prob_fdb
-              trigger fcmean eq complete and em eq complete
-              edit PARAM '129 130 133 001 078 228 144 all'
-              edit MARS_FDB_SET_TABLE '1'
-          endfamily
-          task signi
-            trigger wmanom eq complete
-          task prob_thr
-            trigger wmanom eq complete
-          task prob_perc
-            trigger wmanom eq complete
-        endfamily
-        family ensms
-          complete /emc_36r1/main/ref/00/events:cf
-          trigger ../fc eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-          family limits
-            limit fdb 1
-            limit gen 8
-          endfamily
-          task ensms
-            edit ENS_M 'false'
-            edit ENS_S 'false'
-            edit ENS_MARS 'false'
-            event stage
-          family 498
-            trigger ./ensms:stage or ./ensms eq complete
-            edit STEP1 '366'
-            edit STEP2 '498'
-            edit BY '6'
-            edit STEPS '0'
-            family T
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit LIST_PARAM 'T'
-              inlimit ../limits:gen
-              family 850
-                task ensms
-                  edit LIST_LEV '850'
-              endfamily
-              family 500
-                task ensms
-                  edit LIST_LEV '500'
-              endfamily
-            endfamily
-            family Z
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit LIST_PARAM 'Z'
-              inlimit ../limits:gen
-              family 1000
-                task ensms
-                  edit LIST_LEV '1000'
-              endfamily
-              family 500
-                task ensms
-                  edit LIST_LEV '500'
-              endfamily
-            endfamily
-            task ensms
-              trigger T eq complete and Z eq complete
-              edit ENS_MARS 'false'
-              inlimit ../limits:fdb
-          endfamily
-          family 636
-            trigger ./ensms:stage or ./ensms eq complete
-            edit STEP1 '504'
-            edit STEP2 '636'
-            edit BY '6'
-            edit STEPS '0'
-            family T
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit LIST_PARAM 'T'
-              inlimit ../limits:gen
-              family 850
-                task ensms
-                  edit LIST_LEV '850'
-              endfamily
-              family 500
-                task ensms
-                  edit LIST_LEV '500'
-              endfamily
-            endfamily
-            family Z
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit LIST_PARAM 'Z'
-              inlimit ../limits:gen
-              family 1000
-                task ensms
-                  edit LIST_LEV '1000'
-              endfamily
-              family 500
-                task ensms
-                  edit LIST_LEV '500'
-              endfamily
-            endfamily
-            task ensms
-              trigger T eq complete and Z eq complete
-              edit ENS_MARS 'false'
-              inlimit ../limits:fdb
-          endfamily
-          family 768
-            trigger ./ensms:stage or ./ensms eq complete
-            edit STEP1 '642'
-            edit STEP2 '768'
-            edit BY '6'
-            edit STEPS '0'
-            family T
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit LIST_PARAM 'T'
-              inlimit ../limits:gen
-              family 850
-                task ensms
-                  edit LIST_LEV '850'
-              endfamily
-              family 500
-                task ensms
-                  edit LIST_LEV '500'
-              endfamily
-            endfamily
-            family Z
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit LIST_PARAM 'Z'
-              inlimit ../limits:gen
-              family 1000
-                task ensms
-                  edit LIST_LEV '1000'
-              endfamily
-              family 500
-                task ensms
-                  edit LIST_LEV '500'
-              endfamily
-            endfamily
-            task ensms
-              trigger T eq complete and Z eq complete
-              edit ENS_MARS 'false'
-              inlimit ../limits:fdb
-          endfamily
-        endfamily
-      endfamily
-      family prod
-        trigger fc eq complete and postproc eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-        edit EMOS_STREAM 'ENFO'
-        edit EMOS_DOMAIN 'G'
-        edit EMOS_TYPE 'FC'
-        edit PROD_TASK '1'
-        edit EMOS_PROJECT '00'
-        edit EMOS_BASE '00'
-        edit PGNPES '32'
-        family eps
-          trigger ( ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and ( /emc_36r1/main/00/legA/prod/getreq/eps eq complete or /emc_36r1/main/00/legA/prod/getreq/eps:001) and ( /emc_36r1/main/00/legA/prod/getreq/bitmap eq complete or /emc_36r1/main/00/legA/prod/getreq/bitmap:001)))
-          edit EMOS_STREAM 'ENFO'
-          family day01
-            edit EMOS_TIME_STEP_H '0001'
-            task prodgen
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day02
-            edit EMOS_TIME_STEP_H '0002'
-            task prodgen
-              trigger ../day01/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day01/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day03
-            edit EMOS_TIME_STEP_H '0003'
-            task prodgen
-              trigger ../day02/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day02/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day04
-            edit EMOS_TIME_STEP_H '0004'
-            task prodgen
-              trigger ../day03/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day03/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day05
-            edit EMOS_TIME_STEP_H '0005'
-            task prodgen
-              trigger ../day04/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day04/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day06
-            edit EMOS_TIME_STEP_H '0006'
-            task prodgen
-              trigger ../day05/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day05/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day07
-            edit EMOS_TIME_STEP_H '0007'
-            task prodgen
-              trigger ../day06/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day06/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day08
-            edit EMOS_TIME_STEP_H '0008'
-            task prodgen
-              trigger ../day07/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day07/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day09
-            edit EMOS_TIME_STEP_H '0009'
-            task prodgen
-              trigger ../day08/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day08/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day10
-            edit EMOS_TIME_STEP_H '0010'
-            task prodgen
-              trigger ../day09/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day09/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day11
-            edit EMOS_TIME_STEP_H '0011'
-            task prodgen
-              trigger ../day10/prodgen eq complete
-              edit MEM '1900'
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day10/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day12
-            edit EMOS_TIME_STEP_H '0012'
-            task prodgen
-              trigger ../day11/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day11/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day13
-            edit EMOS_TIME_STEP_H '0013'
-            task prodgen
-              trigger ../day12/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day12/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day14
-            edit EMOS_TIME_STEP_H '0014'
-            task prodgen
-              trigger ../day13/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day13/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day15
-            edit EMOS_TIME_STEP_H '0015'
-            task prodgen
-              trigger ../day14/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day14/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day16
-            edit EMOS_TIME_STEP_H '0016'
-            task prodgen
-              trigger ../day15/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day15/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day17
-            edit EMOS_TIME_STEP_H '0017'
-            task prodgen
-              trigger ../day16/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day16/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day18
-            edit EMOS_TIME_STEP_H '0018'
-            task prodgen
-              trigger ../day17/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day17/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day19
-            edit EMOS_TIME_STEP_H '0019'
-            task prodgen
-              trigger ../day18/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day18/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day20
-            edit EMOS_TIME_STEP_H '0020'
-            task prodgen
-              trigger ../day19/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day19/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day21
-            edit EMOS_TIME_STEP_H '0021'
-            task prodgen
-              trigger ../day20/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day20/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day22
-            edit EMOS_TIME_STEP_H '0022'
-            task prodgen
-              trigger ../day21/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day21/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day23
-            edit EMOS_TIME_STEP_H '0023'
-            task prodgen
-              trigger ../day22/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day22/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day24
-            edit EMOS_TIME_STEP_H '0024'
-            task prodgen
-              trigger ../day23/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day23/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day25
-            edit EMOS_TIME_STEP_H '0025'
-            task prodgen
-              trigger ../day24/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day24/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day26
-            edit EMOS_TIME_STEP_H '0026'
-            task prodgen
-              trigger ../day25/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day25/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day27
-            edit EMOS_TIME_STEP_H '0027'
-            task prodgen
-              trigger ../day26/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day26/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day28
-            edit EMOS_TIME_STEP_H '0028'
-            task prodgen
-              trigger ../day27/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day27/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day29
-            edit EMOS_TIME_STEP_H '0029'
-            task prodgen
-              trigger ../day28/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day28/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day30
-            edit EMOS_TIME_STEP_H '0030'
-            task prodgen
-              trigger ../day29/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day29/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day31
-            edit EMOS_TIME_STEP_H '0031'
-            task prodgen
-              trigger ../day30/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day30/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day32
-            edit EMOS_TIME_STEP_H '0032'
-            task prodgen
-              trigger ../day31/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day31/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day33
-            edit EMOS_TIME_STEP_H '0033'
-            task prodgen
-              trigger ../day32/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day32/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-        endfamily
-        family wave
-          trigger ./eps/day33/prodgen eq complete and ( ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and ( /emc_36r1/main/00/legA/prod/getreq/wave_eps eq complete or /emc_36r1/main/00/legA/prod/getreq/wave_eps:001)))
-          edit PGNPES '4'
-          edit EMOS_STREAM 'WAEF'
-          family day01
-            edit EMOS_TIME_STEP_H '0001'
-            task prodgen
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ./pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day02
-            edit EMOS_TIME_STEP_H '0002'
-            task prodgen
-              trigger ../day01/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day01/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day03
-            edit EMOS_TIME_STEP_H '0003'
-            task prodgen
-              trigger ../day02/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day02/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day04
-            edit EMOS_TIME_STEP_H '0004'
-            task prodgen
-              trigger ../day03/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day03/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day05
-            edit EMOS_TIME_STEP_H '0005'
-            task prodgen
-              trigger ../day04/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day04/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day06
-            edit EMOS_TIME_STEP_H '0006'
-            task prodgen
-              trigger ../day05/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day05/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day07
-            edit EMOS_TIME_STEP_H '0007'
-            task prodgen
-              trigger ../day06/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day06/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day08
-            edit EMOS_TIME_STEP_H '0008'
-            task prodgen
-              trigger ../day07/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day07/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day09
-            edit EMOS_TIME_STEP_H '0009'
-            task prodgen
-              trigger ../day08/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day08/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day10
-            edit EMOS_TIME_STEP_H '0010'
-            task prodgen
-              trigger ../day09/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day09/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day11
-            edit EMOS_TIME_STEP_H '0011'
-            task prodgen
-              trigger ../day10/prodgen eq complete
-              edit MEM '1900'
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day10/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day12
-            edit EMOS_TIME_STEP_H '0012'
-            task prodgen
-              trigger ../day11/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day11/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day13
-            edit EMOS_TIME_STEP_H '0013'
-            task prodgen
-              trigger ../day12/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day12/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day14
-            edit EMOS_TIME_STEP_H '0014'
-            task prodgen
-              trigger ../day13/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day13/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day15
-            edit EMOS_TIME_STEP_H '0015'
-            task prodgen
-              trigger ../day14/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day14/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day16
-            edit EMOS_TIME_STEP_H '0016'
-            task prodgen
-              trigger ../day15/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day15/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day17
-            edit EMOS_TIME_STEP_H '0017'
-            task prodgen
-              trigger ../day16/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day16/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day18
-            edit EMOS_TIME_STEP_H '0018'
-            task prodgen
-              trigger ../day17/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day17/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day19
-            edit EMOS_TIME_STEP_H '0019'
-            task prodgen
-              trigger ../day18/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day18/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day20
-            edit EMOS_TIME_STEP_H '0020'
-            task prodgen
-              trigger ../day19/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day19/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day21
-            edit EMOS_TIME_STEP_H '0021'
-            task prodgen
-              trigger ../day20/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day20/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day22
-            edit EMOS_TIME_STEP_H '0022'
-            task prodgen
-              trigger ../day21/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day21/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day23
-            edit EMOS_TIME_STEP_H '0023'
-            task prodgen
-              trigger ../day22/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day22/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day24
-            edit EMOS_TIME_STEP_H '0024'
-            task prodgen
-              trigger ../day23/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day23/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day25
-            edit EMOS_TIME_STEP_H '0025'
-            task prodgen
-              trigger ../day24/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day24/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day26
-            edit EMOS_TIME_STEP_H '0026'
-            task prodgen
-              trigger ../day25/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day25/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day27
-            edit EMOS_TIME_STEP_H '0027'
-            task prodgen
-              trigger ../day26/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day26/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day28
-            edit EMOS_TIME_STEP_H '0028'
-            task prodgen
-              trigger ../day27/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day27/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day29
-            edit EMOS_TIME_STEP_H '0029'
-            task prodgen
-              trigger ../day28/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day28/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day30
-            edit EMOS_TIME_STEP_H '0030'
-            task prodgen
-              trigger ../day29/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day29/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day31
-            edit EMOS_TIME_STEP_H '0031'
-            task prodgen
-              trigger ../day30/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day30/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day32
-            edit EMOS_TIME_STEP_H '0032'
-            task prodgen
-              trigger ../day31/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day31/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-          family day33
-            edit EMOS_TIME_STEP_H '0033'
-            task prodgen
-              trigger ../day32/prodgen eq complete
-            task pdb
-              trigger prodgen eq complete
-              inlimit /emc_36r1/limits:pdb
-              inlimit /limits:pdb
-              label info ""
-              event 1 
-            task q2diss
-              late -s +00:05 -c +00:15
-              trigger ../day32/q2diss eq complete and pdb eq complete
-              edit USER_PRIORITY '93'
-              inlimit /emc_36r1/limits:q2diss
-              inlimit /limits:q2diss
-              label info ""
-              event 1 
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-    family arch
-      trigger ./legC/fc eq complete
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-      edit EPSLEG '3'
-      edit FSFAMILY 'mars'
-      edit OVERLAP '0'
-      edit EMOS_TYPE 'an'
-      edit EPSFCRES '255'
-      inlimit /emc_36r1/limits:mars
-      inlimit /limits:mars
-      family cf
-        edit EMOS_TYPE 'cf'
-        edit NUMBER '0'
-        family cf408
-          edit STEPS '366/to/408/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family cf480
-          edit STEPS '414/to/480/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family cf600
-          edit STEPS '486/to/600/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family cf768
-          edit STEPS '606/to/768/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-      endfamily
-      family pf
-        complete /emc_36r1/main/ref/00/events:cf
-        edit EMOS_TYPE 'pf'
-        family pf408
-          edit STEPS '366/to/408/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family pf480
-          edit STEPS '414/to/480/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family pf600
-          edit STEPS '486/to/600/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family pf768
-          edit STEPS '606/to/768/by/6'
-          task pfpl
-            inlimit /emc_36r1/limits:pl
-            label files ""
-            label info ""
-            event fdb
-          task pfsfc
-            trigger ../../postproc/dp eq complete
-            inlimit /emc_36r1/limits:sfc
-            label files ""
-            label info ""
-            event fdb
-          task pfil
-            label files ""
-            label info ""
-            event fdb
-          task pfwv
-            edit STREAM 'WAEF'
-            edit EMOS_STREAM 'WAEF'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-      endfamily
-      family postproc
-        complete /emc_36r1/main/ref/00/events:cf
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-        edit FCCHUNK '1'
-        edit FCLENGTH '768'
-        inlimit /emc_36r1/limits:postproc
-        family mofc
-          complete /emc_36r1/main/ref/00/events:cf
-          trigger /emc_36r1/00/legC/postproc/mofc eq complete
-          task prob_archive
-            label info ""
-          task wmem_archive
-            label info ""
-          task wmanom_archive
-            label info ""
-          task signi_archive
-            trigger wmanom_archive eq complete
-            label info ""
-        endfamily
-        family ensms
-          trigger /emc_36r1/00/legC/postproc/ensms eq complete
-          edit EMOS_TYPE 'an'
-          family 768
-            edit STEPS '366/to/768/by/6'
-            task mean
-              edit TYPE 'em'
-              label files ""
-              label info ""
-              event fdb
-            task stdev
-              edit TYPE 'es'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family dp
-          trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-          edit RUNVARFC '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          edit EMOS_TYPE 'pf'
-          edit STEPS '366/to/768/by/6'
-          family cf
-            edit EMOS_TYPE 'cf'
-            task derivedp
-              label files ""
-              label info ""
-              event fdb
-            task extra_arc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit STEPS '360/to/768'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            task derivedp
-              label files ""
-              label info ""
-              event fdb
-            task extra_arc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit STEPS '360/to/768'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family extra
-          trigger /emc_36r1/00/legC/postproc/extra eq complete
-          edit RUNVARFC '1'
-          task wm_sfc_arc
-            label files ""
-            label info ""
-            event fdb
-          task wm_ua_arc
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family reord
-          complete /emc_36r1/lag/ref/00/events:cf
-          edit EPSCOUPLE '1'
-          edit EMOS_TYPE 'pf'
-          edit FCLENGTH0 '360'
-          edit FCLENGTH '768'
-          edit EPSFCRES '255'
-          edit FCCHUNK '1'
-          edit STEP1 '360'
-          edit STEP2 '768'
-          edit STEPS '-1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-          limit reord 1
-          inlimit reord
-          label info ""
-          family 130
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '130.128'
-            task reord
-              label info ""
-          endfamily
-          family 228
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '228.128'
-            task reord
-              label info ""
-          endfamily
-          family 207
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '207.128'
-            task reord
-              label info ""
-          endfamily
-          family 167
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '167.128'
-            task reord
-              label info ""
-          endfamily
-          family 164
-            edit GENERATE '1'
-            edit ARCHIVE '0'
-            edit PARAMS '164.128'
-            task reord
-              label info ""
-          endfamily
-          family arch
-            trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
-            edit GENERATE '0'
-            edit ARCHIVE '1'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task reord
-              label info ""
-          endfamily
-        endfamily
-        family nino
-          edit FCCHUNK '1'
-          edit OCTOTAL '5'
-          edit FCTOTAL '51'
-          edit DAILY '0'
-          edit RUNVARFC '1'
-          edit FCLENGTH1 '360'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FCLENGTH '768'
-          edit EPSCOUPLE '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-          limit semaphore 10
-          inlimit /limits:linux_cluster
-          inlimit semaphore
-          family 00
-            edit OCGROUP 'an00'
-            edit FCGROUP 'fc0'
-            edit EPSMEMBER '0'
-            edit MEMBER '0'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 01
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc0'
-            edit EPSMEMBER '1'
-            edit MEMBER '1'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 02
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc0'
-            edit EPSMEMBER '2'
-            edit MEMBER '2'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 03
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc0'
-            edit EPSMEMBER '3'
-            edit MEMBER '3'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 04
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc0'
-            edit EPSMEMBER '4'
-            edit MEMBER '4'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 05
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc1'
-            edit EPSMEMBER '5'
-            edit MEMBER '5'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 06
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc1'
-            edit EPSMEMBER '6'
-            edit MEMBER '6'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 07
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc1'
-            edit EPSMEMBER '7'
-            edit MEMBER '7'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 08
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc1'
-            edit EPSMEMBER '8'
-            edit MEMBER '8'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 09
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc1'
-            edit EPSMEMBER '9'
-            edit MEMBER '9'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 10
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc2'
-            edit EPSMEMBER '10'
-            edit MEMBER '10'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 11
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc2'
-            edit EPSMEMBER '11'
-            edit MEMBER '11'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 12
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc2'
-            edit EPSMEMBER '12'
-            edit MEMBER '12'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 13
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc2'
-            edit EPSMEMBER '13'
-            edit MEMBER '13'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 14
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc2'
-            edit EPSMEMBER '14'
-            edit MEMBER '14'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 15
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc3'
-            edit EPSMEMBER '15'
-            edit MEMBER '15'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 16
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc3'
-            edit EPSMEMBER '16'
-            edit MEMBER '16'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 17
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc3'
-            edit EPSMEMBER '17'
-            edit MEMBER '17'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 18
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc3'
-            edit EPSMEMBER '18'
-            edit MEMBER '18'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 19
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc3'
-            edit EPSMEMBER '19'
-            edit MEMBER '19'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 20
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc4'
-            edit EPSMEMBER '20'
-            edit MEMBER '20'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 21
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc4'
-            edit EPSMEMBER '21'
-            edit MEMBER '21'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 22
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc4'
-            edit EPSMEMBER '22'
-            edit MEMBER '22'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 23
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc4'
-            edit EPSMEMBER '23'
-            edit MEMBER '23'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 24
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc4'
-            edit EPSMEMBER '24'
-            edit MEMBER '24'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 25
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc5'
-            edit EPSMEMBER '25'
-            edit MEMBER '25'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 26
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc5'
-            edit EPSMEMBER '26'
-            edit MEMBER '26'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 27
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc5'
-            edit EPSMEMBER '27'
-            edit MEMBER '27'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 28
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc5'
-            edit EPSMEMBER '28'
-            edit MEMBER '28'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 29
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc5'
-            edit EPSMEMBER '29'
-            edit MEMBER '29'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 30
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc6'
-            edit EPSMEMBER '30'
-            edit MEMBER '30'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 31
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc6'
-            edit EPSMEMBER '31'
-            edit MEMBER '31'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 32
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc6'
-            edit EPSMEMBER '32'
-            edit MEMBER '32'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 33
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc6'
-            edit EPSMEMBER '33'
-            edit MEMBER '33'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 34
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc6'
-            edit EPSMEMBER '34'
-            edit MEMBER '34'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 35
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc7'
-            edit EPSMEMBER '35'
-            edit MEMBER '35'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 36
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc7'
-            edit EPSMEMBER '36'
-            edit MEMBER '36'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 37
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc7'
-            edit EPSMEMBER '37'
-            edit MEMBER '37'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 38
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc7'
-            edit EPSMEMBER '38'
-            edit MEMBER '38'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 39
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc7'
-            edit EPSMEMBER '39'
-            edit MEMBER '39'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 40
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc8'
-            edit EPSMEMBER '40'
-            edit MEMBER '40'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 41
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc8'
-            edit EPSMEMBER '41'
-            edit MEMBER '41'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 42
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc8'
-            edit EPSMEMBER '42'
-            edit MEMBER '42'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 43
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc8'
-            edit EPSMEMBER '43'
-            edit MEMBER '43'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 44
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc8'
-            edit EPSMEMBER '44'
-            edit MEMBER '44'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 45
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc9'
-            edit EPSMEMBER '45'
-            edit MEMBER '45'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 46
-            edit OCGROUP 'an1'
-            edit FCGROUP 'fc9'
-            edit EPSMEMBER '46'
-            edit MEMBER '46'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 47
-            edit OCGROUP 'an2'
-            edit FCGROUP 'fc9'
-            edit EPSMEMBER '47'
-            edit MEMBER '47'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 48
-            edit OCGROUP 'an3'
-            edit FCGROUP 'fc9'
-            edit EPSMEMBER '48'
-            edit MEMBER '48'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 49
-            edit OCGROUP 'an4'
-            edit FCGROUP 'fc9'
-            edit EPSMEMBER '49'
-            edit MEMBER '49'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-          family 50
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc10'
-            edit EPSMEMBER '50'
-            edit MEMBER '50'
-            task nino_daily
-            task tcyc
-              trigger nino_daily eq complete or nino_daily eq aborted
-          endfamily
-        endfamily
-        task tcyctoecfs
-          trigger nino eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-          edit EPSCOUPLE '1'
-          edit FCLENGTH '768'
-          inlimit /limits:linux_cluster
-      endfamily
-      family coupled
-        complete /emc_36r1/main/ref/00/events:cf
-        edit EPSLEG '3'
-        edit OCLEG '3'
-        edit OCEPS '3'
-        edit FCCHUNK '1'
-        edit FCLENGTH '768'
-        edit FCLENGTH0 '360'
-        edit OCEPSTOT '3'
-        edit FCTOTAL '51'
-        edit RUNVARFC '1'
-        edit EPSCOUPLE '1'
-        edit RUNCOUPLE '1'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-        inlimit /emc_36r1/lag/ref/00:mutex
-        task preparcoce
-        task arcfc
-          trigger preparcoce eq complete
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-    endfamily
-    family msjobs
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete and /emc_36r1/main/make eq complete)
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'ecgate'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit VERSION '0046'
-      edit STREAM 'EF'
-      edit EMOS_STREAM 'EF'
-      edit SMSURLBASE 'http://ecgate.ecmwf.int:9080'
-      edit SMSURL 'do/events'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs'
-      edit DELAY '120'
-      edit EMOS_TIME_STEP_H '768'
-      family hindcast
-        trigger /emc_36r1/hc0/postproc eq complete and /emc_36r1/00/ref/thu1000 eq complete
-        edit STREAM 'ENFH'
-        edit EMOS_STREAM 'ENFH'
-        edit MSJ_DIR 'mofcrefc'
-        task ms_ec
-      endfamily
-      family legC
-        trigger ../legC eq complete and /emc_36r1/00/ref/thu2200 eq complete
-        edit MSJ_DIR 'mofc_all'
-        task ms_ec
-        family noaa
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit RUNVARFC '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs/noaa'
-          edit DISS_HOUR '2200'
-          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-          edit SMSURL 'CDC/EF/00'
-          edit CALL_FTP 'false'
-          edit CALL_ECPDS 'true'
-          task delete
-            trigger ncep_weekly eq complete and /emc_36r1/00/web eq complete and /emc_36r1/00/ref/tue eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-          task ncep_weekly
-            trigger /emc_36r1/00/web/process/mjo eq complete
-            edit SMSURL 'NO9/EF/00'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-            edit FCLENGTH '768'
-            edit ERA40END '2002033000'
-        endfamily
-      endfamily
-    endfamily
-    family web
-      trigger ../00:YMD + 14 le ../hc2:YMD
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit WSHOST 'linux_cluster'
-      edit QUEUE 'plots-medium'
-      edit MARS_DB 'c1b fdb'
-      edit EPSLEG '3'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-      edit EMOS_TYPE '00'
-      edit RUNVARFC '1'
-      edit NH_ENSEMBLES '4'
-      edit EXPVER_ENFH '0046'
-      edit EXPVER_EFHS '0046'
-      inlimit /limits:linux_cluster
-      inlimit /emc_36r1/limits:webplots
-      family stage
-        edit RETRIEVE 'stage'
-        task chi200
-        task olr
-        task u200
-        task u850
-      endfamily
-      family process
-        trigger ../legC/fc eq complete and ../legC/postproc eq complete
-        family anomaly
-          family temp
-            edit VAR 'TEMP'
-            task plot_anom
-          endfamily
-          family rain
-            edit VAR 'RAIN'
-            task plot_anom
-          endfamily
-          family mslp
-            edit VAR 'MSLP'
-            task plot_anom
-          endfamily
-          family 2mtm
-            edit VAR '2MTM'
-            task plot_anom
-          endfamily
-          task toweb
-            trigger temp eq complete and rain eq complete and mslp eq complete and ./2mtm eq complete
-        endfamily
-        family probanom
-          family temp
-            edit VAR 'TEMP'
-            task plot_prob
-          endfamily
-          family rain
-            edit VAR 'RAIN'
-            task plot_prob
-          endfamily
-          family mslp
-            edit VAR 'MSLP'
-            task plot_prob
-          endfamily
-          family 2mtm
-            edit VAR '2MTM'
-            task plot_prob
-          endfamily
-          task toweb
-            trigger temp eq complete and rain eq complete and mslp eq complete and ./2mtm eq complete
-        endfamily
-        family tercile
-          family temp
-            edit VAR 'TEMP'
-            task plot_terc
-          endfamily
-          family rain
-            edit VAR 'RAIN'
-            task plot_terc
-          endfamily
-          family mslp
-            edit VAR 'MSLP'
-            task plot_terc
-          endfamily
-          family 2mtm
-            edit VAR '2MTM'
-            task plot_terc
-          endfamily
-          task toweb
-            trigger temp eq complete and rain eq complete and mslp eq complete and ./2mtm eq complete
-            edit TERCILES '.terc1. .terc2.'
-        endfamily
-        family eps
-          trigger ./tercile eq complete or ./tercile/toweb eq aborted
-          family members
-            task mslp
-              late -c +02:00
-            task z500
-            task mslp_wm
-            task z500_wm
-          endfamily
-          family plumes
-            task plume31
-            task plumeter
-              trigger plume31 eq complete
-          endfamily
-          family regime
-            task kmeansclust
-            task kmeansclust_week
-            task plotkmeansclust
-              trigger kmeansclust_week eq complete and kmeansclust eq complete
-            task hovmoeller
-            task hovmoeller_itr
-            task flowz500
-            task multivar
-          endfamily
-          task epstoweb
-            trigger members eq complete and plumes eq complete and regime eq complete
-        endfamily
-        family mjo
-          trigger ../stage eq complete
-          edit FCLENGTH '768'
-          edit ERA40END '2002033000'
-          family process
-            task chi200
-            task olr
-            task u850
-            task u200
-          endfamily
-          task mjotoweb
-            trigger ceof eq complete
-          task ceof
-            trigger process eq complete
-          family ncep
-            trigger process eq complete
-            task olr_to_ncep
-            task u200_to_ncep
-            task u850_to_ncep
-          endfamily
-        endfamily
-        family tcyc
-          trigger /emc_36r1/00/arch/postproc/nino eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web/tcyc'
-          family hr
-            edit KIND 'hr'
-            family clim
-              edit PROC 'clim'
-              task tcycweb
-            endfamily
-            family map
-              edit PROC 'map'
-              task tcycweb
-            endfamily
-            family diff
-              trigger clim eq complete and map eq complete
-              edit PROC 'diff'
-              task tcycweb
-            endfamily
-          endfamily
-          family ts
-            edit KIND 'ts'
-            family clim
-              edit PROC 'clim'
-              task tcycweb
-            endfamily
-            family map
-              edit PROC 'map'
-              task tcycweb
-            endfamily
-            family diff
-              trigger clim eq complete and map eq complete
-              edit PROC 'diff'
-              task tcycweb
-            endfamily
-          endfamily
-          family td
-            edit KIND 'td'
-            family clim
-              edit PROC 'clim'
-              task tcycweb
-            endfamily
-            family map
-              edit PROC 'map'
-              task tcycweb
-            endfamily
-            family diff
-              trigger clim eq complete and map eq complete
-              edit PROC 'diff'
-              task tcycweb
-            endfamily
-          endfamily
-          task freq
-            trigger hr eq complete and ts eq complete and td eq complete
-          task tcyctoweb
-            trigger hr eq complete and ts eq complete and td eq complete and freq eq complete
-        endfamily
-        family tcyc_hc
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web/tcyc'
-          task tcyc_hc
-            edit WSHOST 'localhost'
-        endfamily
-      endfamily
-      task web_update
-        trigger ./process eq complete and /emc_36r1/00/ref/thu2200 eq complete
-      family clean
-        trigger process eq complete and web_update eq complete
-        task migrate
-        task delete
-          trigger migrate eq complete
-      endfamily
-    endfamily
-    family amma
-      trigger ./web eq complete and ./ref/thu2200 eq complete
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit UPDATE_WEB_NOW 'yes'
-      edit WSHOST 'linux_cluster'
-      edit QUEUE 'emos'
-      edit FSFAMILY 'assim'
-      edit FCTOTAL '51'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg/amma'
-      edit RUNVARFC '1'
-      edit EMOS_TYPE '00'
-      edit EMOS_BASE '00'
-      inlimit /limits:linux_cluster
-      family init
-        task list
-        task getfore
-          trigger ./list eq complete
-        task getclim
-          trigger ./getfore eq complete
-      endfamily
-      family anomaly
-        trigger ./init eq complete
-        family sf200
-          edit VAR 'SF200'
-          task stats_a
-          task plot_a
-            trigger stats_a eq complete
-        endfamily
-        family vp200
-          trigger ./sf200 eq complete
-          edit VAR 'VP200'
-          task stats_a
-          task plot_a
-            trigger stats_a eq complete
-        endfamily
-        task antoweb
-          trigger ./vp200 eq complete
-      endfamily
-      family tercile
-        trigger ./anomaly eq complete or ./anomaly/antoweb eq aborted
-        family sf200
-          edit VAR 'SF200'
-          task stats_t
-          task plot_t
-            trigger stats_t eq complete
-        endfamily
-        family vp200
-          trigger ./sf200 eq complete
-          edit VAR 'VP200'
-          task stats_t
-          task plot_t
-            trigger stats_t eq complete
-        endfamily
-        task trtoweb
-          trigger ./vp200 eq complete
-      endfamily
-      family mjo
-        trigger ./tercile eq complete or ./tercile/trtoweb eq aborted
-        edit ERA40END '2002033000'
-        task chi200
-          edit FCLENGTH '768'
-        task mjotoweb
-          trigger ./chi200 eq complete
-      endfamily
-      task cleanup
-        trigger ./mjo eq complete
-    endfamily
-    family efi
-      trigger ../hc0:YMD + 14 le ../hc2:YMD
-      edit MAXDAY '15'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-      inlimit /emc_36r1/limits:efih
-      family op
-        family clim
-          trigger /emc_36r1/hc2/efi/op eq complete
-          family steps24
-            family 000_024
-              edit ACC '24'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 012_036
-              edit ACC '24'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '24'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 036_060
-              edit ACC '24'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '24'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 060_084
-              edit ACC '24'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '24'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 084_108
-              edit ACC '24'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '24'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 108_132
-              edit ACC '24'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '24'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-            endfamily
-          endfamily
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family nop
-        family clim
-          trigger /emc_36r1/hc2/efi/nop eq complete
-          family steps24
-            family 000_024
-              edit ACC '24'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 012_036
-              edit ACC '24'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '24'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 036_060
-              edit ACC '24'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '24'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 060_084
-              edit ACC '24'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '24'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 084_108
-              edit ACC '24'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '24'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 108_132
-              edit ACC '24'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '24'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '24'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '24'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '24'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '24'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 240_264
-              edit ACC '24'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '264'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 264_288
-              edit ACC '24'
-              edit EFI_STEP1 '264'
-              edit EFI_STEP2 '288'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 288_312
-              edit ACC '24'
-              edit EFI_STEP1 '288'
-              edit EFI_STEP2 '312'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 312_336
-              edit ACC '24'
-              edit EFI_STEP1 '312'
-              edit EFI_STEP2 '336'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 336_360
-              edit ACC '24'
-              edit EFI_STEP1 '336'
-              edit EFI_STEP2 '360'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-          endfamily
-          family steps06
-            family 006_006
-              edit ACC '0'
-              edit EFI_STEP1 '006'
-              edit EFI_STEP2 '006'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 012_012
-              edit ACC '0'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '012'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 018_018
-              edit ACC '0'
-              edit EFI_STEP1 '018'
-              edit EFI_STEP2 '018'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 024_024
-              edit ACC '0'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 030_030
-              edit ACC '0'
-              edit EFI_STEP1 '030'
-              edit EFI_STEP2 '030'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 036_036
-              edit ACC '0'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '036'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 042_042
-              edit ACC '0'
-              edit EFI_STEP1 '042'
-              edit EFI_STEP2 '042'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 048_048
-              edit ACC '0'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 054_054
-              edit ACC '0'
-              edit EFI_STEP1 '054'
-              edit EFI_STEP2 '054'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 060_060
-              edit ACC '0'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '060'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 066_066
-              edit ACC '0'
-              edit EFI_STEP1 '066'
-              edit EFI_STEP2 '066'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 072_072
-              edit ACC '0'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 078_078
-              edit ACC '0'
-              edit EFI_STEP1 '078'
-              edit EFI_STEP2 '078'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 084_084
-              edit ACC '0'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '084'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 090_090
-              edit ACC '0'
-              edit EFI_STEP1 '090'
-              edit EFI_STEP2 '090'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 096_096
-              edit ACC '0'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 102_102
-              edit ACC '0'
-              edit EFI_STEP1 '102'
-              edit EFI_STEP2 '102'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 108_108
-              edit ACC '0'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '108'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 114_114
-              edit ACC '0'
-              edit EFI_STEP1 '114'
-              edit EFI_STEP2 '114'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 120_120
-              edit ACC '0'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 126_126
-              edit ACC '0'
-              edit EFI_STEP1 '126'
-              edit EFI_STEP2 '126'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 132_132
-              edit ACC '0'
-              edit EFI_STEP1 '132'
-              edit EFI_STEP2 '132'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 138_138
-              edit ACC '0'
-              edit EFI_STEP1 '138'
-              edit EFI_STEP2 '138'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 144_144
-              edit ACC '0'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 150_150
-              edit ACC '0'
-              edit EFI_STEP1 '150'
-              edit EFI_STEP2 '150'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 156_156
-              edit ACC '0'
-              edit EFI_STEP1 '156'
-              edit EFI_STEP2 '156'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 162_162
-              edit ACC '0'
-              edit EFI_STEP1 '162'
-              edit EFI_STEP2 '162'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 168_168
-              edit ACC '0'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 174_174
-              edit ACC '0'
-              edit EFI_STEP1 '174'
-              edit EFI_STEP2 '174'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 180_180
-              edit ACC '0'
-              edit EFI_STEP1 '180'
-              edit EFI_STEP2 '180'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 186_186
-              edit ACC '0'
-              edit EFI_STEP1 '186'
-              edit EFI_STEP2 '186'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 192_192
-              edit ACC '0'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '192'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 198_198
-              edit ACC '0'
-              edit EFI_STEP1 '198'
-              edit EFI_STEP2 '198'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 204_204
-              edit ACC '0'
-              edit EFI_STEP1 '204'
-              edit EFI_STEP2 '204'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 210_210
-              edit ACC '0'
-              edit EFI_STEP1 '210'
-              edit EFI_STEP2 '210'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 216_216
-              edit ACC '0'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '216'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 222_222
-              edit ACC '0'
-              edit EFI_STEP1 '222'
-              edit EFI_STEP2 '222'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 228_228
-              edit ACC '0'
-              edit EFI_STEP1 '228'
-              edit EFI_STEP2 '228'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 234_234
-              edit ACC '0'
-              edit EFI_STEP1 '234'
-              edit EFI_STEP2 '234'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-            family 240_240
-              edit ACC '0'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prep_sort
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prep_sort
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prep_sort
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prep_sort
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prep_sort
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prep_sort
-              endfamily
-              family 10dd
-                edit RF_NAME '10dd'
-                task prep_sort
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prep_sort
-              endfamily
-              family tcc
-                edit RF_NAME 'tcc'
-                task prep_sort
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prep_sort
-              endfamily
-            endfamily
-          endfamily
-          family 120_168
-            trigger ./steps24 eq complete
-            edit ACC '48'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_240
-            trigger ./steps24 eq complete
-            edit ACC '72'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 000_168
-            trigger ./steps24 eq complete
-            edit ACC '168'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_336
-            trigger ./steps24 eq complete
-            edit ACC '96'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_336
-            trigger ./steps24 eq complete
-            edit ACC '168'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      task efi_clean
-      task sync_climate
-        trigger op eq complete and nop eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi'
-        time 20:45
-      family swarm
-        trigger ./sync_climate eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        inlimit /limits:linux_cluster
-        time 20:45
-        task sync_climate
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:35
-      trigger ref eq complete and logfilestore eq complete and legC eq complete and arch eq complete and msjobs eq complete and web eq complete and amma eq complete and efi eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-  family limits
-    limit mars 15
-    limit marsret 10
-    limit reservation 1
-    limit pftotal 72
-    limit pertic 26
-    limit modelepsA 13
-    limit modelepsB 52
-    limit pl 3
-    limit sfc 3
-    limit prodeps 9
-    limit prodwave 5
-    limit pdb 5
-    limit q2diss 5
-    limit w2diss 2
-    limit hind 60
-    limit pesh 60
-    limit efih 40
-    limit refc 10
-    limit webplots 9
-    limit postproc 40
-    limit dp 8
-    limit tc 7
-    limit efi 20
-    limit extra 20
-  endfamily
-  family main
-    repeat date YMD 20091003 20121212 1
-    edit LOGTASK 'main'
-    edit SUITE_START '20091124'
-    family make
-      task setup
-      task links
-        trigger setup eq complete
-        edit FSFAMILY 'an'
-        edit WSHOST 'bee01'
-      task datalinks
-        trigger setup eq complete and links eq complete
-      family det_bins
-        trigger links eq complete and datalinks eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-        task odbsql
-        task odbtools
-          trigger odbsql eq complete
-        task black
-          edit FSFAMILY 'an'
-        task b2otools
-          trigger odbtools eq complete
-          edit CALC_PSBIAS 'false'
-          edit INIPSBIAS 'false'
-          edit USE_PSBIAS 'false'
-        task ifs
-          trigger black eq complete and odbsql eq complete and odbtools eq complete and b2otools eq complete
-          edit FSFAMILY 'an'
-      endfamily
-      family bins
-        trigger links eq complete and datalinks eq complete and det_bins eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-        task cluster
-        task wamabs
-        task prepdata
-        task tc_ws
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task mc_tools
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-          edit THREADS '1'
-        task efi
-      endfamily
-      family prod
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/prod/make'
-        edit EMOS_DOMAIN 'g'
-        edit EMOS_TYPE 'fc'
-        edit EMOS_STREAM 'OPER'
-        task wparam
-          edit EMOS_TYPE 'wp'
-        task tf
-          edit EMOS_TYPE 'tf'
-        task sortreq
-        task bitmap
-        task clima
-        task disssch
-        task tools
-        task ef
-          edit EMOS_STREAM 'ENFO'
-          edit EMOS_TYPE 'ef'
-        task waef
-          edit EMOS_STREAM 'WAEF'
-          edit EMOS_TYPE 'ef'
-      endfamily
-      family mofc
-        trigger links eq complete
-        edit EPSCOUPLE '1'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-        edit RUNCOUPLE '1'
-        edit RUNVARFC '1'
-        task ocsetup
-        task libsoc
-          trigger ocsetup eq complete
-        task oclinks
-          trigger libsoc eq complete
-        task oasis
-          trigger ../det_bins/ifs eq complete
-        task prepdata
-          trigger oclinks eq complete
-        task ma_tools
-          trigger oclinks eq complete
-        family ocean
-          trigger ./ma_tools eq complete
-          task getoce
-          task getfr
-            trigger getoce eq complete
-          task ocean
-            trigger ../libsoc eq complete
-          task forcing
-            trigger ../libsoc eq complete and ocean eq complete
-          task getcouple
-            trigger getoce eq complete
-            edit RUNCOUPLE '1'
-            edit FCGROUP 'fc0'
-        endfamily
-        task tools
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task mofc_tools
-          edit EPSCOUPLE '1'
-        task lib_pp
-          edit EPSCOUPLE '1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task lib_verif
-          edit EPSCOUPLE '1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task lib_clim
-          edit EPSCOUPLE '1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit START_DAY '20091008'
-          edit END_DAY '20121213'
-          edit RUNHINDCAST '1'
-          inlimit /limits:linux_cluster
-      endfamily
-      family wconst
-        trigger bins/wamabs eq complete and links eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-        edit EPSNLEGS '3'
-        edit EPSFCLEV '62'
-        edit EPSWAMNSTPW '1'
-        edit EPSINISTEP_PREVIOUS '0'
-        edit EPSWAMRESOL 'global50'
-        edit EPSFCRES '639'
-        edit TSTEP '1200'
-        edit EPSWAMNFRE '30'
-        edit EPSWAMNANG '24'
-        edit CLASS 'od'
-        task wconstA
-          edit EPSWAMRESOL 'global50'
-          edit EPSFCRES '639'
-          edit EPSWAMNFRE '30'
-          edit EPSWAMNANG '24'
-        task wconstB
-          trigger wconstA eq complete
-          edit EPSWAMRESOL 'global50'
-          edit EPSINISTEP '216'
-          edit EPSFCRES '319'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-        task wconstC
-          trigger wconstB eq complete
-          edit EPSCOUPLE '1'
-          edit EPSWAMRESOL 'global300'
-          edit EPSFCRES '319'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-      endfamily
-      task makesvevo
-        trigger links eq complete
-      task makesvevo_00
-        trigger links eq complete
-        edit DELTA_DAY '1'
-        edit EMOS_BASE '00'
-      task inistage
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-      family make_sv
-        trigger det_bins/ifs eq complete and links eq complete and inistage eq complete
-        family m2_12
-          edit EMOS_BASE '12'
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family m2_00
-          edit EMOS_BASE '00'
-          edit DELTA_DAY '-1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family m1_12
-          edit EMOS_BASE '12'
-          edit DELTA_DAY '-1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family m1_00
-          edit EMOS_BASE '00'
-          edit DELTA_DAY '-0'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-      endfamily
-      family calib
-        trigger links eq complete and datalinks eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-        family onws
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-          task tubes
-            edit DELTA_DAY '0'
-          task tubes_00
-            edit EMOS_BASE '00'
-            edit DELTA_DAY '1'
-        endfamily
-        family onsc
-          edit QUEUE 'ns'
-          edit QUEUE_EPILOG 'ns'
-          edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-          edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-          inlimit /limits:c1b
-          task tubes
-            edit DELTA_DAY '0'
-          task tubes_00
-            edit EMOS_BASE '00'
-            edit DELTA_DAY '1'
-        endfamily
-      endfamily
-    endfamily
-    task inistage
-      trigger ./make eq complete
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-    task inistage_1
-      trigger ./inistage eq complete
-      edit DELTA_DAY '1'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
-    family ref
-      trigger /emc_36r1/main:YMD le /emc_36r1/main/ref:MC_STOP
-      edit MC_STOP '20121213'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-      limit mutex 1
-      family 12
-        edit EMOS_BASE '12'
-        task events
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-          edit HINDCAST '1'
-          edit ONLY_CF '0'
-          event noefi
-          event 240 
-          event 360 
-          event cpl
-          event 768 
-          event cf
-      endfamily
-      family 00
-        edit EMOS_BASE '00'
-        edit DELTA_DAY '1'
-        task events
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-          edit HINDCAST '1'
-          edit ONLY_CF '0'
-          event noefi
-          event 240 
-          event 360 
-          event cpl
-          event 768 
-          event cf
-      endfamily
-      task dummy
-        time 13:00
-      task cpl_nocpl
-      task wait
-        complete ( /emc_36r1/lag:YMD + 1) ge /emc_36r1/main:YMD
-        trigger ( /emc_36r1/lag:YMD + 1) ge /emc_36r1/main:YMD
-    endfamily
-    family 12
-      trigger ( ./make eq complete) and ( ./inistage eq complete)
-      edit EMOS_BASE '12'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-      family ref
-        trigger ../make eq complete and ( /emc_36r1/main:YMD le /e_36r1/main:YMD)
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit QUEUE 'emos-exp'
-        limit mutex 1
-        task an
-          trigger /e_36r1/main/12/an eq complete
-        task anfc
-          complete ( ( /e_36r1/main/12/an/surf_anal/slwet eq complete and ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar eq complete)) or /e_36r1/main/12/an eq complete)
-          trigger 0 eq 1
-        task model_active
-          trigger /e_36r1/main/12/fc/model eq active or /e_36r1/main/12/fc/model eq complete
-        task an_active
-          trigger /e_36r1/main/12/an/4dvar/uptraj_0 eq active or /e_36r1/main/12/an/4dvar/uptraj_0 eq complete
-        task model
-          trigger /e_36r1/main/12/fc/model eq complete
-        task dc
-          trigger /e_36r1/main/00dc/fc/model:step ge 12 or /e_36r1/main/00dc/fc/model eq complete
-        task obs
-          trigger /e_36r1/main/12/obs/get/get_stor eq complete
-      endfamily
-      family sv
-        trigger ./ref/dc eq complete and ./ref/an_active eq complete
-        edit EVOLVE 'no'
-        edit FASTEX 'no'
-        edit EPSTYPE 'sv'
-        edit FCMEM '2000'
-        edit FCSTACK '400'
-        edit FCMRFS '100'
-        edit FCLENGTH '48'
-        edit EPSSVTCSUB '1'
-        edit EPSSVOP '1'
-        edit NPES '16'
-        edit EPSSVTSTEP '900'
-        task getini
-          edit LINIENDA '0'
-          edit INIDATEENDA '0'
-          edit EPSCOUPLE '0'
-          edit N_PERT_AN '10'
-          edit EPSCOUPL_A '0'
-          edit EPSCOUPL_B '0'
-          edit EPSCOUPL_C '0'
-        task inidata_sv
-          trigger getini eq complete
-          edit THREADS '8'
-        task targets
-          late -s +00:03 -c +00:10
-          trigger ../ref/obs eq complete
-          edit EPSTCBB '1'
-          label da_info ""
-          label dcda_info ""
-          event sv
-        task svsh
-          trigger inidata_sv eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit THREADS '8'
-          edit USER_PRIORITY '73'
-        task svnh
-          trigger inidata_sv eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit THREADS '8'
-          edit USER_PRIORITY '74'
-        task subspace
-          trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-        task sv1
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '1'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-          edit USER_PRIORITY '72'
-        task sv2
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '2'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-          edit USER_PRIORITY '71'
-        task sv3
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '3'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task sv4
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '4'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task sv5
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '5'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task sv6
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '6'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task getsvevo
-          event ecfs
-        task getsvs
-          trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit EPSTROP '1'
-        task sv_value
-          trigger getsvs eq complete
-          inlimit /emc_36r1/main/ref:mutex
-        task svnhevo
-          trigger svnh eq complete and ../legA/fc eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit STACK '350'
-          edit HEMISPHERE 'n'
-          edit EVOLVE 'yes'
-          edit ANNPES '8'
-          edit CPUTIME '120000'
-        task svshevo
-          trigger svsh eq complete and ../legA/fc eq complete
-          edit NPES '24'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit STACK '450'
-          edit EVOLVE 'yes'
-          edit ANNPES '8'
-          edit CPUTIME '120000'
-        task clean
-          trigger ../legA/fc eq complete and svnhevo eq complete and svshevo eq complete
-        task dcopy
-          trigger clean eq complete
-          edit SMSFILES '/home/ma/emos/def/o/system'
-      endfamily
-      family legA
-        edit EPSLEG '1'
-        family fc
-          trigger /emc_36r1/main/12/ref/anfc eq complete
-          edit FCMEM '2240'
-          edit FCSTACK '700'
-          edit FCMRFS '0'
-          edit PRIORITY '72'
-          edit USER_PRIORITY '72'
-          edit N_PERT_AN '10'
-          edit SSTLEN '240'
-          edit EPSINISTEP_PREVIOUS '0'
-          edit EPSWAMNFRE '30'
-          edit EPSWAMNANG '24'
-          edit TSTEP '1200'
-          edit EPSFCRES '639'
-          edit RESOL '639'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit CPUTIME '1000'
-          edit MEM '960'
-          edit THREADS '8'
-          edit NPES '8'
-          edit EPSLEG '1'
-          edit PERSST 'true'
-          edit SSTINT '1'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata
-            trigger getini eq complete
-            edit THREADS '8'
-          task getae
-            event 1 
-          task rot
-            trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-            edit EPSTROP '1'
-          family pert_ic
-            trigger rot eq complete and inidata eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-            inlimit /emc_36r1/limits:pertic
-            family 00
-              task pertinic
-                edit MEMBER '0'
-            endfamily
-            family 01
-              task pertinic
-                edit MEMBER '1'
-            endfamily
-            family 02
-              task pertinic
-                edit MEMBER '2'
-            endfamily
-            family 03
-              task pertinic
-                edit MEMBER '3'
-            endfamily
-            family 04
-              task pertinic
-                edit MEMBER '4'
-            endfamily
-            family 05
-              task pertinic
-                edit MEMBER '5'
-            endfamily
-            family 06
-              task pertinic
-                edit MEMBER '6'
-            endfamily
-            family 07
-              task pertinic
-                edit MEMBER '7'
-            endfamily
-            family 08
-              task pertinic
-                edit MEMBER '8'
-            endfamily
-            family 09
-              task pertinic
-                edit MEMBER '9'
-            endfamily
-            family 10
-              task pertinic
-                edit MEMBER '10'
-            endfamily
-            family 11
-              task pertinic
-                edit MEMBER '11'
-            endfamily
-            family 12
-              task pertinic
-                edit MEMBER '12'
-            endfamily
-            family 13
-              task pertinic
-                edit MEMBER '13'
-            endfamily
-            family 14
-              task pertinic
-                edit MEMBER '14'
-            endfamily
-            family 15
-              task pertinic
-                edit MEMBER '15'
-            endfamily
-            family 16
-              task pertinic
-                edit MEMBER '16'
-            endfamily
-            family 17
-              task pertinic
-                edit MEMBER '17'
-            endfamily
-            family 18
-              task pertinic
-                edit MEMBER '18'
-            endfamily
-            family 19
-              task pertinic
-                edit MEMBER '19'
-            endfamily
-            family 20
-              task pertinic
-                edit MEMBER '20'
-            endfamily
-            family 21
-              task pertinic
-                edit MEMBER '21'
-            endfamily
-            family 22
-              task pertinic
-                edit MEMBER '22'
-            endfamily
-            family 23
-              task pertinic
-                edit MEMBER '23'
-            endfamily
-            family 24
-              task pertinic
-                edit MEMBER '24'
-            endfamily
-            family 25
-              task pertinic
-                edit MEMBER '25'
-            endfamily
-            family 26
-              task pertinic
-                edit MEMBER '26'
-            endfamily
-            family 27
-              task pertinic
-                edit MEMBER '27'
-            endfamily
-            family 28
-              task pertinic
-                edit MEMBER '28'
-            endfamily
-            family 29
-              task pertinic
-                edit MEMBER '29'
-            endfamily
-            family 30
-              task pertinic
-                edit MEMBER '30'
-            endfamily
-            family 31
-              task pertinic
-                edit MEMBER '31'
-            endfamily
-            family 32
-              task pertinic
-                edit MEMBER '32'
-            endfamily
-            family 33
-              task pertinic
-                edit MEMBER '33'
-            endfamily
-            family 34
-              task pertinic
-                edit MEMBER '34'
-            endfamily
-            family 35
-              task pertinic
-                edit MEMBER '35'
-            endfamily
-            family 36
-              task pertinic
-                edit MEMBER '36'
-            endfamily
-            family 37
-              task pertinic
-                edit MEMBER '37'
-            endfamily
-            family 38
-              task pertinic
-                edit MEMBER '38'
-            endfamily
-            family 39
-              task pertinic
-                edit MEMBER '39'
-            endfamily
-            family 40
-              task pertinic
-                edit MEMBER '40'
-            endfamily
-            family 41
-              task pertinic
-                edit MEMBER '41'
-            endfamily
-            family 42
-              task pertinic
-                edit MEMBER '42'
-            endfamily
-            family 43
-              task pertinic
-                edit MEMBER '43'
-            endfamily
-            family 44
-              task pertinic
-                edit MEMBER '44'
-            endfamily
-            family 45
-              task pertinic
-                edit MEMBER '45'
-            endfamily
-            family 46
-              task pertinic
-                edit MEMBER '46'
-            endfamily
-            family 47
-              task pertinic
-                edit MEMBER '47'
-            endfamily
-            family 48
-              task pertinic
-                edit MEMBER '48'
-            endfamily
-            family 49
-              task pertinic
-                edit MEMBER '49'
-            endfamily
-            family 50
-              task pertinic
-                edit MEMBER '50'
-            endfamily
-          endfamily
-          task cp_pert
-            trigger pert_ic eq complete
-            event 1 
-          task wavini
-            trigger /emc_36r1/main/12/ref/an eq complete
-            edit FSFAMILY 'mc'
-          family cv
-            trigger ./pert_ic/00 eq complete and ./inidata eq complete and ./wavini eq complete and /emc_36r1/main/12/ref/model_active eq complete
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit EPSFCRES '639'
-            edit TSTEP '1200'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit CLASS 'od'
-            edit PERSST 'no'
-            edit EPSTYPE 'cv'
-            edit EMOS_TYPE 'cv'
-            edit EPSNLEGS '1'
-            edit EPSLEG '1'
-            edit EPSINISTEP '360'
-            edit FCLENGTH '360'
-            edit USER_PRIORITY '73'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            inlimit /emc_36r1/limits:pftotal
-            family control_1
-              edit MEMBER '1'
-              edit EPSMEMBER '1'
-              edit SUBFSFAMILY '/cv001'
-              task getiniLeg
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit FCNPES '32'
-                edit THREADS '4'
-                meter step -1 360 360
-              task derived_param
-                trigger modeleps eq complete
-                edit STEPS '0:144:3 144:360:6'
-            endfamily
-            family control_2
-              edit MEMBER '2'
-              edit EPSMEMBER '2'
-              edit SUBFSFAMILY '/cv002'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              task getiniLeg
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task intHtoL
-                trigger getiniLeg eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '1200'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                meter step -1 360 360
-              task derived_param
-                trigger modeleps eq complete
-                edit STEPS '0:144:3 144:360:6'
-            endfamily
-          endfamily
-          task wavfcdata
-            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-            edit EPSCOUPLE '1'
-          task getpersSST
-            trigger ./inidata eq complete
-            edit EPSCOUPLE '1'
-            edit EPS_INI_STREAM 'DA'
-            edit EPSFCRES '639'
-          family pf
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete and ../../ref/model_active eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTYPE 'pf'
-            edit EMOS_TYPE 'pf'
-            edit USER_PRIORITY '72'
-            edit PRIORITY '72'
-            edit FCNPES '32'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit EPSFCRES '639'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit EPSINISTEP '216'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '1'
-            edit CLASS 'od'
-            inlimit /emc_36r1/limits:pftotal
-            meter step -1 240 240
-            family 01
-              edit EPSMEMBER '1'
-              edit MEMBER '1'
-              edit SUBFSFAMILY '/pf001'
-              task getiniLeg
-                trigger ../../pert_ic/01/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 02
-              edit EPSMEMBER '2'
-              edit MEMBER '2'
-              edit SUBFSFAMILY '/pf002'
-              task getiniLeg
-                trigger ../../pert_ic/02/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 03
-              edit EPSMEMBER '3'
-              edit MEMBER '3'
-              edit SUBFSFAMILY '/pf003'
-              task getiniLeg
-                trigger ../../pert_ic/03/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 04
-              edit EPSMEMBER '4'
-              edit MEMBER '4'
-              edit SUBFSFAMILY '/pf004'
-              task getiniLeg
-                trigger ../../pert_ic/04/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 05
-              edit EPSMEMBER '5'
-              edit MEMBER '5'
-              edit SUBFSFAMILY '/pf005'
-              task getiniLeg
-                trigger ../../pert_ic/05/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 06
-              edit EPSMEMBER '6'
-              edit MEMBER '6'
-              edit SUBFSFAMILY '/pf006'
-              task getiniLeg
-                trigger ../../pert_ic/06/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 07
-              edit EPSMEMBER '7'
-              edit MEMBER '7'
-              edit SUBFSFAMILY '/pf007'
-              task getiniLeg
-                trigger ../../pert_ic/07/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 08
-              edit EPSMEMBER '8'
-              edit MEMBER '8'
-              edit SUBFSFAMILY '/pf008'
-              task getiniLeg
-                trigger ../../pert_ic/08/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 09
-              edit EPSMEMBER '9'
-              edit MEMBER '9'
-              edit SUBFSFAMILY '/pf009'
-              task getiniLeg
-                trigger ../../pert_ic/09/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 10
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              edit SUBFSFAMILY '/pf010'
-              task getiniLeg
-                trigger ../../pert_ic/10/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 11
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              edit SUBFSFAMILY '/pf011'
-              task getiniLeg
-                trigger ../../pert_ic/11/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 12
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              edit SUBFSFAMILY '/pf012'
-              task getiniLeg
-                trigger ../../pert_ic/12/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 13
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              edit SUBFSFAMILY '/pf013'
-              task getiniLeg
-                trigger ../../pert_ic/13/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 14
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              edit SUBFSFAMILY '/pf014'
-              task getiniLeg
-                trigger ../../pert_ic/14/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 15
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              edit SUBFSFAMILY '/pf015'
-              task getiniLeg
-                trigger ../../pert_ic/15/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 16
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              edit SUBFSFAMILY '/pf016'
-              task getiniLeg
-                trigger ../../pert_ic/16/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 17
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              edit SUBFSFAMILY '/pf017'
-              task getiniLeg
-                trigger ../../pert_ic/17/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 18
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              edit SUBFSFAMILY '/pf018'
-              task getiniLeg
-                trigger ../../pert_ic/18/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 19
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              edit SUBFSFAMILY '/pf019'
-              task getiniLeg
-                trigger ../../pert_ic/19/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 20
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              edit SUBFSFAMILY '/pf020'
-              task getiniLeg
-                trigger ../../pert_ic/20/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 21
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              edit SUBFSFAMILY '/pf021'
-              task getiniLeg
-                trigger ../../pert_ic/21/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 22
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              edit SUBFSFAMILY '/pf022'
-              task getiniLeg
-                trigger ../../pert_ic/22/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 23
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              edit SUBFSFAMILY '/pf023'
-              task getiniLeg
-                trigger ../../pert_ic/23/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 24
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              edit SUBFSFAMILY '/pf024'
-              task getiniLeg
-                trigger ../../pert_ic/24/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 25
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              edit SUBFSFAMILY '/pf025'
-              task getiniLeg
-                trigger ../../pert_ic/25/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 26
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              edit SUBFSFAMILY '/pf026'
-              task getiniLeg
-                trigger ../../pert_ic/26/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 27
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              edit SUBFSFAMILY '/pf027'
-              task getiniLeg
-                trigger ../../pert_ic/27/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 28
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              edit SUBFSFAMILY '/pf028'
-              task getiniLeg
-                trigger ../../pert_ic/28/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 29
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              edit SUBFSFAMILY '/pf029'
-              task getiniLeg
-                trigger ../../pert_ic/29/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 30
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              edit SUBFSFAMILY '/pf030'
-              task getiniLeg
-                trigger ../../pert_ic/30/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 31
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              edit SUBFSFAMILY '/pf031'
-              task getiniLeg
-                trigger ../../pert_ic/31/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 32
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              edit SUBFSFAMILY '/pf032'
-              task getiniLeg
-                trigger ../../pert_ic/32/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 33
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              edit SUBFSFAMILY '/pf033'
-              task getiniLeg
-                trigger ../../pert_ic/33/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 34
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              edit SUBFSFAMILY '/pf034'
-              task getiniLeg
-                trigger ../../pert_ic/34/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 35
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              edit SUBFSFAMILY '/pf035'
-              task getiniLeg
-                trigger ../../pert_ic/35/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 36
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              edit SUBFSFAMILY '/pf036'
-              task getiniLeg
-                trigger ../../pert_ic/36/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 37
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              edit SUBFSFAMILY '/pf037'
-              task getiniLeg
-                trigger ../../pert_ic/37/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 38
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              edit SUBFSFAMILY '/pf038'
-              task getiniLeg
-                trigger ../../pert_ic/38/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 39
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              edit SUBFSFAMILY '/pf039'
-              task getiniLeg
-                trigger ../../pert_ic/39/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 40
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              edit SUBFSFAMILY '/pf040'
-              task getiniLeg
-                trigger ../../pert_ic/40/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 41
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              edit SUBFSFAMILY '/pf041'
-              task getiniLeg
-                trigger ../../pert_ic/41/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 42
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              edit SUBFSFAMILY '/pf042'
-              task getiniLeg
-                trigger ../../pert_ic/42/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 43
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              edit SUBFSFAMILY '/pf043'
-              task getiniLeg
-                trigger ../../pert_ic/43/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 44
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              edit SUBFSFAMILY '/pf044'
-              task getiniLeg
-                trigger ../../pert_ic/44/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 45
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              edit SUBFSFAMILY '/pf045'
-              task getiniLeg
-                trigger ../../pert_ic/45/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 46
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              edit SUBFSFAMILY '/pf046'
-              task getiniLeg
-                trigger ../../pert_ic/46/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 47
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              edit SUBFSFAMILY '/pf047'
-              task getiniLeg
-                trigger ../../pert_ic/47/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 48
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              edit SUBFSFAMILY '/pf048'
-              task getiniLeg
-                trigger ../../pert_ic/48/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 49
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              edit SUBFSFAMILY '/pf049'
-              task getiniLeg
-                trigger ../../pert_ic/49/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 50
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              edit SUBFSFAMILY '/pf050'
-              task getiniLeg
-                trigger ../../pert_ic/50/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family cf
-            trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete and /emc_36r1/main/12/ref/model_active eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit MEMBER '0'
-            edit EPSMEMBER '0'
-            edit SUBFSFAMILY '/cf000'
-            edit EPSTYPE 'cf'
-            edit EMOS_TYPE 'cf'
-            edit USER_PRIORITY '73'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit EPSFCRES '639'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit EPSINISTEP '216'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '1'
-            edit CLASS 'od'
-            task getiniLeg
-              trigger ../inidata eq complete and ../wavini eq complete
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task modeleps
-              trigger getiniLeg eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '1'
-              edit EPSFCRES '639'
-              edit EPSINISTEP '216'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit CLASS 'od'
-              edit FCNPES '32'
-              edit THREADS '4'
-              meter step -1 240 240
-          endfamily
-          family reservation1
-            trigger ./pf/01/modeleps eq active or ./pf/01/modeleps eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reserve_cpu
-              late -s +00:02 -c +00:02
-              edit RESERVED_CPUS '10880'
-              edit RESERVE_FOR '48'
-              label info ""
-            task rm_res
-              late -s +00:02 -c +00:02
-              trigger ./reserve_cpu eq complete
-              edit RESERVATION_LABEL 'emos12'
-              label info ""
-          endfamily
-          family reservation2
-            trigger ( ./pf/46/modeleps eq active or ./pf/46/modeleps eq complete) and ( ./pf/47/modeleps eq active or ./pf/47/modeleps eq complete) and ( ./pf/48/modeleps eq active or ./pf/48/modeleps eq complete) and ( ./pf/49/modeleps eq active or ./pf/49/modeleps eq complete) and ( ./pf/50/modeleps eq active or ./pf/50/modeleps eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reset_class
-              late -s +00:02 -c +00:02
-              edit RESERVATION_DEFINITION 'default'
-              label info ""
-            task ms_cpu
-              late -s +00:02 -c +00:02
-              edit MS_CPUS '12800'
-              label info ""
-            task reserve_cpu
-              late -s +00:02 -c +00:02
-              edit RESERVED_CPUS '6400'
-              edit RESERVE_FOR '40'
-              label info ""
-          endfamily
-          family reservation3
-            trigger ( ./pf eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reserve_cpu
-              late -s +00:02 -c +00:02
-              edit RESERVED_CPUS '1024'
-              edit RESERVE_FOR '20'
-              label info ""
-          endfamily
-        endfamily
-        family fax
-          trigger /emc_36r1/main/12/ref/an eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-          task ena4
-            trigger ../postproc/clusters eq complete and ../postproc/ensms eq complete
-            edit ANALYSIS 'NO'
-          task plume
-            trigger ../postproc/prob eq complete and /emc_36r1/main/12/ref/model eq complete
-            edit ANALYSIS 'YES'
-          task fax
-            trigger plume eq complete and ena4 eq complete
-            edit SMSTRIES '1'
-          task manfax
-            trigger plume eq complete and ena4 eq complete
-            edit SMSTRIES '1'
-            edit COUNTRY ''
-          task faxcheck
-            trigger fax eq complete
-          task faxcheck2
-            trigger fax eq complete
-            time 08:00
-        endfamily
-        family postproc
-          trigger ./fc ne queued
-          edit STEPS '24/240/12/24 168/168/12/48 240/240/12/72 240/240/12/120'
-          inlimit /emc_36r1/limits:postproc
-          family prepare
-            complete /emc_36r1/main/ref/12/events:cf
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            family all
-              complete ../../fc eq complete and ./query eq active
-              trigger ../../fc eq complete and ( ./query eq queued or ./query eq complete)
-              edit KIND 'all'
-              edit STEP '-1'
-              family t850
-                edit PARAM 'T'
-                edit LEVEL '850'
-                task pp_prep
-              endfamily
-              family t500
-                edit PARAM 'T'
-                edit LEVEL '500'
-                task pp_prep
-              endfamily
-              family z1000
-                edit PARAM 'Z'
-                edit LEVEL '1000'
-                task pp_prep
-              endfamily
-              family z500
-                edit PARAM 'Z'
-                edit LEVEL '500'
-                task pp_prep
-              endfamily
-            endfamily
-            family query
-              complete ../../fc eq complete and ../../fc/pf:step le 0
-              trigger ( ( ../../fc/pf:step ge 0) and ( ../../fc/cf/modeleps:step ge 0)) or ( ../../fc/pf eq complete and ../../fc/cf eq complete)
-              edit KIND 'query'
-              family t850
-                edit PARAM 'T'
-                edit LEVEL '850'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-              family t500
-                edit PARAM 'T'
-                edit LEVEL '500'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-              family z1000
-                edit PARAM 'Z'
-                edit LEVEL '1000'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-              family z500
-                edit PARAM 'Z'
-                edit LEVEL '500'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-            endfamily
-          endfamily
-          family ensms
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger ( ../fc eq complete) and ( ./prepare eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            family limits
-              limit fdb 1
-              limit gen 8
-            endfamily
-            task ensms
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit ENS_MARS 'false'
-              event stage
-            family 048
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '003'
-              edit STEP2 '048'
-              edit BY '3'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 096
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '051'
-              edit STEP2 '096'
-              edit BY '3'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 144
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '099'
-              edit STEP2 '144'
-              edit BY '3'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 240
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '150'
-              edit STEP2 '240'
-              edit BY '6'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-          endfamily
-          family prob
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger /emc_36r1/main/12/legA/fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            edit STEP1 '12'
-            edit STEP2 '240'
-            edit BY '12'
-            family 24
-              edit STEP1 '24'
-              edit STEP2 '240'
-              edit BY '24'
-              family t850
-                trigger ../../prepare/all/t850 eq complete
-                family 120_240
-                  edit STEPS '120 240'
-                  task t850
-                    event 1 
-                endfamily
-                family 120_168
-                  trigger ./120_240/t850:1 or ./120_240 eq complete
-                  edit STEPS '120 168'
-                  task t850
-                    event 1 
-                endfamily
-                family 168_240
-                  trigger ./120_240/t850:1 or ./120_240 eq complete
-                  edit STEPS '168 240'
-                  task t850
-                    event 1 
-                endfamily
-              endfamily
-              task rain
-              task ff
-            endfamily
-            family 12
-              edit STEP1 '12'
-              edit STEP2 '228'
-              edit BY '24'
-              task t850
-                trigger ../../prepare/all/t850 eq complete
-              task rain
-              task ff
-            endfamily
-            task 2t
-            task swh
-            task mwp
-            task 10fg
-              trigger ../dp eq complete
-            task prob_fdb
-              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
-          endfamily
-          family tc
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger ../fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
-            edit TCINIEXPVER '0046'
-            family obsdata
-              trigger ( /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/legA/fc/cf eq complete)
-              task retrieve
-                late -c +00:10
-                trigger ( /emc_36r1/main/12/sv/targets eq complete or /emc_36r1/main/12/sv/targets:sv)
-                label info ""
-                event notc
-              task obs
-                trigger retrieve eq complete
-            endfamily
-            family stage
-              trigger ( /emc_36r1/main/12/legA/fc eq complete)
-              task an
-              task fc
-              task pf
-              task cf
-            endfamily
-            family tracking
-              trigger obsdata/obs eq complete and stage eq complete
-              inlimit /emc_36r1/limits:tc
-              family 1
-                edit MEMBER '1'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 2
-                edit MEMBER '2'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 3
-                edit MEMBER '3'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 4
-                edit MEMBER '4'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 5
-                edit MEMBER '5'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 6
-                edit MEMBER '6'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 7
-                edit MEMBER '7'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 8
-                edit MEMBER '8'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 9
-                edit MEMBER '9'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 10
-                edit MEMBER '10'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 11
-                edit MEMBER '11'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 12
-                edit MEMBER '12'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 13
-                edit MEMBER '13'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 14
-                edit MEMBER '14'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 15
-                edit MEMBER '15'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 16
-                edit MEMBER '16'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 17
-                edit MEMBER '17'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 18
-                edit MEMBER '18'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 19
-                edit MEMBER '19'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 20
-                edit MEMBER '20'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 21
-                edit MEMBER '21'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 22
-                edit MEMBER '22'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 23
-                edit MEMBER '23'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 24
-                edit MEMBER '24'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 25
-                edit MEMBER '25'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 26
-                edit MEMBER '26'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 27
-                edit MEMBER '27'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 28
-                edit MEMBER '28'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 29
-                edit MEMBER '29'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 30
-                edit MEMBER '30'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 31
-                edit MEMBER '31'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 32
-                edit MEMBER '32'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 33
-                edit MEMBER '33'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 34
-                edit MEMBER '34'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 35
-                edit MEMBER '35'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 36
-                edit MEMBER '36'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 37
-                edit MEMBER '37'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 38
-                edit MEMBER '38'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 39
-                edit MEMBER '39'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 40
-                edit MEMBER '40'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 41
-                edit MEMBER '41'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 42
-                edit MEMBER '42'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 43
-                edit MEMBER '43'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 44
-                edit MEMBER '44'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 45
-                edit MEMBER '45'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 46
-                edit MEMBER '46'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 47
-                edit MEMBER '47'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 48
-                edit MEMBER '48'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 49
-                edit MEMBER '49'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 50
-                edit MEMBER '50'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family cf
-                edit MEMBER '51'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family oper
-                edit MEMBER '52'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-            endfamily
-            family post_process
-              task to_bufr
-                trigger ../tracking eq complete
-            endfamily
-          endfamily
-          family calibrate
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger /emc_36r1/main/12/ref/an eq complete and ../fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
-            family onsc
-              edit QUEUE 'ns'
-              edit QUEUE_EPILOG 'ns'
-              edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-              edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-              inlimit /limits:c1b
-              task feedupcal
-              task upcal
-                trigger feedupcal eq complete
-                edit Z500_EXPVER '0001'
-                edit METVIEW 'metview'
-              task revertupcal
-            endfamily
-          endfamily
-          family clusters
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger ./calibrate/onsc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/clusters'
-            edit USER_PRIORITY '81'
-            edit QUEUE 'ns'
-            edit QUEUE_EPILOG 'ns'
-            edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-            edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-            inlimit /limits:c1b
-            task cthresh
-            task cluster
-              trigger cthresh eq complete and /emc_36r1/main/12/ref/model eq complete
-              edit USER_PRIORITY '76'
-            task tubcon
-              trigger /emc_36r1/main/12/ref/model eq complete
-            task tubgen
-              late -c +00:20
-              trigger tubcon eq complete
-          endfamily
-          family efi
-            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
-            trigger /emc_36r1/main/12/legA/postproc/dp eq complete
-            edit HC_VERSION '0046'
-            edit HC_EXPVER '0046'
-            edit REF_VERSION '0046'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            edit NC_DAYS '31'
-            edit EPSLEG '1'
-            inlimit /emc_36r1/limits:efi
-            task stage
-              edit NC_DAYS '31'
-            family 000_120
-              trigger ./stage eq complete
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 024_144
-              trigger ./stage eq complete
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 000_240
-              trigger ./stage eq complete
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 012_036
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 036_060
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 060_084
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 084_108
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 108_132
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-          endfamily
-          task efi2fdb
-            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
-            trigger ./efi eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            inlimit /emc_36r1/main/ref:mutex
-            event none
-          family dp
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '0:144:3 144:240:6'
-            inlimit /emc_36r1/limits:dp
-            family cf
-              trigger ../../fc/cf eq complete
-              edit EMOS_TYPE 'cf'
-              task derived_param
-                edit MEMBER 'off'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/12/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                trigger ../../../fc/pf/01 eq complete
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task derived_param
-              endfamily
-              family 02
-                trigger ../../../fc/pf/02 eq complete
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task derived_param
-              endfamily
-              family 03
-                trigger ../../../fc/pf/03 eq complete
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task derived_param
-              endfamily
-              family 04
-                trigger ../../../fc/pf/04 eq complete
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task derived_param
-              endfamily
-              family 05
-                trigger ../../../fc/pf/05 eq complete
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task derived_param
-              endfamily
-              family 06
-                trigger ../../../fc/pf/06 eq complete
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task derived_param
-              endfamily
-              family 07
-                trigger ../../../fc/pf/07 eq complete
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task derived_param
-              endfamily
-              family 08
-                trigger ../../../fc/pf/08 eq complete
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task derived_param
-              endfamily
-              family 09
-                trigger ../../../fc/pf/09 eq complete
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task derived_param
-              endfamily
-              family 10
-                trigger ../../../fc/pf/10 eq complete
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task derived_param
-              endfamily
-              family 11
-                trigger ../../../fc/pf/11 eq complete
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task derived_param
-              endfamily
-              family 12
-                trigger ../../../fc/pf/12 eq complete
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task derived_param
-              endfamily
-              family 13
-                trigger ../../../fc/pf/13 eq complete
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task derived_param
-              endfamily
-              family 14
-                trigger ../../../fc/pf/14 eq complete
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task derived_param
-              endfamily
-              family 15
-                trigger ../../../fc/pf/15 eq complete
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task derived_param
-              endfamily
-              family 16
-                trigger ../../../fc/pf/16 eq complete
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task derived_param
-              endfamily
-              family 17
-                trigger ../../../fc/pf/17 eq complete
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task derived_param
-              endfamily
-              family 18
-                trigger ../../../fc/pf/18 eq complete
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task derived_param
-              endfamily
-              family 19
-                trigger ../../../fc/pf/19 eq complete
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task derived_param
-              endfamily
-              family 20
-                trigger ../../../fc/pf/20 eq complete
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task derived_param
-              endfamily
-              family 21
-                trigger ../../../fc/pf/21 eq complete
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task derived_param
-              endfamily
-              family 22
-                trigger ../../../fc/pf/22 eq complete
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task derived_param
-              endfamily
-              family 23
-                trigger ../../../fc/pf/23 eq complete
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task derived_param
-              endfamily
-              family 24
-                trigger ../../../fc/pf/24 eq complete
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task derived_param
-              endfamily
-              family 25
-                trigger ../../../fc/pf/25 eq complete
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task derived_param
-              endfamily
-              family 26
-                trigger ../../../fc/pf/26 eq complete
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task derived_param
-              endfamily
-              family 27
-                trigger ../../../fc/pf/27 eq complete
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task derived_param
-              endfamily
-              family 28
-                trigger ../../../fc/pf/28 eq complete
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task derived_param
-              endfamily
-              family 29
-                trigger ../../../fc/pf/29 eq complete
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task derived_param
-              endfamily
-              family 30
-                trigger ../../../fc/pf/30 eq complete
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task derived_param
-              endfamily
-              family 31
-                trigger ../../../fc/pf/31 eq complete
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task derived_param
-              endfamily
-              family 32
-                trigger ../../../fc/pf/32 eq complete
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task derived_param
-              endfamily
-              family 33
-                trigger ../../../fc/pf/33 eq complete
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task derived_param
-              endfamily
-              family 34
-                trigger ../../../fc/pf/34 eq complete
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task derived_param
-              endfamily
-              family 35
-                trigger ../../../fc/pf/35 eq complete
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task derived_param
-              endfamily
-              family 36
-                trigger ../../../fc/pf/36 eq complete
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task derived_param
-              endfamily
-              family 37
-                trigger ../../../fc/pf/37 eq complete
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task derived_param
-              endfamily
-              family 38
-                trigger ../../../fc/pf/38 eq complete
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task derived_param
-              endfamily
-              family 39
-                trigger ../../../fc/pf/39 eq complete
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task derived_param
-              endfamily
-              family 40
-                trigger ../../../fc/pf/40 eq complete
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task derived_param
-              endfamily
-              family 41
-                trigger ../../../fc/pf/41 eq complete
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task derived_param
-              endfamily
-              family 42
-                trigger ../../../fc/pf/42 eq complete
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task derived_param
-              endfamily
-              family 43
-                trigger ../../../fc/pf/43 eq complete
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task derived_param
-              endfamily
-              family 44
-                trigger ../../../fc/pf/44 eq complete
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task derived_param
-              endfamily
-              family 45
-                trigger ../../../fc/pf/45 eq complete
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task derived_param
-              endfamily
-              family 46
-                trigger ../../../fc/pf/46 eq complete
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task derived_param
-              endfamily
-              family 47
-                trigger ../../../fc/pf/47 eq complete
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task derived_param
-              endfamily
-              family 48
-                trigger ../../../fc/pf/48 eq complete
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task derived_param
-              endfamily
-              family 49
-                trigger ../../../fc/pf/49 eq complete
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task derived_param
-              endfamily
-              family 50
-                trigger ../../../fc/pf/50 eq complete
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task derived_param
-              endfamily
-            endfamily
-          endfamily
-          family extra
-            trigger ./dp eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '0:144:3 144:240:6'
-            inlimit /emc_36r1/limits:extra
-            family cf
-              edit EMOS_TYPE 'cf'
-              task extrafields
-                edit EPSFCRES '639'
-                edit FCLENGTH '240'
-                edit FCLENGTH0 '0'
-                edit RUNVARFC '1'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/12/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 05
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 06
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 07
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 08
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 09
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 10
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 11
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 12
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 13
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 14
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 15
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 16
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 17
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 18
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 19
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 20
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 21
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 22
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 23
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 24
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 25
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 26
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 27
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 28
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 29
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 30
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 31
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 32
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 33
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 34
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 35
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 36
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 37
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 38
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 39
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 40
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 41
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 42
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 43
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 44
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 45
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 46
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 47
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 48
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 49
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 50
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family prod
-          edit MEM '3000'
-          edit ACCOUNT 'oeenfopg'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'cp'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '90'
-          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
-          edit SMSURL 'sub=fixed/'
-          inlimit /limits:prod
-          family eps
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            inlimit /emc_36r1/limits:prodeps
-            family 0000
-              edit EMOS_TIME_STEP_H '0000'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0003
-              edit EMOS_TIME_STEP_H '0003'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0006
-              edit EMOS_TIME_STEP_H '0006'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0009
-              edit EMOS_TIME_STEP_H '0009'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0012
-              edit EMOS_TIME_STEP_H '0012'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0015
-              edit EMOS_TIME_STEP_H '0015'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0018
-              edit EMOS_TIME_STEP_H '0018'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0021
-              edit EMOS_TIME_STEP_H '0021'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0024
-              edit EMOS_TIME_STEP_H '0024'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0027
-              edit EMOS_TIME_STEP_H '0027'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0030
-              edit EMOS_TIME_STEP_H '0030'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0033
-              edit EMOS_TIME_STEP_H '0033'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0036
-              edit EMOS_TIME_STEP_H '0036'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0039
-              edit EMOS_TIME_STEP_H '0039'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0042
-              edit EMOS_TIME_STEP_H '0042'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0045
-              edit EMOS_TIME_STEP_H '0045'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0048
-              edit EMOS_TIME_STEP_H '0048'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0051
-              edit EMOS_TIME_STEP_H '0051'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0054
-              edit EMOS_TIME_STEP_H '0054'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0057
-              edit EMOS_TIME_STEP_H '0057'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0060
-              edit EMOS_TIME_STEP_H '0060'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0063
-              edit EMOS_TIME_STEP_H '0063'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0066
-              edit EMOS_TIME_STEP_H '0066'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0069
-              edit EMOS_TIME_STEP_H '0069'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0072
-              edit EMOS_TIME_STEP_H '0072'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0075
-              edit EMOS_TIME_STEP_H '0075'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0078
-              edit EMOS_TIME_STEP_H '0078'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0081
-              edit EMOS_TIME_STEP_H '0081'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0084
-              edit EMOS_TIME_STEP_H '0084'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0087
-              edit EMOS_TIME_STEP_H '0087'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0090
-              edit EMOS_TIME_STEP_H '0090'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0093
-              edit EMOS_TIME_STEP_H '0093'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0096
-              edit EMOS_TIME_STEP_H '0096'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0099
-              edit EMOS_TIME_STEP_H '0099'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0102
-              edit EMOS_TIME_STEP_H '0102'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0105
-              edit EMOS_TIME_STEP_H '0105'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0108
-              edit EMOS_TIME_STEP_H '0108'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0111
-              edit EMOS_TIME_STEP_H '0111'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0114
-              edit EMOS_TIME_STEP_H '0114'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0117
-              edit EMOS_TIME_STEP_H '0117'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0120
-              edit EMOS_TIME_STEP_H '0120'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0123
-              edit EMOS_TIME_STEP_H '0123'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0126
-              edit EMOS_TIME_STEP_H '0126'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0129
-              edit EMOS_TIME_STEP_H '0129'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0132
-              edit EMOS_TIME_STEP_H '0132'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0135
-              edit EMOS_TIME_STEP_H '0135'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0138
-              edit EMOS_TIME_STEP_H '0138'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0141
-              edit EMOS_TIME_STEP_H '0141'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0144
-              edit EMOS_TIME_STEP_H '0144'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0150
-              edit EMOS_TIME_STEP_H '0150'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0156
-              edit EMOS_TIME_STEP_H '0156'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0162
-              edit EMOS_TIME_STEP_H '0162'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0168
-              edit EMOS_TIME_STEP_H '0168'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0174
-              edit EMOS_TIME_STEP_H '0174'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0180
-              edit EMOS_TIME_STEP_H '0180'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0186
-              edit EMOS_TIME_STEP_H '0186'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0192
-              edit EMOS_TIME_STEP_H '0192'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0198
-              edit EMOS_TIME_STEP_H '0198'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0204
-              edit EMOS_TIME_STEP_H '0204'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0210
-              edit EMOS_TIME_STEP_H '0210'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0216
-              edit EMOS_TIME_STEP_H '0216'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0222
-              edit EMOS_TIME_STEP_H '0222'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0228
-              edit EMOS_TIME_STEP_H '0228'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0234
-              edit EMOS_TIME_STEP_H '0234'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0240
-              edit EMOS_TIME_STEP_H '0240'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-          endfamily
-          family wave
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            edit PGNPES '2'
-            edit URL 'GWAEF/12'
-            inlimit /emc_36r1/limits:prodwave
-            family 0000
-              edit EMOS_TIME_STEP_H '0000'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0003
-              edit EMOS_TIME_STEP_H '0003'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0006
-              edit EMOS_TIME_STEP_H '0006'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0009
-              edit EMOS_TIME_STEP_H '0009'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0012
-              edit EMOS_TIME_STEP_H '0012'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0015
-              edit EMOS_TIME_STEP_H '0015'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0018
-              edit EMOS_TIME_STEP_H '0018'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0021
-              edit EMOS_TIME_STEP_H '0021'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0024
-              edit EMOS_TIME_STEP_H '0024'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0027
-              edit EMOS_TIME_STEP_H '0027'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0030
-              edit EMOS_TIME_STEP_H '0030'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0033
-              edit EMOS_TIME_STEP_H '0033'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0036
-              edit EMOS_TIME_STEP_H '0036'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0039
-              edit EMOS_TIME_STEP_H '0039'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0042
-              edit EMOS_TIME_STEP_H '0042'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0045
-              edit EMOS_TIME_STEP_H '0045'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0048
-              edit EMOS_TIME_STEP_H '0048'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0051
-              edit EMOS_TIME_STEP_H '0051'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0054
-              edit EMOS_TIME_STEP_H '0054'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0057
-              edit EMOS_TIME_STEP_H '0057'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0060
-              edit EMOS_TIME_STEP_H '0060'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0063
-              edit EMOS_TIME_STEP_H '0063'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0066
-              edit EMOS_TIME_STEP_H '0066'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0069
-              edit EMOS_TIME_STEP_H '0069'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0072
-              edit EMOS_TIME_STEP_H '0072'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0075
-              edit EMOS_TIME_STEP_H '0075'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0078
-              edit EMOS_TIME_STEP_H '0078'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0081
-              edit EMOS_TIME_STEP_H '0081'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0084
-              edit EMOS_TIME_STEP_H '0084'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0087
-              edit EMOS_TIME_STEP_H '0087'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0090
-              edit EMOS_TIME_STEP_H '0090'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0093
-              edit EMOS_TIME_STEP_H '0093'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0096
-              edit EMOS_TIME_STEP_H '0096'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0099
-              edit EMOS_TIME_STEP_H '0099'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0102
-              edit EMOS_TIME_STEP_H '0102'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0105
-              edit EMOS_TIME_STEP_H '0105'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0108
-              edit EMOS_TIME_STEP_H '0108'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0111
-              edit EMOS_TIME_STEP_H '0111'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0114
-              edit EMOS_TIME_STEP_H '0114'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0117
-              edit EMOS_TIME_STEP_H '0117'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0120
-              edit EMOS_TIME_STEP_H '0120'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0123
-              edit EMOS_TIME_STEP_H '0123'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0126
-              edit EMOS_TIME_STEP_H '0126'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0129
-              edit EMOS_TIME_STEP_H '0129'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0132
-              edit EMOS_TIME_STEP_H '0132'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0135
-              edit EMOS_TIME_STEP_H '0135'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0138
-              edit EMOS_TIME_STEP_H '0138'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0141
-              edit EMOS_TIME_STEP_H '0141'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0144
-              edit EMOS_TIME_STEP_H '0144'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0150
-              edit EMOS_TIME_STEP_H '0150'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0156
-              edit EMOS_TIME_STEP_H '0156'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0162
-              edit EMOS_TIME_STEP_H '0162'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0168
-              edit EMOS_TIME_STEP_H '0168'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0174
-              edit EMOS_TIME_STEP_H '0174'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0180
-              edit EMOS_TIME_STEP_H '0180'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0186
-              edit EMOS_TIME_STEP_H '0186'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0192
-              edit EMOS_TIME_STEP_H '0192'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0198
-              edit EMOS_TIME_STEP_H '0198'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0204
-              edit EMOS_TIME_STEP_H '0204'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0210
-              edit EMOS_TIME_STEP_H '0210'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0216
-              edit EMOS_TIME_STEP_H '0216'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0222
-              edit EMOS_TIME_STEP_H '0222'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0228
-              edit EMOS_TIME_STEP_H '0228'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0234
-              edit EMOS_TIME_STEP_H '0234'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0240
-              edit EMOS_TIME_STEP_H '0240'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-          endfamily
-          family getreq
-            trigger ../fc/pf eq active or ../fc/pf/01 eq complete
-            edit EMOS_TYPE 'cm'
-            edit EMOS_DOMAIN 'G'
-            edit EMOS_PROJECT '12'
-            edit PROD_TASK '1'
-            edit SMSTRIES '1'
-            edit EMOS_STREAM 'ENFO'
-            task collectreq
-              edit QUEUE 'diss'
-              edit USER 'emos'
-              edit WSHOST 'diss'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit LOGDIR '/diss/log'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit EMOS_BASE '12'
-            task eps
-              late -s +00:03 -c +00:10
-              trigger collectreq eq complete
-              label info ""
-              event 1 
-            task collectwave
-              trigger collectreq eq complete
-              edit QUEUE 'diss'
-              edit USER 'emos'
-              edit WSHOST 'diss'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit LOGDIR '/diss/log'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit EMOS_STREAM 'WAEF'
-              edit EMOS_BASE '12'
-            task wave_eps
-              late -s +00:03 -c +00:10
-              trigger collectwave eq complete
-              edit EMOS_STREAM 'WAEF'
-              edit USER_PRIORITY '89'
-              label info ""
-              event 1 
-            task collectbitmap
-              trigger collectwave eq complete
-              edit QUEUE 'diss'
-              edit USER 'emos'
-              edit WSHOST 'diss'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit LOGDIR '/diss/log'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit SMSOUT '/vol/emos_nc/output'
-            task bitmap
-              late -s +00:03 -c +00:10
-              trigger collectbitmap eq complete and ( eps:001 or eps eq complete)
-              event 1 
-          endfamily
-          task enfo_tc
-            late -s +00:05 -c +00:15
-            trigger ( ./getreq/eps:001 or ./getreq/eps eq complete) and ../postproc/tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TYPE 'tf'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '1'
-          task oper_tc
-            late -s +00:05 -c +00:15
-            trigger ./enfo_tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TYPE 'tf'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '1'
-            edit EMOS_STREAM 'OPER'
-          task prod_wparam
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and /e_36r1/main/12/prod/240/prod_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TYPE 'wp'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '52'
-          task enfo_postproc
-            late -s +00:05 -c +00:15
-            trigger ../postproc eq complete and ( ../../legA/prod/getreq/eps eq complete) and ../../legA/postproc/efi eq complete and ../../legA/postproc/clusters eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'ep'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '21'
-          task waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '1'
-        endfamily
-        family prod2diss
-          edit USER_PRIORITY '90'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'ef'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-          edit SMSURL 'GENFO/12'
-          task operation_is_late
-            event yes
-          family eps
-            family 0000
-              edit EMOS_TIME_STEP_H '0000'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0000/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0003
-              edit EMOS_TIME_STEP_H '0003'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0003/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0000/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0006
-              edit EMOS_TIME_STEP_H '0006'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0006/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0003/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0009
-              edit EMOS_TIME_STEP_H '0009'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0009/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0006/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0012
-              edit EMOS_TIME_STEP_H '0012'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0012/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0009/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0015
-              edit EMOS_TIME_STEP_H '0015'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0015/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0012/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0018
-              edit EMOS_TIME_STEP_H '0018'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0018/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0015/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0021
-              edit EMOS_TIME_STEP_H '0021'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0021/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0018/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0024
-              edit EMOS_TIME_STEP_H '0024'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0024/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0021/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0027
-              edit EMOS_TIME_STEP_H '0027'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0027/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0024/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0030
-              edit EMOS_TIME_STEP_H '0030'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0030/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0027/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0033
-              edit EMOS_TIME_STEP_H '0033'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0033/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0030/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0036
-              edit EMOS_TIME_STEP_H '0036'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0036/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0033/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0039
-              edit EMOS_TIME_STEP_H '0039'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0039/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0036/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0042
-              edit EMOS_TIME_STEP_H '0042'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0042/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0039/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0045
-              edit EMOS_TIME_STEP_H '0045'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0045/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0042/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0048
-              edit EMOS_TIME_STEP_H '0048'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0048/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0045/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0051
-              edit EMOS_TIME_STEP_H '0051'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0051/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0048/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0054
-              edit EMOS_TIME_STEP_H '0054'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0054/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0051/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0057
-              edit EMOS_TIME_STEP_H '0057'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0057/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0054/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0060
-              edit EMOS_TIME_STEP_H '0060'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0060/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0057/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0063
-              edit EMOS_TIME_STEP_H '0063'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0063/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0060/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0066
-              edit EMOS_TIME_STEP_H '0066'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0066/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0063/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0069
-              edit EMOS_TIME_STEP_H '0069'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0069/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0066/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0072
-              edit EMOS_TIME_STEP_H '0072'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0072/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0069/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0075
-              edit EMOS_TIME_STEP_H '0075'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0075/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0072/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0078
-              edit EMOS_TIME_STEP_H '0078'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0078/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0075/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0081
-              edit EMOS_TIME_STEP_H '0081'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0081/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0078/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0084
-              edit EMOS_TIME_STEP_H '0084'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0084/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0081/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0087
-              edit EMOS_TIME_STEP_H '0087'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0087/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0084/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0090
-              edit EMOS_TIME_STEP_H '0090'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0090/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0087/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0093
-              edit EMOS_TIME_STEP_H '0093'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0093/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0090/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0096
-              edit EMOS_TIME_STEP_H '0096'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0096/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0093/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0099
-              edit EMOS_TIME_STEP_H '0099'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0099/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0096/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0102
-              edit EMOS_TIME_STEP_H '0102'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0102/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0099/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0105
-              edit EMOS_TIME_STEP_H '0105'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0105/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0102/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0108
-              edit EMOS_TIME_STEP_H '0108'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0108/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0105/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0111
-              edit EMOS_TIME_STEP_H '0111'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0111/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0108/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0114
-              edit EMOS_TIME_STEP_H '0114'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0114/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0111/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0117
-              edit EMOS_TIME_STEP_H '0117'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0117/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0114/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0120
-              edit EMOS_TIME_STEP_H '0120'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0120/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0117/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0123
-              edit EMOS_TIME_STEP_H '0123'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0123/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0120/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0126
-              edit EMOS_TIME_STEP_H '0126'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0126/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0123/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0129
-              edit EMOS_TIME_STEP_H '0129'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0129/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0126/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0132
-              edit EMOS_TIME_STEP_H '0132'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0132/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0129/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0135
-              edit EMOS_TIME_STEP_H '0135'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0135/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0132/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0138
-              edit EMOS_TIME_STEP_H '0138'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0138/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0135/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0141
-              edit EMOS_TIME_STEP_H '0141'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0141/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0138/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0144
-              edit EMOS_TIME_STEP_H '0144'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0144/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0141/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0150
-              edit EMOS_TIME_STEP_H '0150'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0150/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0144/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0156
-              edit EMOS_TIME_STEP_H '0156'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0156/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0150/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0162
-              edit EMOS_TIME_STEP_H '0162'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0162/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0156/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0168
-              edit EMOS_TIME_STEP_H '0168'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0168/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0162/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0174
-              edit EMOS_TIME_STEP_H '0174'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0174/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0168/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0180
-              edit EMOS_TIME_STEP_H '0180'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0180/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0174/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0186
-              edit EMOS_TIME_STEP_H '0186'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0186/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0180/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0192
-              edit EMOS_TIME_STEP_H '0192'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0192/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0186/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0198
-              edit EMOS_TIME_STEP_H '0198'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0198/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0192/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0204
-              edit EMOS_TIME_STEP_H '0204'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0204/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0198/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0210
-              edit EMOS_TIME_STEP_H '0210'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0210/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0204/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0216
-              edit EMOS_TIME_STEP_H '0216'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0216/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0210/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0222
-              edit EMOS_TIME_STEP_H '0222'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0222/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0216/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0228
-              edit EMOS_TIME_STEP_H '0228'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0228/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0222/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0234
-              edit EMOS_TIME_STEP_H '0234'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0234/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0228/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0240
-              edit EMOS_TIME_STEP_H '0240'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0240/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0234/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            task check
-              trigger ./0240 eq complete
-          endfamily
-          family wave
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TYPE 'we'
-            edit SMSURL 'GWAEF/12'
-            family 0000
-              trigger ../../prod/wave/0000/prodwave eq complete
-              edit EMOS_TIME_STEP_H '0000'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0003
-              trigger ../../prod/wave/0003/prodwave eq complete and ( ./0000 eq complete)
-              edit EMOS_TIME_STEP_H '0003'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0006
-              trigger ../../prod/wave/0006/prodwave eq complete and ( ./0003 eq complete)
-              edit EMOS_TIME_STEP_H '0006'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0009
-              trigger ../../prod/wave/0009/prodwave eq complete and ( ./0006 eq complete)
-              edit EMOS_TIME_STEP_H '0009'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0012
-              trigger ../../prod/wave/0012/prodwave eq complete and ( ./0009 eq complete)
-              edit EMOS_TIME_STEP_H '0012'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0015
-              trigger ../../prod/wave/0015/prodwave eq complete and ( ./0012 eq complete)
-              edit EMOS_TIME_STEP_H '0015'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0018
-              trigger ../../prod/wave/0018/prodwave eq complete and ( ./0015 eq complete)
-              edit EMOS_TIME_STEP_H '0018'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0021
-              trigger ../../prod/wave/0021/prodwave eq complete and ( ./0018 eq complete)
-              edit EMOS_TIME_STEP_H '0021'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0024
-              trigger ../../prod/wave/0024/prodwave eq complete and ( ./0021 eq complete)
-              edit EMOS_TIME_STEP_H '0024'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0027
-              trigger ../../prod/wave/0027/prodwave eq complete and ( ./0024 eq complete)
-              edit EMOS_TIME_STEP_H '0027'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0030
-              trigger ../../prod/wave/0030/prodwave eq complete and ( ./0027 eq complete)
-              edit EMOS_TIME_STEP_H '0030'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0033
-              trigger ../../prod/wave/0033/prodwave eq complete and ( ./0030 eq complete)
-              edit EMOS_TIME_STEP_H '0033'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0036
-              trigger ../../prod/wave/0036/prodwave eq complete and ( ./0033 eq complete)
-              edit EMOS_TIME_STEP_H '0036'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0039
-              trigger ../../prod/wave/0039/prodwave eq complete and ( ./0036 eq complete)
-              edit EMOS_TIME_STEP_H '0039'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0042
-              trigger ../../prod/wave/0042/prodwave eq complete and ( ./0039 eq complete)
-              edit EMOS_TIME_STEP_H '0042'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0045
-              trigger ../../prod/wave/0045/prodwave eq complete and ( ./0042 eq complete)
-              edit EMOS_TIME_STEP_H '0045'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0048
-              trigger ../../prod/wave/0048/prodwave eq complete and ( ./0045 eq complete)
-              edit EMOS_TIME_STEP_H '0048'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0051
-              trigger ../../prod/wave/0051/prodwave eq complete and ( ./0048 eq complete)
-              edit EMOS_TIME_STEP_H '0051'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0054
-              trigger ../../prod/wave/0054/prodwave eq complete and ( ./0051 eq complete)
-              edit EMOS_TIME_STEP_H '0054'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0057
-              trigger ../../prod/wave/0057/prodwave eq complete and ( ./0054 eq complete)
-              edit EMOS_TIME_STEP_H '0057'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0060
-              trigger ../../prod/wave/0060/prodwave eq complete and ( ./0057 eq complete)
-              edit EMOS_TIME_STEP_H '0060'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0063
-              trigger ../../prod/wave/0063/prodwave eq complete and ( ./0060 eq complete)
-              edit EMOS_TIME_STEP_H '0063'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0066
-              trigger ../../prod/wave/0066/prodwave eq complete and ( ./0063 eq complete)
-              edit EMOS_TIME_STEP_H '0066'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0069
-              trigger ../../prod/wave/0069/prodwave eq complete and ( ./0066 eq complete)
-              edit EMOS_TIME_STEP_H '0069'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0072
-              trigger ../../prod/wave/0072/prodwave eq complete and ( ./0069 eq complete)
-              edit EMOS_TIME_STEP_H '0072'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0075
-              trigger ../../prod/wave/0075/prodwave eq complete and ( ./0072 eq complete)
-              edit EMOS_TIME_STEP_H '0075'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0078
-              trigger ../../prod/wave/0078/prodwave eq complete and ( ./0075 eq complete)
-              edit EMOS_TIME_STEP_H '0078'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0081
-              trigger ../../prod/wave/0081/prodwave eq complete and ( ./0078 eq complete)
-              edit EMOS_TIME_STEP_H '0081'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0084
-              trigger ../../prod/wave/0084/prodwave eq complete and ( ./0081 eq complete)
-              edit EMOS_TIME_STEP_H '0084'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0087
-              trigger ../../prod/wave/0087/prodwave eq complete and ( ./0084 eq complete)
-              edit EMOS_TIME_STEP_H '0087'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0090
-              trigger ../../prod/wave/0090/prodwave eq complete and ( ./0087 eq complete)
-              edit EMOS_TIME_STEP_H '0090'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0093
-              trigger ../../prod/wave/0093/prodwave eq complete and ( ./0090 eq complete)
-              edit EMOS_TIME_STEP_H '0093'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0096
-              trigger ../../prod/wave/0096/prodwave eq complete and ( ./0093 eq complete)
-              edit EMOS_TIME_STEP_H '0096'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0099
-              trigger ../../prod/wave/0099/prodwave eq complete and ( ./0096 eq complete)
-              edit EMOS_TIME_STEP_H '0099'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0102
-              trigger ../../prod/wave/0102/prodwave eq complete and ( ./0099 eq complete)
-              edit EMOS_TIME_STEP_H '0102'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0105
-              trigger ../../prod/wave/0105/prodwave eq complete and ( ./0102 eq complete)
-              edit EMOS_TIME_STEP_H '0105'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0108
-              trigger ../../prod/wave/0108/prodwave eq complete and ( ./0105 eq complete)
-              edit EMOS_TIME_STEP_H '0108'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0111
-              trigger ../../prod/wave/0111/prodwave eq complete and ( ./0108 eq complete)
-              edit EMOS_TIME_STEP_H '0111'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0114
-              trigger ../../prod/wave/0114/prodwave eq complete and ( ./0111 eq complete)
-              edit EMOS_TIME_STEP_H '0114'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0117
-              trigger ../../prod/wave/0117/prodwave eq complete and ( ./0114 eq complete)
-              edit EMOS_TIME_STEP_H '0117'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0120
-              trigger ../../prod/wave/0120/prodwave eq complete and ( ./0117 eq complete)
-              edit EMOS_TIME_STEP_H '0120'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0123
-              trigger ../../prod/wave/0123/prodwave eq complete and ( ./0120 eq complete)
-              edit EMOS_TIME_STEP_H '0123'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0126
-              trigger ../../prod/wave/0126/prodwave eq complete and ( ./0123 eq complete)
-              edit EMOS_TIME_STEP_H '0126'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0129
-              trigger ../../prod/wave/0129/prodwave eq complete and ( ./0126 eq complete)
-              edit EMOS_TIME_STEP_H '0129'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0132
-              trigger ../../prod/wave/0132/prodwave eq complete and ( ./0129 eq complete)
-              edit EMOS_TIME_STEP_H '0132'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0135
-              trigger ../../prod/wave/0135/prodwave eq complete and ( ./0132 eq complete)
-              edit EMOS_TIME_STEP_H '0135'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0138
-              trigger ../../prod/wave/0138/prodwave eq complete and ( ./0135 eq complete)
-              edit EMOS_TIME_STEP_H '0138'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0141
-              trigger ../../prod/wave/0141/prodwave eq complete and ( ./0138 eq complete)
-              edit EMOS_TIME_STEP_H '0141'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0144
-              trigger ../../prod/wave/0144/prodwave eq complete and ( ./0141 eq complete)
-              edit EMOS_TIME_STEP_H '0144'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0150
-              trigger ../../prod/wave/0150/prodwave eq complete and ( ./0144 eq complete)
-              edit EMOS_TIME_STEP_H '0150'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0156
-              trigger ../../prod/wave/0156/prodwave eq complete and ( ./0150 eq complete)
-              edit EMOS_TIME_STEP_H '0156'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0162
-              trigger ../../prod/wave/0162/prodwave eq complete and ( ./0156 eq complete)
-              edit EMOS_TIME_STEP_H '0162'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0168
-              trigger ../../prod/wave/0168/prodwave eq complete and ( ./0162 eq complete)
-              edit EMOS_TIME_STEP_H '0168'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0174
-              trigger ../../prod/wave/0174/prodwave eq complete and ( ./0168 eq complete)
-              edit EMOS_TIME_STEP_H '0174'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0180
-              trigger ../../prod/wave/0180/prodwave eq complete and ( ./0174 eq complete)
-              edit EMOS_TIME_STEP_H '0180'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0186
-              trigger ../../prod/wave/0186/prodwave eq complete and ( ./0180 eq complete)
-              edit EMOS_TIME_STEP_H '0186'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0192
-              trigger ../../prod/wave/0192/prodwave eq complete and ( ./0186 eq complete)
-              edit EMOS_TIME_STEP_H '0192'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0198
-              trigger ../../prod/wave/0198/prodwave eq complete and ( ./0192 eq complete)
-              edit EMOS_TIME_STEP_H '0198'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0204
-              trigger ../../prod/wave/0204/prodwave eq complete and ( ./0198 eq complete)
-              edit EMOS_TIME_STEP_H '0204'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0210
-              trigger ../../prod/wave/0210/prodwave eq complete and ( ./0204 eq complete)
-              edit EMOS_TIME_STEP_H '0210'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0216
-              trigger ../../prod/wave/0216/prodwave eq complete and ( ./0210 eq complete)
-              edit EMOS_TIME_STEP_H '0216'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0222
-              trigger ../../prod/wave/0222/prodwave eq complete and ( ./0216 eq complete)
-              edit EMOS_TIME_STEP_H '0222'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0228
-              trigger ../../prod/wave/0228/prodwave eq complete and ( ./0222 eq complete)
-              edit EMOS_TIME_STEP_H '0228'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0234
-              trigger ../../prod/wave/0234/prodwave eq complete and ( ./0228 eq complete)
-              edit EMOS_TIME_STEP_H '0234'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0240
-              trigger ../../prod/wave/0240/prodwave eq complete and ( ./0234 eq complete)
-              edit EMOS_TIME_STEP_H '0240'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            task check
-              trigger ./0240 eq complete
-          endfamily
-          task diss_wparam
-            late -s +00:05 -c +00:15
-            trigger ../prod/prod_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'wp'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/waef_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/enfo_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'ep'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_enfotc
-            late -s +00:05 -c +00:15
-            trigger ../prod/enfo_tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'tf'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_opertc
-            late -s +00:05 -c +00:15
-            trigger ../prod/oper_tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'tf'
-            edit EMOS_STREAM 'DA'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-        endfamily
-      endfamily
-      family legB
-        complete /emc_36r1/main/ref/12/events:240
-        edit EPSLEG '2'
-        family fc
-          edit FCMEM '2240'
-          edit FCSTACK '700'
-          edit FCMRFS '0'
-          edit PRIORITY '71'
-          edit USER_PRIORITY '71'
-          edit N_PERT_AN '10'
-          edit SSTLEN '144'
-          edit EPSINISTEP_PREVIOUS '216'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          edit TSTEP '2700'
-          edit EPSFCRES '639'
-          edit RESOL '639'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit CPUTIME '1000'
-          edit MEM '960'
-          edit THREADS '8'
-          edit NPES '8'
-          edit EPSLEG '2'
-          edit PERSST 'true'
-          edit SSTINT '1'
-          task wavfcdata
-            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-            edit EPSCOUPLE '1'
-          task getpersSST
-            trigger ../../legA/fc/inidata eq complete and ../../legA/fc/getpersSST eq complete
-            edit EPSCOUPLE '1'
-            edit EPS_INI_STREAM 'DA'
-            edit EPSFCRES '319'
-            edit RESOL '319'
-          family pf
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger ./getpersSST eq complete and ./wavfcdata eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTYPE 'pf'
-            edit EMOS_TYPE 'pf'
-            edit USER_PRIORITY '71'
-            edit PRIORITY '71'
-            edit FCNPES '32'
-            edit FCCHUNK '1'
-            edit OCTOTAL '5'
-            edit FCTOTAL '51'
-            edit FCLENGTH1 '216'
-            edit DAILY '0'
-            edit RUNVARFC '1'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSFCRES '319'
-            edit EPSWAMRESOL 'global50'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit EPSINISTEP '360'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '2'
-            edit CLASS 'od'
-            edit THREADS '2'
-            inlimit /emc_36r1/limits:pftotal
-            meter step -1 144 144
-            family 01
-              trigger ../../../legA/fc/pf/01 eq complete
-              edit EPSMEMBER '1'
-              edit MEMBER '1'
-              edit SUBFSFAMILY '/pf001'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 02
-              trigger ../../../legA/fc/pf/02 eq complete
-              edit EPSMEMBER '2'
-              edit MEMBER '2'
-              edit SUBFSFAMILY '/pf002'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 03
-              trigger ../../../legA/fc/pf/03 eq complete
-              edit EPSMEMBER '3'
-              edit MEMBER '3'
-              edit SUBFSFAMILY '/pf003'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 04
-              trigger ../../../legA/fc/pf/04 eq complete
-              edit EPSMEMBER '4'
-              edit MEMBER '4'
-              edit SUBFSFAMILY '/pf004'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 05
-              trigger ../../../legA/fc/pf/05 eq complete
-              edit EPSMEMBER '5'
-              edit MEMBER '5'
-              edit SUBFSFAMILY '/pf005'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 06
-              trigger ../../../legA/fc/pf/06 eq complete
-              edit EPSMEMBER '6'
-              edit MEMBER '6'
-              edit SUBFSFAMILY '/pf006'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 07
-              trigger ../../../legA/fc/pf/07 eq complete
-              edit EPSMEMBER '7'
-              edit MEMBER '7'
-              edit SUBFSFAMILY '/pf007'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 08
-              trigger ../../../legA/fc/pf/08 eq complete
-              edit EPSMEMBER '8'
-              edit MEMBER '8'
-              edit SUBFSFAMILY '/pf008'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 09
-              trigger ../../../legA/fc/pf/09 eq complete
-              edit EPSMEMBER '9'
-              edit MEMBER '9'
-              edit SUBFSFAMILY '/pf009'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 10
-              trigger ../../../legA/fc/pf/10 eq complete
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              edit SUBFSFAMILY '/pf010'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 11
-              trigger ../../../legA/fc/pf/11 eq complete
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              edit SUBFSFAMILY '/pf011'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 12
-              trigger ../../../legA/fc/pf/12 eq complete
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              edit SUBFSFAMILY '/pf012'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 13
-              trigger ../../../legA/fc/pf/13 eq complete
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              edit SUBFSFAMILY '/pf013'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 14
-              trigger ../../../legA/fc/pf/14 eq complete
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              edit SUBFSFAMILY '/pf014'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 15
-              trigger ../../../legA/fc/pf/15 eq complete
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              edit SUBFSFAMILY '/pf015'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 16
-              trigger ../../../legA/fc/pf/16 eq complete
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              edit SUBFSFAMILY '/pf016'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 17
-              trigger ../../../legA/fc/pf/17 eq complete
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              edit SUBFSFAMILY '/pf017'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 18
-              trigger ../../../legA/fc/pf/18 eq complete
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              edit SUBFSFAMILY '/pf018'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 19
-              trigger ../../../legA/fc/pf/19 eq complete
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              edit SUBFSFAMILY '/pf019'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 20
-              trigger ../../../legA/fc/pf/20 eq complete
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              edit SUBFSFAMILY '/pf020'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 21
-              trigger ../../../legA/fc/pf/21 eq complete
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              edit SUBFSFAMILY '/pf021'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 22
-              trigger ../../../legA/fc/pf/22 eq complete
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              edit SUBFSFAMILY '/pf022'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 23
-              trigger ../../../legA/fc/pf/23 eq complete
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              edit SUBFSFAMILY '/pf023'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 24
-              trigger ../../../legA/fc/pf/24 eq complete
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              edit SUBFSFAMILY '/pf024'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 25
-              trigger ../../../legA/fc/pf/25 eq complete
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              edit SUBFSFAMILY '/pf025'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 26
-              trigger ../../../legA/fc/pf/26 eq complete
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              edit SUBFSFAMILY '/pf026'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 27
-              trigger ../../../legA/fc/pf/27 eq complete
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              edit SUBFSFAMILY '/pf027'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 28
-              trigger ../../../legA/fc/pf/28 eq complete
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              edit SUBFSFAMILY '/pf028'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 29
-              trigger ../../../legA/fc/pf/29 eq complete
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              edit SUBFSFAMILY '/pf029'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 30
-              trigger ../../../legA/fc/pf/30 eq complete
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              edit SUBFSFAMILY '/pf030'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 31
-              trigger ../../../legA/fc/pf/31 eq complete
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              edit SUBFSFAMILY '/pf031'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 32
-              trigger ../../../legA/fc/pf/32 eq complete
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              edit SUBFSFAMILY '/pf032'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 33
-              trigger ../../../legA/fc/pf/33 eq complete
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              edit SUBFSFAMILY '/pf033'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 34
-              trigger ../../../legA/fc/pf/34 eq complete
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              edit SUBFSFAMILY '/pf034'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 35
-              trigger ../../../legA/fc/pf/35 eq complete
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              edit SUBFSFAMILY '/pf035'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 36
-              trigger ../../../legA/fc/pf/36 eq complete
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              edit SUBFSFAMILY '/pf036'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 37
-              trigger ../../../legA/fc/pf/37 eq complete
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              edit SUBFSFAMILY '/pf037'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 38
-              trigger ../../../legA/fc/pf/38 eq complete
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              edit SUBFSFAMILY '/pf038'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 39
-              trigger ../../../legA/fc/pf/39 eq complete
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              edit SUBFSFAMILY '/pf039'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 40
-              trigger ../../../legA/fc/pf/40 eq complete
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              edit SUBFSFAMILY '/pf040'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 41
-              trigger ../../../legA/fc/pf/41 eq complete
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              edit SUBFSFAMILY '/pf041'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 42
-              trigger ../../../legA/fc/pf/42 eq complete
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              edit SUBFSFAMILY '/pf042'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 43
-              trigger ../../../legA/fc/pf/43 eq complete
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              edit SUBFSFAMILY '/pf043'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 44
-              trigger ../../../legA/fc/pf/44 eq complete
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              edit SUBFSFAMILY '/pf044'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 45
-              trigger ../../../legA/fc/pf/45 eq complete
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              edit SUBFSFAMILY '/pf045'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 46
-              trigger ../../../legA/fc/pf/46 eq complete
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              edit SUBFSFAMILY '/pf046'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 47
-              trigger ../../../legA/fc/pf/47 eq complete
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              edit SUBFSFAMILY '/pf047'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 48
-              trigger ../../../legA/fc/pf/48 eq complete
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              edit SUBFSFAMILY '/pf048'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 49
-              trigger ../../../legA/fc/pf/49 eq complete
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              edit SUBFSFAMILY '/pf049'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 50
-              trigger ../../../legA/fc/pf/50 eq complete
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              edit SUBFSFAMILY '/pf050'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-          endfamily
-          family cf
-            trigger ../../legA/fc/cf eq complete and not /emc_36r1/main/ref/12/events:cpl and ./getpersSST eq complete and ./wavfcdata eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit MEMBER '0'
-            edit EPSMEMBER '0'
-            edit SUBFSFAMILY '/cf000'
-            edit EPSTYPE 'cf'
-            edit EMOS_TYPE 'cf'
-            edit USER_PRIORITY '72'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSFCRES '319'
-            edit EPSWAMRESOL 'global50'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit EPSINISTEP '360'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '2'
-            edit CLASS 'od'
-            edit SMSTRIES '1'
-            edit RUNCOUPLE '0'
-            task getvarepsdata
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '2700'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSLEG '2'
-              edit EPSINISTEP '216'
-              edit EPSFCRES '639'
-              edit EPSFCRESN '319'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '2700'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '216'
-              edit EPSFCRES '319'
-              edit NPES '24'
-              edit FCNPES '24'
-              edit THREADS '2'
-              edit CLASS 'od'
-            task modeleps
-              trigger intHtoL eq complete and getvarepsdata eq complete
-              edit FCNPES '32'
-              edit THREADS '4'
-              edit SMSTRIES '1'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSLEG '2'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '144'
-              edit EPSINISTEP_PREVIOUS '216'
-              edit FCLENGTH '144'
-              edit TSTEP '2700'
-              edit CLASS 'od'
-              meter step -1 144 144
-          endfamily
-          family reservation
-            trigger ./pf/46/intHtoL eq complete and ./pf/47/intHtoL eq complete and ./pf/48/intHtoL eq complete and ./pf/49/intHtoL eq complete and ./pf/50/intHtoL eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reset_class
-              late -s +00:02 -c +00:02
-              edit RESERVATION_DEFINITION 'default'
-              label info ""
-            task reset_cpu
-              late -s +00:02 -c +00:02
-              edit RESERVED_CPUS '0'
-              label info ""
-          endfamily
-        endfamily
-        family postproc
-          trigger ./fc/pf eq complete and ./fc/cf eq complete
-          edit STEPS '252/360/12/24 360/360/12/120'
-          inlimit /emc_36r1/limits:postproc
-          family ensms
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger ../fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            family limits
-              limit fdb 1
-              limit gen 8
-            endfamily
-            task ensms
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit ENS_MARS 'false'
-              event stage
-            family 300
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '246'
-              edit STEP2 '300'
-              edit BY '6'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 360
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '306'
-              edit STEP2 '360'
-              edit BY '6'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-          endfamily
-          family prob
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger ( /emc_36r1/main/12/legB/fc eq complete) and ( /emc_36r1/main/12/legA/postproc/prob eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            edit STEP1 '252'
-            edit STEP2 '360'
-            edit BY '12'
-            family 24
-              edit STEP1 '240'
-              edit STEP2 '360'
-              edit BY '24'
-              task t850
-              task rain
-              task ff
-            endfamily
-            family 12
-              edit STEP1 '252'
-              edit STEP2 '348'
-              edit BY '24'
-              task t850
-              task rain
-              task ff
-            endfamily
-            task 2t
-            task swh
-            task mwp
-            task 10fg
-              trigger ../dp eq complete
-            task prob_fdb
-              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
-          endfamily
-          family dp
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '246:360:6'
-            inlimit /emc_36r1/limits:dp
-            family dp
-              trigger ./cf eq complete and ./pf eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit OVERLAP '1'
-              edit STEPS '216:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                complete /emc_36r1/main/ref/12/events:cf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-                family 05
-                  edit EPSMEMBER '5'
-                  edit MEMBER '5'
-                  edit SUBFSFAMILY '/pf005'
-                  task derived_param
-                endfamily
-                family 06
-                  edit EPSMEMBER '6'
-                  edit MEMBER '6'
-                  edit SUBFSFAMILY '/pf006'
-                  task derived_param
-                endfamily
-                family 07
-                  edit EPSMEMBER '7'
-                  edit MEMBER '7'
-                  edit SUBFSFAMILY '/pf007'
-                  task derived_param
-                endfamily
-                family 08
-                  edit EPSMEMBER '8'
-                  edit MEMBER '8'
-                  edit SUBFSFAMILY '/pf008'
-                  task derived_param
-                endfamily
-                family 09
-                  edit EPSMEMBER '9'
-                  edit MEMBER '9'
-                  edit SUBFSFAMILY '/pf009'
-                  task derived_param
-                endfamily
-                family 10
-                  edit EPSMEMBER '10'
-                  edit MEMBER '10'
-                  edit SUBFSFAMILY '/pf010'
-                  task derived_param
-                endfamily
-                family 11
-                  edit EPSMEMBER '11'
-                  edit MEMBER '11'
-                  edit SUBFSFAMILY '/pf011'
-                  task derived_param
-                endfamily
-                family 12
-                  edit EPSMEMBER '12'
-                  edit MEMBER '12'
-                  edit SUBFSFAMILY '/pf012'
-                  task derived_param
-                endfamily
-                family 13
-                  edit EPSMEMBER '13'
-                  edit MEMBER '13'
-                  edit SUBFSFAMILY '/pf013'
-                  task derived_param
-                endfamily
-                family 14
-                  edit EPSMEMBER '14'
-                  edit MEMBER '14'
-                  edit SUBFSFAMILY '/pf014'
-                  task derived_param
-                endfamily
-                family 15
-                  edit EPSMEMBER '15'
-                  edit MEMBER '15'
-                  edit SUBFSFAMILY '/pf015'
-                  task derived_param
-                endfamily
-                family 16
-                  edit EPSMEMBER '16'
-                  edit MEMBER '16'
-                  edit SUBFSFAMILY '/pf016'
-                  task derived_param
-                endfamily
-                family 17
-                  edit EPSMEMBER '17'
-                  edit MEMBER '17'
-                  edit SUBFSFAMILY '/pf017'
-                  task derived_param
-                endfamily
-                family 18
-                  edit EPSMEMBER '18'
-                  edit MEMBER '18'
-                  edit SUBFSFAMILY '/pf018'
-                  task derived_param
-                endfamily
-                family 19
-                  edit EPSMEMBER '19'
-                  edit MEMBER '19'
-                  edit SUBFSFAMILY '/pf019'
-                  task derived_param
-                endfamily
-                family 20
-                  edit EPSMEMBER '20'
-                  edit MEMBER '20'
-                  edit SUBFSFAMILY '/pf020'
-                  task derived_param
-                endfamily
-                family 21
-                  edit EPSMEMBER '21'
-                  edit MEMBER '21'
-                  edit SUBFSFAMILY '/pf021'
-                  task derived_param
-                endfamily
-                family 22
-                  edit EPSMEMBER '22'
-                  edit MEMBER '22'
-                  edit SUBFSFAMILY '/pf022'
-                  task derived_param
-                endfamily
-                family 23
-                  edit EPSMEMBER '23'
-                  edit MEMBER '23'
-                  edit SUBFSFAMILY '/pf023'
-                  task derived_param
-                endfamily
-                family 24
-                  edit EPSMEMBER '24'
-                  edit MEMBER '24'
-                  edit SUBFSFAMILY '/pf024'
-                  task derived_param
-                endfamily
-                family 25
-                  edit EPSMEMBER '25'
-                  edit MEMBER '25'
-                  edit SUBFSFAMILY '/pf025'
-                  task derived_param
-                endfamily
-                family 26
-                  edit EPSMEMBER '26'
-                  edit MEMBER '26'
-                  edit SUBFSFAMILY '/pf026'
-                  task derived_param
-                endfamily
-                family 27
-                  edit EPSMEMBER '27'
-                  edit MEMBER '27'
-                  edit SUBFSFAMILY '/pf027'
-                  task derived_param
-                endfamily
-                family 28
-                  edit EPSMEMBER '28'
-                  edit MEMBER '28'
-                  edit SUBFSFAMILY '/pf028'
-                  task derived_param
-                endfamily
-                family 29
-                  edit EPSMEMBER '29'
-                  edit MEMBER '29'
-                  edit SUBFSFAMILY '/pf029'
-                  task derived_param
-                endfamily
-                family 30
-                  edit EPSMEMBER '30'
-                  edit MEMBER '30'
-                  edit SUBFSFAMILY '/pf030'
-                  task derived_param
-                endfamily
-                family 31
-                  edit EPSMEMBER '31'
-                  edit MEMBER '31'
-                  edit SUBFSFAMILY '/pf031'
-                  task derived_param
-                endfamily
-                family 32
-                  edit EPSMEMBER '32'
-                  edit MEMBER '32'
-                  edit SUBFSFAMILY '/pf032'
-                  task derived_param
-                endfamily
-                family 33
-                  edit EPSMEMBER '33'
-                  edit MEMBER '33'
-                  edit SUBFSFAMILY '/pf033'
-                  task derived_param
-                endfamily
-                family 34
-                  edit EPSMEMBER '34'
-                  edit MEMBER '34'
-                  edit SUBFSFAMILY '/pf034'
-                  task derived_param
-                endfamily
-                family 35
-                  edit EPSMEMBER '35'
-                  edit MEMBER '35'
-                  edit SUBFSFAMILY '/pf035'
-                  task derived_param
-                endfamily
-                family 36
-                  edit EPSMEMBER '36'
-                  edit MEMBER '36'
-                  edit SUBFSFAMILY '/pf036'
-                  task derived_param
-                endfamily
-                family 37
-                  edit EPSMEMBER '37'
-                  edit MEMBER '37'
-                  edit SUBFSFAMILY '/pf037'
-                  task derived_param
-                endfamily
-                family 38
-                  edit EPSMEMBER '38'
-                  edit MEMBER '38'
-                  edit SUBFSFAMILY '/pf038'
-                  task derived_param
-                endfamily
-                family 39
-                  edit EPSMEMBER '39'
-                  edit MEMBER '39'
-                  edit SUBFSFAMILY '/pf039'
-                  task derived_param
-                endfamily
-                family 40
-                  edit EPSMEMBER '40'
-                  edit MEMBER '40'
-                  edit SUBFSFAMILY '/pf040'
-                  task derived_param
-                endfamily
-                family 41
-                  edit EPSMEMBER '41'
-                  edit MEMBER '41'
-                  edit SUBFSFAMILY '/pf041'
-                  task derived_param
-                endfamily
-                family 42
-                  edit EPSMEMBER '42'
-                  edit MEMBER '42'
-                  edit SUBFSFAMILY '/pf042'
-                  task derived_param
-                endfamily
-                family 43
-                  edit EPSMEMBER '43'
-                  edit MEMBER '43'
-                  edit SUBFSFAMILY '/pf043'
-                  task derived_param
-                endfamily
-                family 44
-                  edit EPSMEMBER '44'
-                  edit MEMBER '44'
-                  edit SUBFSFAMILY '/pf044'
-                  task derived_param
-                endfamily
-                family 45
-                  edit EPSMEMBER '45'
-                  edit MEMBER '45'
-                  edit SUBFSFAMILY '/pf045'
-                  task derived_param
-                endfamily
-                family 46
-                  edit EPSMEMBER '46'
-                  edit MEMBER '46'
-                  edit SUBFSFAMILY '/pf046'
-                  task derived_param
-                endfamily
-                family 47
-                  edit EPSMEMBER '47'
-                  edit MEMBER '47'
-                  edit SUBFSFAMILY '/pf047'
-                  task derived_param
-                endfamily
-                family 48
-                  edit EPSMEMBER '48'
-                  edit MEMBER '48'
-                  edit SUBFSFAMILY '/pf048'
-                  task derived_param
-                endfamily
-                family 49
-                  edit EPSMEMBER '49'
-                  edit MEMBER '49'
-                  edit SUBFSFAMILY '/pf049'
-                  task derived_param
-                endfamily
-                family 50
-                  edit EPSMEMBER '50'
-                  edit MEMBER '50'
-                  edit SUBFSFAMILY '/pf050'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family cf
-              trigger ../../fc/cf eq complete
-              edit EMOS_TYPE 'cf'
-              task derived_param
-                edit MEMBER 'off'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/12/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                trigger ../../../fc/pf/01 eq complete
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task derived_param
-              endfamily
-              family 02
-                trigger ../../../fc/pf/02 eq complete
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task derived_param
-              endfamily
-              family 03
-                trigger ../../../fc/pf/03 eq complete
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task derived_param
-              endfamily
-              family 04
-                trigger ../../../fc/pf/04 eq complete
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task derived_param
-              endfamily
-              family 05
-                trigger ../../../fc/pf/05 eq complete
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task derived_param
-              endfamily
-              family 06
-                trigger ../../../fc/pf/06 eq complete
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task derived_param
-              endfamily
-              family 07
-                trigger ../../../fc/pf/07 eq complete
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task derived_param
-              endfamily
-              family 08
-                trigger ../../../fc/pf/08 eq complete
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task derived_param
-              endfamily
-              family 09
-                trigger ../../../fc/pf/09 eq complete
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task derived_param
-              endfamily
-              family 10
-                trigger ../../../fc/pf/10 eq complete
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task derived_param
-              endfamily
-              family 11
-                trigger ../../../fc/pf/11 eq complete
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task derived_param
-              endfamily
-              family 12
-                trigger ../../../fc/pf/12 eq complete
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task derived_param
-              endfamily
-              family 13
-                trigger ../../../fc/pf/13 eq complete
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task derived_param
-              endfamily
-              family 14
-                trigger ../../../fc/pf/14 eq complete
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task derived_param
-              endfamily
-              family 15
-                trigger ../../../fc/pf/15 eq complete
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task derived_param
-              endfamily
-              family 16
-                trigger ../../../fc/pf/16 eq complete
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task derived_param
-              endfamily
-              family 17
-                trigger ../../../fc/pf/17 eq complete
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task derived_param
-              endfamily
-              family 18
-                trigger ../../../fc/pf/18 eq complete
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task derived_param
-              endfamily
-              family 19
-                trigger ../../../fc/pf/19 eq complete
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task derived_param
-              endfamily
-              family 20
-                trigger ../../../fc/pf/20 eq complete
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task derived_param
-              endfamily
-              family 21
-                trigger ../../../fc/pf/21 eq complete
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task derived_param
-              endfamily
-              family 22
-                trigger ../../../fc/pf/22 eq complete
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task derived_param
-              endfamily
-              family 23
-                trigger ../../../fc/pf/23 eq complete
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task derived_param
-              endfamily
-              family 24
-                trigger ../../../fc/pf/24 eq complete
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task derived_param
-              endfamily
-              family 25
-                trigger ../../../fc/pf/25 eq complete
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task derived_param
-              endfamily
-              family 26
-                trigger ../../../fc/pf/26 eq complete
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task derived_param
-              endfamily
-              family 27
-                trigger ../../../fc/pf/27 eq complete
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task derived_param
-              endfamily
-              family 28
-                trigger ../../../fc/pf/28 eq complete
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task derived_param
-              endfamily
-              family 29
-                trigger ../../../fc/pf/29 eq complete
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task derived_param
-              endfamily
-              family 30
-                trigger ../../../fc/pf/30 eq complete
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task derived_param
-              endfamily
-              family 31
-                trigger ../../../fc/pf/31 eq complete
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task derived_param
-              endfamily
-              family 32
-                trigger ../../../fc/pf/32 eq complete
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task derived_param
-              endfamily
-              family 33
-                trigger ../../../fc/pf/33 eq complete
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task derived_param
-              endfamily
-              family 34
-                trigger ../../../fc/pf/34 eq complete
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task derived_param
-              endfamily
-              family 35
-                trigger ../../../fc/pf/35 eq complete
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task derived_param
-              endfamily
-              family 36
-                trigger ../../../fc/pf/36 eq complete
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task derived_param
-              endfamily
-              family 37
-                trigger ../../../fc/pf/37 eq complete
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task derived_param
-              endfamily
-              family 38
-                trigger ../../../fc/pf/38 eq complete
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task derived_param
-              endfamily
-              family 39
-                trigger ../../../fc/pf/39 eq complete
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task derived_param
-              endfamily
-              family 40
-                trigger ../../../fc/pf/40 eq complete
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task derived_param
-              endfamily
-              family 41
-                trigger ../../../fc/pf/41 eq complete
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task derived_param
-              endfamily
-              family 42
-                trigger ../../../fc/pf/42 eq complete
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task derived_param
-              endfamily
-              family 43
-                trigger ../../../fc/pf/43 eq complete
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task derived_param
-              endfamily
-              family 44
-                trigger ../../../fc/pf/44 eq complete
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task derived_param
-              endfamily
-              family 45
-                trigger ../../../fc/pf/45 eq complete
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task derived_param
-              endfamily
-              family 46
-                trigger ../../../fc/pf/46 eq complete
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task derived_param
-              endfamily
-              family 47
-                trigger ../../../fc/pf/47 eq complete
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task derived_param
-              endfamily
-              family 48
-                trigger ../../../fc/pf/48 eq complete
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task derived_param
-              endfamily
-              family 49
-                trigger ../../../fc/pf/49 eq complete
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task derived_param
-              endfamily
-              family 50
-                trigger ../../../fc/pf/50 eq complete
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task derived_param
-              endfamily
-            endfamily
-          endfamily
-          family extra
-            trigger ./dp eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '246:360:6'
-            inlimit /emc_36r1/limits:extra
-            family cf
-              edit EMOS_TYPE 'cf'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '360'
-                edit FCLENGTH0 '240'
-                edit RUNVARFC '1'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/12/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 05
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 06
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 07
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 08
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 09
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 10
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 11
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 12
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 13
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 14
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 15
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 16
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 17
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 18
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 19
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 20
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 21
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 22
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 23
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 24
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 25
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 26
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 27
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 28
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 29
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 30
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 31
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 32
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 33
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 34
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 35
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 36
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 37
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 38
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 39
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 40
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 41
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 42
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 43
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 44
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 45
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 46
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 47
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 48
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 49
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 50
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-            endfamily
-          endfamily
-          family calibrate
-            complete /emc_36r1/main/ref/12/events:cf
-            trigger /emc_36r1/main/12/ref/an eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
-            family onws
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              inlimit /limits:linux_cluster
-              task feedupcal
-              task upcal
-                trigger feedupcal eq complete
-              task revertupcal
-            endfamily
-          endfamily
-          family efi
-            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
-            trigger /emc_36r1/main/12/legB/postproc/dp eq complete
-            edit HC_VERSION '0046'
-            edit HC_EXPVER '0046'
-            edit REF_VERSION '0046'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            edit NC_DAYS '31'
-            edit EPSLEG '2'
-            inlimit /emc_36r1/limits:efi
-            task stage
-              edit NC_DAYS '31'
-            family 228_324
-              trigger ./stage eq complete
-              edit ACC '96'
-              edit EFI_STEP1 '228'
-              edit EFI_STEP2 '324'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 168_336
-              trigger ./stage eq complete
-              edit ACC '168'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '336'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 000_024
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 024_048
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 048_072
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 072_096
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 096_120
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 120_144
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 108_156
-              trigger ./stage eq complete
-              edit ACC '48'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '156'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 156_228
-              trigger ./stage eq complete
-              edit ACC '72'
-              edit EFI_STEP1 '156'
-              edit EFI_STEP2 '228'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 000_168
-              trigger ./stage eq complete
-              edit ACC '168'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 012_036
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 036_060
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 060_084
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 084_108
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 108_132
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-          endfamily
-          task efi2fdb
-            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
-            trigger ./efi eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            inlimit /emc_36r1/main/ref:mutex
-            event none
-        endfamily
-        family prod
-          edit MEM '3000'
-          edit ACCOUNT 'oeenfopg'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'cp'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '90'
-          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
-          edit SMSURL 'sub=fixed/'
-          inlimit /limits:prod
-          family eps
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            inlimit /emc_36r1/limits:prodeps
-            family 0246
-              edit EMOS_TIME_STEP_H '0246'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0252
-              edit EMOS_TIME_STEP_H '0252'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0258
-              edit EMOS_TIME_STEP_H '0258'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0264
-              edit EMOS_TIME_STEP_H '0264'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0270
-              edit EMOS_TIME_STEP_H '0270'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0276
-              edit EMOS_TIME_STEP_H '0276'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0282
-              edit EMOS_TIME_STEP_H '0282'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0288
-              edit EMOS_TIME_STEP_H '0288'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0294
-              edit EMOS_TIME_STEP_H '0294'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0300
-              edit EMOS_TIME_STEP_H '0300'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0306
-              edit EMOS_TIME_STEP_H '0306'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0312
-              edit EMOS_TIME_STEP_H '0312'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0318
-              edit EMOS_TIME_STEP_H '0318'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0324
-              edit EMOS_TIME_STEP_H '0324'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0330
-              edit EMOS_TIME_STEP_H '0330'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0336
-              edit EMOS_TIME_STEP_H '0336'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0342
-              edit EMOS_TIME_STEP_H '0342'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0348
-              edit EMOS_TIME_STEP_H '0348'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0354
-              edit EMOS_TIME_STEP_H '0354'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0360
-              edit EMOS_TIME_STEP_H '0360'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-          endfamily
-          family wave
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            edit PGNPES '2'
-            edit URL 'GWAEF/12'
-            inlimit /emc_36r1/limits:prodwave
-            family 0246
-              edit EMOS_TIME_STEP_H '0246'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0252
-              edit EMOS_TIME_STEP_H '0252'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0258
-              edit EMOS_TIME_STEP_H '0258'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0264
-              edit EMOS_TIME_STEP_H '0264'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0270
-              edit EMOS_TIME_STEP_H '0270'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0276
-              edit EMOS_TIME_STEP_H '0276'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0282
-              edit EMOS_TIME_STEP_H '0282'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0288
-              edit EMOS_TIME_STEP_H '0288'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0294
-              edit EMOS_TIME_STEP_H '0294'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0300
-              edit EMOS_TIME_STEP_H '0300'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0306
-              edit EMOS_TIME_STEP_H '0306'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0312
-              edit EMOS_TIME_STEP_H '0312'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0318
-              edit EMOS_TIME_STEP_H '0318'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0324
-              edit EMOS_TIME_STEP_H '0324'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0330
-              edit EMOS_TIME_STEP_H '0330'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0336
-              edit EMOS_TIME_STEP_H '0336'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0342
-              edit EMOS_TIME_STEP_H '0342'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0348
-              edit EMOS_TIME_STEP_H '0348'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0354
-              edit EMOS_TIME_STEP_H '0354'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0360
-              edit EMOS_TIME_STEP_H '0360'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-          endfamily
-          task prod_wparam
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and ../../legA/prod/prod_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TYPE 'wp'
-            edit EMOS_TIME_STEP_H '0360'
-            edit PGNPES '52'
-          task enfo_postproc
-            late -s +00:05 -c +00:15
-            trigger ../postproc/prob eq complete and ../postproc/ensms eq complete and ( ../../legA/prod/getreq/eps eq complete)
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'ep'
-            edit EMOS_TIME_STEP_H '0360'
-            edit PGNPES '21'
-          task waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TIME_STEP_H '0360'
-            edit PGNPES '1'
-        endfamily
-        family prod2diss
-          edit USER_PRIORITY '90'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'ef'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-          edit SMSURL 'GENFO/12'
-          family eps
-            family 0246
-              edit EMOS_TIME_STEP_H '0246'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0246/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../../../../legA/prod2diss/eps//0240/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0252
-              edit EMOS_TIME_STEP_H '0252'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0252/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0246/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0258
-              edit EMOS_TIME_STEP_H '0258'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0258/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0252/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0264
-              edit EMOS_TIME_STEP_H '0264'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0264/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0258/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0270
-              edit EMOS_TIME_STEP_H '0270'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0270/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0264/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0276
-              edit EMOS_TIME_STEP_H '0276'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0276/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0270/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0282
-              edit EMOS_TIME_STEP_H '0282'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0282/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0276/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0288
-              edit EMOS_TIME_STEP_H '0288'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0288/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0282/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0294
-              edit EMOS_TIME_STEP_H '0294'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0294/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0288/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0300
-              edit EMOS_TIME_STEP_H '0300'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0300/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0294/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0306
-              edit EMOS_TIME_STEP_H '0306'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0306/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0300/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0312
-              edit EMOS_TIME_STEP_H '0312'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0312/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0306/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0318
-              edit EMOS_TIME_STEP_H '0318'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0318/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0312/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0324
-              edit EMOS_TIME_STEP_H '0324'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0324/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0318/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0330
-              edit EMOS_TIME_STEP_H '0330'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0330/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0324/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0336
-              edit EMOS_TIME_STEP_H '0336'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0336/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0330/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0342
-              edit EMOS_TIME_STEP_H '0342'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0342/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0336/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0348
-              edit EMOS_TIME_STEP_H '0348'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0348/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0342/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0354
-              edit EMOS_TIME_STEP_H '0354'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0354/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0348/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0360
-              edit EMOS_TIME_STEP_H '0360'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0360/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0354/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            task check
-              trigger ./0360 eq complete
-          endfamily
-          family wave
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TYPE 'we'
-            edit SMSURL 'GWAEF/12'
-            family 0246
-              trigger ../../prod/wave/0246/prodwave eq complete and ( ../../../legA/prod2diss/wave/0240 eq complete)
-              edit EMOS_TIME_STEP_H '0246'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0252
-              trigger ../../prod/wave/0252/prodwave eq complete and ( ./0246 eq complete)
-              edit EMOS_TIME_STEP_H '0252'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0258
-              trigger ../../prod/wave/0258/prodwave eq complete and ( ./0252 eq complete)
-              edit EMOS_TIME_STEP_H '0258'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0264
-              trigger ../../prod/wave/0264/prodwave eq complete and ( ./0258 eq complete)
-              edit EMOS_TIME_STEP_H '0264'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0270
-              trigger ../../prod/wave/0270/prodwave eq complete and ( ./0264 eq complete)
-              edit EMOS_TIME_STEP_H '0270'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0276
-              trigger ../../prod/wave/0276/prodwave eq complete and ( ./0270 eq complete)
-              edit EMOS_TIME_STEP_H '0276'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0282
-              trigger ../../prod/wave/0282/prodwave eq complete and ( ./0276 eq complete)
-              edit EMOS_TIME_STEP_H '0282'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0288
-              trigger ../../prod/wave/0288/prodwave eq complete and ( ./0282 eq complete)
-              edit EMOS_TIME_STEP_H '0288'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0294
-              trigger ../../prod/wave/0294/prodwave eq complete and ( ./0288 eq complete)
-              edit EMOS_TIME_STEP_H '0294'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0300
-              trigger ../../prod/wave/0300/prodwave eq complete and ( ./0294 eq complete)
-              edit EMOS_TIME_STEP_H '0300'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0306
-              trigger ../../prod/wave/0306/prodwave eq complete and ( ./0300 eq complete)
-              edit EMOS_TIME_STEP_H '0306'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0312
-              trigger ../../prod/wave/0312/prodwave eq complete and ( ./0306 eq complete)
-              edit EMOS_TIME_STEP_H '0312'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0318
-              trigger ../../prod/wave/0318/prodwave eq complete and ( ./0312 eq complete)
-              edit EMOS_TIME_STEP_H '0318'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0324
-              trigger ../../prod/wave/0324/prodwave eq complete and ( ./0318 eq complete)
-              edit EMOS_TIME_STEP_H '0324'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0330
-              trigger ../../prod/wave/0330/prodwave eq complete and ( ./0324 eq complete)
-              edit EMOS_TIME_STEP_H '0330'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0336
-              trigger ../../prod/wave/0336/prodwave eq complete and ( ./0330 eq complete)
-              edit EMOS_TIME_STEP_H '0336'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0342
-              trigger ../../prod/wave/0342/prodwave eq complete and ( ./0336 eq complete)
-              edit EMOS_TIME_STEP_H '0342'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0348
-              trigger ../../prod/wave/0348/prodwave eq complete and ( ./0342 eq complete)
-              edit EMOS_TIME_STEP_H '0348'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0354
-              trigger ../../prod/wave/0354/prodwave eq complete and ( ./0348 eq complete)
-              edit EMOS_TIME_STEP_H '0354'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0360
-              trigger ../../prod/wave/0360/prodwave eq complete and ( ./0354 eq complete)
-              edit EMOS_TIME_STEP_H '0360'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            task check
-              trigger ./0360 eq complete
-          endfamily
-          task diss_wparam
-            late -s +00:05 -c +00:15
-            trigger ../prod/prod_wparam eq complete and ../../legA/prod2diss/diss_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TIME_STEP_H '0360'
-            edit EMOS_TYPE 'wp'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/waef_postproc eq complete and ../../legA/prod2diss/diss_waef_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0360'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/enfo_postproc eq complete and ../../legA/prod2diss/diss_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0360'
-            edit EMOS_TYPE 'ep'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-        endfamily
-      endfamily
-    endfamily
-    family 00
-      trigger ( ./make eq complete) and ( ./inistage eq complete)
-      edit DELTA_DAY '1'
-      edit EMOS_BASE '00'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-      family ref
-        trigger ../make eq complete and ( /emc_36r1/main:YMD le /e_36r1/main:YMD)
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit QUEUE 'emos-exp'
-        limit mutex 1
-        task an
-          trigger /e_36r1/main/00/an eq complete
-        task anfc
-          complete ( ( /e_36r1/main/00/an/surf_anal/slwet eq complete and ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar eq complete)) or /e_36r1/main/00/an eq complete)
-          trigger 0 eq 1
-        task model_active
-          trigger /e_36r1/main/00/fc/model eq active or /e_36r1/main/00/fc/model eq complete
-        task an_active
-          trigger /e_36r1/main/00/an/4dvar/uptraj_0 eq active or /e_36r1/main/00/an/4dvar/uptraj_0 eq complete
-        task model
-          trigger /e_36r1/main/00/fc/model eq complete
-        family oceini
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-          inlimit /emc_36r1/limits:marsret
-          time 23:45
-          task dummy
-        endfamily
-        task dc
-          trigger /e_36r1/main/12dc/fc/model:step ge 12 or /e_36r1/main/12dc/fc/model eq complete
-        task obs
-          trigger /e_36r1/main/00/obs/get/get_stor eq complete
-      endfamily
-      family sv
-        trigger ./ref/dc eq complete and ./ref/an_active eq complete
-        edit EVOLVE 'no'
-        edit FASTEX 'no'
-        edit EPSTYPE 'sv'
-        edit FCMEM '2000'
-        edit FCSTACK '400'
-        edit FCMRFS '100'
-        edit FCLENGTH '48'
-        edit EPSSVTCSUB '1'
-        edit EPSSVOP '1'
-        edit NPES '16'
-        edit EPSSVTSTEP '900'
-        task getini
-          edit LINIENDA '0'
-          edit INIDATEENDA '0'
-          edit EPSCOUPLE '0'
-          edit N_PERT_AN '10'
-          edit EPSCOUPL_A '0'
-          edit EPSCOUPL_B '0'
-          edit EPSCOUPL_C '0'
-        task inidata_sv
-          trigger getini eq complete
-          edit THREADS '8'
-        task targets
-          late -s +00:03 -c +00:10
-          trigger ../ref/obs eq complete
-          edit EPSTCBB '1'
-          label da_info ""
-          label dcda_info ""
-          event sv
-        task svsh
-          trigger inidata_sv eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit THREADS '8'
-          edit USER_PRIORITY '73'
-        task svnh
-          trigger inidata_sv eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit THREADS '8'
-          edit USER_PRIORITY '74'
-        task subspace
-          trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-        task sv1
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '1'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-          edit USER_PRIORITY '72'
-        task sv2
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '2'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-          edit USER_PRIORITY '71'
-        task sv3
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '3'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task sv4
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '4'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task sv5
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '5'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task sv6
-          trigger ( targets eq complete or targets:sv) and subspace eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          edit MEMBER '6'
-          edit EPSTROP '1'
-          edit EPSSVDIAB 'true'
-          edit THREADS '8'
-        task getsvevo
-          event ecfs
-        task getsvs
-          trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit EPSTROP '1'
-        task sv_value
-          trigger getsvs eq complete
-          inlimit /emc_36r1/main/ref:mutex
-        task svnhevo
-          trigger svnh eq complete and ../legA/fc eq complete
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit STACK '350'
-          edit HEMISPHERE 'n'
-          edit EVOLVE 'yes'
-          edit ANNPES '8'
-          edit CPUTIME '120000'
-        task svshevo
-          trigger svsh eq complete and ../legA/fc eq complete
-          edit NPES '24'
-          edit THREADS '8'
-          edit MEM '1300'
-          edit MRF '10'
-          edit STACK '450'
-          edit EVOLVE 'yes'
-          edit ANNPES '8'
-          edit CPUTIME '120000'
-        task clean
-          trigger ../legA/fc eq complete and svnhevo eq complete and svshevo eq complete
-        task dcopy
-          trigger clean eq complete
-          edit SMSFILES '/home/ma/emos/def/o/system'
-      endfamily
-      family legA
-        edit EPSLEG '1'
-        family fc
-          trigger /emc_36r1/main/00/ref/anfc eq complete
-          edit FCMEM '2240'
-          edit FCSTACK '700'
-          edit FCMRFS '0'
-          edit PRIORITY '72'
-          edit USER_PRIORITY '72'
-          edit N_PERT_AN '10'
-          edit SSTLEN '240'
-          edit EPSINISTEP_PREVIOUS '0'
-          edit EPSWAMNFRE '30'
-          edit EPSWAMNANG '24'
-          edit TSTEP '1200'
-          edit EPSFCRES '639'
-          edit RESOL '639'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit CPUTIME '1000'
-          edit MEM '960'
-          edit THREADS '8'
-          edit NPES '8'
-          edit EPSLEG '1'
-          edit PERSST 'true'
-          edit SSTINT '1'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata
-            trigger getini eq complete
-            edit THREADS '8'
-          task getae
-            event 1 
-          task rot
-            trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-            edit EPSTROP '1'
-          family pert_ic
-            trigger rot eq complete and inidata eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-            inlimit /emc_36r1/limits:pertic
-            family 00
-              task pertinic
-                edit MEMBER '0'
-            endfamily
-            family 01
-              task pertinic
-                edit MEMBER '1'
-            endfamily
-            family 02
-              task pertinic
-                edit MEMBER '2'
-            endfamily
-            family 03
-              task pertinic
-                edit MEMBER '3'
-            endfamily
-            family 04
-              task pertinic
-                edit MEMBER '4'
-            endfamily
-            family 05
-              task pertinic
-                edit MEMBER '5'
-            endfamily
-            family 06
-              task pertinic
-                edit MEMBER '6'
-            endfamily
-            family 07
-              task pertinic
-                edit MEMBER '7'
-            endfamily
-            family 08
-              task pertinic
-                edit MEMBER '8'
-            endfamily
-            family 09
-              task pertinic
-                edit MEMBER '9'
-            endfamily
-            family 10
-              task pertinic
-                edit MEMBER '10'
-            endfamily
-            family 11
-              task pertinic
-                edit MEMBER '11'
-            endfamily
-            family 12
-              task pertinic
-                edit MEMBER '12'
-            endfamily
-            family 13
-              task pertinic
-                edit MEMBER '13'
-            endfamily
-            family 14
-              task pertinic
-                edit MEMBER '14'
-            endfamily
-            family 15
-              task pertinic
-                edit MEMBER '15'
-            endfamily
-            family 16
-              task pertinic
-                edit MEMBER '16'
-            endfamily
-            family 17
-              task pertinic
-                edit MEMBER '17'
-            endfamily
-            family 18
-              task pertinic
-                edit MEMBER '18'
-            endfamily
-            family 19
-              task pertinic
-                edit MEMBER '19'
-            endfamily
-            family 20
-              task pertinic
-                edit MEMBER '20'
-            endfamily
-            family 21
-              task pertinic
-                edit MEMBER '21'
-            endfamily
-            family 22
-              task pertinic
-                edit MEMBER '22'
-            endfamily
-            family 23
-              task pertinic
-                edit MEMBER '23'
-            endfamily
-            family 24
-              task pertinic
-                edit MEMBER '24'
-            endfamily
-            family 25
-              task pertinic
-                edit MEMBER '25'
-            endfamily
-            family 26
-              task pertinic
-                edit MEMBER '26'
-            endfamily
-            family 27
-              task pertinic
-                edit MEMBER '27'
-            endfamily
-            family 28
-              task pertinic
-                edit MEMBER '28'
-            endfamily
-            family 29
-              task pertinic
-                edit MEMBER '29'
-            endfamily
-            family 30
-              task pertinic
-                edit MEMBER '30'
-            endfamily
-            family 31
-              task pertinic
-                edit MEMBER '31'
-            endfamily
-            family 32
-              task pertinic
-                edit MEMBER '32'
-            endfamily
-            family 33
-              task pertinic
-                edit MEMBER '33'
-            endfamily
-            family 34
-              task pertinic
-                edit MEMBER '34'
-            endfamily
-            family 35
-              task pertinic
-                edit MEMBER '35'
-            endfamily
-            family 36
-              task pertinic
-                edit MEMBER '36'
-            endfamily
-            family 37
-              task pertinic
-                edit MEMBER '37'
-            endfamily
-            family 38
-              task pertinic
-                edit MEMBER '38'
-            endfamily
-            family 39
-              task pertinic
-                edit MEMBER '39'
-            endfamily
-            family 40
-              task pertinic
-                edit MEMBER '40'
-            endfamily
-            family 41
-              task pertinic
-                edit MEMBER '41'
-            endfamily
-            family 42
-              task pertinic
-                edit MEMBER '42'
-            endfamily
-            family 43
-              task pertinic
-                edit MEMBER '43'
-            endfamily
-            family 44
-              task pertinic
-                edit MEMBER '44'
-            endfamily
-            family 45
-              task pertinic
-                edit MEMBER '45'
-            endfamily
-            family 46
-              task pertinic
-                edit MEMBER '46'
-            endfamily
-            family 47
-              task pertinic
-                edit MEMBER '47'
-            endfamily
-            family 48
-              task pertinic
-                edit MEMBER '48'
-            endfamily
-            family 49
-              task pertinic
-                edit MEMBER '49'
-            endfamily
-            family 50
-              task pertinic
-                edit MEMBER '50'
-            endfamily
-          endfamily
-          task cp_pert
-            trigger pert_ic eq complete
-            event 1 
-          task wavini
-            trigger /emc_36r1/main/00/ref/an eq complete
-            edit FSFAMILY 'mc'
-          family cv
-            trigger ./pert_ic/00 eq complete and ./inidata eq complete and ./wavini eq complete and /emc_36r1/main/00/ref/model_active eq complete
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit EPSFCRES '639'
-            edit TSTEP '1200'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit CLASS 'od'
-            edit PERSST 'no'
-            edit EPSTYPE 'cv'
-            edit EMOS_TYPE 'cv'
-            edit EPSNLEGS '1'
-            edit EPSLEG '1'
-            edit EPSINISTEP '360'
-            edit FCLENGTH '360'
-            edit USER_PRIORITY '73'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            inlimit /emc_36r1/limits:pftotal
-            family control_1
-              edit MEMBER '1'
-              edit EPSMEMBER '1'
-              edit SUBFSFAMILY '/cv001'
-              task getiniLeg
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit FCNPES '32'
-                edit THREADS '4'
-                meter step -1 360 360
-              task derived_param
-                trigger modeleps eq complete
-                edit STEPS '0:144:3 144:360:6'
-            endfamily
-            family control_2
-              edit MEMBER '2'
-              edit EPSMEMBER '2'
-              edit SUBFSFAMILY '/cv002'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              task getiniLeg
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task intHtoL
-                trigger getiniLeg eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '1200'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                meter step -1 360 360
-              task derived_param
-                trigger modeleps eq complete
-                edit STEPS '0:144:3 144:360:6'
-            endfamily
-          endfamily
-          task wavfcdata
-            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-            edit EPSCOUPLE '1'
-          task getpersSST
-            trigger ./inidata eq complete
-            edit EPSCOUPLE '1'
-            edit EPS_INI_STREAM 'DA'
-            edit EPSFCRES '639'
-          family pf
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete and ../../ref/model_active eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTYPE 'pf'
-            edit EMOS_TYPE 'pf'
-            edit USER_PRIORITY '72'
-            edit PRIORITY '72'
-            edit FCNPES '64'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit EPSFCRES '639'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit EPSINISTEP '216'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '1'
-            edit CLASS 'od'
-            inlimit /emc_36r1/limits:pftotal
-            meter step -1 240 240
-            family 01
-              edit EPSMEMBER '1'
-              edit MEMBER '1'
-              edit SUBFSFAMILY '/pf001'
-              task getiniLeg
-                trigger ../../pert_ic/01/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 02
-              edit EPSMEMBER '2'
-              edit MEMBER '2'
-              edit SUBFSFAMILY '/pf002'
-              task getiniLeg
-                trigger ../../pert_ic/02/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 03
-              edit EPSMEMBER '3'
-              edit MEMBER '3'
-              edit SUBFSFAMILY '/pf003'
-              task getiniLeg
-                trigger ../../pert_ic/03/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 04
-              edit EPSMEMBER '4'
-              edit MEMBER '4'
-              edit SUBFSFAMILY '/pf004'
-              task getiniLeg
-                trigger ../../pert_ic/04/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 05
-              edit EPSMEMBER '5'
-              edit MEMBER '5'
-              edit SUBFSFAMILY '/pf005'
-              task getiniLeg
-                trigger ../../pert_ic/05/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 06
-              edit EPSMEMBER '6'
-              edit MEMBER '6'
-              edit SUBFSFAMILY '/pf006'
-              task getiniLeg
-                trigger ../../pert_ic/06/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 07
-              edit EPSMEMBER '7'
-              edit MEMBER '7'
-              edit SUBFSFAMILY '/pf007'
-              task getiniLeg
-                trigger ../../pert_ic/07/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 08
-              edit EPSMEMBER '8'
-              edit MEMBER '8'
-              edit SUBFSFAMILY '/pf008'
-              task getiniLeg
-                trigger ../../pert_ic/08/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 09
-              edit EPSMEMBER '9'
-              edit MEMBER '9'
-              edit SUBFSFAMILY '/pf009'
-              task getiniLeg
-                trigger ../../pert_ic/09/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 10
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              edit SUBFSFAMILY '/pf010'
-              task getiniLeg
-                trigger ../../pert_ic/10/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 11
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              edit SUBFSFAMILY '/pf011'
-              task getiniLeg
-                trigger ../../pert_ic/11/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 12
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              edit SUBFSFAMILY '/pf012'
-              task getiniLeg
-                trigger ../../pert_ic/12/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 13
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              edit SUBFSFAMILY '/pf013'
-              task getiniLeg
-                trigger ../../pert_ic/13/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 14
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              edit SUBFSFAMILY '/pf014'
-              task getiniLeg
-                trigger ../../pert_ic/14/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 15
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              edit SUBFSFAMILY '/pf015'
-              task getiniLeg
-                trigger ../../pert_ic/15/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 16
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              edit SUBFSFAMILY '/pf016'
-              task getiniLeg
-                trigger ../../pert_ic/16/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 17
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              edit SUBFSFAMILY '/pf017'
-              task getiniLeg
-                trigger ../../pert_ic/17/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 18
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              edit SUBFSFAMILY '/pf018'
-              task getiniLeg
-                trigger ../../pert_ic/18/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 19
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              edit SUBFSFAMILY '/pf019'
-              task getiniLeg
-                trigger ../../pert_ic/19/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 20
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              edit SUBFSFAMILY '/pf020'
-              task getiniLeg
-                trigger ../../pert_ic/20/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 21
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              edit SUBFSFAMILY '/pf021'
-              task getiniLeg
-                trigger ../../pert_ic/21/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 22
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              edit SUBFSFAMILY '/pf022'
-              task getiniLeg
-                trigger ../../pert_ic/22/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 23
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              edit SUBFSFAMILY '/pf023'
-              task getiniLeg
-                trigger ../../pert_ic/23/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 24
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              edit SUBFSFAMILY '/pf024'
-              task getiniLeg
-                trigger ../../pert_ic/24/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 25
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              edit SUBFSFAMILY '/pf025'
-              task getiniLeg
-                trigger ../../pert_ic/25/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 26
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              edit SUBFSFAMILY '/pf026'
-              task getiniLeg
-                trigger ../../pert_ic/26/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 27
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              edit SUBFSFAMILY '/pf027'
-              task getiniLeg
-                trigger ../../pert_ic/27/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 28
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              edit SUBFSFAMILY '/pf028'
-              task getiniLeg
-                trigger ../../pert_ic/28/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 29
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              edit SUBFSFAMILY '/pf029'
-              task getiniLeg
-                trigger ../../pert_ic/29/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 30
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              edit SUBFSFAMILY '/pf030'
-              task getiniLeg
-                trigger ../../pert_ic/30/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 31
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              edit SUBFSFAMILY '/pf031'
-              task getiniLeg
-                trigger ../../pert_ic/31/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 32
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              edit SUBFSFAMILY '/pf032'
-              task getiniLeg
-                trigger ../../pert_ic/32/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 33
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              edit SUBFSFAMILY '/pf033'
-              task getiniLeg
-                trigger ../../pert_ic/33/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 34
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              edit SUBFSFAMILY '/pf034'
-              task getiniLeg
-                trigger ../../pert_ic/34/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 35
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              edit SUBFSFAMILY '/pf035'
-              task getiniLeg
-                trigger ../../pert_ic/35/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 36
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              edit SUBFSFAMILY '/pf036'
-              task getiniLeg
-                trigger ../../pert_ic/36/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 37
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              edit SUBFSFAMILY '/pf037'
-              task getiniLeg
-                trigger ../../pert_ic/37/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 38
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              edit SUBFSFAMILY '/pf038'
-              task getiniLeg
-                trigger ../../pert_ic/38/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 39
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              edit SUBFSFAMILY '/pf039'
-              task getiniLeg
-                trigger ../../pert_ic/39/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 40
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              edit SUBFSFAMILY '/pf040'
-              task getiniLeg
-                trigger ../../pert_ic/40/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 41
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              edit SUBFSFAMILY '/pf041'
-              task getiniLeg
-                trigger ../../pert_ic/41/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 42
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              edit SUBFSFAMILY '/pf042'
-              task getiniLeg
-                trigger ../../pert_ic/42/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 43
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              edit SUBFSFAMILY '/pf043'
-              task getiniLeg
-                trigger ../../pert_ic/43/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 44
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              edit SUBFSFAMILY '/pf044'
-              task getiniLeg
-                trigger ../../pert_ic/44/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 45
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              edit SUBFSFAMILY '/pf045'
-              task getiniLeg
-                trigger ../../pert_ic/45/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 46
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              edit SUBFSFAMILY '/pf046'
-              task getiniLeg
-                trigger ../../pert_ic/46/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 47
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              edit SUBFSFAMILY '/pf047'
-              task getiniLeg
-                trigger ../../pert_ic/47/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 48
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              edit SUBFSFAMILY '/pf048'
-              task getiniLeg
-                trigger ../../pert_ic/48/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 49
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              edit SUBFSFAMILY '/pf049'
-              task getiniLeg
-                trigger ../../pert_ic/49/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-            family 50
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              edit SUBFSFAMILY '/pf050'
-              task getiniLeg
-                trigger ../../pert_ic/50/pertinic eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:modelepsA
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family cf
-            trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete and /emc_36r1/main/00/ref/model_active eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit MEMBER '0'
-            edit EPSMEMBER '0'
-            edit SUBFSFAMILY '/cf000'
-            edit EPSTYPE 'cf'
-            edit EMOS_TYPE 'cf'
-            edit USER_PRIORITY '73'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMRESOL 'global50'
-            edit EPSFCRES '639'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit EPSINISTEP '216'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '1'
-            edit CLASS 'od'
-            task getiniLeg
-              trigger ../inidata eq complete and ../wavini eq complete
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task modeleps
-              trigger getiniLeg eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSLEG '1'
-              edit EPSFCRES '639'
-              edit EPSINISTEP '216'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit CLASS 'od'
-              edit FCNPES '32'
-              edit THREADS '4'
-              meter step -1 240 240
-          endfamily
-          family reservation1
-            trigger ./pf/01/modeleps eq active or ./pf/01/modeleps eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reserve_cpu
-              late -s +00:02 -c +00:02
-              edit RESERVED_CPUS '10880'
-              edit RESERVE_FOR '40'
-              label info ""
-            task rm_res
-              late -s +00:02 -c +00:02
-              trigger ./reserve_cpu eq complete
-              edit RESERVATION_LABEL 'emos00'
-              label info ""
-          endfamily
-          family reservation2
-            trigger ( ./pf/46/modeleps eq active or ./pf/46/modeleps eq complete) and ( ./pf/47/modeleps eq active or ./pf/47/modeleps eq complete) and ( ./pf/48/modeleps eq active or ./pf/48/modeleps eq complete) and ( ./pf/49/modeleps eq active or ./pf/49/modeleps eq complete) and ( ./pf/50/modeleps eq active or ./pf/50/modeleps eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reset_class
-              late -s +00:02 -c +00:02
-              edit RESERVATION_DEFINITION 'default'
-              label info ""
-            task ms_cpu
-              late -s +00:02 -c +00:02
-              edit MS_CPUS '$((64*80))'
-              label info ""
-            task reserve_cpu
-              late -s +00:02 -c +00:02
-              complete /emc_36r1/main/ref/00/events:768
-              edit RESERVED_CPUS '6400'
-              edit RESERVE_FOR '40'
-              label info ""
-            task reserve_cpu1
-              late -s +00:02 -c +00:02
-              complete ( /emc_36r1/main/ref/00/events eq complete) and ( not /emc_36r1/main/ref/00/events:768)
-              edit RESERVED_CPUS '6400'
-              edit RESERVE_FOR '100'
-              label info ""
-          endfamily
-          family reservation3
-            trigger ( ./pf eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reserve_cpu
-              late -s +00:02 -c +00:02
-              complete /emc_36r1/main/ref/00/events:768
-              edit RESERVED_CPUS '3200'
-              edit RESERVE_FOR '30'
-              label info ""
-            task reserve_cpu1
-              late -s +00:02 -c +00:02
-              complete ( /emc_36r1/main/ref/00/events eq complete) and ( not /emc_36r1/main/ref/00/events:768)
-              edit RESERVED_CPUS '3200'
-              edit RESERVE_FOR '80'
-              label info ""
-          endfamily
-        endfamily
-        family fax
-          trigger /emc_36r1/main/00/ref/an eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-          task ena4
-            trigger ../postproc/clusters eq complete and ../postproc/ensms eq complete
-            edit ANALYSIS 'NO'
-          task plume
-            trigger ../postproc/prob eq complete and /emc_36r1/main/00/ref/model eq complete
-            edit ANALYSIS 'YES'
-          task fax
-            trigger plume eq complete and ena4 eq complete
-            edit SMSTRIES '1'
-          task manfax
-            trigger plume eq complete and ena4 eq complete
-            edit SMSTRIES '1'
-            edit COUNTRY ''
-          task faxcheck
-            trigger fax eq complete
-          task faxcheck2
-            trigger fax eq complete
-            time 08:00
-        endfamily
-        family postproc
-          trigger ./fc ne queued
-          edit STEPS '24/240/12/24 168/168/12/48 240/240/12/72 240/240/12/120'
-          inlimit /emc_36r1/limits:postproc
-          family prepare
-            complete /emc_36r1/main/ref/00/events:cf
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            family all
-              complete ../../fc eq complete and ./query eq active
-              trigger ../../fc eq complete and ( ./query eq queued or ./query eq complete)
-              edit KIND 'all'
-              edit STEP '-1'
-              family t850
-                edit PARAM 'T'
-                edit LEVEL '850'
-                task pp_prep
-              endfamily
-              family t500
-                edit PARAM 'T'
-                edit LEVEL '500'
-                task pp_prep
-              endfamily
-              family z1000
-                edit PARAM 'Z'
-                edit LEVEL '1000'
-                task pp_prep
-              endfamily
-              family z500
-                edit PARAM 'Z'
-                edit LEVEL '500'
-                task pp_prep
-              endfamily
-            endfamily
-            family query
-              complete ../../fc eq complete and ../../fc/pf:step le 0
-              trigger ( ( ../../fc/pf:step ge 0) and ( ../../fc/cf/modeleps:step ge 0)) or ( ../../fc/pf eq complete and ../../fc/cf eq complete)
-              edit KIND 'query'
-              family t850
-                edit PARAM 'T'
-                edit LEVEL '850'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-              family t500
-                edit PARAM 'T'
-                edit LEVEL '500'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-              family z1000
-                edit PARAM 'Z'
-                edit LEVEL '1000'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-              family z500
-                edit PARAM 'Z'
-                edit LEVEL '500'
-                task pp_prep
-                  meter step -1 240 240
-              endfamily
-            endfamily
-          endfamily
-          family ensms
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger ( ../fc eq complete) and ( ./prepare eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            family limits
-              limit fdb 1
-              limit gen 8
-            endfamily
-            task ensms
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit ENS_MARS 'false'
-              event stage
-            family 048
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '003'
-              edit STEP2 '048'
-              edit BY '3'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 096
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '051'
-              edit STEP2 '096'
-              edit BY '3'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 144
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '099'
-              edit STEP2 '144'
-              edit BY '3'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 240
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '150'
-              edit STEP2 '240'
-              edit BY '6'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-          endfamily
-          family prob
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger /emc_36r1/main/00/legA/fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            edit STEP1 '12'
-            edit STEP2 '240'
-            edit BY '12'
-            family 24
-              edit STEP1 '24'
-              edit STEP2 '240'
-              edit BY '24'
-              family t850
-                trigger ../../prepare/all/t850 eq complete
-                family 120_240
-                  edit STEPS '120 240'
-                  task t850
-                    event 1 
-                endfamily
-                family 120_168
-                  trigger ./120_240/t850:1 or ./120_240 eq complete
-                  edit STEPS '120 168'
-                  task t850
-                    event 1 
-                endfamily
-                family 168_240
-                  trigger ./120_240/t850:1 or ./120_240 eq complete
-                  edit STEPS '168 240'
-                  task t850
-                    event 1 
-                endfamily
-              endfamily
-              task rain
-              task ff
-            endfamily
-            family 12
-              edit STEP1 '12'
-              edit STEP2 '228'
-              edit BY '24'
-              task t850
-                trigger ../../prepare/all/t850 eq complete
-              task rain
-              task ff
-            endfamily
-            task 2t
-            task swh
-            task mwp
-            task 10fg
-              trigger ../dp eq complete
-            task prob_fdb
-              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
-          endfamily
-          family tc
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger ../fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
-            edit TCINIEXPVER '0046'
-            family obsdata
-              trigger ( /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete)
-              task retrieve
-                late -c +00:10
-                trigger ( /emc_36r1/main/00/sv/targets eq complete or /emc_36r1/main/00/sv/targets:sv)
-                label info ""
-                event notc
-              task obs
-                trigger retrieve eq complete
-            endfamily
-            family stage
-              trigger ( /emc_36r1/main/00/legA/fc eq complete)
-              task an
-              task fc
-              task pf
-              task cf
-            endfamily
-            family tracking
-              trigger obsdata/obs eq complete and stage eq complete
-              inlimit /emc_36r1/limits:tc
-              family 1
-                edit MEMBER '1'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 2
-                edit MEMBER '2'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 3
-                edit MEMBER '3'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 4
-                edit MEMBER '4'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 5
-                edit MEMBER '5'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 6
-                edit MEMBER '6'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 7
-                edit MEMBER '7'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 8
-                edit MEMBER '8'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 9
-                edit MEMBER '9'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 10
-                edit MEMBER '10'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 11
-                edit MEMBER '11'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 12
-                edit MEMBER '12'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 13
-                edit MEMBER '13'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 14
-                edit MEMBER '14'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 15
-                edit MEMBER '15'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 16
-                edit MEMBER '16'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 17
-                edit MEMBER '17'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 18
-                edit MEMBER '18'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 19
-                edit MEMBER '19'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 20
-                edit MEMBER '20'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 21
-                edit MEMBER '21'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 22
-                edit MEMBER '22'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 23
-                edit MEMBER '23'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 24
-                edit MEMBER '24'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 25
-                edit MEMBER '25'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 26
-                edit MEMBER '26'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 27
-                edit MEMBER '27'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 28
-                edit MEMBER '28'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 29
-                edit MEMBER '29'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 30
-                edit MEMBER '30'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 31
-                edit MEMBER '31'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 32
-                edit MEMBER '32'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 33
-                edit MEMBER '33'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 34
-                edit MEMBER '34'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 35
-                edit MEMBER '35'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 36
-                edit MEMBER '36'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 37
-                edit MEMBER '37'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 38
-                edit MEMBER '38'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 39
-                edit MEMBER '39'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 40
-                edit MEMBER '40'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 41
-                edit MEMBER '41'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 42
-                edit MEMBER '42'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 43
-                edit MEMBER '43'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 44
-                edit MEMBER '44'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 45
-                edit MEMBER '45'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 46
-                edit MEMBER '46'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 47
-                edit MEMBER '47'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 48
-                edit MEMBER '48'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 49
-                edit MEMBER '49'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family 50
-                edit MEMBER '50'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family cf
-                edit MEMBER '51'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-              family oper
-                edit MEMBER '52'
-                edit SLEEP '1'
-                task get_data
-                task hilo
-                  trigger get_data eq complete
-                task tracking
-                  trigger hilo eq complete
-              endfamily
-            endfamily
-            family post_process
-              task to_bufr
-                trigger ../tracking eq complete
-            endfamily
-          endfamily
-          family calibrate
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger /emc_36r1/main/00/ref/an eq complete and ../fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
-            family onsc
-              edit QUEUE 'ns'
-              edit QUEUE_EPILOG 'ns'
-              edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-              edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-              inlimit /limits:c1b
-              task feedupcal
-              task upcal
-                trigger feedupcal eq complete
-                edit Z500_EXPVER '0001'
-                edit METVIEW 'metview'
-              task revertupcal
-            endfamily
-          endfamily
-          family clusters
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger ./calibrate/onsc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/clusters'
-            edit USER_PRIORITY '81'
-            edit QUEUE 'ns'
-            edit QUEUE_EPILOG 'ns'
-            edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-            edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-            inlimit /limits:c1b
-            task cthresh
-            task cluster
-              trigger cthresh eq complete and /emc_36r1/main/00/ref/model eq complete
-              edit USER_PRIORITY '76'
-            task tubcon
-              trigger /emc_36r1/main/00/ref/model eq complete
-            task tubgen
-              late -c +00:20
-              trigger tubcon eq complete
-          endfamily
-          family efi
-            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
-            trigger /emc_36r1/main/00/legA/postproc/dp eq complete
-            edit HC_VERSION '0046'
-            edit HC_EXPVER '0046'
-            edit REF_VERSION '0046'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            edit NC_DAYS '31'
-            edit EPSLEG '1'
-            inlimit /emc_36r1/limits:efi
-            task stage
-              edit NC_DAYS '31'
-            family 000_120
-              trigger ./stage eq complete
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 024_144
-              trigger ./stage eq complete
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 000_240
-              trigger ./stage eq complete
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 000_024
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 024_048
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 048_072
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 072_096
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-            family 096_120
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-            endfamily
-          endfamily
-          task efi2fdb
-            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
-            trigger ./efi eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            inlimit /emc_36r1/main/ref:mutex
-            event none
-          family dp
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '0:144:3 144:240:6'
-            inlimit /emc_36r1/limits:dp
-            family cf
-              trigger ../../fc/cf eq complete
-              edit EMOS_TYPE 'cf'
-              task derived_param
-                edit MEMBER 'off'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/00/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                trigger ../../../fc/pf/01 eq complete
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task derived_param
-              endfamily
-              family 02
-                trigger ../../../fc/pf/02 eq complete
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task derived_param
-              endfamily
-              family 03
-                trigger ../../../fc/pf/03 eq complete
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task derived_param
-              endfamily
-              family 04
-                trigger ../../../fc/pf/04 eq complete
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task derived_param
-              endfamily
-              family 05
-                trigger ../../../fc/pf/05 eq complete
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task derived_param
-              endfamily
-              family 06
-                trigger ../../../fc/pf/06 eq complete
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task derived_param
-              endfamily
-              family 07
-                trigger ../../../fc/pf/07 eq complete
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task derived_param
-              endfamily
-              family 08
-                trigger ../../../fc/pf/08 eq complete
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task derived_param
-              endfamily
-              family 09
-                trigger ../../../fc/pf/09 eq complete
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task derived_param
-              endfamily
-              family 10
-                trigger ../../../fc/pf/10 eq complete
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task derived_param
-              endfamily
-              family 11
-                trigger ../../../fc/pf/11 eq complete
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task derived_param
-              endfamily
-              family 12
-                trigger ../../../fc/pf/12 eq complete
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task derived_param
-              endfamily
-              family 13
-                trigger ../../../fc/pf/13 eq complete
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task derived_param
-              endfamily
-              family 14
-                trigger ../../../fc/pf/14 eq complete
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task derived_param
-              endfamily
-              family 15
-                trigger ../../../fc/pf/15 eq complete
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task derived_param
-              endfamily
-              family 16
-                trigger ../../../fc/pf/16 eq complete
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task derived_param
-              endfamily
-              family 17
-                trigger ../../../fc/pf/17 eq complete
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task derived_param
-              endfamily
-              family 18
-                trigger ../../../fc/pf/18 eq complete
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task derived_param
-              endfamily
-              family 19
-                trigger ../../../fc/pf/19 eq complete
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task derived_param
-              endfamily
-              family 20
-                trigger ../../../fc/pf/20 eq complete
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task derived_param
-              endfamily
-              family 21
-                trigger ../../../fc/pf/21 eq complete
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task derived_param
-              endfamily
-              family 22
-                trigger ../../../fc/pf/22 eq complete
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task derived_param
-              endfamily
-              family 23
-                trigger ../../../fc/pf/23 eq complete
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task derived_param
-              endfamily
-              family 24
-                trigger ../../../fc/pf/24 eq complete
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task derived_param
-              endfamily
-              family 25
-                trigger ../../../fc/pf/25 eq complete
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task derived_param
-              endfamily
-              family 26
-                trigger ../../../fc/pf/26 eq complete
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task derived_param
-              endfamily
-              family 27
-                trigger ../../../fc/pf/27 eq complete
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task derived_param
-              endfamily
-              family 28
-                trigger ../../../fc/pf/28 eq complete
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task derived_param
-              endfamily
-              family 29
-                trigger ../../../fc/pf/29 eq complete
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task derived_param
-              endfamily
-              family 30
-                trigger ../../../fc/pf/30 eq complete
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task derived_param
-              endfamily
-              family 31
-                trigger ../../../fc/pf/31 eq complete
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task derived_param
-              endfamily
-              family 32
-                trigger ../../../fc/pf/32 eq complete
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task derived_param
-              endfamily
-              family 33
-                trigger ../../../fc/pf/33 eq complete
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task derived_param
-              endfamily
-              family 34
-                trigger ../../../fc/pf/34 eq complete
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task derived_param
-              endfamily
-              family 35
-                trigger ../../../fc/pf/35 eq complete
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task derived_param
-              endfamily
-              family 36
-                trigger ../../../fc/pf/36 eq complete
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task derived_param
-              endfamily
-              family 37
-                trigger ../../../fc/pf/37 eq complete
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task derived_param
-              endfamily
-              family 38
-                trigger ../../../fc/pf/38 eq complete
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task derived_param
-              endfamily
-              family 39
-                trigger ../../../fc/pf/39 eq complete
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task derived_param
-              endfamily
-              family 40
-                trigger ../../../fc/pf/40 eq complete
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task derived_param
-              endfamily
-              family 41
-                trigger ../../../fc/pf/41 eq complete
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task derived_param
-              endfamily
-              family 42
-                trigger ../../../fc/pf/42 eq complete
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task derived_param
-              endfamily
-              family 43
-                trigger ../../../fc/pf/43 eq complete
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task derived_param
-              endfamily
-              family 44
-                trigger ../../../fc/pf/44 eq complete
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task derived_param
-              endfamily
-              family 45
-                trigger ../../../fc/pf/45 eq complete
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task derived_param
-              endfamily
-              family 46
-                trigger ../../../fc/pf/46 eq complete
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task derived_param
-              endfamily
-              family 47
-                trigger ../../../fc/pf/47 eq complete
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task derived_param
-              endfamily
-              family 48
-                trigger ../../../fc/pf/48 eq complete
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task derived_param
-              endfamily
-              family 49
-                trigger ../../../fc/pf/49 eq complete
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task derived_param
-              endfamily
-              family 50
-                trigger ../../../fc/pf/50 eq complete
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task derived_param
-              endfamily
-            endfamily
-          endfamily
-          family extra
-            trigger ./dp eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '0:144:3 144:240:6'
-            inlimit /emc_36r1/limits:extra
-            family cf
-              edit EMOS_TYPE 'cf'
-              task extrafields
-                edit EPSFCRES '639'
-                edit FCLENGTH '240'
-                edit FCLENGTH0 '0'
-                edit RUNVARFC '1'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/00/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 05
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 06
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 07
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 08
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 09
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 10
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 11
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 12
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 13
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 14
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 15
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 16
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 17
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 18
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 19
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 20
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 21
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 22
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 23
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 24
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 25
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 26
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 27
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 28
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 29
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 30
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 31
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 32
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 33
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 34
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 35
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 36
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 37
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 38
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 39
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 40
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 41
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 42
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 43
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 44
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 45
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 46
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 47
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 48
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 49
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family 50
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family prod
-          edit MEM '3000'
-          edit ACCOUNT 'oeenfopg'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'cp'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '90'
-          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
-          edit SMSURL 'sub=fixed/'
-          inlimit /limits:prod
-          family eps
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            inlimit /emc_36r1/limits:prodeps
-            family 0000
-              edit EMOS_TIME_STEP_H '0000'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0003
-              edit EMOS_TIME_STEP_H '0003'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0006
-              edit EMOS_TIME_STEP_H '0006'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0009
-              edit EMOS_TIME_STEP_H '0009'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0012
-              edit EMOS_TIME_STEP_H '0012'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0015
-              edit EMOS_TIME_STEP_H '0015'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0018
-              edit EMOS_TIME_STEP_H '0018'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0021
-              edit EMOS_TIME_STEP_H '0021'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0024
-              edit EMOS_TIME_STEP_H '0024'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0027
-              edit EMOS_TIME_STEP_H '0027'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0030
-              edit EMOS_TIME_STEP_H '0030'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0033
-              edit EMOS_TIME_STEP_H '0033'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0036
-              edit EMOS_TIME_STEP_H '0036'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0039
-              edit EMOS_TIME_STEP_H '0039'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0042
-              edit EMOS_TIME_STEP_H '0042'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0045
-              edit EMOS_TIME_STEP_H '0045'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0048
-              edit EMOS_TIME_STEP_H '0048'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0051
-              edit EMOS_TIME_STEP_H '0051'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0054
-              edit EMOS_TIME_STEP_H '0054'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0057
-              edit EMOS_TIME_STEP_H '0057'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0060
-              edit EMOS_TIME_STEP_H '0060'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0063
-              edit EMOS_TIME_STEP_H '0063'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0066
-              edit EMOS_TIME_STEP_H '0066'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0069
-              edit EMOS_TIME_STEP_H '0069'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0072
-              edit EMOS_TIME_STEP_H '0072'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0075
-              edit EMOS_TIME_STEP_H '0075'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0078
-              edit EMOS_TIME_STEP_H '0078'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0081
-              edit EMOS_TIME_STEP_H '0081'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0084
-              edit EMOS_TIME_STEP_H '0084'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0087
-              edit EMOS_TIME_STEP_H '0087'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0090
-              edit EMOS_TIME_STEP_H '0090'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0093
-              edit EMOS_TIME_STEP_H '0093'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0096
-              edit EMOS_TIME_STEP_H '0096'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0099
-              edit EMOS_TIME_STEP_H '0099'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0102
-              edit EMOS_TIME_STEP_H '0102'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0105
-              edit EMOS_TIME_STEP_H '0105'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0108
-              edit EMOS_TIME_STEP_H '0108'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0111
-              edit EMOS_TIME_STEP_H '0111'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0114
-              edit EMOS_TIME_STEP_H '0114'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0117
-              edit EMOS_TIME_STEP_H '0117'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0120
-              edit EMOS_TIME_STEP_H '0120'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0123
-              edit EMOS_TIME_STEP_H '0123'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0126
-              edit EMOS_TIME_STEP_H '0126'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0129
-              edit EMOS_TIME_STEP_H '0129'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0132
-              edit EMOS_TIME_STEP_H '0132'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0135
-              edit EMOS_TIME_STEP_H '0135'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0138
-              edit EMOS_TIME_STEP_H '0138'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0141
-              edit EMOS_TIME_STEP_H '0141'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0144
-              edit EMOS_TIME_STEP_H '0144'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0150
-              edit EMOS_TIME_STEP_H '0150'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0156
-              edit EMOS_TIME_STEP_H '0156'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0162
-              edit EMOS_TIME_STEP_H '0162'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0168
-              edit EMOS_TIME_STEP_H '0168'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0174
-              edit EMOS_TIME_STEP_H '0174'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0180
-              edit EMOS_TIME_STEP_H '0180'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0186
-              edit EMOS_TIME_STEP_H '0186'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0192
-              edit EMOS_TIME_STEP_H '0192'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0198
-              edit EMOS_TIME_STEP_H '0198'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0204
-              edit EMOS_TIME_STEP_H '0204'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0210
-              edit EMOS_TIME_STEP_H '0210'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0216
-              edit EMOS_TIME_STEP_H '0216'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0222
-              edit EMOS_TIME_STEP_H '0222'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0228
-              edit EMOS_TIME_STEP_H '0228'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0234
-              edit EMOS_TIME_STEP_H '0234'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0240
-              edit EMOS_TIME_STEP_H '0240'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-          endfamily
-          family wave
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            edit PGNPES '2'
-            edit URL 'GWAEF/00'
-            inlimit /emc_36r1/limits:prodwave
-            family 0000
-              edit EMOS_TIME_STEP_H '0000'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0003
-              edit EMOS_TIME_STEP_H '0003'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0006
-              edit EMOS_TIME_STEP_H '0006'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0009
-              edit EMOS_TIME_STEP_H '0009'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0012
-              edit EMOS_TIME_STEP_H '0012'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0015
-              edit EMOS_TIME_STEP_H '0015'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0018
-              edit EMOS_TIME_STEP_H '0018'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0021
-              edit EMOS_TIME_STEP_H '0021'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0024
-              edit EMOS_TIME_STEP_H '0024'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0027
-              edit EMOS_TIME_STEP_H '0027'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0030
-              edit EMOS_TIME_STEP_H '0030'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0033
-              edit EMOS_TIME_STEP_H '0033'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0036
-              edit EMOS_TIME_STEP_H '0036'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0039
-              edit EMOS_TIME_STEP_H '0039'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0042
-              edit EMOS_TIME_STEP_H '0042'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0045
-              edit EMOS_TIME_STEP_H '0045'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0048
-              edit EMOS_TIME_STEP_H '0048'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0051
-              edit EMOS_TIME_STEP_H '0051'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0054
-              edit EMOS_TIME_STEP_H '0054'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0057
-              edit EMOS_TIME_STEP_H '0057'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0060
-              edit EMOS_TIME_STEP_H '0060'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0063
-              edit EMOS_TIME_STEP_H '0063'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0066
-              edit EMOS_TIME_STEP_H '0066'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0069
-              edit EMOS_TIME_STEP_H '0069'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0072
-              edit EMOS_TIME_STEP_H '0072'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0075
-              edit EMOS_TIME_STEP_H '0075'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0078
-              edit EMOS_TIME_STEP_H '0078'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0081
-              edit EMOS_TIME_STEP_H '0081'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0084
-              edit EMOS_TIME_STEP_H '0084'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0087
-              edit EMOS_TIME_STEP_H '0087'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0090
-              edit EMOS_TIME_STEP_H '0090'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0093
-              edit EMOS_TIME_STEP_H '0093'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0096
-              edit EMOS_TIME_STEP_H '0096'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0099
-              edit EMOS_TIME_STEP_H '0099'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0102
-              edit EMOS_TIME_STEP_H '0102'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0105
-              edit EMOS_TIME_STEP_H '0105'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0108
-              edit EMOS_TIME_STEP_H '0108'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0111
-              edit EMOS_TIME_STEP_H '0111'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0114
-              edit EMOS_TIME_STEP_H '0114'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0117
-              edit EMOS_TIME_STEP_H '0117'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0120
-              edit EMOS_TIME_STEP_H '0120'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0123
-              edit EMOS_TIME_STEP_H '0123'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0126
-              edit EMOS_TIME_STEP_H '0126'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0129
-              edit EMOS_TIME_STEP_H '0129'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0132
-              edit EMOS_TIME_STEP_H '0132'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0135
-              edit EMOS_TIME_STEP_H '0135'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0138
-              edit EMOS_TIME_STEP_H '0138'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0141
-              edit EMOS_TIME_STEP_H '0141'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0144
-              edit EMOS_TIME_STEP_H '0144'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0150
-              edit EMOS_TIME_STEP_H '0150'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0156
-              edit EMOS_TIME_STEP_H '0156'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0162
-              edit EMOS_TIME_STEP_H '0162'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0168
-              edit EMOS_TIME_STEP_H '0168'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0174
-              edit EMOS_TIME_STEP_H '0174'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0180
-              edit EMOS_TIME_STEP_H '0180'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0186
-              edit EMOS_TIME_STEP_H '0186'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0192
-              edit EMOS_TIME_STEP_H '0192'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0198
-              edit EMOS_TIME_STEP_H '0198'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0204
-              edit EMOS_TIME_STEP_H '0204'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0210
-              edit EMOS_TIME_STEP_H '0210'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0216
-              edit EMOS_TIME_STEP_H '0216'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0222
-              edit EMOS_TIME_STEP_H '0222'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0228
-              edit EMOS_TIME_STEP_H '0228'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0234
-              edit EMOS_TIME_STEP_H '0234'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0240
-              edit EMOS_TIME_STEP_H '0240'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-          endfamily
-          family getreq
-            trigger ../fc/pf eq active or ../fc/pf/01 eq complete
-            edit EMOS_TYPE 'cm'
-            edit EMOS_DOMAIN 'G'
-            edit EMOS_PROJECT '12'
-            edit PROD_TASK '1'
-            edit SMSTRIES '1'
-            edit EMOS_STREAM 'ENFO'
-            task collectreq
-              edit QUEUE 'diss'
-              edit USER 'emos'
-              edit WSHOST 'diss'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit LOGDIR '/diss/log'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit EMOS_BASE '00'
-            task eps
-              late -s +00:03 -c +00:10
-              trigger collectreq eq complete
-              label info ""
-              event 1 
-            task collectwave
-              trigger collectreq eq complete
-              edit QUEUE 'diss'
-              edit USER 'emos'
-              edit WSHOST 'diss'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit LOGDIR '/diss/log'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit EMOS_STREAM 'WAEF'
-              edit EMOS_BASE '00'
-            task wave_eps
-              late -s +00:03 -c +00:10
-              trigger collectwave eq complete
-              edit EMOS_STREAM 'WAEF'
-              edit USER_PRIORITY '89'
-              label info ""
-              event 1 
-            task collectbitmap
-              trigger collectwave eq complete
-              edit QUEUE 'diss'
-              edit USER 'emos'
-              edit WSHOST 'diss'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit LOGDIR '/diss/log'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit SMSOUT '/vol/emos_nc/output'
-            task bitmap
-              late -s +00:03 -c +00:10
-              trigger collectbitmap eq complete and ( eps:001 or eps eq complete)
-              event 1 
-          endfamily
-          task enfo_tc
-            late -s +00:05 -c +00:15
-            trigger ( ./getreq/eps:001 or ./getreq/eps eq complete) and ../postproc/tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TYPE 'tf'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '1'
-          task oper_tc
-            late -s +00:05 -c +00:15
-            trigger ./enfo_tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TYPE 'tf'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '1'
-            edit EMOS_STREAM 'OPER'
-          task prod_wparam
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and /e_36r1/main/00/prod/240/prod_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TYPE 'wp'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '52'
-          task enfo_postproc
-            late -s +00:05 -c +00:15
-            trigger ../postproc eq complete and ( ../../legA/prod/getreq/eps eq complete) and ../../legA/postproc/efi eq complete and ../../legA/postproc/clusters eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'ep'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '21'
-          task waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TIME_STEP_H '0240'
-            edit PGNPES '1'
-        endfamily
-        family prod2diss
-          edit USER_PRIORITY '90'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'ef'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-          edit SMSURL 'GENFO/00'
-          task operation_is_late
-            event yes
-          family eps
-            family 0000
-              edit EMOS_TIME_STEP_H '0000'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0000/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0003
-              edit EMOS_TIME_STEP_H '0003'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0003/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0000/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0006
-              edit EMOS_TIME_STEP_H '0006'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0006/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0003/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0009
-              edit EMOS_TIME_STEP_H '0009'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0009/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0006/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0012
-              edit EMOS_TIME_STEP_H '0012'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0012/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0009/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0015
-              edit EMOS_TIME_STEP_H '0015'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0015/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0012/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0018
-              edit EMOS_TIME_STEP_H '0018'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0018/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0015/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0021
-              edit EMOS_TIME_STEP_H '0021'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0021/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0018/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0024
-              edit EMOS_TIME_STEP_H '0024'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0024/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0021/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0027
-              edit EMOS_TIME_STEP_H '0027'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0027/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0024/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0030
-              edit EMOS_TIME_STEP_H '0030'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0030/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0027/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0033
-              edit EMOS_TIME_STEP_H '0033'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0033/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0030/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0036
-              edit EMOS_TIME_STEP_H '0036'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0036/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0033/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0039
-              edit EMOS_TIME_STEP_H '0039'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0039/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0036/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0042
-              edit EMOS_TIME_STEP_H '0042'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0042/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0039/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0045
-              edit EMOS_TIME_STEP_H '0045'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0045/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0042/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0048
-              edit EMOS_TIME_STEP_H '0048'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0048/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0045/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0051
-              edit EMOS_TIME_STEP_H '0051'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0051/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0048/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0054
-              edit EMOS_TIME_STEP_H '0054'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0054/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0051/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0057
-              edit EMOS_TIME_STEP_H '0057'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0057/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0054/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0060
-              edit EMOS_TIME_STEP_H '0060'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0060/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0057/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0063
-              edit EMOS_TIME_STEP_H '0063'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0063/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0060/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0066
-              edit EMOS_TIME_STEP_H '0066'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0066/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0063/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0069
-              edit EMOS_TIME_STEP_H '0069'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0069/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0066/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0072
-              edit EMOS_TIME_STEP_H '0072'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0072/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0069/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0075
-              edit EMOS_TIME_STEP_H '0075'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0075/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0072/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0078
-              edit EMOS_TIME_STEP_H '0078'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0078/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0075/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0081
-              edit EMOS_TIME_STEP_H '0081'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0081/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0078/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0084
-              edit EMOS_TIME_STEP_H '0084'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0084/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0081/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0087
-              edit EMOS_TIME_STEP_H '0087'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0087/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0084/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0090
-              edit EMOS_TIME_STEP_H '0090'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0090/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0087/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0093
-              edit EMOS_TIME_STEP_H '0093'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0093/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0090/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0096
-              edit EMOS_TIME_STEP_H '0096'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0096/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0093/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0099
-              edit EMOS_TIME_STEP_H '0099'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0099/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0096/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0102
-              edit EMOS_TIME_STEP_H '0102'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0102/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0099/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0105
-              edit EMOS_TIME_STEP_H '0105'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0105/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0102/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0108
-              edit EMOS_TIME_STEP_H '0108'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0108/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0105/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0111
-              edit EMOS_TIME_STEP_H '0111'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0111/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0108/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0114
-              edit EMOS_TIME_STEP_H '0114'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0114/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0111/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0117
-              edit EMOS_TIME_STEP_H '0117'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0117/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0114/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0120
-              edit EMOS_TIME_STEP_H '0120'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0120/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0117/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0123
-              edit EMOS_TIME_STEP_H '0123'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0123/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0120/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0126
-              edit EMOS_TIME_STEP_H '0126'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0126/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0123/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0129
-              edit EMOS_TIME_STEP_H '0129'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0129/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0126/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0132
-              edit EMOS_TIME_STEP_H '0132'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0132/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0129/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0135
-              edit EMOS_TIME_STEP_H '0135'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0135/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0132/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0138
-              edit EMOS_TIME_STEP_H '0138'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0138/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0135/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0141
-              edit EMOS_TIME_STEP_H '0141'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0141/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0138/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0144
-              edit EMOS_TIME_STEP_H '0144'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0144/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0141/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0150
-              edit EMOS_TIME_STEP_H '0150'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0150/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0144/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0156
-              edit EMOS_TIME_STEP_H '0156'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0156/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0150/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0162
-              edit EMOS_TIME_STEP_H '0162'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0162/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0156/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0168
-              edit EMOS_TIME_STEP_H '0168'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0168/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0162/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0174
-              edit EMOS_TIME_STEP_H '0174'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0174/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0168/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0180
-              edit EMOS_TIME_STEP_H '0180'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0180/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0174/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0186
-              edit EMOS_TIME_STEP_H '0186'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0186/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0180/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0192
-              edit EMOS_TIME_STEP_H '0192'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0192/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0186/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0198
-              edit EMOS_TIME_STEP_H '0198'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0198/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0192/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0204
-              edit EMOS_TIME_STEP_H '0204'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0204/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0198/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0210
-              edit EMOS_TIME_STEP_H '0210'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0210/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0204/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0216
-              edit EMOS_TIME_STEP_H '0216'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0216/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0210/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0222
-              edit EMOS_TIME_STEP_H '0222'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0222/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0216/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0228
-              edit EMOS_TIME_STEP_H '0228'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0228/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0222/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0234
-              edit EMOS_TIME_STEP_H '0234'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0234/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0228/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0240
-              edit EMOS_TIME_STEP_H '0240'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0240/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0234/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            task check
-              trigger ./0240 eq complete
-          endfamily
-          family wave
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TYPE 'we'
-            edit SMSURL 'GWAEF/00'
-            family 0000
-              trigger ../../prod/wave/0000/prodwave eq complete
-              edit EMOS_TIME_STEP_H '0000'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0003
-              trigger ../../prod/wave/0003/prodwave eq complete and ( ./0000 eq complete)
-              edit EMOS_TIME_STEP_H '0003'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0006
-              trigger ../../prod/wave/0006/prodwave eq complete and ( ./0003 eq complete)
-              edit EMOS_TIME_STEP_H '0006'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0009
-              trigger ../../prod/wave/0009/prodwave eq complete and ( ./0006 eq complete)
-              edit EMOS_TIME_STEP_H '0009'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0012
-              trigger ../../prod/wave/0012/prodwave eq complete and ( ./0009 eq complete)
-              edit EMOS_TIME_STEP_H '0012'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0015
-              trigger ../../prod/wave/0015/prodwave eq complete and ( ./0012 eq complete)
-              edit EMOS_TIME_STEP_H '0015'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0018
-              trigger ../../prod/wave/0018/prodwave eq complete and ( ./0015 eq complete)
-              edit EMOS_TIME_STEP_H '0018'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0021
-              trigger ../../prod/wave/0021/prodwave eq complete and ( ./0018 eq complete)
-              edit EMOS_TIME_STEP_H '0021'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0024
-              trigger ../../prod/wave/0024/prodwave eq complete and ( ./0021 eq complete)
-              edit EMOS_TIME_STEP_H '0024'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0027
-              trigger ../../prod/wave/0027/prodwave eq complete and ( ./0024 eq complete)
-              edit EMOS_TIME_STEP_H '0027'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0030
-              trigger ../../prod/wave/0030/prodwave eq complete and ( ./0027 eq complete)
-              edit EMOS_TIME_STEP_H '0030'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0033
-              trigger ../../prod/wave/0033/prodwave eq complete and ( ./0030 eq complete)
-              edit EMOS_TIME_STEP_H '0033'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0036
-              trigger ../../prod/wave/0036/prodwave eq complete and ( ./0033 eq complete)
-              edit EMOS_TIME_STEP_H '0036'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0039
-              trigger ../../prod/wave/0039/prodwave eq complete and ( ./0036 eq complete)
-              edit EMOS_TIME_STEP_H '0039'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0042
-              trigger ../../prod/wave/0042/prodwave eq complete and ( ./0039 eq complete)
-              edit EMOS_TIME_STEP_H '0042'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0045
-              trigger ../../prod/wave/0045/prodwave eq complete and ( ./0042 eq complete)
-              edit EMOS_TIME_STEP_H '0045'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0048
-              trigger ../../prod/wave/0048/prodwave eq complete and ( ./0045 eq complete)
-              edit EMOS_TIME_STEP_H '0048'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0051
-              trigger ../../prod/wave/0051/prodwave eq complete and ( ./0048 eq complete)
-              edit EMOS_TIME_STEP_H '0051'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0054
-              trigger ../../prod/wave/0054/prodwave eq complete and ( ./0051 eq complete)
-              edit EMOS_TIME_STEP_H '0054'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0057
-              trigger ../../prod/wave/0057/prodwave eq complete and ( ./0054 eq complete)
-              edit EMOS_TIME_STEP_H '0057'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0060
-              trigger ../../prod/wave/0060/prodwave eq complete and ( ./0057 eq complete)
-              edit EMOS_TIME_STEP_H '0060'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0063
-              trigger ../../prod/wave/0063/prodwave eq complete and ( ./0060 eq complete)
-              edit EMOS_TIME_STEP_H '0063'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0066
-              trigger ../../prod/wave/0066/prodwave eq complete and ( ./0063 eq complete)
-              edit EMOS_TIME_STEP_H '0066'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0069
-              trigger ../../prod/wave/0069/prodwave eq complete and ( ./0066 eq complete)
-              edit EMOS_TIME_STEP_H '0069'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0072
-              trigger ../../prod/wave/0072/prodwave eq complete and ( ./0069 eq complete)
-              edit EMOS_TIME_STEP_H '0072'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0075
-              trigger ../../prod/wave/0075/prodwave eq complete and ( ./0072 eq complete)
-              edit EMOS_TIME_STEP_H '0075'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0078
-              trigger ../../prod/wave/0078/prodwave eq complete and ( ./0075 eq complete)
-              edit EMOS_TIME_STEP_H '0078'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0081
-              trigger ../../prod/wave/0081/prodwave eq complete and ( ./0078 eq complete)
-              edit EMOS_TIME_STEP_H '0081'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0084
-              trigger ../../prod/wave/0084/prodwave eq complete and ( ./0081 eq complete)
-              edit EMOS_TIME_STEP_H '0084'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0087
-              trigger ../../prod/wave/0087/prodwave eq complete and ( ./0084 eq complete)
-              edit EMOS_TIME_STEP_H '0087'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0090
-              trigger ../../prod/wave/0090/prodwave eq complete and ( ./0087 eq complete)
-              edit EMOS_TIME_STEP_H '0090'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0093
-              trigger ../../prod/wave/0093/prodwave eq complete and ( ./0090 eq complete)
-              edit EMOS_TIME_STEP_H '0093'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0096
-              trigger ../../prod/wave/0096/prodwave eq complete and ( ./0093 eq complete)
-              edit EMOS_TIME_STEP_H '0096'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0099
-              trigger ../../prod/wave/0099/prodwave eq complete and ( ./0096 eq complete)
-              edit EMOS_TIME_STEP_H '0099'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0102
-              trigger ../../prod/wave/0102/prodwave eq complete and ( ./0099 eq complete)
-              edit EMOS_TIME_STEP_H '0102'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0105
-              trigger ../../prod/wave/0105/prodwave eq complete and ( ./0102 eq complete)
-              edit EMOS_TIME_STEP_H '0105'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0108
-              trigger ../../prod/wave/0108/prodwave eq complete and ( ./0105 eq complete)
-              edit EMOS_TIME_STEP_H '0108'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0111
-              trigger ../../prod/wave/0111/prodwave eq complete and ( ./0108 eq complete)
-              edit EMOS_TIME_STEP_H '0111'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0114
-              trigger ../../prod/wave/0114/prodwave eq complete and ( ./0111 eq complete)
-              edit EMOS_TIME_STEP_H '0114'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0117
-              trigger ../../prod/wave/0117/prodwave eq complete and ( ./0114 eq complete)
-              edit EMOS_TIME_STEP_H '0117'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0120
-              trigger ../../prod/wave/0120/prodwave eq complete and ( ./0117 eq complete)
-              edit EMOS_TIME_STEP_H '0120'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0123
-              trigger ../../prod/wave/0123/prodwave eq complete and ( ./0120 eq complete)
-              edit EMOS_TIME_STEP_H '0123'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0126
-              trigger ../../prod/wave/0126/prodwave eq complete and ( ./0123 eq complete)
-              edit EMOS_TIME_STEP_H '0126'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0129
-              trigger ../../prod/wave/0129/prodwave eq complete and ( ./0126 eq complete)
-              edit EMOS_TIME_STEP_H '0129'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0132
-              trigger ../../prod/wave/0132/prodwave eq complete and ( ./0129 eq complete)
-              edit EMOS_TIME_STEP_H '0132'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0135
-              trigger ../../prod/wave/0135/prodwave eq complete and ( ./0132 eq complete)
-              edit EMOS_TIME_STEP_H '0135'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0138
-              trigger ../../prod/wave/0138/prodwave eq complete and ( ./0135 eq complete)
-              edit EMOS_TIME_STEP_H '0138'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0141
-              trigger ../../prod/wave/0141/prodwave eq complete and ( ./0138 eq complete)
-              edit EMOS_TIME_STEP_H '0141'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0144
-              trigger ../../prod/wave/0144/prodwave eq complete and ( ./0141 eq complete)
-              edit EMOS_TIME_STEP_H '0144'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0150
-              trigger ../../prod/wave/0150/prodwave eq complete and ( ./0144 eq complete)
-              edit EMOS_TIME_STEP_H '0150'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0156
-              trigger ../../prod/wave/0156/prodwave eq complete and ( ./0150 eq complete)
-              edit EMOS_TIME_STEP_H '0156'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0162
-              trigger ../../prod/wave/0162/prodwave eq complete and ( ./0156 eq complete)
-              edit EMOS_TIME_STEP_H '0162'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0168
-              trigger ../../prod/wave/0168/prodwave eq complete and ( ./0162 eq complete)
-              edit EMOS_TIME_STEP_H '0168'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0174
-              trigger ../../prod/wave/0174/prodwave eq complete and ( ./0168 eq complete)
-              edit EMOS_TIME_STEP_H '0174'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0180
-              trigger ../../prod/wave/0180/prodwave eq complete and ( ./0174 eq complete)
-              edit EMOS_TIME_STEP_H '0180'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0186
-              trigger ../../prod/wave/0186/prodwave eq complete and ( ./0180 eq complete)
-              edit EMOS_TIME_STEP_H '0186'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0192
-              trigger ../../prod/wave/0192/prodwave eq complete and ( ./0186 eq complete)
-              edit EMOS_TIME_STEP_H '0192'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0198
-              trigger ../../prod/wave/0198/prodwave eq complete and ( ./0192 eq complete)
-              edit EMOS_TIME_STEP_H '0198'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0204
-              trigger ../../prod/wave/0204/prodwave eq complete and ( ./0198 eq complete)
-              edit EMOS_TIME_STEP_H '0204'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0210
-              trigger ../../prod/wave/0210/prodwave eq complete and ( ./0204 eq complete)
-              edit EMOS_TIME_STEP_H '0210'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0216
-              trigger ../../prod/wave/0216/prodwave eq complete and ( ./0210 eq complete)
-              edit EMOS_TIME_STEP_H '0216'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0222
-              trigger ../../prod/wave/0222/prodwave eq complete and ( ./0216 eq complete)
-              edit EMOS_TIME_STEP_H '0222'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0228
-              trigger ../../prod/wave/0228/prodwave eq complete and ( ./0222 eq complete)
-              edit EMOS_TIME_STEP_H '0228'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0234
-              trigger ../../prod/wave/0234/prodwave eq complete and ( ./0228 eq complete)
-              edit EMOS_TIME_STEP_H '0234'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0240
-              trigger ../../prod/wave/0240/prodwave eq complete and ( ./0234 eq complete)
-              edit EMOS_TIME_STEP_H '0240'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            task check
-              trigger ./0240 eq complete
-          endfamily
-          task diss_wparam
-            late -s +00:05 -c +00:15
-            trigger ../prod/prod_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'wp'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/waef_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/enfo_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'ep'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_enfotc
-            late -s +00:05 -c +00:15
-            trigger ../prod/enfo_tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'tf'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_opertc
-            late -s +00:05 -c +00:15
-            trigger ../prod/oper_tc eq complete
-            edit PROD_TASK 't'
-            edit EMOS_TIME_STEP_H '0240'
-            edit EMOS_TYPE 'tf'
-            edit EMOS_STREAM 'DA'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-        endfamily
-      endfamily
-      family legB
-        complete /emc_36r1/main/ref/00/events:240
-        edit EPSLEG '2'
-        family fc
-          complete /emc_36r1/main/ref/00/events:cpl and /emc_36r1/main/00/legBcpl/fc eq complete
-          trigger /emc_36r1/main/ref/00/events eq complete and not /emc_36r1/main/ref/00/events:cpl
-          edit FCMEM '2240'
-          edit FCSTACK '700'
-          edit FCMRFS '0'
-          edit PRIORITY '71'
-          edit USER_PRIORITY '71'
-          edit N_PERT_AN '10'
-          edit SSTLEN '144'
-          edit EPSINISTEP_PREVIOUS '216'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          edit TSTEP '2700'
-          edit EPSFCRES '639'
-          edit RESOL '639'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit CPUTIME '1000'
-          edit MEM '960'
-          edit THREADS '8'
-          edit NPES '8'
-          edit EPSLEG '2'
-          edit PERSST 'true'
-          edit SSTINT '1'
-          task wavfcdata
-            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-            edit EPSCOUPLE '1'
-          task getpersSST
-            trigger ../../legA/fc/inidata eq complete and ../../legA/fc/getpersSST eq complete
-            edit EPSCOUPLE '1'
-            edit EPS_INI_STREAM 'DA'
-            edit EPSFCRES '319'
-            edit RESOL '319'
-          family pf
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger ./getpersSST eq complete and ./wavfcdata eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTYPE 'pf'
-            edit EMOS_TYPE 'pf'
-            edit USER_PRIORITY '71'
-            edit PRIORITY '71'
-            edit FCNPES '32'
-            edit FCCHUNK '1'
-            edit OCTOTAL '5'
-            edit FCTOTAL '51'
-            edit FCLENGTH1 '216'
-            edit DAILY '0'
-            edit RUNVARFC '1'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSFCRES '319'
-            edit EPSWAMRESOL 'global50'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit EPSINISTEP '360'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '2'
-            edit CLASS 'od'
-            edit THREADS '2'
-            inlimit /emc_36r1/limits:pftotal
-            meter step -1 144 144
-            family 01
-              trigger ../../../legA/fc/pf/01 eq complete
-              edit EPSMEMBER '1'
-              edit MEMBER '1'
-              edit SUBFSFAMILY '/pf001'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 02
-              trigger ../../../legA/fc/pf/02 eq complete
-              edit EPSMEMBER '2'
-              edit MEMBER '2'
-              edit SUBFSFAMILY '/pf002'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 03
-              trigger ../../../legA/fc/pf/03 eq complete
-              edit EPSMEMBER '3'
-              edit MEMBER '3'
-              edit SUBFSFAMILY '/pf003'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 04
-              trigger ../../../legA/fc/pf/04 eq complete
-              edit EPSMEMBER '4'
-              edit MEMBER '4'
-              edit SUBFSFAMILY '/pf004'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 05
-              trigger ../../../legA/fc/pf/05 eq complete
-              edit EPSMEMBER '5'
-              edit MEMBER '5'
-              edit SUBFSFAMILY '/pf005'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 06
-              trigger ../../../legA/fc/pf/06 eq complete
-              edit EPSMEMBER '6'
-              edit MEMBER '6'
-              edit SUBFSFAMILY '/pf006'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 07
-              trigger ../../../legA/fc/pf/07 eq complete
-              edit EPSMEMBER '7'
-              edit MEMBER '7'
-              edit SUBFSFAMILY '/pf007'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 08
-              trigger ../../../legA/fc/pf/08 eq complete
-              edit EPSMEMBER '8'
-              edit MEMBER '8'
-              edit SUBFSFAMILY '/pf008'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 09
-              trigger ../../../legA/fc/pf/09 eq complete
-              edit EPSMEMBER '9'
-              edit MEMBER '9'
-              edit SUBFSFAMILY '/pf009'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 10
-              trigger ../../../legA/fc/pf/10 eq complete
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              edit SUBFSFAMILY '/pf010'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 11
-              trigger ../../../legA/fc/pf/11 eq complete
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              edit SUBFSFAMILY '/pf011'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 12
-              trigger ../../../legA/fc/pf/12 eq complete
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              edit SUBFSFAMILY '/pf012'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 13
-              trigger ../../../legA/fc/pf/13 eq complete
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              edit SUBFSFAMILY '/pf013'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 14
-              trigger ../../../legA/fc/pf/14 eq complete
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              edit SUBFSFAMILY '/pf014'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 15
-              trigger ../../../legA/fc/pf/15 eq complete
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              edit SUBFSFAMILY '/pf015'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 16
-              trigger ../../../legA/fc/pf/16 eq complete
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              edit SUBFSFAMILY '/pf016'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 17
-              trigger ../../../legA/fc/pf/17 eq complete
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              edit SUBFSFAMILY '/pf017'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 18
-              trigger ../../../legA/fc/pf/18 eq complete
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              edit SUBFSFAMILY '/pf018'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 19
-              trigger ../../../legA/fc/pf/19 eq complete
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              edit SUBFSFAMILY '/pf019'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 20
-              trigger ../../../legA/fc/pf/20 eq complete
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              edit SUBFSFAMILY '/pf020'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 21
-              trigger ../../../legA/fc/pf/21 eq complete
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              edit SUBFSFAMILY '/pf021'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 22
-              trigger ../../../legA/fc/pf/22 eq complete
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              edit SUBFSFAMILY '/pf022'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 23
-              trigger ../../../legA/fc/pf/23 eq complete
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              edit SUBFSFAMILY '/pf023'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 24
-              trigger ../../../legA/fc/pf/24 eq complete
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              edit SUBFSFAMILY '/pf024'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 25
-              trigger ../../../legA/fc/pf/25 eq complete
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              edit SUBFSFAMILY '/pf025'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 26
-              trigger ../../../legA/fc/pf/26 eq complete
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              edit SUBFSFAMILY '/pf026'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 27
-              trigger ../../../legA/fc/pf/27 eq complete
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              edit SUBFSFAMILY '/pf027'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 28
-              trigger ../../../legA/fc/pf/28 eq complete
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              edit SUBFSFAMILY '/pf028'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 29
-              trigger ../../../legA/fc/pf/29 eq complete
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              edit SUBFSFAMILY '/pf029'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 30
-              trigger ../../../legA/fc/pf/30 eq complete
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              edit SUBFSFAMILY '/pf030'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 31
-              trigger ../../../legA/fc/pf/31 eq complete
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              edit SUBFSFAMILY '/pf031'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 32
-              trigger ../../../legA/fc/pf/32 eq complete
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              edit SUBFSFAMILY '/pf032'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 33
-              trigger ../../../legA/fc/pf/33 eq complete
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              edit SUBFSFAMILY '/pf033'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 34
-              trigger ../../../legA/fc/pf/34 eq complete
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              edit SUBFSFAMILY '/pf034'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 35
-              trigger ../../../legA/fc/pf/35 eq complete
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              edit SUBFSFAMILY '/pf035'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 36
-              trigger ../../../legA/fc/pf/36 eq complete
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              edit SUBFSFAMILY '/pf036'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 37
-              trigger ../../../legA/fc/pf/37 eq complete
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              edit SUBFSFAMILY '/pf037'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 38
-              trigger ../../../legA/fc/pf/38 eq complete
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              edit SUBFSFAMILY '/pf038'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 39
-              trigger ../../../legA/fc/pf/39 eq complete
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              edit SUBFSFAMILY '/pf039'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 40
-              trigger ../../../legA/fc/pf/40 eq complete
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              edit SUBFSFAMILY '/pf040'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 41
-              trigger ../../../legA/fc/pf/41 eq complete
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              edit SUBFSFAMILY '/pf041'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 42
-              trigger ../../../legA/fc/pf/42 eq complete
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              edit SUBFSFAMILY '/pf042'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 43
-              trigger ../../../legA/fc/pf/43 eq complete
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              edit SUBFSFAMILY '/pf043'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 44
-              trigger ../../../legA/fc/pf/44 eq complete
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              edit SUBFSFAMILY '/pf044'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 45
-              trigger ../../../legA/fc/pf/45 eq complete
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              edit SUBFSFAMILY '/pf045'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 46
-              trigger ../../../legA/fc/pf/46 eq complete
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              edit SUBFSFAMILY '/pf046'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 47
-              trigger ../../../legA/fc/pf/47 eq complete
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              edit SUBFSFAMILY '/pf047'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 48
-              trigger ../../../legA/fc/pf/48 eq complete
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              edit SUBFSFAMILY '/pf048'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 49
-              trigger ../../../legA/fc/pf/49 eq complete
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              edit SUBFSFAMILY '/pf049'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 50
-              trigger ../../../legA/fc/pf/50 eq complete
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              edit SUBFSFAMILY '/pf050'
-              edit SMSTRIES '1'
-              task getvarepsdata
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger intHtoL eq complete and getvarepsdata eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '144'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-          endfamily
-          family cf
-            complete /emc_36r1/main/00/legBcpl/fc/cf/modeleps:step ge 144
-            trigger ../../legA/fc/cf eq complete and not /emc_36r1/main/ref/00/events:cpl and ./getpersSST eq complete and ./wavfcdata eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit MEMBER '0'
-            edit EPSMEMBER '0'
-            edit SUBFSFAMILY '/cf000'
-            edit EPSTYPE 'cf'
-            edit EMOS_TYPE 'cf'
-            edit USER_PRIORITY '72'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSFCRES '319'
-            edit EPSWAMRESOL 'global50'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit EPSINISTEP '360'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '2'
-            edit CLASS 'od'
-            edit SMSTRIES '1'
-            edit RUNCOUPLE '0'
-            task getvarepsdata
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '2700'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSLEG '2'
-              edit EPSINISTEP '216'
-              edit EPSFCRES '639'
-              edit EPSFCRESN '319'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '2700'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '216'
-              edit EPSFCRES '319'
-              edit NPES '24'
-              edit FCNPES '24'
-              edit THREADS '2'
-              edit CLASS 'od'
-            task modeleps
-              trigger intHtoL eq complete and getvarepsdata eq complete
-              edit FCNPES '32'
-              edit THREADS '4'
-              edit SMSTRIES '1'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSLEG '2'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '144'
-              edit EPSINISTEP_PREVIOUS '216'
-              edit FCLENGTH '144'
-              edit TSTEP '2700'
-              edit CLASS 'od'
-              meter step -1 144 144
-          endfamily
-        endfamily
-        family postproc
-          trigger ./fc/pf eq complete and ./fc/cf eq complete
-          edit STEPS '252/360/12/24 360/360/12/120'
-          inlimit /emc_36r1/limits:postproc
-          family ensms
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger ../fc eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            family limits
-              limit fdb 1
-              limit gen 8
-            endfamily
-            task ensms
-              edit ENS_M 'false'
-              edit ENS_S 'false'
-              edit ENS_MARS 'false'
-              event stage
-            family 300
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '246'
-              edit STEP2 '300'
-              edit BY '6'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-            family 360
-              trigger ./ensms:stage or ./ensms eq complete
-              edit STEP1 '306'
-              edit STEP2 '360'
-              edit BY '6'
-              edit STEPS '0'
-              family T
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'T'
-                inlimit ../limits:gen
-                family 850
-                  task ensms
-                    edit LIST_LEV '850'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              family Z
-                edit ENS_M 'false'
-                edit ENS_S 'false'
-                edit LIST_PARAM 'Z'
-                inlimit ../limits:gen
-                family 1000
-                  task ensms
-                    edit LIST_LEV '1000'
-                endfamily
-                family 500
-                  task ensms
-                    edit LIST_LEV '500'
-                endfamily
-              endfamily
-              task ensms
-                trigger T eq complete and Z eq complete
-                edit ENS_MARS 'false'
-                inlimit ../limits:fdb
-            endfamily
-          endfamily
-          family prob
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger ( /emc_36r1/main/00/legB/fc eq complete) and ( /emc_36r1/main/00/legA/postproc/prob eq complete)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            edit STEP1 '252'
-            edit STEP2 '360'
-            edit BY '12'
-            family 24
-              edit STEP1 '240'
-              edit STEP2 '360'
-              edit BY '24'
-              task t850
-              task rain
-              task ff
-            endfamily
-            family 12
-              edit STEP1 '252'
-              edit STEP2 '348'
-              edit BY '24'
-              task t850
-              task rain
-              task ff
-            endfamily
-            task 2t
-            task swh
-            task mwp
-            task 10fg
-              trigger ../dp eq complete
-            task prob_fdb
-              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
-          endfamily
-          family dp
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '246:360:6'
-            inlimit /emc_36r1/limits:dp
-            family dp
-              trigger ./cf eq complete and ./pf eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit OVERLAP '1'
-              edit STEPS '216:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                complete /emc_36r1/main/ref/00/events:cf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-                family 05
-                  edit EPSMEMBER '5'
-                  edit MEMBER '5'
-                  edit SUBFSFAMILY '/pf005'
-                  task derived_param
-                endfamily
-                family 06
-                  edit EPSMEMBER '6'
-                  edit MEMBER '6'
-                  edit SUBFSFAMILY '/pf006'
-                  task derived_param
-                endfamily
-                family 07
-                  edit EPSMEMBER '7'
-                  edit MEMBER '7'
-                  edit SUBFSFAMILY '/pf007'
-                  task derived_param
-                endfamily
-                family 08
-                  edit EPSMEMBER '8'
-                  edit MEMBER '8'
-                  edit SUBFSFAMILY '/pf008'
-                  task derived_param
-                endfamily
-                family 09
-                  edit EPSMEMBER '9'
-                  edit MEMBER '9'
-                  edit SUBFSFAMILY '/pf009'
-                  task derived_param
-                endfamily
-                family 10
-                  edit EPSMEMBER '10'
-                  edit MEMBER '10'
-                  edit SUBFSFAMILY '/pf010'
-                  task derived_param
-                endfamily
-                family 11
-                  edit EPSMEMBER '11'
-                  edit MEMBER '11'
-                  edit SUBFSFAMILY '/pf011'
-                  task derived_param
-                endfamily
-                family 12
-                  edit EPSMEMBER '12'
-                  edit MEMBER '12'
-                  edit SUBFSFAMILY '/pf012'
-                  task derived_param
-                endfamily
-                family 13
-                  edit EPSMEMBER '13'
-                  edit MEMBER '13'
-                  edit SUBFSFAMILY '/pf013'
-                  task derived_param
-                endfamily
-                family 14
-                  edit EPSMEMBER '14'
-                  edit MEMBER '14'
-                  edit SUBFSFAMILY '/pf014'
-                  task derived_param
-                endfamily
-                family 15
-                  edit EPSMEMBER '15'
-                  edit MEMBER '15'
-                  edit SUBFSFAMILY '/pf015'
-                  task derived_param
-                endfamily
-                family 16
-                  edit EPSMEMBER '16'
-                  edit MEMBER '16'
-                  edit SUBFSFAMILY '/pf016'
-                  task derived_param
-                endfamily
-                family 17
-                  edit EPSMEMBER '17'
-                  edit MEMBER '17'
-                  edit SUBFSFAMILY '/pf017'
-                  task derived_param
-                endfamily
-                family 18
-                  edit EPSMEMBER '18'
-                  edit MEMBER '18'
-                  edit SUBFSFAMILY '/pf018'
-                  task derived_param
-                endfamily
-                family 19
-                  edit EPSMEMBER '19'
-                  edit MEMBER '19'
-                  edit SUBFSFAMILY '/pf019'
-                  task derived_param
-                endfamily
-                family 20
-                  edit EPSMEMBER '20'
-                  edit MEMBER '20'
-                  edit SUBFSFAMILY '/pf020'
-                  task derived_param
-                endfamily
-                family 21
-                  edit EPSMEMBER '21'
-                  edit MEMBER '21'
-                  edit SUBFSFAMILY '/pf021'
-                  task derived_param
-                endfamily
-                family 22
-                  edit EPSMEMBER '22'
-                  edit MEMBER '22'
-                  edit SUBFSFAMILY '/pf022'
-                  task derived_param
-                endfamily
-                family 23
-                  edit EPSMEMBER '23'
-                  edit MEMBER '23'
-                  edit SUBFSFAMILY '/pf023'
-                  task derived_param
-                endfamily
-                family 24
-                  edit EPSMEMBER '24'
-                  edit MEMBER '24'
-                  edit SUBFSFAMILY '/pf024'
-                  task derived_param
-                endfamily
-                family 25
-                  edit EPSMEMBER '25'
-                  edit MEMBER '25'
-                  edit SUBFSFAMILY '/pf025'
-                  task derived_param
-                endfamily
-                family 26
-                  edit EPSMEMBER '26'
-                  edit MEMBER '26'
-                  edit SUBFSFAMILY '/pf026'
-                  task derived_param
-                endfamily
-                family 27
-                  edit EPSMEMBER '27'
-                  edit MEMBER '27'
-                  edit SUBFSFAMILY '/pf027'
-                  task derived_param
-                endfamily
-                family 28
-                  edit EPSMEMBER '28'
-                  edit MEMBER '28'
-                  edit SUBFSFAMILY '/pf028'
-                  task derived_param
-                endfamily
-                family 29
-                  edit EPSMEMBER '29'
-                  edit MEMBER '29'
-                  edit SUBFSFAMILY '/pf029'
-                  task derived_param
-                endfamily
-                family 30
-                  edit EPSMEMBER '30'
-                  edit MEMBER '30'
-                  edit SUBFSFAMILY '/pf030'
-                  task derived_param
-                endfamily
-                family 31
-                  edit EPSMEMBER '31'
-                  edit MEMBER '31'
-                  edit SUBFSFAMILY '/pf031'
-                  task derived_param
-                endfamily
-                family 32
-                  edit EPSMEMBER '32'
-                  edit MEMBER '32'
-                  edit SUBFSFAMILY '/pf032'
-                  task derived_param
-                endfamily
-                family 33
-                  edit EPSMEMBER '33'
-                  edit MEMBER '33'
-                  edit SUBFSFAMILY '/pf033'
-                  task derived_param
-                endfamily
-                family 34
-                  edit EPSMEMBER '34'
-                  edit MEMBER '34'
-                  edit SUBFSFAMILY '/pf034'
-                  task derived_param
-                endfamily
-                family 35
-                  edit EPSMEMBER '35'
-                  edit MEMBER '35'
-                  edit SUBFSFAMILY '/pf035'
-                  task derived_param
-                endfamily
-                family 36
-                  edit EPSMEMBER '36'
-                  edit MEMBER '36'
-                  edit SUBFSFAMILY '/pf036'
-                  task derived_param
-                endfamily
-                family 37
-                  edit EPSMEMBER '37'
-                  edit MEMBER '37'
-                  edit SUBFSFAMILY '/pf037'
-                  task derived_param
-                endfamily
-                family 38
-                  edit EPSMEMBER '38'
-                  edit MEMBER '38'
-                  edit SUBFSFAMILY '/pf038'
-                  task derived_param
-                endfamily
-                family 39
-                  edit EPSMEMBER '39'
-                  edit MEMBER '39'
-                  edit SUBFSFAMILY '/pf039'
-                  task derived_param
-                endfamily
-                family 40
-                  edit EPSMEMBER '40'
-                  edit MEMBER '40'
-                  edit SUBFSFAMILY '/pf040'
-                  task derived_param
-                endfamily
-                family 41
-                  edit EPSMEMBER '41'
-                  edit MEMBER '41'
-                  edit SUBFSFAMILY '/pf041'
-                  task derived_param
-                endfamily
-                family 42
-                  edit EPSMEMBER '42'
-                  edit MEMBER '42'
-                  edit SUBFSFAMILY '/pf042'
-                  task derived_param
-                endfamily
-                family 43
-                  edit EPSMEMBER '43'
-                  edit MEMBER '43'
-                  edit SUBFSFAMILY '/pf043'
-                  task derived_param
-                endfamily
-                family 44
-                  edit EPSMEMBER '44'
-                  edit MEMBER '44'
-                  edit SUBFSFAMILY '/pf044'
-                  task derived_param
-                endfamily
-                family 45
-                  edit EPSMEMBER '45'
-                  edit MEMBER '45'
-                  edit SUBFSFAMILY '/pf045'
-                  task derived_param
-                endfamily
-                family 46
-                  edit EPSMEMBER '46'
-                  edit MEMBER '46'
-                  edit SUBFSFAMILY '/pf046'
-                  task derived_param
-                endfamily
-                family 47
-                  edit EPSMEMBER '47'
-                  edit MEMBER '47'
-                  edit SUBFSFAMILY '/pf047'
-                  task derived_param
-                endfamily
-                family 48
-                  edit EPSMEMBER '48'
-                  edit MEMBER '48'
-                  edit SUBFSFAMILY '/pf048'
-                  task derived_param
-                endfamily
-                family 49
-                  edit EPSMEMBER '49'
-                  edit MEMBER '49'
-                  edit SUBFSFAMILY '/pf049'
-                  task derived_param
-                endfamily
-                family 50
-                  edit EPSMEMBER '50'
-                  edit MEMBER '50'
-                  edit SUBFSFAMILY '/pf050'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family cf
-              trigger ../../fc/cf eq complete
-              edit EMOS_TYPE 'cf'
-              task derived_param
-                edit MEMBER 'off'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/00/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                trigger ../../../fc/pf/01 eq complete
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task derived_param
-              endfamily
-              family 02
-                trigger ../../../fc/pf/02 eq complete
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task derived_param
-              endfamily
-              family 03
-                trigger ../../../fc/pf/03 eq complete
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task derived_param
-              endfamily
-              family 04
-                trigger ../../../fc/pf/04 eq complete
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task derived_param
-              endfamily
-              family 05
-                trigger ../../../fc/pf/05 eq complete
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task derived_param
-              endfamily
-              family 06
-                trigger ../../../fc/pf/06 eq complete
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task derived_param
-              endfamily
-              family 07
-                trigger ../../../fc/pf/07 eq complete
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task derived_param
-              endfamily
-              family 08
-                trigger ../../../fc/pf/08 eq complete
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task derived_param
-              endfamily
-              family 09
-                trigger ../../../fc/pf/09 eq complete
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task derived_param
-              endfamily
-              family 10
-                trigger ../../../fc/pf/10 eq complete
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task derived_param
-              endfamily
-              family 11
-                trigger ../../../fc/pf/11 eq complete
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task derived_param
-              endfamily
-              family 12
-                trigger ../../../fc/pf/12 eq complete
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task derived_param
-              endfamily
-              family 13
-                trigger ../../../fc/pf/13 eq complete
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task derived_param
-              endfamily
-              family 14
-                trigger ../../../fc/pf/14 eq complete
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task derived_param
-              endfamily
-              family 15
-                trigger ../../../fc/pf/15 eq complete
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task derived_param
-              endfamily
-              family 16
-                trigger ../../../fc/pf/16 eq complete
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task derived_param
-              endfamily
-              family 17
-                trigger ../../../fc/pf/17 eq complete
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task derived_param
-              endfamily
-              family 18
-                trigger ../../../fc/pf/18 eq complete
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task derived_param
-              endfamily
-              family 19
-                trigger ../../../fc/pf/19 eq complete
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task derived_param
-              endfamily
-              family 20
-                trigger ../../../fc/pf/20 eq complete
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task derived_param
-              endfamily
-              family 21
-                trigger ../../../fc/pf/21 eq complete
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task derived_param
-              endfamily
-              family 22
-                trigger ../../../fc/pf/22 eq complete
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task derived_param
-              endfamily
-              family 23
-                trigger ../../../fc/pf/23 eq complete
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task derived_param
-              endfamily
-              family 24
-                trigger ../../../fc/pf/24 eq complete
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task derived_param
-              endfamily
-              family 25
-                trigger ../../../fc/pf/25 eq complete
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task derived_param
-              endfamily
-              family 26
-                trigger ../../../fc/pf/26 eq complete
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task derived_param
-              endfamily
-              family 27
-                trigger ../../../fc/pf/27 eq complete
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task derived_param
-              endfamily
-              family 28
-                trigger ../../../fc/pf/28 eq complete
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task derived_param
-              endfamily
-              family 29
-                trigger ../../../fc/pf/29 eq complete
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task derived_param
-              endfamily
-              family 30
-                trigger ../../../fc/pf/30 eq complete
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task derived_param
-              endfamily
-              family 31
-                trigger ../../../fc/pf/31 eq complete
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task derived_param
-              endfamily
-              family 32
-                trigger ../../../fc/pf/32 eq complete
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task derived_param
-              endfamily
-              family 33
-                trigger ../../../fc/pf/33 eq complete
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task derived_param
-              endfamily
-              family 34
-                trigger ../../../fc/pf/34 eq complete
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task derived_param
-              endfamily
-              family 35
-                trigger ../../../fc/pf/35 eq complete
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task derived_param
-              endfamily
-              family 36
-                trigger ../../../fc/pf/36 eq complete
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task derived_param
-              endfamily
-              family 37
-                trigger ../../../fc/pf/37 eq complete
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task derived_param
-              endfamily
-              family 38
-                trigger ../../../fc/pf/38 eq complete
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task derived_param
-              endfamily
-              family 39
-                trigger ../../../fc/pf/39 eq complete
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task derived_param
-              endfamily
-              family 40
-                trigger ../../../fc/pf/40 eq complete
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task derived_param
-              endfamily
-              family 41
-                trigger ../../../fc/pf/41 eq complete
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task derived_param
-              endfamily
-              family 42
-                trigger ../../../fc/pf/42 eq complete
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task derived_param
-              endfamily
-              family 43
-                trigger ../../../fc/pf/43 eq complete
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task derived_param
-              endfamily
-              family 44
-                trigger ../../../fc/pf/44 eq complete
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task derived_param
-              endfamily
-              family 45
-                trigger ../../../fc/pf/45 eq complete
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task derived_param
-              endfamily
-              family 46
-                trigger ../../../fc/pf/46 eq complete
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task derived_param
-              endfamily
-              family 47
-                trigger ../../../fc/pf/47 eq complete
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task derived_param
-              endfamily
-              family 48
-                trigger ../../../fc/pf/48 eq complete
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task derived_param
-              endfamily
-              family 49
-                trigger ../../../fc/pf/49 eq complete
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task derived_param
-              endfamily
-              family 50
-                trigger ../../../fc/pf/50 eq complete
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task derived_param
-              endfamily
-            endfamily
-          endfamily
-          family extra
-            trigger ./dp eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit STEPS '246:360:6'
-            inlimit /emc_36r1/limits:extra
-            family cf
-              edit EMOS_TYPE 'cf'
-              task extrafields
-                edit EPSFCRES '319'
-                edit FCLENGTH '360'
-                edit FCLENGTH0 '240'
-                edit RUNVARFC '1'
-            endfamily
-            family pf
-              complete /emc_36r1/main/ref/00/events:cf
-              edit EMOS_TYPE 'pf'
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 05
-                edit EPSMEMBER '5'
-                edit MEMBER '5'
-                edit SUBFSFAMILY '/pf005'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 06
-                edit EPSMEMBER '6'
-                edit MEMBER '6'
-                edit SUBFSFAMILY '/pf006'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 07
-                edit EPSMEMBER '7'
-                edit MEMBER '7'
-                edit SUBFSFAMILY '/pf007'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 08
-                edit EPSMEMBER '8'
-                edit MEMBER '8'
-                edit SUBFSFAMILY '/pf008'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 09
-                edit EPSMEMBER '9'
-                edit MEMBER '9'
-                edit SUBFSFAMILY '/pf009'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 10
-                edit EPSMEMBER '10'
-                edit MEMBER '10'
-                edit SUBFSFAMILY '/pf010'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 11
-                edit EPSMEMBER '11'
-                edit MEMBER '11'
-                edit SUBFSFAMILY '/pf011'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 12
-                edit EPSMEMBER '12'
-                edit MEMBER '12'
-                edit SUBFSFAMILY '/pf012'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 13
-                edit EPSMEMBER '13'
-                edit MEMBER '13'
-                edit SUBFSFAMILY '/pf013'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 14
-                edit EPSMEMBER '14'
-                edit MEMBER '14'
-                edit SUBFSFAMILY '/pf014'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 15
-                edit EPSMEMBER '15'
-                edit MEMBER '15'
-                edit SUBFSFAMILY '/pf015'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 16
-                edit EPSMEMBER '16'
-                edit MEMBER '16'
-                edit SUBFSFAMILY '/pf016'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 17
-                edit EPSMEMBER '17'
-                edit MEMBER '17'
-                edit SUBFSFAMILY '/pf017'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 18
-                edit EPSMEMBER '18'
-                edit MEMBER '18'
-                edit SUBFSFAMILY '/pf018'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 19
-                edit EPSMEMBER '19'
-                edit MEMBER '19'
-                edit SUBFSFAMILY '/pf019'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 20
-                edit EPSMEMBER '20'
-                edit MEMBER '20'
-                edit SUBFSFAMILY '/pf020'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 21
-                edit EPSMEMBER '21'
-                edit MEMBER '21'
-                edit SUBFSFAMILY '/pf021'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 22
-                edit EPSMEMBER '22'
-                edit MEMBER '22'
-                edit SUBFSFAMILY '/pf022'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 23
-                edit EPSMEMBER '23'
-                edit MEMBER '23'
-                edit SUBFSFAMILY '/pf023'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 24
-                edit EPSMEMBER '24'
-                edit MEMBER '24'
-                edit SUBFSFAMILY '/pf024'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 25
-                edit EPSMEMBER '25'
-                edit MEMBER '25'
-                edit SUBFSFAMILY '/pf025'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 26
-                edit EPSMEMBER '26'
-                edit MEMBER '26'
-                edit SUBFSFAMILY '/pf026'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 27
-                edit EPSMEMBER '27'
-                edit MEMBER '27'
-                edit SUBFSFAMILY '/pf027'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 28
-                edit EPSMEMBER '28'
-                edit MEMBER '28'
-                edit SUBFSFAMILY '/pf028'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 29
-                edit EPSMEMBER '29'
-                edit MEMBER '29'
-                edit SUBFSFAMILY '/pf029'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 30
-                edit EPSMEMBER '30'
-                edit MEMBER '30'
-                edit SUBFSFAMILY '/pf030'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 31
-                edit EPSMEMBER '31'
-                edit MEMBER '31'
-                edit SUBFSFAMILY '/pf031'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 32
-                edit EPSMEMBER '32'
-                edit MEMBER '32'
-                edit SUBFSFAMILY '/pf032'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 33
-                edit EPSMEMBER '33'
-                edit MEMBER '33'
-                edit SUBFSFAMILY '/pf033'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 34
-                edit EPSMEMBER '34'
-                edit MEMBER '34'
-                edit SUBFSFAMILY '/pf034'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 35
-                edit EPSMEMBER '35'
-                edit MEMBER '35'
-                edit SUBFSFAMILY '/pf035'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 36
-                edit EPSMEMBER '36'
-                edit MEMBER '36'
-                edit SUBFSFAMILY '/pf036'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 37
-                edit EPSMEMBER '37'
-                edit MEMBER '37'
-                edit SUBFSFAMILY '/pf037'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 38
-                edit EPSMEMBER '38'
-                edit MEMBER '38'
-                edit SUBFSFAMILY '/pf038'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 39
-                edit EPSMEMBER '39'
-                edit MEMBER '39'
-                edit SUBFSFAMILY '/pf039'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 40
-                edit EPSMEMBER '40'
-                edit MEMBER '40'
-                edit SUBFSFAMILY '/pf040'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 41
-                edit EPSMEMBER '41'
-                edit MEMBER '41'
-                edit SUBFSFAMILY '/pf041'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 42
-                edit EPSMEMBER '42'
-                edit MEMBER '42'
-                edit SUBFSFAMILY '/pf042'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 43
-                edit EPSMEMBER '43'
-                edit MEMBER '43'
-                edit SUBFSFAMILY '/pf043'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 44
-                edit EPSMEMBER '44'
-                edit MEMBER '44'
-                edit SUBFSFAMILY '/pf044'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 45
-                edit EPSMEMBER '45'
-                edit MEMBER '45'
-                edit SUBFSFAMILY '/pf045'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 46
-                edit EPSMEMBER '46'
-                edit MEMBER '46'
-                edit SUBFSFAMILY '/pf046'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 47
-                edit EPSMEMBER '47'
-                edit MEMBER '47'
-                edit SUBFSFAMILY '/pf047'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 48
-                edit EPSMEMBER '48'
-                edit MEMBER '48'
-                edit SUBFSFAMILY '/pf048'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 49
-                edit EPSMEMBER '49'
-                edit MEMBER '49'
-                edit SUBFSFAMILY '/pf049'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-              family 50
-                edit EPSMEMBER '50'
-                edit MEMBER '50'
-                edit SUBFSFAMILY '/pf050'
-                task extrafields
-                  edit EPSFCRES '319'
-                  edit FCLENGTH '360'
-                  edit FCLENGTH0 '240'
-                  edit RUNVARFC '1'
-              endfamily
-            endfamily
-          endfamily
-          family calibrate
-            complete /emc_36r1/main/ref/00/events:cf
-            trigger /emc_36r1/main/00/ref/an eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
-            family onws
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              inlimit /limits:linux_cluster
-              task feedupcal
-              task upcal
-                trigger feedupcal eq complete
-              task revertupcal
-            endfamily
-          endfamily
-          family efi
-            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
-            trigger /emc_36r1/main/00/legB/postproc/dp eq complete
-            edit HC_VERSION '0046'
-            edit HC_EXPVER '0046'
-            edit REF_VERSION '0046'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            edit NC_DAYS '31'
-            edit EPSLEG '2'
-            inlimit /emc_36r1/limits:efi
-            task stage
-              edit NC_DAYS '31'
-            family 240_336
-              trigger ./stage eq complete
-              edit ACC '96'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '336'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 168_336
-              trigger ./stage eq complete
-              edit ACC '168'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '336'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 012_036
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 036_060
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 060_084
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 084_108
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 108_132
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 120_144
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 120_168
-              trigger ./stage eq complete
-              edit ACC '48'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 168_240
-              trigger ./stage eq complete
-              edit ACC '72'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 000_168
-              trigger ./stage eq complete
-              edit ACC '168'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task extindex
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task extindex
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task extindex
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task extindex
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 000_024
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 024_048
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 048_072
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 072_096
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-            family 096_120
-              trigger ./stage eq complete
-              edit ACC '24'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task extindex
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task extindex
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task extindex
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task extindex
-              endfamily
-            endfamily
-          endfamily
-          task efi2fdb
-            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
-            trigger ./efi eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            inlimit /emc_36r1/main/ref:mutex
-            event none
-        endfamily
-        family prod
-          edit MEM '3000'
-          edit ACCOUNT 'oeenfopg'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'cp'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit USER_PRIORITY '90'
-          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
-          edit SMSURL 'sub=fixed/'
-          inlimit /limits:prod
-          family eps
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            inlimit /emc_36r1/limits:prodeps
-            family 0246
-              edit EMOS_TIME_STEP_H '0246'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0252
-              edit EMOS_TIME_STEP_H '0252'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0258
-              edit EMOS_TIME_STEP_H '0258'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0264
-              edit EMOS_TIME_STEP_H '0264'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0270
-              edit EMOS_TIME_STEP_H '0270'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0276
-              edit EMOS_TIME_STEP_H '0276'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0282
-              edit EMOS_TIME_STEP_H '0282'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0288
-              edit EMOS_TIME_STEP_H '0288'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0294
-              edit EMOS_TIME_STEP_H '0294'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0300
-              edit EMOS_TIME_STEP_H '0300'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0306
-              edit EMOS_TIME_STEP_H '0306'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0312
-              edit EMOS_TIME_STEP_H '0312'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0318
-              edit EMOS_TIME_STEP_H '0318'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0324
-              edit EMOS_TIME_STEP_H '0324'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0330
-              edit EMOS_TIME_STEP_H '0330'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0336
-              edit EMOS_TIME_STEP_H '0336'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0342
-              edit EMOS_TIME_STEP_H '0342'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0348
-              edit EMOS_TIME_STEP_H '0348'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0354
-              edit EMOS_TIME_STEP_H '0354'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-            family 0360
-              edit EMOS_TIME_STEP_H '0360'
-              task prodgen
-                late -s +00:05 -c +00:15
-            endfamily
-          endfamily
-          family wave
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
-            edit PGNPES '2'
-            edit URL 'GWAEF/00'
-            inlimit /emc_36r1/limits:prodwave
-            family 0246
-              edit EMOS_TIME_STEP_H '0246'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0252
-              edit EMOS_TIME_STEP_H '0252'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0258
-              edit EMOS_TIME_STEP_H '0258'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0264
-              edit EMOS_TIME_STEP_H '0264'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0270
-              edit EMOS_TIME_STEP_H '0270'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0276
-              edit EMOS_TIME_STEP_H '0276'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0282
-              edit EMOS_TIME_STEP_H '0282'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0288
-              edit EMOS_TIME_STEP_H '0288'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0294
-              edit EMOS_TIME_STEP_H '0294'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0300
-              edit EMOS_TIME_STEP_H '0300'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0306
-              edit EMOS_TIME_STEP_H '0306'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0312
-              edit EMOS_TIME_STEP_H '0312'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0318
-              edit EMOS_TIME_STEP_H '0318'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0324
-              edit EMOS_TIME_STEP_H '0324'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0330
-              edit EMOS_TIME_STEP_H '0330'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0336
-              edit EMOS_TIME_STEP_H '0336'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0342
-              edit EMOS_TIME_STEP_H '0342'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0348
-              edit EMOS_TIME_STEP_H '0348'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0354
-              edit EMOS_TIME_STEP_H '0354'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-            family 0360
-              edit EMOS_TIME_STEP_H '0360'
-              task prodwave
-                late -s +00:05 -c +00:15
-                edit EMOS_STREAM 'WE'
-                edit EMOS_TYPE 'we'
-            endfamily
-          endfamily
-          task prod_wparam
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and ../../legA/prod/prod_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TYPE 'wp'
-            edit EMOS_TIME_STEP_H '0360'
-            edit PGNPES '52'
-          task enfo_postproc
-            late -s +00:05 -c +00:15
-            trigger ../postproc/prob eq complete and ../postproc/ensms eq complete and ( ../../legA/prod/getreq/eps eq complete)
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'ep'
-            edit EMOS_TIME_STEP_H '0360'
-            edit PGNPES '21'
-          task waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TIME_STEP_H '0360'
-            edit PGNPES '1'
-        endfamily
-        family prod2diss
-          edit USER_PRIORITY '90'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
-          edit EMOS_DOMAIN 'G'
-          edit EMOS_TYPE 'ef'
-          edit EMOS_PROJECT '12'
-          edit PROD_TASK '1'
-          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-          edit SMSURL 'GENFO/00'
-          family eps
-            family 0246
-              edit EMOS_TIME_STEP_H '0246'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0246/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../../../../legA/prod2diss/eps//0240/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0252
-              edit EMOS_TIME_STEP_H '0252'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0252/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0246/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0258
-              edit EMOS_TIME_STEP_H '0258'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0258/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0252/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0264
-              edit EMOS_TIME_STEP_H '0264'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0264/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0258/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0270
-              edit EMOS_TIME_STEP_H '0270'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0270/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0264/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0276
-              edit EMOS_TIME_STEP_H '0276'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0276/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0270/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0282
-              edit EMOS_TIME_STEP_H '0282'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0282/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0276/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0288
-              edit EMOS_TIME_STEP_H '0288'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0288/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0282/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0294
-              edit EMOS_TIME_STEP_H '0294'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0294/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0288/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0300
-              edit EMOS_TIME_STEP_H '0300'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0300/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0294/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0306
-              edit EMOS_TIME_STEP_H '0306'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0306/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0300/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0312
-              edit EMOS_TIME_STEP_H '0312'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0312/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0306/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0318
-              edit EMOS_TIME_STEP_H '0318'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0318/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0312/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0324
-              edit EMOS_TIME_STEP_H '0324'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0324/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0318/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0330
-              edit EMOS_TIME_STEP_H '0330'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0330/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0324/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0336
-              edit EMOS_TIME_STEP_H '0336'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0336/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0330/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0342
-              edit EMOS_TIME_STEP_H '0342'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0342/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0336/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0348
-              edit EMOS_TIME_STEP_H '0348'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0348/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0342/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0354
-              edit EMOS_TIME_STEP_H '0354'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0354/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0348/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            family 0360
-              edit EMOS_TIME_STEP_H '0360'
-              task pdb
-                late -s +00:05 -c +00:15
-                trigger ../../../prod/eps/0360/prodgen eq complete
-                inlimit /emc_36r1/limits:pdb
-                inlimit /limits:pdb
-                label info ""
-                event 1 
-              task q2diss
-                late -s +00:05 -c +00:15
-                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0354/q2diss eq complete)
-                inlimit /emc_36r1/limits:q2diss
-                inlimit /limits:q2diss
-                label info ""
-                event 1 
-            endfamily
-            task check
-              trigger ./0360 eq complete
-          endfamily
-          family wave
-            edit EMOS_STREAM 'WE'
-            edit EMOS_TYPE 'we'
-            edit SMSURL 'GWAEF/00'
-            family 0246
-              trigger ../../prod/wave/0246/prodwave eq complete and ( ../../../legA/prod2diss/wave/0240 eq complete)
-              edit EMOS_TIME_STEP_H '0246'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0252
-              trigger ../../prod/wave/0252/prodwave eq complete and ( ./0246 eq complete)
-              edit EMOS_TIME_STEP_H '0252'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0258
-              trigger ../../prod/wave/0258/prodwave eq complete and ( ./0252 eq complete)
-              edit EMOS_TIME_STEP_H '0258'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0264
-              trigger ../../prod/wave/0264/prodwave eq complete and ( ./0258 eq complete)
-              edit EMOS_TIME_STEP_H '0264'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0270
-              trigger ../../prod/wave/0270/prodwave eq complete and ( ./0264 eq complete)
-              edit EMOS_TIME_STEP_H '0270'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0276
-              trigger ../../prod/wave/0276/prodwave eq complete and ( ./0270 eq complete)
-              edit EMOS_TIME_STEP_H '0276'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0282
-              trigger ../../prod/wave/0282/prodwave eq complete and ( ./0276 eq complete)
-              edit EMOS_TIME_STEP_H '0282'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0288
-              trigger ../../prod/wave/0288/prodwave eq complete and ( ./0282 eq complete)
-              edit EMOS_TIME_STEP_H '0288'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0294
-              trigger ../../prod/wave/0294/prodwave eq complete and ( ./0288 eq complete)
-              edit EMOS_TIME_STEP_H '0294'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0300
-              trigger ../../prod/wave/0300/prodwave eq complete and ( ./0294 eq complete)
-              edit EMOS_TIME_STEP_H '0300'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0306
-              trigger ../../prod/wave/0306/prodwave eq complete and ( ./0300 eq complete)
-              edit EMOS_TIME_STEP_H '0306'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0312
-              trigger ../../prod/wave/0312/prodwave eq complete and ( ./0306 eq complete)
-              edit EMOS_TIME_STEP_H '0312'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0318
-              trigger ../../prod/wave/0318/prodwave eq complete and ( ./0312 eq complete)
-              edit EMOS_TIME_STEP_H '0318'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0324
-              trigger ../../prod/wave/0324/prodwave eq complete and ( ./0318 eq complete)
-              edit EMOS_TIME_STEP_H '0324'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0330
-              trigger ../../prod/wave/0330/prodwave eq complete and ( ./0324 eq complete)
-              edit EMOS_TIME_STEP_H '0330'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0336
-              trigger ../../prod/wave/0336/prodwave eq complete and ( ./0330 eq complete)
-              edit EMOS_TIME_STEP_H '0336'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0342
-              trigger ../../prod/wave/0342/prodwave eq complete and ( ./0336 eq complete)
-              edit EMOS_TIME_STEP_H '0342'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0348
-              trigger ../../prod/wave/0348/prodwave eq complete and ( ./0342 eq complete)
-              edit EMOS_TIME_STEP_H '0348'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0354
-              trigger ../../prod/wave/0354/prodwave eq complete and ( ./0348 eq complete)
-              edit EMOS_TIME_STEP_H '0354'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            family 0360
-              trigger ../../prod/wave/0360/prodwave eq complete and ( ./0354 eq complete)
-              edit EMOS_TIME_STEP_H '0360'
-              task diss
-                late -s +00:05 -c +00:15
-                inlimit /emc_36r1/limits:w2diss
-                inlimit /limits:q2diss
-                label info ""
-                event pdb
-            endfamily
-            task check
-              trigger ./0360 eq complete
-          endfamily
-          task diss_wparam
-            late -s +00:05 -c +00:15
-            trigger ../prod/prod_wparam eq complete and ../../legA/prod2diss/diss_wparam eq complete
-            edit PROD_TASK 'w'
-            edit EMOS_TIME_STEP_H '0360'
-            edit EMOS_TYPE 'wp'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_waef_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/waef_postproc eq complete and ../../legA/prod2diss/diss_waef_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0360'
-            edit EMOS_TYPE 'pw'
-            edit EMOS_STREAM 'WE'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-          task diss_postproc
-            late -s +00:05 -c +00:15
-            trigger ../prod/enfo_postproc eq complete and ../../legA/prod2diss/diss_postproc eq complete
-            edit PROD_TASK 'p'
-            edit EMOS_TIME_STEP_H '0360'
-            edit EMOS_TYPE 'ep'
-            inlimit /emc_36r1/limits:q2diss
-            inlimit /limits:q2diss
-            label info ""
-            event pdb
-        endfamily
-      endfamily
-      family legBcpl
-        complete /emc_36r1/main/ref/00/events:240 or /emc_36r1/main/ref/00/events:360
-        trigger /emc_36r1/main/ref/00/events eq complete and /emc_36r1/main/ref/00/events:cpl and /emc_36r1/main/00/ref/oceini eq complete
-        edit EPSLEG '2'
-        edit EPSCOUPLE '1'
-        edit RUNCOUPLE '1'
-        edit OC_DELAY_START '0'
-        family fc
-          edit FCMEM '2240'
-          edit FCSTACK '700'
-          edit FCMRFS '0'
-          edit PRIORITY '71'
-          edit USER_PRIORITY '71'
-          edit N_PERT_AN '10'
-          edit SSTLEN '144'
-          edit EPSINISTEP_PREVIOUS '216'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          edit TSTEP '2700'
-          edit EPSFCRES '639'
-          edit RESOL '639'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-          edit CPUTIME '1000'
-          edit MEM '960'
-          edit THREADS '8'
-          edit NPES '8'
-          edit EPSLEG '2'
-          family pf
-            complete /emc_36r1/main/ref/00/events:cf
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTYPE 'pf'
-            edit EMOS_TYPE 'pf'
-            edit USER_PRIORITY '71'
-            edit PRIORITY '71'
-            edit FCNPES '32'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSFCRES '319'
-            edit EPSWAMRESOL 'global50'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit EPSINISTEP '360'
-            edit FCLENGTH '240'
-            edit TSTEP '1200'
-            edit EPSLEG '2'
-            edit CLASS 'od'
-            edit THREADS '2'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:pftotal
-            meter step -1 144 144
-            family 01
-              edit EPSMEMBER '1'
-              edit MEMBER '1'
-              edit SUBFSFAMILY '/pf001'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/01/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/01 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 02
-              edit EPSMEMBER '2'
-              edit MEMBER '2'
-              edit SUBFSFAMILY '/pf002'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/02/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/02 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 03
-              edit EPSMEMBER '3'
-              edit MEMBER '3'
-              edit SUBFSFAMILY '/pf003'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/03/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/03 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 04
-              edit EPSMEMBER '4'
-              edit MEMBER '4'
-              edit SUBFSFAMILY '/pf004'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/04/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/04 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 05
-              edit EPSMEMBER '5'
-              edit MEMBER '5'
-              edit SUBFSFAMILY '/pf005'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc1'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/05/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/05 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 06
-              edit EPSMEMBER '6'
-              edit MEMBER '6'
-              edit SUBFSFAMILY '/pf006'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc1'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/06/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/06 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 07
-              edit EPSMEMBER '7'
-              edit MEMBER '7'
-              edit SUBFSFAMILY '/pf007'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc1'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/07/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/07 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 08
-              edit EPSMEMBER '8'
-              edit MEMBER '8'
-              edit SUBFSFAMILY '/pf008'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc1'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/08/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/08 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 09
-              edit EPSMEMBER '9'
-              edit MEMBER '9'
-              edit SUBFSFAMILY '/pf009'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc1'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/09/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/09 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 10
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              edit SUBFSFAMILY '/pf010'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc2'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/10/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/10 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 11
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              edit SUBFSFAMILY '/pf011'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc2'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/11/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/11 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 12
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              edit SUBFSFAMILY '/pf012'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc2'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/12/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/12 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 13
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              edit SUBFSFAMILY '/pf013'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc2'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/13/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/13 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 14
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              edit SUBFSFAMILY '/pf014'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc2'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/14/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/14 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 15
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              edit SUBFSFAMILY '/pf015'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc3'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/15/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/15 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 16
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              edit SUBFSFAMILY '/pf016'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc3'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/16/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/16 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 17
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              edit SUBFSFAMILY '/pf017'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc3'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/17/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/17 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 18
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              edit SUBFSFAMILY '/pf018'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc3'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/18/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/18 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 19
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              edit SUBFSFAMILY '/pf019'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc3'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/19/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/19 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 20
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              edit SUBFSFAMILY '/pf020'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc4'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/20/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/20 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 21
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              edit SUBFSFAMILY '/pf021'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc4'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/21/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/21 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 22
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              edit SUBFSFAMILY '/pf022'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc4'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/22/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/22 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 23
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              edit SUBFSFAMILY '/pf023'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc4'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/23/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/23 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 24
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              edit SUBFSFAMILY '/pf024'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc4'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/24/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/24 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 25
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              edit SUBFSFAMILY '/pf025'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc5'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/25/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/25 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 26
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              edit SUBFSFAMILY '/pf026'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc5'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/26/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/26 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 27
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              edit SUBFSFAMILY '/pf027'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc5'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/27/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/27 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 28
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              edit SUBFSFAMILY '/pf028'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc5'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/28/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/28 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 29
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              edit SUBFSFAMILY '/pf029'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc5'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/29/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/29 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 30
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              edit SUBFSFAMILY '/pf030'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc6'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/30/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/30 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 31
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              edit SUBFSFAMILY '/pf031'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc6'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/31/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/31 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 32
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              edit SUBFSFAMILY '/pf032'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc6'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/32/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/32 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 33
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              edit SUBFSFAMILY '/pf033'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc6'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/33/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/33 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 34
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              edit SUBFSFAMILY '/pf034'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc6'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/34/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/34 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 35
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              edit SUBFSFAMILY '/pf035'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc7'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/35/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/35 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 36
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              edit SUBFSFAMILY '/pf036'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc7'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/36/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/36 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 37
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              edit SUBFSFAMILY '/pf037'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc7'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/37/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/37 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 38
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              edit SUBFSFAMILY '/pf038'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc7'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/38/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/38 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 39
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              edit SUBFSFAMILY '/pf039'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc7'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/39/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/39 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 40
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              edit SUBFSFAMILY '/pf040'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc8'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/40/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/40 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 41
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              edit SUBFSFAMILY '/pf041'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc8'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/41/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/41 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 42
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              edit SUBFSFAMILY '/pf042'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc8'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/42/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/42 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 43
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              edit SUBFSFAMILY '/pf043'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc8'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/43/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/43 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 44
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              edit SUBFSFAMILY '/pf044'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc8'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/44/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/44 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 45
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              edit SUBFSFAMILY '/pf045'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc9'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/45/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/45 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 46
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              edit SUBFSFAMILY '/pf046'
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc9'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/46/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/46 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 47
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              edit SUBFSFAMILY '/pf047'
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc9'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/47/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/47 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 48
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              edit SUBFSFAMILY '/pf048'
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc9'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/48/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/48 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 49
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              edit SUBFSFAMILY '/pf049'
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc9'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/49/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/49 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-            family 50
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              edit SUBFSFAMILY '/pf050'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc10'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger /emc_36r1/main/00/legA/fc/pf/50/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:modelepsB
-              endfamily
-              task getvarepsdata
-                trigger ../../../../legA/fc/pf/50 eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '144'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                edit SMSTRIES '1'
-                inlimit /emc_36r1/limits:modelepsB
-                meter step -1 144 144
-            endfamily
-          endfamily
-          family cf
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit MEMBER '0'
-            edit EPSMEMBER '0'
-            edit SUBFSFAMILY '/cf000'
-            edit EPSTYPE 'cf'
-            edit EMOS_TYPE 'cf'
-            edit USER_PRIORITY '72'
-            edit EPSNLEGS '3'
-            edit EPSFCLEV '62'
-            edit EPSWAMNSTPW '1'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSFCRES '319'
-            edit EPSWAMRESOL 'global50'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit EPSINISTEP '360'
-            edit TSTEP '1200'
-            edit EPSLEG '2'
-            edit CLASS 'od'
-            edit OCGROUP 'an0'
-            edit FCGROUP 'fc0'
-            edit FCCHUNK '1'
-            edit OCTOTAL '5'
-            edit FCTOTAL '51'
-            edit FCLENGTH '144'
-            edit FCLENGTH1 '216'
-            edit DAILY '0'
-            edit RUNVARFC '1'
-            family ocean
-              edit RUNACAN '0'
-              edit RUNVARFC '1'
-              edit RUNCOUPLE '0'
-              edit ACAN_LAG '-12'
-              edit EPSLEG '1'
-              task oceini
-                edit STREAM 'ocea'
-              task linkoce
-                trigger oceini eq complete
-              task addforce
-                trigger /emc_36r1/main/00/legA/fc/cf/modeleps eq complete
-              task runhope
-                trigger linkoce eq complete and addforce eq complete
-                edit FCLENGTH '216'
-                edit THREADS '16'
-                inlimit /emc_36r1/limits:modelepsB
-            endfamily
-            task getvarepsdata
-              trigger ../../../legA/fc/cf eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '2700'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSLEG '2'
-              edit EPSINISTEP '216'
-              edit EPSFCRES '639'
-              edit EPSFCRESN '319'
-              edit CLASS 'od'
-            task intHtoL
-              trigger getvarepsdata eq complete
-              edit MEM '1300'
-              edit MRF '10'
-              edit CPUTIME '1000'
-              edit STACK '450'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit TSTEP '2700'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '216'
-              edit EPSFCRES '319'
-              edit NPES '24'
-              edit FCNPES '24'
-              edit THREADS '2'
-              edit CLASS 'od'
-            task modeleps
-              trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSLEG '2'
-              edit EPSFCRES '319'
-              edit EPSINISTEP '360'
-              edit EPSINISTEP_PREVIOUS '216'
-              edit FCLENGTH '144'
-              edit EPSFCLENGTH_A '240'
-              edit MEM '3200'
-              edit MRF '10'
-              edit STACK '350'
-              edit FCCHUNK '1'
-              edit SMSTRIES '1'
-              edit NPES '1'
-              edit THREADS '64'
-              edit FCNPES '1'
-              edit TSTEP '2700'
-              edit CLASS 'od'
-              inlimit /emc_36r1/limits:modelepsB
-              meter step -1 144 144
-          endfamily
-          family reservation
-            trigger ./pf/46/intHtoL eq complete and ./pf/47/intHtoL eq complete and ./pf/48/intHtoL eq complete and ./pf/49/intHtoL eq complete and ./pf/50/intHtoL eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
-            inlimit /emc_36r1/limits:reservation
-            task reset_class
-              late -s +00:02 -c +00:02
-              edit RESERVATION_DEFINITION 'default'
-              label info ""
-            task reset_cpu
-              late -s +00:02 -c +00:02
-              complete /emc_36r1/main/ref/00/events:768
-              edit RESERVED_CPUS '0'
-              label info ""
-          endfamily
-        endfamily
-      endfamily
-      family legC
-        trigger /emc_36r1/main/ref/00/events eq complete and /emc_36r1/main/ref/00/events:768
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:35
-      trigger logfilestore eq complete and /emc_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete and /emc_36r1/main/ref/dummy eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-  family hc2
-    repeat date YMD 20091008 20121212 7
-    edit ACCOUNT 'oeenfo'
-    edit LOGTASK 'hc2'
-    edit QUEUE 'ns'
-    edit QUEUE_EPILOG 'ns'
-    edit ENSEMBLES '4'
-    edit ENS_SIZE '4'
-    edit RUNHINDCAST '1'
-    edit STREAM 'ENFH'
-    edit EMOS_STREAM 'ENFH'
-    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-    edit EMOS_BASE '00'
-    edit INICLASS 'EI'
-    edit INIEXPVER '0001'
-    edit INILEVELS '60'
-    edit DELETE_FAMILY 'true'
-    family back
-      trigger /emc_36r1/main/make eq complete
-      inlimit /emc_36r1/limits:hind
-      task stage_hc
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-      task rmfdb
-        trigger ./stage_hc eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-      task lock_fam
-        trigger 0 eq 1
-      task lock_1701
-        complete ./18 eq complete
-        trigger 0 eq 1
-      family 18
-        trigger ./rmfdb eq complete
-        edit DELTA_YEAR '-18'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                    edit SMSPASS 'stripped'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 17
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-17'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 16
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-16'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 15
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-15'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 14
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-14'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 13
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-13'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 12
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-12'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 11
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-11'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 10
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-10'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 09
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-09'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 08
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-08'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 07
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-07'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 06
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-06'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 05
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-05'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 04
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-04'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 03
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-03'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 02
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-02'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-      family 01
-        trigger ./lock_1701 eq complete and ./rmfdb eq complete
-        edit DELTA_YEAR '-01'
-        family m2
-          edit DELTA_DAY '-2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '3000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit FCNPES '16'
-          edit EPSSVTSTEP '900'
-          edit MEM '1600'
-          edit MRF '10'
-          edit NPES '16'
-          edit THREADS '4'
-          edit CPUTIME '12000'
-          edit STACK '350'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit CPUTIME '1000'
-            edit STACK '450'
-          task svsh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            edit MEMBER '0'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnhevo
-            trigger svnh eq complete
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit CPUTIME '120000'
-          task svshevo
-            trigger svsh eq complete
-            edit EVOLVE 'yes'
-          task svsave
-            trigger svshevo eq complete and svnhevo eq complete
-          task clean
-            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
-        endfamily
-        family sv
-          edit EVOLVE 'no'
-          edit FASTEX 'no'
-          edit EPSTYPE 'sv'
-          edit FCMEM '2000'
-          edit FCSTACK '400'
-          edit FCMRFS '100'
-          edit FCLENGTH '48'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          edit NPES '16'
-          edit EPSSVTSTEP '900'
-          task getini
-            edit LINIENDA '0'
-            edit INIDATEENDA '0'
-            edit EPSCOUPLE '0'
-            edit N_PERT_AN '10'
-            edit EPSCOUPL_A '0'
-            edit EPSCOUPL_B '0'
-            edit EPSCOUPL_C '0'
-          task inidata_sv
-            trigger getini eq complete
-            edit THREADS '8'
-          task targets
-            late -s +00:03 -c +00:10
-            edit EPSTCBB '1'
-            label da_info ""
-            label dcda_info ""
-            event sv
-          task svsh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '73'
-            inlimit /emc_36r1/limits:pesh 2
-          task svnh
-            trigger inidata_sv eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit THREADS '8'
-            edit USER_PRIORITY '74'
-            inlimit /emc_36r1/limits:pesh 2
-          task subspace
-            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
-          task sv1
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '72'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv2
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            edit USER_PRIORITY '71'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv3
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv4
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv5
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task sv6
-            trigger ( targets eq complete or targets:sv) and subspace eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit CPUTIME '12000'
-            edit STACK '350'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit EPSSVDIAB 'true'
-            edit THREADS '8'
-            inlimit /emc_36r1/limits:pesh 2
-          task getsvevo
-            event ecfs
-          task getsvs
-            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit EPSTROP '1'
-          task svnhevo
-            trigger svnh eq complete and ../legA/fc eq complete
-            edit MEM '1600'
-            edit MRF '10'
-            edit NPES '16'
-            edit THREADS '4'
-            edit STACK '350'
-            edit HEMISPHERE 'n'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-          task svshevo
-            trigger svsh eq complete and ../legA/fc eq complete
-            edit NPES '24'
-            edit THREADS '8'
-            edit MEM '1300'
-            edit MRF '10'
-            edit STACK '450'
-            edit EVOLVE 'yes'
-            edit ANNPES '8'
-            edit CPUTIME '120000'
-            inlimit /emc_36r1/limits:pesh 2
-        endfamily
-        family legA
-          family fc
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '240'
-            edit EPSINISTEP_PREVIOUS '0'
-            edit EPSWAMNFRE '30'
-            edit EPSWAMNANG '24'
-            edit TSTEP '1200'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '1'
-            task getini
-              edit LINIENDA '0'
-              edit INIDATEENDA '0'
-              edit EPSCOUPLE '0'
-              edit N_PERT_AN '10'
-              edit EPSCOUPL_A '0'
-              edit EPSCOUPL_B '0'
-              edit EPSCOUPL_C '0'
-            task inidata
-              trigger getini eq complete
-              edit THREADS '8'
-            task getae
-              event 1 
-            task rot
-              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
-              edit EPSTROP '1'
-            family pert_ic
-              trigger rot eq complete and inidata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTROP '1'
-              inlimit /emc_36r1/limits:pertic
-              family 00
-                task pertinic
-                  edit MEMBER '0'
-              endfamily
-              family 01
-                task pertinic
-                  edit MEMBER '1'
-              endfamily
-              family 02
-                task pertinic
-                  edit MEMBER '2'
-              endfamily
-              family 03
-                task pertinic
-                  edit MEMBER '3'
-              endfamily
-              family 04
-                task pertinic
-                  edit MEMBER '4'
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-              event 1 
-            task wavini
-              edit FSFAMILY 'mc'
-              edit PERSST 'true'
-              edit SSTINT '1'
-            task wavfcdata
-              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
-              edit EPSCOUPLE '1'
-            task getpersSST
-              trigger ./inidata eq complete
-              edit EPSCOUPLE '1'
-              edit EPS_INI_STREAM 'DA'
-              edit EPSFCRES '639'
-            family pf
-              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              meter step -1 240 240
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                task getiniLeg
-                  trigger ../../pert_ic/01/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                task getiniLeg
-                  trigger ../../pert_ic/02/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                task getiniLeg
-                  trigger ../../pert_ic/03/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                task getiniLeg
-                  trigger ../../pert_ic/04/pertinic eq complete
-                  edit LINIENDA '0'
-                  edit INIDATEENDA '0'
-                  edit EPSCOUPLE '0'
-                  edit N_PERT_AN '10'
-                  edit EPSCOUPL_A '0'
-                  edit EPSCOUPL_B '0'
-                  edit EPSCOUPL_C '0'
-                task modeleps
-                  trigger getiniLeg eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '30'
-                  edit EPSWAMNANG '24'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '639'
-                  edit EPSINISTEP '216'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '240'
-                  edit TSTEP '1200'
-                  edit CLASS 'od'
-                  edit THREADS '4'
-                  inlimit /emc_36r1/limits:pesh 6
-                  meter step -1 240 240
-              endfamily
-            endfamily
-            family cf
-              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSWAMRESOL 'global50'
-              edit EPSFCRES '639'
-              edit EPSWAMNFRE '30'
-              edit EPSWAMNANG '24'
-              edit EPSINISTEP '216'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '1'
-              edit CLASS 'od'
-              task getiniLeg
-                trigger ../inidata eq complete and ../wavini eq complete
-                edit LINIENDA '0'
-                edit INIDATEENDA '0'
-                edit EPSCOUPLE '0'
-                edit N_PERT_AN '10'
-                edit EPSCOUPL_A '0'
-                edit EPSCOUPL_B '0'
-                edit EPSCOUPL_C '0'
-              task modeleps
-                trigger getiniLeg eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSLEG '1'
-                edit EPSFCRES '639'
-                edit EPSINISTEP '216'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit FCLENGTH '240'
-                edit TSTEP '1200'
-                edit CLASS 'od'
-                edit FCNPES '32'
-                edit THREADS '4'
-                inlimit /emc_36r1/limits:pesh 6
-                meter step -1 240 240
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../fc eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:dp
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '0:240:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                task extrafields
-                  edit EPSFCRES '639'
-                  edit FCLENGTH '240'
-                  edit FCLENGTH0 '0'
-                  edit RUNVARFC '1'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task extrafields
-                    edit EPSFCRES '639'
-                    edit FCLENGTH '240'
-                    edit FCLENGTH0 '0'
-                    edit RUNVARFC '1'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family legBcpl
-          trigger ./legA eq complete
-          family fc
-            edit EPSCOUPLE '1'
-            edit FCMEM '2240'
-            edit FCSTACK '700'
-            edit FCMRFS '0'
-            edit PRIORITY '67'
-            edit USER_PRIORITY '67'
-            edit N_PERT_AN '10'
-            edit SSTLEN '144'
-            edit EPSINISTEP_PREVIOUS '216'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            edit TSTEP '2700'
-            edit EPSFCRES '639'
-            edit RESOL '639'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-            edit CPUTIME '1000'
-            edit MEM '960'
-            edit THREADS '8'
-            edit NPES '8'
-            edit EPSLEG '2'
-            family pf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit EPSTYPE 'pf'
-              edit EMOS_TYPE 'pf'
-              edit USER_PRIORITY '67'
-              edit PRIORITY '67'
-              edit FCNPES '32'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit FCLENGTH '240'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit THREADS '2'
-              edit RUNVARFC '1'
-              meter step -1 552 552
-              family 01
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                edit SUBFSFAMILY '/pf001'
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/01 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 02
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                edit SUBFSFAMILY '/pf002'
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/02 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 03
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                edit SUBFSFAMILY '/pf003'
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/03 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-              family 04
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                edit SUBFSFAMILY '/pf004'
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit FCLENGTH '144'
-                edit FCLENGTH1 '216'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                family ocean
-                  edit RUNACAN '0'
-                  edit RUNVARFC '1'
-                  edit RUNCOUPLE '0'
-                  edit ACAN_LAG '-12'
-                  edit EPSLEG '1'
-                  task oceini
-                    edit STREAM 'ocea'
-                  task linkoce
-                    trigger oceini eq complete
-                  task addforce
-                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
-                  task runhope
-                    trigger linkoce eq complete and addforce eq complete
-                    edit FCLENGTH '216'
-                    edit THREADS '16'
-                    inlimit /emc_36r1/limits:pesh
-                endfamily
-                task getvarepsdata
-                  trigger ../../../../legA/fc/pf/04 eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '639'
-                  edit EPSFCRESN '319'
-                  edit CLASS 'od'
-                task intHtoL
-                  trigger getvarepsdata eq complete
-                  edit MEM '1300'
-                  edit MRF '10'
-                  edit CPUTIME '1000'
-                  edit STACK '450'
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit EPSWAMRESOL 'global50'
-                  edit TSTEP '2700'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '319'
-                  edit NPES '24'
-                  edit FCNPES '24'
-                  edit THREADS '2'
-                  edit CLASS 'od'
-                task modeleps
-                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                  edit EPSNLEGS '3'
-                  edit EPSFCLEV '62'
-                  edit EPSWAMNSTPW '1'
-                  edit EPSWAMRESOL 'global50'
-                  edit EPSWAMNFRE '25'
-                  edit EPSWAMNANG '12'
-                  edit EPSLEG '2'
-                  edit EPSFCRES '319'
-                  edit EPSINISTEP '360'
-                  edit EPSINISTEP_PREVIOUS '216'
-                  edit FCLENGTH '552'
-                  edit EPSFCLENGTH_A '240'
-                  edit MEM '3200'
-                  edit MRF '10'
-                  edit STACK '350'
-                  edit FCCHUNK '1'
-                  edit NPES '1'
-                  edit THREADS '64'
-                  edit FCNPES '1'
-                  edit TSTEP '2700'
-                  edit CLASS 'od'
-                  edit SMSTRIES '1'
-                  inlimit /emc_36r1/limits:pesh
-                  meter step -1 552 552
-              endfamily
-            endfamily
-            family cf
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit MEMBER '0'
-              edit EPSMEMBER '0'
-              edit SUBFSFAMILY '/cf000'
-              edit EPSTYPE 'cf'
-              edit EMOS_TYPE 'cf'
-              edit USER_PRIORITY '78'
-              edit EPSNLEGS '3'
-              edit EPSFCLEV '62'
-              edit EPSWAMNSTPW '1'
-              edit EPSINISTEP_PREVIOUS '0'
-              edit EPSFCRES '319'
-              edit EPSWAMRESOL 'global50'
-              edit EPSWAMNFRE '25'
-              edit EPSWAMNANG '12'
-              edit EPSINISTEP '552'
-              edit TSTEP '1200'
-              edit EPSLEG '2'
-              edit CLASS 'od'
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit FCLENGTH '144'
-              edit FCLENGTH1 '216'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              family ocean
-                edit RUNACAN '0'
-                edit RUNVARFC '1'
-                edit RUNCOUPLE '0'
-                edit ACAN_LAG '-12'
-                edit EPSLEG '1'
-                task oceini
-                  edit STREAM 'ocea'
-                task linkoce
-                  trigger oceini eq complete
-                task addforce
-                  trigger ../../../../legA/fc/cf/modeleps eq complete
-                task runhope
-                  trigger linkoce eq complete and addforce eq complete
-                  edit FCLENGTH '216'
-                  edit THREADS '16'
-                  inlimit /emc_36r1/limits:pesh
-              endfamily
-              task getvarepsdata
-                trigger ../../../legA/fc/cf eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '639'
-                edit EPSFCRESN '319'
-                edit CLASS 'od'
-              task intHtoL
-                trigger getvarepsdata eq complete
-                edit MEM '1300'
-                edit MRF '10'
-                edit CPUTIME '1000'
-                edit STACK '450'
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSINISTEP_PREVIOUS '0'
-                edit EPSWAMRESOL 'global50'
-                edit TSTEP '2700'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSINISTEP '216'
-                edit EPSFCRES '319'
-                edit NPES '24'
-                edit FCNPES '24'
-                edit THREADS '2'
-                edit CLASS 'od'
-              task modeleps
-                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
-                edit EPSNLEGS '3'
-                edit EPSFCLEV '62'
-                edit EPSWAMNSTPW '1'
-                edit EPSWAMRESOL 'global50'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSLEG '2'
-                edit EPSFCRES '319'
-                edit EPSINISTEP '360'
-                edit EPSINISTEP_PREVIOUS '216'
-                edit FCLENGTH '552'
-                edit EPSFCLENGTH_A '240'
-                edit MEM '3200'
-                edit MRF '10'
-                edit STACK '350'
-                edit FCCHUNK '1'
-                edit SMSTRIES '1'
-                edit NPES '1'
-                edit THREADS '64'
-                edit FCNPES '1'
-                edit TSTEP '2700'
-                edit CLASS 'od'
-                inlimit /emc_36r1/limits:pesh
-                meter step -1 552 552
-            endfamily
-          endfamily
-          family postproc
-            trigger ./fc eq complete
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              trigger ../../legA/postproc/dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:dp
-              family dp
-                trigger ./cf eq complete and ./pf eq complete
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-                edit OVERLAP '1'
-                edit STEPS '216:240:6'
-                inlimit /emc_36r1/limits:dp
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derived_param
-                    edit MEMBER 'off'
-                endfamily
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 01
-                    edit EPSMEMBER '1'
-                    edit MEMBER '1'
-                    edit SUBFSFAMILY '/pf001'
-                    task derived_param
-                  endfamily
-                  family 02
-                    edit EPSMEMBER '2'
-                    edit MEMBER '2'
-                    edit SUBFSFAMILY '/pf002'
-                    task derived_param
-                  endfamily
-                  family 03
-                    edit EPSMEMBER '3'
-                    edit MEMBER '3'
-                    edit SUBFSFAMILY '/pf003'
-                    task derived_param
-                  endfamily
-                  family 04
-                    edit EPSMEMBER '4'
-                    edit MEMBER '4'
-                    edit SUBFSFAMILY '/pf004'
-                    task derived_param
-                  endfamily
-                endfamily
-              endfamily
-              family cf
-                trigger ../../fc/cf eq complete
-                edit EMOS_TYPE 'cf'
-                task derived_param
-                  edit MEMBER 'off'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  trigger ../../../fc/pf/01 eq complete
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  task derived_param
-                endfamily
-                family 02
-                  trigger ../../../fc/pf/02 eq complete
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  task derived_param
-                endfamily
-                family 03
-                  trigger ../../../fc/pf/03 eq complete
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  task derived_param
-                endfamily
-                family 04
-                  trigger ../../../fc/pf/04 eq complete
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  task derived_param
-                endfamily
-              endfamily
-            endfamily
-            family extra
-              trigger ./dp eq complete
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
-              edit STEPS '246:768:6'
-              inlimit /emc_36r1/limits:extra
-              family cf
-                edit EMOS_TYPE 'cf'
-                edit EPSFCRES '319'
-                task extrafields
-                  edit FCLENGTH '768'
-                  edit FCLENGTH0 '240'
-                task wm_sfc
-                  trigger extrafields eq complete
-                  edit FCLENGTH '768'
-                task wm_ua
-                  trigger extrafields eq complete and wm_sfc eq complete
-                  edit FCLENGTH '768'
-              endfamily
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 01
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  edit SUBFSFAMILY '/pf001'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 02
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  edit SUBFSFAMILY '/pf002'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 03
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  edit SUBFSFAMILY '/pf003'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-                family 04
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  edit SUBFSFAMILY '/pf004'
-                  edit EPSFCRES '319'
-                  task extrafields
-                    edit FCLENGTH '768'
-                    edit FCLENGTH0 '240'
-                  task wm_sfc
-                    trigger extrafields eq complete
-                    edit FCLENGTH '768'
-                  task wm_ua
-                    trigger extrafields eq complete and wm_sfc eq complete
-                    edit FCLENGTH '768'
-                endfamily
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        task save_logs
-          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit SCHOST 'localhost'
-      endfamily
-    endfamily
-    family arch
-      edit EMOS_TYPE 'an'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-      edit FSFAMILY 'mars'
-      edit OVERLAP '0'
-      edit YMD '20100114'
-      limit mutex 1
-      inlimit /emc_36r1/limits:mars
-      inlimit /limits:mars
-      family 18
-        trigger ( ../back/18 eq complete)
-        edit DELTA_YEAR '-18'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/18/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 17
-        trigger ( ../back/17 eq complete)
-        edit DELTA_YEAR '-17'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/17/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 16
-        trigger ( ../back/16 eq complete)
-        edit DELTA_YEAR '-16'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/16/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 15
-        trigger ( ../back/15 eq complete)
-        edit DELTA_YEAR '-15'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/15/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 14
-        trigger ( ../back/14 eq complete)
-        edit DELTA_YEAR '-14'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/14/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 13
-        trigger ( ../back/13 eq complete)
-        edit DELTA_YEAR '-13'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/13/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 12
-        trigger ( ../back/12 eq complete)
-        edit DELTA_YEAR '-12'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/12/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 11
-        trigger ( ../back/11 eq complete)
-        edit DELTA_YEAR '-11'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/11/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 10
-        trigger ( ../back/10 eq complete)
-        edit DELTA_YEAR '-10'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/10/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 09
-        trigger ( ../back/09 eq complete)
-        edit DELTA_YEAR '-09'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/09/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 08
-        trigger ( ../back/08 eq complete)
-        edit DELTA_YEAR '-08'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/08/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 07
-        trigger ( ../back/07 eq complete)
-        edit DELTA_YEAR '-07'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/07/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 06
-        trigger ( ../back/06 eq complete)
-        edit DELTA_YEAR '-06'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/06/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 05
-        trigger ( ../back/05 eq complete)
-        edit DELTA_YEAR '-05'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/05/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 04
-        trigger ( ../back/04 eq complete)
-        edit DELTA_YEAR '-04'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/04/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 03
-        trigger ( ../back/03 eq complete)
-        edit DELTA_YEAR '-03'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/03/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 02
-        trigger ( ../back/02 eq complete)
-        edit DELTA_YEAR '-02'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/02/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-      family 01
-        trigger ( ../back/01 eq complete)
-        edit DELTA_YEAR '-01'
-        family legA
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf144
-              edit STEPS '0/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/144/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '150/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf072
-              edit STEPS '0/to/072/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                edit STEPS '006/to/072/by/6'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '078/to/144/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit RUNVARFC '1'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '006/to/144/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legB
-          edit EPSLEG '2'
-          edit EPSWAMNFRE '25'
-          edit EPSWAMNANG '12'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                edit EMOS_TYPE 'pf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 240
-                  edit STEPS '216/222/228/234/240'
-                  edit OVERLAP '1'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 360
-                  edit STEPS '246/to/360/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '240/to/360'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            task cfml
-              edit STEPS '216'
-            family cf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family pf240
-              edit STEPS '216/228/240'
-              edit OVERLAP '1'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf300
-              edit STEPS '246/to/300/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf360
-              edit STEPS '306/to/360/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            task pfml
-              edit STEPS '360'
-            task accum
-              edit STEPS '240'
-              edit OVERLAP '1'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family coupled
-            edit EPSLEG '2'
-            edit OCLEG '2'
-            edit OCEPS '2'
-            edit FCCHUNK '1'
-            edit FCLENGTH '360'
-            edit FCLENGTH0 '216'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-        endfamily
-        family legC
-          edit EPSLEG '3'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit EMOS_TYPE 'an'
-          edit EPSFCRES '255'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family cf
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            edit EMOS_TYPE 'pf'
-            family cf408
-              edit STEPS '366/to/408/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf480
-              edit STEPS '414/to/480/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf600
-              edit STEPS '486/to/600/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf768
-              edit STEPS '606/to/768/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'ENWH'
-                edit EMOS_STREAM 'ENWH'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family postproc
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            edit FCCHUNK '1'
-            edit FCLENGTH '768'
-            inlimit /emc_36r1/limits:postproc
-            family dp
-              edit RUNVARFC '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              edit EMOS_TYPE 'pf'
-              edit STEPS '366/to/768/by/6'
-              family cf
-                edit EMOS_TYPE 'cf'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-                task extra_arc
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit STEPS '360/to/768'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family extra
-              trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
-              edit RUNVARFC '1'
-              task wm_sfc_arc
-                label files ""
-                label info ""
-                event fdb
-              task wm_ua_arc
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family nino
-              edit FCCHUNK '1'
-              edit OCTOTAL '5'
-              edit FCTOTAL '51'
-              edit DAILY '0'
-              edit RUNVARFC '1'
-              edit FCLENGTH1 '360'
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit FCLENGTH '768'
-              edit EPSCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              limit semaphore 10
-              inlimit /limits:linux_cluster
-              inlimit semaphore
-              family 00
-                edit OCGROUP 'an00'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '0'
-                edit MEMBER '0'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 01
-                edit OCGROUP 'an1'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '1'
-                edit MEMBER '1'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 02
-                edit OCGROUP 'an2'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '2'
-                edit MEMBER '2'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 03
-                edit OCGROUP 'an3'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '3'
-                edit MEMBER '3'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-              family 04
-                edit OCGROUP 'an4'
-                edit FCGROUP 'fc0'
-                edit EPSMEMBER '4'
-                edit MEMBER '4'
-                task nino_daily
-                task tcyc
-                  trigger nino_daily eq complete or nino_daily eq aborted
-              endfamily
-            endfamily
-            task tcyctoecfs
-              trigger nino eq complete
-              edit QUEUE 'emos-e'
-              edit QUEUE_EPILOG 'emos-exp'
-              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit LOGDIR '/vol/emos_nc/output'
-              edit SMSOUT '/vol/emos_nc/output'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit EPSCOUPLE '1'
-              edit FCLENGTH '768'
-              inlimit /limits:linux_cluster
-          endfamily
-        endfamily
-        task hc_clean
-          trigger legA eq complete and legB eq complete and legC eq complete
-        task save_logs
-          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-      endfamily
-    endfamily
-    family efi
-      trigger ./back eq complete
-      edit MAXDAY '15'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-      inlimit /emc_36r1/limits:efih
-      family stage
-        edit RETRIEVE 'stage'
-        edit RF_NAME 'all'
-        task prep
-      endfamily
-      family op
-        trigger ./stage eq complete
-        family prep
-          family stage
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit ACC '24'
-            edit EFI_STEP1 '00'
-            edit EFI_STEP2 '24'
-            edit RETRIEVE 'stage'
-            inlimit /limits:linux_cluster
-            family all
-              edit RF_NAME 'all'
-              task prep
-            endfamily
-          endfamily
-          family d0105_24
-            edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
-            edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
-            edit ACC '24'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family d0610_24
-            edit EFI_STEP1 '108 120 132 144 168 192 216'
-            edit EFI_STEP2 '132 144 156 168 192 216 240'
-            edit ACC '24'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family nop
-        trigger ./stage eq complete
-        family prep
-          family stage
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit ACC '24'
-            edit EFI_STEP1 '00'
-            edit EFI_STEP2 '24'
-            edit RETRIEVE 'stage'
-            inlimit /limits:linux_cluster
-            family all
-              edit RF_NAME 'all'
-              task prep
-            endfamily
-          endfamily
-          family d0105_24
-            edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
-            edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
-            edit ACC '24'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-          family d0610_24
-            edit EFI_STEP1 '108 120 132 144 168 192 216'
-            edit EFI_STEP2 '132 144 156 168 192 216 240'
-            edit ACC '24'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-          family d1115_24
-            edit EFI_STEP1 '240 264 288 312 336'
-            edit EFI_STEP2 '264 288 312 336 360'
-            edit ACC '24'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-          family d0102_06
-            edit EFI_STEP1 '006 012 018 024 030 036 042 048'
-            edit EFI_STEP2 '006 012 018 024 030 036 042 048'
-            edit ACC '0'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-          family d0304_06
-            edit EFI_STEP1 '054 060 066 072 078 084 090 096'
-            edit EFI_STEP2 '054 060 066 072 078 084 090 096'
-            edit ACC '0'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-          family d0506_06
-            edit EFI_STEP1 '102 108 114 120 126 132 138 144'
-            edit EFI_STEP2 '102 108 114 120 126 132 138 144'
-            edit ACC '0'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-          family d0708_06
-            edit EFI_STEP1 '150 156 162 168 174 180 186 192'
-            edit EFI_STEP2 '150 156 162 168 174 180 186 192'
-            edit ACC '0'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-          family d0910_06
-            edit EFI_STEP1 '198 204 210 216 222 228 234 240'
-            edit EFI_STEP2 '198 204 210 216 222 228 234 240'
-            edit ACC '0'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-    family adm
-      task hindsync
-        trigger ../back eq complete and ../arch eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-        edit NH_WEEKS_KEPT '3'
-        edit BACKUP_HCFDB '0'
-      family fri
-        complete ./fri/compl eq complete and ./fri/dummy eq queued
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-        task dummy
-          cron -w 5 09:00
-        task compl
-          complete ./dummy eq active or ./dummy eq submitted
-          trigger 1 eq 0
-      endfamily
-      family 1to2
-        edit ORIG_FDB_ROOT 'undef'
-        edit DEST_FDB_ROOT 'undef'
-        edit SMSINCLUDE '/home/ma/emos/def/o/include'
-        family chver
-          repeat integer DELTA_YEAR -18 -1
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-          edit VERSION '9906'
-          edit VERSION_TO '9936'
-          edit CHVER_FDB_ROOT '/ma_fdb'
-          edit GENERAT '1'
-          edit CLEANER '0'
-          family enfh
-            edit CHVER_STREAM 'enfh'
-            family 0
-              edit CHVER_TYPE ':0000:[0:]:'
-              task chver
-                label info ""
-            endfamily
-            family 1
-              edit CHVER_TYPE ':0000:1:'
-              task chver
-                label info ""
-            endfamily
-            family 2
-              edit CHVER_TYPE ':0000:2:'
-              task chver
-                label info ""
-            endfamily
-            family 3
-              edit CHVER_TYPE ':0000:3:'
-              task chver
-                label info ""
-            endfamily
-            family 4
-              edit CHVER_TYPE ':0000:4:'
-              task chver
-                label info ""
-            endfamily
-          endfamily
-          family enwh
-            edit CHVER_STREAM 'enwh'
-            task chver
-              label info ""
-          endfamily
-          family efho
-            edit CHVER_STREAM 'efho'
-            task chver
-              label info ""
-          endfamily
-          family ewho
-            edit CHVER_STREAM 'ewho'
-            task chver
-              label info ""
-          endfamily
-          task save_logs
-            trigger enfh eq complete and enwh eq complete and efho eq complete and ewho eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1'
-            edit SCHOST 'localhost'
-        endfamily
-        family arch
-          trigger ./chver:DELTA_YEAR gt ./arch:DELTA_YEAR or ./chver eq complete
-          repeat integer DELTA_YEAR -18 -1
-          edit EMOS_TYPE 'an'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit VERSION '9936'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family legA
-            family cf
-              edit EMOS_TYPE 'cf'
-              edit NUMBER '0'
-              family cf144
-                edit STEPS '0/to/144/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  edit STEPS '006/to/144/by/6'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf240
-                edit STEPS '150/to/240/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family pf
-              edit EMOS_TYPE 'pf'
-              family pf072
-                edit STEPS '0/to/072/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  edit STEPS '006/to/072/by/6'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf144
-                edit STEPS '078/to/144/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf192
-                edit STEPS '150/to/192/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf240
-                edit STEPS '198/to/240/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfml
-                  edit STEPS '216'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family postproc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit RUNVARFC '1'
-              inlimit /emc_36r1/limits:postproc
-              family dp
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 144
-                    edit STEPS '006/to/144/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 240
-                    edit STEPS '150/to/240/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '0/to/240'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  family 144
-                    edit STEPS '006/to/144/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 240
-                    edit STEPS '150/to/240/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '0/to/240'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-              endfamily
-            endfamily
-            family coupled
-              trigger ./cf eq complete and ./pf eq complete
-              edit EPSLEG '1'
-              edit OCLEG '1'
-              edit OCEPS '1'
-              edit FCCHUNK '1'
-              edit FCLENGTH '240'
-              edit FCLENGTH0 '0'
-              edit OCEPSTOT '3'
-              edit FCTOTAL '51'
-              edit RUNVARFC '1'
-              edit EPSCOUPLE '1'
-              edit RUNCOUPLE '0'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              inlimit /emc_36r1/lag/ref/00:mutex
-              task preparcoce
-              task arcfc
-                trigger preparcoce eq complete
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family legB
-            edit EPSLEG '2'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            inlimit /emc_36r1/limits:mars
-            inlimit /limits:mars
-            family postproc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              inlimit /emc_36r1/limits:postproc
-              family dp
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 240
-                    edit STEPS '216/222/228/234/240'
-                    edit OVERLAP '1'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 360
-                    edit STEPS '246/to/360/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '240/to/360'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  family 240
-                    edit STEPS '216/222/228/234/240'
-                    edit OVERLAP '1'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 360
-                    edit STEPS '246/to/360/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '240/to/360'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-              endfamily
-            endfamily
-            family cf
-              edit EMOS_TYPE 'cf'
-              edit NUMBER '0'
-              task cfml
-                edit STEPS '216'
-              family cf240
-                edit STEPS '216/228/240'
-                edit OVERLAP '1'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf300
-                edit STEPS '246/to/300/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf360
-                edit STEPS '306/to/360/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task accum
-                edit STEPS '240'
-                edit OVERLAP '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf
-              edit EMOS_TYPE 'pf'
-              family pf240
-                edit STEPS '216/228/240'
-                edit OVERLAP '1'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf300
-                edit STEPS '246/to/300/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf360
-                edit STEPS '306/to/360/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task pfml
-                edit STEPS '360'
-              task accum
-                edit STEPS '240'
-                edit OVERLAP '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family coupled
-              edit EPSLEG '2'
-              edit OCLEG '2'
-              edit OCEPS '2'
-              edit FCCHUNK '1'
-              edit FCLENGTH '360'
-              edit FCLENGTH0 '216'
-              edit OCEPSTOT '3'
-              edit FCTOTAL '51'
-              edit RUNVARFC '1'
-              edit EPSCOUPLE '1'
-              edit RUNCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              inlimit /emc_36r1/lag/ref/00:mutex
-              task preparcoce
-              task arcfc
-                trigger preparcoce eq complete
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family legC
-            edit EPSLEG '3'
-            edit FSFAMILY 'mars'
-            edit OVERLAP '0'
-            edit EMOS_TYPE 'an'
-            edit EPSFCRES '255'
-            inlimit /emc_36r1/limits:mars
-            inlimit /limits:mars
-            family cf
-              edit EMOS_TYPE 'cf'
-              edit NUMBER '0'
-              family cf408
-                edit STEPS '366/to/408/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf480
-                edit STEPS '414/to/480/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf600
-                edit STEPS '486/to/600/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf768
-                edit STEPS '606/to/768/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family pf
-              edit EMOS_TYPE 'pf'
-              family cf408
-                edit STEPS '366/to/408/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf480
-                edit STEPS '414/to/480/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf600
-                edit STEPS '486/to/600/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf768
-                edit STEPS '606/to/768/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family postproc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit FCCHUNK '1'
-              edit FCLENGTH '768'
-              inlimit /emc_36r1/limits:postproc
-              family dp
-                trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-                edit RUNVARFC '1'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-                edit EMOS_TYPE 'pf'
-                edit STEPS '366/to/768/by/6'
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                  task extra_arc
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit STEPS '360/to/768'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family pf
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                  task extra_arc
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit STEPS '360/to/768'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-              endfamily
-              family extra
-                trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
-                edit RUNVARFC '1'
-                task wm_sfc_arc
-                  label files ""
-                  label info ""
-                  event fdb
-                task wm_ua_arc
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family nino
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                edit FCLENGTH1 '360'
-                edit QUEUE 'emos-e'
-                edit QUEUE_EPILOG 'emos-exp'
-                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                edit LOGDIR '/vol/emos_nc/output'
-                edit SMSOUT '/vol/emos_nc/output'
-                edit FCLENGTH '768'
-                edit EPSCOUPLE '1'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                limit semaphore 10
-                inlimit /limits:linux_cluster
-                inlimit semaphore
-                family 00
-                  edit OCGROUP 'an00'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '0'
-                  edit MEMBER '0'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 01
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 02
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 03
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 04
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-              endfamily
-              task tcyctoecfs
-                trigger nino eq complete
-                edit QUEUE 'emos-e'
-                edit QUEUE_EPILOG 'emos-exp'
-                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                edit LOGDIR '/vol/emos_nc/output'
-                edit SMSOUT '/vol/emos_nc/output'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                edit EPSCOUPLE '1'
-                edit FCLENGTH '768'
-                inlimit /limits:linux_cluster
-            endfamily
-          endfamily
-          task save_logs
-            trigger legA eq complete and legB eq complete and legC eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1'
-            edit SCHOST 'localhost'
-        endfamily
-        family clean
-          task chver
-            trigger ../arch eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            edit GENERAT '0'
-            edit CLEANER '1'
-        endfamily
-      endfamily
-      family eto1
-        trigger ./1to2 eq complete
-        edit ORIG_FDB_ROOT 'undef'
-        edit DEST_FDB_ROOT 'undef'
-        family chver
-          repeat integer DELTA_YEAR -18 -1
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-          edit VERSION '0046'
-          edit VERSION_TO '9906'
-          edit CHVER_FDB_ROOT '/ma_fdb'
-          edit GENERAT '1'
-          edit CLEANER '0'
-          family enfh
-            edit CHVER_STREAM 'enfh'
-            family 0
-              edit CHVER_TYPE ':0000:[0:]:'
-              task chver
-                label info ""
-            endfamily
-            family 1
-              edit CHVER_TYPE ':0000:1:'
-              task chver
-                label info ""
-            endfamily
-            family 2
-              edit CHVER_TYPE ':0000:2:'
-              task chver
-                label info ""
-            endfamily
-            family 3
-              edit CHVER_TYPE ':0000:3:'
-              task chver
-                label info ""
-            endfamily
-            family 4
-              edit CHVER_TYPE ':0000:4:'
-              task chver
-                label info ""
-            endfamily
-          endfamily
-          family enwh
-            edit CHVER_STREAM 'enwh'
-            task chver
-              label info ""
-          endfamily
-          family efho
-            edit CHVER_STREAM 'efho'
-            task chver
-              label info ""
-          endfamily
-          family ewho
-            edit CHVER_STREAM 'ewho'
-            task chver
-              label info ""
-          endfamily
-          task save_logs
-            trigger enfh eq complete and enwh eq complete and efho eq complete and ewho eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1'
-            edit SCHOST 'localhost'
-        endfamily
-        family arch
-          trigger ./chver:DELTA_YEAR gt ./arch:DELTA_YEAR or ./chver eq complete
-          repeat integer DELTA_YEAR -18 -1
-          edit EMOS_TYPE 'an'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          edit FSFAMILY 'mars'
-          edit OVERLAP '0'
-          edit VERSION '9906'
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family legA
-            family cf
-              edit EMOS_TYPE 'cf'
-              edit NUMBER '0'
-              family cf144
-                edit STEPS '0/to/144/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  edit STEPS '006/to/144/by/6'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf240
-                edit STEPS '150/to/240/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family pf
-              edit EMOS_TYPE 'pf'
-              family pf072
-                edit STEPS '0/to/072/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  edit STEPS '006/to/072/by/6'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf144
-                edit STEPS '078/to/144/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf192
-                edit STEPS '150/to/192/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf240
-                edit STEPS '198/to/240/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfml
-                  edit STEPS '216'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family postproc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit RUNVARFC '1'
-              inlimit /emc_36r1/limits:postproc
-              family dp
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 144
-                    edit STEPS '006/to/144/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 240
-                    edit STEPS '150/to/240/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '0/to/240'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  family 144
-                    edit STEPS '006/to/144/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 240
-                    edit STEPS '150/to/240/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '0/to/240'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-              endfamily
-            endfamily
-            family coupled
-              trigger ./cf eq complete and ./pf eq complete
-              edit EPSLEG '1'
-              edit OCLEG '1'
-              edit OCEPS '1'
-              edit FCCHUNK '1'
-              edit FCLENGTH '240'
-              edit FCLENGTH0 '0'
-              edit OCEPSTOT '3'
-              edit FCTOTAL '51'
-              edit RUNVARFC '1'
-              edit EPSCOUPLE '1'
-              edit RUNCOUPLE '0'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              inlimit /emc_36r1/lag/ref/00:mutex
-              task preparcoce
-              task arcfc
-                trigger preparcoce eq complete
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family legB
-            edit EPSLEG '2'
-            edit EPSWAMNFRE '25'
-            edit EPSWAMNANG '12'
-            inlimit /emc_36r1/limits:mars
-            inlimit /limits:mars
-            family postproc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              inlimit /emc_36r1/limits:postproc
-              family dp
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-                family pf
-                  edit EMOS_TYPE 'pf'
-                  family 240
-                    edit STEPS '216/222/228/234/240'
-                    edit OVERLAP '1'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 360
-                    edit STEPS '246/to/360/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '240/to/360'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  family 240
-                    edit STEPS '216/222/228/234/240'
-                    edit OVERLAP '1'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  family 360
-                    edit STEPS '246/to/360/by/6'
-                    task derivedp
-                      label files ""
-                      label info ""
-                      event fdb
-                  endfamily
-                  task extra_arc
-                    edit STEPS '240/to/360'
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit RUNVARFC '1'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-              endfamily
-            endfamily
-            family cf
-              edit EMOS_TYPE 'cf'
-              edit NUMBER '0'
-              task cfml
-                edit STEPS '216'
-              family cf240
-                edit STEPS '216/228/240'
-                edit OVERLAP '1'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf300
-                edit STEPS '246/to/300/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf360
-                edit STEPS '306/to/360/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task accum
-                edit STEPS '240'
-                edit OVERLAP '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf
-              edit EMOS_TYPE 'pf'
-              family pf240
-                edit STEPS '216/228/240'
-                edit OVERLAP '1'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf300
-                edit STEPS '246/to/300/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf360
-                edit STEPS '306/to/360/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task pfml
-                edit STEPS '360'
-              task accum
-                edit STEPS '240'
-                edit OVERLAP '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family coupled
-              edit EPSLEG '2'
-              edit OCLEG '2'
-              edit OCEPS '2'
-              edit FCCHUNK '1'
-              edit FCLENGTH '360'
-              edit FCLENGTH0 '216'
-              edit OCEPSTOT '3'
-              edit FCTOTAL '51'
-              edit RUNVARFC '1'
-              edit EPSCOUPLE '1'
-              edit RUNCOUPLE '1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              inlimit /emc_36r1/lag/ref/00:mutex
-              task preparcoce
-              task arcfc
-                trigger preparcoce eq complete
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family legC
-            edit EPSLEG '3'
-            edit FSFAMILY 'mars'
-            edit OVERLAP '0'
-            edit EMOS_TYPE 'an'
-            edit EPSFCRES '255'
-            inlimit /emc_36r1/limits:mars
-            inlimit /limits:mars
-            family cf
-              edit EMOS_TYPE 'cf'
-              edit NUMBER '0'
-              family cf408
-                edit STEPS '366/to/408/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf480
-                edit STEPS '414/to/480/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf600
-                edit STEPS '486/to/600/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf768
-                edit STEPS '606/to/768/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family pf
-              edit EMOS_TYPE 'pf'
-              family cf408
-                edit STEPS '366/to/408/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf480
-                edit STEPS '414/to/480/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf600
-                edit STEPS '486/to/600/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family pf768
-                edit STEPS '606/to/768/by/6'
-                task pfpl
-                  inlimit /emc_36r1/limits:pl
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfsfc
-                  trigger ../../postproc/dp eq complete
-                  inlimit /emc_36r1/limits:sfc
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfil
-                  label files ""
-                  label info ""
-                  event fdb
-                task pfwv
-                  edit STREAM 'ENWH'
-                  edit EMOS_STREAM 'ENWH'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family postproc
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-              edit FCCHUNK '1'
-              edit FCLENGTH '768'
-              inlimit /emc_36r1/limits:postproc
-              family dp
-                trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
-                edit RUNVARFC '1'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-                edit EMOS_TYPE 'pf'
-                edit STEPS '366/to/768/by/6'
-                family cf
-                  edit EMOS_TYPE 'cf'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                  task extra_arc
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit STEPS '360/to/768'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family pf
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                  task extra_arc
-                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                    edit STEPS '360/to/768'
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-              endfamily
-              family extra
-                trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
-                edit RUNVARFC '1'
-                task wm_sfc_arc
-                  label files ""
-                  label info ""
-                  event fdb
-                task wm_ua_arc
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family nino
-                edit FCCHUNK '1'
-                edit OCTOTAL '5'
-                edit FCTOTAL '51'
-                edit DAILY '0'
-                edit RUNVARFC '1'
-                edit FCLENGTH1 '360'
-                edit QUEUE 'emos-e'
-                edit QUEUE_EPILOG 'emos-exp'
-                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                edit LOGDIR '/vol/emos_nc/output'
-                edit SMSOUT '/vol/emos_nc/output'
-                edit FCLENGTH '768'
-                edit EPSCOUPLE '1'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                limit semaphore 10
-                inlimit /limits:linux_cluster
-                inlimit semaphore
-                family 00
-                  edit OCGROUP 'an00'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '0'
-                  edit MEMBER '0'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 01
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '1'
-                  edit MEMBER '1'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 02
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '2'
-                  edit MEMBER '2'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 03
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '3'
-                  edit MEMBER '3'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-                family 04
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc0'
-                  edit EPSMEMBER '4'
-                  edit MEMBER '4'
-                  task nino_daily
-                  task tcyc
-                    trigger nino_daily eq complete or nino_daily eq aborted
-                endfamily
-              endfamily
-              task tcyctoecfs
-                trigger nino eq complete
-                edit QUEUE 'emos-e'
-                edit QUEUE_EPILOG 'emos-exp'
-                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                edit LOGDIR '/vol/emos_nc/output'
-                edit SMSOUT '/vol/emos_nc/output'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                edit EPSCOUPLE '1'
-                edit FCLENGTH '768'
-                inlimit /limits:linux_cluster
-            endfamily
-          endfamily
-          task save_logs
-            trigger legA eq complete and legB eq complete and legC eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1'
-            edit SCHOST 'localhost'
-        endfamily
-        family clean
-          task chver
-            trigger ../arch eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            edit GENERAT '0'
-            edit CLEANER '1'
-        endfamily
-      endfamily
-    endfamily
-    task stage_pp
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      late -s +00:05 -c +00:25
-      trigger logfilestore eq complete and back eq complete and arch eq complete and efi eq complete and adm eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-  family lag
-    repeat date YMD 20091003 20121212 1
-    edit EMOS_TYPE 'an'
-    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-    edit FSFAMILY 'mars'
-    edit OVERLAP '0'
-    edit LOGTASK 'lag'
-    edit MARS_DB 'marsod'
-    family ref
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-      family 12
-        edit EMOS_BASE '12'
-        limit mutex 1
-        task events
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-          edit HINDCAST '1'
-          edit ONLY_CF '0'
-          event noefi
-          event 240 
-          event 360 
-          event cpl
-          event 768 
-          event cf
-      endfamily
-      family 00
-        edit DELTA_DAY '1'
-        edit EMOS_BASE '00'
-        limit mutex 1
-        task events
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-          edit HINDCAST '1'
-          edit ONLY_CF '0'
-          event noefi
-          event 240 
-          event 360 
-          event cpl
-          event 768 
-          event cf
-      endfamily
-      task smove
-        trigger /emc_36r1/lag/12 eq complete
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/system'
-      family loop
-        task dummy
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit WSHOST 'localhost'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          time 12:45
-      endfamily
-      family warn
-        trigger ./loop eq complete
-        task dummy
-          complete /emc_36r1/lag/logfiles eq complete
-          time 16:00
-      endfamily
-      task checkarchive
-        trigger /emc_36r1/main/make eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1'
-        edit FSFAMILY 'mars'
-        edit EMOS_TYPE 'an'
-        edit OSTREAM 'WEOV EFOV'
-        edit HSTREAM 'EFHO EFHS ENFH ENWH EWHO'
-        inlimit /limits:linux_cluster
-        label info "none"
-    endfamily
-    family 12
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD)
-      edit DELTA_DAY '0'
-      edit EMOS_BASE '12'
-      family legA
-        trigger /emc_36r1/lag/ref/12/events eq complete
-        edit EPSWAMNFRE '30'
-        edit EPSWAMNANG '24'
-        family init
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/ref/an eq complete)
-          edit FSFAMILY 'mc'
-          task rmfdb
-        endfamily
-        family tc
-          complete /emc_36r1/lag/ref/12/events:cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/postproc/tc eq complete)
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          edit FSFAMILY 'mc'
-          task clean
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
-          task to_ecfs
-            label files ""
-            label info ""
-            event fdb
-          task to_mars
-            trigger to_ecfs eq complete
-        endfamily
-        family archive
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/postproc eq complete) and /emc_36r1/lag/ref/12/events eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                complete /emc_36r1/lag/ref/12/events:cf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '0/to/144/by/3'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '0/to/144/by/3'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family cluster
-              complete /emc_36r1/lag/ref/12/events:cf
-              edit STEPS '72/84/96/108/120/132/144/156/168'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family a
-                edit DOMAIN 'a'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family b
-                trigger ./a eq complete
-                edit DOMAIN 'b'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family c
-                trigger ./b eq complete
-                edit DOMAIN 'c'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family d
-                trigger ./c eq complete
-                edit DOMAIN 'd'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family e
-                trigger ./d eq complete
-                edit DOMAIN 'e'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family ensms
-              complete /emc_36r1/lag/ref/12/events:cf
-              edit STEPS '3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-              task mean
-                edit TYPE 'em'
-                label files ""
-                label info ""
-                event fdb
-              task stdev
-                edit TYPE 'es'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family prob
-              complete /emc_36r1/lag/ref/12/events:cf
-              family 2t
-                edit PARAM '2t'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family swp_mwp
-                edit PARAM 'swp_mwp'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family 10fg
-                edit PARAM '10fg'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family ff
-                edit PARAM 'ff'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family rain
-                edit PARAM 'rain'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family t850
-                edit PARAM 't850'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family efi
-              complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/postproc eq complete)
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family 2t
-                edit RF_NAME '2t'
-                task efi
-                  label info ""
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task efi
-                  label info ""
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task efi
-                  label info ""
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task efi
-                  label info ""
-              endfamily
-            endfamily
-          endfamily
-          family cf
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc/cf eq complete)
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf036
-              edit STEPS '0/to/36/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf072
-              edit STEPS '39/to/72/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf108
-              edit STEPS '075/to/108/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf144
-              edit STEPS '111/to/144/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf180
-              edit STEPS '150/to/180/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '186/to/240/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family cv
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc/cv eq complete)
-            edit EMOS_TYPE 'cv'
-            edit NUMBER '1/2'
-            family cv036
-              edit STEPS '0/to/036/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv072
-              edit STEPS '039/to/072/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv108
-              edit STEPS '075/to/108/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv144
-              edit STEPS '111/to/144/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv180
-              edit STEPS '150/to/180/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv240
-              edit STEPS '186/to/240/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv300
-              edit STEPS '246/to/300/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv360
-              edit STEPS '306/to/360/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            complete /emc_36r1/lag/ref/12/events:cf
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/lag/ref/12/events eq complete)
-            edit EMOS_TYPE 'pf'
-            family pf024
-              edit STEPS '0/to/024/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf048
-              edit STEPS '027/to/048/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf072
-              edit STEPS '051/to/072/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf096
-              edit STEPS '075/to/096/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf120
-              edit STEPS '099/to/120/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '123/to/144/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family icp
-            complete /emc_36r1/lag/ref/12/events:cf
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc eq complete)
-            edit ARCHTYPE 'icp'
-            task ml
-              edit FCLENGTH '240'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          task flush
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc eq complete)
-            edit STREAM 'enfo'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family ecfs
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/sv eq complete and /emc_36r1/main/12/legA/fc eq complete)
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit FSFAMILY 'mc'
-          task svsave
-          task save
-        endfamily
-      endfamily
-      family legB
-        complete /emc_36r1/lag/ref/12/events:240
-        edit EPSLEG '2'
-        edit EPSWAMNFRE '25'
-        edit EPSWAMNANG '12'
-        inlimit /emc_36r1/limits:mars
-        inlimit /limits:mars
-        family postproc
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legB/postproc eq complete) and /emc_36r1/lag/ref/12/events eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-          inlimit /emc_36r1/limits:postproc
-          family ensms
-            complete /emc_36r1/lag/ref/12/events:cf
-            family 360
-              edit STEPS '246/to/360/by/6'
-              task mean
-                edit TYPE 'em'
-                label files ""
-                label info ""
-                event fdb
-              task stdev
-                edit TYPE 'es'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family prob
-            complete /emc_36r1/lag/ref/12/events:cf
-            family 2t
-              edit PARAM '2t'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family swp_mwp
-              edit PARAM 'swp_mwp'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family 10fg
-              edit PARAM '10fg'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family ff
-              edit PARAM 'ff'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family rain
-              edit PARAM 'rain'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family t850
-              edit PARAM 't850'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family dp
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-            family pf
-              complete /emc_36r1/lag/ref/12/events:cf
-              edit EMOS_TYPE 'pf'
-              family 240
-                edit STEPS '216/222/228/234/240'
-                edit OVERLAP '1'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family 360
-                edit STEPS '246/to/360/by/6'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task extra_arc
-                edit STEPS '240/to/360'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                edit RUNVARFC '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf
-              edit EMOS_TYPE 'cf'
-              family 240
-                edit STEPS '216/222/228/234/240'
-                edit OVERLAP '1'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family 360
-                edit STEPS '246/to/360/by/6'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task extra_arc
-                edit STEPS '240/to/360'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                edit RUNVARFC '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family efi
-            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-        endfamily
-        family cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legB/fc/cf eq complete)
-          edit EMOS_TYPE 'cf'
-          edit NUMBER '0'
-          family cf240
-            edit STEPS '216/228/240'
-            edit OVERLAP '1'
-            task cfml
-              label files ""
-              label info ""
-              event fdb
-            task cfpl
-              label files ""
-              label info ""
-              event fdb
-            task cfsfc
-              label files ""
-              label info ""
-              event fdb
-            task cfil
-              label files ""
-              label info ""
-              event fdb
-            task cfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family cf300
-            edit STEPS '246/to/300/by/6'
-            task cfml
-              label files ""
-              label info ""
-              event fdb
-            task cfpl
-              label files ""
-              label info ""
-              event fdb
-            task cfsfc
-              label files ""
-              label info ""
-              event fdb
-            task cfil
-              label files ""
-              label info ""
-              event fdb
-            task cfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family cf360
-            edit STEPS '306/to/360/by/6'
-            task cfml
-              label files ""
-              label info ""
-              event fdb
-            task cfpl
-              label files ""
-              label info ""
-              event fdb
-            task cfsfc
-              label files ""
-              label info ""
-              event fdb
-            task cfil
-              label files ""
-              label info ""
-              event fdb
-            task cfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          task accum
-            edit STEPS '240'
-            edit OVERLAP '1'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family pf
-          complete /emc_36r1/lag/ref/12/events:cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legB/fc/pf eq complete and /emc_36r1/lag/ref/12/events eq complete)
-          edit EMOS_TYPE 'pf'
-          family pf240
-            edit STEPS '216/228/240'
-            edit OVERLAP '1'
-            task pfpl
-              inlimit /emc_36r1/limits:pl
-              label files ""
-              label info ""
-              event fdb
-            task pfsfc
-              trigger ../../postproc/dp eq complete
-              inlimit /emc_36r1/limits:sfc
-              label files ""
-              label info ""
-              event fdb
-            task pfil
-              label files ""
-              label info ""
-              event fdb
-            task pfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf300
-            edit STEPS '246/to/300/by/6'
-            task pfpl
-              inlimit /emc_36r1/limits:pl
-              label files ""
-              label info ""
-              event fdb
-            task pfsfc
-              trigger ../../postproc/dp eq complete
-              inlimit /emc_36r1/limits:sfc
-              label files ""
-              label info ""
-              event fdb
-            task pfil
-              label files ""
-              label info ""
-              event fdb
-            task pfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf360
-            edit STEPS '306/to/360/by/6'
-            task pfpl
-              inlimit /emc_36r1/limits:pl
-              label files ""
-              label info ""
-              event fdb
-            task pfsfc
-              trigger ../../postproc/dp eq complete
-              inlimit /emc_36r1/limits:sfc
-              label files ""
-              label info ""
-              event fdb
-            task pfil
-              label files ""
-              label info ""
-              event fdb
-            task pfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          task pfml
-            edit STEPS '360'
-          task accum
-            edit STEPS '240'
-            edit OVERLAP '1'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-      endfamily
-    endfamily
-    family 00
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD)
-      edit DELTA_DAY '1'
-      edit EMOS_BASE '00'
-      edit QUEUE 'os'
-      family legA
-        trigger /emc_36r1/lag/ref/00/events eq complete
-        edit EPSWAMNFRE '30'
-        edit EPSWAMNANG '24'
-        family init
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/ref/an eq complete)
-          edit FSFAMILY 'mc'
-          task rmfdb
-        endfamily
-        family tc
-          complete /emc_36r1/lag/ref/00/events:cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/postproc/tc eq complete)
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          edit FSFAMILY 'mc'
-          task clean
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
-          task to_ecfs
-            label files ""
-            label info ""
-            event fdb
-          task to_mars
-            trigger to_ecfs eq complete
-        endfamily
-        family archive
-          inlimit /emc_36r1/limits:mars
-          inlimit /limits:mars
-          family postproc
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/postproc eq complete) and /emc_36r1/lag/ref/00/events eq complete
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            family dp
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family pf
-                complete /emc_36r1/lag/ref/00/events:cf
-                edit EMOS_TYPE 'pf'
-                family 144
-                  edit STEPS '0/to/144/by/3'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family cf
-                edit EMOS_TYPE 'cf'
-                family 144
-                  edit STEPS '0/to/144/by/3'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                family 240
-                  edit STEPS '150/to/240/by/6'
-                  task derivedp
-                    label files ""
-                    label info ""
-                    event fdb
-                endfamily
-                task extra_arc
-                  edit STEPS '0/to/240'
-                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                  edit RUNVARFC '1'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family cluster
-              complete /emc_36r1/lag/ref/00/events:cf
-              edit STEPS '72/84/96/108/120/132/144/156/168'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family a
-                edit DOMAIN 'a'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family b
-                trigger ./a eq complete
-                edit DOMAIN 'b'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family c
-                trigger ./b eq complete
-                edit DOMAIN 'c'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family d
-                trigger ./c eq complete
-                edit DOMAIN 'd'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family e
-                trigger ./d eq complete
-                edit DOMAIN 'e'
-                task cmpl
-                  edit TYPE 'cm'
-                  label files ""
-                  label info ""
-                  event fdb
-                task cspl
-                  edit TYPE 'cs'
-                  label files ""
-                  label info ""
-                  event fdb
-                task tube
-                  edit STEPS '48/72/96/120/144/168/192/216/240'
-                  edit REFERENCE '96/144/168/192/240'
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family reord
-              complete /emc_36r1/lag/ref/00/events:cf
-              edit EPSCOUPLE '1'
-              edit EMOS_TYPE 'pf'
-              edit FCLENGTH0 '0'
-              edit FCLENGTH '240'
-              edit EPSFCRES '639'
-              edit FCCHUNK '1'
-              edit STEP1 '0'
-              edit STEP2 '240'
-              edit STEPS '-1'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-              limit reord 1
-              inlimit reord
-              label info ""
-              family 130
-                edit GENERATE '1'
-                edit ARCHIVE '0'
-                edit PARAMS '130.128'
-                task reord
-                  label info ""
-              endfamily
-              family 228
-                edit GENERATE '1'
-                edit ARCHIVE '0'
-                edit PARAMS '228.128'
-                task reord
-                  label info ""
-              endfamily
-              family 207
-                edit GENERATE '1'
-                edit ARCHIVE '0'
-                edit PARAMS '207.128'
-                task reord
-                  label info ""
-              endfamily
-              family 167
-                edit GENERATE '1'
-                edit ARCHIVE '0'
-                edit PARAMS '167.128'
-                task reord
-                  label info ""
-              endfamily
-              family 164
-                edit GENERATE '1'
-                edit ARCHIVE '0'
-                edit PARAMS '164.128'
-                task reord
-                  label info ""
-              endfamily
-              family arch
-                trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
-                edit GENERATE '0'
-                edit ARCHIVE '1'
-                inlimit /emc_36r1/lag/ref/00:mutex
-                task reord
-                  label info ""
-              endfamily
-            endfamily
-            family ensms
-              complete /emc_36r1/lag/ref/00/events:cf
-              edit STEPS '3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-              task mean
-                edit TYPE 'em'
-                label files ""
-                label info ""
-                event fdb
-              task stdev
-                edit TYPE 'es'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family prob
-              complete /emc_36r1/lag/ref/00/events:cf
-              family 2t
-                edit PARAM '2t'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family swp_mwp
-                edit PARAM 'swp_mwp'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family 10fg
-                edit PARAM '10fg'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family ff
-                edit PARAM 'ff'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family rain
-                edit PARAM 'rain'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family t850
-                edit PARAM 't850'
-                task arc_prob
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-            endfamily
-            family efi
-              complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/postproc eq complete)
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-              family 2t
-                edit RF_NAME '2t'
-                task efi
-                  label info ""
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task efi
-                  label info ""
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task efi
-                  label info ""
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task efi
-                  label info ""
-              endfamily
-            endfamily
-          endfamily
-          family coupled
-            complete ( /emc_36r1/lag/ref/00/events:cf or /emc_36r1/lag/ref/00/events:360) or ( /emc_36r1/lag/ref/00/events eq complete and not /emc_36r1/lag/ref/00/events:cpl)
-            trigger ./cf eq complete and ./pf eq complete
-            edit EPSLEG '1'
-            edit OCLEG '1'
-            edit OCEPS '1'
-            edit FCCHUNK '1'
-            edit FCLENGTH '240'
-            edit FCLENGTH0 '0'
-            edit OCEPSTOT '3'
-            edit FCTOTAL '51'
-            edit RUNVARFC '1'
-            edit EPSCOUPLE '1'
-            edit RUNCOUPLE '0'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-            inlimit /emc_36r1/lag/ref/00:mutex
-            task preparcoce
-            task arcfc
-              trigger preparcoce eq complete
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family cf
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc/cf eq complete)
-            edit EMOS_TYPE 'cf'
-            edit NUMBER '0'
-            family cf036
-              edit STEPS '0/to/36/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf072
-              edit STEPS '39/to/72/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf108
-              edit STEPS '075/to/108/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf144
-              edit STEPS '111/to/144/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf180
-              edit STEPS '150/to/180/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf240
-              edit STEPS '186/to/240/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family cv
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc/cv eq complete)
-            edit EMOS_TYPE 'cv'
-            edit NUMBER '1/2'
-            family cv036
-              edit STEPS '0/to/036/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv072
-              edit STEPS '039/to/072/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv108
-              edit STEPS '075/to/108/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv144
-              edit STEPS '111/to/144/by/3'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv180
-              edit STEPS '150/to/180/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv240
-              edit STEPS '186/to/240/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv300
-              edit STEPS '246/to/300/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cv360
-              edit STEPS '306/to/360/by/6'
-              task cfml
-                label files ""
-                label info ""
-                event fdb
-              task cfpl
-                label files ""
-                label info ""
-                event fdb
-              task cfsfc
-                trigger ../../postproc/dp eq complete
-                label files ""
-                label info ""
-                event fdb
-              task cfil
-                label files ""
-                label info ""
-                event fdb
-              task cfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task derivedp
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family pf
-            complete /emc_36r1/lag/ref/00/events:cf
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/lag/ref/00/events eq complete)
-            edit EMOS_TYPE 'pf'
-            family pf024
-              edit STEPS '0/to/024/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf048
-              edit STEPS '027/to/048/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf072
-              edit STEPS '051/to/072/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf096
-              edit STEPS '075/to/096/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf120
-              edit STEPS '099/to/120/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf144
-              edit STEPS '123/to/144/by/3'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf192
-              edit STEPS '150/to/192/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family pf240
-              edit STEPS '198/to/240/by/6'
-              task pfpl
-                inlimit /emc_36r1/limits:pl
-                label files ""
-                label info ""
-                event fdb
-              task pfsfc
-                trigger ../../postproc/dp eq complete
-                inlimit /emc_36r1/limits:sfc
-                label files ""
-                label info ""
-                event fdb
-              task pfil
-                label files ""
-                label info ""
-                event fdb
-              task pfwv
-                edit STREAM 'WAEF'
-                edit EMOS_STREAM 'WAEF'
-                label files ""
-                label info ""
-                event fdb
-              task pfml
-                edit STEPS '216'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family icp
-            complete /emc_36r1/lag/ref/00/events:cf
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc eq complete)
-            edit ARCHTYPE 'icp'
-            task ml
-              edit FCLENGTH '240'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          task flush
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc eq complete)
-            edit STREAM 'enfo'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family ecfs
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/sv eq complete and /emc_36r1/main/00/legA/fc eq complete)
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
-          edit FSFAMILY 'mc'
-          task svsave
-          task save
-        endfamily
-      endfamily
-      family legB
-        complete /emc_36r1/lag/ref/00/events:240
-        edit EPSLEG '2'
-        edit EPSWAMNFRE '25'
-        edit EPSWAMNANG '12'
-        inlimit /emc_36r1/limits:mars
-        inlimit /limits:mars
-        family postproc
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legB/postproc eq complete) and /emc_36r1/lag/ref/00/events eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-          inlimit /emc_36r1/limits:postproc
-          family ensms
-            complete /emc_36r1/lag/ref/00/events:cf
-            family 360
-              edit STEPS '246/to/360/by/6'
-              task mean
-                edit TYPE 'em'
-                label files ""
-                label info ""
-                event fdb
-              task stdev
-                edit TYPE 'es'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family prob
-            complete /emc_36r1/lag/ref/00/events:cf
-            family 2t
-              edit PARAM '2t'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family swp_mwp
-              edit PARAM 'swp_mwp'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family 10fg
-              edit PARAM '10fg'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family ff
-              edit PARAM 'ff'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family rain
-              edit PARAM 'rain'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family t850
-              edit PARAM 't850'
-              task arc_prob
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family dp
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-            family pf
-              complete /emc_36r1/lag/ref/00/events:cf
-              edit EMOS_TYPE 'pf'
-              family 240
-                edit STEPS '216/222/228/234/240'
-                edit OVERLAP '1'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family 360
-                edit STEPS '246/to/360/by/6'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task extra_arc
-                edit STEPS '240/to/360'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                edit RUNVARFC '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-            family cf
-              edit EMOS_TYPE 'cf'
-              family 240
-                edit STEPS '216/222/228/234/240'
-                edit OVERLAP '1'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              family 360
-                edit STEPS '246/to/360/by/6'
-                task derivedp
-                  label files ""
-                  label info ""
-                  event fdb
-              endfamily
-              task extra_arc
-                edit STEPS '240/to/360'
-                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-                edit RUNVARFC '1'
-                label files ""
-                label info ""
-                event fdb
-            endfamily
-          endfamily
-          family efi
-            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-            family 2t
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task efi
-                label info ""
-            endfamily
-          endfamily
-          family reord
-            complete /emc_36r1/lag/ref/00/events:cf
-            edit EPSCOUPLE '1'
-            edit EMOS_TYPE 'pf'
-            edit FCLENGTH0 '240'
-            edit FCLENGTH '360'
-            edit EPSFCRES '639'
-            edit FCCHUNK '1'
-            edit STEP1 '240'
-            edit STEP2 '360'
-            edit STEPS '-1'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
-            limit reord 1
-            inlimit reord
-            label info ""
-            family 130
-              edit GENERATE '1'
-              edit ARCHIVE '0'
-              edit PARAMS '130.128'
-              task reord
-                label info ""
-            endfamily
-            family 228
-              edit GENERATE '1'
-              edit ARCHIVE '0'
-              edit PARAMS '228.128'
-              task reord
-                label info ""
-            endfamily
-            family 207
-              edit GENERATE '1'
-              edit ARCHIVE '0'
-              edit PARAMS '207.128'
-              task reord
-                label info ""
-            endfamily
-            family 167
-              edit GENERATE '1'
-              edit ARCHIVE '0'
-              edit PARAMS '167.128'
-              task reord
-                label info ""
-            endfamily
-            family 164
-              edit GENERATE '1'
-              edit ARCHIVE '0'
-              edit PARAMS '164.128'
-              task reord
-                label info ""
-            endfamily
-            family arch
-              trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
-              edit GENERATE '0'
-              edit ARCHIVE '1'
-              inlimit /emc_36r1/lag/ref/00:mutex
-              task reord
-                label info ""
-            endfamily
-          endfamily
-        endfamily
-        family cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legB/fc/cf eq complete)
-          edit EMOS_TYPE 'cf'
-          edit NUMBER '0'
-          family cf240
-            edit STEPS '216/228/240'
-            edit OVERLAP '1'
-            task cfml
-              label files ""
-              label info ""
-              event fdb
-            task cfpl
-              label files ""
-              label info ""
-              event fdb
-            task cfsfc
-              label files ""
-              label info ""
-              event fdb
-            task cfil
-              label files ""
-              label info ""
-              event fdb
-            task cfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family cf300
-            edit STEPS '246/to/300/by/6'
-            task cfml
-              label files ""
-              label info ""
-              event fdb
-            task cfpl
-              label files ""
-              label info ""
-              event fdb
-            task cfsfc
-              label files ""
-              label info ""
-              event fdb
-            task cfil
-              label files ""
-              label info ""
-              event fdb
-            task cfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family cf360
-            edit STEPS '306/to/360/by/6'
-            task cfml
-              label files ""
-              label info ""
-              event fdb
-            task cfpl
-              label files ""
-              label info ""
-              event fdb
-            task cfsfc
-              label files ""
-              label info ""
-              event fdb
-            task cfil
-              label files ""
-              label info ""
-              event fdb
-            task cfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          task accum
-            edit STEPS '240'
-            edit OVERLAP '1'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family pf
-          complete /emc_36r1/lag/ref/00/events:cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legB/fc/pf eq complete and /emc_36r1/lag/ref/00/events eq complete)
-          edit EMOS_TYPE 'pf'
-          family pf240
-            edit STEPS '216/228/240'
-            edit OVERLAP '1'
-            task pfpl
-              inlimit /emc_36r1/limits:pl
-              label files ""
-              label info ""
-              event fdb
-            task pfsfc
-              trigger ../../postproc/dp eq complete
-              inlimit /emc_36r1/limits:sfc
-              label files ""
-              label info ""
-              event fdb
-            task pfil
-              label files ""
-              label info ""
-              event fdb
-            task pfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf300
-            edit STEPS '246/to/300/by/6'
-            task pfpl
-              inlimit /emc_36r1/limits:pl
-              label files ""
-              label info ""
-              event fdb
-            task pfsfc
-              trigger ../../postproc/dp eq complete
-              inlimit /emc_36r1/limits:sfc
-              label files ""
-              label info ""
-              event fdb
-            task pfil
-              label files ""
-              label info ""
-              event fdb
-            task pfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          family pf360
-            edit STEPS '306/to/360/by/6'
-            task pfpl
-              inlimit /emc_36r1/limits:pl
-              label files ""
-              label info ""
-              event fdb
-            task pfsfc
-              trigger ../../postproc/dp eq complete
-              inlimit /emc_36r1/limits:sfc
-              label files ""
-              label info ""
-              event fdb
-            task pfil
-              label files ""
-              label info ""
-              event fdb
-            task pfwv
-              edit STREAM 'WAEF'
-              edit EMOS_STREAM 'WAEF'
-              label files ""
-              label info ""
-              event fdb
-          endfamily
-          task pfml
-            edit STEPS '360'
-          task accum
-            edit STEPS '240'
-            edit OVERLAP '1'
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-        family coupled
-          complete /emc_36r1/lag/ref/00/events:cf or /emc_36r1/lag/ref/00/events:360 or ( /emc_36r1/lag/ref/00/events eq complete and not /emc_36r1/lag/ref/00/events:cpl)
-          trigger /emc_36r1/lag/00/legA/archive/coupled eq complete
-          edit EPSLEG '2'
-          edit OCLEG '2'
-          edit OCEPS '2'
-          edit FCCHUNK '1'
-          edit FCLENGTH '360'
-          edit FCLENGTH0 '216'
-          edit OCEPSTOT '3'
-          edit FCTOTAL '51'
-          edit RUNVARFC '1'
-          edit EPSCOUPLE '1'
-          edit RUNCOUPLE '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-          inlimit /emc_36r1/lag/ref/00:mutex
-          task preparcoce
-          task arcfc
-            trigger preparcoce eq complete
-            label files ""
-            label info ""
-            event fdb
-        endfamily
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'lag'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1'
-    task logfiles
-      late -s +00:05 -c +00:35
-      trigger /emc_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete and logfilestore eq complete and ./ref/loop eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'lag'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1'
-  endfamily
-  family pop
-    repeat date YMD 20091003 20121212 1
-    edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
-    edit SMSURL 'sub=fixed/'
-    edit VERSION '0046'
-    edit STREAM 'EF'
-    edit EMOS_STREAM 'EF'
-    edit SMSFILES '/home/ma/emos/def/emc_36r1'
-    edit LOGTASK 'pop'
-    edit SUITE_START '20091124'
-    family 12
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/ref/model eq complete)
-      edit DELTA_DAY '0'
-      edit EMOS_BASE '12'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/pop'
-      task events
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-        edit HINDCAST '1'
-        edit ONLY_CF '0'
-        event noefi
-        event 240 
-        event 360 
-        event cpl
-        event 768 
-        event cf
-      family data
-        trigger events eq complete
-        family metgram
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete)
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit QUEUE 'emos'
-          edit SMSTRIES '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
-          inlimit /limits:linux_cluster
-          family 240
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/legA/fc/cf eq complete)
-            edit KIND '10_days'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family 360
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
-            edit KIND '15_days'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family wave
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/legA/fc/cf eq complete)
-            edit KIND '10_days_wave'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family 15d
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
-            edit KIND '15_days_pf'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family efi
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
-            edit KIND 'efi'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '10'
-              edit REMOTE_KEEP_DAYS '10'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-        endfamily
-        family distribution
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data'
-          edit DISTRIB_FDB '/leda/fdb1'
-          inlimit /limits:linux_cluster
-          task ff
-            edit PARAMETER 'ff'
-            edit STEP_LIST '84 108 132 156 180'
-            edit RANK '9999'
-          task 2t
-            edit PARAMETER '2t'
-            edit STEP_LIST '84 108 132 156 180'
-            edit RANK '9998'
-          task tp
-            edit PARAMETER 'tp'
-            edit STEP_LIST '102 126 150 174 198'
-            edit RANK '9997'
-          task tp5
-            edit PARAMETER 'tp5'
-            edit STEP_LIST '174'
-            edit RANK '9996'
-          task tp10
-            edit PARAMETER 'tp10'
-            edit STEP_LIST '240'
-            edit RANK '9995'
-          task cleanup
-            trigger ff eq complete and ./2t eq complete and tp eq complete and tp5 eq complete and tp10 eq complete
-        endfamily
-        family fields
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/fields'
-          inlimit /limits:linux_cluster
-          inlimit /emc_36r1/limits:webplots
-          task efi
-            complete ( /emc_36r1/pop/12/events:cf) or ( /emc_36r1/pop/12/events:noefi)
-            trigger /emc_36r1/pop/12/events eq complete
-            event none
-          task globalefi
-            complete ( /emc_36r1/pop/12/events:cf) or ( /emc_36r1/pop/12/events:noefi)
-            trigger /emc_36r1/pop/12/events eq complete
-            event none
-          family legA
-            task proba
-              complete /emc_36r1/pop/12/events:cf
-              trigger /emc_36r1/pop/12/events eq complete
-              edit RANGE 'legA'
-              edit PLOT_STEPS_RANGE '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
-              edit PLOT_STEPS '12/to/240/by/12'
-          endfamily
-          family legB
-            task proba
-              complete /emc_36r1/pop/12/events:cf
-              trigger /emc_36r1/pop/12/events eq complete
-              edit RANGE 'legB'
-              edit PLOT_STEPS '252/to/360/by/12'
-              edit PLOT_STEPS_RANGE '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
-          endfamily
-          task proba_mean
-            complete /emc_36r1/pop/12/events:cf
-            trigger /emc_36r1/pop/12/events eq complete
-            edit PLOT_STEPS_MEAN '240-360'
-          task lsmoro
-            edit STEP_LIST '0/to/144/by/12'
-        endfamily
-        family tc
-          complete /emc_36r1/pop/12/events:cf
-          trigger ( /emc_36r1/pop/12/events eq complete) and ( ( /emc_36r1/lag:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/lag:YMD eq /emc_36r1/pop:YMD and /emc_36r1/lag/12/legA/tc eq complete))
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
-          inlimit /limits:linux_cluster
-          task cleanup
-          task check_data
-          family post_process
-            task strike_prob
-              trigger ../check_data eq complete
-          endfamily
-          family diagnostics
-            trigger post_process eq complete
-            task det_errors
-            task spreadskill
-            task reliability
-          endfamily
-          family store
-            trigger ( /emc_36r1/pop/12/data/tc/diagnostics eq complete)
-            task to_ecfs_pop
-          endfamily
-        endfamily
-        family tcyc
-          complete /emc_36r1/pop/12/events:cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/fc eq complete)
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FCCHUNK '1'
-          edit OCTOTAL '5'
-          edit FCTOTAL '51'
-          edit FCLENGTH1 '216'
-          edit DAILY '0'
-          edit RUNVARFC '1'
-          edit FCLENGTH '360'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-          edit EPSCOUPLE '1'
-          edit RADIUS '500'
-          limit semaphore 8
-          inlimit /limits:linux_cluster
-          inlimit semaphore
-          task genes_stage
-            edit DELTA_DAY '1'
-          family genesis
-            trigger genes_stage eq complete
-            family da
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER 'da'
-              edit MEMBER 'da'
-              task tcyc
-            endfamily
-            family 00
-              edit OCGROUP 'an00'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '00'
-              edit MEMBER '00'
-              task tcyc
-            endfamily
-            family 01
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '01'
-              edit MEMBER '01'
-              task tcyc
-            endfamily
-            family 02
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '02'
-              edit MEMBER '02'
-              task tcyc
-            endfamily
-            family 03
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '03'
-              edit MEMBER '03'
-              task tcyc
-            endfamily
-            family 04
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '04'
-              edit MEMBER '04'
-              task tcyc
-            endfamily
-            family 05
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '05'
-              edit MEMBER '05'
-              task tcyc
-            endfamily
-            family 06
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '06'
-              edit MEMBER '06'
-              task tcyc
-            endfamily
-            family 07
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '07'
-              edit MEMBER '07'
-              task tcyc
-            endfamily
-            family 08
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '08'
-              edit MEMBER '08'
-              task tcyc
-            endfamily
-            family 09
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '09'
-              edit MEMBER '09'
-              task tcyc
-            endfamily
-            family 10
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              task tcyc
-            endfamily
-            family 11
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              task tcyc
-            endfamily
-            family 12
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              task tcyc
-            endfamily
-            family 13
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              task tcyc
-            endfamily
-            family 14
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              task tcyc
-            endfamily
-            family 15
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              task tcyc
-            endfamily
-            family 16
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              task tcyc
-            endfamily
-            family 17
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              task tcyc
-            endfamily
-            family 18
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              task tcyc
-            endfamily
-            family 19
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              task tcyc
-            endfamily
-            family 20
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              task tcyc
-            endfamily
-            family 21
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              task tcyc
-            endfamily
-            family 22
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              task tcyc
-            endfamily
-            family 23
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              task tcyc
-            endfamily
-            family 24
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              task tcyc
-            endfamily
-            family 25
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              task tcyc
-            endfamily
-            family 26
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              task tcyc
-            endfamily
-            family 27
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              task tcyc
-            endfamily
-            family 28
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              task tcyc
-            endfamily
-            family 29
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              task tcyc
-            endfamily
-            family 30
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              task tcyc
-            endfamily
-            family 31
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              task tcyc
-            endfamily
-            family 32
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              task tcyc
-            endfamily
-            family 33
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              task tcyc
-            endfamily
-            family 34
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              task tcyc
-            endfamily
-            family 35
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              task tcyc
-            endfamily
-            family 36
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              task tcyc
-            endfamily
-            family 37
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              task tcyc
-            endfamily
-            family 38
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              task tcyc
-            endfamily
-            family 39
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              task tcyc
-            endfamily
-            family 40
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              task tcyc
-            endfamily
-            family 41
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              task tcyc
-            endfamily
-            family 42
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              task tcyc
-            endfamily
-            family 43
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              task tcyc
-            endfamily
-            family 44
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              task tcyc
-            endfamily
-            family 45
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              task tcyc
-            endfamily
-            family 46
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              task tcyc
-            endfamily
-            family 47
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              task tcyc
-            endfamily
-            family 48
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              task tcyc
-            endfamily
-            family 49
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              task tcyc
-            endfamily
-            family 50
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc10'
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              task tcyc
-            endfamily
-          endfamily
-          task tcyctoecfs
-            trigger genesis eq complete
-        endfamily
-      endfamily
-      family web
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
-        inlimit /limits:linux_cluster
-        inlimit /emc_36r1/limits:webplots
-        family pf
-          complete /emc_36r1/pop/12/events:cf
-          trigger /emc_36r1/pop/12/events eq complete
-          task plumes
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/cf eq complete and /emc_36r1/main/12/legA/fc/pf eq complete)
-          family classic
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/clusters eq complete)
-            edit ANALYSIS 'NO'
-            task clplot
-            task pltube
-            task enplot
-              edit STEPS '12 24 36 48 60 72 84 96 108 120 132 144 156 168 180 192'
-              edit PRINTSTEPS '60 84 108 132 156 180'
-          endfamily
-          family efi
-            complete /emc_36r1/pop/12/events:noefi
-            trigger ../../data/fields eq complete
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
-            inlimit /limits:linux_cluster
-            inlimit /emc_36r1/limits:webplots
-            family efi_tpi
-              task w_efi
-                edit PARAMETER 'tpi'
-            endfamily
-            family efi_10wsi
-              task w_efi
-                edit PARAMETER '10wsi'
-            endfamily
-            family efi_2ti
-              task w_efi
-                edit PARAMETER '2ti'
-            endfamily
-            family efi_10fgi
-              task w_efi
-                edit PARAMETER '10fgi'
-            endfamily
-            task globalefi
-              edit UPDATE_WEB_NOW 'yes'
-          endfamily
-          family proba
-            trigger ../../data/fields eq complete
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
-            edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia,Africa,Global'
-            inlimit /limits:linux_cluster
-            inlimit /emc_36r1/limits:webplots
-            family members
-              family legA
-                edit PLOT_STEPS '12/to/240/by/12'
-                edit STEP_RANGE 'legA'
-                task pb_2t
-                task pb_ff
-                task pb_tp
-                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
-                task w_proba_gusts
-                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
-                task pb_tpr
-                task pb_mwp
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-                task pb_swh
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-              endfamily
-              family legB
-                trigger ( ./legA eq complete)
-                edit PLOT_STEPS '252/to/360/by/12'
-                edit STEP_RANGE 'legB'
-                edit UPDATE_WEB_NOW 'yes'
-                task pb_2t
-                task pb_ff
-                task pb_tp
-                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
-                task w_proba_gusts
-                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
-                task pb_mwp
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-                task pb_swh
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-              endfamily
-              family means
-                trigger ( ./legA eq complete)
-                edit UPDATE_WEB_NOW 'yes'
-                task long_pb_2t
-                task long_pb_tpr
-                task long_w_proba_gusts
-                task long_pb_mwp
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-                task long_pb_swh
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-              endfamily
-            endfamily
-            family additional
-              edit PLOT_STEPS '12/to/156/by/12'
-              edit STEP_RANGE 'legA'
-              task w_proba_rain
-              family wmo_waves
-                edit PLOT_STEPS '12/to/168/by/12'
-                edit PLOT_AREAS 'Global'
-                edit PLOT_GRID '2.5/2.5'
-                task pb_swh
-              endfamily
-            endfamily
-          endfamily
-          family ensm
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc/ensms eq complete and /emc_36r1/main/12/legA/postproc/ensms eq complete)
-            task fields_ensm
-              event 30 
-            task plot_ensm_Z
-              complete fields_ensm eq complete and not fields_ensm:30
-              trigger fields_ensm eq complete and fields_ensm:30
-            task plot_ensm_T
-              complete fields_ensm eq complete and not fields_ensm:30
-              trigger fields_ensm eq complete and fields_ensm:30
-            task cleanup_ensm
-              trigger plot_ensm_Z eq complete and plot_ensm_T eq complete
-              edit SMSPASS 'stripped'
-          endfamily
-          family tc
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/tc'
-            inlimit /limits:linux_cluster
-            family plotting
-              trigger ( /emc_36r1/pop/12/data/tc/post_process eq complete)
-              task spm
-              task epsgram
-              task tstorm
-              task tstorm_web
-                trigger tstorm eq complete
-            endfamily
-            task tc2web
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and ./plotting eq complete and /emc_36r1/pop/12/data/tc/diagnostics eq complete)
-              edit WSHOST 'linux_cluster'
-          endfamily
-          family special
-            family swdfp
-              edit WSHOST 'linux_cluster'
-              edit QUEUE 'serial'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/swdfp'
-              edit PLOTDOM '-45/-10/6/62'
-              edit UPDATE_WEB_NOW 'yes'
-              time 01:30
-              family efi
-                trigger /emc_36r1/pop/12/data/fields eq complete
-                edit QUEUE 'emos-e'
-                edit QUEUE_EPILOG 'emos-exp'
-                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                edit LOGDIR '/vol/emos_nc/output'
-                edit SMSOUT '/vol/emos_nc/output'
-                inlimit /limits:linux_cluster
-                family swdfp_tpi
-                  task w_efi
-                    edit PARAMETER 'tpi'
-                endfamily
-                family swdfp_10wsi
-                  task w_efi
-                    edit PARAMETER '10wsi'
-                endfamily
-                family swdfp_2ti
-                  task w_efi
-                    edit PARAMETER '2ti'
-                endfamily
-                family swdfp_10fgi
-                  task w_efi
-                    edit PARAMETER '10fgi'
-                endfamily
-              endfamily
-              family proba
-                trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/prob eq complete)
-                edit PLOT_LOCATION '/webplots_e/data/swdfp/proba'
-                edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-                task swdfp_proba
-                task swdfp_tp
-                  trigger ./swdfp_proba eq complete
-                task swdfp_ff
-                  trigger ./swdfp_proba eq complete
-                task swdfp_tp24
-                  trigger ./swdfp_proba eq complete
-                  edit STEPS '24/48/72/96/120'
-                task swdfp_proba_clean
-                  trigger ./swdfp_tp eq complete and ./swdfp_ff eq complete and ./swdfp_tp24 eq complete
-              endfamily
-              task swdfp_epsgram
-                trigger /emc_36r1/pop/12/data/metgram eq complete
-            endfamily
-          endfamily
-        endfamily
-        family verification
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit DATEMASK '11.*.*'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/verification'
-          inlimit /limits:linux_cluster
-          task w_probas
-          task w_costloss
-          task w_timeseries
-        endfamily
-        task web_update
-          trigger pf/proba/members/legA eq complete and pf/proba/additional eq complete and pf/plumes eq complete and pf/classic eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit PACKAGES 'esuite'
-          edit UPDATE_STREAM 'enfo'
-          inlimit /emc_36r1/limits:webplots
-      endfamily
-      family paper
-        trigger web/web_update eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/plot'
-        inlimit /limits:linux_cluster
-        task epsgram
-          trigger ../data/metgram eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/paper'
-        family enplot
-          complete /emc_36r1/pop/12/events:cf
-          trigger ( /emc_36r1/pop/12/events eq complete) and ( ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/clusters eq complete))
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit ANALYSIS 'NO'
-          task sthemi
-        endfamily
-        family tube
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/clusters eq complete)
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          inlimit /limits:linux_cluster
-          task ptubfr
-          task tubfrfax
-            trigger ptubfr eq complete
-            edit QUEUE 'emos'
-          task tubukfax
-            trigger ptubuk eq complete
-            edit QUEUE 'emos'
-          task ptubuk
-            trigger ptubfr eq complete
-        endfamily
-        family prob
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/prob eq complete)
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit ANALYSIS 'YES'
-          inlimit /emc_36r1/limits:webplots
-          task clplot
-            trigger ../enplot eq complete
-          task s144
-            trigger clplot eq complete
-            edit STEPS '144'
-          task plumea
-          task pb
-        endfamily
-      endfamily
-      task cleanup
-        trigger paper eq complete and web eq complete
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        inlimit /limits:linux_cluster
-        inlimit /emc_36r1/limits:webplots
-    endfamily
-    family 00
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/ref/model eq complete)
-      edit DELTA_DAY '1'
-      edit EMOS_BASE '00'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/pop'
-      task events
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
-        edit HINDCAST '1'
-        edit ONLY_CF '0'
-        event noefi
-        event 240 
-        event 360 
-        event cpl
-        event 768 
-        event cf
-      family data
-        trigger events eq complete
-        family metgram
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete)
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit QUEUE 'emos'
-          edit SMSTRIES '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
-          inlimit /limits:linux_cluster
-          family 240
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete)
-            edit KIND '10_days'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family 360
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
-            edit KIND '15_days'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family wave
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete)
-            edit KIND '10_days_wave'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family 15d
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
-            edit KIND '15_days_pf'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family 15dclim
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/fc/pf eq complete and /emc_36r1/main/00/legB/fc/cf eq complete and /emc_36r1/00/efi/swarm/sync_climate eq complete)
-            edit KIND 'clim_15_days'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '2'
-              edit REMOTE_KEEP_DAYS '2'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-          family efi
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
-            edit KIND 'efi'
-            edit RHOST 'epsgrams'
-            edit RDIR '/webapps/epsgrams/data/'
-            task gclean
-              edit KEEP_DAYS '10'
-              edit REMOTE_KEEP_DAYS '10'
-            task gdb
-              trigger gclean eq complete
-              edit NEW_DAILY '1'
-              label files ""
-              label info ""
-              label local "-"
-              label remote "-"
-              event fdb
-              event 1 
-            task glink
-              trigger gdb eq complete
-          endfamily
-        endfamily
-        family distribution
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data'
-          edit DISTRIB_FDB '/leda/fdb1'
-          inlimit /limits:linux_cluster
-          task ff
-            edit PARAMETER 'ff'
-            edit STEP_LIST '84 108 132 156 180'
-            edit RANK '9999'
-          task 2t
-            edit PARAMETER '2t'
-            edit STEP_LIST '84 108 132 156 180'
-            edit RANK '9998'
-          task tp
-            edit PARAMETER 'tp'
-            edit STEP_LIST '102 126 150 174 198'
-            edit RANK '9997'
-          task tp5
-            edit PARAMETER 'tp5'
-            edit STEP_LIST '174'
-            edit RANK '9996'
-          task tp10
-            edit PARAMETER 'tp10'
-            edit STEP_LIST '240'
-            edit RANK '9995'
-          task cleanup
-            trigger ff eq complete and ./2t eq complete and tp eq complete and tp5 eq complete and tp10 eq complete
-        endfamily
-        family fields
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/fields'
-          inlimit /limits:linux_cluster
-          inlimit /emc_36r1/limits:webplots
-          task efi
-            complete ( /emc_36r1/pop/00/events:cf) or ( /emc_36r1/pop/00/events:noefi)
-            trigger /emc_36r1/pop/00/events eq complete
-            event none
-          task globalefi
-            complete ( /emc_36r1/pop/00/events:cf) or ( /emc_36r1/pop/00/events:noefi)
-            trigger /emc_36r1/pop/00/events eq complete
-            event none
-          family legA
-            task proba
-              complete /emc_36r1/pop/00/events:cf
-              trigger /emc_36r1/pop/00/events eq complete
-              edit RANGE 'legA'
-              edit PLOT_STEPS_RANGE '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
-              edit PLOT_STEPS '12/to/240/by/12'
-          endfamily
-          family legB
-            task proba
-              complete /emc_36r1/pop/00/events:cf
-              trigger /emc_36r1/pop/00/events eq complete
-              edit RANGE 'legB'
-              edit PLOT_STEPS '252/to/360/by/12'
-              edit PLOT_STEPS_RANGE '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
-          endfamily
-          task proba_mean
-            complete /emc_36r1/pop/00/events:cf
-            trigger /emc_36r1/pop/00/events eq complete
-            edit PLOT_STEPS_MEAN '240-360'
-          task lsmoro
-            edit STEP_LIST '0/to/144/by/12'
-        endfamily
-        family tc
-          complete /emc_36r1/pop/00/events:cf
-          trigger ( /emc_36r1/pop/00/events eq complete) and ( ( /emc_36r1/lag:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/lag:YMD eq /emc_36r1/pop:YMD and /emc_36r1/lag/00/legA/tc eq complete))
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
-          inlimit /limits:linux_cluster
-          task cleanup
-          task check_data
-            trigger /emc_36r1/pop/12/data/tc eq complete
-          family post_process
-            task strike_prob
-              trigger ../check_data eq complete
-          endfamily
-          family diagnostics
-            trigger post_process eq complete
-            task det_errors
-            task spreadskill
-            task reliability
-          endfamily
-          family store
-            trigger ( /emc_36r1/pop/00/data/tc/diagnostics eq complete)
-            task to_ecfs_pop
-          endfamily
-        endfamily
-        family tcyc
-          complete /emc_36r1/pop/00/events:cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/fc eq complete)
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FCCHUNK '1'
-          edit OCTOTAL '5'
-          edit FCTOTAL '51'
-          edit FCLENGTH1 '216'
-          edit DAILY '0'
-          edit RUNVARFC '1'
-          edit FCLENGTH '360'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
-          edit EPSCOUPLE '1'
-          edit RADIUS '500'
-          limit semaphore 5
-          inlimit /limits:linux_cluster
-          inlimit semaphore
-          task genes_stage
-            edit DELTA_DAY '2'
-          family genesis
-            trigger genes_stage eq complete
-            family da
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER 'da'
-              edit MEMBER 'da'
-              task tcyc
-            endfamily
-            family 00
-              edit OCGROUP 'an00'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '00'
-              edit MEMBER '00'
-              task tcyc
-            endfamily
-            family 01
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '01'
-              edit MEMBER '01'
-              task tcyc
-            endfamily
-            family 02
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '02'
-              edit MEMBER '02'
-              task tcyc
-            endfamily
-            family 03
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '03'
-              edit MEMBER '03'
-              task tcyc
-            endfamily
-            family 04
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc0'
-              edit EPSMEMBER '04'
-              edit MEMBER '04'
-              task tcyc
-            endfamily
-            family 05
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '05'
-              edit MEMBER '05'
-              task tcyc
-            endfamily
-            family 06
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '06'
-              edit MEMBER '06'
-              task tcyc
-            endfamily
-            family 07
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '07'
-              edit MEMBER '07'
-              task tcyc
-            endfamily
-            family 08
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '08'
-              edit MEMBER '08'
-              task tcyc
-            endfamily
-            family 09
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc1'
-              edit EPSMEMBER '09'
-              edit MEMBER '09'
-              task tcyc
-            endfamily
-            family 10
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '10'
-              edit MEMBER '10'
-              task tcyc
-            endfamily
-            family 11
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '11'
-              edit MEMBER '11'
-              task tcyc
-            endfamily
-            family 12
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '12'
-              edit MEMBER '12'
-              task tcyc
-            endfamily
-            family 13
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '13'
-              edit MEMBER '13'
-              task tcyc
-            endfamily
-            family 14
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc2'
-              edit EPSMEMBER '14'
-              edit MEMBER '14'
-              task tcyc
-            endfamily
-            family 15
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '15'
-              edit MEMBER '15'
-              task tcyc
-            endfamily
-            family 16
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '16'
-              edit MEMBER '16'
-              task tcyc
-            endfamily
-            family 17
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '17'
-              edit MEMBER '17'
-              task tcyc
-            endfamily
-            family 18
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '18'
-              edit MEMBER '18'
-              task tcyc
-            endfamily
-            family 19
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc3'
-              edit EPSMEMBER '19'
-              edit MEMBER '19'
-              task tcyc
-            endfamily
-            family 20
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '20'
-              edit MEMBER '20'
-              task tcyc
-            endfamily
-            family 21
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '21'
-              edit MEMBER '21'
-              task tcyc
-            endfamily
-            family 22
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '22'
-              edit MEMBER '22'
-              task tcyc
-            endfamily
-            family 23
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '23'
-              edit MEMBER '23'
-              task tcyc
-            endfamily
-            family 24
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc4'
-              edit EPSMEMBER '24'
-              edit MEMBER '24'
-              task tcyc
-            endfamily
-            family 25
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '25'
-              edit MEMBER '25'
-              task tcyc
-            endfamily
-            family 26
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '26'
-              edit MEMBER '26'
-              task tcyc
-            endfamily
-            family 27
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '27'
-              edit MEMBER '27'
-              task tcyc
-            endfamily
-            family 28
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '28'
-              edit MEMBER '28'
-              task tcyc
-            endfamily
-            family 29
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc5'
-              edit EPSMEMBER '29'
-              edit MEMBER '29'
-              task tcyc
-            endfamily
-            family 30
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '30'
-              edit MEMBER '30'
-              task tcyc
-            endfamily
-            family 31
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '31'
-              edit MEMBER '31'
-              task tcyc
-            endfamily
-            family 32
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '32'
-              edit MEMBER '32'
-              task tcyc
-            endfamily
-            family 33
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '33'
-              edit MEMBER '33'
-              task tcyc
-            endfamily
-            family 34
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc6'
-              edit EPSMEMBER '34'
-              edit MEMBER '34'
-              task tcyc
-            endfamily
-            family 35
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '35'
-              edit MEMBER '35'
-              task tcyc
-            endfamily
-            family 36
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '36'
-              edit MEMBER '36'
-              task tcyc
-            endfamily
-            family 37
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '37'
-              edit MEMBER '37'
-              task tcyc
-            endfamily
-            family 38
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '38'
-              edit MEMBER '38'
-              task tcyc
-            endfamily
-            family 39
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc7'
-              edit EPSMEMBER '39'
-              edit MEMBER '39'
-              task tcyc
-            endfamily
-            family 40
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '40'
-              edit MEMBER '40'
-              task tcyc
-            endfamily
-            family 41
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '41'
-              edit MEMBER '41'
-              task tcyc
-            endfamily
-            family 42
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '42'
-              edit MEMBER '42'
-              task tcyc
-            endfamily
-            family 43
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '43'
-              edit MEMBER '43'
-              task tcyc
-            endfamily
-            family 44
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc8'
-              edit EPSMEMBER '44'
-              edit MEMBER '44'
-              task tcyc
-            endfamily
-            family 45
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '45'
-              edit MEMBER '45'
-              task tcyc
-            endfamily
-            family 46
-              edit OCGROUP 'an1'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '46'
-              edit MEMBER '46'
-              task tcyc
-            endfamily
-            family 47
-              edit OCGROUP 'an2'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '47'
-              edit MEMBER '47'
-              task tcyc
-            endfamily
-            family 48
-              edit OCGROUP 'an3'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '48'
-              edit MEMBER '48'
-              task tcyc
-            endfamily
-            family 49
-              edit OCGROUP 'an4'
-              edit FCGROUP 'fc9'
-              edit EPSMEMBER '49'
-              edit MEMBER '49'
-              task tcyc
-            endfamily
-            family 50
-              edit OCGROUP 'an0'
-              edit FCGROUP 'fc10'
-              edit EPSMEMBER '50'
-              edit MEMBER '50'
-              task tcyc
-            endfamily
-          endfamily
-          task tcyctoecfs
-            trigger genesis eq complete
-        endfamily
-        family mjo
-          complete /emc_36r1/lag/ref/00/events:cf
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete)
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit FCLENGTH '360'
-          edit ERA40END '2002033000'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-          edit RUNVARFC '1'
-          inlimit /limits:linux_cluster
-          family stage
-            edit RETRIEVE 'stage'
-            edit DELTA_DAY '2'
-            task chi200
-            task olr
-            task u200
-            task u850
-          endfamily
-          family process
-            task chi200
-            task olr
-            task u850
-            task u200
-          endfamily
-          family ncep
-            trigger ./process eq complete
-            task olr_to_ncep
-            task u200_to_ncep
-            task u850_to_ncep
-          endfamily
-          task ncep_daily
-            trigger ./ncep eq complete
-          task ceof
-            trigger process eq complete
-          task mjo_migrate
-            complete /emc_36r1/pop/00/events:768
-            trigger process eq complete and ceof eq complete and ncep_daily eq complete
-          task mjo_clean
-            complete /emc_36r1/pop/00/events:768
-            trigger process eq complete and ncep eq complete and ncep_daily eq complete and ceof eq complete and mjo_migrate eq complete
-        endfamily
-      endfamily
-      family web
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
-        inlimit /limits:linux_cluster
-        inlimit /emc_36r1/limits:webplots
-        family pf
-          complete /emc_36r1/pop/00/events:cf
-          trigger /emc_36r1/pop/00/events eq complete
-          task plumes
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/cf eq complete and /emc_36r1/main/00/legA/fc/pf eq complete)
-          family classic
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/clusters eq complete)
-            edit ANALYSIS 'NO'
-            task clplot
-            task pltube
-            task enplot
-              edit STEPS '12 24 36 48 60 72 84 96 108 120 132 144 156 168 180 192'
-              edit PRINTSTEPS '60 84 108 132 156 180'
-          endfamily
-          family efi
-            complete /emc_36r1/pop/00/events:noefi
-            trigger ../../data/fields eq complete
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
-            inlimit /limits:linux_cluster
-            inlimit /emc_36r1/limits:webplots
-            family efi_tpi
-              task w_efi
-                edit PARAMETER 'tpi'
-            endfamily
-            family efi_10wsi
-              task w_efi
-                edit PARAMETER '10wsi'
-            endfamily
-            family efi_2ti
-              task w_efi
-                edit PARAMETER '2ti'
-            endfamily
-            family efi_10fgi
-              task w_efi
-                edit PARAMETER '10fgi'
-            endfamily
-            task globalefi
-              edit UPDATE_WEB_NOW 'yes'
-          endfamily
-          family proba
-            trigger ../../data/fields eq complete
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'plots-medium'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
-            edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia,Africa,Global'
-            inlimit /limits:linux_cluster
-            inlimit /emc_36r1/limits:webplots
-            family members
-              family legA
-                edit PLOT_STEPS '12/to/240/by/12'
-                edit STEP_RANGE 'legA'
-                task pb_2t
-                task pb_ff
-                task pb_tp
-                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
-                task w_proba_gusts
-                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
-                task pb_tpr
-                task pb_mwp
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-                task pb_swh
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-              endfamily
-              family legB
-                trigger ( ./legA eq complete)
-                edit PLOT_STEPS '252/to/360/by/12'
-                edit STEP_RANGE 'legB'
-                edit UPDATE_WEB_NOW 'yes'
-                task pb_2t
-                task pb_ff
-                task pb_tp
-                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
-                task w_proba_gusts
-                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
-                task pb_mwp
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-                task pb_swh
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-              endfamily
-              family means
-                trigger ( ./legA eq complete)
-                edit UPDATE_WEB_NOW 'yes'
-                task long_pb_2t
-                task long_pb_tpr
-                task long_w_proba_gusts
-                task long_pb_mwp
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-                task long_pb_swh
-                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
-              endfamily
-            endfamily
-            family additional
-              edit PLOT_STEPS '12/to/156/by/12'
-              edit STEP_RANGE 'legA'
-              task w_proba_rain
-              family wmo_waves
-                edit PLOT_STEPS '12/to/168/by/12'
-                edit PLOT_AREAS 'Global'
-                edit PLOT_GRID '2.5/2.5'
-                task pb_swh
-              endfamily
-            endfamily
-          endfamily
-          family ensm
-            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc/ensms eq complete and /emc_36r1/main/00/legA/postproc/ensms eq complete)
-            task fields_ensm
-              event 30 
-            task plot_ensm_Z
-              complete fields_ensm eq complete and not fields_ensm:30
-              trigger fields_ensm eq complete and fields_ensm:30
-            task plot_ensm_T
-              complete fields_ensm eq complete and not fields_ensm:30
-              trigger fields_ensm eq complete and fields_ensm:30
-            task cleanup_ensm
-              trigger plot_ensm_Z eq complete and plot_ensm_T eq complete
-          endfamily
-          family tc
-            edit WSHOST 'linux_cluster'
-            edit QUEUE 'emos-e'
-            edit QUEUE_EPILOG 'emos-exp'
-            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-            edit LOGDIR '/vol/emos_nc/output'
-            edit SMSOUT '/vol/emos_nc/output'
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/tc'
-            inlimit /limits:linux_cluster
-            family plotting
-              trigger ( /emc_36r1/pop/00/data/tc/post_process eq complete)
-              task spm
-              task epsgram
-              task tstorm
-              task tstorm_web
-                trigger tstorm eq complete
-            endfamily
-            task tc2web
-              trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and ./plotting eq complete and /emc_36r1/pop/00/data/tc/diagnostics eq complete)
-              edit WSHOST 'linux_cluster'
-          endfamily
-          family special
-            family swdfp
-              edit WSHOST 'linux_cluster'
-              edit QUEUE 'serial'
-              edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/swdfp'
-              edit PLOTDOM '-45/-10/6/62'
-              edit UPDATE_WEB_NOW 'yes'
-              time 10:30
-              family efi
-                trigger /emc_36r1/pop/00/data/fields eq complete
-                edit QUEUE 'emos-e'
-                edit QUEUE_EPILOG 'emos-exp'
-                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                edit LOGDIR '/vol/emos_nc/output'
-                edit SMSOUT '/vol/emos_nc/output'
-                inlimit /limits:linux_cluster
-                family swdfp_tpi
-                  task w_efi
-                    edit PARAMETER 'tpi'
-                endfamily
-                family swdfp_10wsi
-                  task w_efi
-                    edit PARAMETER '10wsi'
-                endfamily
-                family swdfp_2ti
-                  task w_efi
-                    edit PARAMETER '2ti'
-                endfamily
-                family swdfp_10fgi
-                  task w_efi
-                    edit PARAMETER '10fgi'
-                endfamily
-              endfamily
-              family proba
-                trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/prob eq complete)
-                edit PLOT_LOCATION '/webplots_e/data/swdfp/proba'
-                edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
-                task swdfp_proba
-                task swdfp_tp
-                  trigger ./swdfp_proba eq complete
-                task swdfp_ff
-                  trigger ./swdfp_proba eq complete
-                task swdfp_tp24
-                  trigger ./swdfp_proba eq complete
-                  edit STEPS '24/48/72/96/120'
-                task swdfp_proba_clean
-                  trigger ./swdfp_tp eq complete and ./swdfp_ff eq complete and ./swdfp_tp24 eq complete
-              endfamily
-              task swdfp_epsgram
-                trigger /emc_36r1/pop/00/data/metgram eq complete
-            endfamily
-          endfamily
-        endfamily
-        family verification
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit DATEMASK '11.*.*'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/verification'
-          inlimit /limits:linux_cluster
-          task w_probas
-          task w_costloss
-          task w_timeseries
-        endfamily
-        task web_update
-          trigger pf/proba/members/legA eq complete and pf/proba/additional eq complete and pf/plumes eq complete and pf/classic eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit PACKAGES 'esuite'
-          edit UPDATE_STREAM 'enfo'
-          inlimit /emc_36r1/limits:webplots
-      endfamily
-      family paper
-        trigger web/web_update eq complete
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/plot'
-        inlimit /limits:linux_cluster
-        task epsgram
-          trigger ../data/metgram eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/paper'
-        family enplot
-          complete /emc_36r1/pop/00/events:cf
-          trigger ( /emc_36r1/pop/00/events eq complete) and ( ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/clusters eq complete))
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit ANALYSIS 'NO'
-          task sthemi
-        endfamily
-        family tube
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/clusters eq complete)
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          inlimit /limits:linux_cluster
-          task ptubfr
-          task tubfrfax
-            trigger ptubfr eq complete
-            edit QUEUE 'emos'
-          task tubukfax
-            trigger ptubuk eq complete
-            edit QUEUE 'emos'
-          task ptubuk
-            trigger ptubfr eq complete
-        endfamily
-        family prob
-          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/prob eq complete)
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'plots-medium'
-          edit ANALYSIS 'YES'
-          inlimit /emc_36r1/limits:webplots
-          task clplot
-            trigger ../enplot eq complete
-          task s144
-            trigger clplot eq complete
-            edit STEPS '144'
-          task plumea
-          task pb
-        endfamily
-      endfamily
-      task cleanup
-        trigger paper eq complete and web eq complete
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'plots-medium'
-        inlimit /limits:linux_cluster
-        inlimit /emc_36r1/limits:webplots
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      trigger ../main/make eq complete and ./12 eq complete and ./00 eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1'
-  endfamily
-  family msjobs
-    complete ( /emc_36r1/msjobs:YMD le /emc_36r1/main:YMD) and /emc_36r1/main/logfiles eq active
-    repeat date YMD 20091003 20121212 1
-    edit QUEUE 'emos'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit WSHOST 'ecgate'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit SMSOUT '/vol/emos_nc/output'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit STREAM 'EF'
-    edit EMOS_STREAM 'EF'
-    edit SMSURLBASE 'http://ecgate.ecmwf.int:9080'
-    edit SMSURL 'do/events'
-    edit SMSFILES '/home/ma/emos/def/emc_36r1'
-    edit DELTA_DAY '-1'
-    edit LOGTASK 'msjobs'
-    family 12
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete and /emc_36r1/main/12/legA/postproc/clusters eq complete and /emc_36r1/main/12/ref/model eq complete)
-      edit EMOS_BASE '12'
-      edit DELTA_DAY '-1'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs'
-      edit SMSTRIES '1'
-      family ms036
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '036'
-        edit MSJ_DIR 'ef12h036'
-        task ms_ec
-      endfamily
-      family ms072
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '072'
-        edit MSJ_DIR 'ef12h072'
-        task ms_ec
-      endfamily
-      family ms120
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '120'
-        edit MSJ_DIR 'ef12h120'
-        task ms_ec
-      endfamily
-      family ms144
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '144'
-        edit MSJ_DIR 'ef12h144'
-        task ms_ec
-      endfamily
-      family ms240
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'ef12h240'
-        task ms_ec
-      endfamily
-      family ms360
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legB/fc eq complete)
-        edit EMOS_TIME_STEP_H '360'
-        edit MSJ_DIR 'ef12h360'
-        task ms_ec
-      endfamily
-      family ms240post
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'ef12h240post'
-        task ms_ec
-      endfamily
-      family ms360post
-        edit EMOS_TIME_STEP_H '360'
-        edit MSJ_DIR 'ef12h360post'
-        task ms_ec
-      endfamily
-      family ms240metgram
-        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/12/data/metgram/240/gdb eq complete)
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'ef12h240metgram'
-        task ms_ec
-      endfamily
-      family ms360metgram
-        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/12/data/metgram/15d/gdb eq complete)
-        edit EMOS_TIME_STEP_H '360'
-        edit MSJ_DIR 'ef12h360metgram'
-        task ms_ec
-      endfamily
-      family ems240
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/prod2diss eq complete)
-        edit EMOS_TIME_STEP '240'
-        edit MSJ_DIR 'eef12h240'
-        task ms_ec
-      endfamily
-    endfamily
-    family 00
-      trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete and /emc_36r1/main/00/legA/postproc/clusters eq complete and /emc_36r1/main/00/ref/model eq complete)
-      edit EMOS_BASE '00'
-      edit DELTA_DAY '0'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs'
-      edit SMSTRIES '1'
-      family ms036
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '036'
-        edit MSJ_DIR 'ef00h036'
-        task ms_ec
-      endfamily
-      family ms072
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '072'
-        edit MSJ_DIR 'ef00h072'
-        task ms_ec
-      endfamily
-      family ms120
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '120'
-        edit MSJ_DIR 'ef00h120'
-        task ms_ec
-      endfamily
-      family ms144
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '144'
-        edit MSJ_DIR 'ef00h144'
-        task ms_ec
-      endfamily
-      family ms240
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'ef00h240'
-        task ms_ec
-      endfamily
-      family ms360
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legB/fc eq complete)
-        edit EMOS_TIME_STEP_H '360'
-        edit MSJ_DIR 'ef00h360'
-        task ms_ec
-      endfamily
-      family ms240post
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'ef00h240post'
-        task ms_ec
-      endfamily
-      family ms360post
-        edit EMOS_TIME_STEP_H '360'
-        edit MSJ_DIR 'ef00h360post'
-        task ms_ec
-      endfamily
-      family ms240metgram
-        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/00/data/metgram/240/gdb eq complete)
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'ef00h240metgram'
-        task ms_ec
-      endfamily
-      family ms360metgram
-        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/00/data/metgram/15d/gdb eq complete)
-        edit EMOS_TIME_STEP_H '360'
-        edit MSJ_DIR 'ef00h360metgram'
-        task ms_ec
-      endfamily
-      family ems240
-        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/prod2diss eq complete)
-        edit EMOS_TIME_STEP '240'
-        edit MSJ_DIR 'eef00h240'
-        task ms_ec
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      inlimit /limits:linux_cluster
-    task logfiles
-      trigger ./00 eq complete and ./12 eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      inlimit /limits:linux_cluster
-      time 13:15
-  endfamily
-  family verify
-    trigger ./00:YMD gt ./verify:YMD or ( ./00:YMD eq ./verify:YMD and ./00/ref/tue eq complete)
-    repeat date YMD 20091007 20121212 7
-    edit ACCOUNT 'oeenfo'
-    edit WSHOST 'linux_cluster'
-    edit UPDATE_WEB_NOW 'yes'
-    edit EMOS_BASE '00'
-    edit QUEUE 'emos-e'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit SMSOUT '/vol/emos_nc/output'
-    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg/verify'
-    edit FSFAMILY 'assim'
-    edit FCTOTAL '51'
-    edit DELTA_DAY '-27'
-    edit RUNHINDCAST '1'
-    edit RUNVARFC '1'
-    edit EMOS_TYPE '00'
-    edit LOGTASK '00'
-    inlimit /limits:linux_cluster
-    family init
-      task list_verif
-      task getana
-        trigger list_verif eq complete
-      task getmofc
-        trigger getana eq complete
-    endfamily
-    family anomaly
-      trigger init eq complete
-      family temp
-        edit VAR 'TEMP'
-        task stats_verif
-        task plot_verif
-          trigger stats_verif eq complete
-      endfamily
-      family rain
-        trigger temp eq complete
-        edit VAR 'RAIN'
-        task stats_verif
-        task plot_verif
-          trigger stats_verif eq complete
-      endfamily
-      family mslp
-        trigger rain eq complete
-        edit VAR 'MSLP'
-        task stats_verif
-        task plot_verif
-          trigger stats_verif eq complete
-      endfamily
-      family 2mtm
-        trigger mslp eq complete
-        edit VAR '2MTM'
-        task stats_verif
-        task plot_verif
-          trigger stats_verif eq complete
-      endfamily
-      family z500
-        trigger ./2mtm eq complete
-        task flowz500_verif
-      endfamily
-      task webvanomaly
-        trigger ./z500 eq complete
-        edit FSFAMILY 'mofc'
-        edit QUEUE 'plots-medium'
-    endfamily
-    family scores
-      trigger anomaly eq complete
-      task mofcdaily_verif
-      task mofcweekly_verif
-        trigger mofcdaily_verif eq complete
-      task alldaily
-        trigger mofcweekly_verif eq complete
-      task allweekly
-        trigger alldaily eq complete
-      task sctoweb
-        trigger allweekly eq complete
-        edit FSFAMILY 'mofc'
-    endfamily
-    family probability
-      trigger scores eq complete
-      family rain
-        edit VAR 'RAIN'
-        task table
-        task stats
-          trigger ./table eq complete
-        task stats1
-          trigger ./stats eq complete
-        task plot_relia
-          trigger ./stats1 eq complete
-        task plot_roc
-          trigger ./plot_relia eq complete
-        task plot_rocmap
-          trigger ./plot_roc eq complete
-        task plot_rpssmap
-          trigger ./plot_rocmap eq complete
-        task plot_value
-          trigger ./plot_rpssmap eq complete
-      endfamily
-      family temp
-        trigger ./rain eq complete
-        edit VAR 'TEMP'
-        task table
-        task stats
-          trigger ./table eq complete
-        task stats1
-          trigger ./stats eq complete
-        task plot_relia
-          trigger ./stats1 eq complete
-        task plot_roc
-          trigger ./plot_relia eq complete
-        task plot_rocmap
-          trigger ./plot_roc eq complete
-        task plot_rpssmap
-          trigger ./plot_rocmap eq complete
-        task plot_value
-          trigger ./plot_rpssmap eq complete
-      endfamily
-      family mslp
-        trigger ./temp eq complete
-        edit VAR 'MSLP'
-        task table
-        task stats
-          trigger ./table eq complete
-        task stats1
-          trigger ./stats eq complete
-        task plot_relia
-          trigger ./stats1 eq complete
-        task plot_roc
-          trigger ./plot_relia eq complete
-        task plot_rocmap
-          trigger ./plot_roc eq complete
-        task plot_rpssmap
-          trigger ./plot_rocmap eq complete
-        task plot_value
-          trigger ./plot_rpssmap eq complete
-      endfamily
-      family 2mtm
-        trigger ./mslp eq complete
-        edit VAR '2MTM'
-        task table
-        task stats
-          trigger ./table eq complete
-        task stats1
-          trigger ./stats eq complete
-        task plot_relia
-          trigger ./stats1 eq complete
-        task plot_roc
-          trigger ./plot_relia eq complete
-        task plot_rocmap
-          trigger ./plot_roc eq complete
-        task plot_rpssmap
-          trigger ./plot_rocmap eq complete
-        task plot_value
-          trigger ./plot_rpssmap eq complete
-      endfamily
-      family pbtoweb
-        trigger ./2mtm eq complete
-        edit FSFAMILY 'mofc'
-        task reliability
-        task roc
-          trigger ./reliability eq complete
-        task rocmap
-          trigger ./roc eq complete
-        task rpssmap
-          trigger ./rocmap eq complete
-        task value
-          trigger ./rpssmap eq complete
-      endfamily
-    endfamily
-    task clean_verif
-      trigger init eq complete and anomaly eq complete and scores eq complete and probability eq complete
-      edit DELTA_DAY '-14'
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      edit FSFAMILY 'mc'
-    task logfiles
-      late -s +00:05 -c +00:35
-      trigger logfilestore eq complete and init eq complete and anomaly eq complete and scores eq complete and probability eq complete and clean_verif eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FSFAMILY 'mc'
-      edit SMSFILES '/home/ma/emos/def/emc_36r1'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-  family efi_next
-    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi'
-    edit EVERSION '0046'
-    edit IMPL_DATE '2012121212'
-    edit EMOS_BASE '00'
-    edit MARS_DB 'marsod'
-    edit EMOS_TYPE 'undef'
-    edit EPS_VERSION '0046'
-    edit VERSION '9939'
-    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-    edit SMSURL 'GENFO/00'
-    edit UPDATE_WEB_NOW 'yes'
-    edit MARS_NEW '0'
-    edit QUEUE 'ns'
-    edit QUEUE_EPILOG 'ns'
-    edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/s1b/emos_esuite/emos_data/9946/log'
-    edit SMSOUT '/s1b/emos_esuite/emos_data/9946/log'
-    limit ext 45
-    inlimit /limits:c1b
-    inlimit ext
-    family mn
-      trigger ./mn:YMD lt ./clim:YMD
-      repeat date YMD 20080221 20121212 1
-      family deps
-        edit SSMFILES '/home/ma/emos/def/emc_36r1'
-        family 00
-          trigger ( ( ( /emc_36r1/main/00/legA/postproc eq complete) and ( /emc_36r1/main/00/legB/postproc eq complete)) and ( /emc_36r1/main:YMD eq ../../mn:YMD)) or ( /emc_36r1/main:YMD gt ../../mn:YMD)
-          task dummy
-            complete 1 eq 1
-        endfamily
-        family 12
-          trigger ( ( ( /emc_36r1/main/12/legA/postproc eq complete) and ( /emc_36r1/main/12/legB/postproc eq complete)) and ( /emc_36r1/main:YMD eq ../../mn:YMD)) or ( /emc_36r1/main:YMD gt ../../mn:YMD)
-          task dummy
-            complete 1 eq 1
-        endfamily
-      endfamily
-      family 12
-        trigger ./deps/12 eq complete
-        edit EMOS_BASE '12'
-        family op
-          edit EPSLEG '1'
-          task stage
-          family 024
-            family 012_036
-              edit ACC '024'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_060
-              edit ACC '024'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_084
-              edit ACC '024'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_108
-              edit ACC '024'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_132
-              edit ACC '024'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '024'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '024'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '024'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            trigger ./024 eq complete
-            family 000_120
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_144
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            trigger ./024 eq complete
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family nop
-          edit EPSLEG '2'
-          task stage
-          family 024
-            family 012_036
-              edit ACC '024'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '036'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_060
-              edit ACC '024'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '060'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_084
-              edit ACC '024'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '084'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_108
-              edit ACC '024'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '108'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_132
-              edit ACC '024'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '132'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 132_156
-              edit ACC '024'
-              edit EFI_STEP1 '132'
-              edit EFI_STEP2 '156'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 156_180
-              edit ACC '024'
-              edit EFI_STEP1 '156'
-              edit EFI_STEP2 '180'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 180_204
-              edit ACC '024'
-              edit EFI_STEP1 '180'
-              edit EFI_STEP2 '204'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 204_228
-              edit ACC '024'
-              edit EFI_STEP1 '204'
-              edit EFI_STEP2 '228'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '24'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '24'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '24'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 240_264
-              edit ACC '24'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '264'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 264_288
-              edit ACC '24'
-              edit EFI_STEP1 '264'
-              edit EFI_STEP2 '288'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 288_312
-              edit ACC '24'
-              edit EFI_STEP1 '288'
-              edit EFI_STEP2 '312'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 312_336
-              edit ACC '24'
-              edit EFI_STEP1 '312'
-              edit EFI_STEP2 '336'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 336_360
-              edit ACC '24'
-              edit EFI_STEP1 '336'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 072
-            family 012_084
-              edit ACC '072'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '084'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_108
-              edit ACC '072'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '108'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_132
-              edit ACC '072'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '132'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_156
-              edit ACC '072'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '156'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_180
-              edit ACC '072'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '180'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 132_204
-              edit ACC '072'
-              edit EFI_STEP1 '132'
-              edit EFI_STEP2 '204'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 156_228
-              edit ACC '072'
-              edit EFI_STEP1 '156'
-              edit EFI_STEP2 '228'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            family 012_132
-              edit ACC '120'
-              edit EFI_STEP1 '012'
-              edit EFI_STEP2 '132'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 036_156
-              edit ACC '120'
-              edit EFI_STEP1 '036'
-              edit EFI_STEP2 '156'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 060_180
-              edit ACC '120'
-              edit EFI_STEP1 '060'
-              edit EFI_STEP2 '180'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 084_204
-              edit ACC '120'
-              edit EFI_STEP1 '084'
-              edit EFI_STEP2 '204'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 108_228
-              edit ACC '120'
-              edit EFI_STEP1 '108'
-              edit EFI_STEP2 '228'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 240_360
-              edit ACC '120'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 360
-            family 000_360
-              edit ACC '360'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_op
-          trigger op eq complete
-          edit EPSLEG '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_nop
-          trigger nop eq complete
-          edit EPSLEG '2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmin
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family ts
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family hsttmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'hsstmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family data
-          trigger arch_op eq complete and arch_nop eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efidata
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efidata
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efidata
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efidata
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efidata
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efidata
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efidata
-          endfamily
-          family hsstmax
-            edit PARAM 'hsstmax'
-            task efidata
-              edit PARAM 'hsttmax'
-          endfamily
-        endfamily
-        family plot
-          trigger data eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSURLBASE 'http://intra.ecmwf.int/plots'
-          edit SMSURL 'd/inspect/esuite/esuite_33r1/medium/eps/efi/'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-          edit METVIEW 'metview_new'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efiplot
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efiplot
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efiplot
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efiplot
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efiplot
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efiplot
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efiplot
-          endfamily
-          family hsstmax
-            edit PARAM 'hsstmax'
-            task efiplot
-              edit PARAM 'hsstmax'
-          endfamily
-          family hsttmax
-            edit PARAM 'hsttmax'
-            task efiplot
-          endfamily
-        endfamily
-      endfamily
-      family 00
-        trigger ( ./deps/00 eq complete or ./deps/00 eq unknown) and ( ./12 eq complete or ./12 eq unknown)
-        edit EMOS_BASE '00'
-        edit DELTA_DAY '1'
-        edit STEP1 '-1'
-        family op
-          edit EPSLEG '1'
-          task stage
-          family 024
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '024'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '024'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '024'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            trigger ./024 eq complete
-            family 000_120
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_144
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            trigger ./024 eq complete
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family nop
-          edit EPSLEG '2'
-          task stage
-          family 024
-            family 000_024
-              edit ACC '024'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '024'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_048
-              edit ACC '024'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '048'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_072
-              edit ACC '024'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '072'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_096
-              edit ACC '024'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '096'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_120
-              edit ACC '024'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '120'
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family reproc
-              family 120_144
-                edit ACC '024'
-                edit EFI_STEP1 '120'
-                edit EFI_STEP2 '144'
-                family tp
-                  edit RF_NAME 'tp'
-                  task extindex
-                endfamily
-              endfamily
-              family 144_168
-                edit ACC '024'
-                edit EFI_STEP1 '144'
-                edit EFI_STEP2 '168'
-                family tp
-                  edit RF_NAME 'tp'
-                  task extindex
-                endfamily
-              endfamily
-            endfamily
-            family 120_144
-              edit ACC '024'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 144_168
-              edit ACC '024'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '168'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10fg
-                edit RF_NAME '10fg'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmin
-                edit RF_NAME '2tmin'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2tmax
-                edit RF_NAME '2tmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family hsttmax
-                edit RF_NAME 'hsttmax'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family ts
-                edit RF_NAME 'ts'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 168_192
-              edit ACC '24'
-              edit EFI_STEP1 '168'
-              edit EFI_STEP2 '192'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 192_216
-              edit ACC '24'
-              edit EFI_STEP1 '192'
-              edit EFI_STEP2 '216'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 216_240
-              edit ACC '24'
-              edit EFI_STEP1 '216'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 240_264
-              edit ACC '24'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '264'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 264_288
-              edit ACC '24'
-              edit EFI_STEP1 '264'
-              edit EFI_STEP2 '288'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 288_312
-              edit ACC '24'
-              edit EFI_STEP1 '288'
-              edit EFI_STEP2 '312'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 312_336
-              edit ACC '24'
-              edit EFI_STEP1 '312'
-              edit EFI_STEP2 '336'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-            family 336_360
-              edit ACC '24'
-              edit EFI_STEP1 '336'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-              endfamily
-            endfamily
-          endfamily
-          family 072
-            family 000_072
-              edit ACC '072'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '072'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_096
-              edit ACC '072'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '096'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_120
-              edit ACC '072'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '120'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_144
-              edit ACC '072'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '144'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_168
-              edit ACC '072'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 120_192
-              edit ACC '072'
-              edit EFI_STEP1 '120'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 144_216
-              edit ACC '072'
-              edit EFI_STEP1 '144'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 120
-            family 000_120
-              edit ACC '120'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '120'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 024_144
-              edit ACC '120'
-              edit EFI_STEP1 '024'
-              edit EFI_STEP2 '144'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 048_168
-              edit ACC '120'
-              edit EFI_STEP1 '048'
-              edit EFI_STEP2 '168'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 072_192
-              edit ACC '120'
-              edit EFI_STEP1 '072'
-              edit EFI_STEP2 '192'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 096_216
-              edit ACC '120'
-              edit EFI_STEP1 '096'
-              edit EFI_STEP2 '216'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-            family 240_360
-              edit ACC '120'
-              edit EFI_STEP1 '240'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 240
-            family 000_240
-              edit ACC '240'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '240'
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-          family 360
-            family 000_360
-              edit ACC '360'
-              edit EFI_STEP1 '000'
-              edit EFI_STEP2 '360'
-              family tp
-                edit RF_NAME 'tp'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 2t
-                edit RF_NAME '2t'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-              family 10ff
-                edit RF_NAME '10ff'
-                task prepeps
-                task extindex
-                  trigger ./prepeps eq complete
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_op
-          trigger op eq complete
-          edit EPSLEG '1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family arch_nop
-          trigger nop eq complete
-          edit EPSLEG '2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-          task efi2fdb
-            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-            event none
-          family arch
-            trigger ./efi2fdb eq complete
-            family 2t
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2t'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10ff
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10ff'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 10fg
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '10fg'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family tp
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'tp'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmin
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmin'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family 2tmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME '2tmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family ts
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'ts'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-            family hsttmax
-              edit step1 '24'
-              edit step2 '24'
-              edit RF_NAME 'hsstmax'
-              task efi
-                label info ""
-              family sot
-                edit EFI_TYPE 'sot'
-                task efi
-              endfamily
-            endfamily
-          endfamily
-        endfamily
-        family data
-          trigger arch_op eq complete and arch_nop eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efidata
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efidata
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efidata
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efidata
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efidata
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efidata
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efidata
-          endfamily
-          family hsstmax
-            edit PARAM 'hsstmax'
-            task efidata
-          endfamily
-        endfamily
-        family plot
-          trigger data eq complete
-          edit WSHOST 'linux_cluster'
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit SMSURLBASE 'http://intra.ecmwf.int/plots'
-          edit SMSURL 'd/inspect/esuite/esuite_33r1/medium/eps/efi/'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
-          edit METVIEW 'metview_new'
-          inlimit /limits:linux_cluster
-          family 2t
-            edit PARAM '2t'
-            task efiplot
-          endfamily
-          family 2tmin
-            edit PARAM '2tmin'
-            task efiplot
-          endfamily
-          family 2tmax
-            edit PARAM '2tmax'
-            task efiplot
-          endfamily
-          family tp
-            edit PARAM 'tp'
-            task efiplot
-          endfamily
-          family 10ff
-            edit PARAM '10ff'
-            task efiplot
-          endfamily
-          family 10fg
-            edit PARAM '10fg'
-            task efiplot
-          endfamily
-          family sf
-            edit PARAM 'sf'
-            task efiplot
-          endfamily
-          family hsstmax
-            edit PARAM 'hsstmax'
-            task efiplot
-              edit PARAM 'hsttmax'
-          endfamily
-          family hsttmax
-            edit PARAM 'hsttmax'
-            task efiplot
-              edit PARAM 'hsstmax'
-          endfamily
-        endfamily
-      endfamily
-      task efi_cleaner
-        trigger ( ./12 eq complete or ./12 eq unknown) and ( ./00 eq complete or ./00 eq unknown)
-    endfamily
-    family hind
-      repeat date YMD 20080717 20121212 7
-      edit DELTA_DAY '0'
-      family stage
-        edit RF_NAME 'all'
-        edit RETRIEVE 'stage'
-        task prep
-      endfamily
-      family op
-        trigger ./stage eq complete
-        edit EPSLEG '1'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          trigger ./024 eq complete
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          trigger ./024 eq complete
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family nop
-        trigger ./stage eq complete
-        edit EPSLEG '2'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 240_264
-            edit ACC '024'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '264'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 264_288
-            edit ACC '024'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '288'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 288_312
-            edit ACC '024'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '312'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 312_336
-            edit ACC '024'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-          family 336_360
-            edit ACC '024'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '360'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 000
-          family 006_006
-            edit ACC '000'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '006'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 012_012
-            edit ACC '000'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '012'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 018_018
-            edit ACC '000'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '018'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 024_024
-            edit ACC '000'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '024'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 030_030
-            edit ACC '000'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '030'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 036_036
-            edit ACC '000'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '036'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 042_042
-            edit ACC '000'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '042'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 048_048
-            edit ACC '000'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '048'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 054_054
-            edit ACC '000'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '054'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 060_060
-            edit ACC '000'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '060'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 066_066
-            edit ACC '000'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '066'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 072_072
-            edit ACC '000'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '072'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 078_078
-            edit ACC '000'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '078'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 084_084
-            edit ACC '000'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '084'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 090_090
-            edit ACC '000'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '090'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 096_096
-            edit ACC '000'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '096'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 102_102
-            edit ACC '000'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '102'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 108_108
-            edit ACC '000'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '108'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 114_114
-            edit ACC '000'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '114'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_120
-            edit ACC '000'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '120'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 126_126
-            edit ACC '000'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '126'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 132_132
-            edit ACC '000'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '132'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 138_138
-            edit ACC '000'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '138'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 144_144
-            edit ACC '000'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '144'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 150_150
-            edit ACC '000'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '150'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 156_156
-            edit ACC '000'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '156'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 162_162
-            edit ACC '000'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '162'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 168_168
-            edit ACC '000'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '168'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 174_174
-            edit ACC '000'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '174'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 180_180
-            edit ACC '000'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '180'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 186_186
-            edit ACC '000'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '186'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 192_192
-            edit ACC '000'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '192'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 198_198
-            edit ACC '000'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '198'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 204_204
-            edit ACC '000'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '204'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 210_210
-            edit ACC '000'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '210'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 216_216
-            edit ACC '000'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '216'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 222_222
-            edit ACC '000'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '222'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 228_228
-            edit ACC '000'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '228'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 234_234
-            edit ACC '000'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '234'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 240_240
-            edit ACC '000'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '240'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 252_252
-            edit ACC '000'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '252'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 264_264
-            edit ACC '000'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '264'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 276_276
-            edit ACC '000'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '276'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 288_288
-            edit ACC '000'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '288'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 300_300
-            edit ACC '000'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '300'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 312_312
-            edit ACC '000'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '312'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 324_324
-            edit ACC '000'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '324'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 336_336
-            edit ACC '000'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '336'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 348_348
-            edit ACC '000'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '348'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-          family 360_360
-            edit ACC '000'
-            edit EFI_STEP1 '360'
-            edit EFI_STEP2 '360'
-            family 850t
-              edit RF_NAME '850t'
-              task prep
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 006
-          family 000_006
-            edit ACC '006'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '006'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 006_012
-            edit ACC '006'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 012_018
-            edit ACC '006'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '018'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 018_024
-            edit ACC '006'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 024_030
-            edit ACC '006'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '030'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 030_036
-            edit ACC '006'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 036_042
-            edit ACC '006'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '042'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 042_048
-            edit ACC '006'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 048_054
-            edit ACC '006'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '054'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 054_060
-            edit ACC '006'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 060_066
-            edit ACC '006'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '066'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 066_072
-            edit ACC '006'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 072_078
-            edit ACC '006'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '078'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 078_084
-            edit ACC '006'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 084_090
-            edit ACC '006'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '090'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 090_096
-            edit ACC '006'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 096_102
-            edit ACC '006'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '102'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 102_108
-            edit ACC '006'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 108_114
-            edit ACC '006'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '114'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 114_120
-            edit ACC '006'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 120_126
-            edit ACC '006'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '126'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 126_132
-            edit ACC '006'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 132_138
-            edit ACC '006'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '138'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 138_144
-            edit ACC '006'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 144_150
-            edit ACC '006'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '150'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 150_156
-            edit ACC '006'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 156_162
-            edit ACC '006'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '162'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 162_168
-            edit ACC '006'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 168_174
-            edit ACC '006'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '174'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 174_180
-            edit ACC '006'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 180_186
-            edit ACC '006'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '186'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 186_192
-            edit ACC '006'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 192_198
-            edit ACC '006'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '198'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 198_204
-            edit ACC '006'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 204_210
-            edit ACC '006'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '210'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 210_216
-            edit ACC '006'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 216_222
-            edit ACC '006'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '222'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 222_228
-            edit ACC '006'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 228_234
-            edit ACC '006'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '234'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-          family 234_240
-            edit ACC '006'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 012
-          family 000_012
-            edit ACC '012'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 012_024
-            edit ACC '012'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 024_036
-            edit ACC '012'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 036_048
-            edit ACC '012'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 048_060
-            edit ACC '012'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 060_072
-            edit ACC '012'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 072_084
-            edit ACC '012'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 084_096
-            edit ACC '012'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 096_108
-            edit ACC '012'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 108_120
-            edit ACC '012'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 120_132
-            edit ACC '012'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 132_144
-            edit ACC '012'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 144_156
-            edit ACC '012'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 156_168
-            edit ACC '012'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 168_180
-            edit ACC '012'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 180_192
-            edit ACC '012'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 192_204
-            edit ACC '012'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 204_216
-            edit ACC '012'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 216_228
-            edit ACC '012'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 228_240
-            edit ACC '012'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 240_252
-            edit ACC '012'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '252'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 252_264
-            edit ACC '012'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '264'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 264_276
-            edit ACC '012'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '276'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 276_288
-            edit ACC '012'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '288'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 288_300
-            edit ACC '012'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '300'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 300_312
-            edit ACC '012'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '312'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 312_324
-            edit ACC '012'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '324'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 324_336
-            edit ACC '012'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '336'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 336_348
-            edit ACC '012'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '348'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-          family 348_360
-            edit ACC '012'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 072
-          trigger ./024 eq complete
-          family 000_072
-            edit ACC '072'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 024_096
-            edit ACC '072'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 048_120
-            edit ACC '072'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 072_144
-            edit ACC '072'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 096_168
-            edit ACC '072'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_192
-            edit ACC '072'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 144_216
-            edit ACC '072'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 168_240
-            edit ACC '072'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          trigger ./024 eq complete
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 048_168
-            edit ACC '120'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 072_192
-            edit ACC '120'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 096_216
-            edit ACC '120'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_240
-            edit ACC '120'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 240_360
-            edit ACC '120'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          trigger ./024 eq complete
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-          family 120_360
-            edit ACC '240'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-        family 360
-          trigger ./024 eq complete
-          family 000_360
-            edit ACC '360'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family check_nrt
-        complete ./check_nrt/go eq complete
-        edit REFPATH '/mofc/hc2'
-        family catchup
-          task check_nrt
-            event ok
-        endfamily
-        family rt
-          trigger catchup eq complete
-          task check_nrt
-            event ok
-            cron -w 1 06:30
-        endfamily
-        task go
-          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
-          trigger 0 eq 1
-      endfamily
-    endfamily
-    family clim
-      repeat date YMD 20080717 20121212 7
-      edit DELTA_DAY '-7'
-      family deps
-        trigger ../hind:YMD gt ../clim:YMD
-        task dummy
-          complete 1 eq 1
-      endfamily
-      family op
-        trigger deps eq complete
-        edit EPSLEG '1'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family op2fdb
-        trigger op eq complete
-        edit EPSLEG '1'
-        task efi2fdb
-          edit KIND 'clim1'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-      endfamily
-      family nop
-        trigger deps eq complete
-        edit EPSLEG '2'
-        family 024
-          family 000_024
-            edit ACC '024'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '024'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_036
-            edit ACC '024'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '036'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_048
-            edit ACC '024'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '048'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_060
-            edit ACC '024'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '060'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_072
-            edit ACC '024'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '072'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_084
-            edit ACC '024'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '084'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_096
-            edit ACC '024'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '096'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_108
-            edit ACC '024'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '108'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_120
-            edit ACC '024'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '120'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_132
-            edit ACC '024'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '132'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_144
-            edit ACC '024'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '144'
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_168
-            edit ACC '024'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '168'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_192
-            edit ACC '024'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '192'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_216
-            edit ACC '024'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '216'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_240
-            edit ACC '024'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_264
-            edit ACC '024'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '264'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 264_288
-            edit ACC '024'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '288'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 288_312
-            edit ACC '024'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '312'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 312_336
-            edit ACC '024'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '336'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-          family 336_360
-            edit ACC '024'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '360'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-            family hsttmax
-              edit RF_NAME 'hsttmax'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 000
-          family 006_006
-            edit ACC '000'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '006'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_012
-            edit ACC '000'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '012'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 018_018
-            edit ACC '000'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '018'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_024
-            edit ACC '000'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '024'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 030_030
-            edit ACC '000'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '030'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_036
-            edit ACC '000'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '036'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 042_042
-            edit ACC '000'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '042'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_048
-            edit ACC '000'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '048'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 054_054
-            edit ACC '000'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '054'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_060
-            edit ACC '000'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '060'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 066_066
-            edit ACC '000'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '066'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_072
-            edit ACC '000'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '072'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 078_078
-            edit ACC '000'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '078'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_084
-            edit ACC '000'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '084'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 090_090
-            edit ACC '000'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '090'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_096
-            edit ACC '000'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '096'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 102_102
-            edit ACC '000'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '102'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_108
-            edit ACC '000'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '108'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 114_114
-            edit ACC '000'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '114'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_120
-            edit ACC '000'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '120'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 126_126
-            edit ACC '000'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '126'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 132_132
-            edit ACC '000'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '132'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 138_138
-            edit ACC '000'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '138'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_144
-            edit ACC '000'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '144'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 150_150
-            edit ACC '000'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '150'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 156_156
-            edit ACC '000'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '156'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 162_162
-            edit ACC '000'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '162'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_168
-            edit ACC '000'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '168'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 174_174
-            edit ACC '000'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '174'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 180_180
-            edit ACC '000'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '180'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 186_186
-            edit ACC '000'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '186'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_192
-            edit ACC '000'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '192'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 198_198
-            edit ACC '000'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '198'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 204_204
-            edit ACC '000'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '204'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 210_210
-            edit ACC '000'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '210'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_216
-            edit ACC '000'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '216'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 222_222
-            edit ACC '000'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '222'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 228_228
-            edit ACC '000'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '228'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 234_234
-            edit ACC '000'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '234'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_240
-            edit ACC '000'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '240'
-            family 10dd
-              edit RF_NAME '10dd'
-              task prep_sort
-            endfamily
-            family tcc
-              edit RF_NAME 'tcc'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 252_252
-            edit ACC '000'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '252'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 264_264
-            edit ACC '000'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '264'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 276_276
-            edit ACC '000'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '276'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 288_288
-            edit ACC '000'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '288'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 300_300
-            edit ACC '000'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '300'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 312_312
-            edit ACC '000'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '312'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 324_324
-            edit ACC '000'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '324'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 336_336
-            edit ACC '000'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '336'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 348_348
-            edit ACC '000'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '348'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-          family 360_360
-            edit ACC '000'
-            edit EFI_STEP1 '360'
-            edit EFI_STEP2 '360'
-            family 850t
-              edit RF_NAME '850t'
-              task prep_sort
-            endfamily
-            family 500z
-              edit RF_NAME '500z'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 006
-          family 000_006
-            edit ACC '006'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '006'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 006_012
-            edit ACC '006'
-            edit EFI_STEP1 '006'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_018
-            edit ACC '006'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '018'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 018_024
-            edit ACC '006'
-            edit EFI_STEP1 '018'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_030
-            edit ACC '006'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '030'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 030_036
-            edit ACC '006'
-            edit EFI_STEP1 '030'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_042
-            edit ACC '006'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '042'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 042_048
-            edit ACC '006'
-            edit EFI_STEP1 '042'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_054
-            edit ACC '006'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '054'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 054_060
-            edit ACC '006'
-            edit EFI_STEP1 '054'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_066
-            edit ACC '006'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '066'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 066_072
-            edit ACC '006'
-            edit EFI_STEP1 '066'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_078
-            edit ACC '006'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '078'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 078_084
-            edit ACC '006'
-            edit EFI_STEP1 '078'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_090
-            edit ACC '006'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '090'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 090_096
-            edit ACC '006'
-            edit EFI_STEP1 '090'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_102
-            edit ACC '006'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '102'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 102_108
-            edit ACC '006'
-            edit EFI_STEP1 '102'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_114
-            edit ACC '006'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '114'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 114_120
-            edit ACC '006'
-            edit EFI_STEP1 '114'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_126
-            edit ACC '006'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '126'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 126_132
-            edit ACC '006'
-            edit EFI_STEP1 '126'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 132_138
-            edit ACC '006'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '138'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 138_144
-            edit ACC '006'
-            edit EFI_STEP1 '138'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_150
-            edit ACC '006'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '150'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 150_156
-            edit ACC '006'
-            edit EFI_STEP1 '150'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 156_162
-            edit ACC '006'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '162'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 162_168
-            edit ACC '006'
-            edit EFI_STEP1 '162'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_174
-            edit ACC '006'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '174'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 174_180
-            edit ACC '006'
-            edit EFI_STEP1 '174'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 180_186
-            edit ACC '006'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '186'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 186_192
-            edit ACC '006'
-            edit EFI_STEP1 '186'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_198
-            edit ACC '006'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '198'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 198_204
-            edit ACC '006'
-            edit EFI_STEP1 '198'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 204_210
-            edit ACC '006'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '210'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 210_216
-            edit ACC '006'
-            edit EFI_STEP1 '210'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_222
-            edit ACC '006'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '222'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 222_228
-            edit ACC '006'
-            edit EFI_STEP1 '222'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 228_234
-            edit ACC '006'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '234'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-          family 234_240
-            edit ACC '006'
-            edit EFI_STEP1 '234'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family ts
-              edit RF_NAME 'ts'
-              task prep_sort
-            endfamily
-            family 10fg
-              edit RF_NAME '10fg'
-              task prep_sort
-            endfamily
-            family 2tmin
-              edit RF_NAME '2tmin'
-              task prep_sort
-            endfamily
-            family 2tmax
-              edit RF_NAME '2tmax'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 012
-          family 000_012
-            edit ACC '012'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '012'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 012_024
-            edit ACC '012'
-            edit EFI_STEP1 '012'
-            edit EFI_STEP2 '024'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_036
-            edit ACC '012'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '036'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 036_048
-            edit ACC '012'
-            edit EFI_STEP1 '036'
-            edit EFI_STEP2 '048'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_060
-            edit ACC '012'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '060'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 060_072
-            edit ACC '012'
-            edit EFI_STEP1 '060'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_084
-            edit ACC '012'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '084'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 084_096
-            edit ACC '012'
-            edit EFI_STEP1 '084'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_108
-            edit ACC '012'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '108'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 108_120
-            edit ACC '012'
-            edit EFI_STEP1 '108'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_132
-            edit ACC '012'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '132'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 132_144
-            edit ACC '012'
-            edit EFI_STEP1 '132'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_156
-            edit ACC '012'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '156'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 156_168
-            edit ACC '012'
-            edit EFI_STEP1 '156'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_180
-            edit ACC '012'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '180'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 180_192
-            edit ACC '012'
-            edit EFI_STEP1 '180'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 192_204
-            edit ACC '012'
-            edit EFI_STEP1 '192'
-            edit EFI_STEP2 '204'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 204_216
-            edit ACC '012'
-            edit EFI_STEP1 '204'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 216_228
-            edit ACC '012'
-            edit EFI_STEP1 '216'
-            edit EFI_STEP2 '228'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 228_240
-            edit ACC '012'
-            edit EFI_STEP1 '228'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_252
-            edit ACC '012'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '252'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 252_264
-            edit ACC '012'
-            edit EFI_STEP1 '252'
-            edit EFI_STEP2 '264'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 264_276
-            edit ACC '012'
-            edit EFI_STEP1 '264'
-            edit EFI_STEP2 '276'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 276_288
-            edit ACC '012'
-            edit EFI_STEP1 '276'
-            edit EFI_STEP2 '288'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 288_300
-            edit ACC '012'
-            edit EFI_STEP1 '288'
-            edit EFI_STEP2 '300'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 300_312
-            edit ACC '012'
-            edit EFI_STEP1 '300'
-            edit EFI_STEP2 '312'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 312_324
-            edit ACC '012'
-            edit EFI_STEP1 '312'
-            edit EFI_STEP2 '324'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 324_336
-            edit ACC '012'
-            edit EFI_STEP1 '324'
-            edit EFI_STEP2 '336'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 336_348
-            edit ACC '012'
-            edit EFI_STEP1 '336'
-            edit EFI_STEP2 '348'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-          family 348_360
-            edit ACC '012'
-            edit EFI_STEP1 '348'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 072
-          family 000_072
-            edit ACC '072'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '072'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_096
-            edit ACC '072'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '096'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_120
-            edit ACC '072'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '120'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_144
-            edit ACC '072'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '144'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_168
-            edit ACC '072'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_192
-            edit ACC '072'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 144_216
-            edit ACC '072'
-            edit EFI_STEP1 '144'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 168_240
-            edit ACC '072'
-            edit EFI_STEP1 '168'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 120
-          family 000_120
-            edit ACC '120'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '120'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 024_144
-            edit ACC '120'
-            edit EFI_STEP1 '024'
-            edit EFI_STEP2 '144'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 048_168
-            edit ACC '120'
-            edit EFI_STEP1 '048'
-            edit EFI_STEP2 '168'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 072_192
-            edit ACC '120'
-            edit EFI_STEP1 '072'
-            edit EFI_STEP2 '192'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 096_216
-            edit ACC '120'
-            edit EFI_STEP1 '096'
-            edit EFI_STEP2 '216'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_240
-            edit ACC '120'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '240'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 240_360
-            edit ACC '120'
-            edit EFI_STEP1 '240'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 240
-          family 000_240
-            edit ACC '240'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '240'
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-          family 120_360
-            edit ACC '240'
-            edit EFI_STEP1 '120'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-        family 360
-          family 000_360
-            edit ACC '360'
-            edit EFI_STEP1 '000'
-            edit EFI_STEP2 '360'
-            family tp
-              edit RF_NAME 'tp'
-              task prep_sort
-            endfamily
-            family 2t
-              edit RF_NAME '2t'
-              task prep_sort
-            endfamily
-            family 10ff
-              edit RF_NAME '10ff'
-              task prep_sort
-            endfamily
-          endfamily
-        endfamily
-      endfamily
-      family nop2fdb
-        trigger nop eq complete and ./op2fdb eq complete
-        edit EPSLEG '2'
-        task efi2fdb
-          edit KIND 'clim2'
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
-      endfamily
-      family arch_nop
-        trigger nop2fdb eq complete
-        edit EPSLEG '2'
-        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
-        family 2t
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '2t'
-          task eficlim
-            label info ""
-        endfamily
-        family 10ff
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '10ff'
-          task eficlim
-            label info ""
-        endfamily
-        family 10fg
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '10fg'
-          task eficlim
-            label info ""
-        endfamily
-        family tp
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'tp'
-          task eficlim
-            label info ""
-        endfamily
-        family 2tmin
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '2tmin'
-          task eficlim
-            label info ""
-        endfamily
-        family 2tmax
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '2tmax'
-          task eficlim
-            label info ""
-        endfamily
-        family ts
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'ts'
-          task eficlim
-            label info ""
-        endfamily
-        family hsttmax
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'hsttmax'
-          task eficlim
-            label info ""
-        endfamily
-        family 10dd
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '10dd'
-          task eficlim
-            label info ""
-        endfamily
-        family 850t
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '850t'
-          task eficlim
-            label info ""
-        endfamily
-        family 500z
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME '500z'
-          task eficlim
-            label info ""
-        endfamily
-        family 2tmean
-          edit step2 '24'
-          edit RF_NAME '2t'
-          edit step1 '0'
-          task eficlim
-            label info ""
-        endfamily
-        family 10ffmean
-          edit step2 '24'
-          edit RF_NAME '10ff'
-          edit step1 '0'
-          task eficlim
-            label info ""
-        endfamily
-        family tcc
-          edit step1 '24'
-          edit step2 '24'
-          edit RF_NAME 'tcc'
-          task eficlim
-            label info ""
-        endfamily
-        family tccmean
-          edit step2 '24'
-          edit RF_NAME 'tcc'
-          edit step1 '0'
-          task eficlim
-            label info ""
-        endfamily
-      endfamily
-      family gdb
-        trigger ( op eq complete and nop eq complete) and ( arch_nop eq complete)
-        edit RHOST 'epsgrams'
-        edit RDIR '/webapps/epsgrams/data/'
-        edit KIND 'clim_15_days'
-        edit WSHOST 'linux_cluster'
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        inlimit /limits:linux_cluster
-        task sync_climate
-        task gclean
-          trigger sync_climate eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
-          edit KEEP_DAYS '14'
-          edit REMOTE_KEEP_DAYS '14'
-        task gdb
-          trigger gclean eq complete and ( /emc_36r1/main:YMD ge /emc_36r1/efi_next/mn:YMD and /emc_36r1/main/00 eq complete)
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
-          label files "="
-          label info "="
-          label local "="
-          label remote "="
-          event fdb
-          event 1 
-        task glink
-          trigger gdb eq complete
-          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
-      endfamily
-      family check_nrt
-        complete ./check_nrt/go eq complete
-        edit REFPATH '/mofc/hc2'
-        family catchup
-          task check_nrt
-            event ok
-        endfamily
-        family rt
-          trigger catchup eq complete
-          task check_nrt
-            event ok
-            cron -w 3 06:30
-        endfamily
-        task go
-          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
-          trigger 0 eq 1
-      endfamily
-      task efi_cleaner
-        trigger ( arch_nop eq complete or arch_nop eq unknown) and ( op eq complete or op eq unknown) and ( nop eq complete or nop eq unknown) and ( op2fdb eq complete or op2fdb eq unknown) and ( nop2fdb eq complete or nop2fdb eq unknown)
-        edit DELTA_DAY '-43'
-    endfamily
-  endfamily
-endsuite
-suite elaw_36r1
-  edit SUITE_TYPE 'law'
-  edit USER 'emos'
-  edit SCHOST 'c1b'
-  edit STHOST '/s1b'
-  edit STHOST_BKUP '/s1a'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit VERSION '0046'
-  edit INIEXPVER '0001'
-  edit WVINIEXPVER 'false'
-  edit INIWDEXPVER '0046'
-  edit INIWDCLASS 'od'
-  edit FIRST_DAY '1'
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit REINITIALIZE 'false'
-  edit DATEMASK '*.*.*'
-  edit YMD '20091016'
-  edit USE_YMD 'true'
-  edit FSFAMILY 'euroshelf'
-  edit VERIF_WAIT '10'
-  edit MARS_DB 'marsod'
-  edit VERIFY 'verify'
-  edit SUITE_START '2009101612'
-  edit SMSTRIES '2'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/elaw_36r1'
-  edit SMSINCLUDE '/home/ma/emos/def/elaw_36r1/include'
-  edit RESERVATION_ON '1'
-  edit QUEUE 'os'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit.36r1 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-  edit ANTIME '12'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '12'
-  edit EMOS_PROJECT '00'
-  edit EMOS_TIME_STEP_H '0000'
-  edit PGEN_BINDIR '/home/ma/emos/bin/diss'
-  edit PGEN_OBJDIR '/home/ma/emos/bin/diss'
-  edit DISS_REQDB_ROOT '/diss/requirements'
-  edit DISS_BINDIR '/diss/bin/DISS'
-  edit ANNPES '1'
-  edit FCNPES '128'
-  edit EMOS_DOMAIN 'M'
-  edit PROD_TASK '1'
-  edit EMOS_TYPE 'fc'
-  edit DATA_COV 'no'
-  edit EMOS_STREAM 'WV'
-  edit STREAM 'DA'
-  edit INISTREAM 'wave'
-  edit ACCOUNT 'oewave'
-  edit WAMLEN '10'
-  edit WAM1ST 'no'
-  edit GRID '0.25/0.25'
-  edit RET_GRID '1.5/1.5'
-  edit SMSLOGHOST 'c1b'
-  edit SMSLOGPORT '9316'
-  edit SLEEPTIME '1'
-  inlimit /limits:c1b
-  clock hybrid 
-  family limits
-    limit mars 2
-    limit prod 5
-    limit pdb 5
-    limit q2diss 5
-    limit prodcheck 1
-  endfamily
-  family main
-    trigger /elaw_36r1/main:YMD le /e_36r1/main:YMD
-    repeat date YMD 20091016 20121212 1
-    edit LOGTASK 'main'
-    family make
-      task setup
-      task wconst
-        trigger setup eq complete
-      task wavini
-        trigger wconst eq complete
-      family prod
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod/make'
-        edit EMOS_DOMAIN 'g'
-        edit EMOS_TYPE 'fc'
-        edit EMOS_STREAM 'OPER'
-        task wparam
-          edit EMOS_TYPE 'wp'
-        task tf
-          edit EMOS_TYPE 'tf'
-        task sortreq
-        task bitmap
-        task clima
-        task disssch
-        task tools
-        task oper
-        task wave
-          edit EMOS_STREAM 'WAVE'
-      endfamily
-    endfamily
-    family 12
-      trigger make eq complete
-      edit EMOS_BASE '12'
-      edit EMOS_PROJECT '12'
-      edit DELTA_DAY '0'
-      family ref
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        task model
-          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/12/fc/model eq complete)
-        task prod
-          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/12/getreq eq complete)
-        task sst
-          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/12/an/surf_anal/sst eq complete)
-      endfamily
-      family euroshelf
-        trigger ref/model eq complete
-        edit EMOS_DOMAIN 'M'
-        edit GRID '0.25/0.25'
-        edit RET_GRID '0.25/0.25'
-        edit WAMLEN '5'
-        task wamobs
-        task wamwind
-        task wamwave
-          trigger /elaw_36r1/main/12/ref/sst eq complete
-        task wamrun
-          trigger wamobs eq complete and wamwind eq complete and wamwave eq complete
-          edit USER_PRIORITY '80'
-          edit SMSTRIES '1'
-          edit THREADS '2'
-      endfamily
-      family getreq
-        trigger ref/prod eq complete
-        edit EMOS_TYPE 'fc'
-        edit EMOS_DOMAIN 'M'
-        edit FSFAMILY 'ppdi'
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'WAVE'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger req:001 or req eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete
-          label info ""
-          event 1 
-      endfamily
-      family prod
-        edit ACCOUNT 'oewavepg'
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit PGNPES '1'
-        edit EMOS_TIME_STEP_H '0000'
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSURL 'MWAVE/12'
-        edit DELTA_DAY '-1'
-        inlimit /limits:prod
-        inlimit /elaw_36r1/limits:prod
-        family 06
-          edit SMSURL 'MWAVE/06'
-          family an
-            trigger /elaw_36r1/main/12/euroshelf/wamrun eq complete and ( /elaw_36r1/main/12/getreq/bitmap:001 or /elaw_36r1/main/12/getreq/bitmap eq complete) and ( /elaw_36r1/main/12/getreq/req:001 or /elaw_36r1/main/12/getreq/req eq complete)
-            edit EMOS_TYPE 'an'
-            edit EMOS_BASE '06'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-        endfamily
-        family 12
-          edit EMOS_TYPE 'fc'
-          edit PROD_TASK '1'
-          edit DELTA_DAY '0'
-          family an
-            trigger /elaw_36r1/main/12/euroshelf/wamrun eq complete and /elaw_36r1/main/12/prod/06/an/prodgen eq complete
-            edit EMOS_TYPE 'an'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 003
-            trigger ../12/an/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0003'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 006
-            trigger ./003/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0006'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 009
-            trigger ./006/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0009'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 012
-            trigger ./009/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0012'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 015
-            trigger ./012/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0015'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 018
-            trigger ./015/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0018'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 021
-            trigger ./018/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0021'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 024
-            trigger ./021/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0024'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 027
-            trigger ./024/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0027'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 030
-            trigger ./027/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0030'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 033
-            trigger ./030/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0033'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 036
-            trigger ./033/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0036'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 039
-            trigger ./036/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0039'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 042
-            trigger ./039/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0042'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 045
-            trigger ./042/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0045'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 048
-            trigger ./045/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0048'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 051
-            trigger ./048/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0051'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 054
-            trigger ./051/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0054'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 057
-            trigger ./054/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0057'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 060
-            trigger ./057/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0060'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 063
-            trigger ./060/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0063'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 066
-            trigger ./063/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0066'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 069
-            trigger ./066/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0069'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 072
-            trigger ./069/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0072'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 075
-            trigger ./072/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0075'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 078
-            trigger ./075/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0078'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 081
-            trigger ./078/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0081'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 084
-            trigger ./081/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0084'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 087
-            trigger ./084/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0087'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 090
-            trigger ./087/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0090'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 093
-            trigger ./090/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0093'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 096
-            trigger ./093/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0096'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 099
-            trigger ./096/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0099'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 102
-            trigger ./099/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0102'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 105
-            trigger ./102/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0105'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 108
-            trigger ./105/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0108'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 111
-            trigger ./108/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0111'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 114
-            trigger ./111/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0114'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 117
-            trigger ./114/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0117'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 120
-            trigger ./117/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0120'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURL 'MWAVE/12'
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_TIME_STEP_H '0000'
-        inlimit /elaw_36r1/limits:pdb
-        inlimit /limits:pdb
-        family 06
-          edit EMOS_TYPE 'an'
-          edit SMSURL 'MWAVE/06'
-          family an
-            trigger /elaw_36r1/main/12/prod/06/an/prodgen eq complete
-            edit EMOS_TYPE 'an'
-            edit EMOS_BASE '06'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-        endfamily
-        family 12
-          edit EMOS_BASE '12'
-          edit EMOS_TYPE 'fc'
-          family an
-            trigger /elaw_36r1/main/12/prod/12/an/prodgen eq complete
-            edit EMOS_TYPE 'an'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 003
-            trigger /elaw_36r1/main/12/prod/12/003/prodgen eq complete and ( ./an/diss:pdb or ./an/diss eq complete)
-            edit EMOS_TIME_STEP_H '0003'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 006
-            trigger /elaw_36r1/main/12/prod/12/006/prodgen eq complete and ( ./003/diss:pdb or ./003/diss eq complete)
-            edit EMOS_TIME_STEP_H '0006'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 009
-            trigger /elaw_36r1/main/12/prod/12/009/prodgen eq complete and ( ./006/diss:pdb or ./006/diss eq complete)
-            edit EMOS_TIME_STEP_H '0009'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 012
-            trigger /elaw_36r1/main/12/prod/12/012/prodgen eq complete and ( ./009/diss:pdb or ./009/diss eq complete)
-            edit EMOS_TIME_STEP_H '0012'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 015
-            trigger /elaw_36r1/main/12/prod/12/015/prodgen eq complete and ( ./012/diss:pdb or ./012/diss eq complete)
-            edit EMOS_TIME_STEP_H '0015'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 018
-            trigger /elaw_36r1/main/12/prod/12/018/prodgen eq complete and ( ./015/diss:pdb or ./015/diss eq complete)
-            edit EMOS_TIME_STEP_H '0018'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 021
-            trigger /elaw_36r1/main/12/prod/12/021/prodgen eq complete and ( ./018/diss:pdb or ./018/diss eq complete)
-            edit EMOS_TIME_STEP_H '0021'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 024
-            trigger /elaw_36r1/main/12/prod/12/024/prodgen eq complete and ( ./021/diss:pdb or ./021/diss eq complete)
-            edit EMOS_TIME_STEP_H '0024'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 027
-            trigger /elaw_36r1/main/12/prod/12/027/prodgen eq complete and ( ./024/diss:pdb or ./024/diss eq complete)
-            edit EMOS_TIME_STEP_H '0027'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 030
-            trigger /elaw_36r1/main/12/prod/12/030/prodgen eq complete and ( ./027/diss:pdb or ./027/diss eq complete)
-            edit EMOS_TIME_STEP_H '0030'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 033
-            trigger /elaw_36r1/main/12/prod/12/033/prodgen eq complete and ( ./030/diss:pdb or ./030/diss eq complete)
-            edit EMOS_TIME_STEP_H '0033'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 036
-            trigger /elaw_36r1/main/12/prod/12/036/prodgen eq complete and ( ./033/diss:pdb or ./033/diss eq complete)
-            edit EMOS_TIME_STEP_H '0036'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 039
-            trigger /elaw_36r1/main/12/prod/12/039/prodgen eq complete and ( ./036/diss:pdb or ./036/diss eq complete)
-            edit EMOS_TIME_STEP_H '0039'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 042
-            trigger /elaw_36r1/main/12/prod/12/042/prodgen eq complete and ( ./039/diss:pdb or ./039/diss eq complete)
-            edit EMOS_TIME_STEP_H '0042'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 045
-            trigger /elaw_36r1/main/12/prod/12/045/prodgen eq complete and ( ./042/diss:pdb or ./042/diss eq complete)
-            edit EMOS_TIME_STEP_H '0045'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 048
-            trigger /elaw_36r1/main/12/prod/12/048/prodgen eq complete and ( ./045/diss:pdb or ./045/diss eq complete)
-            edit EMOS_TIME_STEP_H '0048'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 051
-            trigger /elaw_36r1/main/12/prod/12/051/prodgen eq complete and ( ./048/diss:pdb or ./048/diss eq complete)
-            edit EMOS_TIME_STEP_H '0051'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 054
-            trigger /elaw_36r1/main/12/prod/12/054/prodgen eq complete and ( ./051/diss:pdb or ./051/diss eq complete)
-            edit EMOS_TIME_STEP_H '0054'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 057
-            trigger /elaw_36r1/main/12/prod/12/057/prodgen eq complete and ( ./054/diss:pdb or ./054/diss eq complete)
-            edit EMOS_TIME_STEP_H '0057'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 060
-            trigger /elaw_36r1/main/12/prod/12/060/prodgen eq complete and ( ./057/diss:pdb or ./057/diss eq complete)
-            edit EMOS_TIME_STEP_H '0060'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 063
-            trigger /elaw_36r1/main/12/prod/12/063/prodgen eq complete and ( ./060/diss:pdb or ./060/diss eq complete)
-            edit EMOS_TIME_STEP_H '0063'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 066
-            trigger /elaw_36r1/main/12/prod/12/066/prodgen eq complete and ( ./063/diss:pdb or ./063/diss eq complete)
-            edit EMOS_TIME_STEP_H '0066'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 069
-            trigger /elaw_36r1/main/12/prod/12/069/prodgen eq complete and ( ./066/diss:pdb or ./066/diss eq complete)
-            edit EMOS_TIME_STEP_H '0069'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 072
-            trigger /elaw_36r1/main/12/prod/12/072/prodgen eq complete and ( ./069/diss:pdb or ./069/diss eq complete)
-            edit EMOS_TIME_STEP_H '0072'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 075
-            trigger /elaw_36r1/main/12/prod/12/075/prodgen eq complete and ( ./072/diss:pdb or ./072/diss eq complete)
-            edit EMOS_TIME_STEP_H '0075'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 078
-            trigger /elaw_36r1/main/12/prod/12/078/prodgen eq complete and ( ./075/diss:pdb or ./075/diss eq complete)
-            edit EMOS_TIME_STEP_H '0078'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 081
-            trigger /elaw_36r1/main/12/prod/12/081/prodgen eq complete and ( ./078/diss:pdb or ./078/diss eq complete)
-            edit EMOS_TIME_STEP_H '0081'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 084
-            trigger /elaw_36r1/main/12/prod/12/084/prodgen eq complete and ( ./081/diss:pdb or ./081/diss eq complete)
-            edit EMOS_TIME_STEP_H '0084'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 087
-            trigger /elaw_36r1/main/12/prod/12/087/prodgen eq complete and ( ./084/diss:pdb or ./084/diss eq complete)
-            edit EMOS_TIME_STEP_H '0087'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 090
-            trigger /elaw_36r1/main/12/prod/12/090/prodgen eq complete and ( ./087/diss:pdb or ./087/diss eq complete)
-            edit EMOS_TIME_STEP_H '0090'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 093
-            trigger /elaw_36r1/main/12/prod/12/093/prodgen eq complete and ( ./090/diss:pdb or ./090/diss eq complete)
-            edit EMOS_TIME_STEP_H '0093'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 096
-            trigger /elaw_36r1/main/12/prod/12/096/prodgen eq complete and ( ./093/diss:pdb or ./093/diss eq complete)
-            edit EMOS_TIME_STEP_H '0096'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 099
-            trigger /elaw_36r1/main/12/prod/12/099/prodgen eq complete and ( ./096/diss:pdb or ./096/diss eq complete)
-            edit EMOS_TIME_STEP_H '0099'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 102
-            trigger /elaw_36r1/main/12/prod/12/102/prodgen eq complete and ( ./099/diss:pdb or ./099/diss eq complete)
-            edit EMOS_TIME_STEP_H '0102'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 105
-            trigger /elaw_36r1/main/12/prod/12/105/prodgen eq complete and ( ./102/diss:pdb or ./102/diss eq complete)
-            edit EMOS_TIME_STEP_H '0105'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 108
-            trigger /elaw_36r1/main/12/prod/12/108/prodgen eq complete and ( ./105/diss:pdb or ./105/diss eq complete)
-            edit EMOS_TIME_STEP_H '0108'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 111
-            trigger /elaw_36r1/main/12/prod/12/111/prodgen eq complete and ( ./108/diss:pdb or ./108/diss eq complete)
-            edit EMOS_TIME_STEP_H '0111'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 114
-            trigger /elaw_36r1/main/12/prod/12/114/prodgen eq complete and ( ./111/diss:pdb or ./111/diss eq complete)
-            edit EMOS_TIME_STEP_H '0114'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 117
-            trigger /elaw_36r1/main/12/prod/12/117/prodgen eq complete and ( ./114/diss:pdb or ./114/diss eq complete)
-            edit EMOS_TIME_STEP_H '0117'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 120
-            trigger /elaw_36r1/main/12/prod/12/120/prodgen eq complete and ( ./117/diss:pdb or ./117/diss eq complete)
-            edit EMOS_TIME_STEP_H '0120'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-        endfamily
-        task check
-          trigger ./12 eq complete
-        family reservation
-          trigger ./12 eq complete
-          edit SMSFILES '/home/ma/emos/def/elaw_36r1/smsfiles'
-          task loadl_cycle_limit
-            edit LOADL_CYCLE '65'
-            label info ""
-        endfamily
-      endfamily
-    endfamily
-    family 00
-      trigger ./make eq complete and ./12 eq complete
-      edit EMOS_BASE '00'
-      edit EMOS_PROJECT '00'
-      edit DELTA_DAY '1'
-      edit RESERVATION_ON '1'
-      edit QUEUE 'os'
-      family ref
-        edit QUEUE 'emos-e'
-        edit QUEUE_EPILOG 'emos-exp'
-        edit WSHOST 'localhost'
-        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-        edit LOGDIR '/vol/emos_nc/output'
-        edit SMSOUT '/vol/emos_nc/output'
-        task model
-          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/00/fc/model eq complete)
-        task prod
-          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/00/getreq eq complete)
-        task sst
-          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/00/an/surf_anal/sst eq complete)
-      endfamily
-      family euroshelf
-        trigger ref/model eq complete
-        edit EMOS_DOMAIN 'M'
-        edit GRID '0.25/0.25'
-        edit RET_GRID '0.25/0.25'
-        edit WAMLEN '5'
-        task wamobs
-        task wamwind
-        task wamwave
-          trigger ( /elaw_36r1/main/00/ref/sst eq complete) and ( /elaw_36r1/main/12/euroshelf eq complete)
-        task wamrun
-          trigger wamobs eq complete and wamwind eq complete and wamwave eq complete
-          edit USER_PRIORITY '80'
-          edit SMSTRIES '1'
-          edit THREADS '2'
-      endfamily
-      family getreq
-        trigger ref/prod eq complete
-        edit EMOS_TYPE 'fc'
-        edit EMOS_DOMAIN 'M'
-        edit FSFAMILY 'ppdi'
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
-        edit SMSTRIES '1'
-        edit EMOS_STREAM 'WAVE'
-        task collectreq
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task req
-          late -s +00:03 -c +00:10
-          trigger collectreq eq complete
-          label info ""
-          event 1 
-        task collectbitmap
-          trigger req:001 or req eq complete
-          edit QUEUE 'diss'
-          edit USER 'emos'
-          edit WSHOST 'diss'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit LOGDIR '/diss/log'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSOUT '/vol/emos_nc/output'
-        task bitmap
-          late -s +00:03 -c +00:10
-          trigger collectbitmap eq complete
-          label info ""
-          event 1 
-      endfamily
-      family prod
-        edit ACCOUNT 'oewavepg'
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit PROD_TASK '1'
-        edit PGNPES '1'
-        edit EMOS_TIME_STEP_H '0000'
-        edit USER_PRIORITY '90'
-        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
-        edit SMSURL 'MWAVE/00'
-        inlimit /limits:prod
-        inlimit /elaw_36r1/limits:prod
-        family 18
-          edit DELTA_DAY '0'
-          edit SMSURL 'MWAVE/18'
-          family an
-            trigger /elaw_36r1/main/00/euroshelf/wamrun eq complete and ( /elaw_36r1/main/00/getreq/bitmap:001 or /elaw_36r1/main/00/getreq/bitmap eq complete) and ( /elaw_36r1/main/00/getreq/req:001 or /elaw_36r1/main/00/getreq/req eq complete)
-            edit EMOS_TYPE 'an'
-            edit EMOS_BASE '18'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-        endfamily
-        family 00
-          edit EMOS_TYPE 'fc'
-          edit PROD_TASK '1'
-          edit DELTA_DAY '1'
-          family an
-            trigger /elaw_36r1/main/00/euroshelf/wamrun eq complete and /elaw_36r1/main/00/prod/18/an/prodgen eq complete
-            edit EMOS_TYPE 'an'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 003
-            trigger ../00/an/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0003'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 006
-            trigger ./003/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0006'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 009
-            trigger ./006/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0009'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 012
-            trigger ./009/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0012'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 015
-            trigger ./012/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0015'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 018
-            trigger ./015/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0018'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 021
-            trigger ./018/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0021'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 024
-            trigger ./021/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0024'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 027
-            trigger ./024/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0027'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 030
-            trigger ./027/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0030'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 033
-            trigger ./030/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0033'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 036
-            trigger ./033/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0036'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 039
-            trigger ./036/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0039'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 042
-            trigger ./039/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0042'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 045
-            trigger ./042/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0045'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 048
-            trigger ./045/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0048'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 051
-            trigger ./048/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0051'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 054
-            trigger ./051/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0054'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 057
-            trigger ./054/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0057'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 060
-            trigger ./057/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0060'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 063
-            trigger ./060/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0063'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 066
-            trigger ./063/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0066'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 069
-            trigger ./066/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0069'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 072
-            trigger ./069/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0072'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 075
-            trigger ./072/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0075'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 078
-            trigger ./075/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0078'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 081
-            trigger ./078/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0081'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 084
-            trigger ./081/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0084'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 087
-            trigger ./084/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0087'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 090
-            trigger ./087/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0090'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 093
-            trigger ./090/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0093'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 096
-            trigger ./093/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0096'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 099
-            trigger ./096/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0099'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 102
-            trigger ./099/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0102'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 105
-            trigger ./102/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0105'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 108
-            trigger ./105/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0108'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 111
-            trigger ./108/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0111'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 114
-            trigger ./111/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0114'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 117
-            trigger ./114/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0117'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-          family 120
-            trigger ./117/prodgen eq complete
-            edit EMOS_TIME_STEP_H '0120'
-            task prodgen
-              late -s +00:05 -c +00:15
-          endfamily
-        endfamily
-      endfamily
-      family prod2diss
-        edit USER_PRIORITY '90'
-        edit SMSURL 'MWAVE/00'
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
-        edit EMOS_TYPE 'fc'
-        edit FSFAMILY 'ppdi'
-        edit EMOS_TIME_STEP_H '0000'
-        inlimit /elaw_36r1/limits:pdb
-        inlimit /limits:pdb
-        family 18
-          edit DELTA_DAY '0'
-          edit EMOS_TYPE 'an'
-          edit SMSURL 'MWAVE/18'
-          family an
-            trigger /elaw_36r1/main/00/prod/18/an/prodgen eq complete
-            edit EMOS_TYPE 'an'
-            edit EMOS_BASE '18'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-        endfamily
-        family 00
-          edit EMOS_BASE '00'
-          edit EMOS_TYPE 'fc'
-          family an
-            trigger /elaw_36r1/main/00/prod/00/an/prodgen eq complete
-            edit EMOS_TYPE 'an'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 003
-            trigger /elaw_36r1/main/00/prod/00/003/prodgen eq complete and ( ./an/diss:pdb or ./an/diss eq complete)
-            edit EMOS_TIME_STEP_H '0003'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 006
-            trigger /elaw_36r1/main/00/prod/00/006/prodgen eq complete and ( ./003/diss:pdb or ./003/diss eq complete)
-            edit EMOS_TIME_STEP_H '0006'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 009
-            trigger /elaw_36r1/main/00/prod/00/009/prodgen eq complete and ( ./006/diss:pdb or ./006/diss eq complete)
-            edit EMOS_TIME_STEP_H '0009'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 012
-            trigger /elaw_36r1/main/00/prod/00/012/prodgen eq complete and ( ./009/diss:pdb or ./009/diss eq complete)
-            edit EMOS_TIME_STEP_H '0012'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 015
-            trigger /elaw_36r1/main/00/prod/00/015/prodgen eq complete and ( ./012/diss:pdb or ./012/diss eq complete)
-            edit EMOS_TIME_STEP_H '0015'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 018
-            trigger /elaw_36r1/main/00/prod/00/018/prodgen eq complete and ( ./015/diss:pdb or ./015/diss eq complete)
-            edit EMOS_TIME_STEP_H '0018'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 021
-            trigger /elaw_36r1/main/00/prod/00/021/prodgen eq complete and ( ./018/diss:pdb or ./018/diss eq complete)
-            edit EMOS_TIME_STEP_H '0021'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 024
-            trigger /elaw_36r1/main/00/prod/00/024/prodgen eq complete and ( ./021/diss:pdb or ./021/diss eq complete)
-            edit EMOS_TIME_STEP_H '0024'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 027
-            trigger /elaw_36r1/main/00/prod/00/027/prodgen eq complete and ( ./024/diss:pdb or ./024/diss eq complete)
-            edit EMOS_TIME_STEP_H '0027'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 030
-            trigger /elaw_36r1/main/00/prod/00/030/prodgen eq complete and ( ./027/diss:pdb or ./027/diss eq complete)
-            edit EMOS_TIME_STEP_H '0030'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 033
-            trigger /elaw_36r1/main/00/prod/00/033/prodgen eq complete and ( ./030/diss:pdb or ./030/diss eq complete)
-            edit EMOS_TIME_STEP_H '0033'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 036
-            trigger /elaw_36r1/main/00/prod/00/036/prodgen eq complete and ( ./033/diss:pdb or ./033/diss eq complete)
-            edit EMOS_TIME_STEP_H '0036'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 039
-            trigger /elaw_36r1/main/00/prod/00/039/prodgen eq complete and ( ./036/diss:pdb or ./036/diss eq complete)
-            edit EMOS_TIME_STEP_H '0039'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 042
-            trigger /elaw_36r1/main/00/prod/00/042/prodgen eq complete and ( ./039/diss:pdb or ./039/diss eq complete)
-            edit EMOS_TIME_STEP_H '0042'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 045
-            trigger /elaw_36r1/main/00/prod/00/045/prodgen eq complete and ( ./042/diss:pdb or ./042/diss eq complete)
-            edit EMOS_TIME_STEP_H '0045'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 048
-            trigger /elaw_36r1/main/00/prod/00/048/prodgen eq complete and ( ./045/diss:pdb or ./045/diss eq complete)
-            edit EMOS_TIME_STEP_H '0048'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 051
-            trigger /elaw_36r1/main/00/prod/00/051/prodgen eq complete and ( ./048/diss:pdb or ./048/diss eq complete)
-            edit EMOS_TIME_STEP_H '0051'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 054
-            trigger /elaw_36r1/main/00/prod/00/054/prodgen eq complete and ( ./051/diss:pdb or ./051/diss eq complete)
-            edit EMOS_TIME_STEP_H '0054'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 057
-            trigger /elaw_36r1/main/00/prod/00/057/prodgen eq complete and ( ./054/diss:pdb or ./054/diss eq complete)
-            edit EMOS_TIME_STEP_H '0057'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 060
-            trigger /elaw_36r1/main/00/prod/00/060/prodgen eq complete and ( ./057/diss:pdb or ./057/diss eq complete)
-            edit EMOS_TIME_STEP_H '0060'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 063
-            trigger /elaw_36r1/main/00/prod/00/063/prodgen eq complete and ( ./060/diss:pdb or ./060/diss eq complete)
-            edit EMOS_TIME_STEP_H '0063'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 066
-            trigger /elaw_36r1/main/00/prod/00/066/prodgen eq complete and ( ./063/diss:pdb or ./063/diss eq complete)
-            edit EMOS_TIME_STEP_H '0066'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 069
-            trigger /elaw_36r1/main/00/prod/00/069/prodgen eq complete and ( ./066/diss:pdb or ./066/diss eq complete)
-            edit EMOS_TIME_STEP_H '0069'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 072
-            trigger /elaw_36r1/main/00/prod/00/072/prodgen eq complete and ( ./069/diss:pdb or ./069/diss eq complete)
-            edit EMOS_TIME_STEP_H '0072'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 075
-            trigger /elaw_36r1/main/00/prod/00/075/prodgen eq complete and ( ./072/diss:pdb or ./072/diss eq complete)
-            edit EMOS_TIME_STEP_H '0075'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 078
-            trigger /elaw_36r1/main/00/prod/00/078/prodgen eq complete and ( ./075/diss:pdb or ./075/diss eq complete)
-            edit EMOS_TIME_STEP_H '0078'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 081
-            trigger /elaw_36r1/main/00/prod/00/081/prodgen eq complete and ( ./078/diss:pdb or ./078/diss eq complete)
-            edit EMOS_TIME_STEP_H '0081'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 084
-            trigger /elaw_36r1/main/00/prod/00/084/prodgen eq complete and ( ./081/diss:pdb or ./081/diss eq complete)
-            edit EMOS_TIME_STEP_H '0084'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 087
-            trigger /elaw_36r1/main/00/prod/00/087/prodgen eq complete and ( ./084/diss:pdb or ./084/diss eq complete)
-            edit EMOS_TIME_STEP_H '0087'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 090
-            trigger /elaw_36r1/main/00/prod/00/090/prodgen eq complete and ( ./087/diss:pdb or ./087/diss eq complete)
-            edit EMOS_TIME_STEP_H '0090'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 093
-            trigger /elaw_36r1/main/00/prod/00/093/prodgen eq complete and ( ./090/diss:pdb or ./090/diss eq complete)
-            edit EMOS_TIME_STEP_H '0093'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 096
-            trigger /elaw_36r1/main/00/prod/00/096/prodgen eq complete and ( ./093/diss:pdb or ./093/diss eq complete)
-            edit EMOS_TIME_STEP_H '0096'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 099
-            trigger /elaw_36r1/main/00/prod/00/099/prodgen eq complete and ( ./096/diss:pdb or ./096/diss eq complete)
-            edit EMOS_TIME_STEP_H '0099'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 102
-            trigger /elaw_36r1/main/00/prod/00/102/prodgen eq complete and ( ./099/diss:pdb or ./099/diss eq complete)
-            edit EMOS_TIME_STEP_H '0102'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 105
-            trigger /elaw_36r1/main/00/prod/00/105/prodgen eq complete and ( ./102/diss:pdb or ./102/diss eq complete)
-            edit EMOS_TIME_STEP_H '0105'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 108
-            trigger /elaw_36r1/main/00/prod/00/108/prodgen eq complete and ( ./105/diss:pdb or ./105/diss eq complete)
-            edit EMOS_TIME_STEP_H '0108'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 111
-            trigger /elaw_36r1/main/00/prod/00/111/prodgen eq complete and ( ./108/diss:pdb or ./108/diss eq complete)
-            edit EMOS_TIME_STEP_H '0111'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 114
-            trigger /elaw_36r1/main/00/prod/00/114/prodgen eq complete and ( ./111/diss:pdb or ./111/diss eq complete)
-            edit EMOS_TIME_STEP_H '0114'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 117
-            trigger /elaw_36r1/main/00/prod/00/117/prodgen eq complete and ( ./114/diss:pdb or ./114/diss eq complete)
-            edit EMOS_TIME_STEP_H '0117'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-          family 120
-            trigger /elaw_36r1/main/00/prod/00/120/prodgen eq complete and ( ./117/diss:pdb or ./117/diss eq complete)
-            edit EMOS_TIME_STEP_H '0120'
-            task diss
-              late -s +00:05 -c +00:15
-              label info ""
-              event pdb
-          endfamily
-        endfamily
-        task check
-          trigger ./00 eq complete
-        family reservation
-          trigger ./00 eq complete
-          edit SMSFILES '/home/ma/emos/def/elaw_36r1/smsfiles'
-          task loadl_cycle_limit
-            edit LOADL_CYCLE '65'
-            label info ""
-        endfamily
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'main'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger make eq complete and ./12 eq complete and ./00 eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'main'
-      inlimit /limits:linux_cluster
-  endfamily
-  family lag
-    trigger /elaw_36r1/main/make eq complete
-    repeat date YMD 20091016 20121212 1
-    edit LOGTASK 'lag'
-    edit MARS_DB 'marsod'
-    family 12
-      edit EMOS_BASE '12'
-      edit EMOS_PROJECT '12'
-      edit DELTA_DAY '0'
-      task wavesave
-        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/12/euroshelf/wamrun eq complete)
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/euroshelf'
-      family euroshelf
-        trigger ./wavesave eq complete
-        task buoycol
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task monthly
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit DATEMASK '04.*.*'
-          inlimit /limits:linux_cluster
-        task uracol
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task fc_plot
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task uraplot
-          trigger uracol eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task windplot
-          trigger uracol eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task uraesf
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task urascat
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit DATEMASK '03.*.*'
-          inlimit /limits:linux_cluster
-      endfamily
-      family archive
-        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/12/euroshelf/wamrun eq complete)
-        edit FSFAMILY 'mars'
-        inlimit /elaw_36r1/limits:mars
-        inlimit /limits:mars
-        task medite_06
-          edit EMOS_BASE '06'
-          label files ""
-          label info ""
-          event fdb
-        task medite_12
-          edit EMOS_BASE '12'
-          label files ""
-          label info ""
-          event fdb
-        task fc12m
-          label files ""
-          label info ""
-          event fdb
-        task flush
-          edit STREAM 'wave'
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family clean
-        trigger /elaw_36r1/main/make eq complete and euroshelf eq complete and archive eq complete
-        task clold
-        task clean_ws
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-      endfamily
-    endfamily
-    family 00
-      edit EMOS_BASE '00'
-      edit EMOS_PROJECT '00'
-      edit DELTA_DAY '1'
-      edit QUEUE 'os'
-      task wavesave
-        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/00/euroshelf/wamrun eq complete)
-        edit SMSFILES '/home/ma/emos/def/elaw_36r1/euroshelf'
-      family euroshelf
-        trigger ./wavesave eq complete
-        task buoycol
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task monthly
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit DATEMASK '04.*.*'
-          inlimit /limits:linux_cluster
-        task uracol
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task fc_plot
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task uraplot
-          trigger uracol eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task windplot
-          trigger uracol eq complete
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task uraesf
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-        task urascat
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          edit DATEMASK '03.*.*'
-          inlimit /limits:linux_cluster
-      endfamily
-      family archive
-        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/00/euroshelf/wamrun eq complete)
-        edit FSFAMILY 'mars'
-        inlimit /elaw_36r1/limits:mars
-        inlimit /limits:mars
-        task medite_18
-          edit DELTA_DAY '0'
-          edit EMOS_BASE '18'
-          label files ""
-          label info ""
-          event fdb
-        task medite_00
-          edit EMOS_BASE '00'
-          label files ""
-          label info ""
-          event fdb
-        task fc12m
-          label files ""
-          label info ""
-          event fdb
-        task flush
-          edit STREAM 'wave'
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family clean
-        trigger /elaw_36r1/main/make eq complete and euroshelf eq complete and archive eq complete
-        task clold
-        task clean_ws
-          edit QUEUE 'emos-e'
-          edit QUEUE_EPILOG 'emos-exp'
-          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit LOGDIR '/vol/emos_nc/output'
-          edit SMSOUT '/vol/emos_nc/output'
-          inlimit /limits:linux_cluster
-      endfamily
-    endfamily
-    task checkarchive
-      trigger /elaw_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FSFAMILY 'mars'
-      edit EMOS_TYPE 'an'
-      inlimit /limits:linux_cluster
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-      edit LOGTASK 'lag'
-    task logfiles
-      late -s +00:05 -c +00:15
-      trigger /elaw_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete and checkarchive eq complete and logfilestore eq complete
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      edit LOGTASK 'lag'
-      inlimit /limits:linux_cluster
-  endfamily
-endsuite
-suite ema_36r1
-  edit USER 'emos'
-  edit SCHOST 'c1b'
-  edit STHOST '/s1b'
-  edit STHOST_BKUP '/s1a'
-  edit SCHOST_BKP 'c1a'
-  edit WSHOST 'linux_cluster'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit SMSLOGHOST 'c1b'
-  edit SMSLOGPORT '9316'
-  edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-  edit SMSURL 'USA/GMAED/12'
-  edit VERSION '0046'
-  edit FIRST_DAY '1'
-  edit SMSTRIES '2'
-  edit DELTA_DAY '0'
-  edit EMOS_BASE '12'
-  edit EMOS_TIME_STEP_H '0000'
-  edit FSFAMILY ''
-  edit EPSTYPE 'fc'
-  edit MEMBER '0'
-  edit INIMA ''
-  edit INIMACONS '0'
-  edit INILEVELS '91'
-  edit VERIFY 'verify'
-  edit PERIOD_4D '12'
-  edit WINDOW_LENGTH_4D '12'
-  edit WINDOW_OFFSET_4D '9'
-  edit ANNPES '48'
-  edit ANMEM '3584'
-  edit ANSTACK '700'
-  edit ANMRFS '160'
-  edit FCNPES '92'
-  edit FCMEM '3584'
-  edit FCSTACK '690'
-  edit FCMRFS '32'
-  edit ININPES '48'
-  edit REINITIALIZE 'false'
-  edit DATEMASK '*.*.*'
-  edit YMD 'dummy'
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/ema_36r1'
-  edit SMSINCLUDE '/home/ma/emos/def/ema_36r1/include'
-  edit ACCOUNT 'oemaed'
-  edit STREAM 'MAED'
-  edit EMOS_STREAM 'MAED'
-  edit MARS_DB 'marsod'
-  edit SUITE_START '20040814'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit.36r1 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT% '
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
-  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
-  edit INIEXPVER '0046'
-  edit SLEEPTIME '1'
-  inlimit /limits:c1b
-  clock hybrid -86400
-  family limits
-    limit inidata 1
-    limit mars 3
-    limit prod 5
-    limit pdb 5
-    limit q2diss 5
-  endfamily
-  family make
-    task setup
-    task links
-      trigger setup eq complete
-      edit FSFAMILY 'fc'
-      edit WSHOST 'bee01'
-    task datalinks
-      trigger setup eq complete and links eq complete
-      edit FSFAMILY 'fc'
-    task ifs
-      trigger links eq complete and datalinks eq complete
-      edit FSFAMILY 'fc'
-    task wamabs
-      trigger links eq complete and datalinks eq complete
-    task wconst
-      trigger wamabs eq complete
-    task ma_bin
-      trigger links eq complete and datalinks eq complete
-    task ma_tools
-      trigger links eq complete and datalinks eq complete
-    task prepdata
-      trigger links eq complete and datalinks eq complete
-  endfamily
-  family init
-    trigger /pp1/main/extractions/ma eq complete and make eq complete and /ema_36r1:ECF_DATE le /o/main:YMD
-    task ma_clean
-      edit FSFAMILY 'gfc'
-    task rmfdb
-      trigger ma_clean eq complete
-      edit FSFAMILY 'mars'
-    task flush
-      trigger ma_clean eq complete
-      edit STREAM 'MAED'
-      edit EMOS_TYPE 'an'
-      edit FSFAMILY 'mars'
-      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
-      label files ""
-      label info ""
-      event fdb
-    task ma_stage
-      trigger ma_clean eq complete
-      edit DATEMASK '01.*.*'
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      inlimit /limits:linux_cluster
-    task ma_generate
-      trigger ma_stage eq complete and ma_clean eq complete
-    task getini
-      trigger ma_generate eq complete
-      edit INIMA 'mfr ncep ukm dwd '
-      edit FSFAMILY 'gfc'
-    task wavini
-      trigger ma_stage eq complete and ma_clean eq complete
-      edit FSFAMILY 'gfc'
-  endfamily
-  family dwd
-    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
-    edit INIMA 'dwd'
-    edit INIMACONS '0'
-    family fc
-      edit FCLENGTH '240'
-      edit FCMEM '2000'
-      edit FCSTACK '700'
-      edit FCMRFS '0'
-      edit FSFAMILY 'gfc'
-      task inidata
-        edit THREADS '4'
-        inlimit /ema_36r1/limits:inidata
-      task getfcdata
-        trigger inidata eq complete
-        edit FSFAMILY 'fc'
-      task getpersSST
-        trigger getfcdata eq complete
-        edit FSFAMILY 'fc'
-        edit SSTLEN '240'
-        edit SSTINT '1'
-        edit THREADS '2'
-        edit NPES '4'
-        edit MEM '1000'
-        edit CPUTIME '960'
-      task model
-        trigger getpersSST eq complete
-        edit PERSST 'true'
-        edit FSFAMILY 'fc'
-        edit FCLENGTH '240'
-        meter step -1 240 240
-    endfamily
-    family archive
-      trigger fc/inidata eq complete
-      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
-      edit EMOS_TYPE 'an'
-      edit FSFAMILY 'mars'
-      task ma_anml
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-      task sp2fdb
-        trigger ../fc/model:step ge 0 or ../fc/model eq complete
-        edit EMOS_TYPE 'fc'
-        edit STEPS '0'
-        label files ""
-        label info ""
-        event fdb
-      family fc000
-        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
-        edit STEPS '0'
-        task fcml
-          label files ""
-          label info ""
-          event fdb
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc024
-        trigger ../fc/model:step ge 24 or ../fc/model eq complete
-        edit STEPS '3/6/9/12/15/18/21/24'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc036
-        trigger ../fc/model:step ge 36 or ../fc/model eq complete
-        edit STEPS '27/30/33/36'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc060
-        trigger ../fc/model:step ge 60 or ../fc/model eq complete
-        edit STEPS '39/42/45/48/51/54/57/60'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc072
-        trigger ../fc/model:step ge 72 or ../fc/model eq complete
-        edit STEPS '63/66/69/72'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc120
-        trigger ../fc/model:step ge 120 or ../fc/model eq complete
-        edit STEPS '78/84/90/96/102/108/114/120'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc180
-        trigger ../fc/model:step ge 180 or ../fc/model eq complete
-        edit STEPS '126/132/138/144/150/156/162/168/174/180'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc240
-        trigger ../fc/model:step ge 240 or ../fc/model eq complete
-        edit STEPS '186/192/198/204/210/216/222/228/234/240'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcextra
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      task fc12g
-        trigger ../fc/model eq complete
-        edit STREAM 'MAED'
-        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-        edit STEPS_SPECTRAL ''
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-    endfamily
-  endfamily
-  family ukm
-    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
-    edit INIMA 'ukm'
-    edit INIMACONS '0'
-    family fc
-      edit FCLENGTH '240'
-      edit FCMEM '2000'
-      edit FCSTACK '700'
-      edit FCMRFS '0'
-      edit FSFAMILY 'gfc'
-      task inidata
-        edit THREADS '4'
-        inlimit /ema_36r1/limits:inidata
-      task getfcdata
-        trigger inidata eq complete
-        edit FSFAMILY 'fc'
-      task getpersSST
-        trigger getfcdata eq complete
-        edit FSFAMILY 'fc'
-        edit SSTLEN '240'
-        edit SSTINT '1'
-        edit THREADS '2'
-        edit NPES '4'
-        edit MEM '1000'
-        edit CPUTIME '960'
-      task model
-        trigger getpersSST eq complete
-        edit PERSST 'true'
-        edit FSFAMILY 'fc'
-        edit FCLENGTH '240'
-        meter step -1 240 240
-    endfamily
-    family archive
-      trigger fc/inidata eq complete
-      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
-      edit EMOS_TYPE 'an'
-      edit FSFAMILY 'mars'
-      task ma_anml
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-      task sp2fdb
-        trigger ../fc/model:step ge 0 or ../fc/model eq complete
-        edit EMOS_TYPE 'fc'
-        edit STEPS '0'
-        label files ""
-        label info ""
-        event fdb
-      family fc000
-        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
-        edit STEPS '0'
-        task fcml
-          label files ""
-          label info ""
-          event fdb
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc024
-        trigger ../fc/model:step ge 24 or ../fc/model eq complete
-        edit STEPS '3/6/9/12/15/18/21/24'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc036
-        trigger ../fc/model:step ge 36 or ../fc/model eq complete
-        edit STEPS '27/30/33/36'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc060
-        trigger ../fc/model:step ge 60 or ../fc/model eq complete
-        edit STEPS '39/42/45/48/51/54/57/60'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc072
-        trigger ../fc/model:step ge 72 or ../fc/model eq complete
-        edit STEPS '63/66/69/72'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc120
-        trigger ../fc/model:step ge 120 or ../fc/model eq complete
-        edit STEPS '78/84/90/96/102/108/114/120'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc180
-        trigger ../fc/model:step ge 180 or ../fc/model eq complete
-        edit STEPS '126/132/138/144/150/156/162/168/174/180'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc240
-        trigger ../fc/model:step ge 240 or ../fc/model eq complete
-        edit STEPS '186/192/198/204/210/216/222/228/234/240'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcextra
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      task fc12g
-        trigger ../fc/model eq complete
-        edit STREAM 'MAED'
-        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-        edit STEPS_SPECTRAL ''
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-    endfamily
-  endfamily
-  family ncep
-    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
-    edit INIMA 'ncep'
-    edit INIMACONS '0'
-    family fc
-      edit FCLENGTH '240'
-      edit FCMEM '2000'
-      edit FCSTACK '700'
-      edit FCMRFS '0'
-      edit FSFAMILY 'gfc'
-      task inidata
-        edit THREADS '4'
-        inlimit /ema_36r1/limits:inidata
-      task getfcdata
-        trigger inidata eq complete
-        edit FSFAMILY 'fc'
-      task getpersSST
-        trigger getfcdata eq complete
-        edit FSFAMILY 'fc'
-        edit SSTLEN '240'
-        edit SSTINT '1'
-        edit THREADS '2'
-        edit NPES '4'
-        edit MEM '1000'
-        edit CPUTIME '960'
-      task model
-        trigger getpersSST eq complete
-        edit PERSST 'true'
-        edit FSFAMILY 'fc'
-        edit FCLENGTH '240'
-        meter step -1 240 240
-      task derived_param
-        trigger model eq complete
-        edit MEMBER 'off'
-        edit SMSFILES '/home/ma/emos/def/ema_36r1/mc/fc'
-        edit STEPS '0/12/24/36/48/60/72/84/96/108/120/132/144/156/168/180/192/204/216/228/240'
-        edit EMOS_TYPE 'fc'
-    endfamily
-    family archive
-      trigger fc/inidata eq complete
-      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
-      edit EMOS_TYPE 'an'
-      edit FSFAMILY 'mars'
-      task ma_anml
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-      task sp2fdb
-        trigger ../fc/model:step ge 0 or ../fc/model eq complete
-        edit EMOS_TYPE 'fc'
-        edit STEPS '0'
-        label files ""
-        label info ""
-        event fdb
-      family fc000
-        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
-        edit STEPS '0'
-        task fcml
-          label files ""
-          label info ""
-          event fdb
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc024
-        trigger ../fc/model:step ge 24 or ../fc/model eq complete
-        edit STEPS '3/6/9/12/15/18/21/24'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc036
-        trigger ../fc/model:step ge 36 or ../fc/model eq complete
-        edit STEPS '27/30/33/36'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc060
-        trigger ../fc/model:step ge 60 or ../fc/model eq complete
-        edit STEPS '39/42/45/48/51/54/57/60'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc072
-        trigger ../fc/model:step ge 72 or ../fc/model eq complete
-        edit STEPS '63/66/69/72'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc120
-        trigger ../fc/model:step ge 120 or ../fc/model eq complete
-        edit STEPS '78/84/90/96/102/108/114/120'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc180
-        trigger ../fc/model:step ge 180 or ../fc/model eq complete
-        edit STEPS '126/132/138/144/150/156/162/168/174/180'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc240
-        trigger ../fc/model:step ge 240 or ../fc/model eq complete
-        edit STEPS '186/192/198/204/210/216/222/228/234/240'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcextra
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      task fc12g
-        trigger ../fc/model eq complete
-        edit STREAM 'MAED'
-        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-        edit STEPS_SPECTRAL ''
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-    endfamily
-  endfamily
-  family mfr
-    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
-    edit INIMA 'mfr'
-    edit INIMACONS '0'
-    family fc
-      edit FCLENGTH '240'
-      edit FCMEM '2000'
-      edit FCSTACK '700'
-      edit FCMRFS '0'
-      edit FSFAMILY 'gfc'
-      task inidata
-        edit THREADS '4'
-        inlimit /ema_36r1/limits:inidata
-      task getfcdata
-        trigger inidata eq complete
-        edit FSFAMILY 'fc'
-      task getpersSST
-        trigger getfcdata eq complete
-        edit FSFAMILY 'fc'
-        edit SSTLEN '240'
-        edit SSTINT '1'
-        edit THREADS '2'
-        edit NPES '4'
-        edit MEM '1000'
-        edit CPUTIME '960'
-      task model
-        trigger getpersSST eq complete
-        edit PERSST 'true'
-        edit FSFAMILY 'fc'
-        edit FCLENGTH '240'
-        meter step -1 240 240
-    endfamily
-    family archive
-      trigger fc/inidata eq complete
-      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
-      edit EMOS_TYPE 'an'
-      edit FSFAMILY 'mars'
-      task ma_anml
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-      task sp2fdb
-        trigger ../fc/model:step ge 0 or ../fc/model eq complete
-        edit EMOS_TYPE 'fc'
-        edit STEPS '0'
-        label files ""
-        label info ""
-        event fdb
-      family fc000
-        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
-        edit STEPS '0'
-        task fcml
-          label files ""
-          label info ""
-          event fdb
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc024
-        trigger ../fc/model:step ge 24 or ../fc/model eq complete
-        edit STEPS '3/6/9/12/15/18/21/24'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc036
-        trigger ../fc/model:step ge 36 or ../fc/model eq complete
-        edit STEPS '27/30/33/36'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc060
-        trigger ../fc/model:step ge 60 or ../fc/model eq complete
-        edit STEPS '39/42/45/48/51/54/57/60'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc072
-        trigger ../fc/model:step ge 72 or ../fc/model eq complete
-        edit STEPS '63/66/69/72'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc120
-        trigger ../fc/model:step ge 120 or ../fc/model eq complete
-        edit STEPS '78/84/90/96/102/108/114/120'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc180
-        trigger ../fc/model:step ge 180 or ../fc/model eq complete
-        edit STEPS '126/132/138/144/150/156/162/168/174/180'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc240
-        trigger ../fc/model:step ge 240 or ../fc/model eq complete
-        edit STEPS '186/192/198/204/210/216/222/228/234/240'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcextra
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      task fc12g
-        trigger ../fc/model eq complete
-        edit STREAM 'MAED'
-        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-        edit STEPS_SPECTRAL ''
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-    endfamily
-  endfamily
-  family consensus
-    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
-    edit INIMA 'mfr ncep ukm dwd '
-    edit INIMACONS '1'
-    family fc
-      edit FCLENGTH '240'
-      edit FCMEM '2000'
-      edit FCSTACK '700'
-      edit FCMRFS '0'
-      edit FSFAMILY 'gfc'
-      task inidata
-        edit THREADS '4'
-        inlimit /ema_36r1/limits:inidata
-      task getfcdata
-        trigger inidata eq complete
-        edit FSFAMILY 'fc'
-      task getpersSST
-        trigger getfcdata eq complete
-        edit FSFAMILY 'fc'
-        edit SSTLEN '240'
-        edit SSTINT '1'
-        edit THREADS '2'
-        edit NPES '4'
-        edit MEM '1000'
-        edit CPUTIME '960'
-      task model
-        trigger getpersSST eq complete
-        edit PERSST 'true'
-        edit FSFAMILY 'fc'
-        edit FCLENGTH '240'
-        meter step -1 240 240
-    endfamily
-    family archive
-      trigger fc/inidata eq complete
-      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
-      edit EMOS_TYPE 'an'
-      edit FSFAMILY 'mars'
-      task ma_anml
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-      task sp2fdb
-        trigger ../fc/model:step ge 0 or ../fc/model eq complete
-        edit EMOS_TYPE 'fc'
-        edit STEPS '0'
-        label files ""
-        label info ""
-        event fdb
-      family fc000
-        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
-        edit STEPS '0'
-        task fcml
-          label files ""
-          label info ""
-          event fdb
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc024
-        trigger ../fc/model:step ge 24 or ../fc/model eq complete
-        edit STEPS '3/6/9/12/15/18/21/24'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc036
-        trigger ../fc/model:step ge 36 or ../fc/model eq complete
-        edit STEPS '27/30/33/36'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc060
-        trigger ../fc/model:step ge 60 or ../fc/model eq complete
-        edit STEPS '39/42/45/48/51/54/57/60'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc072
-        trigger ../fc/model:step ge 72 or ../fc/model eq complete
-        edit STEPS '63/66/69/72'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc120
-        trigger ../fc/model:step ge 120 or ../fc/model eq complete
-        edit STEPS '78/84/90/96/102/108/114/120'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc180
-        trigger ../fc/model:step ge 180 or ../fc/model eq complete
-        edit STEPS '126/132/138/144/150/156/162/168/174/180'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      family fc240
-        trigger ../fc/model:step ge 240 or ../fc/model eq complete
-        edit STEPS '186/192/198/204/210/216/222/228/234/240'
-        task fcsfc
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcpl
-          trigger fcsfc:fdb or fcsfc eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcil
-          trigger fcpl:fdb or fcpl eq complete
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-        task fcextra
-          inlimit /ema_36r1/limits:mars
-          inlimit /limits:mars
-          label files ""
-          label info ""
-          event fdb
-      endfamily
-      task fc12g
-        trigger ../fc/model eq complete
-        edit STREAM 'MAED'
-        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
-        edit STEPS_SPECTRAL ''
-        inlimit /ema_36r1/limits:mars
-        inlimit /limits:mars
-        label files ""
-        label info ""
-        event fdb
-    endfamily
-  endfamily
-  family verify
-    trigger dwd eq complete and ukm eq complete and ncep eq complete and mfr eq complete and consensus eq complete
-    edit QUEUE 'emos-e'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit SMSOUT '/vol/emos_nc/output'
-    edit SMSFILES '/home/ma/emos/def/ema_36r1/verif'
-    inlimit /limits:linux_cluster
-    task vmaprep
-    family washington
-      trigger vmaprep eq complete
-      edit CENTRE 'washington'
-      edit CENTRE_STREAM 'ma_washington_36r1'
-      task vmacrd
-        edit DATEMASK '28.*.*'
-      task vmali1
-      task vmali2
-      task vmaup1
-        trigger vmali1 eq complete
-      task vmaup2
-        trigger vmaup1 eq complete and vmali2 eq complete
-      task vmacrmv
-        edit DATEMASK '28.*.*'
-      task vmamemv
-        trigger vmaup2 eq complete
-        edit DATEMASK '01.*.*'
-      task vmaupmv
-        trigger vmamemv eq complete
-        edit DATEMASK '01.*.*'
-      task vmacrmb
-        edit DATEMASK '28.*.*'
-      task vmamemb
-        trigger vmaup2 eq complete
-        edit DATEMASK '10.*.*'
-      task vmaupmb
-        trigger vmamemb eq complete
-        edit DATEMASK '10.*.*'
-    endfamily
-    family bracknell
-      trigger vmaprep eq complete
-      edit CENTRE 'bracknell'
-      edit CENTRE_STREAM 'ma_bracknell_36r1'
-      task vmacrd
-        edit DATEMASK '28.*.*'
-      task vmali1
-      task vmali2
-      task vmaup1
-        trigger vmali1 eq complete
-      task vmaup2
-        trigger vmaup1 eq complete and vmali2 eq complete
-      task vmacrmv
-        edit DATEMASK '28.*.*'
-      task vmamemv
-        trigger vmaup2 eq complete
-        edit DATEMASK '01.*.*'
-      task vmaupmv
-        trigger vmamemv eq complete
-        edit DATEMASK '01.*.*'
-      task vmacrmb
-        edit DATEMASK '28.*.*'
-      task vmamemb
-        trigger vmaup2 eq complete
-        edit DATEMASK '10.*.*'
-      task vmaupmb
-        trigger vmamemb eq complete
-        edit DATEMASK '10.*.*'
-    endfamily
-    family offenbach
-      trigger vmaprep eq complete
-      edit CENTRE 'offenbach'
-      edit CENTRE_STREAM 'ma_offenbach_36r1'
-      task vmacrd
-        edit DATEMASK '28.*.*'
-      task vmali1
-      task vmali2
-      task vmaup1
-        trigger vmali1 eq complete
-      task vmaup2
-        trigger vmaup1 eq complete and vmali2 eq complete
-      task vmacrmv
-        edit DATEMASK '28.*.*'
-      task vmamemv
-        trigger vmaup2 eq complete
-        edit DATEMASK '01.*.*'
-      task vmaupmv
-        trigger vmamemv eq complete
-        edit DATEMASK '01.*.*'
-      task vmacrmb
-        edit DATEMASK '28.*.*'
-      task vmamemb
-        trigger vmaup2 eq complete
-        edit DATEMASK '10.*.*'
-      task vmaupmb
-        trigger vmamemb eq complete
-        edit DATEMASK '10.*.*'
-    endfamily
-    family toulouse
-      trigger vmaprep eq complete
-      edit CENTRE 'toulouse'
-      edit CENTRE_STREAM 'ma_toulouse_36r1'
-      task vmacrd
-        edit DATEMASK '28.*.*'
-      task vmali1
-      task vmali2
-      task vmaup1
-        trigger vmali1 eq complete
-      task vmaup2
-        trigger vmaup1 eq complete and vmali2 eq complete
-      task vmacrmv
-        edit DATEMASK '28.*.*'
-      task vmamemv
-        trigger vmaup2 eq complete
-        edit DATEMASK '01.*.*'
-      task vmaupmv
-        trigger vmamemv eq complete
-        edit DATEMASK '01.*.*'
-      task vmacrmb
-        edit DATEMASK '28.*.*'
-      task vmamemb
-        trigger vmaup2 eq complete
-        edit DATEMASK '10.*.*'
-      task vmaupmb
-        trigger vmamemb eq complete
-        edit DATEMASK '10.*.*'
-    endfamily
-    family consensus
-      trigger vmaprep eq complete
-      edit CENTRE 'consensus'
-      edit CENTRE_STREAM 'ma_consensus_36r1'
-      task vmacrd
-        edit DATEMASK '28.*.*'
-      task vmali1
-      task vmali2
-      task vmaup1
-        trigger vmali1 eq complete
-      task vmaup2
-        trigger vmaup1 eq complete and vmali2 eq complete
-      task vmacrmv
-        edit DATEMASK '28.*.*'
-      task vmamemv
-        trigger vmaup2 eq complete
-        edit DATEMASK '01.*.*'
-      task vmaupmv
-        trigger vmamemv eq complete
-        edit DATEMASK '01.*.*'
-      task vmacrmb
-        edit DATEMASK '28.*.*'
-      task vmamemb
-        trigger vmaup2 eq complete
-        edit DATEMASK '10.*.*'
-      task vmaupmb
-        trigger vmamemb eq complete
-        edit DATEMASK '10.*.*'
-    endfamily
-  endfamily
-  family trans
-    complete /ema_36r1/ncep eq complete and /ema_36r1/ncep/fc/model:step lt 240
-    trigger /ema_36r1/ncep/fc eq complete and /ema_36r1/consensus/fc eq complete
-    edit EMOS_TYPE 'fc'
-    edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
-    edit FSFAMILY 'ppdi'
-    edit SMSTRIES '1'
-    edit EMOS_STREAM 'MAED'
-    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
-    edit SMSURL 'USA/GMAED/12'
-    edit SCHEDULE_DISS_TIME '0'
-    inlimit /ema_36r1/limits:prod
-    family 000
-      edit STEP '000'
-      task trans_ma
-    endfamily
-    family 012
-      trigger ./000 eq complete
-      edit STEP '012'
-      task trans_ma
-    endfamily
-    family 024
-      trigger ./012 eq complete
-      edit STEP '024'
-      task trans_ma
-    endfamily
-    family 036
-      trigger ./024 eq complete
-      edit STEP '036'
-      task trans_ma
-    endfamily
-    family 048
-      trigger ./036 eq complete
-      edit STEP '048'
-      task trans_ma
-    endfamily
-    family 060
-      trigger ./048 eq complete
-      edit STEP '060'
-      task trans_ma
-    endfamily
-    family 072
-      trigger ./060 eq complete
-      edit STEP '072'
-      task trans_ma
-    endfamily
-    family 084
-      trigger ./072 eq complete
-      edit STEP '084'
-      task trans_ma
-    endfamily
-    family 096
-      trigger ./084 eq complete
-      edit STEP '096'
-      task trans_ma
-    endfamily
-    family 108
-      trigger ./096 eq complete
-      edit STEP '108'
-      task trans_ma
-    endfamily
-    family 120
-      trigger ./108 eq complete
-      edit STEP '120'
-      task trans_ma
-    endfamily
-    family 132
-      trigger ./120 eq complete
-      edit STEP '132'
-      task trans_ma
-    endfamily
-    family 144
-      trigger ./132 eq complete
-      edit STEP '144'
-      task trans_ma
-    endfamily
-    family 156
-      trigger ./144 eq complete
-      edit STEP '156'
-      task trans_ma
-    endfamily
-    family 168
-      trigger ./156 eq complete
-      edit STEP '168'
-      task trans_ma
-    endfamily
-    family 180
-      trigger ./168 eq complete
-      edit STEP '180'
-      task trans_ma
-    endfamily
-    family 192
-      trigger ./180 eq complete
-      edit STEP '192'
-      task trans_ma
-    endfamily
-    family 204
-      trigger ./192 eq complete
-      edit STEP '204'
-      task trans_ma
-    endfamily
-    family 216
-      trigger ./204 eq complete
-      edit STEP '216'
-      task trans_ma
-    endfamily
-    family 228
-      trigger ./216 eq complete
-      edit STEP '228'
-      task trans_ma
-    endfamily
-    family 240
-      trigger ./228 eq complete
-      edit STEP '240'
-      task trans_ma
-    endfamily
-  endfamily
-  family pop
-    edit QUEUE 'emos-e'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit SMSOUT '/vol/emos_nc/output'
-    edit SMSFILES '/home/ma/emos/def/ema_36r1/plot'
-    inlimit /limits:linux_cluster
-    family 12
-      trigger /ema_36r1/dwd eq complete and /ema_36r1/ukm eq complete and /ema_36r1/ncep eq complete and /ema_36r1/mfr eq complete and /ema_36r1/consensus eq complete
-      edit EMOS_BASE '12'
-      family paper
-        task ma_plot
-      endfamily
-    endfamily
-  endfamily
-  family msjobs
-    edit QUEUE 'emos'
-    edit QUEUE_EPILOG 'emos-exp'
-    edit WSHOST 'ecgate'
-    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-    edit SMSOUT '/vol/emos_nc/output'
-    edit LOGDIR '/vol/emos_nc/output'
-    edit VERSION '0046'
-    edit STREAM 'MA'
-    edit EMOS_STREAM 'MA'
-    edit SMSTRYNO '1'
-    edit SMSURLBASE 'http://ecgate.ecmwf.int:9080'
-    edit SMSURL 'do/events'
-    family 12
-      trigger ../trans eq complete
-      edit SMSFILES '/home/ma/emos/def/ema_36r1/msjobs'
-      family msma
-        edit EMOS_TIME_STEP_H '240'
-        edit MSJ_DIR 'ma12h240'
-        task ms_ec
-      endfamily
-    endfamily
-  endfamily
-  family check
-    task checkarchive
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit FSFAMILY 'mars'
-      edit EMOS_TYPE 'an'
-      inlimit /limits:linux_cluster
-      label info ""
-  endfamily
-  family save
-    edit SMSFILES '/home/ma/emos/def/ema_36r1/restart'
-    task logfilestore
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-  endfamily
-  family log
-    trigger make eq complete and init eq complete and dwd eq complete and ukm eq complete and ncep eq complete and mfr eq complete and consensus eq complete and verify eq complete and trans eq complete and pop eq complete and msjobs eq complete and check eq complete and save eq complete
-    edit SMSFILES '/home/ma/emos/def/ema_36r1/restart'
-    task logfiles
-      late -s +00:05 -c +00:15
-      edit QUEUE 'emos-e'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-      time 14:00
-  endfamily
-endsuite
-suite ejason2_val
-  edit SMSHOME '/vol/emos_nc/output'
-  edit SMSFILES '/home/ma/emos/def/ejason2_val/smsfiles'
-  edit SMSINCLUDE '/home/ma/emos/def/ejason2_val/include'
-  edit MEM '2500'
-  edit USER 'emos'
-  edit SCHOST 'c1b'
-  edit SCHOST_BKUP 'c1a'
-  edit WSHOST 'linux_cluster'
-  edit ACCOUNT 'oesu'
-  edit WSLOGDIR '/vol/emos_nc/output'
-  edit SCLOGDIR '/s1b/emos_esuite/emos_data/9002/log'
-  edit SMSLOGHOST 'c1b'
-  edit SMSLOGPORT '9316'
-  edit SMSURLBASE 'http://www.cnes.fr/web'
-  edit SMSURL '1441-jason.php'
-  edit QUEUE 'ns'
-  edit QUEUE_EPILOG 'ns'
-  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
-  edit LOGDIR '/s1b/emos_esuite/emos_data/9002/log'
-  edit SMSOUT '/s1b/emos_esuite/emos_data/9002/log'
-  edit VERSION '5'
-  edit EXPVER '9002'
-  edit GRID '400'
-  edit HOMEDIR '/s1b/emos_esuite/emos_data/jasonII'
-  edit SLEEPTIME '1'
-  inlimit /limits:c1b
-  clock hybrid 
-  family limits
-    limit limiter 1
-    limit c1b 7
-    limit swarm 7
-  endfamily
-  family main
-    repeat date YMD 20071231 20091231 1
-    edit LOGTASK 'main'
-    edit CALL_ECPDS 'false'
-    edit DESTINATION 'EMI'
-    edit ECPDS_STREAM 'JSN2'
-    family make
-      task common
-      task local
-        trigger common eq complete
-      task purge
-    endfamily
-    task cleaner
-      trigger make eq complete
-      edit KEEP_DAYS '2'
-    task stage
-    family prod
-      trigger make eq complete
-      inlimit /ejason2_val/limits:limiter
-      family 15P
-        edit LABELS '15P'
-        edit EMOS_CYCLE '12'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
-      endfamily
-      family 18P
-        edit LABELS '18P'
-        edit EMOS_CYCLE '12'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
-      endfamily
-      family 21P
-        edit LABELS '21P'
-        edit EMOS_CYCLE '12'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
-      endfamily
-      family 24P
-        edit LABELS '24P'
-        edit EMOS_CYCLE '12'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
-      endfamily
-      family 03P
-        edit LABELS '03P'
-        edit DELTA_DAY '1'
-        edit EMOS_CYCLE '00'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
-      endfamily
-      family 06P
-        edit LABELS '06P'
-        edit DELTA_DAY '1'
-        edit EMOS_CYCLE '00'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
-      endfamily
-      family 09P
-        edit LABELS '09P'
-        edit DELTA_DAY '1'
-        edit EMOS_CYCLE '00'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
-      endfamily
-      family 12P
-        edit LABELS '12P'
-        edit DELTA_DAY '1'
-        edit EMOS_CYCLE '00'
-        task jason2_val
-          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
-        task arch_val
-          trigger ( ./jason2_val eq complete) and ( ../03P eq complete) and ( ../06P eq complete) and ( ../09P eq complete) and ( ../24P eq complete) and ( ../15P eq complete) and ( ../18P eq complete) and ( ../21P eq complete)
-          edit DELTA_DAY '0'
-      endfamily
-    endfamily
-    task logfilestore
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit KEEPLOGS 'no'
-      edit LOGSTOECFS 'no'
-      edit MOVE_TO_ECFS 'yes'
-    task logfiles
-      trigger ( prod eq complete) and ( logfilestore eq complete)
-      edit QUEUE 'emos'
-      edit QUEUE_EPILOG 'emos-exp'
-      edit WSHOST 'localhost'
-      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit LOGDIR '/vol/emos_nc/output'
-      edit SMSOUT '/vol/emos_nc/output'
-      edit MOVE_TO_ECFS 'no'
-  endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/test_auto_add_extern.def 5.13.0-1/ANode/test/parser/data/single_defs/test_auto_add_extern.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/test_auto_add_extern.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/test_auto_add_extern.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-#
-# test auto add extern for triggers and inlimits
-#
-extern /a/b/c/d         
-extern /a/b/c/d/e:event        
-extern /a/b/c/d/e:meter       
-extern /made/up/redundant/extren     # REDUNDANT extern, should get removed after auto_add_extren(true)
-extern /made/up/redundant/extren     # Duplicates should be ignored.
-
-extern /limits:c1a
-extern /limits:c1a                   # Duplicates should be ignored
-extern fred
-extern limits:hpcd
-extern /suiteName:sg1
-extern /obs/limits:hpcd
-
-extern /extern/f1/parent_variable:var1
-extern /extern/f1/parent_variable:var2
-
-# Expect 10 unique externs
-# expect:  extern /made/up/redundant/extren  to be removed
-# Also because we have defined externs , expect no warnings:
-
-suite extern
-   family f1
-      task p
-            trigger /a/b/c/d == complete          # extern path
-      task q
-            trigger /a/b/c/d/e:event == set       # extern event path
-      task r
-            trigger /a/b/c/d/e:meter le 30        # extern meter path   
-      task parent_variable
-            trigger :var1 == 1 and :var2 == 2
-    endfamily
-    
-    
-    inlimit /limits:c1a
-    inlimit fred
-    family anon    
-         inlimit limits:hpcd       
-      task t1
-         inlimit /suiteName:sg1            
-      task t2
-            inlimit /obs/limits:hpcd       
-      task t3
-            inlimit /limits:c1a            
-    endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/test_complete.def 5.13.0-1/ANode/test/parser/data/single_defs/test_complete.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/test_complete.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/test_complete.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-   suite complete
-      edit SMSHOME data/SMSHOME
-      edit SMSINCLUDE $SMSHOME/includes
-      edit SLEEPTIME 1
-      family family
-         complete /complete/family/check:nofiles
-         repeat integer VAR 0 3
-         task check
-            event 1 nofiles
-         task t1
-            trigger check == complete
-        task t2
-            trigger t2 == complete
-      endfamily
-   endsuite
-
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/test_repeat.def 5.13.0-1/ANode/test/parser/data/single_defs/test_repeat.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/test_repeat.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/test_repeat.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite s1
-  # clock real 300 -c 60
-  family daily
-    repeat date YMD 20101215 20101217 1
-    task t1
-      time 10:30
-  endfamily
-endsuite
diff -pruN 5.12.4-1/ANode/test/parser/data/single_defs/test_time_why.def 5.13.0-1/ANode/test/parser/data/single_defs/test_time_why.def
--- 5.12.4-1/ANode/test/parser/data/single_defs/test_time_why.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/ANode/test/parser/data/single_defs/test_time_why.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-# Definition of the suite test
-suite test
- family f2
-     edit SLEEP 20
-     task t1
-         date 5.*.*
-         time 00:30 23:30 00:30
-     task t2
-         day tuesday
-         day wednesday
-         day monday
-         day sunday
-         time 09:00
-    task t21
-         day tuesday
-         day wednesday
-         day monday
-         day sunday
-         today 09:00
-     task t3
-         date 1.*.*
-         time 08:00
-     task t4
-         date 6.*.*
-         date 7.*.*
-         date 8.*.*
-         date 5.*.*
-         time 09:02
-     task t5
-         time 08:00
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Base/CMakeLists.txt 5.13.0-1/Base/CMakeLists.txt
--- 5.12.4-1/Base/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,254 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-set(srcs
-  # Headers
-  src/ecflow/base/AbstractClientEnv.hpp
-  src/ecflow/base/AbstractServer.hpp
-  src/ecflow/base/Client.hpp
-  src/ecflow/base/ClientOptionsParser.hpp
-  src/ecflow/base/ClientToServerRequest.hpp
-  src/ecflow/base/Cmd.hpp
-  src/ecflow/base/Connection.hpp
-  src/ecflow/base/Gnuplot.hpp
-  src/ecflow/base/ServerReply.hpp
-  src/ecflow/base/ServerToClientResponse.hpp
-  src/ecflow/base/Stats.hpp
-  src/ecflow/base/WhyCmd.hpp
-  src/ecflow/base/ZombieCtrl.hpp
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/base/Openssl.hpp>
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/base/ssl_connection.hpp>
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/base/SslClient.hpp>
-  src/ecflow/base/cts/ClientToServerCmd.hpp
-  src/ecflow/base/cts/CtsCmdRegistry.hpp
-  src/ecflow/base/cts/EditHistoryMgr.hpp
-  src/ecflow/base/cts/task/AbortCmd.hpp
-  src/ecflow/base/cts/task/CompleteCmd.hpp
-  src/ecflow/base/cts/task/CtsWaitCmd.hpp
-  src/ecflow/base/cts/task/EventCmd.hpp
-  src/ecflow/base/cts/task/InitCmd.hpp
-  src/ecflow/base/cts/task/LabelCmd.hpp
-  src/ecflow/base/cts/task/MeterCmd.hpp
-  src/ecflow/base/cts/task/QueueCmd.hpp
-  src/ecflow/base/cts/task/TaskApi.hpp
-  src/ecflow/base/cts/task/TaskCmd.hpp
-  src/ecflow/base/cts/user/AlterCmd.hpp
-  src/ecflow/base/cts/user/BeginCmd.hpp
-  src/ecflow/base/cts/user/CFileCmd.hpp
-  src/ecflow/base/cts/user/CheckPtCmd.hpp
-  src/ecflow/base/cts/user/ClientHandleCmd.hpp
-  src/ecflow/base/cts/user/CSyncCmd.hpp
-  src/ecflow/base/cts/user/CtsApi.hpp
-  src/ecflow/base/cts/user/CtsCmd.hpp
-  src/ecflow/base/cts/user/CtsNodeCmd.hpp
-  src/ecflow/base/cts/user/DeleteCmd.hpp
-  src/ecflow/base/cts/user/EditScriptCmd.hpp
-  src/ecflow/base/cts/user/ForceCmd.hpp
-  src/ecflow/base/cts/user/FreeDepCmd.hpp
-  src/ecflow/base/cts/user/GroupCTSCmd.hpp
-  src/ecflow/base/cts/user/LoadDefsCmd.hpp
-  src/ecflow/base/cts/user/LogCmd.hpp
-  src/ecflow/base/cts/user/LogMessageCmd.hpp
-  src/ecflow/base/cts/user/MoveCmd.hpp
-  src/ecflow/base/cts/user/OrderNodeCmd.hpp
-  src/ecflow/base/cts/user/PathsCmd.hpp
-  src/ecflow/base/cts/user/PlugCmd.hpp
-  src/ecflow/base/cts/user/QueryCmd.hpp
-  src/ecflow/base/cts/user/ReplaceNodeCmd.hpp
-  src/ecflow/base/cts/user/RequeueNodeCmd.hpp
-  src/ecflow/base/cts/user/RunNodeCmd.hpp
-  src/ecflow/base/cts/user/ServerVersionCmd.hpp
-  src/ecflow/base/cts/user/ShowCmd.hpp
-  src/ecflow/base/cts/user/UserCmd.hpp
-  src/ecflow/base/cts/user/ZombieCmd.hpp
-  src/ecflow/base/stc/BlockClientZombieCmd.hpp
-  src/ecflow/base/stc/DefsCache.hpp
-  src/ecflow/base/stc/DefsCmd.hpp
-  src/ecflow/base/stc/ErrorCmd.hpp
-  src/ecflow/base/stc/GroupSTCCmd.hpp
-  src/ecflow/base/stc/PreAllocatedReply.hpp
-  src/ecflow/base/stc/SClientHandleCmd.hpp
-  src/ecflow/base/stc/SClientHandleSuitesCmd.hpp
-  src/ecflow/base/stc/SNewsCmd.hpp
-  src/ecflow/base/stc/SNodeCmd.hpp
-  src/ecflow/base/stc/SServerLoadCmd.hpp
-  src/ecflow/base/stc/SStatsCmd.hpp
-  src/ecflow/base/stc/SStringCmd.hpp
-  src/ecflow/base/stc/SStringVecCmd.hpp
-  src/ecflow/base/stc/SSuitesCmd.hpp
-  src/ecflow/base/stc/SSyncCmd.hpp
-  src/ecflow/base/stc/ServerToClientCmd.hpp
-  src/ecflow/base/stc/StcCmd.hpp
-  src/ecflow/base/stc/ZombieGetCmd.hpp
-  # Sources
-  src/ecflow/base/Client.cpp
-  src/ecflow/base/ClientOptionsParser.cpp
-  src/ecflow/base/ClientToServerRequest.cpp
-  src/ecflow/base/Connection.cpp
-  src/ecflow/base/Gnuplot.cpp
-  src/ecflow/base/ServerReply.cpp
-  src/ecflow/base/ServerToClientResponse.cpp
-  src/ecflow/base/Stats.cpp
-  src/ecflow/base/WhyCmd.cpp
-  src/ecflow/base/ZombieCtrl.cpp
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/base/Openssl.cpp>
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/base/ssl_connection.cpp>
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/base/SslClient.cpp>
-  src/ecflow/base/cts/ClientToServerCmd.cpp
-  src/ecflow/base/cts/CtsCmdRegistry.cpp
-  src/ecflow/base/cts/EditHistoryMgr.cpp
-  src/ecflow/base/cts/task/AbortCmd.cpp
-  src/ecflow/base/cts/task/CompleteCmd.cpp
-  src/ecflow/base/cts/task/CtsWaitCmd.cpp
-  src/ecflow/base/cts/task/EventCmd.cpp
-  src/ecflow/base/cts/task/InitCmd.cpp
-  src/ecflow/base/cts/task/LabelCmd.cpp
-  src/ecflow/base/cts/task/MeterCmd.cpp
-  src/ecflow/base/cts/task/QueueCmd.cpp
-  src/ecflow/base/cts/task/TaskApi.cpp
-  src/ecflow/base/cts/task/TaskCmd.cpp
-  src/ecflow/base/cts/user/AlterCmd.cpp
-  src/ecflow/base/cts/user/BeginCmd.cpp
-  src/ecflow/base/cts/user/CFileCmd.cpp
-  src/ecflow/base/cts/user/CSyncCmd.cpp
-  src/ecflow/base/cts/user/CheckPtCmd.cpp
-  src/ecflow/base/cts/user/ClientHandleCmd.cpp
-  src/ecflow/base/cts/user/CtsApi.cpp
-  src/ecflow/base/cts/user/CtsCmd.cpp
-  src/ecflow/base/cts/user/CtsNodeCmd.cpp
-  src/ecflow/base/cts/user/DeleteCmd.cpp
-  src/ecflow/base/cts/user/EditScriptCmd.cpp
-  src/ecflow/base/cts/user/ForceCmd.cpp
-  src/ecflow/base/cts/user/FreeDepCmd.cpp
-  src/ecflow/base/cts/user/GroupCTSCmd.cpp
-  src/ecflow/base/cts/user/LoadDefsCmd.cpp
-  src/ecflow/base/cts/user/LogCmd.cpp
-  src/ecflow/base/cts/user/LogMessageCmd.cpp
-  src/ecflow/base/cts/user/MoveCmd.cpp
-  src/ecflow/base/cts/user/OrderNodeCmd.cpp
-  src/ecflow/base/cts/user/PathsCmd.cpp
-  src/ecflow/base/cts/user/PlugCmd.cpp
-  src/ecflow/base/cts/user/QueryCmd.cpp
-  src/ecflow/base/cts/user/ReplaceNodeCmd.cpp
-  src/ecflow/base/cts/user/RequeueNodeCmd.cpp
-  src/ecflow/base/cts/user/RunNodeCmd.cpp
-  src/ecflow/base/cts/user/ServerVersionCmd.cpp
-  src/ecflow/base/cts/user/ShowCmd.cpp
-  src/ecflow/base/cts/user/UserCmd.cpp
-  src/ecflow/base/cts/user/ZombieCmd.cpp
-  src/ecflow/base/stc/BlockClientZombieCmd.cpp
-  src/ecflow/base/stc/DefsCache.cpp
-  src/ecflow/base/stc/DefsCmd.cpp
-  src/ecflow/base/stc/ErrorCmd.cpp
-  src/ecflow/base/stc/GroupSTCCmd.cpp
-  src/ecflow/base/stc/PreAllocatedReply.cpp
-  src/ecflow/base/stc/SClientHandleCmd.cpp
-  src/ecflow/base/stc/SClientHandleSuitesCmd.cpp
-  src/ecflow/base/stc/SNewsCmd.cpp
-  src/ecflow/base/stc/SNodeCmd.cpp
-  src/ecflow/base/stc/SServerLoadCmd.cpp
-  src/ecflow/base/stc/SStatsCmd.cpp
-  src/ecflow/base/stc/SStringCmd.cpp
-  src/ecflow/base/stc/SStringVecCmd.cpp
-  src/ecflow/base/stc/SSuitesCmd.cpp
-  src/ecflow/base/stc/SSyncCmd.cpp
-  src/ecflow/base/stc/ServerToClientCmd.cpp
-  src/ecflow/base/stc/StcCmd.cpp
-  src/ecflow/base/stc/ZombieGetCmd.cpp
-)
-
-ecbuild_add_library(
-  TARGET
-    base
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-  PUBLIC_LIBS
-    node
-    Boost::boost # Boost header-only libraries must be available (namely asio)
-)
-target_clangformat(base)
-
-
-set(test_srcs
-  # Headers
-  test/MockServer.hpp
-  test/TestHelper.hpp
-  # Sources
-  test/TestAlterCmd.cpp
-  test/TestArchiveAndRestoreCmd.cpp
-  test/TestBase_main.cpp # test entry point
-  test/TestClientHandleCmd.cpp
-  test/TestCmd.cpp
-  test/TestDeleteNodeCmd.cpp
-  test/TestForceCmd.cpp
-  test/TestFreeDepCmd.cpp
-  test/TestInLimitAndLimit.cpp
-  test/TestLogCmd.cpp
-  test/TestMeterCmd.cpp
-  test/TestProgramOptions.cpp
-  test/TestQueryCmd.cpp
-  test/TestQueueCmd.cpp
-  test/TestRequest.cpp
-  test/TestRequeueNodeCmd.cpp
-  test/TestResolveDependencies.cpp
-  test/TestSpecificIssues.cpp
-  test/TestSSyncCmd.cpp
-  test/TestSSyncCmdOrder.cpp
-  test/TestSSyncCmd_CH1.cpp
-  test/TestStatsCmd.cpp
-)
-
-ecbuild_add_test(
-  TARGET
-    u_base
-  LABELS
-    unit nightly
-  SOURCES
-    ${test_srcs}
-  INCLUDES
-    ../ANode/test
-  LIBS
-    base
-    Threads::Threads
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-  TEST_DEPENDS
-    u_parser
-)
-target_clangformat(u_base
-  CONDITION ENABLE_TESTS
-)
-
-# The following is not technically a test (as it makes no checks),
-# but a tool to measure the time it takes to generate a job file
-if (ENABLE_ALL_TESTS)
-  set(test_srcs
-    # Sources
-    test/TestJobGenPerf.cpp
-  )
-
-  ecbuild_add_test(
-    TARGET
-      p_job_gen
-    LABELS
-      performance
-    SOURCES
-      ${test_srcs}
-    LIBS
-      base
-      Threads::Threads
-  )
-  target_clangformat(p_job_gen
-    CONDITION ENABLE_TESTS
-  )
-endif()
diff -pruN 5.12.4-1/Base/src/ecflow/base/AbstractClientEnv.hpp 5.13.0-1/Base/src/ecflow/base/AbstractClientEnv.hpp
--- 5.12.4-1/Base/src/ecflow/base/AbstractClientEnv.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/AbstractClientEnv.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_AbstractClientEnv_HPP
-#define ecflow_base_AbstractClientEnv_HPP
-
-#include <string>
-#include <vector>
-
-///
-/// \brief This class is used to represent the client environment to the cmds
-///
-/// This abstraction ONLY covers aspects that are required, to _CREATE_
-/// the client command/request that is to be sent to the server
-/// The key theme is that we can define a new client to server command
-/// in one place. i.e it allows the functionality, command line arguments,
-/// parsing of the arguments, can all be done in the command class itself
-/// If the command requires any additional arguments from the client environment
-/// they should be added to this class, and the implementation in the derived class
-///
-
-class AbstractClientEnv {
-protected:
-    AbstractClientEnv() = default;
-
-public:
-    AbstractClientEnv(const AbstractClientEnv&)                  = delete;
-    const AbstractClientEnv& operator=(const AbstractClientEnv&) = delete;
-
-    virtual ~AbstractClientEnv() = default;
-
-    virtual void set_cli(bool f) = 0;
-    virtual bool get_cli() const = 0;
-
-    /// For all tasks/child based commands we require taskPath and password and optional Remote ID
-    /// When the jobs use a queueing system the remote id (ECF_RID) is used to
-    /// aid killing of jobs.(typically zombies)
-    virtual bool checkTaskPathAndPassword(std::string& errorMsg) const = 0;
-    virtual const std::string& task_path() const                       = 0;
-    virtual int task_try_no() const                                    = 0;
-    virtual const std::string& jobs_password() const                   = 0;
-    virtual const std::string& process_or_remote_id() const            = 0;
-
-    /// For test allow env variable to be set on defs, i.e. allow us to inject ECF_CLIENT to defs
-    virtual const std::vector<std::pair<std::string, std::string>>& env() const = 0;
-
-    /// Allow ping to set the host:port
-    virtual void set_host_port(const std::string& host, const std::string& port) = 0;
-
-    /// return the current host
-    virtual const std::string& host() const = 0;
-
-    /// returns the port number
-    virtual const std::string& port() const = 0;
-
-    /// debug client, when environment variable ECF_CLIENT_DEBUG is set.
-    virtual bool debug() const = 0;
-
-    /// Returns the user password read from the password file.
-    /// This value is cached, so we only read passwd file once
-    /// When the password is read in we crypt the password, using user name as a salt.
-    virtual const std::string& get_custom_user_password(const std::string& user) const = 0;
-    virtual const std::string& get_user_password(const std::string& user) const        = 0;
-    virtual void clear_user_password() = 0; // force password check again
-
-    // returns a user specified user name. When this is used a password must be provided
-    virtual const std::string& get_user_name() const = 0;
-    virtual void set_user_name(const std::string&)   = 0;
-    // set password is needed when user is authenticated from an http server call: in this case
-    // the password is given in the url (or some other means), so it will not be read from a local file
-    virtual void set_password(const std::string&) = 0;
-
-    /// Some commands work on construction. to avoid this under test. Call set_test
-    /// i.e Command like CtsCmd::SERVER_LOAD can be client side only, in which case
-    /// when testing the client interface we want to avoid opening the log file.
-    virtual void set_test()         = 0;
-    virtual bool under_test() const = 0;
-};
-
-#endif /* ecflow_base_AbstractClientEnv_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/AbstractServer.hpp 5.13.0-1/Base/src/ecflow/base/AbstractServer.hpp
--- 5.12.4-1/Base/src/ecflow/base/AbstractServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/AbstractServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,212 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_AbstractServer_HPP
-#define ecflow_base_AbstractServer_HPP
-
-#include <memory>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/base/Stats.hpp"
-#include "ecflow/base/ZombieCtrl.hpp"
-#include "ecflow/core/CheckPt.hpp"
-#include "ecflow/core/SState.hpp"
-#include "ecflow/core/Str.hpp"
-
-class Defs;
-
-/// This class is provided so that the cmd can issue requests to the server
-/// without depending on the server implementation
-///
-class AbstractServer {
-public:
-    virtual ~AbstractServer() = default;
-
-    /// Returns an NON empty string if server is ssl enabled.
-    /// 0/ "1 : enabled : uses shared ssl certificates";
-    /// 0/ "  : enabled : uses server/port specific ssl certificates";
-    virtual const std::string& ssl() const { return ecf::Str::EMPTY(); }
-
-    /// returns the current state of the server
-    /// The following table shows the effect of state, on server behaviour:
-    ///
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    virtual SState::State state() const = 0;
-
-    /// returns the server host and port number
-    virtual std::pair<std::string, std::string> hostPort() const = 0;
-
-    /// returns the defs held by the server. This should always exist. ECFLOW-182
-    virtual defs_ptr defs() const = 0;
-
-    /// Update the defs help by the server. This allows multiple suites to loaded
-    /// into the server. Note the input defs will be drained of its suites/externs as they
-    /// will get transferred to the server. If the server already has suites of the same
-    /// name, then an error message is created. This can be overridden with the force option
-    virtual void updateDefs(defs_ptr, bool force) = 0;
-
-    /// Remove all suites,externs,client handles, ready for a new start
-    virtual void clear_defs() = 0;
-
-    /// Forces the defs file in the server to be written to disk *IF* no args provided.
-    /// Otherwise updated mode OR check_pt interval OR check pt alarm
-    virtual bool checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
-                             int check_pt_interval        = 0,
-                             int check_pt_save_time_alarm = 0) = 0;
-
-    /// Ask the server to restore the  defs from the checkpt file. If that fails the back check pt is tried
-    virtual void restore_defs_from_checkpt() = 0;
-
-    /// This function should be called, when the node tree changes state
-    virtual void nodeTreeStateChanged() = 0;
-
-    /// returns true if the server allows task communication
-    /// Task-->server communication is stopped by halted()
-    virtual bool allowTaskCommunication() const = 0;
-
-    /// Stops job scheduling. Check point is enabled. (i,e if we were previously halted)
-    /// However any client request can still communicate with the server
-    /// Does NOT affect check pointing. Since any request can make changes to node tree
-    /// Places server in SHUTDOWN state.
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    virtual void shutdown() = 0;
-
-    /// Stop job scheduling *AND*  task communication with server. Failed task request are logged
-    /// Hence nodes can be stuck in submitted/active states.
-    /// Task based command will continue attempting, communication with the server for up to 24hrs.
-    ///
-    /// When the server is halted, we do *NOT* do any further check pointing
-    /// In a typical operational scenario where we have a home, and backup servers.
-    /// The checkpoint file is copied to the backup servers periodically (via a task)
-    /// hence we want to preserve the state of the last checkpoint. By prevent any state
-    /// changes to the node tree.
-    ///
-    /// Hence halted(), will completely stop the server. Server will only respond
-    /// to user requests. (tasks requests are blocked)
-    /// Places server in HALTED state.
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    virtual void halted() = 0;
-
-    /// Start scheduling tasks and respond to all requests. Check pointing is enabled
-    /// Places server in RUNNING state.
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    virtual void restart() = 0;
-
-    /// Ask the server to reload file the hold list of users and their access rights
-    /// The white list file is specified by the environment variable ECF_LISTS
-    /// This allows/disallows user access on the live server
-    /// Return true if file is reloaded ok, else false and error message if:
-    /// 	a/ File does not exist
-    ///  	b/ File is empty
-    ///  	c/ Errors in parsing file
-    /// If errors arise the exist user still stay in affect
-    virtual bool reloadWhiteListFile(std::string& errorMsg) = 0;
-
-    virtual bool reloadPasswdFile(std::string& errorMsg)       = 0;
-    virtual bool reloadCustomPasswdFile(std::string& errorMsg) = 0;
-
-    /// There are several kinds of authentications:
-    ///     a/ None
-    ///     b/ List mode.   ASCII file based on ECF_LISTS is defined. referred as white list file
-    ///     c/ Secure mode. ASCII file based ECF_PASSWD is defined. Referred to as black list file
-    //
-    /// Returns true if the given user has access to the server, false otherwise
-    virtual bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) = 0;
-    virtual bool authenticateReadAccess(const std::string& user,
-                                        bool custom_user,
-                                        const std::string& passwd,
-                                        const std::string& path)                                              = 0;
-    virtual bool authenticateReadAccess(const std::string& user,
-                                        bool custom_user,
-                                        const std::string& passwd,
-                                        const std::vector<std::string>& paths)                                = 0;
-
-    /// Returns true if user has matching write access privileges.
-    virtual bool authenticateWriteAccess(const std::string& user)                                        = 0;
-    virtual bool authenticateWriteAccess(const std::string& user, const std::string& path)               = 0;
-    virtual bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) = 0;
-
-    /// Shutdown the server and let 'user' has have exclusive lock on it.
-    /// If the lock succeeds return true, (This will end up calling the shutdown()
-    /// command on the server). If already locked does nothing and return's false
-    virtual bool lock(const std::string& user) = 0;
-
-    /// Unlock's the server., and restarts job scheduling
-    virtual void unlock() = 0;
-
-    /// Return the user that has exclusive lock, else an empty string
-    virtual const std::string& lockedUser() const = 0;
-
-    /// Return Controller for zombies
-    ZombieCtrl& zombie_ctrl() { return zombie_ctrl_; }
-
-    /// returns the statistical class
-    Stats& stats() { return stats_; }
-
-    /// Call to update the number of request, & returns stats
-    Stats& update_stats() {
-        stats_.update();
-        return stats_;
-    }
-
-    /// Update for number of requests per second
-    void update_stats(int poll_interval) { stats_.update_stats(poll_interval); }
-
-    // Instead of immediate node tree traversal at the end of child command
-    // we use 'increment_job_generation_count' to defer job generation to server
-    // The server will check job generation count at poll time.
-    // This approach radically reduces the number of times we traverse the node tree
-    // and hence improves server throughput.
-    void increment_job_generation_count() { job_gen_count_++; }
-    void reset_job_generation_count() { job_gen_count_ = 0; }
-    int get_job_generation_count() const { return job_gen_count_; }
-
-    /// This job generation is special, in that it will time out, job generation time >= next poll.
-    /// This can be called at the end of a *USER* command(force,alter,requeue,etc), hence time_now may be >=
-    /// next_poll_time If this is the case, we will defer job generation
-    virtual void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
-                                                     bool user_cmd_context) const = 0;
-
-    /// returns the number of seconds at which we should check time dependencies
-    /// this includes evaluating trigger dependencies and submit the corresponding jobs.
-    /// This is set at 60 seconds. But will vary for debug/test purposes only.
-    /// For Testing the state change queued->submitted->active duration < submitJobsInterval
-    /// If this state change happens at the job submission boundary then
-    /// time series can get a skew.
-    virtual int poll_interval() const = 0;
-
-    /// enable and disable debug output from the server
-    virtual void debug_server_on()  = 0;
-    virtual void debug_server_off() = 0;
-    virtual bool debug() const      = 0;
-
-protected:
-    AbstractServer() = default;
-
-private:
-    ZombieCtrl zombie_ctrl_;
-    Stats stats_;
-    int job_gen_count_{0};
-};
-
-#endif /* ecflow_base_AbstractServer_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/Client.cpp 5.13.0-1/Base/src/ecflow/base/Client.cpp
--- 5.12.4-1/Base/src/ecflow/base/Client.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Client.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,353 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/Client.hpp"
-
-#include <iostream>
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/base/stc/StcCmd.hpp"
-
-#ifdef DEBUG_PERF
-    #include "ecflow/core/DebugPerf.hpp"
-#endif
-
-// #define DEBUG_CLIENT 1;
-#ifdef DEBUG_CLIENT
-    #include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
-#endif
-
-/// The timeout will typically happen when the server has died, but socket is still open
-/// If we do not have a timeout, it will hang indefinitely
-
-/// Constructor starts the asynchronous connect operation.
-Client::Client(boost::asio::io_service& io_service,
-               Cmd_ptr cmd_ptr,
-               const std::string& host,
-               const std::string& port,
-               int timeout)
-    : stopped_(false),
-      host_(host),
-      port_(port),
-      connection_(io_service),
-      deadline_(io_service),
-      timeout_(timeout) {
-    /// Avoid sending a NULL request to the server
-    if (!cmd_ptr.get())
-        throw std::runtime_error("Client::Client: No request specified !");
-
-    // The timeout can be set externally for testing, however when its not set the timeout is obtained from the command
-    // Vary the timeout, according to the command, hence loading the definition has longer timeout than ping
-    if (0 == timeout_) {
-        timeout_ = cmd_ptr->timeout();
-    }
-
-#ifdef DEBUG_CLIENT
-    std::cout << "   Client::Client() timeout(" << timeout_ << ") " << host_ << ":" << port_ << " ";
-    cmd_ptr->print(std::cout);
-    std::cout << std::endl;
-#endif
-
-    outbound_request_.set_cmd(cmd_ptr);
-
-    // Host name resolution is performed using a resolver, where host and service
-    // names(or ports) are looked up and converted into one or more end points
-    boost::asio::ip::tcp::resolver resolver(io_service);
-    boost::asio::ip::tcp::resolver::query query(host_, port_);
-    boost::asio::ip::tcp::resolver::iterator endpoint_iterator = resolver.resolve(query);
-
-    // The list of end points obtained could contain both IPv4 and IPv6 end points,
-    // so a program may try each of them until it finds one that works.
-    // This keeps the Client program independent of a specific IP version.
-    start(endpoint_iterator);
-}
-
-Client::~Client() {
-#ifdef DEBUG_CLIENT
-    std::cout << "   Client::~Client(): connection_.socket().is_open()=" << connection_.socket().is_open() << std::endl;
-#endif
-}
-
-/// Private ==============================================================================
-
-// This function terminates all the actors to shut down the connection. It
-// may be called by the user of the client class, or by the class itself in
-// response to graceful termination or an unrecoverable error.
-void Client::start(boost::asio::ip::tcp::resolver::iterator endpoint_iter) {
-    // Start the connect actor.
-    start_connect(endpoint_iter);
-
-    // Start the deadline actor. You will note that we're not setting any
-    // particular deadline here. Instead, the connect and input actors will
-    // update the deadline prior to each asynchronous operation.
-    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
-}
-
-bool Client::start_connect(boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
-    if (endpoint_iterator != boost::asio::ip::tcp::resolver::iterator()) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   Client::start_connect: Trying " << endpoint_iterator->endpoint() << "..." << std::endl;
-#endif
-
-        // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that
-        // were cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or
-        // will soon be executed. If it returns 1 then the wait handler was successfully cancelled.
-
-        // Set a deadline for the connect operation.
-        deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
-
-        boost::asio::ip::tcp::endpoint endpoint = *endpoint_iterator;
-        connection_.socket_ll().async_connect(endpoint,
-                                              [this, endpoint_iterator](const boost::system::error_code& error) {
-                                                  this->handle_connect(error, endpoint_iterator);
-                                              });
-    }
-    else {
-        // ran out of end points
-        return false;
-    }
-    return true;
-}
-
-void Client::handle_connect(const boost::system::error_code& e,
-                            boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
-#ifdef DEBUG_CLIENT
-    std::cout << "   Client::handle_connect stopped_=" << stopped_ << std::endl;
-#endif
-
-    if (stopped_)
-        return;
-
-    // The async_connect() function automatically opens the socket at the start
-    // of the asynchronous operation. If the socket is closed at this time then
-    // the timeout handler must have run first.
-    if (!connection_.socket_ll().is_open()) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   Client::handle_connect: *Connect timeout*:  Trying next end point" << std::endl;
-#endif
-        // Try the next available end point.
-        if (!start_connect(++endpoint_iterator)) {
-            // Ran out of end points, An error occurred
-            stop();
-            std::stringstream ss;
-            if (e)
-                ss << "Client::handle_connect: Ran out of end points : connection error( " << e.message()
-                   << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
-            else
-                ss << "Client::handle_connect: Ran out of end points : connection error for request( "
-                   << outbound_request_ << " ) on " << host_ << ":" << port_;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else if (e) {
-
-#ifdef DEBUG_CLIENT
-        std::cout << "   Client::handle_connect Connect error: " << e.message() << " . Trying next end point"
-                  << std::endl;
-#endif
-
-        // Some kind of error. We need to close the socket used in the previous connection attempt
-        // before starting a new one.
-        connection_.socket_ll().close();
-
-        // Try the next end point.
-        if (!start_connect(++endpoint_iterator)) {
-            // Ran out of end points. An error occurred.
-            stop();
-            std::stringstream ss;
-            ss << "Client::handle_connect: Ran out of end points: connection error( " << e.message()
-               << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else {
-#ifdef DEBUG_CLIENT
-        std::cout << "   Client::handle_connect **Successfully** established connection to the server: Sending Out "
-                     "bound request = "
-                  << outbound_request_ << std::endl;
-#endif
-
-        // **Successfully** established connection to the server
-        // Start operation to *SEND* a request to the server
-        start_write();
-    }
-}
-
-void Client::start_write() {
-    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
-    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
-    // executed. If it returns 1 then the wait handler was successfully cancelled.
-
-    // Set a deadline for the write operation.
-    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
-
-    connection_.async_write(outbound_request_,
-                            [this](const boost::system::error_code& error) { this->handle_write(error); });
-}
-
-void Client::handle_write(const boost::system::error_code& e) {
-#ifdef DEBUG_CLIENT
-    std::cout << "   Client::handle_write stopped_ = " << stopped_ << std::endl;
-#endif
-    if (stopped_)
-        return;
-
-    if (!e) {
-
-#ifdef DEBUG_CLIENT
-        std::cout << "   Client::handle_write OK: Check for server reply" << std::endl;
-#endif
-        // Check to see if the server was happy with our request.
-        // If all is OK, the server may choose not to reply(cuts down on network traffic)
-        // In which case handle_read will get a End of File error.
-        start_read();
-    }
-    else {
-
-        // An error occurred.
-        stop();
-
-        std::stringstream ss;
-        ss << "Client::handle_write: error (" << e.message() << " ) for request( " << outbound_request_ << " ) on "
-           << host_ << ":" << port_;
-        throw std::runtime_error(ss.str());
-    }
-
-    // Nothing to do. The socket will be closed automatically when the last
-    // reference to the connection object goes away.
-}
-
-void Client::start_read() {
-    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
-    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
-    // executed. If it returns 1 then the wait handler was successfully cancelled.
-
-    // Set a deadline for the read operation.
-    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
-
-    connection_.async_read(inbound_response_,
-                           [this](const boost::system::error_code& error) { this->handle_read(error); });
-}
-
-void Client::handle_read(const boost::system::error_code& e) {
-#ifdef DEBUG_CLIENT
-    std::cout << "   Client::handle_read stopped_ = " << stopped_ << std::endl;
-#endif
-    if (stopped_)
-        return;
-
-    // close socket, & cancel timer.
-    stop();
-
-    if (!e) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   Client::handle_read OK \n";
-        std::cout << "      outbound_request_ = " << outbound_request_ << "\n";
-        std::cout << "      inbound_response_ = " << inbound_response_ << "\n";
-#endif
-        /// ***********************************************************
-        /// ClientInvoker will call back, to handle_server_response.
-        /// ***********************************************************
-        // Successfully handled request
-    }
-    else {
-        //
-        // A connection error occurred. EOF
-        //   - In cases where ( to cut down network traffic),
-        //     the server does a shutdown/closes the socket without replying we will get End of File error.
-        //   - if we have a NONSSL client talking to SSL server, the SSL server will not reply, we will get End of File
-        //   error.
-        //
-        // i.e. client requests a response from the server, and it does not reply(or replies with shutdown/close)
-        // In both cases we will treat as an error
-
-        if (e.value() == boost::asio::error::eof) {
-#ifdef DEBUG_CLIENT
-            std::cout << "   Client::handle_read: End of File (server did not reply or mixing ssl and non-ssl)"
-                      << std::endl;
-#endif
-            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::END_OF_FILE));
-            return;
-        }
-
-        // If we get back Invalid argument. It means server could *NOT* decode client message. Equally client could not
-        // decode server reply
-        //   - Could be boost version of client/server are incompatible
-        //   - 4 series ecflow cannot talk to 5 series ecflow or vice versa
-        // We treat this specially
-        if (e.value() == boost::asio::error::invalid_argument) {
-#ifdef DEBUG_CLIENT
-            std::cout
-                << "   Client::handle_read: Server replied with invalid argument (i.e could not decode client message) "
-                << std::endl;
-#endif
-            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::INVALID_ARGUMENT));
-            return;
-        }
-
-        std::stringstream ss;
-        ss << "Client::handle_read: connection error( " << e.message() << " ) for request( " << outbound_request_
-           << " ) on " << host_ << ":" << port_;
-        throw std::runtime_error(ss.str());
-    }
-
-    // Since we are not starting a new operation the io_service will run out of
-    // work to do and the Client will exit.
-}
-
-void Client::stop() {
-    stopped_ = true;
-    connection_.socket_ll().close();
-    deadline_.cancel();
-}
-
-/// Handle completion of a write operation.
-/// Handle completion of a read operation.
-bool Client::handle_server_response(ServerReply& server_reply, bool debug) const {
-#ifdef DEBUG_PERF
-    ecf::ScopedDurationTimer timer("  Client::handle_server_response");
-#endif
-    if (debug)
-        std::cout << "  Client::handle_server_response" << std::endl;
-    server_reply.set_host_port(host_, port_); // client context, needed by some commands, ie. SServerLoadCmd
-    return inbound_response_.handle_server_response(server_reply, outbound_request_.get_cmd(), debug);
-}
-
-void Client::check_deadline() {
-#ifdef DEBUG_CLIENT
-    std::cout << "   Client::check_deadline stopped_=" << stopped_ << " expires("
-              << to_simple_string(deadline_.expires_at()) << ") time now("
-              << to_simple_string(boost::asio::deadline_timer::traits_type::now()) << ")" << std::endl;
-#endif
-    if (stopped_)
-        return;
-
-    // Check whether the deadline has passed. We compare the deadline against
-    // the current time since a new asynchronous operation may have moved the
-    // deadline before this actor had a chance to run.
-    if (deadline_.expires_at() <= boost::asio::deadline_timer::traits_type::now()) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   Client::check_deadline timed out" << std::endl;
-#endif
-
-        // The deadline has passed. The socket is closed so that any outstanding
-        // asynchronous operations are cancelled.
-        stop();
-
-        std::stringstream ss;
-        ss << "Client::check_deadline: timed out after " << timeout_ << " seconds for request( " << outbound_request_
-           << " ) on " << host_ << ":" << port_;
-        throw std::runtime_error(ss.str());
-    }
-
-    // Put the actor back to sleep.
-    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/Client.hpp 5.13.0-1/Base/src/ecflow/base/Client.hpp
--- 5.12.4-1/Base/src/ecflow/base/Client.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Client.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,78 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_Client_HPP
-#define ecflow_base_Client_HPP
-
-#include <boost/asio.hpp>
-
-#include "ecflow/base/ClientToServerRequest.hpp"
-#include "ecflow/base/Connection.hpp"
-#include "ecflow/base/ServerToClientResponse.hpp"
-
-///
-/// \brief  This class acts as the client part. ( in client/server architecture)
-///
-/// \note The plug command can move a node to another server hence the server
-/// itself will NEED to ACT as a client. This is why client lives in Base and
-/// not the Client project
-///
-
-class Client {
-public:
-    /// Constructor starts the asynchronous connect operation.
-    Client(boost::asio::io_service& io_service,
-           Cmd_ptr cmd_ptr,
-           const std::string& host,
-           const std::string& port,
-           int timout = 0);
-    ~Client();
-
-    /// Client side, get the server response, handles reply from server
-    /// Returns true if all is ok, else false if further client action is required
-    /// will throw std::runtime_error for errors
-    bool handle_server_response(ServerReply&, bool debug) const;
-
-private:
-    void start(boost::asio::ip::tcp::resolver::iterator);
-    void stop();
-    void check_deadline();
-
-    bool start_connect(boost::asio::ip::tcp::resolver::iterator);
-    void start_write();
-    void start_read();
-
-    /// Handle completion of a connect operation.
-    void handle_connect(const boost::system::error_code& e, boost::asio::ip::tcp::resolver::iterator endpoint_iterator);
-
-    /// Handle completion of a read operation.
-    void handle_read(const boost::system::error_code& e);
-
-    /// Handle completion of a write operation
-    void handle_write(const boost::system::error_code& e);
-
-private:
-    bool stopped_;
-    std::string host_;                        /// the servers name
-    std::string port_;                        /// the port on the server
-    connection connection_;                   /// The connection to the server.
-    ClientToServerRequest outbound_request_;  /// The request we will send to the server
-    ServerToClientResponse inbound_response_; /// The response we get back from the server
-
-    boost::asio::deadline_timer deadline_;
-
-    //    connect        : timeout_ second
-    //    send request   : timeout_ second
-    //    receive reply  : timeout_ second
-    // Default value of 0 means take the timeout from the command
-    int timeout_;
-};
-
-#endif /* ecflow_base_Client_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/ClientOptionsParser.cpp 5.13.0-1/Base/src/ecflow/base/ClientOptionsParser.cpp
--- 5.12.4-1/Base/src/ecflow/base/ClientOptionsParser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ClientOptionsParser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,207 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/ClientOptionsParser.hpp"
-
-#include "ecflow/core/Str.hpp"
-
-namespace ecf {
-
-namespace {
-
-bool is_valid_path(const std::string& path) {
-    return !path.empty() && path[0] == '/';
-}
-
-void parse_option(ClientOptionsParser::option_t& option,
-                  ClientOptionsParser::option_set_t& processed_options,
-                  ClientOptionsParser::arguments_set_t& args) {
-    // We must consider two forms of options:
-    //     1) --<option> <arg1>
-    //     2) --<option>=<arg1>
-
-    if (auto found = args[0].find('='); found == std::string::npos) {
-        // In case form 1) is used, we discard the '--<option>'
-        args.erase(args.begin());
-        if (args.empty()) {
-            // This means that the option doesn't actually have a value (i.e. acts as a flag) and we simply return
-            return;
-        }
-        // store the 'arg1'
-        option.value.push_back(args.front());
-        option.original_tokens.push_back(args.front());
-    }
-    else {
-        // Otherwise, form 2) is used, and the first positional value must be
-        // taken by tokenizing the option '--<option>=<arg1>'
-        std::string arg = args[0].substr(found + 1);
-        option.value.push_back(arg);
-        option.original_tokens.push_back(arg);
-    }
-    // Discard the option at the front
-    args.erase(args.begin());
-}
-
-template <typename PREDICATE>
-void parse_positional_arguments(
-    ClientOptionsParser::option_t& option,
-    ClientOptionsParser::option_set_t& processed_options,
-    ClientOptionsParser::arguments_set_t& args,
-    size_t maximum_positional_args,
-    PREDICATE predicate = [](const std::string&) { return true; }) {
-
-    // Collect up to N positional arguments, that satisfy the predicate
-    for (size_t i = 0; i < maximum_positional_args && !args.empty(); ++i) {
-        // Take each of the positional values as an option value
-        std::string& arg = args.front();
-        // Once we find the first argument that doesn't satify the predicate,
-        // we stop collecting arguments
-        if (!predicate(arg)) {
-            break;
-        }
-        option.value.push_back(arg);
-        option.original_tokens.push_back(arg);
-
-        // Remove the argument value
-        args.erase(args.begin());
-    }
-}
-
-void parse_positional_arguments(ClientOptionsParser::option_t& option,
-                                ClientOptionsParser::option_set_t& processed_options,
-                                ClientOptionsParser::arguments_set_t& args,
-                                size_t maximum_positional_args) {
-
-    // Collect up to N positional arguments
-    parse_positional_arguments(
-        option, processed_options, args, maximum_positional_args, [](const std::string&) { return true; });
-}
-
-void parse_alter(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
-
-    // *** Important! ***
-    // This custom handler is needed to ensure that the "--alter" option
-    // special value parameters are handled correctly. For example,
-    // values starting with --, such as "--hello".
-    //
-    // The custom handling will consider that 5+ positional values (not
-    // to be confused with positional arguments) are provided with the
-    // --alter option, as per one of the following forms:
-    //     1) --alter arg1 arg2 arg3 (arg4) path [path [path [...]]]
-    //     2) --alter=arg1 arg2 arg3 (arg4) path [path [path [...]]]
-
-    ClientOptionsParser::option_t alter{std::string{"alter"}, {}};
-
-    // This effectively always collects an argument (i.e. the operation)
-    parse_option(alter, processed_options, args);
-
-    // Collect up to 4 positional arguments, that are not paths
-    parse_positional_arguments(
-        alter, processed_options, args, 4, [](const std::string& arg) { return !is_valid_path(arg); });
-
-    // Collect remaining positional arguments, that are paths
-    parse_positional_arguments(
-        alter, processed_options, args, std::numeric_limits<size_t>::max(), [](const std::string& arg) {
-            return is_valid_path(arg);
-        });
-
-    processed_options.push_back(alter);
-}
-
-void parse_label(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
-
-    // *** Important! ***
-    // This custom handler is needed to ensure that the "--label" option
-    // special value parameters are handled correctly. For example,
-    // values starting with -, such as "-j64".
-    //
-    // The custom handling will consider that 2 positional values (not
-    // to be confused with positional arguments) are provided with the
-    // --label option, as per one of the following forms:
-    //     1) --label arg1 arg2
-    //     2) --label=arg1 arg2
-
-    ClientOptionsParser::option_t label{std::string{"label"}, {}};
-
-    // This effectively always collects an argument (i.e. the label name)
-    parse_option(label, processed_options, args);
-
-    // Collect 1 positional argument (i.e. the label value)
-    parse_positional_arguments(label, processed_options, args, 1);
-
-    processed_options.push_back(label);
-}
-
-void parse_meter(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
-
-    // *** Important! ***
-    // This custom handler is needed to ensure that the "--meter" option
-    // special value parameters are handled correctly. For example,
-    // values starting with -, such as "-1".
-    //
-    // The custom handling will consider that 2 positional values (not
-    // to be confused with positional arguments) are provided with the
-    // --label option, as per one of the following forms:
-    //     1) --label arg1 arg2
-    //     2) --label=arg1 arg2
-
-    ClientOptionsParser::option_t meter{std::string{"meter"}, {}};
-
-    // This effectively always collects an argument (i.e. the meter name)
-    parse_option(meter, processed_options, args);
-
-    // Collect 1 positional argument (i.e. the meter value)
-    parse_positional_arguments(meter, processed_options, args, 1);
-
-    processed_options.push_back(meter);
-}
-
-void parse_abort(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
-
-    // *** Important! ***
-    // This custom handler is needed to ensure that the "--abort" option
-    // special value parameters are handled correctly. For example,
-    // values starting with -, such as "--some reason--".
-    //
-    // The custom handling will consider that 2 positional values (not
-    // to be confused with positional arguments) are provided with the
-    // --label option, as per one of the following forms:
-    //     1) --label arg1 arg2
-    //     2) --label=arg1 arg2
-
-    ClientOptionsParser::option_t abort{std::string{"abort"}, {}};
-
-    // This effectively always collects an argument (i.e. the reason text)
-    parse_option(abort, processed_options, args);
-
-    processed_options.push_back(abort);
-}
-
-} // namespace
-
-ClientOptionsParser::option_set_t ClientOptionsParser::operator()(ClientOptionsParser::arguments_set_t& args) {
-    option_set_t processed_options;
-
-    if (ecf::algorithm::starts_with(args[0], "--alter")) {
-        parse_alter(processed_options, args);
-    }
-    else if (ecf::algorithm::starts_with(args[0], "--label")) {
-        parse_label(processed_options, args);
-    }
-    else if (ecf::algorithm::starts_with(args[0], "--meter")) {
-        parse_meter(processed_options, args);
-    }
-    else if (ecf::algorithm::starts_with(args[0], "--abort")) {
-        parse_abort(processed_options, args);
-    }
-    return processed_options;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Base/src/ecflow/base/ClientOptionsParser.hpp 5.13.0-1/Base/src/ecflow/base/ClientOptionsParser.hpp
--- 5.12.4-1/Base/src/ecflow/base/ClientOptionsParser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ClientOptionsParser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_ClientOptionsParser_HPP
-#define ecflow_base_ClientOptionsParser_HPP
-
-#include <string>
-#include <vector>
-
-#include <boost/program_options.hpp>
-
-namespace ecf {
-
-struct ClientOptionsParser
-{
-    using option_t        = boost::program_options::option;
-    using option_set_t    = std::vector<option_t>;
-    using arguments_set_t = std::vector<std::string>;
-
-    option_set_t operator()(arguments_set_t& args);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_base_ClientOptionsParser_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/ClientToServerRequest.cpp 5.13.0-1/Base/src/ecflow/base/ClientToServerRequest.cpp
--- 5.12.4-1/Base/src/ecflow/base/ClientToServerRequest.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ClientToServerRequest.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/ClientToServerRequest.hpp"
-
-#include <stdexcept>
-
-using namespace std;
-
-STC_Cmd_ptr ClientToServerRequest::handleRequest(AbstractServer* as) const {
-    if (cmd_.get()) {
-        return cmd_->handleRequest(as);
-    }
-
-    /// means programming error somewhere
-    throw std::runtime_error("ClientToServerRequest::handleRequest: Cannot send a NULL request to the server !");
-}
-
-std::ostream& ClientToServerRequest::print(std::ostream& os) const {
-    if (cmd_.get()) {
-        os << cmd_->print_short(); // avoid printing hundreds of paths in the command
-        return os;
-    }
-    return os << "NULL request";
-}
-
-bool ClientToServerRequest::operator==(const ClientToServerRequest& rhs) const {
-    if (!cmd_.get() && !rhs.cmd_.get()) {
-        return true;
-    }
-    if (cmd_.get() && !rhs.cmd_.get()) {
-        return false;
-    }
-    if (!cmd_.get() && rhs.cmd_.get()) {
-        return false;
-    }
-    return (cmd_->equals(rhs.cmd_.get()));
-}
-
-std::ostream& operator<<(std::ostream& os, const ClientToServerRequest& d) {
-    return d.print(os);
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/ClientToServerRequest.hpp 5.13.0-1/Base/src/ecflow/base/ClientToServerRequest.hpp
--- 5.12.4-1/Base/src/ecflow/base/ClientToServerRequest.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ClientToServerRequest.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,61 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_ClientToServerRequest_HPP
-#define ecflow_base_ClientToServerRequest_HPP
-
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-
-// Base class for client to server requesting.
-// This class is used in the IPC messaging from  client to server.
-class ClientToServerRequest {
-public:
-    ClientToServerRequest()                             = default;
-    ClientToServerRequest(const ClientToServerRequest&) = delete;
-    ~ClientToServerRequest()                            = default;
-
-    ClientToServerRequest& operator=(const ClientToServerRequest&) = delete;
-
-    void set_cmd(const Cmd_ptr& cmd) {
-        cmd_ = cmd;
-        cmd_->setup_user_authentification();
-    }
-    Cmd_ptr get_cmd() const { return cmd_; }
-
-    /// This is called in the server only, to handle the quest.
-    STC_Cmd_ptr handleRequest(AbstractServer*) const;
-
-    std::ostream& print(std::ostream& os) const;
-
-    bool getRequest() const { return (cmd_.get()) ? cmd_->get_cmd() : false; }
-    bool terminateRequest() const { return (cmd_.get()) ? cmd_->terminate_cmd() : false; }
-    bool groupRequest() const { return (cmd_.get()) ? cmd_->group_cmd() : false; }
-
-    void cleanup() {
-        if (cmd_.get())
-            cmd_->cleanup();
-    } // reclaim memory *AFTER* command has run
-
-    /// Used by boost test, to verify persistence
-    bool operator==(const ClientToServerRequest& rhs) const;
-
-private:
-    Cmd_ptr cmd_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar) {
-        ar(CEREAL_NVP(cmd_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ClientToServerRequest& d);
-
-#endif /* ecflow_base_ClientToServerRequest_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/Cmd.hpp 5.13.0-1/Base/src/ecflow/base/Cmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/Cmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Cmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_Cmd_HPP
-#define ecflow_base_Cmd_HPP
-
-#include <memory>
-
-class ClientToServerCmd;
-class ServerToClientCmd;
-class ServerReply;
-
-typedef std::shared_ptr<ClientToServerCmd> Cmd_ptr;
-typedef std::shared_ptr<ServerToClientCmd> STC_Cmd_ptr;
-
-#endif /* ecflow_base_Cmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/Connection.cpp 5.13.0-1/Base/src/ecflow/base/Connection.cpp
--- 5.12.4-1/Base/src/ecflow/base/Connection.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Connection.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/Connection.hpp"
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Log.hpp"
-
-connection::~connection() {
-#ifdef DEBUG_CONNECTION
-    if (Ecf::server())
-        std::cout << "SERVER: Connection::~connection  socket_.is_open() = " << socket_.is_open() << "\n\n";
-    else
-        std::cout << "CLIENT: Connection::~connection  socket_.is_open() = " << socket_.is_open() << "\n\n";
-#endif
-}
-
-connection::connection(boost::asio::io_service& io_service) : socket_(io_service) {
-#ifdef DEBUG_CONNECTION
-    if (Ecf::server())
-        std::cout << "SERVER: Connection::connection\n";
-    else
-        std::cout << "CLIENT: Connection::connection\n";
-#endif
-}
-
-void connection::log_error(const char* msg) {
-    const char* in_context = ", in client";
-    if (Ecf::server())
-        in_context = ", in server";
-    ecf::LogToCout logToCout;
-    LOG(ecf::Log::ERR, msg << in_context);
-}
-
-void connection::log_archive_error(const char* msg, const std::exception& ae, const std::string& data) {
-    const char* in_context = ", in client";
-    if (Ecf::server())
-        in_context = ", in server";
-    ecf::LogToCout logToCout;
-    LOG(ecf::Log::ERR, msg << ae.what() << in_context << " data:\n" << data);
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/Connection.hpp 5.13.0-1/Base/src/ecflow/base/Connection.hpp
--- 5.12.4-1/Base/src/ecflow/base/Connection.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Connection.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,221 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_Connection_HPP
-#define ecflow_base_Connection_HPP
-
-///
-/// \brief Serves as the connection between client server
-///
-/// \note If you change this file then ssl_connection.hpp may also need changing
-///
-
-#if defined(HPUX)
-    #include <sys/select.h> // hp-ux uses pselect
-#endif
-
-#include <iomanip>
-#include <memory>
-#include <sstream>
-
-#include <boost/asio.hpp>
-
-#include "ecflow/core/Serialization.hpp"
-
-// #define DEBUG_CONNECTION 1
-#ifdef DEBUG_CONNECTION
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-/// The connection class provides serialisation primitives on top of a socket.
-/**
- * Each message sent using this class consists of:
- * @li An 8-byte header containing the length of the serialized data in
- * hexadecimal.
- * @li The serialized data.
- */
-class connection {
-public:
-    ~connection();
-
-    explicit connection(boost::asio::io_service& io_service);
-    boost::asio::ip::tcp::socket& socket() { return socket_; }
-    boost::asio::ip::tcp::socket& socket_ll() { return socket_; }
-
-    /// Asynchronously write a data structure to the socket.
-    template <typename T, typename Handler>
-    void async_write(const T& t, Handler handler) {
-
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: Connection::async_write\n";
-        else
-            std::cout << "CLIENT: Connection::async_write\n";
-        std::cout << "   Serialise the data first so we know how large it is\n";
-#endif
-        // Serialise the data first so we know how large it is.
-        try {
-            ecf::save_as_string(outbound_data_, t);
-        }
-        catch (const std::exception& ae) {
-            // Unable to decode data. Something went wrong, inform the caller.
-            log_archive_error("Connection::async_write, exception ", ae, outbound_data_);
-            boost::asio::post(socket_.get_executor(), [handler]() { handler(boost::asio::error::invalid_argument); });
-            return;
-        }
-
-#ifdef DEBUG_CONNECTION
-        std::cout << "   Format the header:\n";
-#endif
-        // Format the header.
-        std::ostringstream header_stream;
-        header_stream << std::setw(header_length) << std::hex << outbound_data_.size();
-        if (!header_stream || header_stream.str().size() != header_length) {
-            // Something went wrong, inform the caller.
-            log_error("Connection::async_write, could not format header");
-            boost::asio::post(socket_.get_executor(), [handler]() { handler(boost::asio::error::invalid_argument); });
-            return;
-        }
-        outbound_header_ = header_stream.str();
-
-#ifdef DEBUG_CONNECTION
-        std::cout << "   Write the HEADER and serialised DATA to the socket\n";
-        std::cout << "   outbound_header_.size(" << outbound_header_.size() << ")\n";
-        std::cout << "   outbound_header_:'" << outbound_header_ << "' # this is the size in hex\n";
-        std::cout << "   outbound_data_.size(" << outbound_data_.size() << ")\n";
-        std::cout << "   hdr+data:'" << outbound_header_ << outbound_data_ << "'\n";
-#endif
-        // Write the serialized data to the socket. We use "gather-write" to send
-        // both the header and the data in a single write operation.
-        std::vector<boost::asio::const_buffer> buffers;
-        buffers.reserve(2);
-        buffers.emplace_back(boost::asio::buffer(outbound_header_));
-        buffers.emplace_back(boost::asio::buffer(outbound_data_));
-        boost::asio::async_write(
-            socket_, buffers, [handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
-                handler(error);
-            });
-
-#ifdef DEBUG_CONNECTION
-        std::cout << "   END\n";
-#endif
-    }
-
-    /// Asynchronously read a data structure from the socket.
-    template <typename T, typename Handler>
-    void async_read(T& t, Handler handler) {
-
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: Connection::async_read\n";
-        else
-            std::cout << "CLIENT: Connection::async_read\n";
-#endif
-
-        // Issue a read operation to read exactly the number of bytes in a header
-        boost::asio::async_read(
-            socket_,
-            boost::asio::buffer(inbound_header_),
-            [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
-                this->handle_read_header(error, t, handler);
-            });
-    }
-
-private:
-    /// Handle a completed read of a message header.
-    template <typename T, typename Handler>
-    void handle_read_header(const boost::system::error_code& e, T& t, Handler handler) {
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: Connection::handle_read_header\n";
-        else
-            std::cout << "CLIENT: Connection::handle_read_header\n";
-        std::cout << "   header:'" << std::string(inbound_header_, header_length)
-                  << "'  # this size of payload in hex\n";
-#endif
-        if (e) {
-            handler(e);
-        }
-        else {
-            // Determine the length of the serialized data.
-            std::istringstream is(std::string(inbound_header_, header_length));
-            std::size_t inbound_data_size = 0;
-            if (!(is >> std::hex >> inbound_data_size)) {
-
-                // Header doesn't seem to be valid. Inform the caller.
-                std::string err =
-                    "Connection::handle_read_header: invalid header : " + std::string(inbound_header_, header_length);
-                log_error(err.c_str());
-                handler(boost::asio::error::invalid_argument);
-                return;
-            }
-
-            // Start an asynchronous call to receive the data.
-            inbound_data_.resize(inbound_data_size);
-            boost::asio::async_read(
-                socket_,
-                boost::asio::buffer(inbound_data_),
-                [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
-                    this->handle_read_data(error, t, handler);
-                });
-        }
-    }
-
-    /// Handle a completed read of message data.
-    template <typename T, typename Handler>
-    void handle_read_data(const boost::system::error_code& e, T& t, Handler handler) {
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: Connection::handle_read_data\n";
-        else
-            std::cout << "CLIENT: Connection::handle_read_data\n";
-#endif
-
-        if (e) {
-            handler(e);
-        }
-        else {
-            // Extract the data structure from the data just received.
-            std::string archive_data(&inbound_data_[0], inbound_data_.size());
-            try {
-#ifdef DEBUG_CONNECTION
-                std::cout << "   inbound_data_.size(" << inbound_data_.size() << ") typeid(" << typeid(t).name()
-                          << ")\n";
-                std::cout << "   '" << archive_data << "'\n";
-#endif
-                ecf::restore_from_string(archive_data, t);
-            }
-            catch (std::exception& e) {
-                log_archive_error("Connection::handle_read_data, Unable to decode data :", e, archive_data);
-                handler(boost::asio::error::invalid_argument);
-                return;
-            }
-
-            // Inform caller that data has been received ok.
-            handler(e);
-        }
-    }
-
-private:
-    static void log_error(const char* msg);
-    static void log_archive_error(const char* msg, const std::exception& ae, const std::string& data);
-
-private:
-    boost::asio::ip::tcp::socket socket_; /// The underlying socket.
-    std::string outbound_header_;         /// Holds an out-bound header.
-    std::string outbound_data_;           /// Holds the out-bound data.
-    enum { header_length = 8 };           /// The size of a fixed length header.
-    char inbound_header_[header_length];  /// Holds an in-bound header.
-    std::vector<char> inbound_data_;      /// Holds the in-bound data.
-};
-
-typedef std::shared_ptr<connection> connection_ptr;
-
-#endif /* ecflow_base_Connection_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/Gnuplot.cpp 5.13.0-1/Base/src/ecflow/base/Gnuplot.cpp
--- 5.12.4-1/Base/src/ecflow/base/Gnuplot.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Gnuplot.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,394 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/Gnuplot.hpp"
-
-#include <cassert>
-#include <iostream>
-#include <sstream>
-#include <stdexcept>
-#include <vector>
-
-#include <sys/stat.h> // for chmod
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/File_r.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/NodePath.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-Gnuplot::Gnuplot(const std::string& log_file,
-                 const std::string& host,
-                 const std::string& port,
-                 size_t no_of_suites_to_plot)
-    : log_file_(log_file),
-      host_(host),
-      port_(port),
-      no_of_suites_to_plot_(no_of_suites_to_plot) {
-    if (!fs::exists(log_file)) {
-        std::stringstream ss;
-        ss << "Gnuplot::Gnuplot: The log file " << log_file << " does not exist\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string path_to_gnuplot = File::which("gnuplot");
-    if (path_to_gnuplot.empty()) {
-        std::stringstream ss;
-        ss << "Gnuplot::Gnuplot: could not find gnuplot on $PATH.";
-        throw std::runtime_error(ss.str());
-    }
-}
-
-void Gnuplot::show_server_load() const {
-    std::string gnuplot_dat_file    = host_.prefix_host_and_port(port_, "gnuplot.dat");
-    std::string gnuplot_script_file = host_.prefix_host_and_port(port_, "gnuplot.script");
-
-    // The vector index is the order in which suites are found, this will be used to place the suite in the correct
-    // column
-    std::vector<SuiteLoad> suite_vec;
-    std::string gnuplot_file = create_gnuplot_file(suite_vec, gnuplot_dat_file);
-    std::string gnuplot_script =
-        create_gnuplot_script(gnuplot_file, suite_vec, no_of_suites_to_plot_, gnuplot_script_file);
-
-    // make the gnuplot_script file executable
-    if (chmod(gnuplot_script.c_str(), 0755) != 0) {
-        std::stringstream ss;
-        ss << "Gnuplot::show_server_load: Could not make gnu script file " << gnuplot_script
-           << "  executable by using chmod";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string execute_gnuplot = "gnuplot " + gnuplot_script;
-    ::system(execute_gnuplot.c_str());
-}
-
-std::string Gnuplot::create_gnuplot_file(std::vector<SuiteLoad>& suite_vec, const std::string& temp_file) const {
-    /// Will read the log file and create a new file that can be used as input to gnuplot
-    /// We will collate each request/cmd to the server made over a second.
-    /// There are two kinds of commands:
-    ///   o User Commands: these start with --
-    ///   o Child Command: these start with chd:
-    /// All child commands specify a path and hence suite, whereas for user commands this is optional
-    /// We will trap all use of paths, so that we can show which suites are contributing to the server load
-    /// This will be done for 4 suites
-    ///
-    /// Will convert: FROM:
-    ///   XXX:[HH:MM:SS D.M.YYYY] chd:init [+additional information]
-    ///   XXX:[HH:MM:SS D.M.YYYY] --begin  [+additional information]
-    /// -------------: TO:
-    ///    1         2         3             4              5            6        7       8         9       10
-    ///  HH:MM:SS D.M.YYYY request/sec  child_request  users_requests  suite_0 suite_1  suite_2  suite_3  suite_n
-
-    /// The log file can be massive > 50Mb
-    File_r log_file(log_file_);
-    if (!log_file.ok())
-        throw std::runtime_error("Gnuplot::prepare_for_gnuplot: Could not open log file " + log_file_);
-
-    /// Create a new file that can be used with gnuplot. This has to be column based
-    std::ofstream gnuplot_file(temp_file.c_str());
-    if (!gnuplot_file) {
-        throw std::runtime_error("Gnuplot::prepare_for_gnuplot: Could not open output file: " + temp_file);
-    }
-
-    gnuplot_file << "#time    date     total-request child user suite_0  suite_1 suite_2  suite_3  suite_n\n";
-
-    std::vector<std::string> new_time_stamp;
-    std::vector<std::string> old_time_stamp;
-    size_t child_requests_per_second   = 0;
-    size_t user_request_per_second     = 0;
-    unsigned int plot_data_line_number = 0;
-    string line;
-    while (log_file.good()) {
-        log_file.getline(line); // default delimiter is /n
-
-        // The log file format we are interested is :
-        // 0             1         2            3
-        // MSG:[HH:MM:SS D.M.YYYY] chd:fullname [path +additional information]
-        // MSG:[HH:MM:SS D.M.YYYY] --begin      [args | path(optional) ]    :<user>
-
-        /// We are only interested in Commands (i.e MSG:), and not state changes
-        if (line.empty())
-            continue;
-        if (line[0] != 'M')
-            continue;
-        std::string::size_type msg_pos = line.find("MSG:");
-        if (msg_pos != 0)
-            continue;
-
-        bool child_cmd = false;
-        bool user_cmd  = false;
-        if (line.find(Str::CHILD_CMD()) != std::string::npos)
-            child_cmd = true;
-        else if (line.find(Str::USER_CMD()) != std::string::npos)
-            user_cmd = true;
-        if (!child_cmd && !user_cmd)
-            continue;
-
-        new_time_stamp.clear();
-        {
-            /// MSG:[HH:MM:SS D.M.YYYY] chd:fullname [+additional information] ---> HH:MM:SS D.M.YYYY
-            /// EXTRACT the date
-            string::size_type first_open_bracket = line.find('[');
-            if (first_open_bracket == std::string::npos) {
-                std::cout << line << "\n";
-                assert(false);
-                continue;
-            }
-            line.erase(0, first_open_bracket + 1);
-
-            string::size_type first_closed_bracket = line.find(']');
-            if (first_closed_bracket == std::string::npos) {
-                std::cout << line << "\n";
-                assert(false);
-                continue;
-            }
-            std::string time_stamp = line.substr(0, first_closed_bracket);
-
-            Str::split(time_stamp, new_time_stamp);
-            if (new_time_stamp.size() != 2)
-                continue;
-
-            line.erase(0, first_closed_bracket + 1);
-        }
-
-        // Should be just left with " chd:<child command> " or " --<user command>, since we have remove time stamp
-        // #ifdef DEBUG
-        //       std::cout << line << "\n";
-        // #endif
-
-        if (old_time_stamp.empty()) {
-            if (child_cmd)
-                child_requests_per_second++;
-            else
-                user_request_per_second++;
-
-            // Extract path if any, to determine the suite most contributing to server load
-            size_t column_index   = 0;
-            bool suite_path_found = extract_suite_path(line, child_cmd, suite_vec, column_index);
-            if (suite_path_found)
-                assert(suite_vec[column_index].request_per_second_ <=
-                       (child_requests_per_second + user_request_per_second));
-        }
-        else if (old_time_stamp[0] == new_time_stamp[0]) { // HH:MM:SS == HH:MM:SS
-            if (child_cmd)
-                child_requests_per_second++;
-            else
-                user_request_per_second++;
-
-            size_t column_index   = 0;
-            bool suite_path_found = extract_suite_path(line, child_cmd, suite_vec, column_index);
-            if (suite_path_found)
-                assert(suite_vec[column_index].request_per_second_ <=
-                       (child_requests_per_second + user_request_per_second));
-        }
-        else {
-            /// Start of *NEW* time,
-            /// write the *OLD* time line should contain time date without []
-            ///    1         2         3             4              5            6        7      8       9       10
-            ///  HH:MM:SS D.M.YYYY total_request child_request  users_requests suite_0 suite_1 suite_2 suite_3 suite_n
-            plot_data_line_number++;
-            gnuplot_file << old_time_stamp[0] << " " << old_time_stamp[1] << " "
-                         << (child_requests_per_second + user_request_per_second) << " " << child_requests_per_second
-                         << " " << user_request_per_second << " ";
-            for (auto& i : suite_vec) {
-                gnuplot_file << i.request_per_second_ << " ";
-            }
-            gnuplot_file << "\n";
-
-            // clear request per second
-            child_requests_per_second = 0;
-            user_request_per_second   = 0;
-            for (auto& i : suite_vec) {
-                i.request_per_second_ = 0;
-            }
-
-            // start of *new* time
-            if (child_cmd)
-                child_requests_per_second++;
-            else
-                user_request_per_second++;
-
-            size_t column_index   = 0;
-            bool suite_path_found = extract_suite_path(line, child_cmd, suite_vec, column_index);
-            if (suite_path_found)
-                assert(suite_vec[column_index].request_per_second_ <=
-                       (child_requests_per_second + user_request_per_second));
-        }
-
-        old_time_stamp = new_time_stamp;
-    }
-
-    if (plot_data_line_number < 3) {
-        throw std::runtime_error("Gnuplot::prepare_for_gnuplot: Log file empty or not enough data for plot\n");
-    }
-    return temp_file;
-}
-
-std::string Gnuplot::create_gnuplot_script(const std::string& path_to_file,
-                                           const std::vector<SuiteLoad>& suite_vec,
-                                           size_t no_of_suites_to_plot,
-                                           const std::string& script) const {
-    /// Create the gnuplot script file for rendering the graph
-    std::ofstream gnuplot_script(script.c_str());
-    if (!gnuplot_script) {
-        throw std::runtime_error("Gnuplot::create_gnuplot_script: Could not open output file: " + script);
-    }
-
-    gnuplot_script << "set term png\n";
-    gnuplot_script << "set output \"" << host_.name() << "." << port_ << ".png\"\n";
-
-    gnuplot_script << "set autoscale                          # scale axes automatically\n";
-    gnuplot_script << "set xtic auto rotate                   # set xtics automatically\n";
-    gnuplot_script << "set ytic auto                          # set ytics automatically\n";
-    //   gnuplot_script << "set origin 0,0.08                      # offset y, so that rotated xtics don't truncate,
-    //   However cause title to disappear\n";
-    gnuplot_script << "set title \"Server request per second\"\n";
-    gnuplot_script << "set x2label \"time/min\" textcolor lt 3\n";
-    gnuplot_script << "set ylabel \"requests\"\n";
-    gnuplot_script << "set xdata time\n";
-    gnuplot_script << "set grid                             # show grid\n";
-    gnuplot_script << "set timefmt \"%H:%M:%S %d.%m.%Y\"\n";
-
-    // # LINE COLORS, STYLES
-    // # type 'test' to see the colors and point types available.
-    // # Differs from x11 to postscript
-    // # lt chooses a particular line type: -1=black 1=red 2=grn 3=blue 4=purple 5=aqua 6=brn 7=orange 8=light-brn
-    // # lt must be specified before pt for colored points
-    // # for postscipt -1=normal, 1=grey, 2=dashed, 3=hashed, 4=dot, 5=dot-dash
-    // # lw chooses a line width 1=normal, can use 0.8, 0.3, 1.5, 3, etc.
-    // # ls chooses a line style
-
-    ///    1         2         3             4              5            6        7       8         9       n
-    ///  HH:MM:SS D.M.YYYY total_request child_request  users_requests suite_0 suite_1  suite_2  suite_3  suite_n
-
-    // determine which suite columns to plot based on server load
-    std::vector<SuiteLoad> suite_vec_copy = suite_vec;
-
-    //   cout << "sort vector according to load\n";
-    std::sort(suite_vec_copy.begin(), suite_vec_copy.end(), [](const SuiteLoad& a, const SuiteLoad& b) {
-        return a.total_request_per_second_ > b.total_request_per_second_;
-    });
-    //   for(size_t i = 0; i < suite_vec_copy.size(); i++) {
-    //      cout << " " << suite_vec_copy[i].first << " " << suite_vec_copy[i].second << "\n";
-    //   }
-
-    //   cout << "get top loaded suites\n";
-    std::vector<std::string> suites;
-    for (size_t i = 0; i < suite_vec_copy.size() && i < no_of_suites_to_plot; i++) {
-        suites.push_back(suite_vec_copy[i].suite_name_);
-    }
-    //   std::copy(suites.begin(), suites.end(), std::ostream_iterator <std::string> (std::cout, "\n"));
-
-    //   cout << "now determine which columns the top suites belong to, **THIS** time <int> indicates column\n";
-    std::vector<std::pair<std::string, int>> ordered_suites;
-    for (size_t column = 0; column < suite_vec.size(); column++) {
-        for (auto& suite : suites) {
-            if (suite == suite_vec[column].suite_name_) {
-                ordered_suites.emplace_back(suite, column);
-            }
-        }
-    }
-    //   for(size_t i = 0; i < ordered_suites.size(); i++) {
-    //      cout << " " << ordered_suites[i].first << " " << ordered_suites[i].second << "\n";
-    //   }
-
-    gnuplot_script << "plot \"" << path_to_file << R"(" using 1:4 title "child" with lines, ")" << path_to_file
-                   << R"(" using 1:5 title "user" with lines, ")" << path_to_file
-                   << R"(" using 1:3 smooth bezier title "total-load" with lines lt 3)";
-    if (!ordered_suites.empty())
-        gnuplot_script << ",";
-    else
-        gnuplot_script << "\n";
-    for (size_t i = 0; i < ordered_suites.size(); i++) {
-        gnuplot_script << "\"" << path_to_file << "\" using 1:" << (6 + ordered_suites[i].second)
-                       << " smooth bezier title \"" << ordered_suites[i].first << "\" with lines";
-        if (i == ordered_suites.size() - 1)
-            gnuplot_script << "\n";
-        else
-            gnuplot_script << ",";
-    }
-
-    //   gnuplot_script << "pause -1 \"Hit any key to continue\"\n\n";
-
-    return script;
-}
-
-bool Gnuplot::extract_suite_path(const std::string& line,
-                                 bool child_cmd,
-                                 std::vector<SuiteLoad>& suite_vec,
-                                 size_t& column_index // 0 based
-) {
-    // line should either
-    //  chd:<childcommand> path
-    //  --<user command)   path<optional> :<user>
-    size_t forward_slash = line.find('/');
-    if (forward_slash != std::string::npos) {
-
-        std::string path;
-        if (child_cmd) {
-
-            // For labels ignore paths in the label part
-            // MSG:[14:55:04 17.10.2013] chd:label progress 'core/nodeattr/nodeAParser'
-            // /suite/build/cray/cray_gnu/build_release/test
-            if (line.find("chd:label") != std::string::npos) {
-                size_t last_tick = line.rfind("'");
-                if (last_tick != std::string::npos) {
-                    size_t the_forward_slash = line.find('/', last_tick);
-                    if (the_forward_slash != std::string::npos) {
-                        forward_slash = the_forward_slash;
-                    }
-                }
-            }
-            path = line.substr(forward_slash);
-        }
-        else {
-            // Ignore the --news command, they dont have a path, hence i.e to ignore line like:
-            //  MSG:[09:36:05 22.10.2013] --news=1 36506 6  :ma0 [server handle(36508,7) server(36508,7)
-            //                     : *Large* scale changes (new handle or suites added/removed) :NEWS]
-            //   the /removed was being interpreted as a suite
-            if (line.find("--news") != std::string::npos)
-                return false;
-        }
-
-        // find the space after the path
-        size_t space_pos = line.find(" ", forward_slash);
-        if (space_pos != std::string::npos && space_pos > forward_slash) {
-            path = line.substr(forward_slash, space_pos - forward_slash);
-        }
-
-        if (!path.empty()) {
-
-            std::vector<std::string> theNodeNames;
-            theNodeNames.reserve(4);
-            NodePath::split(path, theNodeNames);
-            if (!theNodeNames.empty()) {
-                for (size_t n = 0; n < suite_vec.size(); n++) {
-                    if (suite_vec[n].suite_name_ == theNodeNames[0]) {
-                        suite_vec[n].request_per_second_++;
-                        suite_vec[n].total_request_per_second_++;
-                        column_index = n;
-                        return true;
-                    }
-                }
-
-                suite_vec.emplace_back(theNodeNames[0]);
-                column_index = suite_vec.size() - 1;
-                return true;
-            }
-        }
-    }
-    return false;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Base/src/ecflow/base/Gnuplot.hpp 5.13.0-1/Base/src/ecflow/base/Gnuplot.hpp
--- 5.12.4-1/Base/src/ecflow/base/Gnuplot.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Gnuplot.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,81 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_Gnuplot_HPP
-#define ecflow_base_Gnuplot_HPP
-
-#include <string>
-#include <vector>
-
-#include "ecflow/core/Host.hpp"
-
-///
-/// \brief Encompasses functionality for plotting server load
-///
-
-namespace ecf {
-
-class Gnuplot {
-public:
-    Gnuplot()               = delete;
-    Gnuplot(const Gnuplot&) = delete;
-    Gnuplot(const std::string& log_file,
-            const std::string& host,
-            const std::string& port,
-            size_t no_of_suites_to_plot = 5);
-
-    Gnuplot& operator=(const Gnuplot&) = delete;
-
-    /// parse the log file and show gnuplot of server load
-    /// Include the suite most contributing to the load
-    /// generates two files
-    ///    o <host>.<port>.gnuplot.dat
-    ///    o <host>.<port>.gnuplot.script
-    void show_server_load() const;
-
-private:
-    std::string log_file_;
-    Host host_;
-    std::string port_;
-    size_t no_of_suites_to_plot_;
-
-private:
-    struct SuiteLoad
-    {
-        explicit SuiteLoad(const std::string& name)
-            : suite_name_(name),
-              request_per_second_(1),
-              total_request_per_second_(1) {}
-
-        std::string suite_name_;
-        size_t request_per_second_;
-        size_t total_request_per_second_;
-    };
-
-    /// Returns that path to file created by this function.
-    /// The create file is to be used by gnuplot to show the server load.
-    ///  Can throw exceptions
-    std::string create_gnuplot_file(std::vector<SuiteLoad>& suite_vec, const std::string& input_data) const;
-
-    /// returns the path to the gnuplot script
-    std::string create_gnuplot_script(const std::string& path_to_file,
-                                      const std::vector<SuiteLoad>& suite_vec,
-                                      size_t no_of_suites_to_plot,
-                                      const std::string& script) const;
-
-    static bool extract_suite_path(const std::string& line,
-                                   bool child_cmd,
-                                   std::vector<SuiteLoad>& suite_vec,
-                                   size_t& column_index // 0 based
-    );
-};
-} // namespace ecf
-
-#endif /* ecflow_base_Gnuplot_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/Openssl.cpp 5.13.0-1/Base/src/ecflow/base/Openssl.cpp
--- 5.12.4-1/Base/src/ecflow/base/Openssl.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Openssl.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,293 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/Openssl.hpp"
-
-#include <cassert>
-#include <cstdlib> // getenv
-#include <stdexcept>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-std::string Openssl::info() const {
-    if (ssl_ == "1")
-        return "1 : enabled : uses shared ssl certificates";
-    return ssl_ + " : enabled : uses server/port specific ssl certificates";
-}
-
-bool Openssl::enable_no_throw(std::string host, const std::string& port, const std::string& ecf_ssl_env) {
-    if (host == Str::LOCALHOST())
-        host = Host().name();
-
-    //   if (Ecf::server()) cout << "Openssl::enable(SERVER) ---> input host:" << host << " port:" << port << " ECF_SSL
-    //   = " << ecf_ssl_env << "\n"; else               cout << "Openssl::enable(CLIENT) ---> input host:" << host << "
-    //   port:" << port << " ECF_SSL = " << ecf_ssl_env << "\n";
-
-    if (ecf_ssl_env.empty() || ecf_ssl_env == "1") {
-        // LOOK for      $HOME/.ecflowrc/ssl/server.crt
-        // THEN LOOK for $HOME/.ecflowrc/ssl/<host>.<port>.crt
-        // Look for the certificate that HAVE to exist on both client and server. i.e Self signed certificate (CRT)
-        // Needed for testing, avoid <host>.<port>.crt when ports numbers are auto generated
-        ssl_ = "1";
-        if (!fs::exists(crt())) { // crt() uses ssl_
-
-            // More specific per server. But we take an extra hit on file access.
-            ssl_ = host;
-            ssl_ += ".";
-            ssl_ += port;
-            if (!fs::exists(crt())) { // crt() uses ssl_
-                ssl_.clear();
-                return false;
-            }
-        }
-    }
-    else {
-        ssl_ = host;
-        ssl_ += ".";
-        ssl_ += port;
-        if (!fs::exists(crt())) { // crt() uses ssl_
-            ssl_.clear();
-            return false;
-        }
-    }
-    // cout << "Openssl::enable input ssl_:'" << ssl_ << "'\n";
-    return true;
-}
-
-void Openssl::enable(std::string host, const std::string& port) {
-    if (host == Str::LOCALHOST())
-        host = Host().name();
-
-    if (!enable_no_throw(host, port)) {
-        std::stringstream ss;
-        ss << "Openssl::enable: Error: Expected to find the self signed certificate file(CRT) server.crt or " << host
-           << "." << port << ".crt in $HOME/.ecflowrc/ssl";
-        throw std::runtime_error(ss.str());
-    }
-}
-
-void Openssl::enable_if_defined(std::string host, const std::string& port) {
-    char* ecf_ssl = getenv("ECF_SSL");
-    if (ecf_ssl) {
-        std::string ecf_ssl_env = ecf_ssl;
-
-        if (host == Str::LOCALHOST())
-            host = Host().name();
-
-        if (!enable_no_throw(host, port, ecf_ssl_env)) {
-            std::stringstream ss;
-            if (ecf_ssl_env == "1") {
-                ss << "Openssl::enable: Error: Expected to find the self signed certificate file(CRT) server.crt *OR* "
-                   << host << "." << port << ".crt in $HOME/.ecflowrc/ssl when ECF_SSL=1";
-            }
-            else {
-                ss << "Openssl::enable: Error: Expected to find the self signed certificate file(CRT) " << host << "."
-                   << port << ".crt in $HOME/.ecflowrc/ssl when ECF_SSL=" << host << "." << port;
-            }
-            throw std::runtime_error(ss.str());
-        }
-    }
-}
-
-boost::asio::ssl::context& Openssl::context() {
-    assert(ssl_context_);
-    return *ssl_context_;
-}
-
-void Openssl::init_for_server() {
-    //   std::cout << " Openssl::init_for_server  host :" << host_ << "@" << port_ << "\n";
-    //   std::cout << " Openssl::init_for_server ssl_:'" << ssl_ << "'\n";
-    if (enabled()) {
-        check_server_certificates();
-
-        ssl_context_ = std::make_unique<boost::asio::ssl::context>(boost::asio::ssl::context::sslv23);
-        ssl_context_->set_options(boost::asio::ssl::context::default_workarounds | boost::asio::ssl::context::no_sslv2 |
-                                  boost::asio::ssl::context::single_dh_use);
-        // this must be done before loading any keys. as below
-        ssl_context_->set_password_callback(
-            [this](std::size_t size, boost::asio::ssl::context_base::password_purpose purpose) {
-                return this->get_password();
-            });
-        ssl_context_->use_certificate_chain_file(crt());
-        ssl_context_->use_private_key_file(key(), boost::asio::ssl::context::pem);
-        ssl_context_->use_tmp_dh_file(pem());
-    }
-}
-
-void Openssl::init_for_client() {
-    //   std::cout << " Openssl::init_for_client host :" << host_ << "@" << port_ << "\n";
-    if (!init_for_client_ && enabled()) {
-        init_for_client_ = true;
-
-        ssl_context_ = std::make_unique<boost::asio::ssl::context>(boost::asio::ssl::context::sslv23);
-        ssl_context_->load_verify_file(crt());
-    }
-}
-
-std::string Openssl::get_password() const {
-    // std::cout << "Openssl::get_password()\n";
-    std::string passwd_file = passwd();
-    if (fs::exists(passwd_file)) {
-        std::string contents;
-        if (ecf::File::open(passwd_file, contents)) {
-            // remove /n added by editor.
-            if (!contents.empty() && contents[contents.size() - 1] == '\n')
-                contents.erase(contents.begin() + contents.size() - 1);
-            // std::cout << "Server::get_password() passwd('" << contents << "')\n";
-            return contents;
-        }
-        else {
-            std::stringstream ss;
-            ss << "Server::get_password file " << passwd_file << " exists, but can't be opened (" << strerror(errno)
-               << ")";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    // std::cout << "Server::get_password() passwd('test')\n";
-    return "test";
-}
-
-std::string Openssl::certificates_dir() const {
-    std::string home_path = getenv("HOME");
-    home_path += "/.ecflowrc/ssl/";
-    return home_path;
-}
-
-std::string Openssl::pem() const {
-    std::string str = certificates_dir();
-    if (ssl_ == "1") {
-        // assume 2048-bit dh key, but accept 1024-bit for
-        // backwards-compatibility (note: openssl might
-        // not accept it, depending on the version used)
-        str += "dh2048.pem";
-
-        if (!fs::exists(str)) {
-            return certificates_dir() + "dh1024.pem";
-        }
-        return str;
-    }
-
-    str += ssl_;
-    str += ".pem";
-    return str;
-}
-
-std::string Openssl::crt() const {
-    std::string str = certificates_dir();
-    if (ssl_ == "1") {
-        str += "server.crt";
-        return str;
-    }
-    str += ssl_;
-    str += ".crt";
-    return str;
-}
-
-std::string Openssl::key() const {
-    std::string str = certificates_dir();
-    if (ssl_ == "1") {
-        str += "server.key";
-        return str;
-    }
-    str += ssl_;
-    str += ".key";
-    return str;
-}
-
-std::string Openssl::passwd() const {
-    std::string str = certificates_dir();
-    if (ssl_ == "1") {
-        str += "server.passwd";
-        return str;
-    }
-    str += ssl_;
-    str += ".passwd";
-    return str;
-}
-
-const char* Openssl::ssl_info() {
-    return "ecFlow client and server are SSL enabled. To use SSL choose between:\n"
-           "  1. export ECF_SSL=1              # search for server.crt otherwise <host>.<port>.crt\n"
-           "  2. export ECF_SSL=<host>.<port>  # Use server specific certificates <host>.<port>.***\n"
-           "  3. use --ssl           # argument on ecflow_client/ecflow_server, same as option 1.\n"
-           "                         # Typically ssl server can be started with ecflow_start.sh -s\n"
-           "  4. Client.enable_ssl() # for python client\n\n"
-           "ecFlow expects the certificates to be in directory $HOME/.ecflowrc/ssl\n"
-           "The certificates can be shared if you have multiple servers running on\n"
-           "the same machine. In this case use ECF_SSL=1, then\n"
-           "ecflow_server expects the following files in $HOME/.ecflowrc/ssl\n\n"
-           "   - dh2048.pem\n"
-           "   - server.crt\n"
-           "   - server.key\n"
-           "   - server.passwd (optional) if this exists it must contain the pass phrase used to create server.key\n\n"
-           "ecflow_client expects the following files in : $HOME/.ecflowrc/ssl\n\n"
-           "   - server.crt (this must be the same as server)\n\n"
-           "Alternatively you can have different setting for each server ECF_SSL=<host>.<port>\n"
-           "Then server expect files of the type:\n\n"
-           "   - <host>.<port>.pem\n"
-           "   - <host>.<port>.crt\n"
-           "   - <host>.<port>.key\n"
-           "   - <host>.<port>.passwd (optional)\n\n"
-           "and client expect files of the type:\n\n"
-           "   - <host>.<port>.crt  # as before this must be same as the server\n\n"
-           "The server/client will automatically check existence of both variants,\n"
-           "but will give preference to NON <host>.<port>.*** variants first, when ECF_SSL=1\n"
-           "The following steps, show you how to create the certificate files.\n"
-           "This may need to be adapted if you want to use <host>.<port>.***\n\n"
-           "- Generate a password protected private key. This will request a pass phrase.\n"
-           "  This key is a 1024 bit RSA key which is encrypted using Triple-DES and stored\n"
-           "  in a PEM format so that it is readable as ASCII text\n\n"
-           "     > openssl genrsa -des3 -out server.key 1024   # Password protected private key\n"
-           "- Additional security.\n"
-           "  If you want additional security, create a file called 'server.passwd' and add the pass phrase to the "
-           "file.\n"
-           "  Then set the file permission so that file is only readable by the server process.\n"
-           "  Or you can choose to remove password requirement. In that case we don't need server.passwd file.\n\n"
-           "     > cp server.key server.key.secure\n"
-           "     > openssl rsa -in server.key.secure -out server.key  # remove password requirement\n"
-           "- Sign certificate with private key (self signed certificate).Generate Certificate Signing Request(CSR).\n"
-           "  This will prompt with a number of questions.\n"
-           "  However please ensure 'common name' matches the host where your server is going to run.\n\n"
-           "     > openssl req -new -key server.key -out server.csr # Generate Certificate Signing Request(CSR)\n"
-           "- Generate a self signed certificate CRT, by using the CSR and private key.\n\n"
-           "     > openssl x509 -req -days 3650 -in server.csr -signkey server.key -out server.crt\n\n"
-           "- Generate dhparam file. ecFlow expects 2048 key.\n"
-           "     > openssl dhparam -out dh2048.pem 2048";
-}
-
-void Openssl::check_server_certificates() const {
-    //   cout << "Openssl::check_server_certificates: ssl'" << ssl_ << "'\n";
-
-    {
-        string server_key = key();
-        if (!fs::exists(server_key))
-            throw std::runtime_error("Error: The password protected private server key file '" + server_key +
-                                     "' does not exist\n\n" + ssl_info());
-    }
-    {
-        string server_pem = pem();
-        if (!fs::exists(server_pem))
-            throw std::runtime_error("Error: The dhparam file(pem) '" + server_pem + "' does not exist\n\n" +
-                                     ssl_info());
-    }
-}
-
-std::ostream& operator<<(std::ostream& os, const ecf::Openssl& ssl) {
-    ssl.print(os);
-    return os;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Base/src/ecflow/base/Openssl.hpp 5.13.0-1/Base/src/ecflow/base/Openssl.hpp
--- 5.12.4-1/Base/src/ecflow/base/Openssl.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Openssl.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,79 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_Openssl_HPP
-#define ecflow_base_Openssl_HPP
-
-#include <memory>
-#include <ostream>
-#include <string>
-
-#include <boost/asio/ssl.hpp>
-
-namespace ecf {
-
-class Openssl {
-public:
-    Openssl(const Openssl&)                  = delete;
-    const Openssl& operator=(const Openssl&) = delete;
-
-    /// There is no SSL protocol version named SSLv23.
-    /// The SSLv23_method() API and its variants choose SSLv2, SSLv3, or TLSv1 for compatibility with the peer
-    /// Consider the incompatibility among the SSL/TLS versions when you develop
-    /// SSL client/server applications. For example, a TLSv1 server cannot understand
-    /// a client-hello message from an SSLv2 or SSLv3 client.
-    /// The SSLv2 client/server recognises messages from only an SSLv2 peer.
-    /// The SSLv23_method() API and its variants may be used when the compatibility with the peer is important.
-    /// An SSL server with the SSLv23 method can understand any of the SSLv2, SSLv3, and TLSv1 hello messages.
-    /// However, the SSL client using the SSLv23 method cannot establish connection with the SSL server
-    ///  with the SSLv3/TLSv1 method because SSLv2 hello message is sent by the client
-    Openssl() = default;
-
-    const std::string& ssl() const { return ssl_; }
-    bool enabled() const { return !ssl_.empty(); }
-
-    bool enable_no_throw(std::string host,
-                         const std::string& port,
-                         const std::string& ecf_ssl_env = "");         // returns false if cannot enable
-    void enable(std::string host, const std::string& port);            // Can throw if certificate (CRT) are missing
-    void enable_if_defined(std::string host, const std::string& port); // Can throw if certificate (CRT) are missing
-    void disable() { ssl_.clear(); }                                   // override environment setting for ECF_SSL
-
-    void init_for_server();
-    void init_for_client();
-
-    boost::asio::ssl::context& context();
-
-    static const char* ssl_info();
-    void print(std::ostream& os) const { os << ssl_; }
-    std::string info() const;
-
-private:
-    void check_server_certificates() const;
-    void load_verify_file(boost::asio::ssl::context&); /// load server.crt file into the ssl context
-    std::string certificates_dir() const;              /// Directory where ssl certificates are held
-    std::string get_password() const;
-
-    std::string pem() const;
-    std::string crt() const;
-    std::string key() const;
-    std::string passwd() const;
-
-private:
-    std::string ssl_;                                        // Non empty if ssl has been enabled
-    std::unique_ptr<boost::asio::ssl::context> ssl_context_; // create on demand, otherwise non-ssl context takes a hit.
-    bool init_for_client_{false};
-};
-
-std::ostream& operator<<(std::ostream& os, const ecf::Openssl&);
-
-} // namespace ecf
-
-#endif /* ecflow_base_Openssl_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/ServerReply.cpp 5.13.0-1/Base/src/ecflow/base/ServerReply.cpp
--- 5.12.4-1/Base/src/ecflow/base/ServerReply.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ServerReply.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,34 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/ServerReply.hpp"
-
-/// *Note* server_reply_.client_handle_ is kept until the next call to register a new client_handle
-/// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-void ServerReply::clear_for_invoke(bool command_line_interface) {
-    // std::cout << "ServerReply::clear_for_invoke\n";
-    cli_                          = command_line_interface;
-    in_sync_                      = false;
-    full_sync_                    = false;
-    news_                         = ServerReply::NO_NEWS;
-    block_client_on_home_server_  = false;
-    block_client_server_halted_   = false;
-    block_client_zombie_detected_ = false;
-    invalid_argument_             = false;
-    eof_                          = false;
-    host_.clear();
-    port_.clear();
-    error_msg_.clear();
-    str_.clear();
-    zombies_.clear();
-    str_vec_.clear();
-    client_handle_suites_.clear();
-    changed_nodes_.clear();
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/ServerReply.hpp 5.13.0-1/Base/src/ecflow/base/ServerReply.hpp
--- 5.12.4-1/Base/src/ecflow/base/ServerReply.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ServerReply.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,155 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_ServerReply_HPP
-#define ecflow_base_ServerReply_HPP
-
-#include "ecflow/attribute/Zombie.hpp"
-#include "ecflow/base/Stats.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-/// This class is used to hold the replies back from the server
-/// *Note* server_reply_.client_handle_ is kept until the next call to register a new client_handle
-/// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-
-class ServerReply {
-public:
-    ServerReply(const ServerReply&)                  = delete;
-    const ServerReply& operator=(const ServerReply&) = delete;
-
-    enum News_t { NO_NEWS, NEWS, DO_FULL_SYNC };
-    ServerReply() = default;
-
-    /// *Note* server_reply_.client_handle_ is kept until the next call to register a new client_handle
-    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-    /// and reset everything else
-    void clear_for_invoke(bool command_line_interface); // true if calling from command line
-
-    /// task based replies
-    bool block_client_on_home_server() const { return block_client_on_home_server_; }
-    void set_block_client_on_home_server() { block_client_on_home_server_ = true; }
-
-    bool block_client_server_halted() const { return block_client_server_halted_; }
-    void set_block_client_server_halted() { block_client_server_halted_ = true; }
-
-    bool block_client_zombie_detected() const { return block_client_zombie_detected_; }
-    void set_block_client_zombie_detected() { block_client_zombie_detected_ = true; }
-
-    bool invalid_argument() const { return invalid_argument_; }
-    void set_invalid_argument() { invalid_argument_ = true; }
-
-    bool eof() const { return eof_; }
-    void set_eof() { eof_ = true; }
-
-    void set_host_port(const std::string& host, const std::string& port) {
-        host_ = host;
-        port_ = port;
-    }
-    const std::string& host() const { return host_; }
-    const std::string& port() const { return port_; }
-
-    bool client_request_failed() const { return !error_msg_.empty(); }
-    void set_error_msg(const std::string& e) { error_msg_ = e; }
-    const std::string& error_msg() const { return error_msg_; }
-    std::string& get_error_msg() { return error_msg_; }
-
-    const std::vector<Zombie>& zombies() const { return zombies_; }
-    void set_zombies(const std::vector<Zombie>& z) { zombies_ = z; }
-
-    /// For uses with the suites cmd, or any other command that needs a vector of strings form server
-    const std::vector<std::string>& get_string_vec() const { return str_vec_; }
-    void set_string_vec(const std::vector<std::string>& z) { str_vec_ = z; }
-
-    const std::vector<std::pair<unsigned int, std::vector<std::string>>>& get_client_handle_suites() const {
-        return client_handle_suites_;
-    }
-    void set_client_handle_suites(const std::vector<std::pair<unsigned int, std::vector<std::string>>>& s) {
-        client_handle_suites_ = s;
-    }
-
-    /// Only valid when the client requested the CFileCmd or log file from the server
-    /// Other times this will be empty.
-    const std::string& get_string() const { return str_; }
-    void set_string(const std::string& f) { str_ = f; }
-
-    /// Only valid when Stats command called.
-    const Stats& stats() const { return stats_; }
-    void set_stats(const Stats& s) { stats_ = s; }
-
-    /// Return true if client is using Command Level Interface. Set via clear_for_invoke()
-    bool cli() const { return cli_; }
-
-    /// Only valid after a call to sync()
-    /// in_sync() should be called after call to sync() Returns true if client defs is now in_sync with server
-    bool in_sync() const { return in_sync_; }
-    void set_sync(bool b) { in_sync_ = b; }
-
-    /// The SSyncCmd will set if we have a full sync(ie retrieved full node tree from server) or incremental sync
-    bool full_sync() const { return full_sync_; }
-    void set_full_sync(bool f) { full_sync_ = f; }
-
-    /// Only valid after a call to news()
-    /// return true if the server has changed
-    News_t get_news() const { return news_; }
-    void set_news(News_t n) { news_ = n; }
-
-    /// Only valid when the client requested the defs node tree from the server
-    /// The defs *WILL* be retained until the next call to get the server defs
-    /// **Hence is NOT reset in clear_for_invoke()
-    defs_ptr client_defs() const { return client_defs_; }
-    void set_client_defs(defs_ptr d) { client_defs_ = d; }
-
-    /// Only valid when the client requested the node from the server
-    /// The node *WILL* be retained until the next call to get the node
-    /// **Hence is NOT reset in clear_for_invoke()
-    node_ptr client_node() const { return client_node_; }
-    void set_client_node(node_ptr d) { client_node_ = d; }
-
-    /// A client handle of value 0 is not valid. Created in the server
-    /// We should keep a reference to the client handle, for use with client handle commands
-    /// **Hence is NOT reset in clear_for_invoke()
-    void set_client_handle(int handle) { client_handle_ = handle; }
-    int client_handle() const { return client_handle_; }
-
-    // During incremental sync, record list of changed nodes, used by python api
-    std::vector<std::string>& changed_nodes() { return changed_nodes_; }
-
-private:
-    friend class SSyncCmd;
-
-    std::string host_;                       // clear at the start of invoke
-    std::string port_;                       // clear at the start of invoke
-    std::string str_;                        // clear at the start of invoke
-    std::string error_msg_;                  // clear at the start of invoke
-    std::vector<Zombie> zombies_;            // clear at the start of invoke
-    std::vector<std::string> str_vec_;       // clear at the start of invoke
-    std::vector<std::string> changed_nodes_; // clear at the start of invoke
-    std::vector<std::pair<unsigned int, std::vector<std::string>>>
-        client_handle_suites_; // clear at the start of invoke
-    Stats stats_;              // Used for test only, ideally need to clear
-
-    defs_ptr client_defs_; // server reply stored as the client side defs, kept locally
-    node_ptr client_node_; // server reply stored as the client side node, kept locally
-
-    int client_handle_{0}; // set locally when suites are registered, and kept for reference
-    News_t news_{NO_NEWS}; // clear at the start of invoke
-
-    bool cli_{false};
-    bool in_sync_{false};                      // clear at the start of invoke
-    bool full_sync_{false};                    // clear at the start of invoke
-    bool block_client_on_home_server_{false};  // clear at the start of invoke
-    bool block_client_server_halted_{false};   // clear at the start of invoke
-    bool block_client_zombie_detected_{false}; // clear at the start of invoke
-    bool delete_all_{false};                   // clear at the start of invoke
-    bool invalid_argument_{false};             // clear at the start of invoke
-    bool eof_{false};                          // clear at the start of invoke
-};
-
-#endif /* ecflow_base_ServerReply_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/ServerToClientResponse.cpp 5.13.0-1/Base/src/ecflow/base/ServerToClientResponse.cpp
--- 5.12.4-1/Base/src/ecflow/base/ServerToClientResponse.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ServerToClientResponse.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/ServerToClientResponse.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/base/ClientToServerRequest.hpp" // for throw
-
-using namespace std;
-using namespace ecf;
-
-bool ServerToClientResponse::handle_server_response(ServerReply& r, Cmd_ptr cts_cmd, bool debug) const {
-    /// Called in client context: see ClientInvoker
-    if (stc_cmd_.get()) {
-        return stc_cmd_->handle_server_response(r, cts_cmd, debug);
-    }
-
-    /// ClientToServerRequest::handleRequest returned a NULL pointer stc_cmd_.
-    std::string ss;
-    ss += "ServerToClientResponse::handle_server_response: ";
-    if (cts_cmd.get()) {
-        ss += "Client request ";
-        ss += cts_cmd->print_short();
-        ss += " failed. ";
-    }
-    ss += "Server replied with a NULL message\n";
-    throw std::runtime_error(ss);
-}
-
-std::ostream& ServerToClientResponse::print(std::ostream& os) const {
-    if (stc_cmd_.get()) {
-        os << stc_cmd_->print();
-        return os;
-    }
-    return os << "NULL ServerToClientResponse";
-}
-
-bool ServerToClientResponse::operator==(const ServerToClientResponse& rhs) const {
-    if (!stc_cmd_.get() && !rhs.stc_cmd_.get()) {
-        return true;
-    }
-    if (stc_cmd_.get() && !rhs.stc_cmd_.get()) {
-        return false;
-    }
-    if (!stc_cmd_.get() && rhs.stc_cmd_.get()) {
-        return false;
-    }
-    return (stc_cmd_->equals(rhs.stc_cmd_.get()));
-}
-
-std::ostream& operator<<(std::ostream& os, const ServerToClientResponse& d) {
-    return d.print(os);
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/ServerToClientResponse.hpp 5.13.0-1/Base/src/ecflow/base/ServerToClientResponse.hpp
--- 5.12.4-1/Base/src/ecflow/base/ServerToClientResponse.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ServerToClientResponse.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_ServerToClientResponse_HPP
-#define ecflow_base_ServerToClientResponse_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-// Base class for server to client requesting. This class is used in the IPC messaging between
-// server and client
-class ServerToClientResponse {
-public:
-    ServerToClientResponse()                              = default;
-    ServerToClientResponse(const ServerToClientResponse&) = delete;
-    explicit ServerToClientResponse(const STC_Cmd_ptr& cmd) : stc_cmd_(cmd) {}
-    ~ServerToClientResponse() = default;
-
-    ServerToClientResponse& operator=(const ServerToClientResponse&) = delete;
-
-    STC_Cmd_ptr get_cmd() const { return stc_cmd_; }
-    void set_cmd(const STC_Cmd_ptr& cmd) { stc_cmd_ = cmd; }
-
-    std::ostream& print(std::ostream& os) const;
-
-    void cleanup() {
-        if (stc_cmd_.get())
-            stc_cmd_->cleanup();
-    } // reclaim memory *AFTER* command has run
-
-    /// Handle the response from the server. On the client side
-    /// return true IF and ONLY IF client response was ok, if further client action required return false
-    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const;
-
-    /// Used by boost test, to verify persistence
-    bool operator==(const ServerToClientResponse& rhs) const;
-
-private:
-    STC_Cmd_ptr stc_cmd_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar) {
-        ar(CEREAL_NVP(stc_cmd_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ServerToClientResponse& d);
-
-#endif /* ecflow_base_ServerToClientResponse_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/SslClient.cpp 5.13.0-1/Base/src/ecflow/base/SslClient.cpp
--- 5.12.4-1/Base/src/ecflow/base/SslClient.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/SslClient.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,382 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/SslClient.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/stc/ErrorCmd.hpp"
-#include "ecflow/base/stc/StcCmd.hpp"
-
-// #define DEBUG_CLIENT 1;
-
-#ifdef DEBUG_CLIENT
-    #include <iostream>
-
-    #include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
-#endif
-
-/// The timeout will typically happen when the server has died, but socket is still open
-/// If we do not have a timeout, it will hang indefinitely
-
-/// Constructor starts the asynchronous connect operation.
-SslClient::SslClient(boost::asio::io_service& io_service,
-                     boost::asio::ssl::context& context,
-                     Cmd_ptr cmd_ptr,
-                     const std::string& host,
-                     const std::string& port,
-                     int timeout)
-    : stopped_(false),
-      host_(host),
-      port_(port),
-      connection_(io_service, context),
-      deadline_(io_service),
-      timeout_(timeout) {
-    /// Avoid sending a NULL request to the server
-    if (!cmd_ptr.get())
-        throw std::runtime_error("SslClient::SslClient: No request specified !");
-
-    // The timeout can be set externally for testing, however when its not set the timeout is obtained from the command
-    // Vary the timeout, according to the command, hence loading the definition has longer timeout than ping
-    if (0 == timeout_) {
-        timeout_ = cmd_ptr->timeout();
-    }
-
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::SslClient() timeout(" << timeout_ << ") " << host_ << ":" << port_ << " ";
-    std::string output;
-    cmd_ptr->print(output);
-    std::cout << output << std::endl;
-#endif
-
-    outbound_request_.set_cmd(cmd_ptr);
-
-    // Host name resolution is performed using a resolver, where host and service
-    // names(or ports) are looked up and converted into one or more end points
-    boost::asio::ip::tcp::resolver resolver(io_service);
-    boost::asio::ip::tcp::resolver::query query(host_, port_);
-    boost::asio::ip::tcp::resolver::iterator endpoint_iterator = resolver.resolve(query);
-
-    // The list of end points obtained could contain both IPv4 and IPv6 end points,
-    // so a program may try each of them until it finds one that works.
-    // This keeps the SslClient program independent of a specific IP version.
-    start(endpoint_iterator);
-}
-
-SslClient::~SslClient() {
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::~SslClient(): connection_.socket().is_open()=" << connection_.socket_ll().is_open()
-              << std::endl;
-#endif
-}
-
-/// Private ==============================================================================
-
-// This function terminates all the actors to shut down the connection. It
-// may be called by the user of the client class, or by the class itself in
-// response to graceful termination or an unrecoverable error.
-void SslClient::start(boost::asio::ip::tcp::resolver::iterator endpoint_iter) {
-    // Start the connect actor.
-    start_connect(endpoint_iter);
-
-    // Start the deadline actor. You will note that we're not setting any
-    // particular deadline here. Instead, the connect and input actors will
-    // update the deadline prior to each asynchronous operation.
-    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
-}
-
-bool SslClient::start_connect(boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
-    if (endpoint_iterator != boost::asio::ip::tcp::resolver::iterator()) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   SslClient::start_connect: Trying " << endpoint_iterator->endpoint() << "..." << std::endl;
-#endif
-
-        // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that
-        // were cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or
-        // will soon be executed. If it returns 1 then the wait handler was successfully cancelled.
-
-        // Set a deadline for the connect operation.
-        deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
-
-        boost::asio::ip::tcp::endpoint endpoint = *endpoint_iterator;
-        connection_.socket_ll().async_connect(endpoint,
-                                              [this, endpoint_iterator](const boost::system::error_code& error) {
-                                                  this->handle_connect(error, endpoint_iterator);
-                                              });
-    }
-    else {
-        // ran out of end points
-        return false;
-    }
-    return true;
-}
-
-void SslClient::handle_connect(const boost::system::error_code& e,
-                               boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::handle_connect stopped_=" << stopped_ << std::endl;
-#endif
-
-    if (stopped_)
-        return;
-
-    // The async_connect() function automatically opens the socket at the start
-    // of the asynchronous operation. If the socket is closed at this time then
-    // the timeout handler must have run first.
-    if (!connection_.socket_ll().is_open()) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   SslClient::handle_connect: *Connect timeout*:  Trying next end point" << std::endl;
-#endif
-        // Try the next available end point.
-        if (!start_connect(++endpoint_iterator)) {
-            // Ran out of end points, An error occurred
-            stop();
-            std::stringstream ss;
-            if (e)
-                ss << "SslClient::handle_connect: Ran out of end points : connection error( " << e.message()
-                   << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
-            else
-                ss << "SslClient::handle_connect: Ran out of end points : connection error for request( "
-                   << outbound_request_ << " ) on " << host_ << ":" << port_;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else if (e) {
-
-#ifdef DEBUG_CLIENT
-        std::cout << "   SslClient::handle_connect Connect error: " << e.message() << " . Trying next end point"
-                  << std::endl;
-#endif
-
-        // Some kind of error. We need to close the socket used in the previous connection attempt
-        // before starting a new one.
-        connection_.socket_ll().close();
-
-        // Try the next end point.
-        if (!start_connect(++endpoint_iterator)) {
-            // Ran out of end points. An error occurred.
-            stop();
-            std::stringstream ss;
-            ss << "SslClient::handle_connect: Ran out of end points: connection error( " << e.message()
-               << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
-            throw std::runtime_error(ss.str());
-        }
-    }
-    else {
-#ifdef DEBUG_CLIENT
-        std::cout << "   SslClient::handle_connect **Successfully** established connection to the server: Sending Out "
-                     "bound request = "
-                  << outbound_request_ << std::endl;
-#endif
-
-        // **Successfully** established connection to the server
-        start_handshake();
-    }
-}
-
-void SslClient::start_handshake() {
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::start_handshake " << outbound_request_ << std::endl;
-#endif
-    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
-    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
-    // executed. If it returns 1 then the wait handler was successfully cancelled. Set a deadline for the write
-    // operation.
-    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
-
-    connection_.socket().async_handshake(boost::asio::ssl::stream_base::client,
-                                         [this](const boost::system::error_code& e) { handle_handshake(e); });
-}
-
-void SslClient::handle_handshake(const boost::system::error_code& e) {
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::handle_handshake " << std::endl;
-#endif
-    if (!e) {
-        start_write();
-    }
-    else {
-        // An error occurred.
-        stop();
-
-        std::stringstream ss;
-        ss << "SslClient::handle_handshake: error(" << e.message() << ") on " << host_ << ":" << port_
-           << " possibly non-ssl server";
-        inbound_response_.set_cmd(std::make_shared<ErrorCmd>(ss.str()));
-    }
-}
-
-void SslClient::start_write() {
-    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
-    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
-    // executed. If it returns 1 then the wait handler was successfully cancelled.
-
-    // Set a deadline for the write operation.
-    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
-
-    connection_.async_write(outbound_request_,
-                            [this](const boost::system::error_code& error) { this->handle_write(error); });
-}
-
-void SslClient::handle_write(const boost::system::error_code& e) {
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::handle_write stopped_ = " << stopped_ << std::endl;
-#endif
-    if (stopped_)
-        return;
-
-    if (!e) {
-
-#ifdef DEBUG_CLIENT
-        std::cout << "   SslClient::handle_write OK: Check for server reply" << std::endl;
-#endif
-        // Check to see if the server was happy with our request.
-        // If all is OK, the server may choose not to reply(cuts down on network traffic)
-        // In which case handle_read will get a End of File error.
-        start_read();
-    }
-    else {
-
-        // An error occurred.
-        stop();
-
-        std::stringstream ss;
-        ss << "SslClient::handle_write: error (" << e.message() << " ) for request( " << outbound_request_ << " ) on "
-           << host_ << ":" << port_;
-        throw std::runtime_error(ss.str());
-    }
-
-    // Nothing to do. The socket will be closed automatically when the last
-    // reference to the connection object goes away.
-}
-
-void SslClient::start_read() {
-    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
-    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
-    // executed. If it returns 1 then the wait handler was successfully cancelled.
-
-    // Set a deadline for the read operation.
-    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
-
-    connection_.async_read(inbound_response_,
-                           [this](const boost::system::error_code& error) { this->handle_read(error); });
-}
-
-void SslClient::handle_read(const boost::system::error_code& e) {
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::handle_read stopped_ = " << stopped_ << std::endl;
-#endif
-    if (stopped_)
-        return;
-
-    // close socket, & cancel timer.
-    stop();
-
-    if (!e) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   SslClient::handle_read OK \n";
-        std::cout << "      outbound_request_ = " << outbound_request_ << "\n";
-        std::cout << "      inbound_response_ = " << inbound_response_ << "\n";
-#endif
-        /// ***********************************************************
-        /// ClientInvoker will call back, to handle_server_response.
-        /// ***********************************************************
-        // Successfully handled request
-    }
-    else {
-        //
-        // A connection error occurred. EOF
-        //   - In cases where ( to cut down network traffic),
-        //     the server does a shutdown/closes the socket without replying we will get End of File error.
-        //   - if we have a NONSSL client talking to SSL server, the SSL server will not reply, we will get End of File
-        //   error.
-        //
-        // i.e. client requests a response from the server, and it does not reply(or replies with shutdown/close)
-        // In both cases we will treat as an error
-
-        if (e.value() == boost::asio::error::eof) {
-#ifdef DEBUG_CLIENT
-            std::cout << "   Client::handle_read: End of File (server did not reply or mixing ssl and non-ssl)"
-                      << std::endl;
-#endif
-            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::END_OF_FILE));
-            return;
-        }
-
-        // If we get back Invalid argument. It means server could *NOT* decode client message. Equally client could not
-        // decode server reply
-        //   - Could be boost version of client/server are incompatible
-        //   - 4 series ecflow cannot talk to 5 series ecflow or vice versa
-        // We treat this specially
-        if (e.value() == boost::asio::error::invalid_argument) {
-#ifdef DEBUG_CLIENT
-            std::cout
-                << "   Client::handle_read: Server replied with invalid argument (i.e could not decode client message) "
-                << std::endl;
-#endif
-            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::INVALID_ARGUMENT));
-            return;
-        }
-
-        std::stringstream ss;
-        ss << "Client::handle_read: connection error( " << e.message() << " ) for request( " << outbound_request_
-           << " ) on " << host_ << ":" << port_;
-        throw std::runtime_error(ss.str());
-    }
-
-    // Since we are not starting a new operation the io_service will run out of
-    // work to do and the Client will exit.
-}
-
-void SslClient::stop() {
-    stopped_ = true;
-    connection_.socket_ll().close();
-    deadline_.cancel();
-}
-
-/// Handle completion of a write operation.
-/// Handle completion of a read operation.
-bool SslClient::handle_server_response(ServerReply& server_reply, bool debug) const {
-    if (debug)
-        std::cout << "  SslClient::handle_server_response" << std::endl;
-    server_reply.set_host_port(host_, port_); // client context, needed by some commands, ie. SServerLoadCmd
-    return inbound_response_.handle_server_response(server_reply, outbound_request_.get_cmd(), debug);
-}
-
-void SslClient::check_deadline() {
-#ifdef DEBUG_CLIENT
-    std::cout << "   SslClient::check_deadline stopped_=" << stopped_ << " expires("
-              << to_simple_string(deadline_.expires_at()) << ") time now("
-              << to_simple_string(boost::asio::deadline_timer::traits_type::now()) << ")" << std::endl;
-#endif
-    if (stopped_)
-        return;
-
-    // Check whether the deadline has passed. We compare the deadline against
-    // the current time since a new asynchronous operation may have moved the
-    // deadline before this actor had a chance to run.
-    if (deadline_.expires_at() <= boost::asio::deadline_timer::traits_type::now()) {
-#ifdef DEBUG_CLIENT
-        std::cout << "   SslClient::check_deadline timed out" << std::endl;
-#endif
-
-        // The deadline has passed. The socket is closed so that any outstanding
-        // asynchronous operations are cancelled.
-        stop();
-
-        std::stringstream ss;
-        ss << "SslClient::check_deadline: timed out after " << timeout_ << " seconds for request( " << outbound_request_
-           << " ) on " << host_ << ":" << port_;
-        throw std::runtime_error(ss.str());
-    }
-
-    // Put the actor back to sleep.
-    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/SslClient.hpp 5.13.0-1/Base/src/ecflow/base/SslClient.hpp
--- 5.12.4-1/Base/src/ecflow/base/SslClient.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/SslClient.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,80 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_SslClient_HPP
-#define ecflow_base_SslClient_HPP
-
-///
-/// \brief This class acts as the client part. ( in client/server architecture)
-///
-/// \note The plug command can move a node to another server hence the server
-/// itself will NEED to ACT as a client. This is why client lives in Base and
-/// not the Client project
-///
-
-#include "ecflow/base/ClientToServerRequest.hpp"
-#include "ecflow/base/ServerToClientResponse.hpp"
-#include "ecflow/base/ssl_connection.hpp"
-
-class SslClient {
-public:
-    /// Constructor starts the asynchronous connect operation.
-    SslClient(boost::asio::io_service& io_service,
-              boost::asio::ssl::context& context,
-              Cmd_ptr cmd_ptr,
-              const std::string& host,
-              const std::string& port,
-              int timout = 0);
-    ~SslClient();
-
-    /// Client side, get the server response, handles reply from server
-    /// Returns true if all is ok, else false if further client action is required
-    /// will throw std::runtime_error for errors
-    bool handle_server_response(ServerReply&, bool debug) const;
-
-private:
-    void start(boost::asio::ip::tcp::resolver::iterator);
-    void stop();
-    void check_deadline();
-
-    bool start_connect(boost::asio::ip::tcp::resolver::iterator);
-
-    void start_handshake();
-    void handle_handshake(const boost::system::error_code& e);
-    void start_write();
-    void start_read();
-
-    /// Handle completion of a connect operation.
-    void handle_connect(const boost::system::error_code& e, boost::asio::ip::tcp::resolver::iterator endpoint_iterator);
-
-    /// Handle completion of a read operation.
-    void handle_read(const boost::system::error_code& e);
-
-    /// Handle completion of a write operation
-    void handle_write(const boost::system::error_code& e);
-
-private:
-    bool stopped_;
-    std::string host_;                        /// the servers name
-    std::string port_;                        /// the port on the server
-    ssl_connection connection_;               /// The connection to the server.
-    ClientToServerRequest outbound_request_;  /// The request we will send to the server
-    ServerToClientResponse inbound_response_; /// The response we get back from the server
-
-    boost::asio::deadline_timer deadline_;
-
-    //    connect        : timeout_ second
-    //    send request   : timeout_ second
-    //    receive reply  : timeout_ second
-    // Default value of 0 means take the timeout from the command
-    int timeout_;
-};
-
-#endif /* ecflow_base_SslClient_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/Stats.cpp 5.13.0-1/Base/src/ecflow/base/Stats.cpp
--- 5.12.4-1/Base/src/ecflow/base/Stats.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Stats.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,356 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/Stats.hpp"
-
-#include <iomanip>
-#include <sstream>
-
-#include <boost/range/adaptors.hpp>
-
-#include "ecflow/core/SState.hpp"
-
-using namespace std;
-
-Stats::Stats() = default;
-
-void Stats::update_stats(int poll_interval) {
-    // Called at poll time, ie just before node tree traversal
-    request_vec_.emplace_back(request_count_, poll_interval);
-    request_count_ = 0;
-    request_stats_.clear();
-
-    // To avoid excessive memory usage, we store only a limited number of:
-    //  - requests per poll period
-    // Since we're polling every 60 seconds, sample cover the last hour
-    if (request_vec_.size() > 60) {
-        request_vec_.pop_front();
-    }
-}
-
-void Stats::update_for_serialisation() {
-    /// This *ONLY* computes the data when this function is called
-    /// >>> Hence the server load is only valid for last hour <<<
-
-    if (!request_stats_.empty()) {
-        // Found request statistics in 'cache'. Nothing further to do...
-        return;
-    }
-
-    if (request_vec_.empty()) {
-        // No data to create statistics...
-        return;
-    }
-
-    std::stringstream ss;
-    ss << setiosflags(ios::fixed) << setprecision(2);
-
-    int count      = 0;
-    double request = 0.0;
-    double seconds = 0.0;
-    for (const auto& entry : boost::adaptors::reverse(request_vec_)) {
-        count++;
-        request += entry.first;
-        seconds += entry.second;
-        double request_per_second = request / seconds;
-
-        switch (count) {
-            case 5:
-            case 15:
-            case 30:
-            case 60: {
-                ss << " ";
-                [[fallthrough]];
-            }
-            case 1: {
-                ss << request_per_second;
-            }
-            default: {
-                // nothing to do...
-            }
-        }
-    }
-    request_stats_ = ss.str();
-}
-
-void Stats::reset() {
-    checkpt_                   = 0;
-    restore_defs_from_checkpt_ = 0;
-
-    server_version_         = 0;
-    restart_server_         = 0;
-    shutdown_server_        = 0;
-    halt_server_            = 0;
-    reload_white_list_file_ = 0;
-    reload_passwd_file_     = 0;
-    ping_                   = 0;
-    debug_server_on_        = 0;
-    debug_server_off_       = 0;
-    get_defs_               = 0;
-    sync_                   = 0;
-    sync_full_              = 0;
-    sync_clock_             = 0;
-    news_                   = 0;
-
-    node_job_gen_            = 0;
-    node_check_job_gen_only_ = 0;
-    node_delete_             = 0;
-    node_suspend_            = 0;
-    node_resume_             = 0;
-    node_kill_               = 0;
-    node_status_             = 0;
-    node_edit_history_       = 0;
-    node_archive_            = 0;
-    node_restore_            = 0;
-
-    log_cmd_     = 0;
-    log_msg_cmd_ = 0;
-    begin_cmd_   = 0;
-
-    task_init_     = 0;
-    task_complete_ = 0;
-    task_wait_     = 0;
-    task_abort_    = 0;
-    task_event_    = 0;
-    task_meter_    = 0;
-    task_label_    = 0;
-    task_queue_    = 0;
-
-    zombie_fob_    = 0;
-    zombie_fail_   = 0;
-    zombie_adopt_  = 0;
-    zombie_remove_ = 0;
-    zombie_get_    = 0;
-    zombie_block_  = 0;
-    zombie_kill_   = 0;
-
-    requeue_node_ = 0;
-    order_node_   = 0;
-    run_node_     = 0;
-    load_defs_    = 0;
-    replace_      = 0;
-    force_        = 0;
-    free_dep_     = 0;
-    suites_       = 0;
-    edit_script_  = 0;
-
-    alter_cmd_   = 0;
-    ch_cmd_      = 0;
-    file_ecf_    = 0;
-    file_job_    = 0;
-    file_jobout_ = 0;
-    file_cmdout_ = 0;
-    file_manual_ = 0;
-
-    plug_            = 0;
-    move_            = 0;
-    group_cmd_       = 0;
-    server_load_cmd_ = 0;
-    stats_           = 0;
-    check_           = 0;
-    query_           = 0;
-}
-
-static string show_checkpt_mode(ecf::CheckPt::Mode m) {
-    switch (m) {
-        case ecf::CheckPt::NEVER:
-            return "CHECK_NEVER";
-            break;
-        case ecf::CheckPt::ON_TIME:
-            return "CHECK_ON_TIME";
-            break;
-        case ecf::CheckPt::ALWAYS:
-            return "CHECK_ON_ALWAYS";
-            break;
-        case ecf::CheckPt::UNDEFINED:
-            return "UNDEFINED";
-            break;
-    }
-    return std::string();
-}
-
-void Stats::show(std::ostream& os) const {
-    int width = 35;
-    os << "Server statistics\n";
-    os << left << setw(width) << "   Version " << version_ << "\n";
-    os << left << setw(width) << "   Status " << SState::to_string(status_) << "\n";
-    os << left << setw(width) << "   Host " << host_ << "\n";
-    os << left << setw(width) << "   Port " << port_ << "\n";
-    os << left << setw(width) << "   Up since " << up_since_ << "\n";
-    os << left << setw(width) << "   Job sub' interval " << job_sub_interval_ << "s\n";
-    os << left << setw(width) << "   ECF_HOME " << ECF_HOME_ << "\n";
-    os << left << setw(width) << "   ECF_LOG " << ECF_LOG_ << "\n";
-    os << left << setw(width) << "   ECF_CHECK " << ECF_CHECK_ << "\n";
-    os << left << setw(width) << "   ECF_SSL " << ECF_SSL_ << "\n";
-    os << left << setw(width) << "   Check pt interval " << checkpt_interval_ << "s\n";
-    os << left << setw(width) << "   Check pt mode " << show_checkpt_mode(checkpt_mode_) << "\n";
-    os << left << setw(width) << "   Check pt save time alarm " << checkpt_save_time_alarm_ << "s\n";
-    os << left << setw(width) << "   Number of Suites " << no_of_suites_ << "\n";
-    os << left << setw(width) << "   Request/s per 1,5,15,30,60 min " << request_stats_ << "\n";
-
-    if (checkpt_ || restore_defs_from_checkpt_ || server_version_ || restart_server_ || shutdown_server_ ||
-        halt_server_ || ping_ || debug_server_on_ || debug_server_off_ || get_defs_ || sync_ || sync_full_ ||
-        sync_clock_ || news_)
-        os << "\n";
-    if (!locked_by_user_.empty())
-        os << left << setw(width) << "   Locked by user " << locked_by_user_ << "\n";
-    if (checkpt_ != 0)
-        os << left << setw(width) << "   Check points " << checkpt_ << "\n";
-    if (restore_defs_from_checkpt_ != 0)
-        os << left << setw(width) << "   Restore from Check point " << restore_defs_from_checkpt_ << "\n";
-    if (restart_server_ != 0)
-        os << left << setw(width) << "   Restart server " << restart_server_ << "\n";
-    if (shutdown_server_ != 0)
-        os << left << setw(width) << "   Shutdown server " << shutdown_server_ << "\n";
-    if (halt_server_ != 0)
-        os << left << setw(width) << "   Halt server " << halt_server_ << "\n";
-    if (ping_ != 0)
-        os << left << setw(width) << "   Ping " << ping_ << "\n";
-    if (debug_server_on_ != 0)
-        os << left << setw(width) << "   debug server on " << debug_server_on_ << "\n";
-    if (debug_server_off_ != 0)
-        os << left << setw(width) << "   debug server off " << debug_server_off_ << "\n";
-    if (get_defs_ != 0)
-        os << left << setw(width) << "   Get full definition " << get_defs_ << "\n";
-    if (server_version_ != 0)
-        os << left << setw(width) << "   Server version " << server_version_ << "\n";
-    if (sync_ != 0)
-        os << left << setw(width) << "   Sync " << sync_ << "\n";
-    if (sync_full_ != 0)
-        os << left << setw(width) << "   Sync full " << sync_full_ << "\n";
-    if (sync_clock_ != 0)
-        os << left << setw(width) << "   Sync suite clock " << sync_clock_ << "\n";
-    if (news_ != 0)
-        os << left << setw(width) << "   News " << news_ << "\n";
-
-    if (task_init_ || task_complete_ || task_wait_ || task_abort_ || task_event_ || task_meter_ || task_label_ ||
-        task_queue_)
-        os << "\n";
-    if (task_init_ != 0)
-        os << left << setw(width) << "   Task init " << task_init_ << "\n";
-    if (task_complete_ != 0)
-        os << left << setw(width) << "   Task complete " << task_complete_ << "\n";
-    if (task_wait_ != 0)
-        os << left << setw(width) << "   Task wait " << task_wait_ << "\n";
-    if (task_abort_ != 0)
-        os << left << setw(width) << "   Task abort " << task_abort_ << "\n";
-    if (task_event_ != 0)
-        os << left << setw(width) << "   Task event " << task_event_ << "\n";
-    if (task_meter_ != 0)
-        os << left << setw(width) << "   Task meter " << task_meter_ << "\n";
-    if (task_label_ != 0)
-        os << left << setw(width) << "   Task label " << task_label_ << "\n";
-    if (task_queue_ != 0)
-        os << left << setw(width) << "   Task queue " << task_queue_ << "\n";
-
-    if (zombie_fob_ || zombie_fail_ || zombie_adopt_ || zombie_remove_ || zombie_get_ || zombie_block_ || zombie_kill_)
-        os << "\n";
-    if (zombie_fob_ != 0)
-        os << left << setw(width) << "   Zombie fob " << zombie_fob_ << "\n";
-    if (zombie_fail_ != 0)
-        os << left << setw(width) << "   Zombie fail " << zombie_fail_ << "\n";
-    if (zombie_adopt_ != 0)
-        os << left << setw(width) << "   Zombie adopt " << zombie_adopt_ << "\n";
-    if (zombie_remove_ != 0)
-        os << left << setw(width) << "   Zombie remove " << zombie_remove_ << "\n";
-    if (zombie_get_ != 0)
-        os << left << setw(width) << "   Zombie get " << zombie_get_ << "\n";
-    if (zombie_block_ != 0)
-        os << left << setw(width) << "   Zombie block " << zombie_block_ << "\n";
-    if (zombie_kill_ != 0)
-        os << left << setw(width) << "   Zombie kill " << zombie_kill_ << "\n";
-
-    if (load_defs_ || begin_cmd_ || requeue_node_ || node_job_gen_ || node_check_job_gen_only_ || node_delete_ ||
-        node_suspend_ || node_resume_ || node_kill_ || node_status_ || node_edit_history_ || log_cmd_ || log_msg_cmd_ ||
-        order_node_ || run_node_ || replace_ || force_ || free_dep_ || suites_ || edit_script_ || alter_cmd_ ||
-        ch_cmd_ || plug_ || move_ || group_cmd_ || reload_white_list_file_ || server_load_cmd_ || stats_ || check_ ||
-        query_ || reload_passwd_file_ || node_archive_ || node_restore_)
-        os << "\n";
-
-    if (load_defs_ != 0)
-        os << left << setw(width) << "   Load definition " << load_defs_ << "\n";
-    if (begin_cmd_ != 0)
-        os << left << setw(width) << "   Begin " << begin_cmd_ << "\n";
-    if (requeue_node_ != 0)
-        os << left << setw(width) << "   Requeue " << requeue_node_ << "\n";
-    if (node_job_gen_ != 0)
-        os << left << setw(width) << "   Job generation " << node_job_gen_ << "\n";
-    if (node_check_job_gen_only_ != 0)
-        os << left << setw(width) << "   Check Job generation " << node_check_job_gen_only_ << "\n";
-    if (node_delete_ != 0)
-        os << left << setw(width) << "   Node delete " << node_delete_ << "\n";
-    if (node_suspend_ != 0)
-        os << left << setw(width) << "   Node suspend " << node_suspend_ << "\n";
-    if (node_resume_ != 0)
-        os << left << setw(width) << "   Node resume " << node_resume_ << "\n";
-    if (node_kill_ != 0)
-        os << left << setw(width) << "   Node kill " << node_kill_ << "\n";
-    if (node_status_ != 0)
-        os << left << setw(width) << "   Node status " << node_status_ << "\n";
-    if (node_edit_history_ != 0)
-        os << left << setw(width) << "   Node edit history " << node_edit_history_ << "\n";
-    if (node_archive_ != 0)
-        os << left << setw(width) << "   Node archive " << node_archive_ << "\n";
-    if (node_restore_ != 0)
-        os << left << setw(width) << "   Node restore " << node_restore_ << "\n";
-    if (log_cmd_ != 0)
-        os << left << setw(width) << "   Log cmd " << log_cmd_ << "\n";
-    if (log_msg_cmd_ != 0)
-        os << left << setw(width) << "   Log message " << log_msg_cmd_ << "\n";
-    if (order_node_ != 0)
-        os << left << setw(width) << "   Order " << order_node_ << "\n";
-    if (run_node_ != 0)
-        os << left << setw(width) << "   Run " << run_node_ << "\n";
-    if (replace_ != 0)
-        os << left << setw(width) << "   Replace " << replace_ << "\n";
-    if (force_ != 0)
-        os << left << setw(width) << "   Force  " << force_ << "\n";
-    if (free_dep_ != 0)
-        os << left << setw(width) << "   Free dependencies " << free_dep_ << "\n";
-    if (suites_ != 0)
-        os << left << setw(width) << "   Suites " << suites_ << "\n";
-    if (edit_script_ != 0)
-        os << left << setw(width) << "   Edit script " << edit_script_ << "\n";
-    if (alter_cmd_ != 0)
-        os << left << setw(width) << "   Alter " << alter_cmd_ << "\n";
-    if (ch_cmd_ != 0)
-        os << left << setw(width) << "   Client handle " << ch_cmd_ << "\n";
-    if (plug_ != 0)
-        os << left << setw(width) << "   Plug " << plug_ << "\n";
-    if (move_ != 0)
-        os << left << setw(width) << "   Move " << move_ << "\n";
-    if (group_cmd_ != 0)
-        os << left << setw(width) << "   Group " << group_cmd_ << "\n";
-    if (server_load_cmd_ != 0)
-        os << left << setw(width) << "   Server load cmd " << server_load_cmd_ << "\n";
-    if (stats_ != 0)
-        os << left << setw(width) << "   stats cmd " << stats_ << "\n";
-    if (check_ != 0)
-        os << left << setw(width) << "   checks " << check_ << "\n";
-    if (query_ != 0)
-        os << left << setw(width) << "   query " << query_ << "\n";
-    if (reload_white_list_file_ != 0)
-        os << left << setw(width) << "   Reload white list file " << reload_white_list_file_ << "\n";
-    if (reload_passwd_file_ != 0)
-        os << left << setw(width) << "   Reload password file " << reload_passwd_file_ << "\n";
-    if (file_ecf_ || file_job_ || file_jobout_ || file_manual_ || file_cmdout_)
-        os << "\n";
-    if (file_ecf_ != 0)
-        os << left << setw(width) << "   File ECF " << file_ecf_ << "\n";
-    if (file_job_ != 0)
-        os << left << setw(width) << "   File job " << file_job_ << "\n";
-    if (file_jobout_ != 0)
-        os << left << setw(width) << "   File Job out " << file_jobout_ << "\n";
-    if (file_cmdout_ != 0)
-        os << left << setw(width) << "   File Cmd out " << file_cmdout_ << "\n";
-    if (file_manual_ != 0)
-        os << left << setw(width) << "   File manual " << file_manual_ << "\n";
-    os << flush;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/Stats.hpp 5.13.0-1/Base/src/ecflow/base/Stats.hpp
--- 5.12.4-1/Base/src/ecflow/base/Stats.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/Stats.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,228 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_Stats_HPP
-#define ecflow_base_Stats_HPP
-
-#include <deque>
-#include <string>
-
-#include "ecflow/core/CheckPt.hpp"
-#include "ecflow/core/Serialization.hpp"
-
-/// This class is used to store all statistical data about all the
-/// commands processed by the server. Uses default copy constructor
-struct Stats
-{
-
-    Stats();
-    void show(std::ostream& os = std::cout) const;
-
-    void update() { request_count_++; }
-    void update_stats(int poll_interval);
-    void update_for_serialisation();
-    void reset();
-
-    std::string locked_by_user_;
-    std::string host_;
-    std::string port_;
-    std::string up_since_;
-    std::string version_;
-    std::string request_stats_;
-    std::string ECF_HOME_;
-    std::string ECF_CHECK_;
-    std::string ECF_LOG_;
-    std::string ECF_SSL_{"disabled"};
-
-    int status_{0}; // 0 HALTED, 1 SHUTDOWN, 2 RUNNING
-    int request_count_{0};
-    int job_sub_interval_{0};
-    int checkpt_interval_{0};
-    int checkpt_save_time_alarm_{0};
-    ecf::CheckPt::Mode checkpt_mode_{ecf::CheckPt::UNDEFINED};
-    int no_of_suites_{0};
-
-    unsigned int checkpt_{0};
-    unsigned int restore_defs_from_checkpt_{0};
-
-    unsigned int server_version_{0};
-    unsigned int restart_server_{0};
-    unsigned int shutdown_server_{0};
-    unsigned int halt_server_{0};
-    unsigned int reload_white_list_file_{0};
-    unsigned int reload_passwd_file_{0};
-    unsigned int ping_{0};
-    unsigned int debug_server_on_{0};
-    unsigned int debug_server_off_{0};
-    unsigned int get_defs_{0};
-    unsigned int sync_{0};
-    unsigned int sync_full_{0};
-    unsigned int sync_clock_{0};
-    unsigned int news_{0};
-
-    unsigned int node_job_gen_{0};
-    unsigned int node_check_job_gen_only_{0};
-    unsigned int node_delete_{0};
-    unsigned int node_suspend_{0};
-    unsigned int node_resume_{0};
-    unsigned int node_kill_{0};
-    unsigned int node_status_{0};
-    unsigned int node_edit_history_{0};
-    unsigned int node_archive_{0};
-    unsigned int node_restore_{0};
-
-    unsigned int log_cmd_{0};
-    unsigned int log_msg_cmd_{0};
-    unsigned int begin_cmd_{0};
-
-    unsigned int task_init_{0};
-    unsigned int task_complete_{0};
-    unsigned int task_wait_{0};
-    unsigned int task_abort_{0};
-    unsigned int task_event_{0};
-    unsigned int task_meter_{0};
-    unsigned int task_label_{0};
-    unsigned int task_queue_{0};
-
-    unsigned int zombie_fob_{0};
-    unsigned int zombie_fail_{0};
-    unsigned int zombie_adopt_{0};
-    unsigned int zombie_remove_{0};
-    unsigned int zombie_get_{0};
-    unsigned int zombie_block_{0};
-    unsigned int zombie_kill_{0};
-
-    unsigned int requeue_node_{0};
-    unsigned int order_node_{0};
-    unsigned int run_node_{0};
-    unsigned int load_defs_{0};
-    unsigned int replace_{0};
-    unsigned int force_{0};
-    unsigned int free_dep_{0};
-    unsigned int suites_{0};
-    unsigned int edit_script_{0};
-
-    unsigned int alter_cmd_{0};
-    unsigned int ch_cmd_{0};
-    unsigned int file_ecf_{0};
-    unsigned int file_job_{0};
-    unsigned int file_jobout_{0};
-    unsigned int file_cmdout_{0};
-    unsigned int file_manual_{0};
-
-    unsigned int plug_{0};
-    unsigned int move_{0};
-    unsigned int group_cmd_{0};
-    unsigned int server_load_cmd_{0};
-    unsigned int stats_{0};
-    unsigned int check_{0};
-    unsigned int query_{0};
-
-private:
-    std::deque<std::pair<int, int>> request_vec_; // pair.first =  number of requests, pair.second = poll interval
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar & status_;
-        ar & locked_by_user_;
-        ar & host_;
-        ar & port_;
-        ar & up_since_;
-        ar & version_;
-        ar & job_sub_interval_;
-        ar & checkpt_interval_;
-        ar & checkpt_save_time_alarm_;
-        ar & checkpt_mode_;
-        ar & no_of_suites_;
-        ar & request_stats_;
-        ar & ECF_HOME_;
-        ar & ECF_CHECK_;
-        ar & ECF_LOG_;
-        ar & ECF_SSL_;
-
-        ar & checkpt_;
-
-        ar & server_version_;
-        ar & restart_server_;
-        ar & shutdown_server_;
-        ar & halt_server_;
-        ar & reload_white_list_file_;
-        ar & reload_passwd_file_;
-        ar & ping_;
-        ar & debug_server_on_;
-        ar & debug_server_off_;
-
-        ar & get_defs_;
-        ar & sync_;
-        ar & sync_full_;
-        ar & sync_clock_;
-        ar & news_;
-
-        ar & node_job_gen_;
-        ar & node_check_job_gen_only_;
-        ar & node_delete_;
-        ar & node_suspend_;
-        ar & node_resume_;
-        ar & node_kill_;
-        ar & node_status_;
-        ar & node_edit_history_;
-        ar & node_archive_;
-        ar & node_restore_;
-
-        ar & log_cmd_;
-        ar & log_msg_cmd_;
-        ar & begin_cmd_;
-
-        ar & task_init_;
-        ar & task_complete_;
-        ar & task_wait_;
-        ar & task_abort_;
-        ar & task_event_;
-        ar & task_meter_;
-        ar & task_label_;
-        ar & task_queue_;
-
-        ar & zombie_fob_;
-        ar & zombie_fail_;
-        ar & zombie_adopt_;
-        ar & zombie_remove_;
-        ar & zombie_get_;
-        ar & zombie_block_;
-        ar & zombie_kill_;
-
-        ar & requeue_node_;
-        ar & order_node_;
-        ar & run_node_;
-        ar & load_defs_;
-        ar & replace_;
-        ar & force_;
-        ar & free_dep_;
-        ar & suites_;
-        ar & edit_script_;
-
-        ar & alter_cmd_;
-        ar & ch_cmd_;
-        ar & file_ecf_;
-        ar & file_job_;
-        ar & file_jobout_;
-        ar & file_cmdout_;
-        ar & file_manual_;
-
-        ar & plug_;
-        ar & move_;
-        ar & group_cmd_;
-        ar & server_load_cmd_;
-        ar & stats_;
-        ar & check_;
-        ar & query_;
-    }
-};
-#endif
diff -pruN 5.12.4-1/Base/src/ecflow/base/WhyCmd.cpp 5.13.0-1/Base/src/ecflow/base/WhyCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/WhyCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/WhyCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,51 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/WhyCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Node.hpp"
-
-WhyCmd::WhyCmd(defs_ptr defs, const std::string& absNodePath) : defs_(defs) {
-    if (!defs_.get()) {
-        throw std::runtime_error("WhyCmd: The definition parameter is empty");
-    }
-
-    if (!absNodePath.empty()) {
-        node_ = defs_->findAbsNode(absNodePath);
-        if (!node_.get()) {
-            std::string errorMsg = "WhyCmd: The node path parameter '";
-            errorMsg += absNodePath;
-            errorMsg += "' cannot be found.";
-            throw std::runtime_error(errorMsg);
-        }
-    }
-}
-
-std::string WhyCmd::why() const {
-    std::vector<std::string> theReasonWhy;
-    if (node_.get()) {
-        node_->bottom_up_why(theReasonWhy);
-    }
-    else {
-        defs_->top_down_why(theReasonWhy);
-    }
-
-    // Don't add /n on very last item
-    std::string reason;
-    for (size_t i = 0; i < theReasonWhy.size(); ++i) {
-        reason += theReasonWhy[i];
-        if (i != theReasonWhy.size() - 1)
-            reason += "\n";
-    }
-    return reason;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/WhyCmd.hpp 5.13.0-1/Base/src/ecflow/base/WhyCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/WhyCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/WhyCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_WhyCmd_HPP
-#define ecflow_base_WhyCmd_HPP
-
-///
-/// \brief Client side command only.
-///
-/// \note Placed in this category, since the server does not need to link with it.
-///
-
-#include <string>
-
-#include "ecflow/node/NodeFwd.hpp"
-
-class WhyCmd {
-public:
-    WhyCmd()              = delete;
-    WhyCmd(const WhyCmd&) = delete;
-    WhyCmd(WhyCmd&&)      = delete;
-
-    WhyCmd(defs_ptr defs, const std::string& absNodePath);
-
-    /// Why the node is not running
-    /// Return a '/n' separated string which lists the reasons why
-    /// the provided node is not active.
-    std::string why() const;
-
-private:
-    defs_ptr defs_;
-    node_ptr node_;
-};
-
-#endif /* ecflow_base_WhyCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/ZombieCtrl.cpp 5.13.0-1/Base/src/ecflow/base/ZombieCtrl.cpp
--- 5.12.4-1/Base/src/ecflow/base/ZombieCtrl.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ZombieCtrl.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,818 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/ZombieCtrl.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost::posix_time;
-
-// #define DEBUG_ZOMBIE  1
-
-/// Zombie creation:
-/// *** ECF  *** Zombies is created with: process(node path, password, pid/rid , try_no) ***
-/// *** PATH *** Zombies is created with: process(node path, password, pid/rid , try_no) ***
-/// *** USER *** Zombies is created with:    TASK(node path, password, pid/rid , try_no) ***
-///
-/// There are several places where we hold path,password,pid/rid,etc
-///                        Task Cmd/
-///            Node Tree   Process(n)   USER Zombie         PATH/ECF Zombie
-///  Path                               same as node tree   same as process
-///  password                           same as node tree   same as process
-///  pid/rid                            same as node tree   same as process
-///  try no                             same as node tree   same as process
-///    ^                    |
-///    | ----adopt-----------
-///
-/// Zombie Finding:
-/// For a given Task, we could have multiple zombie process, i.e. with different password/process id
-/// We can't assume that there is only one zombie process. Hence search/zombie matching
-/// should involve matching with password/process id first and then resort to path matching
-///
-/// Note: Only the init child command is required pass the process id. The other child command may
-//        or may *not* provide this. In the test scenario we do.
-static bool match(const Zombie& z,
-                  const std::string& path_to_task,
-                  const std::string& process_or_remote_id,
-                  const std::string& password);
-
-bool ZombieCtrl::handle_path_zombie(AbstractServer* as,
-                                    const TaskCmd* task_cmd, // The child command
-                                    std::string& action_taken,
-                                    STC_Cmd_ptr& theReply // Reply varies according to User Action
-) {
-#ifdef DEBUG_ZOMBIE
-    std::cout << "   ZombieCtrl::handle_path_zombie:";
-#endif
-    const std::string& path_to_task         = task_cmd->path_to_node();
-    const std::string& jobs_password        = task_cmd->jobs_password();
-    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
-
-    /// *** The ZombieAttr may have added/ deleted via AlterCmd. This allows for dynamic changes
-    /// *no* task, find the closest Zombie attribute up the Node tree, ie attribute could be on family/suite even though
-    /// task has been deleted If none found we resort to default behaviour
-    node_ptr closest_matching_node = as->defs()->find_closest_matching_node(path_to_task);
-#ifdef DEBUG_ZOMBIE
-    if (closest_matching_node.get())
-        std::cout << " closest node found: ";
-#endif
-
-#ifdef DEBUG_ZOMBIE
-    std::cout << " Searching for match over " << zombies_.size() << " zombies :";
-#endif
-    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, jobs_password);
-    if (!theExistingZombie.empty()) {
-        // When NULL is passed for task, we change existing zombie to be of type PATH
-        return handle_existing_zombie(
-            theExistingZombie, nullptr /*task*/, closest_matching_node, task_cmd, action_taken, theReply);
-    }
-
-    /// Create a zombie,
-    /// *** PATH *** Zombies is created with: process path, process password, and process id/rid , process try_no ***
-#ifdef DEBUG_ZOMBIE
-    std::cout << " No matching zombie fnd: Creating Path Zombie: ";
-#endif
-
-    ZombieAttr attr = ZombieAttr::get_default_attr(Child::PATH);
-    if (closest_matching_node.get()) {
-        closest_matching_node->findParentZombie(Child::PATH, attr); // Override default from node tree
-    }
-
-    Zombie new_zombie(Child::PATH,
-                      task_cmd->child_type(),
-                      attr,
-                      path_to_task,
-                      jobs_password,
-                      process_or_remote_id,
-                      task_cmd->try_no(),
-                      task_cmd->hostname());
-    zombies_.emplace_back(new_zombie);
-
-    /// The user action may end deleting the zombie just added. Depends on ZombieAttribute settings
-    return handle_user_actions(new_zombie, nullptr /*task*/, task_cmd, action_taken, theReply);
-}
-
-bool ZombieCtrl::handle_zombie(Submittable* task,       // This NULL for path zombies
-                               const TaskCmd* task_cmd, // The child command
-                               std::string& action_taken,
-                               STC_Cmd_ptr& theReply // Reply varies according to User Action
-) {
-#ifdef DEBUG_ZOMBIE
-    std::cout << "   ZombieCtrl::handle_zombie:";
-#endif
-    const std::string& path_to_task         = task_cmd->path_to_node();
-    const std::string& jobs_password        = task_cmd->jobs_password();
-    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
-
-    /// Mark task as zombie
-    if (task)
-        task->flag().set(ecf::Flag::ZOMBIE);
-
-    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, jobs_password);
-    if (!theExistingZombie.empty()) {
-        return handle_existing_zombie(theExistingZombie, task, node_ptr(), task_cmd, action_taken, theReply);
-    }
-
-    /// Create Zombie:
-    /// *** ECF *** Zombies is created with: process path, process password, and process id/rid , process try_no ***
-    Child::ZombieType zombie_type = Child::ECF;
-    if (task_cmd->pid_missmatch() && task_cmd->password_missmatch())
-        zombie_type = Child::ECF_PID_PASSWD;
-    else if (task_cmd->pid_missmatch())
-        zombie_type = Child::ECF_PID;
-    else if (task_cmd->password_missmatch())
-        zombie_type = Child::ECF_PASSWD;
-    ZombieAttr attr = ZombieAttr::get_default_attr(zombie_type);
-
-    /// Look for any Zombie attribute up node tree, use this to construct & configure zombie
-    if (task)
-        task->findParentZombie(zombie_type, attr);
-
-    /// Handle corner case ,where we have two jobs with different process id, but same password
-    /// Can happen if jobs is started externally, or via test, occasionally
-    ecf::Child::CmdType child_type = task_cmd->child_type();
-    if (child_type == Child::INIT && task && task->state() == NState::ACTIVE) {
-
-        /// Find zombie by path only, and remove it. Re-added again below. With updated, data<<<<
-#ifdef DEBUG_ZOMBIE
-        cout << " >TASK already active:< ";
-#endif
-        size_t zombieVecSize = zombies_.size();
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task) {
-                zombie_type = zombies_[i].type(); // recover the original zombie type
-                zombies_.erase(zombies_.begin() + i);
-#ifdef DEBUG_ZOMBIE
-                cout << " Removing: ";
-#endif
-                break;
-            }
-        }
-    }
-
-#ifdef DEBUG_ZOMBIE
-    std::cout << " Creating ECF Zombie:";
-#endif
-    Zombie new_zombie(zombie_type,
-                      child_type,
-                      attr,
-                      path_to_task,
-                      jobs_password,
-                      process_or_remote_id,
-                      task_cmd->try_no(),
-                      task_cmd->hostname());
-    zombies_.push_back(new_zombie);
-
-    return handle_user_actions(new_zombie, task, task_cmd, action_taken, theReply);
-}
-
-bool ZombieCtrl::handle_existing_zombie(Zombie& theExistingZombie,      // The server already knows about the zombie
-                                        Submittable* task,              // This NULL for path zombies
-                                        node_ptr closest_matching_node, // only defined for path zombies
-                                        const TaskCmd* task_cmd,        // The child command
-                                        std::string& action_taken,      // User action taken
-                                        STC_Cmd_ptr& theReply           // Reply varies according to User Action
-) {
-#ifdef DEBUG_ZOMBIE
-    std::cout << " handle_existing_zombie: ";
-#endif
-    // If we have no task, then change the zombie type to PATH
-    if (!task) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << " : updating zombie type to PATH: ";
-#endif
-        theExistingZombie.set_type(ecf::Child::PATH);
-    }
-
-    /// *** The ZombieAttr may have added/ deleted via AlterCmd. This allows for dynamic changes
-    ZombieAttr attr = ZombieAttr::get_default_attr(theExistingZombie.type());
-    if (closest_matching_node.get()) {
-#ifdef DEBUG_ZOMBIE
-        cout << " Attr found for path zombie(" << attr.toString() << "): ";
-#endif
-        closest_matching_node->findParentZombie(theExistingZombie.type(), attr); // Override default from node tree
-    }
-
-    if (task && task->findParentZombie(theExistingZombie.type(), attr)) { // Override default from node tree
-#ifdef DEBUG_ZOMBIE
-        cout << " Attr found(" << attr.toString() << "): ";
-#endif
-    }
-    theExistingZombie.set_attr(attr);                             // Update attribute stored on the zombie
-    theExistingZombie.set_last_child_cmd(task_cmd->child_type()); // The zombie stores the last child command.
-    if (theExistingZombie.host().empty())
-        theExistingZombie.set_host(task_cmd->hostname());
-    theExistingZombie.increment_calls(); // record how times server handled with zombie
-
-    /// Update the process id, if it is empty on the existing zombie
-    /// *** NOTE**** cannot update process id from task, as that could be an ID from a different JOB,
-    /// ************ Hence zombie matching resorts to path and password matching
-    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
-    if (theExistingZombie.process_or_remote_id().empty() && !process_or_remote_id.empty()) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << "Updating process id(" << process_or_remote_id << "): ";
-#endif
-        theExistingZombie.set_process_or_remote_id(process_or_remote_id);
-    }
-
-    return handle_user_actions(theExistingZombie, task, task_cmd, action_taken, theReply);
-}
-
-bool ZombieCtrl::handle_user_actions(Zombie& theZombie,         // Existing or one we just created
-                                     Submittable* task,         // This is NULL for path zombies
-                                     const TaskCmd* task_cmd,   // The child command
-                                     std::string& action_taken, // User action taken
-                                     STC_Cmd_ptr& theReply      // Reply varies according to User Action
-) {
-    const std::string& path_to_task         = task_cmd->path_to_node();
-    const std::string& process_password     = task_cmd->jobs_password();
-    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
-
-    if (theZombie.manual_user_action())
-        action_taken = "manual-";
-    else
-        action_taken = "automatic-";
-
-    // *ADOPT* If zombie is set to adopt, copy over password and carry on as >NORMAL< , i.e. we return true
-    if (task && theZombie.adopt()) {
-
-        action_taken += "adopt";
-        /// Zombie was marked to adopt. password copied over, and zombie removed
-        /// *MUST* use the password of the process, and *NOT* the zombie
-        /// Since next time process communicates, it will be *WITH* the process password
-        task->set_jobs_password(process_password);
-        task->set_process_or_remote_id(process_or_remote_id);
-
-        /// Remove the zombie, as its been adopted
-        /// matching by password/process id may fail, hence remove by path
-        bool remove_ok = remove(path_to_task, process_or_remote_id, process_password);
-        if (!remove_ok) {
-            (void)remove_by_path(path_to_task);
-        }
-
-        /// Clear the zombie flag
-        task->flag().clear(ecf::Flag::ZOMBIE);
-
-#ifdef DEBUG_ZOMBIE
-        std::cout << " >>>ADOPT<<< then remove(" << remove_ok << ") ";
-        if (!remove_ok)
-            std::cout << " >>>ERROR<<<< Remove failed ";
-        std::cout << " zombies_.size(" << zombies_.size() << ")\n";
-#endif
-        return true;
-    }
-
-    // *FOB*
-    if (theZombie.fob()) {
-        /// Means return as if everything is OK. hence ClientInvoker will *NOT* block, and job can continue.
-        action_taken += "fob";
-
-        /// On the child COMPLETE/ABORT cmd, remove the zombie:
-        /// *****************************************************************************************
-        /// Since we are returning false, The Task Cmd complete/abort **wont** be able to remove the zombie
-        /// i.e since we want job to continue, *WITHOUT* invoking the dohandeRequest
-        /// *****************************************************************************************
-        if (task_cmd->child_type() == Child::COMPLETE || task_cmd->child_type() == Child::ABORT) {
-
-            bool remove_ok = remove(path_to_task, process_or_remote_id, process_password);
-            if (!remove_ok) {
-                (void)remove_by_path(path_to_task);
-            }
-
-            /// Clear the zombie flag
-            if (task)
-                task->flag().clear(ecf::Flag::ZOMBIE);
-
-#ifdef DEBUG_ZOMBIE
-            std::cout << " child == COMPLETE remove zombie ";
-            if (!remove_ok)
-                std::cout << " >>>ERROR<<<< Remove failed ";
-#endif
-        }
-
-#ifdef DEBUG_ZOMBIE
-        std::cout << " >>>FOB<<< zombies_.size(" << zombies_.size() << ")\n";
-#endif
-        theReply = PreAllocatedReply::ok_cmd();
-        return false;
-    }
-
-    // *FAIL* Ask ClientInvoker *NOT* to block,  *fail* with an error.
-    if (theZombie.fail()) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << " >>>FAIL<<< zombies_.size(" << zombies_.size() << ")\n";
-#endif
-        action_taken += "fail";
-        theReply = PreAllocatedReply::error_cmd("[ authentication failed ] Request set to FAIL via zombie setting");
-        return false;
-    }
-
-    // *KILL* Typically kill is immediate(i.e. via ZombieCmd), However this could have been set via ZombieAttribute
-    if (theZombie.kill()) {
-        // when a task a script is killed(i,e with kill -15), it will typically be trapped
-        // This will then typically call abort. We have a choice:
-        //    a/ If we remove the zombie, the action taken will be lost, when the abort arises, hence default action is
-        //    block b/ Change the action type to be fob, so that the abort does not block c/ Continue killing until
-        //    process terminate. Up to use to remove zombies
-        // Opted for option b/ however we do *NOT* change action type, we just fob
-        if (task) {
-            if (!task->flag().is_set(ecf::Flag::KILLED)) {
-
-                action_taken += "kill & fob";
-
-                // Kill the task, separate process, will typically send kill -15 to script.
-                task->kill(theZombie.process_or_remote_id());
-            }
-            else {
-                action_taken += "kill(already killed, fobing instead)";
-            }
-        }
-        else {
-            action_taken += "kill(no task, fobing instead)";
-        }
-#ifdef DEBUG_ZOMBIE
-        std::cout << " >>>KILL<<< zombies_.size(" << zombies_.size() << ")\n";
-#endif
-        theReply = PreAllocatedReply::ok_cmd(); // do not block the script, fob
-        return false;
-    }
-
-    // *REMOVE* Typically Removal is immediate(i.e. via ZombieCmd), However this could have been set via ZombieAttribute
-    if (theZombie.remove()) {
-        /// Ask ClientInvoker to continue blocking, Zombie may re-appear
-        action_taken += "remove";
-        bool remove_ok = remove(path_to_task, process_or_remote_id, process_password);
-        if (!remove_ok)
-            (void)remove_by_path(path_to_task);
-
-#ifdef DEBUG_ZOMBIE
-        std::cout << " >>>REMOVE<<< zombies_.size(" << zombies_.size() << ") : BLOCKING ";
-        if (!remove_ok)
-            std::cout << " >>>ERROR<<<< Remove failed ";
-#endif
-        theReply = PreAllocatedReply::block_client_zombie_cmd(theZombie.type());
-        return false;
-    }
-
-    // *DEFAULT*:
-    //       Label,event,meter             : fob
-    //       init,complete,abort,queue,wait: block
-    if (task_cmd->child_type() == Child::LABEL || task_cmd->child_type() == Child::EVENT ||
-        task_cmd->child_type() == Child::METER) {
-
-        /// Means return as if everything is OK. hence ClientInvoker will *NOT* block, and job can continue.
-#ifdef DEBUG_ZOMBIE
-        std::cout << ": FOB\n";
-#endif
-        action_taken += "fob";
-        theReply = PreAllocatedReply::ok_cmd();
-        return false;
-    }
-
-#ifdef DEBUG_ZOMBIE
-    std::cout << ": BLOCKING\n";
-#endif
-    // i.e it will make several attempts , and then start contacting servers in the hosts file.
-    action_taken += "block";
-    theReply = PreAllocatedReply::block_client_zombie_cmd(theZombie.type());
-    return false;
-}
-
-void ZombieCtrl::add_user_zombies(const std::vector<Submittable*>& tasks, const std::string& user_cmd) {
-    size_t taskVecSize = tasks.size();
-    for (size_t i = 0; i < taskVecSize; i++) {
-        Submittable* t = tasks[i];
-        if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
-
-            Zombie& theExistingZombie = find(t);
-            if (theExistingZombie.empty()) {
-
-#ifdef DEBUG_ZOMBIE
-                std::cout << "   ZombieCtrl::do_add_user_zombies " << t->absNodePath() << " "
-                          << t->process_or_remote_id() << " " << t->jobsPassword() << "\n";
-#endif
-
-                ZombieAttr attr = ZombieAttr::get_default_attr(Child::USER); // get the default USER zombie attribute
-                t->findParentZombie(Child::USER, attr);                      // Override default from the node tree
-
-                zombies_.emplace_back(Child::USER,
-                                      Child::INIT,
-                                      attr,
-                                      t->absNodePath(),
-                                      t->jobsPassword(),
-                                      t->process_or_remote_id(),
-                                      t->try_no(),
-                                      "",
-                                      user_cmd);
-
-                /// Mark task as zombie for xcdp
-                t->flag().set(ecf::Flag::ZOMBIE);
-            }
-        }
-    }
-}
-
-void ZombieCtrl::add_user_zombies(Node* node, const std::string& user_cmd) {
-    if (!node)
-        return;
-    std::vector<Submittable*> tasks;
-    node->get_all_active_submittables(tasks);
-    add_user_zombies(tasks, user_cmd);
-}
-
-void ZombieCtrl::add_user_zombies(defs_ptr defs, const std::string& user_cmd) {
-    if (!defs.get())
-        return;
-    std::vector<Submittable*> tasks;
-    defs->get_all_active_submittables(tasks);
-    add_user_zombies(tasks, user_cmd);
-}
-
-/// Returns the list of zombies, **updated** with seconds since creation
-void ZombieCtrl::get(std::vector<Zombie>& ret) {
-
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-
-    size_t zombieVecSize = zombies_.size();
-    ret.reserve(zombieVecSize);
-    for (size_t i = 0; i < zombieVecSize; i++) {
-
-        time_duration duration = time_now - zombies_[i].creation_time();
-        zombies_[i].set_duration(duration.total_seconds());
-
-        ret.push_back(zombies_[i]);
-    }
-}
-
-void ZombieCtrl::remove_stale_zombies(const boost::posix_time::ptime& time_now) {
-    for (auto i = zombies_.begin(); i != zombies_.end(); ++i) {
-        time_duration duration = time_now - (*i).creation_time();
-        if (duration.total_seconds() > (*i).allowed_age()) {
-#ifdef DEBUG_ZOMBIE
-            std::cout << "   ZombieCtrl::remove_stale_zombies " << (*i) << "\n";
-#endif
-            zombies_.erase(i--);
-        }
-    }
-}
-
-void ZombieCtrl::fob(const std::string& path_to_task,
-                     const std::string& process_or_remote_id,
-                     const std::string& password) {
-
-    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
-    if (theExistingZombie.empty())
-        return;
-    theExistingZombie.set_fob();
-}
-
-void ZombieCtrl::fobCli(const std::string& path_to_task, Submittable* task) {
-
-    if (task) {
-        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
-        /// If zombie password does *NOT* match then this is the real zombie.
-        size_t zombieVecSize = zombies_.size();
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
-                zombies_[i].set_fob();
-                return;
-            }
-        }
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task &&
-                zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
-                zombies_[i].set_fob();
-                return;
-            }
-        }
-    }
-
-    /// The best we can do
-    Zombie& theExistingZombie = find_by_path(path_to_task);
-    if (theExistingZombie.empty())
-        return;
-    theExistingZombie.set_fob();
-}
-
-void ZombieCtrl::fail(const std::string& path_to_task,
-                      const std::string& process_or_remote_id,
-                      const std::string& password) {
-
-    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
-    if (theExistingZombie.empty())
-        return;
-    theExistingZombie.set_fail();
-}
-
-void ZombieCtrl::failCli(const std::string& path_to_task, Submittable* task) {
-
-    if (task) {
-        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
-        /// If zombie password does *NOT* match then this is the real zombie.
-        size_t zombieVecSize = zombies_.size();
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
-                zombies_[i].set_fail();
-                return;
-            }
-        }
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task &&
-                zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
-                zombies_[i].set_fail();
-                return;
-            }
-        }
-    }
-
-    /// The best we can do
-    Zombie& theExistingZombie = find_by_path(path_to_task);
-    if (theExistingZombie.empty())
-        return;
-    theExistingZombie.set_fail();
-}
-
-void ZombieCtrl::adopt(const std::string& path_to_task,
-                       const std::string& process_or_remote_id,
-                       const std::string& password) {
-
-    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
-    if (theExistingZombie.empty())
-        return;
-    theExistingZombie.set_adopt();
-}
-
-void ZombieCtrl::adoptCli(const std::string& path_to_task, Submittable* task) {
-
-    if (!task) {
-        throw std::runtime_error("ZombieCtrl::adoptCli: Can't adopt zombie, there is no corresponding task!");
-    }
-
-    /// ***************************************************************************************
-    /// IMPORTANT: We should *NEVER* adopt a zombie, when the process id are different
-    /// This can end up, with two process running, Will mess up job output, as well as corruption caused
-    /// but running the same job twice. Better to kill both and re-queue.
-    /// Note: PBS can create two process, i.e same password, different PID's
-    /// ***************************************************************************************
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (zombies_[i].path_to_task() == path_to_task &&
-            zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
-            std::stringstream ss;
-            ss << "ZombieCtrl::adoptCli: Can *not* adopt zombies, where process id are different. Task("
-               << task->process_or_remote_id() << ") zombie(" << zombies_[i].process_or_remote_id()
-               << "). Please kill both process, and re-queue";
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
-    /// If zombie password does *NOT* match then this is the real zombie.
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
-            zombies_[i].set_adopt();
-            return;
-        }
-    }
-}
-
-void ZombieCtrl::block(const std::string& path_to_task,
-                       const std::string& process_or_remote_id,
-                       const std::string& password) {
-
-    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
-    if (theExistingZombie.empty())
-        return;
-    theExistingZombie.set_block();
-}
-
-void ZombieCtrl::blockCli(const std::string& path_to_task, Submittable* task) {
-
-    if (!task) {
-        throw std::runtime_error("ZombieCtrl::blockCli: Can't block zombie, there is no corresponding task for path " +
-                                 path_to_task);
-    }
-    else {
-        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
-        /// If zombie password does *NOT* match then this is the real zombie.
-        size_t zombieVecSize = zombies_.size();
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
-                zombies_[i].set_block();
-                return;
-            }
-        }
-    }
-}
-
-void ZombieCtrl::kill(const std::string& path_to_task,
-                      const std::string& process_or_remote_id,
-                      const std::string& password) {
-
-    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
-    if (theExistingZombie.empty())
-        return;
-    theExistingZombie.set_kill();
-}
-
-void ZombieCtrl::killCli(const std::string& path_to_task, Submittable* task) {
-
-    if (!task) {
-        throw std::runtime_error("ZombieCtrl::killCli: Can't kill zombie, there is no corresponding task for path " +
-                                 path_to_task);
-    }
-
-    /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
-    /// If zombie password does *NOT* match then this is the real zombie.
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
-            task->kill(zombies_[i].process_or_remote_id());
-            zombies_[i].set_kill();
-            return;
-        }
-    }
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (zombies_[i].path_to_task() == path_to_task &&
-            zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
-            task->kill(zombies_[i].process_or_remote_id());
-            zombies_[i].set_kill();
-            return;
-        }
-    }
-    /// The best we can do
-    Zombie& theExistingZombie = find_by_path(path_to_task);
-    if (theExistingZombie.empty()) {
-        throw std::runtime_error("ZombieCtrl::killCli: Can't kill, could not locate zombie(and hence pid) for path: " +
-                                 path_to_task);
-    }
-    task->kill(theExistingZombie.process_or_remote_id());
-    theExistingZombie.set_kill();
-    remove_by_path(path_to_task);
-}
-
-/// Called by the child commands, ie complete and abort
-/// Hence remove zombie with matching password/process id ?
-bool ZombieCtrl::remove(Submittable* t) {
-    if (t) {
-        return remove(t->absNodePath(), t->process_or_remote_id(), t->jobsPassword());
-    }
-    return false;
-}
-
-bool ZombieCtrl::remove(const std::string& path_to_task,
-                        const std::string& process_or_remote_id,
-                        const std::string& password) {
-
-    /// Note: Its possible for two separate jobs to have the same password. (submit 1, submit 2) before job1 active,
-    /// password overridden by submit 2 Hence remove needs to at least match process_id
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (match(zombies_[i], path_to_task, process_or_remote_id, password)) {
-            // #ifdef DEBUG_ZOMBIE
-            //			std::cout << "   ZombieCtrl::remove " << zombies_[i] << " \n";
-            // #endif
-            zombies_.erase(zombies_.begin() + i);
-            return true;
-        }
-    }
-    return false;
-}
-
-void ZombieCtrl::removeCli(const std::string& path_to_task, Submittable* task) {
-
-    if (task) {
-        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
-        /// If zombie password does *NOT* match then this is the real zombie.
-        size_t zombieVecSize = zombies_.size();
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
-#ifdef DEBUG_ZOMBIE
-                std::cout << "   ZombieCtrl::removeCli " << zombies_[i] << " \n";
-#endif
-                zombies_.erase(zombies_.begin() + i);
-                return;
-            }
-        }
-        for (size_t i = 0; i < zombieVecSize; i++) {
-            if (zombies_[i].path_to_task() == path_to_task &&
-                zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
-#ifdef DEBUG_ZOMBIE
-                std::cout << "   ZombieCtrl::removeCli " << zombies_[i] << " \n";
-#endif
-                zombies_.erase(zombies_.begin() + i);
-                return;
-            }
-        }
-    }
-
-    /// The best we can do
-    (void)remove_by_path(path_to_task);
-}
-
-bool ZombieCtrl::remove_by_path(const std::string& path_to_task) {
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (zombies_[i].path_to_task() == path_to_task) {
-#ifdef DEBUG_ZOMBIE
-            std::cout << "   ZombieCtrl::remove_by_path : " << zombies_[i] << " \n";
-#endif
-            zombies_.erase(zombies_.begin() + i);
-            return true;
-        }
-    }
-    return false;
-}
-
-/// Query
-const Zombie& ZombieCtrl::find(const std::string& path_to_task,
-                               const std::string& process_or_remote_id,
-                               const std::string& password) const {
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (match(zombies_[i], path_to_task, process_or_remote_id, password)) {
-            return zombies_[i];
-        }
-    }
-    return Zombie::EMPTY();
-}
-
-//================= private ===================================================================
-
-Zombie& ZombieCtrl::find(Submittable* task) {
-    if (task)
-        return find_zombie(task->absNodePath(), task->process_or_remote_id(), task->jobsPassword());
-    return Zombie::EMPTY_();
-}
-
-const Zombie& ZombieCtrl::find(Submittable* task) const {
-    if (task)
-        return find(task->absNodePath(), task->process_or_remote_id(), task->jobsPassword());
-    return Zombie::EMPTY();
-}
-
-Zombie& ZombieCtrl::find_zombie(const std::string& path_to_task,
-                                const std::string& process_or_remote_id,
-                                const std::string& password) {
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (match(zombies_[i], path_to_task, process_or_remote_id, password)) {
-            return zombies_[i];
-        }
-    }
-    return find_by_path(path_to_task);
-}
-
-bool match(const Zombie& z,
-           const std::string& path_to_task,
-           const std::string& process_or_remote_id,
-           const std::string& password) {
-    ///  Process/remote id only created when task becomes active.
-    if (z.path_to_task() == path_to_task) {
-        if (process_or_remote_id.empty() || z.process_or_remote_id().empty()) {
-            if (z.jobs_password() == password) {
-                return true;
-            }
-        }
-        else if (z.process_or_remote_id() == process_or_remote_id) {
-            return true;
-        }
-    }
-    return false;
-}
-
-Zombie& ZombieCtrl::find_by_path(const std::string& path_to_task) {
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (zombies_[i].path_to_task() == path_to_task) {
-            return zombies_[i];
-        }
-    }
-    return Zombie::EMPTY_();
-}
-
-const Zombie& ZombieCtrl::find_by_path_only(const std::string& path_to_task) const {
-    size_t zombieVecSize = zombies_.size();
-    for (size_t i = 0; i < zombieVecSize; i++) {
-        if (zombies_[i].path_to_task() == path_to_task) {
-            return zombies_[i];
-        }
-    }
-    return Zombie::EMPTY();
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/ZombieCtrl.hpp 5.13.0-1/Base/src/ecflow/base/ZombieCtrl.hpp
--- 5.12.4-1/Base/src/ecflow/base/ZombieCtrl.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ZombieCtrl.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,138 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_ZombieCtrl_HPP
-#define ecflow_base_ZombieCtrl_HPP
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/attribute/Zombie.hpp"
-#include "ecflow/base/Cmd.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-class TaskCmd;
-class AbstractServer;
-
-///
-/// \brief manages the zombies
-///
-
-/// All zombies are auto deleted after a period of time. See Zombie::allowed_age()
-class ZombieCtrl {
-public:
-    ZombieCtrl()                  = default;
-    ZombieCtrl(const ZombieCtrl&) = delete;
-    ZombieCtrl(ZombieCtrl&&)      = delete;
-
-    ZombieCtrl& operator=(const ZombieCtrl&) = delete;
-    ZombieCtrl& operator=(ZombieCtrl&&)      = delete;
-
-    /// Handle the zombie, and return back to the client
-    bool handle_zombie(Submittable*,              // Must be NON NULL
-                       const TaskCmd* task_cmd,   // The child command
-                       std::string& action_taken, // action taken
-                       STC_Cmd_ptr& theReply      // Reply varies according to User Action
-    );
-
-    bool handle_path_zombie(AbstractServer* as,        // Find closest matching node
-                            const TaskCmd* task_cmd,   // The child command
-                            std::string& action_taken, // action taken
-                            STC_Cmd_ptr& theReply      // Reply varies according to User Action
-    );
-
-    /// Find all *Tasks* beneath the input Node, that are in active or submitted states
-    /// We deliberately ignore aliases (This was requested by Axel)
-    /// Then add as 'USER' zombies. This should be called when commands like, delete, requeue,
-    /// run, are using the force option, and will create zombies.
-    void add_user_zombies(Node*, const std::string& user_cmd);
-    void add_user_zombies(defs_ptr, const std::string& user_cmd);
-    void add_user_zombies(const std::vector<Submittable*>& tasks, const std::string& user_cmd);
-
-    /// Returns the list of zombies, **updated** with seconds since creation
-    /// To avoid sending attr to client, we copy over its setting, if in effect
-    void get(std::vector<Zombie>&);
-
-    /// remove all zombies, older than their allowed age
-    /// Server typically checks every 60 seconds
-    void remove_stale_zombies(const boost::posix_time::ptime& time_now);
-
-    /// Will ask the child command to terminate, *without* the child command raising any errors
-    /// Since we can have many child commands(init,event,meter, label,complete) in a job
-    /// This fob must stay around, since we don't know how long the job will last for.
-    /// Will override, fail,recover,remove
-    /// For Command Line Interface only the task_path is provided. Just have to make do.
-    void fob(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
-    void fobCli(const std::string& path_to_task, Submittable*);
-
-    /// Similar to a fob, But will ask the child command to terminate, with an error.
-    /// Typically this will raise a trap in the job file, and hence raise an abort
-    /// However the abort will also be a zombie, and will also be auto-terminated
-    /// Hence the job file must be careful to use 'set -e' to avoid infinite recursion
-    /// Since we can have many child commands(init,event,meter, label,complete) in a job
-    /// This fob must stay around, since we don't know how long the job will last for.
-    /// Will override, fob,recover,remove
-    /// For Command Line Interface only the task_path is provided. Just have to make do.
-    void fail(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
-    void failCli(const std::string& path_to_task, Submittable*);
-
-    /// Find the task node, corresponding to the zombie, and copy over
-    /// the password. Then remove the zombie. Next time the child commands
-    /// communicate with the server, all will be ok
-    /// Will override, fail,fob,remove
-    /// For Command Line Interface only the task_path is provided. Just have to make do.
-    void adopt(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
-    void adoptCli(const std::string& path_to_task, Submittable*);
-    void block(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
-    void blockCli(const std::string& path_to_task, Submittable*);
-    void kill(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
-    void killCli(const std::string& path_to_task, Submittable*);
-
-    /// Remove the zombie corresponding to the Task path. Should only be one
-    /// Since we can have many child commands(init,event,meter, label,complete) in a job
-    /// the zombies may get re-added, should we rember this.
-    /// If path not found does nothing.
-    /// For Command Line Interface only the task_path is provided. Just have to make do.
-    bool remove(Submittable*);
-    bool remove(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
-    void removeCli(const std::string& path_to_task, Submittable*);
-    bool remove_by_path(const std::string& path_to_task);
-
-    /// Query
-    const Zombie&
-    find(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password) const;
-    const Zombie& find_by_path_only(const std::string& path_to_task) const;
-
-private:
-    bool handle_existing_zombie(Zombie&,                        // The server already knows about the zombie
-                                Submittable*,                   // This NULL for path zombies
-                                node_ptr closest_matching_node, // only set for path zombies
-                                const TaskCmd* task_cmd,        // The child command
-                                std::string& action_taken,      // User action taken
-                                STC_Cmd_ptr& theReply           // Reply varies according to User Action
-    );
-
-    bool handle_user_actions(Zombie&,                   // The server already knows about the zombie
-                             Submittable*,              // This NULL for path zombies
-                             const TaskCmd* task_cmd,   // The child command
-                             std::string& action_taken, // User action taken
-                             STC_Cmd_ptr& theReply      // Reply varies according to User Action
-    );
-
-    Zombie&
-    find_zombie(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
-    Zombie& find(Submittable*);
-    const Zombie& find(Submittable*) const;
-    Zombie& find_by_path(const std::string& path_to_task);
-
-private:
-    std::vector<Zombie> zombies_;
-};
-
-#endif /* ecflow_base_ZombieCtrl_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/ClientToServerCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/ClientToServerCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/ClientToServerCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/ClientToServerCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,228 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-
-#include <iostream>
-#include <stdexcept>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/EditHistoryMgr.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/CmdContext.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace std;
-using namespace boost;
-using namespace ecf;
-
-// #define DEBUG_INVARIANTS 1
-
-ClientToServerCmd::ClientToServerCmd() : cl_host_(Host().name()) {
-}
-
-ClientToServerCmd::~ClientToServerCmd() = default;
-
-bool ClientToServerCmd::equals(ClientToServerCmd* rhs) const {
-    return hostname() == rhs->hostname();
-}
-
-STC_Cmd_ptr ClientToServerCmd::handleRequest(AbstractServer* as) const {
-    // Allow creating of new time stamp, when *not* in a command. i.e during node tree traversal in server
-    CmdContext cmdContext;
-
-    // Automatically flush log file at the end of the command
-    LogFlusher logFlusher;
-
-    // Create the log time stamp once for a given request
-    Log::instance()->cache_time_stamp();
-
-    // LOG the command, *BEFORE* invoking it. (i.e in case server hangs/crashes)
-    // Allow override in the rare cases, where we want to output additional debug
-    // If logging fails set late flag to warn users, ECFLOW-536
-    do_log(as);
-
-#ifdef DEBUG_INVARIANTS
-    LOG_ASSERT(as->defs(), "ClientToServerCmd::handleRequest: Start:  No defs? ");
-    std::string errmsg;
-    if (!as->defs()->checkInvariants(errmsg)) {
-        LOG(Log::ERR, "ClientToServerCmd::handleRequest: PreCondition: Failed invariant checking:" << errmsg);
-    }
-#endif
-
-    // LogTimer timer("ClientToServerCmd::handleRequest");
-    STC_Cmd_ptr halted;
-    if (!authenticate(as, halted)) {
-        assert(halted.get());
-        return halted;
-    }
-
-    // mark edited nodes, with edit history. relies on doHandleRequest to populate edit_history_nodes_/paths
-    // hence must at the same scope level
-    EditHistoryMgr edit_history_mgr(this, as);
-
-    // Handle the request, and return the reply back to the client
-    STC_Cmd_ptr server_to_client_ptr = doHandleRequest(as);
-    if (isWrite() && server_to_client_ptr->ok()) {
-
-        // This can end up, check pointing the defs file
-        as->nodeTreeStateChanged();
-    }
-
-#ifdef DEBUG_INVARIANTS
-    LOG_ASSERT(as->defs(), "ClientToServerCmd::handleRequest: End:  No defs? ");
-    std::string errmsg;
-    if (!as->defs()->checkInvariants(errmsg)) {
-        LOG(Log::ERR, "ClientToServerCmd::handleRequest: PostCondition: Failed invariant checking:" << errmsg);
-    }
-#endif
-
-    return server_to_client_ptr;
-}
-
-void ClientToServerCmd::do_log(AbstractServer* as) const {
-    std::string ss;
-    print(ss);                // Populate the stream with command details:
-    if (!log(Log::MSG, ss)) { // will automatically add end of line
-        // problems with opening or writing to log file, warn users, ECFLOW-536
-        as->defs()->flag().set(ecf::Flag::LOG_ERROR);
-        as->defs()->set_server().add_or_update_user_variables("ECF_LOG_ERROR", Log::instance()->log_error());
-    }
-}
-
-STC_Cmd_ptr ClientToServerCmd::doJobSubmission(AbstractServer* as) {
-    // This function could be called at the end of *USER* command that can change state.
-    //
-    // We could have other tasks/jobs dependent on the state change. i.e end of time series
-    // This will traverse the node tree and resolve dependencies and may force
-    // Other jobs to be generated, due to the state change.
-    // However *** errors in job submission ***, should *NOT* typically abort the command.
-    // Since we will typically just set task to aborted state
-
-    // This job generation will timeout if job generation takes longer than next poll time.
-    as->traverse_node_tree_and_job_generate(Calendar::second_clock_time(), true /* user cmd context */);
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-node_ptr ClientToServerCmd::find_node(Defs* defs, const std::string& absNodepath) const {
-    node_ptr theNode = defs->findAbsNode(absNodepath);
-    if (!theNode.get()) {
-
-        std::string errorMsg = "Cannot find node at path '";
-        errorMsg += absNodepath;
-        errorMsg += "' ";
-        throw std::runtime_error(errorMsg);
-    }
-    return theNode;
-}
-
-void ClientToServerCmd::dumpVecArgs(const char* argOption, const std::vector<std::string>& args) {
-    cout << "  " << argOption;
-    for (size_t i = 0; i < args.size(); i++) {
-        cout << " args[" << i << "]='" << args[i] << "'";
-    }
-    cout << "\n";
-}
-
-node_ptr ClientToServerCmd::find_node_for_edit(Defs* defs, const std::string& absNodepath) const {
-    node_ptr theNode = find_node(defs, absNodepath);
-    add_node_for_edit_history(theNode);
-    return theNode;
-}
-
-node_ptr ClientToServerCmd::find_node_for_edit_no_throw(Defs* defs, const std::string& absNodepath) const {
-    node_ptr theNode = defs->findAbsNode(absNodepath);
-    add_node_for_edit_history(theNode);
-    return theNode;
-}
-
-void ClientToServerCmd::add_node_for_edit_history(Defs* defs, const std::string& absNodepath) const {
-    add_node_for_edit_history(defs->findAbsNode(absNodepath));
-}
-
-void ClientToServerCmd::add_node_for_edit_history(node_ptr the_node) const {
-    if (the_node.get())
-        edit_history_nodes_.push_back(the_node);
-}
-
-void ClientToServerCmd::add_node_path_for_edit_history(const std::string& absNodepath) const {
-    edit_history_node_paths_.push_back(absNodepath);
-}
-
-void ClientToServerCmd::add_edit_history(Defs* defs) const {
-    if (!use_EditHistoryMgr_) {
-        return; // edit history will be added by the command
-    }
-
-    // record all the user edits to the node. Reuse the time stamp cache created in handleRequest()
-    if (edit_history_nodes_.empty() && edit_history_node_paths_.empty()) {
-
-        defs->flag().set(ecf::Flag::MESSAGE);
-        add_edit_history(defs, Str::ROOT_PATH());
-    }
-    else {
-        // edit_history_node_paths_ is only populated by the delete command
-        size_t the_size = edit_history_node_paths_.size();
-        if (the_size != 0)
-            defs->flag().set(ecf::Flag::MESSAGE);
-        for (size_t i = 0; i < the_size; i++) {
-            add_delete_edit_history(defs, edit_history_node_paths_[i]);
-        }
-
-        the_size = edit_history_nodes_.size();
-        for (size_t i = 0; i < the_size; i++) {
-            node_ptr edited_node = edit_history_nodes_[i].lock();
-            if (edited_node.get()) {
-                // Setting the flag will make a state change. But its OK command allows it.
-                // Since we only get called if command can make state changes (isWrite() == true)
-                SuiteChangedPtr suiteChanged(edited_node.get());
-                edited_node->flag().set(ecf::Flag::MESSAGE); // trap state change in suite for sync
-                add_edit_history(defs, edited_node->absNodePath());
-            }
-        }
-    }
-
-    edit_history_nodes_.clear();
-    edit_history_node_paths_.clear();
-}
-
-void ClientToServerCmd::add_edit_history(Defs* defs, const std::string& path) const {
-    // Note: if the cts_cmd_, had thousands of paths, calling  cts_cmd_->print(ss); will append those paths to the
-    //       output, HUGE performance bottle neck, Since we are recording what command was applied to each node
-    //       we ONLY need the single path.
-    //
-    //       The old code hacked around this issue by doing vector<string>().swap(paths_);in handleRequest()
-    //       This caused its own set of problems. JIRA 434
-    // See: Client/bin/gcc-4.8/release/perf_test_large_defs
-
-    // record all the user edits to the node. Reuse the time stamp cache created in handleRequest()
-    std::string ss("MSG:");
-    ss += Log::instance()->get_cached_time_stamp();
-
-    print(ss, path); // custom print
-    defs->add_edit_history(path, ss);
-}
-
-void ClientToServerCmd::add_delete_edit_history(Defs* defs, const std::string& path) const {
-    // History is added to Str::ROOT_PATH(), but the path must show deleted node path
-    std::string ss("MSG:");
-    ss += Log::instance()->get_cached_time_stamp();
-
-    print(ss, path); // custom print
-    defs->add_edit_history(Str::ROOT_PATH(), ss);
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/ClientToServerCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/ClientToServerCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/ClientToServerCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/ClientToServerCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,196 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_ClientToServerCmd_HPP
-#define ecflow_base_cts_ClientToServerCmd_HPP
-
-#include <boost/program_options.hpp>
-
-#include "ecflow/base/Cmd.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-class AbstractServer;
-class AbstractClientEnv;
-class GroupCTSCmd;
-
-///////////////////////////////////////////////////////////////////////////////////
-// Client->Server cmd's
-///////////////////////////////////////////////////////////////////////////////////
-class ClientToServerCmd {
-public:
-    virtual ~ClientToServerCmd();
-
-    /// The host where the client was called
-    const std::string& hostname() const { return cl_host_; }
-
-    /// The second print is for use by EditHistoryMgr when we have commands that take multiple paths
-    /// The EditHistoryMgr records what command was applied to each node. However when logging the
-    /// the command we do not want logs all the paths, for each node.(performance bottleneck
-    /// when dealing with thousands of paths)
-    virtual void print(std::string& os) const = 0;
-    virtual void print(std::string& os, const std::string& /*path*/) const { print(os); }
-
-    /// Print the command without trailing <user>@<host>. Used by Group command, avoids duplicate user@host for each
-    /// child command
-    virtual void print_only(std::string& os) const { return print(os); }
-
-    /// Print with minimal information. Deals with errors report where cmd have thousands of paths. truncate to one
-    /// path. This should *NOT* include trailing <user>@<host>
-    virtual std::string print_short() const {
-        std::string ret;
-        print_only(ret);
-        return ret;
-    }
-
-    virtual bool equals(ClientToServerCmd* rhs) const;
-
-    /// Called by the _server_ to service the client depending on the Command
-    /// The server will pass itself down via the AbstractServer
-    /// The returned Server to Client  command is sent back to the client
-    /// Uses template pattern, it first authenticates request and then calls
-    /// doHandleRequest. This function can throw exceptions. std::runtime_error
-    STC_Cmd_ptr handleRequest(AbstractServer*) const;
-
-    /// After handleRequest() has run, this function can be used reclaim memory
-    virtual void cleanup() {}
-
-    /// Returns true if handleRequest is testable. Only used in TEST
-    virtual bool handleRequestIsTestable() const { return true; }
-
-    /// How long in seconds the client to attempt to send request and get a reply back
-    /// before the request fails. This timeout affects the wait for the outward request
-    /// and inward reply.
-    ///
-    /// The timeout feature allow the client to fail gracefully in the case
-    /// where the server has died/crashed. The timeout will ensure the socket is closed.
-    /// allowing the server to be restarted without getting the address is use error.
-    ///
-    /// NOTE: We also have a timeout in ClientInvoker/ClientEnvironment, *that* is different,
-    ///       as that applies to CHILD/task commands, and control how long we continue
-    ///       to iterate over the hosts files
-    virtual int timeout() const { return 60; }
-
-    /// A command can be read only command or write only command
-    /// A read only command will not change the state of the suites in the server
-    /// A write only command can modify the state of suite in the server
-    /// Used by the server for authentication since only write only users are allowed to edit.
-    virtual bool isWrite() const { return false; /* returning false means read only */ }
-
-    /// Some read only commands under exceptional situation can modify the DEFS.
-    /// i.e if write permission is removed from ECF_HOME then the check_pt command can fail
-    /// in which case if can set flags, Flag::LATE, Flag::CHECKPT_ERROR, Flag::LOG_ERROR to warn the users
-    /// This function is used to avoid unnecessary warning message.
-    virtual bool is_mutable() const { return false; }
-
-    /// Some commands modify the server but do not affect defs. i.e reload white list file,password file
-    /// Other like ClientHandleCmd make edits to defs(well kind off) but are read only.(i.e anyone can call them)
-    /// This return true for those commands that affect the defs, that we need sync on the client side.
-    virtual bool cmd_updates_defs() const { return isWrite(); }
-
-    /// This Must be called for client->server commands.As this is required
-    /// for authentication. *However* task based commands have their own authentication
-    /// mechanism, and don't need setup_user_authentification().
-    virtual void setup_user_authentification(const std::string& user, const std::string& passwd) = 0; // Used by PlugCmd
-    virtual bool setup_user_authentification(AbstractClientEnv&) = 0; // set user and passwd
-    virtual void setup_user_authentification()                   = 0; // if user empty setup.
-
-    /// Allow control over connection to different servers/hosts if the main server is down
-    /// i.e for a getCmd, we do not want to wait 24 hours, trying all the servers
-    /// However for Task based commands like , init,abort,event, meter,complete we
-    /// want this behaviour as it can alter Node tree state and thus affect dependent nodes
-    virtual bool connect_to_different_servers() const { return false; }
-
-    /// The show occurs on the client side
-    virtual PrintStyle::Type_t show_style() const { return PrintStyle::NOTHING; }
-
-    // Other commands
-    virtual bool get_cmd() const { return false; }
-    virtual bool task_cmd() const { return false; }
-    virtual bool terminate_cmd() const { return false; }
-    virtual bool group_cmd() const { return false; }
-    virtual bool ping_cmd() const { return false; }
-    virtual bool why_cmd(std::string&) const { return false; }
-    virtual bool show_cmd() const { return false; }
-    virtual void add_edit_history(Defs*) const;
-
-    // used by group_cmd to postfix syncCmd on all user commands that modify defs
-    virtual void set_client_handle(int /*client_handle*/) {} // used by group_cmd
-    virtual void set_group_cmd(const GroupCTSCmd*) {}
-
-    // CLIENT side Parse and command construction, create can throw std::runtime_error for errors
-    virtual const char* theArg() const                                              = 0; // used for argument parsing
-    virtual void addOption(boost::program_options::options_description& desc) const = 0;
-    virtual void
-    create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const = 0;
-
-protected:
-    ClientToServerCmd();
-
-    /// called by handleRequest, part of the template pattern
-    virtual STC_Cmd_ptr doHandleRequest(AbstractServer*) const = 0;
-
-    /// return true if authentication succeeds, false and STC_Cmd_ptr to return otherwise
-    /// This function is called from doHandleRequest and hence is called
-    /// from within the server. The default implementation will get the current
-    /// user and authenticate with reference to the white list file
-    virtual bool authenticate(AbstractServer*, STC_Cmd_ptr&) const = 0;
-
-    /// Log the command. Must typically be done before call doHandleRequest(), in case of crash/exception
-    /// In rare case allow override. (i.e for additional debug)
-    /// called by handleRequest, part of the template pattern
-    /// If logging fails set late flag to warn users ECFLOW-536
-    virtual void do_log(AbstractServer*) const;
-
-    /// Some commands which cause a change in state, should force an immediate job submission.
-    /// Providing the server is *NOT* shutdown
-    static STC_Cmd_ptr doJobSubmission(AbstractServer* as);
-
-    static void dumpVecArgs(const char* argOption, const std::vector<std::string>& args);
-
-    /// Find the node otherwise throw std:::runtime_error
-    node_ptr find_node(Defs*, const std::string& absNodepath) const;
-
-    /// Find The node for edit, otherwise throw std:::runtime_error
-    /// Will add the node edit history collection
-    node_ptr find_node_for_edit(Defs*, const std::string& absNodepath) const;
-
-    /// Find The node for edit, otherwise return a NULL pointer
-    /// Will add the node edit history collection
-    node_ptr find_node_for_edit_no_throw(Defs*, const std::string& absNodepath) const;
-
-    /// finds the associated node and adds to edit history nodes
-    void add_node_for_edit_history(Defs* as, const std::string& absNodepath) const;
-    void add_node_for_edit_history(node_ptr) const;
-    void add_node_path_for_edit_history(const std::string& absNodepath) const;
-
-    void add_edit_history(Defs*, const std::string& path) const;
-    void add_delete_edit_history(Defs*, const std::string& path) const;
-
-    mutable bool use_EditHistoryMgr_{
-        true}; // sometime quicker to add edit history in command, than using EditHistoryMgr
-private:
-    friend class GroupCTSCmd;
-    friend class EditHistoryMgr;
-    mutable std::vector<weak_node_ptr> edit_history_nodes_;    // NOT persisted
-    mutable std::vector<std::string> edit_history_node_paths_; // NOT persisted, used when deleting
-
-    std::string cl_host_; // The host where the client was called
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(CEREAL_NVP(cl_host_));
-    }
-};
-
-#endif /* ecflow_base_cts_ClientToServerCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/CtsCmdRegistry.cpp 5.13.0-1/Base/src/ecflow/base/cts/CtsCmdRegistry.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/CtsCmdRegistry.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/CtsCmdRegistry.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,182 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/CtsCmdRegistry.hpp"
-
-#include <memory>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/cts/task/AbortCmd.hpp"
-#include "ecflow/base/cts/task/CompleteCmd.hpp"
-#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
-#include "ecflow/base/cts/task/EventCmd.hpp"
-#include "ecflow/base/cts/task/InitCmd.hpp"
-#include "ecflow/base/cts/task/LabelCmd.hpp"
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-#include "ecflow/base/cts/task/QueueCmd.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/CFileCmd.hpp"
-#include "ecflow/base/cts/user/CSyncCmd.hpp"
-#include "ecflow/base/cts/user/CheckPtCmd.hpp"
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
-#include "ecflow/base/cts/user/DeleteCmd.hpp"
-#include "ecflow/base/cts/user/EditScriptCmd.hpp"
-#include "ecflow/base/cts/user/ForceCmd.hpp"
-#include "ecflow/base/cts/user/FreeDepCmd.hpp"
-#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
-#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
-#include "ecflow/base/cts/user/LogCmd.hpp"
-#include "ecflow/base/cts/user/LogMessageCmd.hpp"
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/cts/user/PlugCmd.hpp"
-#include "ecflow/base/cts/user/QueryCmd.hpp"
-#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/base/cts/user/RunNodeCmd.hpp"
-#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
-#include "ecflow/base/cts/user/ShowCmd.hpp"
-#include "ecflow/base/cts/user/ZombieCmd.hpp"
-
-namespace po = boost::program_options;
-
-CtsCmdRegistry::CtsCmdRegistry(bool addGroupCmd) {
-    // If a new client to server command is added. Make sure to add it here.
-    // Could have used static initialisation' but this is less problematic.
-
-    /// The order dictates how the --help is shown *BUT* Since we traverse this list.
-    /// Place the command which require the fastest response first.
-    vec_.reserve(90);
-
-    vec_.push_back(std::make_shared<CSyncCmd>(CSyncCmd::NEWS, 0, 0, 0));
-    vec_.push_back(std::make_shared<CSyncCmd>(CSyncCmd::SYNC, 0, 0, 0));
-    vec_.push_back(std::make_shared<CSyncCmd>(0)); // SYNC_FULL
-    vec_.push_back(std::make_shared<CSyncCmd>(CSyncCmd::SYNC_CLOCK, 0, 0, 0));
-    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET));
-    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET_STATE));
-    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::MIGRATE));
-    vec_.push_back(std::make_shared<CheckPtCmd>());
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::PING));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RESTORE_DEFS_FROM_CHECKPT));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RESTART_SERVER));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::HALT_SERVER));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::SHUTDOWN_SERVER));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::TERMINATE_SERVER));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RELOAD_WHITE_LIST_FILE));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RELOAD_PASSWD_FILE));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::FORCE_DEP_EVAL));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::STATS));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::STATS_SERVER));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::STATS_RESET));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_ON));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_OFF));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::SERVER_LOAD));
-    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::JOB_GEN));
-    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::CHECK_JOB_GEN_ONLY));
-    vec_.push_back(std::make_shared<DeleteCmd>());
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::SUSPEND));
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::RESUME));
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::KILL));
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::STATUS));
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::CHECK));
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::EDIT_HISTORY));
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::ARCHIVE));
-    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::RESTORE));
-    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::FOB));
-    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::FAIL));
-    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::ADOPT));
-    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::BLOCK));
-    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::REMOVE));
-    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::KILL));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::GET_ZOMBIES));
-    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::SUITES));
-    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::REGISTER));
-    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::DROP));
-    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::DROP_USER));
-    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::ADD));
-    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::REMOVE));
-    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::AUTO_ADD));
-    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::SUITES));
-    vec_.push_back(std::make_shared<LogCmd>());
-    vec_.push_back(std::make_shared<ServerVersionCmd>());
-    vec_.push_back(std::make_shared<LogMessageCmd>());
-    vec_.push_back(std::make_shared<BeginCmd>());
-    vec_.push_back(std::make_shared<InitCmd>());
-    vec_.push_back(std::make_shared<CompleteCmd>());
-    vec_.push_back(std::make_shared<AbortCmd>());
-    vec_.push_back(std::make_shared<CtsWaitCmd>());
-    vec_.push_back(std::make_shared<EventCmd>());
-    vec_.push_back(std::make_shared<MeterCmd>());
-    vec_.push_back(std::make_shared<LabelCmd>());
-    vec_.push_back(std::make_shared<QueueCmd>());
-    vec_.push_back(std::make_shared<RequeueNodeCmd>());
-    vec_.push_back(std::make_shared<OrderNodeCmd>());
-    vec_.push_back(std::make_shared<RunNodeCmd>());
-    vec_.push_back(std::make_shared<ForceCmd>());
-    vec_.push_back(std::make_shared<FreeDepCmd>());
-    vec_.push_back(std::make_shared<LoadDefsCmd>());
-    vec_.push_back(std::make_shared<ReplaceNodeCmd>());
-    vec_.push_back(std::make_shared<CFileCmd>());
-    vec_.push_back(std::make_shared<EditScriptCmd>());
-    vec_.push_back(std::make_shared<AlterCmd>());
-    vec_.push_back(std::make_shared<QueryCmd>());
-    vec_.push_back(std::make_shared<PlugCmd>());
-    // Note: we deliberately do not add MoveCmd, as it should not appear in the public api
-    //       It is created on the fly by the PlugCmd
-
-    /// Command that can *ONLY* be used in a group command
-    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::WHY));
-    vec_.push_back(std::make_shared<ShowCmd>());
-    if (addGroupCmd)
-        vec_.push_back(std::make_shared<GroupCTSCmd>());
-}
-
-bool CtsCmdRegistry::parse(Cmd_ptr& cmd,
-                           boost::program_options::variables_map& vm,
-                           AbstractClientEnv* clientEnv) const {
-    for (const auto& registered_cmd : vec_) {
-
-        if (vm.count(registered_cmd->theArg())) {
-
-            if (clientEnv->debug())
-                std::cout << "  CtsCmdRegistry::parse matched with registered command " << registered_cmd->theArg()
-                          << "\n";
-
-            registered_cmd->create(cmd, vm, clientEnv);
-            return true;
-        }
-    }
-
-    return false;
-}
-
-void CtsCmdRegistry::addAllOptions(boost::program_options::options_description& desc) const {
-    addCmdOptions(desc);
-    addHelpOption(desc);
-}
-
-void CtsCmdRegistry::addCmdOptions(boost::program_options::options_description& desc) const {
-    for (const auto& registered_cmd : vec_) {
-        registered_cmd->addOption(desc);
-    }
-}
-
-void CtsCmdRegistry::addHelpOption(boost::program_options::options_description& desc) const {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    desc.add_options()("help,h", po::value<std::string>()->implicit_value(std::string("")), "Produce help message");
-    desc.add_options()("version,v", "Show ecflow client version number, and version of the boost library used");
-    desc.add_options()("debug,d",
-                       "Enables the display of client environment settings and execution details.\n"
-                       "Has the same effect as setting environment variable ECF_DEBUG_CLIENT.");
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/CtsCmdRegistry.hpp 5.13.0-1/Base/src/ecflow/base/cts/CtsCmdRegistry.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/CtsCmdRegistry.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/CtsCmdRegistry.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_CtsCmdRegistry_HPP
-#define ecflow_base_cts_CtsCmdRegistry_HPP
-
-#include <vector>
-
-#include <boost/program_options.hpp>
-
-#include "ecflow/base/Cmd.hpp"
-
-class AbstractClientEnv;
-
-///
-/// \brief Registration of all the client to server commands
-///
-/// This allows us to parse the arg associated with commands in this category.
-/// The idea is to keep new commands functionality in one place.
-/// Any new client to server commands that are created must be added to this class.
-///
-
-class CtsCmdRegistry {
-public:
-    CtsCmdRegistry(const CtsCmdRegistry&)                  = delete;
-    const CtsCmdRegistry& operator=(const CtsCmdRegistry&) = delete;
-
-    explicit CtsCmdRegistry(bool addGroupCmd = true);
-
-    /// These option describe the arguments for each of the commands
-    /// They also can be presented to the user via --help option.
-    void addAllOptions(boost::program_options::options_description& desc) const;
-    void addCmdOptions(boost::program_options::options_description& desc) const;
-
-    /// Parse arguments given in 'vm' and use that to create a command
-    /// that will be sent to the server. Will throw std::runtime_error for errors
-    /// Returns true if command line argument specified via 'vm', matches one of the
-    /// registered command.
-    /// *** This allows us to distinguish between where we match with a registered
-    /// *** command, but do *NOT* set Cmd_ptr, ie since its a client specific command
-    /// *** i.e there is no need to send it to the server
-    bool parse(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const;
-
-private:
-    std::vector<Cmd_ptr> vec_;
-
-    void addHelpOption(boost::program_options::options_description& desc) const;
-};
-
-#endif /* ecflow_base_cts_CtsCmdRegistry_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/EditHistoryMgr.cpp 5.13.0-1/Base/src/ecflow/base/cts/EditHistoryMgr.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/EditHistoryMgr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/EditHistoryMgr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/EditHistoryMgr.hpp"
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace boost;
-using namespace ecf;
-
-EditHistoryMgr::EditHistoryMgr(const ClientToServerCmd* c, AbstractServer* a)
-    : cts_cmd_(c),
-      as_(a),
-      state_change_no_(Ecf::state_change_no()),
-      modify_change_no_(Ecf::modify_change_no()) {
-    assert(cts_cmd_->edit_history_nodes_.empty());
-    assert(cts_cmd_->edit_history_node_paths_.empty());
-}
-
-EditHistoryMgr::~EditHistoryMgr() {
-    // check if state changed
-    if (state_change_no_ != Ecf::state_change_no() || modify_change_no_ != Ecf::modify_change_no()) {
-
-        // Ignore child commands for edit history, where only interested in user commands
-        if (!cts_cmd_->task_cmd()) {
-
-            // *ONLY* record edit history to commands that change the data model
-            // Otherwise we will end up making a data model change for read only commands
-            // If there has been a change in defs state then the command must return true from isWrite
-            if (cts_cmd_->isWrite()) {
-                cts_cmd_->add_edit_history(as_->defs().get());
-            }
-            else {
-                // Read only command, that is making data model changes, oops ?
-                // Can happen with check pt command, when ecf_home can't be written to, (exceptional)
-                // i.e set late flag( when saving takes more the 30 seconds) *OR* Flag::CHECKPT_ERROR | Flag::LOG_ERROR
-                //       even though its read only command. In which case is_mutable() should return true.
-                if (!cts_cmd_->is_mutable()) {
-                    std::string ss;
-                    cts_cmd_->print(ss);
-                    cout << "cmd " << ss << " should return true from isWrite() ******************\n";
-                    cout << "Read only command is making data changes to defs ?????\n";
-                    cout << "Ecf::state_change_no() " << Ecf::state_change_no() << " Ecf::modify_change_no() "
-                         << Ecf::modify_change_no() << "\n";
-                    cout << "state_change_no_       " << state_change_no_ << " modify_change_no_       "
-                         << modify_change_no_ << "\n";
-                    cout.flush();
-                }
-            }
-        }
-    }
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/EditHistoryMgr.hpp 5.13.0-1/Base/src/ecflow/base/cts/EditHistoryMgr.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/EditHistoryMgr.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/EditHistoryMgr.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_EditHistoryMgr_HPP
-#define ecflow_base_cts_EditHistoryMgr_HPP
-
-class ClientToServerCmd;
-class AbstractServer;
-
-///
-/// \brief This class manages the edit history, for the commands.
-/// It determines if there was a state change, if there was, it adds edit
-/// history to the stored nodes.
-/// Additionally we check that if there was an edit then the command must
-/// return ClientToServerCmd::isWrite() true.
-///
-
-class EditHistoryMgr {
-public:
-    EditHistoryMgr()                      = delete;
-    EditHistoryMgr(const EditHistoryMgr&) = delete;
-    EditHistoryMgr(const ClientToServerCmd*, AbstractServer*);
-    ~EditHistoryMgr();
-
-    EditHistoryMgr& operator=(const EditHistoryMgr&) = delete;
-
-private:
-    const ClientToServerCmd* cts_cmd_;
-    AbstractServer* as_;
-    mutable unsigned int state_change_no_;  // detect state change in defs
-    mutable unsigned int modify_change_no_; // detect state change in defs
-};
-
-#endif /* ecflow_base_cts_EditHistoryMgr_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/AbortCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/AbortCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/AbortCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/AbortCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,134 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/AbortCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-AbortCmd::AbortCmd(const std::string& pathToTask,
-                   const std::string& jobsPassword,
-                   const std::string& process_or_remote_id,
-                   int try_no,
-                   const std::string& reason)
-    : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-      reason_(reason) {
-    if (!reason_.empty()) {
-        // Do not use "\n" | ';' in Submittable::abr_, as this can mess up, --migrate output
-        // Which would then affect --load.
-        Str::replace(reason_, "\n", "");
-        Str::replace(reason_, ";", " ");
-    }
-}
-
-void AbortCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += "abort ";
-    os += path_to_node();
-    os += "  ";
-    os += reason_;
-}
-
-bool AbortCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<AbortCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (reason_ != the_rhs->reason())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-STC_Cmd_ptr AbortCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_abort_++;
-
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-
-    {
-        /// If there is an associated zombie, remove from the list
-        as->zombie_ctrl().remove(submittable_);
-
-        // update suite change numbers before job submission, submittable_ setup during authentication
-        SuiteChanged1 changed(submittable_->suite());
-
-        string theReason = reason_;
-        if (theReason.empty())
-            theReason = "Trap raised in job file";
-
-        submittable_->aborted(theReason); // will set task->set_state(NState::ABORTED);
-    }
-
-    // Do job submission in case any triggers dependent on NState::ABORTED
-    // If task try number is less than ECF_TRIES we attempt to re-submit the job.(ie if still in limit)
-    as->increment_job_generation_count();
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* AbortCmd::arg() {
-    return TaskApi::abortArg();
-}
-const char* AbortCmd::desc() {
-    return "Mark task as aborted. For use in the '.ecf' script file *only*\n"
-           "Hence the context is supplied via environment variables\n"
-           "  arg1 = (optional) string(reason)\n"
-           "         Optionally provide a reason why the abort was raised\n\n"
-           "If this child command is a zombie, then the default action will be to *block*.\n"
-           "The default can be overridden by using zombie attributes.\n"
-           "Otherwise the blocking period is defined by ECF_TIMEOUT.\n\n"
-           "Usage:\n"
-           "  ecflow_client --abort=reasonX";
-}
-
-void AbortCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(AbortCmd::arg(), po::value<string>()->implicit_value(string()), AbortCmd::desc());
-}
-void AbortCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    std::string reason = vm[arg()].as<std::string>();
-
-    if (clientEnv->debug())
-        cout << "  AbortCmd::create " << AbortCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
-             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
-             << clientEnv->task_try_no() << ") reason(" << reason << ")\n";
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("AbortCmd: " + errorMsg);
-    }
-
-    cmd = std::make_shared<AbortCmd>(clientEnv->task_path(),
-                                     clientEnv->jobs_password(),
-                                     clientEnv->process_or_remote_id(),
-                                     clientEnv->task_try_no(),
-                                     reason);
-}
-
-std::ostream& operator<<(std::ostream& os, const AbortCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(AbortCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(AbortCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/AbortCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/AbortCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/AbortCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/AbortCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,54 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_AbortCmd_HPP
-#define ecflow_base_cts_task_AbortCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-
-class AbortCmd final : public TaskCmd {
-public:
-    AbortCmd(const std::string& pathToTask,
-             const std::string& jobsPassword,
-             const std::string& process_or_remote_id,
-             int try_no                = 1,
-             const std::string& reason = "");
-    AbortCmd() : TaskCmd() {}
-
-    const std::string& reason() const { return reason_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::ABORT; }
-
-    std::string reason_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(reason_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const AbortCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(AbortCmd)
-
-#endif /* ecflow_base_cts_task_AbortCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/CompleteCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/CompleteCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/CompleteCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/CompleteCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,124 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/CompleteCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-void CompleteCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += "complete ";
-    os += path_to_node();
-    if (!var_to_del_.empty()) {
-        os += " --remove";
-        for (const auto& var_to_del : var_to_del_) {
-            os += " ";
-            os += var_to_del;
-        }
-    }
-}
-
-bool CompleteCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<CompleteCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (var_to_del_ != the_rhs->variables_to_delete())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-STC_Cmd_ptr CompleteCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_complete_++;
-
-    {
-        /// If there is an associated zombie, remove from the list. Must match,
-        /// Do this before task->complete(), since that clears password & process id
-        /// remove(..) uses password/ process id to match the right zombie
-        as->zombie_ctrl().remove(submittable_);
-
-        // update suite change numbers before job submission, submittable_ setup during authentication
-        SuiteChanged1 changed(submittable_->suite());
-        submittable_->complete(); // will set task->set_state(NState::COMPLETE);
-
-        for (const auto& var_to_delete : var_to_del_) {
-            submittable_->delete_variable_no_error(var_to_delete);
-        }
-    }
-
-    // Do job submission in case any triggers dependent on NState::COMPLETE
-    as->increment_job_generation_count();
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* CompleteCmd::arg() {
-    return TaskApi::completeArg();
-}
-const char* CompleteCmd::desc() {
-    return "Mark task as complete. For use in the '.ecf' script file *only*\n"
-           "Hence the context is supplied via environment variables\n\n"
-           "If this child command is a zombie, then the default action will be to *block*.\n"
-           "The default can be overridden by using zombie attributes.\n"
-           "Otherwise the blocking period is defined by ECF_TIMEOUT.\n"
-           "The init command allows variables to be added, and complete command\n"
-           "allows for them to be removed.\n"
-           "  arg1(--remove)(optional) = a list of variables to removed from this task\n\n"
-           "Usage:\n"
-           "  ecflow_client --complete\n"
-           "  ecflow_client --complete --remove name1 name2 # delete variables name1 and name2 on the task";
-}
-
-void CompleteCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(CompleteCmd::arg(), CompleteCmd::desc())(
-        "remove", po::value<vector<string>>()->multitoken(), "remove variables i.e name name2");
-}
-void CompleteCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    if (clientEnv->debug())
-        cout << "  CompleteCmd::create " << CompleteCmd::arg() << " task_path(" << clientEnv->task_path()
-             << ") password(" << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id()
-             << ") try_no(" << clientEnv->task_try_no() << ")\n";
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("CompleteCmd: " + errorMsg);
-    }
-
-    std::vector<std::string> variable_vec;
-    if (vm.count("remove"))
-        variable_vec = vm["remove"].as<vector<string>>();
-
-    cmd = std::make_shared<CompleteCmd>(clientEnv->task_path(),
-                                        clientEnv->jobs_password(),
-                                        clientEnv->process_or_remote_id(),
-                                        clientEnv->task_try_no(),
-                                        variable_vec);
-}
-
-std::ostream& operator<<(std::ostream& os, const CompleteCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(CompleteCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(CompleteCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/CompleteCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/CompleteCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/CompleteCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/CompleteCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_CompleteCmd_HPP
-#define ecflow_base_cts_task_CompleteCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-#include "ecflow/core/cereal_optional_nvp.hpp"
-
-class CompleteCmd final : public TaskCmd {
-public:
-    CompleteCmd(const std::string& pathToTask,
-                const std::string& jobsPassword,
-                const std::string& process_or_remote_id = "",
-                int try_no                              = 1,
-                const std::vector<std::string>& vec     = std::vector<std::string>())
-        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-          var_to_del_(vec) {}
-    CompleteCmd() : TaskCmd() {}
-
-    const std::vector<std::string>& variables_to_delete() const { return var_to_del_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::COMPLETE; }
-
-private:
-    std::vector<std::string> var_to_del_; //  variables to delete on task
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this));
-        CEREAL_OPTIONAL_NVP(ar, var_to_del_, [this]() { return !var_to_del_.empty(); }); // conditionally save
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const CompleteCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(CompleteCmd)
-
-#endif /* ecflow_base_cts_task_CompleteCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,439 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-// #define DEBUG_ZOMBIE 1
-
-bool TaskCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<TaskCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (path_to_submittable_ != the_rhs->path_to_node())
-        return false;
-    if (jobs_password_ != the_rhs->jobs_password())
-        return false;
-    if (process_or_remote_id_ != the_rhs->process_or_remote_id())
-        return false;
-    if (try_no_ != the_rhs->try_no())
-        return false;
-    return ClientToServerCmd::equals(rhs);
-}
-
-// **********************************************************************************
-// IMPORTANT: In the current SMS/ECF only the init child command, passes the
-// process_or_remote_id_, for *ALL* other child commands this is empty.
-// The Automated tests get round this via setting ECF_RID in the header/tail job includes
-// However since this may not be in .sms/.ecf files, we cannot rely on it
-// Hence we need to be able to handle *EMPTY* process_or_remote_id_ for child commands
-//
-//  Task State | Child                      | Log | Explanation
-//  -------------------------------------------------------------------------------------------------------------
-//  SUBMITTED  | child!=INIT                | ERR | Script has child command in back ground, Bug in script, out of order
-//  ACTIVE     | INIT & pid & passwd match  | WAR | two init commands, overloaded server, or 2*init in script, *FOB*.
-//  Forgive ACTIVE     | INIT & pid & passwd !match | ERR | two init commands, Task started again by user. COMPLETE   |
-//  COMPLETE                   | WAR | two complete, zombie, overloaded server. *FOB*, Allow job to complete. Forgive.
-//  COMPLETE   | child != COMPLETE          | ERR | zombie
-//  ABORTED    | ABORTED                    | WAR | two aborted, zombie, overloaded server. *FOB*, allow process to
-//  exit. Forgive ABORTED    | child != ABORTED           | WAR | zombie
-//  -------------------------------------------------------------------------------------------------------------------
-//
-//  zombie type    |   PID   | password | explanation
-//  ---------------------------------------------------------------------------------------------------------------
-//  ECF_PID        |    X    | matches  | PID miss-match, but password matches. Job scheduled twice. Check submitter
-//  ECF_PID_PASSWD |    X    |     X    | Both PID and password miss-match. Re-queue & submit of active job
-//  ECF_PASSWD     | matches |     X    | Password miss-match, PID matches, system has re-cycled PID or hacked job file?
-//  ECF            | matches | matches  | overloaded server,Two init commands or task complete or aborted but receives
-//  another child cmd USER           |    ?    |     ?    | User initiated zombie whilst task was active or submitted,
-//  command is recorded in zombie PATH           |   n/a   |    n/a   | Task not found. Nodes replaced whilst jobs were
-//  running
-//  ----------------------------------------------------------------------------------------------------------------
-bool TaskCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& theReply) const {
-#ifdef DEBUG_ZOMBIE
-    std::cout << "   TaskCmd::authenticate " << Child::to_string(child_type());
-    std::cout << " " << path_to_submittable_ << " " << process_or_remote_id_ << " " << jobs_password_ << " " << try_no_;
-    const Zombie& zombie = as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
-    if (!zombie.empty())
-        std::cout << "  " << zombie;
-    else {
-        const Zombie& zombiep = as->zombie_ctrl().find_by_path_only(path_to_submittable_);
-        if (!zombiep.empty())
-            std::cout << "  find_by_path_only: " << zombiep;
-    }
-#endif
-    /// ***************************************************************************
-    /// Task based cmd have their own authentication mechanism, hence we
-    /// Don't need to call the base class authenticate
-    /// **************************************************************************
-
-    if (!as->allowTaskCommunication()) {
-        // This is not an Error, hence we don't throw exception
-        theReply = PreAllocatedReply::block_client_server_halted_cmd();
-        return false;
-    }
-
-    submittable_ = get_submittable(as);
-    if (!submittable_) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << ": PATH Zombie\n";
-#endif
-        // Create path zombie, if not already created:
-        std::string action_taken;
-        static_cast<void>(as->zombie_ctrl().handle_path_zombie(as, this, action_taken, theReply));
-
-        // distinguish output by using *path*
-        std::stringstream ss;
-        ss << " zombie(*path*) : chd:" << ecf::Child::to_string(child_type()) << " : " << path_to_submittable_ << " : "
-           << process_or_remote_id_ << " : " << jobs_password_ << " : action(" << action_taken << ")";
-        log(Log::ERR, ss.str());
-        return false;
-    }
-
-    // If the CMD *WAS* created with Submittable::DUMMY_JOBS_PASSWORD then we were testing
-    // This will be copied from client to server, hence we want to avoid same check in the
-    // server. when handleRequest is called()
-    // DO NOT place #ifdef DEBUG otherwise test will start failing for the release build
-    if (jobs_password_ == Submittable::DUMMY_JOBS_PASSWORD()) {
-        return true;
-    }
-
-    SuiteChanged1 changed(submittable_->suite());
-
-    /// Check if User wants to explicitly bypass password checking
-    /// This can be done via AlterCmd by adding a variable on the task,  ECF_PASS with value
-    /// Submittable::FREE_JOBS_PASSWORD Note: this *does not* look for the variable up the node tree, only on the task.
-    std::string ecf_pass_value;
-    if (submittable_->findVariableValue(Str::ECF_PASS(), ecf_pass_value)) {
-
-        if (ecf_pass_value == Submittable::FREE_JOBS_PASSWORD()) {
-            submittable_->flag().clear(ecf::Flag::ZOMBIE);
-            return true;
-        }
-    }
-
-    /// Handle corner case ,where we have two jobs with different process id, but same password
-    /// Can happen if jobs is started externally,
-    /// or via test(i.e submit 1,submit 2(force)) before job1 active its password is overridden
-    bool submittable_allready_aborted  = false;
-    bool submittable_allready_active   = false;
-    bool submittable_allready_complete = false;
-    password_missmatch_                = false;
-    pid_missmatch_                     = false;
-
-    /// *** In complete state, the password is empty.
-    if (submittable_->jobsPassword() != jobs_password_) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << ": submittable pass(" << submittable_->jobsPassword() << ") != jobs_password_(" << jobs_password_
-                  << ")";
-#endif
-        password_missmatch_ = true;
-    }
-
-    /// When state is in SUBMITTED, its process/remote_id is EMPTY. It will be set by the INIT child command.
-    /// Hence we can *NOT* mark it as pid_missmatch.
-    ///
-    /// *** See Note above: Not all child commands pass a process_id. ***
-    /// *** Hence this test for zombies is ONLY valid if process sets the process_or_remote_id_ ****
-    /// *** User should really set ECF_RID in the scripts
-    /// *** In submitted state, the pid is empty. hence clear pid_missmatch_ below
-    /// *** In complete state, the pid is empty.  hence clear pid_missmatch_ below
-    if (!submittable_->process_or_remote_id().empty() && !process_or_remote_id_.empty() &&
-        submittable_->process_or_remote_id() != process_or_remote_id_) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << ":task pid(" << submittable_->process_or_remote_id() << ") != process pid("
-                  << process_or_remote_id_ << ")";
-#endif
-        pid_missmatch_ = true;
-    }
-
-    switch (submittable_->state()) {
-        case NState::SUBMITTED: {
-            // The pid on the task will be empty
-            if (child_type() != Child::INIT) {
-                std::stringstream ss;
-                ss << path_to_submittable_
-                   << " When a node is submitted, expected next child command to be INIT but received "
-                   << Child::to_string(child_type());
-                log(Log::ERR, ss.str());
-            }
-            break;
-        }
-
-        case NState::ACTIVE: {
-            if (child_type() == Child::INIT) {
-#ifdef DEBUG_ZOMBIE
-                std::cout << ":(child_type() == Child::INIT) && submittable_->state() == NState::ACTIVE)";
-#endif
-                // *IF* password and pid matches be more forgiving. How can this case arise:
-                // i.e server is heavily overloaded, client calls init, which times out because server is busy
-                // Client then sends init again. In this case rather than treating it as a zombie, we will let it
-                // through providing the password and pid matches.
-                if (!password_missmatch_ && !pid_missmatch_) {
-                    string ret = " [ overloaded || --init*2 ](pid and passwd match) : chd:";
-                    ret += ecf::Child::to_string(child_type());
-                    ret += " : ";
-                    ret += path_to_submittable_;
-                    ret += " : already active : action(fob)";
-                    log(Log::WAR, ret);
-                    theReply = PreAllocatedReply::ok_cmd();
-                    return false;
-                }
-                submittable_allready_active = true;
-            }
-            break;
-        }
-
-        case NState::COMPLETE: {
-#ifdef DEBUG_ZOMBIE
-            std::cout << ": submittable_->state() == NState::COMPLETE)";
-#endif
-            if (child_type() == Child::COMPLETE) {
-                // Note: when a node completes, we clear tasks password and pid, to save memory on checkpt & network
-                // bandwidth (We could choose not to clear, This would allow us to disambiguate between 2/ and 3/
-                // below). HOWEVER:
-                //
-                // How can this situation arise:
-                //   1/ Two calls to --complete  (rare)
-                //   2/ Overloaded server. Client send --complete to server, but it is overload and does not respond,
-                //   the client then
-                //      times out. Server handles the request. When client tries again we get here. (possible)
-                //   3/ Zombie, two separate process. (possible, typically done by user action)
-                //
-                // For all three it should be safe to just fob:
-                //   1/ Two calls to --complete # Be forgiving
-                //   2/ Overloaded server       # The correct course of action
-                //   3/ zombie                  # The zombie has completed anyway, don't bother blocking it
-
-                submittable_->flag().clear(ecf::Flag::ZOMBIE);
-                as->zombie_ctrl().remove_by_path(path_to_submittable_);
-
-                string ret = " [ overloaded || zombie || --complete*2 ] : chd:";
-                ret += ecf::Child::to_string(child_type());
-                ret += " : ";
-                ret += path_to_submittable_;
-                ret += " : already complete : action(fob)";
-                log(Log::WAR, ret);
-                theReply = PreAllocatedReply::ok_cmd();
-                return false;
-            }
-
-            // If Task state is complete, and we receive **any** child command then it is a zombie
-            submittable_allready_complete = true;
-            password_missmatch_           = false;
-            pid_missmatch_                = false;
-            break;
-        }
-
-        case NState::ABORTED: {
-#ifdef DEBUG_ZOMBIE
-            std::cout << ": submittable_->state() == NState::ABORTED)";
-#endif
-
-            if (child_type() == Child::ABORT) {
-
-                if (!password_missmatch_ && !pid_missmatch_) {
-
-                    as->zombie_ctrl().remove(submittable_);
-
-                    string ret = " [ overloaded || --abort*2 ] (pid and passwd match) : chd:";
-                    ret += ecf::Child::to_string(child_type());
-                    ret += " : ";
-                    ret += path_to_submittable_;
-                    ret += " : already aborted : action(fob)";
-                    log(Log::WAR, ret);
-                    theReply = PreAllocatedReply::ok_cmd();
-                    return false;
-                }
-            }
-
-            // If Task state is aborted, and we receive **any** child command then it is a zombie
-            submittable_allready_aborted = true;
-            password_missmatch_          = false;
-            pid_missmatch_               = false;
-            break;
-        }
-        case NState::QUEUED:
-            break; // WTF
-        case NState::UNKNOWN:
-            break; // WTF
-    }
-
-#ifdef DEBUG_ZOMBIE
-    std::cout << "\n";
-#endif
-
-    if (password_missmatch_ || pid_missmatch_ || submittable_allready_active || submittable_allready_complete ||
-        submittable_allready_aborted) {
-        /// If the task has adopted we return true, and carry on as normal
-        std::string action_taken;
-        if (!as->zombie_ctrl().handle_zombie(submittable_, this, action_taken, theReply)) {
-
-            // LOG failure: Include type of zombie.
-            // ** NOTE **: the zombie may have been removed by user actions. i.e if fob and child cmd is abort |
-            // complete, etc
-            std::stringstream ss;
-            ss << " zombie";
-            const Zombie& theZombie =
-                as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
-            if (!theZombie.empty())
-                ss << "(" << theZombie.type_str() << ")";
-
-            ss << " : chd:" << ecf::Child::to_string(child_type());
-            ss << " : " << path_to_submittable_ << "(" << NState::toString(submittable_->state()) << ")";
-            ss << " : " << process_or_remote_id_ << " : " << jobs_password_;
-            if (submittable_allready_active)
-                ss << " : already active";
-            if (submittable_allready_complete)
-                ss << " : already complete";
-            if (submittable_allready_aborted)
-                ss << " : already aborted";
-            if (password_missmatch_)
-                ss << " : passwd != [ task:" << submittable_->jobsPassword() << " child:" << jobs_password_ << " ]";
-            if (pid_missmatch_)
-                ss << " : pid != [ task:" << submittable_->process_or_remote_id() << " child:" << process_or_remote_id_
-                   << " ]";
-            ss << " : action(" << action_taken << ")";
-            log(Log::ERR, ss.str());
-            return false;
-        }
-    }
-    return true;
-}
-
-Submittable* TaskCmd::get_submittable(AbstractServer* as) const {
-    node_ptr node = as->defs()->findAbsNode(path_to_submittable_);
-    if (!node.get()) {
-        return nullptr;
-    }
-
-    return node->isSubmittable();
-}
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-CtsWaitCmd::CtsWaitCmd(const std::string& pathToTask,
-                       const std::string& jobsPassword,
-                       const std::string& process_or_remote_id,
-                       int try_no,
-                       const std::string& expression)
-    : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-      expression_(expression) {
-    // Parse expression to make sure its valid
-    static_cast<void>(Expression::parse(expression, "CtsWaitCmd:")); // will throw for errors
-}
-
-void CtsWaitCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += "wait ";
-    os += expression_;
-    os += " ";
-    os += path_to_node();
-}
-
-bool CtsWaitCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<CtsWaitCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (expression_ != the_rhs->expression())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-STC_Cmd_ptr CtsWaitCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_wait_++;
-
-    SuiteChanged1 changed(submittable_->suite());
-
-    // Parse the expression, should not fail since client should have already check expression parses
-    // The complete expression have been parsed and we have created the abstract syntax tree
-    // We now need CHECK the AST for path nodes, event and meter. repeats,etc.
-    // *** This will also set the Node pointers ***
-    // If the expression references paths that don't exist throw an error
-    // This can be captured in the ecf script, which should then abort the task
-    // Otherwise we will end up blocking indefinitely
-    std::unique_ptr<AstTop> ast =
-        submittable_->parse_and_check_expressions(expression_, true, "CtsWaitCmd:"); // will throw for errors
-
-    // Evaluate the expression
-    if (ast->evaluate()) {
-
-        submittable_->flag().clear(ecf::Flag::WAIT);
-
-        // expression evaluates, return OK
-        return PreAllocatedReply::ok_cmd();
-    }
-
-    submittable_->flag().set(ecf::Flag::WAIT);
-
-    // Block/wait while expression is false
-    return PreAllocatedReply::block_client_on_home_server_cmd();
-}
-
-const char* CtsWaitCmd::arg() {
-    return TaskApi::waitArg();
-}
-const char* CtsWaitCmd::desc() {
-    return "Evaluates an expression, and block while the expression is false.\n"
-           "For use in the '.ecf' file *only*, hence the context is supplied via environment variables\n"
-           "  arg1 = string(expression)\n\n"
-           "Usage:\n"
-           "  ecflow_client --wait=\"/suite/taskx == complete\"";
-}
-
-void CtsWaitCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(CtsWaitCmd::arg(), po::value<string>(), CtsWaitCmd::desc());
-}
-void CtsWaitCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    std::string expression = vm[arg()].as<std::string>();
-
-    if (clientEnv->debug())
-        cout << "  CtsWaitCmd::create " << CtsWaitCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
-             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
-             << clientEnv->task_try_no() << ") expression(" << expression << ")\n";
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("CtsWaitCmd: " + errorMsg);
-    }
-
-    cmd = std::make_shared<CtsWaitCmd>(clientEnv->task_path(),
-                                       clientEnv->jobs_password(),
-                                       clientEnv->process_or_remote_id(),
-                                       clientEnv->task_try_no(),
-                                       expression);
-}
-
-std::ostream& operator<<(std::ostream& os, const CtsWaitCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(CtsWaitCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(CtsWaitCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/CtsWaitCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_CtsWaitCmd_HPP
-#define ecflow_base_cts_task_CtsWaitCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-
-/// A child command that evaluates a expression. If the expression is false.
-/// Then client invoker will block.
-class CtsWaitCmd final : public TaskCmd {
-public:
-    CtsWaitCmd(const std::string& pathToTask,
-               const std::string& jobsPassword,
-               const std::string& process_or_remote_id,
-               int try_no,
-               const std::string& expression);
-    CtsWaitCmd() : TaskCmd() {}
-
-    const std::string& expression() const { return expression_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::WAIT; }
-
-    std::string expression_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(expression_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const CtsWaitCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(CtsWaitCmd)
-
-#endif /* ecflow_base_cts_task_CtsWaitCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/EventCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/EventCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/EventCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/EventCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,141 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/EventCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool EventCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<EventCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (name_ != the_rhs->name())
-        return false;
-    if (value_ != the_rhs->value())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-void EventCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += "event ";
-    os += name_;
-    os += " ";
-    if (value_)
-        os += "1 ";
-    else
-        os += "0 ";
-    os += path_to_node();
-}
-
-STC_Cmd_ptr EventCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_event_++;
-
-    { // update suite change numbers before job submission,  task_ setup during authentication
-        SuiteChanged1 changed(submittable_->suite());
-
-        // The name could either be "string" or an integer either way it should be unique
-        if (!submittable_->set_event(name_, value_)) {
-            std::string ss;
-            ss = "Event request failed as event '";
-            ss += name_;
-            ss += "' does not exist on task ";
-            ss += path_to_node();
-            ecf::log(Log::ERR, ss);
-            return PreAllocatedReply::ok_cmd();
-        }
-    }
-
-    // Do job submission in case any triggers dependent on events
-    as->increment_job_generation_count();
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* EventCmd::arg() {
-    return TaskApi::eventArg();
-}
-const char* EventCmd::desc() {
-    return "Change event. For use in the '.ecf' script file *only*\n"
-           "Hence the context is supplied via environment variables\n"
-           "  arg1(string | int)     = event-name\n\n"
-           "  arg2(string)(optional) = [ set | clear] default value is set\n\n"
-           "If this child command is a zombie, then the default action will be to *fob*,\n"
-           "i.e allow the ecflow client command to complete without an error\n"
-           "The default can be overridden by using zombie attributes.\n\n"
-           "Usage:\n"
-           "  ecflow_client --event=ev       # set the event, default since event initial value is clear\n"
-           "  ecflow_client --event=ev set   # set the event, explicit\n"
-           "  ecflow_client --event=ev clear # clear the event, use when event initial value is set\n";
-}
-
-void EventCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(EventCmd::arg(), po::value<vector<string>>()->multitoken(), EventCmd::desc());
-}
-void EventCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-    std::string event;
-    if (args.size() >= 1)
-        event = args[0];
-
-    bool value = true;
-    if (args.size() == 2) {
-        if (args[1] == "set")
-            value = true;
-        else if (args[1] == "clear")
-            value = false;
-        else {
-            std::stringstream ss;
-            ss << "EventCmd: The second argument must be [ set | clear ] but found " << args[1];
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    if (clientEnv->debug())
-        cout << "  EventCmd::create " << EventCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
-             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
-             << clientEnv->task_try_no() << ") event(" << event << ")"
-             << ") value(" << value << ")\n";
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("EventCmd: " + errorMsg);
-    }
-
-    cmd = std::make_shared<EventCmd>(clientEnv->task_path(),
-                                     clientEnv->jobs_password(),
-                                     clientEnv->process_or_remote_id(),
-                                     clientEnv->task_try_no(),
-                                     event,
-                                     value);
-}
-
-std::ostream& operator<<(std::ostream& os, const EventCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(EventCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(EventCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/EventCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/EventCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/EventCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/EventCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_EventCmd_HPP
-#define ecflow_base_cts_task_EventCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-#include "ecflow/core/cereal_optional_nvp.hpp"
-
-class EventCmd final : public TaskCmd {
-public:
-    EventCmd(const std::string& pathToTask,
-             const std::string& jobsPassword,
-             const std::string& process_or_remote_id,
-             int try_no,
-             const std::string& eventName,
-             bool value = true) // true = set(default), false = clear
-        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-          name_(eventName),
-          value_(value) {}
-    EventCmd() : TaskCmd() {}
-
-    const std::string& name() const { return name_; }
-    bool value() const { return value_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::EVENT; }
-
-private:
-    std::string name_; // the events name
-    bool value_{true}; // true = set(default), false = clear
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(name_));
-        CEREAL_OPTIONAL_NVP(ar, value_, [this]() { return !value_; }); // conditionally save if value is false
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const EventCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(EventCmd)
-
-#endif /* ecflow_base_cts_task_EventCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/InitCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/InitCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/InitCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/InitCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,154 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/InitCmd.hpp"
-
-#include <stdexcept>
-
-#include <cereal/cereal.hpp>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-void InitCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += "init ";
-    os += path_to_node();
-    if (!var_to_add_.empty()) {
-        os += " --add";
-        for (const auto& var_to_add : var_to_add_) {
-            os += " ";
-            os += var_to_add.name();
-            os += "=";
-            os += var_to_add.theValue();
-        }
-    }
-}
-
-bool InitCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<InitCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (var_to_add_ != the_rhs->variables_to_add())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-STC_Cmd_ptr InitCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_init_++;
-
-    { // update suite change numbers before job submission. submittable_ setup during authentication
-        SuiteChanged1 changed(submittable_->suite());
-        submittable_->init(process_or_remote_id()); // will set task->set_state(NState::ACTIVE);
-
-        for (const auto& var_to_add : var_to_add_) {
-            submittable_->addVariable(var_to_add); // will update or add variable
-        }
-    }
-
-    // Do job submission in case any triggers dependent on NState::ACTIVE
-    as->increment_job_generation_count();
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* InitCmd::arg() {
-    return TaskApi::initArg();
-}
-const char* InitCmd::desc() {
-    return "Mark task as started(active). For use in the '.ecf' script file *only*\n"
-           "Hence the context is supplied via environment variables.\n"
-           "  arg1(string)         = process_or_remote_id The process id of the job or remote_id\n"
-           "                         Using remote id allows the jobs to be killed\n"
-           "  arg2(--add)(optional)= add/update variables as name value pairs\n\n"
-           "If this child command is a zombie, then the default action will be to *block*.\n"
-           "The default can be overridden by using zombie attributes.\n"
-           "Otherwise the blocking period is defined by ECF_TIMEOUT.\n\n"
-           "Usage:\n"
-           "  ecflow_client --init=$$\n"
-           "  ecflow_client --init=$$ --add name=value name2=value2 # add/update variables to task";
-}
-
-void InitCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(InitCmd::arg(), po::value<string>(), InitCmd::desc())(
-        "add",
-        po::value<vector<string>>()->multitoken(),
-        "Add variables e.g. name1=value1 name2=value2. Can only be used in combination with --init command.");
-}
-
-void InitCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    std::string process_or_remote_id = vm[arg()].as<std::string>();
-
-    if (clientEnv->debug())
-        cout << "  InitCmd::create " << InitCmd::arg() << "  clientEnv->task_path(" << clientEnv->task_path()
-             << ") clientEnv->jobs_password(" << clientEnv->jobs_password() << ") clientEnv->process_or_remote_id("
-             << clientEnv->process_or_remote_id() << ") clientEnv->task_try_no(" << clientEnv->task_try_no()
-             << ") process_or_remote_id(" << process_or_remote_id << ") clientEnv->under_test("
-             << clientEnv->under_test() << ")\n";
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("InitCmd: " + errorMsg);
-    }
-
-    /// if ECF_RID is specified then it *MUST* be the same as input argument
-    /// On cca we ECF_RID can be specified under test, and therefore fail this check, hence we use
-    /// clientEnv->under_test()
-    if (!clientEnv->under_test() && !clientEnv->process_or_remote_id().empty() &&
-        clientEnv->process_or_remote_id() != process_or_remote_id) {
-        std::stringstream ss;
-        ss << "remote id(" << process_or_remote_id
-           << ") passed as an argument, not the same the client environment ECF_RID("
-           << clientEnv->process_or_remote_id() << ")";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::vector<Variable> variable_vec;
-    if (vm.count("add")) {
-        vector<string> var_args = vm["add"].as<vector<string>>();
-        if (!var_args.empty()) {
-            variable_vec.reserve(var_args.size());
-            for (const auto& v : var_args) {
-                std::vector<std::string> tokens;
-                Str::split(v, tokens, "=");
-                if (tokens.size() != 2) {
-                    throw std::runtime_error(
-                        "Could not parse variable provided to --add; Expected  var1=value1 var2=value2 but found " + v);
-                }
-                variable_vec.emplace_back(tokens[0], tokens[1]);
-            }
-        }
-    }
-
-    cmd = std::make_shared<InitCmd>(clientEnv->task_path(),
-                                    clientEnv->jobs_password(),
-                                    process_or_remote_id,
-                                    clientEnv->task_try_no(),
-                                    variable_vec);
-}
-
-std::ostream& operator<<(std::ostream& os, const InitCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(InitCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(InitCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/InitCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/InitCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/InitCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/InitCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_InitCmd_HPP
-#define ecflow_base_cts_task_InitCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-#include "ecflow/core/cereal_optional_nvp.hpp"
-
-class InitCmd final : public TaskCmd {
-public:
-    InitCmd(const std::string& pathToTask,
-            const std::string& jobsPassword,
-            const std::string& process_or_remote_id,
-            int try_no,
-            const std::vector<Variable>& vec = {})
-        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-          var_to_add_(vec) {}
-
-    InitCmd() : TaskCmd() {}
-
-    const std::vector<Variable>& variables_to_add() const { return var_to_add_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::INIT; }
-
-private:
-    std::vector<Variable> var_to_add_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this));
-        CEREAL_OPTIONAL_NVP(ar, var_to_add_, [this]() { return !var_to_add_.empty(); }); // conditionally save
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const InitCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(InitCmd)
-
-#endif /* ecflow_base_cts_task_InitCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/LabelCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/LabelCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/LabelCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/LabelCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,138 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/LabelCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool LabelCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<LabelCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (name_ != the_rhs->name())
-        return false;
-    if (label_ != the_rhs->label())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-void LabelCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += "label ";
-    os += name_;
-    os += " '";
-    os += label_;
-    os += "' ";
-    os += path_to_node();
-}
-
-STC_Cmd_ptr LabelCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_label_++;
-
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-
-    // submittable_ setup during authentication
-    if (submittable_->findLabel(name_)) {
-
-        SuiteChanged1 changed(submittable_->suite());
-        submittable_->changeLabel(name_, label_);
-    }
-    // else {
-    //   // ECFLOW-175, avoid filling up log file. Can get thousands of these messages, especially form MARS
-    //   std::string ss;
-    //   ss = "Label request failed as label '"; ss += name_; ss += "' does not exist on task "; ss += path_to_node();
-    //	  ecf::log(Log::ERR,ss);
-    //}
-
-    // Note: reclaiming memory for label_ earlier make *no* difference to performance of server
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* LabelCmd::arg() {
-    return TaskApi::labelArg();
-}
-const char* LabelCmd::desc() {
-    return "Change Label. For use in the '.ecf' script file *only*\n"
-           "Hence the context is supplied via environment variables\n"
-           "  arg1 = label-name\n"
-           "  arg2 = The new label value\n"
-           "         The labels values can be single or multi-line(space separated quoted strings)\n\n"
-           "If this child command is a zombie, then the default action will be to *fob*,\n"
-           "i.e allow the ecflow client command to complete without an error\n"
-           "The default can be overridden by using zombie attributes.\n\n"
-           "Usage:\n"
-           "  ecflow_client --label=progressed merlin";
-}
-
-void LabelCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(LabelCmd::arg(), po::value<vector<string>>()->multitoken(), LabelCmd::desc());
-}
-void LabelCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (clientEnv->debug()) {
-        dumpVecArgs(LabelCmd::arg(), args);
-        cout << "  LabelCmd::create " << LabelCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
-             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
-             << clientEnv->task_try_no() << ")\n";
-    }
-
-    if (args.size() < 2) {
-        std::stringstream ss;
-        ss << "LabelCmd: At least 2 arguments expected. Please specify: <label-name> <label-value>\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string labelName = args[0];
-    args.erase(args.begin()); // remove name from vector of strings
-    std::string labelValue;
-    for (size_t i = 0; i < args.size(); i++) {
-        if (i != 0)
-            labelValue += " ";
-        labelValue += args[i];
-    }
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("LabelCmd: " + errorMsg);
-    }
-
-    cmd = std::make_shared<LabelCmd>(clientEnv->task_path(),
-                                     clientEnv->jobs_password(),
-                                     clientEnv->process_or_remote_id(),
-                                     clientEnv->task_try_no(),
-                                     labelName,
-                                     labelValue);
-}
-
-std::ostream& operator<<(std::ostream& os, const LabelCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(LabelCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(LabelCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/LabelCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/LabelCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/LabelCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/LabelCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,61 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_LabelCmd_HPP
-#define ecflow_base_cts_task_LabelCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-
-class LabelCmd final : public TaskCmd {
-public:
-    LabelCmd(const std::string& pathToTask,
-             const std::string& jobsPassword,
-             const std::string& process_or_remote_id,
-             int try_no,
-             const std::string& name,
-             const std::string& label)
-        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-          name_(name),
-          label_(label) {}
-    LabelCmd() : TaskCmd() {}
-
-    const std::string& name() const { return name_; }
-    const std::string& label() const { return label_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::LABEL; }
-
-private:
-    std::string name_;  // the label name
-    std::string label_; // a single label, or multi-line label
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(name_), CEREAL_NVP(label_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const LabelCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(LabelCmd)
-
-#endif /* ecflow_base_cts_task_LabelCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/MeterCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/MeterCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/MeterCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/MeterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,159 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool MeterCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<MeterCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (name_ != the_rhs->name())
-        return false;
-    if (value_ != the_rhs->value())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-void MeterCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += "meter ";
-    os += name_;
-    os += " ";
-    os += ecf::convert_to<std::string>(value_);
-    os += " ";
-    os += path_to_node();
-}
-
-STC_Cmd_ptr MeterCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_meter_++;
-
-    { // Added scope for SuiteChanged1 changed: i.e update suite change numbers before job submission
-        // submittable_ setup during authentication
-        SuiteChanged1 changed(submittable_->suite());
-
-        /// Allow meter to set any valid value that is in range because:
-        ///   - When we have a network failure, and restoration. The meter tasks, will come in random, order.
-        ///   - When task is executed without a requee the meter value will less than maximum
-        ///
-        /// This has *IMPLICATION*, if the meter is used in a trigger, using a equality
-        /// operator, then the trigger will always hold.  hence suite designers need to
-        /// aware of this.
-        try {
-
-            Meter& the_meter = submittable_->find_meter(name_);
-            if (the_meter.empty()) {
-                LOG(Log::ERR,
-                    "MeterCmd::doHandleRequest: failed as meter '" << name_ << "' does not exist on task "
-                                                                   << path_to_node());
-                return PreAllocatedReply::ok_cmd();
-            }
-
-            /// Invalid meter values(out or range) will raise exceptions.
-            /// Just ignore the request rather than failing client cmd
-            the_meter.set_value(value_);
-        }
-        catch (std::exception& e) {
-            LOG(Log::ERR, "MeterCmd::doHandleRequest: failed for task " << path_to_node() << ". " << e.what());
-            return PreAllocatedReply::ok_cmd();
-        }
-    }
-
-    // Do job submission in case any triggers dependent on meters
-    as->increment_job_generation_count();
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* MeterCmd::arg() {
-    return TaskApi::meterArg();
-}
-const char* MeterCmd::desc() {
-    return "Change meter. For use in the '.ecf' script file *only*\n"
-           "Hence the context is supplied via environment variables\n"
-           "  arg1(string) = meter-name\n"
-           "  arg2(int)    = the new meter value\n\n"
-           "If this child command is a zombie, then the default action will be to *fob*,\n"
-           "i.e allow the ecflow client command to complete without an error\n"
-           "The default can be overridden by using zombie attributes.\n\n"
-           "Usage:\n"
-           "  ecflow_client --meter=my_meter 20";
-}
-
-void MeterCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(MeterCmd::arg(), po::value<vector<string>>()->multitoken(), MeterCmd::desc());
-}
-void MeterCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (clientEnv->debug()) {
-        dumpVecArgs(MeterCmd::arg(), args);
-        cout << "  MeterCmd::create " << MeterCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
-             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
-             << clientEnv->task_try_no() << ")\n";
-    }
-
-    if (args.size() != 2) {
-        std::stringstream ss;
-        ss << "MeterCmd: Two arguments expected, found " << args.size()
-           << " Please specify <meter-name> <meter-value>, ie --meter=name 100\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (args[0].empty()) {
-        throw std::runtime_error("MeterCmd: First argument must be a non-empty string, i.e. --meter=name 100\n");
-    }
-
-    int value = 0;
-    try {
-        std::string strVal = args[1];
-        value              = ecf::convert_to<int>(strVal);
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error("MeterCmd: Second argument must be a integer, i.e. --meter=name 100\n");
-    }
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("MeterCmd: " + errorMsg);
-    }
-
-    cmd = std::make_shared<MeterCmd>(clientEnv->task_path(),
-                                     clientEnv->jobs_password(),
-                                     clientEnv->process_or_remote_id(),
-                                     clientEnv->task_try_no(),
-                                     args[0],
-                                     value);
-}
-
-std::ostream& operator<<(std::ostream& os, const MeterCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(MeterCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(MeterCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/MeterCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/MeterCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/MeterCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/MeterCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,61 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_MeterCmd_HPP
-#define ecflow_base_cts_task_MeterCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-
-class MeterCmd final : public TaskCmd {
-public:
-    MeterCmd(const std::string& pathToTask,
-             const std::string& jobsPassword,
-             const std::string& process_or_remote_id,
-             int try_no,
-             const std::string& meterName,
-             int meterValue)
-        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-          name_(meterName),
-          value_(meterValue) {}
-    MeterCmd() : TaskCmd() {}
-
-    const std::string& name() const { return name_; }
-    int value() const { return value_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::METER; }
-
-private:
-    std::string name_; // the meters name
-    int value_{0};     // the meters value
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(name_), CEREAL_NVP(value_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const MeterCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(MeterCmd)
-
-#endif /* ecflow_base_cts_task_MeterCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/QueueCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/QueueCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/QueueCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/QueueCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,292 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/QueueCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool QueueCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<QueueCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (name_ != the_rhs->name())
-        return false;
-    if (action_ != the_rhs->action())
-        return false;
-    if (step_ != the_rhs->step())
-        return false;
-    if (path_to_node_with_queue_ != the_rhs->path_to_node_with_queue())
-        return false;
-    return TaskCmd::equals(rhs);
-}
-
-void QueueCmd::print(std::string& os) const {
-    os += Str::CHILD_CMD();
-    os += TaskApi::queue_arg();
-    os += " ";
-    os += name_;
-    os += " ";
-    os += action_;
-    os += " ";
-    os += step_;
-    os += " ";
-    if (path_to_node_with_queue_.empty()) {
-        os += path_to_node();
-        return;
-    }
-
-    os += path_to_node_with_queue_;
-    os += " ";
-    os += path_to_node();
-}
-
-STC_Cmd_ptr QueueCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().task_queue_++;
-    std::string result;
-
-    //////////////////////////////////////////////////////////////////////////////
-    // Return the current string value, and then increment the index
-    //////////////////////////////////////////////////////////////////////////////
-    { // Added scope for SuiteChanged1 changed: i.e update suite change numbers before job submission
-        // submittable_ setup during authentication
-        SuiteChanged1 changed(submittable_->suite());
-
-        if (!path_to_node_with_queue_.empty()) {
-            Defs* defs = submittable_->defs();
-            if (defs) {
-                node_ptr node_with_queue = defs->findAbsNode(path_to_node_with_queue_);
-                if (node_with_queue) {
-
-                    QueueAttr& queue_attr = node_with_queue->findQueue(name_);
-                    if (queue_attr.empty()) {
-                        std::stringstream ss;
-                        ss << "QueueCmd:: Could not find queue of name " << name_ << ", on input node "
-                           << path_to_node_with_queue_;
-                        return PreAllocatedReply::error_cmd(ss.str());
-                    }
-
-                    result = handle_queue(queue_attr);
-                }
-                else {
-                    std::stringstream ss;
-                    ss << "QueueCmd:: Could not find node at path " << path_to_node_with_queue_;
-                    return PreAllocatedReply::error_cmd(ss.str());
-                }
-            }
-        }
-        else {
-            bool fnd_queue        = false;
-            QueueAttr& queue_attr = submittable_->findQueue(name_);
-            if (queue_attr.empty()) {
-                Node* parent = submittable_->parent();
-                while (parent) {
-                    QueueAttr& queue_attr1 = parent->findQueue(name_);
-                    if (!queue_attr1.empty()) {
-                        fnd_queue = true;
-                        result    = handle_queue(queue_attr1);
-                        break;
-                    }
-                    parent = parent->parent();
-                }
-            }
-            else {
-                fnd_queue = true;
-                result    = handle_queue(queue_attr);
-            }
-
-            if (!fnd_queue) {
-                std::stringstream ss;
-                ss << "QueueCmd:: Could not find queue " << name_ << " Up the node hierarchy";
-                return PreAllocatedReply::error_cmd(ss.str());
-            }
-        }
-    }
-
-    // Do job submission in case any triggers dependent on QueueAttr
-    as->increment_job_generation_count();
-
-    if (result.empty())
-        return PreAllocatedReply::ok_cmd();
-    return PreAllocatedReply::string_cmd(result);
-}
-
-std::string QueueCmd::handle_queue(QueueAttr& queue_attr) const {
-    if (queue_attr.empty()) {
-        std::stringstream ss;
-        ss << "QueueCmd:: Could not find queue of name " << name_ << " . Program error !";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (action_ == "active")
-        return queue_attr.active(); // return current index and value, make active, update index
-    if (action_ == "complete")
-        queue_attr.complete(step_);
-    if (action_ == "aborted")
-        queue_attr.aborted(step_);
-    if (action_ == "no_of_aborted")
-        return queue_attr.no_of_aborted();
-    if (action_ == "reset")
-        queue_attr.reset_index_to_first_queued_or_aborted();
-
-    return std::string();
-}
-
-const char* QueueCmd::arg() {
-    return TaskApi::queue_arg();
-}
-const char* QueueCmd::desc() {
-    return "QueueCmd. For use in the '.ecf' script file *only*\n"
-           "Hence the context is supplied via environment variables\n"
-           "  arg1(string) = queue-name:\n"
-           "  arg2(string) = action: [active | aborted | complete | no_of_aborted | reset ]\n"
-           "     active: returns the first queued/aborted step, the return string is the queue value from the "
-           "definition\n"
-           "     no_of_aborted: returns number of aborted steps as a string, i.e 10\n"
-           "     reset: sets the index to the first queued/aborted step. Allows steps to be reprocessed for errors\n"
-           "  arg3(string) = step: value returned from step=$(ecflow_client --queue=queue_name active)\n"
-           "                This is only valid for complete and aborted steps\n"
-           "  arg4(string) = path: (optional). The path where the queue is defined.\n"
-           "                 By default we search for the queue up the node tree.\n\n"
-           "If this child command is a zombie, then the default action will be to *block*,\n"
-           "The default can be overridden by using zombie attributes."
-           "If the path to the queue is not defined, then this command will\n"
-           "search for the queue up the node hierarchy. If no queue found, command fails\n\n"
-           "Usage:\n"
-           "step=\"\"\n"
-           "QNAME=\"my_queue_name\"\n"
-           "while [1 == 1 ] ; do\n"
-           "   # this return the first queued/aborted step, then increments to next step, return <NULL> when all steps "
-           "processed\n"
-           "   step=$(ecflow_client --queue=$QNAME active) # of the form string  i.e \"003\". this step is now active\n"
-           "   if [[ $step == \"<NULL>\" ]] ; then\n"
-           "        break;\n"
-           "   fi\n"
-           "   ...\n"
-           "   ecflow_client --queue=$QNAME complete $step   # tell ecflow this step completed\n"
-           "done\n"
-           "\n"
-           "trap() { ecflow_client --queue=$QNAME aborted $step # tell ecflow this step failed }\n";
-}
-
-void QueueCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(QueueCmd::arg(), po::value<vector<string>>()->multitoken(), QueueCmd::desc());
-}
-void QueueCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (clientEnv->debug()) {
-        dumpVecArgs(QueueCmd::arg(), args);
-        cout << "  QueueCmd::create " << QueueCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
-             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
-             << clientEnv->task_try_no() << ")\n";
-    }
-
-    // expect:
-    //   <queue-name> [active | aborted | complete | no_of_aborted | reset ] step <path to node with queue>
-    std::string queue_name, step;
-    std::string path_to_node_with_queue, action;
-    for (size_t i = 0; i < args.size(); i++) {
-        if (i == 0)
-            queue_name = args[i];
-        else {
-            if (args[i] == "active" || args[i] == "aborted" || args[i] == "complete" || args[i] == "no_of_aborted" ||
-                args[i] == "reset") {
-                action = args[i];
-            }
-            else if (args[i].find('/') != std::string::npos)
-                path_to_node_with_queue = args[i];
-            else
-                step = args[i];
-        }
-    }
-    if (clientEnv->debug()) {
-        cout << "  QueueCmd::create "
-             << "queue-name:(" << queue_name << ") action:(" << action << ") step:(" << step
-             << ") path_to_node_with_queue:(" << path_to_node_with_queue << ")\n";
-    }
-
-    if (args.size() == 4 && path_to_node_with_queue.empty()) {
-        std::stringstream ss;
-        ss << "QueueCmd: The fourth argument if specified must provide a path to a node where the queue resides.\n"
-           << "No path specified. " << args[3];
-        throw std::runtime_error(ss.str());
-    }
-
-    if (args.empty() || queue_name.empty() || action.empty()) {
-        std::stringstream ss;
-        ss << "QueueCmd: incorrect argument specified, expected at least two arguments but found " << args.size()
-           << " Please specify <queue-name> [active | aborted | complete | no_of_aborted | reset ] step <path to node "
-              "with queue>(optional) i.e\n"
-           << "--queue=name active  # active does not need a step\n"
-           << "--queue=name active /path/to/node/with/queue\n"
-           << "--queue=name aborted $step\n"
-           << "--queue=name complete $step\n"
-           << "--queue=name no_of_aborted\n"
-           << "--queue=name reset\n";
-        throw std::runtime_error(ss.str());
-    }
-    if ((action == "complete" || action == "aborted") && step.empty()) {
-        std::stringstream ss;
-        ss << "QueueCmd: when --queue=name complete || --queue=name aborted is used a step must be provided e.g.\n"
-           << "  ecflow_client --queue=name aborted $step\n"
-           << "  ecflow_client --queue=name complete $step\n"
-           << "where step is value returned from active, such as\n"
-           << "  step=$(ecflow_client --queue=name active)\n";
-        throw std::runtime_error(ss.str());
-    }
-    if ((action == "active" || action == "reset" || action == "no_of_aborted") && !step.empty()) {
-        throw std::runtime_error("QueueCmd: step should not be used with active, reset or no_of_aborted.");
-    }
-
-    string msg;
-    if (!Str::valid_name(queue_name, msg)) {
-        throw std::runtime_error("QueueCmd: Invalid queue name : " + msg);
-    }
-
-    std::string errorMsg;
-    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
-        throw std::runtime_error("QueueCmd: " + errorMsg);
-    }
-
-    cmd = std::make_shared<QueueCmd>(clientEnv->task_path(),
-                                     clientEnv->jobs_password(),
-                                     clientEnv->process_or_remote_id(),
-                                     clientEnv->task_try_no(),
-                                     queue_name,
-                                     action,
-                                     step,
-                                     path_to_node_with_queue);
-}
-
-std::ostream& operator<<(std::ostream& os, const QueueCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(QueueCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(QueueCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/QueueCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/QueueCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/QueueCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/QueueCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,75 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_QueueCmd_HPP
-#define ecflow_base_cts_task_QueueCmd_HPP
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-
-class QueueAttr;
-
-class QueueCmd final : public TaskCmd {
-public:
-    QueueCmd(const std::string& pathToTask,
-             const std::string& jobsPassword,
-             const std::string& process_or_remote_id,
-             int try_no,
-             const std::string& queueName,
-             const std::string& action,
-             const std::string& step                    = "",
-             const std::string& path_to_node_with_queue = "") // if empty search for queue up node tree
-        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
-          name_(queueName),
-          action_(action),
-          step_(step),
-          path_to_node_with_queue_(path_to_node_with_queue) {}
-    QueueCmd() : TaskCmd() {}
-
-    const std::string& name() const { return name_; }
-    const std::string& action() const { return action_; }
-    const std::string& step() const { return step_; }
-    const std::string& path_to_node_with_queue() const { return path_to_node_with_queue_; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    ecf::Child::CmdType child_type() const override { return ecf::Child::QUEUE; }
-
-    std::string handle_queue(QueueAttr& queue_attr) const;
-
-private:
-    std::string name_;   // the queue name
-    std::string action_; // [ active | aborted | complete | no_of_aborted ]
-    std::string step_;   // will be empty when action is [ active | no_of_aborted]
-    std::string path_to_node_with_queue_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<TaskCmd>(this),
-           CEREAL_NVP(name_),
-           CEREAL_NVP(action_),
-           CEREAL_NVP(step_),
-           CEREAL_NVP(path_to_node_with_queue_));
-    }
-};
-
-CEREAL_FORCE_DYNAMIC_INIT(QueueCmd)
-
-#endif /* ecflow_base_cts_task_QueueCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/TaskApi.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/TaskApi.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/TaskApi.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/TaskApi.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,108 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/TaskApi.hpp"
-
-std::string TaskApi::init(const std::string& process_id) {
-    std::string ret = "--init=";
-    ret += process_id;
-    return ret;
-}
-const char* TaskApi::initArg() {
-    return "init";
-}
-
-std::string TaskApi::abort(const std::string& reason) {
-    if (reason.empty())
-        return "--abort";
-    std::string ret = "--abort=";
-    ret += reason;
-    return ret;
-}
-const char* TaskApi::abortArg() {
-    return "abort";
-}
-
-std::vector<std::string> TaskApi::event(const std::string& eventName, const std::string& value) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-    std::string ret = "--event=";
-    ret += eventName;
-    retVec.push_back(ret);
-    retVec.push_back(value);
-    return retVec;
-}
-const char* TaskApi::eventArg() {
-    return "event";
-}
-
-std::vector<std::string> TaskApi::meter(const std::string& meterName, const std::string& new_meter_value) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-    std::string ret = "--meter=";
-    ret += meterName;
-    retVec.push_back(ret);
-    retVec.push_back(new_meter_value);
-    return retVec;
-}
-const char* TaskApi::meterArg() {
-    return "meter";
-}
-
-std::vector<std::string> TaskApi::queue(const std::string& queueName,
-                                        const std::string& action,
-                                        const std::string& step,
-                                        const std::string& path_to_node_with_queue) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-    std::string ret = "--queue=";
-    ret += queueName;
-    retVec.push_back(ret);
-    retVec.push_back(action);
-    if (!step.empty())
-        retVec.push_back(step);
-    if (!path_to_node_with_queue.empty())
-        retVec.push_back(path_to_node_with_queue);
-    return retVec;
-}
-const char* TaskApi::queue_arg() {
-    return "queue";
-}
-
-std::vector<std::string> TaskApi::label(const std::string& label_name, const std::vector<std::string>& labels) {
-    std::vector<std::string> retVec;
-    retVec.reserve(labels.size() + 1);
-    std::string ret = "--label=";
-    ret += label_name;
-    retVec.push_back(ret);
-    for (const auto& label : labels) {
-        retVec.push_back(label);
-    }
-    return retVec;
-}
-const char* TaskApi::labelArg() {
-    return "label";
-}
-
-std::string TaskApi::complete() {
-    return "--complete";
-}
-const char* TaskApi::completeArg() {
-    return "complete";
-}
-
-std::string TaskApi::wait(const std::string& expression) {
-    std::string ret = "--wait=";
-    ret += expression;
-    return ret;
-}
-const char* TaskApi::waitArg() {
-    return "wait";
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/TaskApi.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/TaskApi.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/TaskApi.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/TaskApi.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,51 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_TaskApi_HPP
-#define ecflow_base_cts_task_TaskApi_HPP
-
-#include <string>
-#include <vector>
-
-///
-/// \brief Task API, i.e the child commands, typically called from the jobs files
-/// The two variant api must correspond i.e '--get' and 'get' since this is used by boost program options
-///
-
-class TaskApi {
-public:
-    TaskApi(const TaskApi&)                  = delete;
-    const TaskApi& operator=(const TaskApi&) = delete;
-
-    /// Used to construct arguments, for argc,argv
-    static std::string init(const std::string& process_id);
-    static std::string abort(const std::string& reason = "");
-    static std::vector<std::string> event(const std::string& eventName, const std::string& value = "set");
-    static std::vector<std::string> meter(const std::string& meterName, const std::string& metervalue);
-    static std::vector<std::string> queue(const std::string& queueName,
-                                          const std::string& action,
-                                          const std::string& step,
-                                          const std::string& path_to_node_with_queue);
-    static std::vector<std::string> label(const std::string& label_name, const std::vector<std::string>& labels);
-    static std::string complete();
-    static std::string wait(const std::string& expression);
-
-    // Only to be used in Cmd
-    static const char* initArg();
-    static const char* abortArg();
-    static const char* eventArg();
-    static const char* meterArg();
-    static const char* queue_arg();
-    static const char* labelArg();
-    static const char* completeArg();
-    static const char* waitArg();
-};
-
-#endif /* ecflow_base_cts_task_TaskApi_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/TaskCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/task/TaskCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/TaskCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/TaskCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,330 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/task/TaskCmd.hpp"
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-// #define DEBUG_ZOMBIE 1
-
-////////////////////////////////////////////////////////////////////////////////////////////////
-bool TaskCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<TaskCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (path_to_submittable_ != the_rhs->path_to_node())
-        return false;
-    if (jobs_password_ != the_rhs->jobs_password())
-        return false;
-    if (process_or_remote_id_ != the_rhs->process_or_remote_id())
-        return false;
-    if (try_no_ != the_rhs->try_no())
-        return false;
-    return ClientToServerCmd::equals(rhs);
-}
-
-// **********************************************************************************
-// IMPORTANT: In the current SMS/ECF only the init child command, passes the
-// process_or_remote_id_, for *ALL* other child commands this is empty.
-// The Automated tests get round this via setting ECF_RID in the header/tail job includes
-// However since this may not be in .sms/.ecf files, we cannot rely on it
-// Hence we need to be able to handle *EMPTY* process_or_remote_id_ for child commands
-//
-//  Task State | Child                      | Log | Explanation
-//  -------------------------------------------------------------------------------------------------------------
-//  SUBMITTED  | child!=INIT                | ERR | Script has child command in back ground, Bug in script, out of order
-//  ACTIVE     | INIT & pid & passwd match  | WAR | two init commands, overloaded server, or 2*init in script, *FOB*.
-//  Forgive ACTIVE     | INIT & pid & passwd !match | ERR | two init commands, Task started again by user. COMPLETE   |
-//  COMPLETE                   | WAR | two complete, zombie, overloaded server. *FOB*, Allow job to complete. Forgive.
-//  COMPLETE   | child != COMPLETE          | ERR | zombie
-//  ABORTED    | ABORTED                    | WAR | two aborted, zombie, overloaded server. *FOB*, allow process to
-//  exit. Forgive ABORTED    | child != ABORTED           | WAR | zombie
-//  -------------------------------------------------------------------------------------------------------------------
-//
-//  zombie type    |   PID   | password | explanation
-//  ---------------------------------------------------------------------------------------------------------------
-//  ECF_PID        |    X    | matches  | PID miss-match, but password matches. Job scheduled twice. Check submitter
-//  ECF_PID_PASSWD |    X    |     X    | Both PID and password miss-match. Re-queue & submit of active job
-//  ECF_PASSWD     | matches |     X    | Password miss-match, PID matches, system has re-cycled PID or hacked job file?
-//  ECF            | matches | matches  | overloaded server,Two init commands or task complete or aborted but receives
-//  another child cmd USER           |    ?    |     ?    | User initiated zombie whilst task was active or submitted,
-//  command is recorded in zombie PATH           |   n/a   |    n/a   | Task not found. Nodes replaced whilst jobs were
-//  running
-//  ----------------------------------------------------------------------------------------------------------------
-bool TaskCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& theReply) const {
-#ifdef DEBUG_ZOMBIE
-    std::cout << "   TaskCmd::authenticate " << Child::to_string(child_type());
-    std::cout << " " << path_to_submittable_ << " " << process_or_remote_id_ << " " << jobs_password_ << " " << try_no_;
-    const Zombie& zombie = as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
-    if (!zombie.empty())
-        std::cout << "  " << zombie;
-    else {
-        const Zombie& zombiep = as->zombie_ctrl().find_by_path_only(path_to_submittable_);
-        if (!zombiep.empty())
-            std::cout << "  find_by_path_only: " << zombiep;
-    }
-#endif
-    /// ***************************************************************************
-    /// Task based cmd have their own authentication mechanism, hence we
-    /// Don't need to call the base class authenticate
-    /// **************************************************************************
-
-    if (!as->allowTaskCommunication()) {
-        // This is not an Error, hence we don't throw exception
-        theReply = PreAllocatedReply::block_client_server_halted_cmd();
-        return false;
-    }
-
-    submittable_ = get_submittable(as);
-    if (!submittable_) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << ": PATH Zombie\n";
-#endif
-        // Create path zombie, if not already created:
-        std::string action_taken;
-        static_cast<void>(as->zombie_ctrl().handle_path_zombie(as, this, action_taken, theReply));
-
-        // distinguish output by using *path*
-        std::stringstream ss;
-        ss << " zombie(*path*) : chd:" << ecf::Child::to_string(child_type()) << " : " << path_to_submittable_ << " : "
-           << process_or_remote_id_ << " : " << jobs_password_ << " : action(" << action_taken << ")";
-        log(Log::ERR, ss.str());
-        return false;
-    }
-
-    // If the CMD *WAS* created with Submittable::DUMMY_JOBS_PASSWORD then we were testing
-    // This will be copied from client to server, hence we want to avoid same check in the
-    // server. when handleRequest is called()
-    // DO NOT place #ifdef DEBUG otherwise test will start failing for the release build
-    if (jobs_password_ == Submittable::DUMMY_JOBS_PASSWORD()) {
-        return true;
-    }
-
-    SuiteChanged1 changed(submittable_->suite());
-
-    /// Check if User wants to explicitly bypass password checking
-    /// This can be done via AlterCmd by adding a variable on the task,  ECF_PASS with value
-    /// Submittable::FREE_JOBS_PASSWORD Note: this *does not* look for the variable up the node tree, only on the task.
-    std::string ecf_pass_value;
-    if (submittable_->findVariableValue(Str::ECF_PASS(), ecf_pass_value)) {
-
-        if (ecf_pass_value == Submittable::FREE_JOBS_PASSWORD()) {
-            submittable_->flag().clear(ecf::Flag::ZOMBIE);
-            return true;
-        }
-    }
-
-    /// Handle corner case ,where we have two jobs with different process id, but same password
-    /// Can happen if jobs is started externally,
-    /// or via test(i.e submit 1,submit 2(force)) before job1 active its password is overridden
-    bool submittable_allready_aborted  = false;
-    bool submittable_allready_active   = false;
-    bool submittable_allready_complete = false;
-    password_missmatch_                = false;
-    pid_missmatch_                     = false;
-
-    /// *** In complete state, the password is empty.
-    if (submittable_->jobsPassword() != jobs_password_) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << ": submittable pass(" << submittable_->jobsPassword() << ") != jobs_password_(" << jobs_password_
-                  << ")";
-#endif
-        password_missmatch_ = true;
-    }
-
-    /// When state is in SUBMITTED, its process/remote_id is EMPTY. It will be set by the INIT child command.
-    /// Hence we can *NOT* mark it as pid_missmatch.
-    ///
-    /// *** See Note above: Not all child commands pass a process_id. ***
-    /// *** Hence this test for zombies is ONLY valid if process sets the process_or_remote_id_ ****
-    /// *** User should really set ECF_RID in the scripts
-    /// *** In submitted state, the pid is empty. hence clear pid_missmatch_ below
-    /// *** In complete state, the pid is empty.  hence clear pid_missmatch_ below
-    if (!submittable_->process_or_remote_id().empty() && !process_or_remote_id_.empty() &&
-        submittable_->process_or_remote_id() != process_or_remote_id_) {
-#ifdef DEBUG_ZOMBIE
-        std::cout << ":task pid(" << submittable_->process_or_remote_id() << ") != process pid("
-                  << process_or_remote_id_ << ")";
-#endif
-        pid_missmatch_ = true;
-    }
-
-    switch (submittable_->state()) {
-        case NState::SUBMITTED: {
-            // The pid on the task will be empty
-            if (child_type() != Child::INIT) {
-                std::stringstream ss;
-                ss << path_to_submittable_
-                   << " When a node is submitted, expected next child command to be INIT but received "
-                   << Child::to_string(child_type());
-                log(Log::ERR, ss.str());
-            }
-            break;
-        }
-
-        case NState::ACTIVE: {
-            if (child_type() == Child::INIT) {
-#ifdef DEBUG_ZOMBIE
-                std::cout << ":(child_type() == Child::INIT) && submittable_->state() == NState::ACTIVE)";
-#endif
-                // *IF* password and pid matches be more forgiving. How can this case arise:
-                // i.e server is heavily overloaded, client calls init, which times out because server is busy
-                // Client then sends init again. In this case rather than treating it as a zombie, we will let it
-                // through providing the password and pid matches.
-                if (!password_missmatch_ && !pid_missmatch_) {
-                    string ret = " [ overloaded || --init*2 ](pid and passwd match) : chd:";
-                    ret += ecf::Child::to_string(child_type());
-                    ret += " : ";
-                    ret += path_to_submittable_;
-                    ret += " : already active : action(fob)";
-                    log(Log::WAR, ret);
-                    theReply = PreAllocatedReply::ok_cmd();
-                    return false;
-                }
-                submittable_allready_active = true;
-            }
-            break;
-        }
-
-        case NState::COMPLETE: {
-#ifdef DEBUG_ZOMBIE
-            std::cout << ": submittable_->state() == NState::COMPLETE)";
-#endif
-            if (child_type() == Child::COMPLETE) {
-                // Note: when a node completes, we clear tasks password and pid, to save memory on checkpt & network
-                // bandwidth (We could choose not to clear, This would allow us to disambiguate between 2/ and 3/
-                // below). HOWEVER:
-                //
-                // How can this situation arise:
-                //   1/ Two calls to --complete  (rare)
-                //   2/ Overloaded server. Client send --complete to server, but it is overload and does not respond,
-                //   the client then
-                //      times out. Server handles the request. When client tries again we get here. (possible)
-                //   3/ Zombie, two separate process. (possible, typically done by user action)
-                //
-                // For all three it should be safe to just fob:
-                //   1/ Two calls to --complete # Be forgiving
-                //   2/ Overloaded server       # The correct course of action
-                //   3/ zombie                  # The zombie has completed anyway, don't bother blocking it
-
-                submittable_->flag().clear(ecf::Flag::ZOMBIE);
-                as->zombie_ctrl().remove_by_path(path_to_submittable_);
-
-                string ret = " [ overloaded || zombie || --complete*2 ] : chd:";
-                ret += ecf::Child::to_string(child_type());
-                ret += " : ";
-                ret += path_to_submittable_;
-                ret += " : already complete : action(fob)";
-                log(Log::WAR, ret);
-                theReply = PreAllocatedReply::ok_cmd();
-                return false;
-            }
-
-            // If Task state is complete, and we receive **any** child command then it is a zombie
-            submittable_allready_complete = true;
-            password_missmatch_           = false;
-            pid_missmatch_                = false;
-            break;
-        }
-
-        case NState::ABORTED: {
-#ifdef DEBUG_ZOMBIE
-            std::cout << ": submittable_->state() == NState::ABORTED)";
-#endif
-
-            if (child_type() == Child::ABORT) {
-
-                if (!password_missmatch_ && !pid_missmatch_) {
-
-                    as->zombie_ctrl().remove(submittable_);
-
-                    string ret = " [ overloaded || --abort*2 ] (pid and passwd match) : chd:";
-                    ret += ecf::Child::to_string(child_type());
-                    ret += " : ";
-                    ret += path_to_submittable_;
-                    ret += " : already aborted : action(fob)";
-                    log(Log::WAR, ret);
-                    theReply = PreAllocatedReply::ok_cmd();
-                    return false;
-                }
-            }
-
-            // If Task state is aborted, and we receive **any** child command then it is a zombie
-            submittable_allready_aborted = true;
-            password_missmatch_          = false;
-            pid_missmatch_               = false;
-            break;
-        }
-        case NState::QUEUED:
-            break; // WTF
-        case NState::UNKNOWN:
-            break; // WTF
-    }
-
-#ifdef DEBUG_ZOMBIE
-    std::cout << "\n";
-#endif
-
-    if (password_missmatch_ || pid_missmatch_ || submittable_allready_active || submittable_allready_complete ||
-        submittable_allready_aborted) {
-        /// If the task has adopted we return true, and carry on as normal
-        std::string action_taken;
-        if (!as->zombie_ctrl().handle_zombie(submittable_, this, action_taken, theReply)) {
-
-            // LOG failure: Include type of zombie.
-            // ** NOTE **: the zombie may have been removed by user actions. i.e if fob and child cmd is abort |
-            // complete, etc
-            std::stringstream ss;
-            ss << " zombie";
-            const Zombie& theZombie =
-                as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
-            if (!theZombie.empty())
-                ss << "(" << theZombie.type_str() << ")";
-
-            ss << " : chd:" << ecf::Child::to_string(child_type());
-            ss << " : " << path_to_submittable_ << "(" << NState::toString(submittable_->state()) << ")";
-            ss << " : " << process_or_remote_id_ << " : " << jobs_password_;
-            if (submittable_allready_active)
-                ss << " : already active";
-            if (submittable_allready_complete)
-                ss << " : already complete";
-            if (submittable_allready_aborted)
-                ss << " : already aborted";
-            if (password_missmatch_)
-                ss << " : passwd != [ task:" << submittable_->jobsPassword() << " child:" << jobs_password_ << " ]";
-            if (pid_missmatch_)
-                ss << " : pid != [ task:" << submittable_->process_or_remote_id() << " child:" << process_or_remote_id_
-                   << " ]";
-            ss << " : action(" << action_taken << ")";
-            log(Log::ERR, ss.str());
-            return false;
-        }
-    }
-    return true;
-}
-
-Submittable* TaskCmd::get_submittable(AbstractServer* as) const {
-    node_ptr node = as->defs()->findAbsNode(path_to_submittable_);
-    if (!node.get()) {
-        return nullptr;
-    }
-
-    return node->isSubmittable();
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/task/TaskCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/task/TaskCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/task/TaskCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/task/TaskCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,90 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_task_TaskCmd_HPP
-#define ecflow_base_cts_task_TaskCmd_HPP
-
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/Child.hpp"
-
-//=================================================================================
-// Task Command
-// ================================================================================
-class TaskCmd : public ClientToServerCmd {
-protected:
-    TaskCmd(const std::string& pathToSubmittable,
-            const std::string& jobsPassword,
-            const std::string& process_or_remote_id,
-            int try_no)
-        : submittable_(nullptr),
-          path_to_submittable_(pathToSubmittable),
-          jobs_password_(jobsPassword),
-          process_or_remote_id_(process_or_remote_id),
-          try_no_(try_no) {
-        assert(!hostname().empty());
-    }
-
-    TaskCmd() = default;
-
-public:
-    bool isWrite() const override { return true; }
-    int timeout() const override { return 190; } // ECFLOW-157 80 -> 190
-
-    const std::string& path_to_node() const { return path_to_submittable_; }
-    const std::string& jobs_password() const { return jobs_password_; }
-    const std::string& process_or_remote_id() const { return process_or_remote_id_; }
-    int try_no() const { return try_no_; }
-    virtual ecf::Child::CmdType child_type() const = 0;
-
-    bool equals(ClientToServerCmd*) const override;
-    bool task_cmd() const override { return true; }
-    bool connect_to_different_servers() const override { return true; }
-
-    bool password_missmatch() const { return password_missmatch_; }
-    bool pid_missmatch() const { return pid_missmatch_; }
-
-protected:
-    /// Overridden to do nothing since Task based commands don't need _user_ based authentication
-    void setup_user_authentification(const std::string& /*user*/, const std::string& /*passwd*/) override {}
-    bool setup_user_authentification(AbstractClientEnv&) override { return true; }
-    void setup_user_authentification() override {}
-
-    bool authenticate(AbstractServer*,
-                      STC_Cmd_ptr&) const override; /// Task have their own mechanism,can throw std::runtime_error
-    Submittable* get_submittable(AbstractServer* as) const; // can throw std::runtime_error
-
-protected:
-    mutable Submittable* submittable_{
-        nullptr}; // stored during authentication and re-used handle request, not persisted, server side only
-
-private:
-    std::string path_to_submittable_;
-    std::string jobs_password_;
-    std::string process_or_remote_id_;
-    int try_no_{0};
-
-private:
-    mutable bool password_missmatch_{
-        false}; // stored during authentication and re-used handle request, not persisted, server side only
-    mutable bool pid_missmatch_{
-        false}; // stored during authentication and re-used handle request, not persisted, server side only
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<ClientToServerCmd>(this),
-           CEREAL_NVP(path_to_submittable_),
-           CEREAL_NVP(jobs_password_),
-           CEREAL_NVP(process_or_remote_id_),
-           CEREAL_NVP(try_no_));
-    }
-};
-
-#endif /* ecflow_base_cts_task_TaskCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/AlterCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/AlterCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/AlterCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/AlterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1692 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Enumerate.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-static std::string dump_args(const std::vector<std::string>& options, const std::vector<std::string>& paths) {
-    std::string the_args;
-    for (const auto& option : options) {
-        the_args += option;
-        the_args += " ";
-    }
-    for (const auto& path : paths) {
-        the_args += path;
-        the_args += " ";
-    }
-    return the_args;
-}
-
-namespace ecf::detail {
-
-template <>
-struct EnumTraits<AlterCmd::Delete_attr_type>
-{
-    using underlying_t = std::underlying_type_t<AlterCmd::Delete_attr_type>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(AlterCmd::DEL_VARIABLE, "variable"),
-        std::make_pair(AlterCmd::DEL_TIME, "time"),
-        std::make_pair(AlterCmd::DEL_TODAY, "today"),
-        std::make_pair(AlterCmd::DEL_DATE, "date"),
-        std::make_pair(AlterCmd::DEL_DAY, "day"),
-        std::make_pair(AlterCmd::DEL_CRON, "cron"),
-        std::make_pair(AlterCmd::DEL_EVENT, "event"),
-        std::make_pair(AlterCmd::DEL_METER, "meter"),
-        std::make_pair(AlterCmd::DEL_LABEL, "label"),
-        std::make_pair(AlterCmd::DEL_TRIGGER, "trigger"),
-        std::make_pair(AlterCmd::DEL_COMPLETE, "complete"),
-        std::make_pair(AlterCmd::DEL_REPEAT, "repeat"),
-        std::make_pair(AlterCmd::DEL_LIMIT, "limit"),
-        std::make_pair(AlterCmd::DEL_LIMIT_PATH, "limit_path"),
-        std::make_pair(AlterCmd::DEL_INLIMIT, "inlimit"),
-        std::make_pair(AlterCmd::DEL_ZOMBIE, "zombie"),
-        std::make_pair(AlterCmd::DEL_LATE, "late"),
-        std::make_pair(AlterCmd::DEL_QUEUE, "queue"),
-        std::make_pair(AlterCmd::DEL_GENERIC, "generic")
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<AlterCmd::Delete_attr_type>::size == map.back().first);
-};
-
-template <>
-struct EnumTraits<AlterCmd::Add_attr_type>
-{
-    using underlying_t = std::underlying_type_t<AlterCmd::Add_attr_type>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(AlterCmd::ADD_TIME, "time"),
-        std::make_pair(AlterCmd::ADD_TODAY, "today"),
-        std::make_pair(AlterCmd::ADD_DATE, "date"),
-        std::make_pair(AlterCmd::ADD_DAY, "day"),
-        std::make_pair(AlterCmd::ADD_ZOMBIE, "zombie"),
-        std::make_pair(AlterCmd::ADD_VARIABLE, "variable"),
-        std::make_pair(AlterCmd::ADD_LATE, "late"),
-        std::make_pair(AlterCmd::ADD_LIMIT, "limit"),
-        std::make_pair(AlterCmd::ADD_INLIMIT, "inlimit"),
-        std::make_pair(AlterCmd::ADD_LABEL, "label")
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<AlterCmd::Add_attr_type>::size == map.back().first);
-};
-
-template <>
-struct EnumTraits<AlterCmd::Change_attr_type>
-{
-    using underlying_t = std::underlying_type_t<AlterCmd::Change_attr_type>;
-
-    static constexpr std::array map = std::array{
-        // clang-format off
-        std::make_pair(AlterCmd::VARIABLE, "variable"),
-        std::make_pair(AlterCmd::CLOCK_TYPE, "clock_type"),
-        std::make_pair(AlterCmd::CLOCK_DATE, "clock_date"),
-        std::make_pair(AlterCmd::CLOCK_GAIN, "clock_gain"),
-        std::make_pair(AlterCmd::CLOCK_SYNC, "clock_sync"),
-        std::make_pair(AlterCmd::EVENT, "event"),
-        std::make_pair(AlterCmd::METER, "meter"),
-        std::make_pair(AlterCmd::LABEL, "label"),
-        std::make_pair(AlterCmd::TRIGGER, "trigger"),
-        std::make_pair(AlterCmd::COMPLETE, "complete"),
-        std::make_pair(AlterCmd::REPEAT, "repeat"),
-        std::make_pair(AlterCmd::LIMIT_MAX, "limit_max"),
-        std::make_pair(AlterCmd::LIMIT_VAL, "limit_value"),
-        std::make_pair(AlterCmd::DEFSTATUS, "defstatus"),
-        std::make_pair(AlterCmd::LATE, "late"),
-        std::make_pair(AlterCmd::TIME, "time"),
-        std::make_pair(AlterCmd::TODAY, "today")
-        // clang-format on
-    };
-    static constexpr size_t size = map.size();
-
-    static_assert(EnumTraits<AlterCmd::Change_attr_type>::size == map.back().first);
-};
-
-} // namespace ecf::detail
-
-static AlterCmd::Delete_attr_type deleteAttrType(const std::string& s) {
-    if (auto found = ecf::Enumerate<AlterCmd::Delete_attr_type>::to_enum(s); found) {
-        return found.value();
-    }
-    return AlterCmd::DELETE_ATTR_ND;
-}
-
-static std::string to_string(AlterCmd::Delete_attr_type d) {
-    if (auto found = ecf::Enumerate<AlterCmd::Delete_attr_type>::to_string(d); found) {
-        return std::string{found.value()};
-    }
-    return {};
-}
-
-static void validDeleteAttr(std::vector<std::string>& vec) {
-    vec = ecf::Enumerate<AlterCmd::Delete_attr_type>::designations();
-}
-
-static AlterCmd::Add_attr_type addAttrType(const std::string& s) {
-    if (auto found = ecf::Enumerate<AlterCmd::Add_attr_type>::to_enum(s); found) {
-        return found.value();
-    }
-    return AlterCmd::ADD_ATTR_ND;
-}
-
-static std::string to_string(AlterCmd::Add_attr_type a) {
-    if (auto found = ecf::Enumerate<AlterCmd::Add_attr_type>::to_string(a); found) {
-        return std::string{found.value()};
-    }
-    return {};
-}
-
-static void validAddAttr(std::vector<std::string>& vec) {
-    vec = Enumerate<AlterCmd::Add_attr_type>::designations();
-}
-
-static AlterCmd::Change_attr_type changeAttrType(const std::string& s) {
-    if (auto found = Enumerate<AlterCmd::Change_attr_type>::to_enum(s); found) {
-        return found.value();
-    }
-    return AlterCmd::CHANGE_ATTR_ND;
-}
-
-static std::string to_string(AlterCmd::Change_attr_type c) {
-    if (auto found = Enumerate<AlterCmd::Change_attr_type>::to_string(c); found) {
-        return std::string{found.value()};
-    }
-    return {};
-}
-
-static void validChangeAttr(std::vector<std::string>& vec) {
-    vec = ecf::Enumerate<AlterCmd::Change_attr_type>::designations();
-}
-
-//=======================================================================================
-
-bool AlterCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<AlterCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (paths_ != the_rhs->paths()) {
-        return false;
-    }
-    if (name_ != the_rhs->name()) {
-        return false;
-    }
-    if (value_ != the_rhs->value()) {
-        return false;
-    }
-    if (del_attr_type_ != the_rhs->delete_attr_type()) {
-        return false;
-    }
-    if (change_attr_type_ != the_rhs->change_attr_type()) {
-        return false;
-    }
-    if (add_attr_type_ != the_rhs->add_attr_type()) {
-        return false;
-    }
-    if (flag_type_ != the_rhs->flag_type()) {
-        return false;
-    }
-    if (flag_ != the_rhs->flag()) {
-        return false;
-    }
-    return UserCmd::equals(rhs);
-}
-
-void AlterCmd::alter_and_attr_type(std::string& alter_type, std::string& attr_type) const {
-    if (del_attr_type_ != AlterCmd::DELETE_ATTR_ND) {
-        alter_type = "delete";
-        attr_type  = to_string(del_attr_type_);
-    }
-    else if (change_attr_type_ != AlterCmd::CHANGE_ATTR_ND) {
-        alter_type = "change";
-        attr_type  = to_string(change_attr_type_);
-    }
-    else if (add_attr_type_ != AlterCmd::ADD_ATTR_ND) {
-        alter_type = "add";
-        attr_type  = to_string(add_attr_type_);
-    }
-    else if (flag_type_ != ecf::Flag::NOT_SET) {
-        if (flag_)
-            alter_type = "set_flag";
-        else
-            alter_type = "clear_flag";
-        attr_type = ecf::Flag::enum_to_string(flag_type_);
-    }
-    else {
-        alter_type = "sort";
-    }
-}
-
-void AlterCmd::print_only(std::string& os) const {
-    std::string alter_type, attr_type;
-    alter_and_attr_type(alter_type, attr_type);
-    if (paths_.empty())
-        os += CtsApi::to_string(CtsApi::alter(std::vector<std::string>(1, " "), alter_type, attr_type, name_, value_));
-    else
-        os += CtsApi::to_string(
-            CtsApi::alter(std::vector<std::string>(1, paths_[0]), alter_type, attr_type, name_, value_));
-}
-
-void AlterCmd::print(std::string& os) const {
-    std::string alter_type, attr_type;
-    alter_and_attr_type(alter_type, attr_type);
-    user_cmd(os, CtsApi::to_string(CtsApi::alter(paths_, alter_type, attr_type, name_, value_)));
-}
-
-void AlterCmd::print(std::string& os, const std::string& path) const {
-    std::string alter_type, attr_type;
-    alter_and_attr_type(alter_type, attr_type);
-    user_cmd(os,
-             CtsApi::to_string(CtsApi::alter(std::vector<std::string>(1, path), alter_type, attr_type, name_, value_)));
-}
-
-STC_Cmd_ptr AlterCmd::alter_server_state(AbstractServer* as) const {
-    Defs* defs = as->defs().get();
-
-    if (del_attr_type_ == AlterCmd::DEL_VARIABLE) {
-        defs->set_server().delete_user_variable(name_);
-    }
-    else if (change_attr_type_ == AlterCmd::VARIABLE || add_attr_type_ == AlterCmd::ADD_VARIABLE) {
-
-        // ECFLOW-380: Some variable should be read only
-        if (name_ == Str::ECF_HOST() || name_ == Str::ECF_PORT() || name_ == "ECF_PID" || name_ == "ECF_VERSION" ||
-            name_ == "ECF_LISTS") {
-            std::stringstream ss;
-            ss << "AlterCmd:: Cannot add or change read only server variable " << name_;
-            throw std::runtime_error(ss.str());
-        }
-        defs->set_server().add_or_update_user_variables(name_, value_);
-    }
-
-    // Update defs flag state
-    if (flag_type_ != Flag::NOT_SET) {
-        if (flag_)
-            defs->flag().set(flag_type_);
-        else {
-            defs->flag().clear(flag_type_);
-            if (flag_type_ == Flag::LOG_ERROR)
-                defs->set_server().delete_user_variable("ECF_LOG_ERROR");
-            if (flag_type_ == Flag::CHECKPT_ERROR)
-                defs->set_server().delete_user_variable("ECF_CHECKPT_ERROR");
-        }
-    }
-
-    // sort
-    ecf::Attr::Type attr = Attr::to_attr(name_);
-    if (attr != ecf::Attr::UNKNOWN) {
-        bool recursive = (value_ == "recursive") ? true : false;
-        defs->sort_attributes(attr, recursive);
-    }
-
-    return doJobSubmission(as);
-}
-
-STC_Cmd_ptr AlterCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().alter_cmd_++;
-    Defs* defs = as->defs().get();
-
-    std::stringstream ss;
-    size_t vec_size = paths_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-
-        /// For root node user means to change server state
-        if (paths_[i] == "/") {
-            return alter_server_state(as);
-        }
-
-        node_ptr node = find_node_for_edit_no_throw(defs, paths_[i]);
-        if (!node.get()) {
-            ss << "AlterCmd: Could not find node at path " << paths_[i] << "\n";
-            LOG(Log::ERR, "AlterCmd: Failed: Could not find node at path " << paths_[i]);
-            continue;
-        }
-
-        SuiteChangedPtr changed(node.get());
-        try {
-            switch (del_attr_type_) {
-                case AlterCmd::DEL_VARIABLE:
-                    node->deleteVariable(name_);
-                    break;
-                case AlterCmd::DEL_TIME:
-                    node->deleteTime(name_);
-                    break;
-                case AlterCmd::DEL_TODAY:
-                    node->deleteToday(name_);
-                    break;
-                case AlterCmd::DEL_DATE:
-                    node->deleteDate(name_);
-                    break;
-                case AlterCmd::DEL_DAY:
-                    node->deleteDay(name_);
-                    break;
-                case AlterCmd::DEL_CRON:
-                    node->deleteCron(name_);
-                    break;
-                case AlterCmd::DEL_EVENT:
-                    node->deleteEvent(name_);
-                    break;
-                case AlterCmd::DEL_METER:
-                    node->deleteMeter(name_);
-                    break;
-                case AlterCmd::DEL_LABEL:
-                    node->deleteLabel(name_);
-                    break;
-                case AlterCmd::DEL_TRIGGER:
-                    node->deleteTrigger();
-                    break;
-                case AlterCmd::DEL_COMPLETE:
-                    node->deleteComplete();
-                    break;
-                case AlterCmd::DEL_REPEAT:
-                    node->deleteRepeat();
-                    break;
-                case AlterCmd::DEL_LIMIT:
-                    node->deleteLimit(name_);
-                    break;
-                case AlterCmd::DEL_LIMIT_PATH:
-                    node->delete_limit_path(name_, value_);
-                    break;
-                case AlterCmd::DEL_INLIMIT:
-                    node->deleteInlimit(name_);
-                    break;
-                case AlterCmd::DEL_ZOMBIE:
-                    node->deleteZombie(name_);
-                    break;
-                case AlterCmd::DEL_LATE:
-                    node->deleteLate();
-                    break;
-                case AlterCmd::DEL_QUEUE:
-                    node->delete_queue(name_);
-                    break;
-                case AlterCmd::DEL_GENERIC:
-                    node->delete_generic(name_);
-                    break;
-                case AlterCmd::DELETE_ATTR_ND:
-                    break;
-                default:
-                    break;
-            }
-        }
-        catch (std::exception& e) {
-            ss << "Alter (delete) failed for " << paths_[i] << " : " << e.what() << "\n";
-        }
-
-        try {
-            switch (change_attr_type_) {
-                case AlterCmd::VARIABLE:
-                    node->changeVariable(name_, value_);
-                    break;
-                case AlterCmd::CLOCK_TYPE:
-                    node->suite()->changeClockType(name_);
-                    break; // node must be a suite, value must [hybrid|real| virtual]
-                case AlterCmd::CLOCK_DATE:
-                    node->suite()->changeClockDate(name_);
-                    break; // Expecting day.month.year: node must be a suite, value must [hybrid|real| virtual]
-                case AlterCmd::CLOCK_GAIN:
-                    node->suite()->changeClockGain(name_);
-                    break; // node must be a suite, value must be int
-                case AlterCmd::CLOCK_SYNC:
-                    node->suite()->changeClockSync();
-                    break; // node must be a suite, sync clock with computer
-                case AlterCmd::EVENT:
-                    node->changeEvent(name_, value_);
-                    break; // if value is empty just set, [1|0] or name [set | clear]
-                case AlterCmd::METER:
-                    node->changeMeter(name_, value_);
-                    break;
-                case AlterCmd::LABEL:
-                    node->changeLabel(name_, value_);
-                    break;
-                case AlterCmd::TRIGGER:
-                    node->changeTrigger(name_);
-                    break; // expression must parse
-                case AlterCmd::COMPLETE:
-                    node->changeComplete(name_);
-                    break; // expression must parse
-                case AlterCmd::REPEAT:
-                    node->changeRepeat(name_);
-                    break; //
-                case AlterCmd::LIMIT_MAX:
-                    node->changeLimitMax(name_, value_);
-                    break; // value must be convertible to int
-                case AlterCmd::LIMIT_VAL:
-                    node->changeLimitValue(name_, value_);
-                    break; // value < limit max, & value must be convertible to an int
-                case AlterCmd::DEFSTATUS:
-                    node->changeDefstatus(name_);
-                    break; // must be a valid state
-                case AlterCmd::LATE:
-                    node->changeLate(LateAttr::create(name_));
-                    break; // must be a valid late
-                case AlterCmd::TIME:
-                    node->change_time(name_, value_);
-                    break;
-                case AlterCmd::TODAY:
-                    node->change_today(name_, value_);
-                    break;
-                case AlterCmd::CHANGE_ATTR_ND:
-                    break;
-                default:
-                    break;
-            }
-        }
-        catch (std::exception& e) {
-            ss << "Alter (change) failed for " << paths_[i] << " : " << e.what() << "\n";
-        }
-
-        try {
-            switch (add_attr_type_) {
-                case AlterCmd::ADD_TIME:
-                    node->addTime(TimeAttr(TimeSeries::create(name_)));
-                    break;
-                case AlterCmd::ADD_TODAY:
-                    node->addToday(TodayAttr(TimeSeries::create(name_)));
-                    break;
-                case AlterCmd::ADD_DATE:
-                    node->addDate(DateAttr::create(name_));
-                    break;
-                case AlterCmd::ADD_DAY:
-                    node->addDay(DayAttr::create(name_));
-                    break;
-                case AlterCmd::ADD_ZOMBIE:
-                    node->addZombie(ZombieAttr::create(name_));
-                    break;
-                case AlterCmd::ADD_VARIABLE:
-                    node->add_variable(name_, value_);
-                    break;
-                case AlterCmd::ADD_LATE:
-                    node->addLate(LateAttr::create(name_));
-                    break;
-                case AlterCmd::ADD_LABEL:
-                    node->addLabel(Label(name_, value_));
-                    break;
-                case AlterCmd::ADD_LIMIT: {
-                    int int_value = 0;
-                    try {
-                        int_value = ecf::convert_to<int>(value_);
-                    }
-                    catch (const ecf::bad_conversion&) {
-                        std::stringstream mss;
-                        mss << "AlterCmd: add_limit " << name_ << " " << value_ << " failed. Expected '" << value_
-                            << "' to be convertible to an integer";
-                        throw std::runtime_error(mss.str());
-                    }
-                    node->addLimit(Limit(name_, int_value));
-                    break;
-                }
-                case AlterCmd::ADD_INLIMIT: {
-                    string path_to_limit; // This can be empty
-                    string limitName;
-                    if (!Extract::pathAndName(name_, path_to_limit, limitName)) {
-                        throw std::runtime_error("AlterCmd::ADD_INLIMIT: Invalid inlimit : " + name_);
-                    }
-                    int token_value = 1;
-                    if (!value_.empty()) {
-                        try {
-                            token_value = ecf::convert_to<int>(value_);
-                        }
-                        catch (const ecf::bad_conversion&) {
-                            ss << "AlterCmd: add_inlimit expected '" << value_ << "' to be convertible to an integer";
-                            throw std::runtime_error(ss.str());
-                        }
-                    }
-                    node->addInLimit(InLimit(limitName, path_to_limit, token_value)); // will throw if not valid
-                    break;
-                }
-                case AlterCmd::ADD_ATTR_ND:
-                    break;
-            }
-        }
-        catch (std::exception& e) {
-            ss << "Alter (add) failed for " << paths_[i] << ": Could not parse " << name_ << " : " << e.what() << "\n";
-        }
-
-        // Change flags
-        if (flag_type_ != Flag::NOT_SET) {
-            if (flag_)
-                node->flag().set(flag_type_);
-            else
-                node->flag().clear(flag_type_);
-        }
-
-        // sort
-        ecf::Attr::Type attr = Attr::to_attr(name_);
-        if (attr != ecf::Attr::UNKNOWN) {
-            bool recursive = (value_ == "recursive") ? true : false;
-            node->sort_attributes(attr, recursive);
-        }
-    }
-
-    std::string error_msg = ss.str();
-    if (!error_msg.empty()) {
-        throw std::runtime_error(error_msg);
-    }
-
-    return doJobSubmission(as);
-}
-
-bool AlterCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
-
-const char* AlterCmd::arg() {
-    return CtsApi::alterArg();
-}
-const char* AlterCmd::desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Alter the node according to the options.\n"
-           "To add/delete/change server variables use '/' for the path.\n"
-           "arg1 =   [ delete | change | add | set_flag | clear_flag | sort ]\n"
-           "         one option must be specified\n"
-           "arg2 = For delete:\n"
-           "         [ variable | time | today | date  | day | cron | event | meter | late | generic | queue |\n"
-           "           label | trigger | complete | repeat | limit | inlimit | limit_path | zombie ]\n"
-           "       For change:\n"
-           "         [ variable | clock_type | clock_gain | clock_date | clock_sync  | event | meter | label |\n"
-           "           trigger  | complete   | repeat     | limit_max  | limit_value | defstatus | late | time | today "
-           "]\n"
-           "         *NOTE* If the clock is changed, then the suite will need to be re-queued in order for\n"
-           "         the change to take effect fully.\n"
-           "       For add:\n"
-           "         [ variable | time | today | date | day | zombie | late | limit | inlimit | label ]\n"
-           "       For set_flag and clear_flag:\n"
-           "         [ force_aborted | user_edit | task_aborted | edit_failed | ecfcmd_failed \n"
-           "           statuscmd_failed | killcmd_failed | no_script | killed | status | late | message | \n"
-           "           complete | queue_limit | task_waiting | locked | zombie | archived | restored |\n"
-           "           threshold | log_error | checkpt_error]\n"
-           "       For sort:\n"
-           "         [ event | meter | label | variable| limit | all ]\n"
-           "arg3 = name/value\n"
-           "       when changing, attributes like variable,meter,event,label,limits,late\n"
-           "       we expect arguments to be quoted. For sort this argument can be called 'recursive'\n"
-           "arg4 = new_value\n"
-           "       specifies the new value only used for 'change'/'add'\n"
-           "       values with spaces must be quoted\n"
-           "arg5 = paths : At least one node path required.The paths must start with a leading '/' character\n\n"
-           "\nUsage:\n\n"
-           "   ecflow_client --alter=add variable GLOBAL \"value\" /           # add server variable\n"
-           "   ecflow_client --alter=add variable FRED \"value\" /path/to/node # add node variable\n"
-           "   ecflow_client --alter=add time \"+00:20\" /path/to/node\n"
-           "   ecflow_client --alter=add date \"01.*.*\" /path/to/node\n"
-           "   ecflow_client --alter=add day \"sunday\"  /path/to/node\n"
-           "   ecflow_client --alter=add label name \"label_value\" /path/to/node\n"
-           "   ecflow_client --alter=add late \"-s 00:01 -a 14:30 -c +00:01\" /path/to/node\n"
-           "   ecflow_client --alter=add limit mars \"100\" /path/to/node\n"
-           "   ecflow_client --alter=add inlimit /path/to/node/withlimit:limit_name \"10\" /path/to/node\n"
-           "   # zombie attributes have the following structure:\n"
-           "     `zombie_type`:(`client_side_action` | `server_side_action`):`child`:`zombie_life_time`\n"
-           "      zombie_type        = \"user\" | \"ecf\" | \"path\" | \"ecf_pid\" | \"ecf_passwd\" | "
-           "\"ecf_pid_passwd\"\n"
-           "      client_side_action = \"fob\" | \"fail\" | \"block\"\n"
-           "      server_side_action = \"adopt\" | \"delete\" | \"kill\"\n"
-           "      child              = \"init\" | \"event\" | \"meter\" | \"label\" | \"wait\" | \"abort\" | "
-           "\"complete\" | \"queue\"\n"
-           "      zombie_life_time   = unsigned integer default: user(300), ecf(3600), path(900)  minimum is 60\n"
-           "   ecflow_client --alter=add zombie \"ecf:fail::\" /path/to/node     # ask system zombies to fail\n"
-           "   ecflow_client --alter=add zombie \"user:fail::\" /path/to/node    # ask user generated zombies to fail\n"
-           "   ecflow_client --alter=add zombie \"path:fail::\" /path/to/node    # ask path zombies to fail\n\n"
-           "   ecflow_client --alter=delete variable FRED /path/to/node    # delete variable FRED\n"
-           "   ecflow_client --alter=delete variable      /path/to/node    # delete *ALL* variables on the specified "
-           "node\n";
-}
-
-void AlterCmd::addOption(boost::program_options::options_description& desc) const {
-    // Important: this option is, in practice, multi-token (and thus should use
-    // po::value<vector<string>>()->multitoken()). However, because of the special handling
-    // necessary to allow positional values, such as "--help", a custom `style_parser` is used
-    // instead when parsing the CLI options -- see ClientOptions for details.
-    desc.add_options()(AlterCmd::arg(), po::value<vector<string>>(), AlterCmd::desc());
-}
-void AlterCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(AlterCmd::arg(), args);
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
-    if (paths.empty()) {
-        std::stringstream ss;
-        ss << "AlterCmd: No paths specified. Paths must begin with a leading '/' character\n"
-           << dump_args(options, paths) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-    if (options.empty()) {
-        std::stringstream ss;
-        ss << "AlterCmd: Invalid argument list:\n" << dump_args(options, paths) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-    if (options.size() < 2) {
-        std::stringstream ss;
-        ss << "Alter: At least three arguments expected. Found " << args.size() << "\n"
-           << dump_args(options, paths) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    // arg[0] should one of [ add | delete | change | set_flag | clear_flag | sort ]
-    std::string alterType = options[0];
-
-    if (alterType == "add") {
-
-        createAdd(cmd, options, paths);
-        return;
-    }
-    else if (alterType == "change") {
-
-        createChange(cmd, options, paths);
-        return;
-    }
-    else if (alterType == "delete") {
-
-        createDelete(cmd, options, paths);
-        return;
-    }
-    else if (alterType == "set_flag") {
-
-        create_flag(cmd, options, paths, true /*set */);
-        return;
-    }
-    else if (alterType == "clear_flag") {
-
-        create_flag(cmd, options, paths, false /*clear */);
-        return;
-    }
-    else if (alterType == "sort") {
-
-        create_sort_attributes(cmd, options, paths);
-        return;
-    }
-
-    std::stringstream ss;
-    ss << "Alter: The first argument must be one of [ change | delete | add | set_flag | clear_flag | sort ] but found "
-          "'"
-       << alterType << "'\n"
-       << dump_args(options, paths) << "\n";
-    throw std::runtime_error(ss.str());
-}
-
-AlterCmd::Add_attr_type AlterCmd::get_add_attr_type(const std::string& attr_type) const {
-    AlterCmd::Add_attr_type theAttrType = addAttrType(attr_type);
-    if (theAttrType == AlterCmd::ADD_ATTR_ND) {
-        std::stringstream ss;
-        ss << "AlterCmd: add: The second argument must be one of [ ";
-        std::vector<std::string> valid;
-        validAddAttr(valid);
-        for (size_t i = 0; i < valid.size(); ++i) {
-            if (i != 0)
-                ss << " | ";
-            ss << valid[i];
-        }
-        ss << "] but found " << attr_type << "\n" << AlterCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-    return theAttrType;
-}
-
-void AlterCmd::createAdd(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const {
-    // options[0] - add
-    // options[1] - [ time | today | date | day | zombie | variable | late | limit | inlimit | label ]
-    // options[2] - [ time_string | date_string | day_string | zombie_string | variable_name | limit_name |
-    //                path_to_limit ]
-    // options[3] - variable_value
-
-    AlterCmd::Add_attr_type theAttrType = get_add_attr_type(options[1]);
-
-    std::stringstream ss;
-    if (options.size() < 3) {
-        ss << "AlterCmd: add: At least four arguments expected. Found " << (options.size() + paths.size()) << "\n"
-           << dump_args(options, paths) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    string name, value;
-    try {
-        extract_name_and_value_for_add(theAttrType, name, value, options, paths);
-        check_for_add(theAttrType, name, value);
-    }
-    catch (std::exception& e) {
-        ss << "AlterCmd: add: Could not parse " << name << ". Error: " << e.what()
-           << "\n for time,today and date the new value should be a quoted string "
-           << "\n for add expected: --alter add variable <name> <value> <paths>\n"
-           << dump_args(options, paths) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    cmd = std::make_shared<AlterCmd>(paths, theAttrType, name, value);
-}
-
-void AlterCmd::extract_name_and_value_for_add(AlterCmd::Add_attr_type theAttrType,
-                                              std::string& name,
-                                              std::string& value,
-                                              std::vector<std::string>& options,
-                                              std::vector<std::string>& paths) const {
-    // **** parse and check format, expect this argument to be single or double tick quoted ****
-    // **** for time,date,day or zombie
-    std::stringstream ss;
-    name = options[2];
-    switch (theAttrType) {
-        case AlterCmd::ADD_TIME:
-            break;
-        case AlterCmd::ADD_TODAY:
-            break;
-        case AlterCmd::ADD_DATE:
-            break;
-        case AlterCmd::ADD_DAY:
-            break;
-        case AlterCmd::ADD_ZOMBIE:
-            break;
-        case AlterCmd::ADD_LATE:
-            break;
-        case AlterCmd::ADD_VARIABLE: {
-            if (options.size() == 3 && paths.size() > 1) {
-                // variable value may be a path, hence it will be in the paths parameter
-                options.push_back(paths[0]);
-                paths.erase(paths.begin());
-            }
-            if (options.size() < 4) {
-                ss << "AlterCmd: add: Expected 'add variable <name> <value> <paths>. Not enough arguments\n"
-                   << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            value = options[3];
-            break;
-        }
-        case AlterCmd::ADD_LABEL: {
-            if (options.size() == 3 && paths.size() > 1) {
-                // label value may be a path, hence it will be in the paths parameter
-                options.push_back(paths[0]);
-                paths.erase(paths.begin());
-            }
-            if (options.size() < 4) {
-                ss << "AlterCmd: add: Expected 'add label <name> <value> <paths>. Not enough arguments\n"
-                   << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            value = options[3];
-            break;
-        }
-        case AlterCmd::ADD_LIMIT: {
-            if (options.size() < 4) {
-                ss << "AlterCmd: add: Expected 'add limit <name> int. Not enough arguments\n"
-                   << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            value = options[3];
-            break;
-        }
-        case AlterCmd::ADD_INLIMIT: { // inlimit /obs/limits:hpcd 2 name=hpcd, path=/obs/limits, tokens=2(optional)
-            // options[0]  - add
-            // options[1]  - [ inlimit ]
-            // options[2]  - [ path_to_limit:limit_name ]   --> name
-            // options[3]  - integer (optional)             --> value
-            if (options.size() < 3) {
-                ss << "AlterCmd: add: Expected 'add inlimit <path-to-limit:limit_name> <int>(optional) <paths>. Not "
-                      "enough arguments\n"
-                   << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            if (options.size() == 4) {
-                value = options[3];
-            }
-            break;
-        }
-        case AlterCmd::ADD_ATTR_ND:
-            break;
-    }
-}
-
-void AlterCmd::check_for_add(AlterCmd::Add_attr_type theAttrType,
-                             const std::string& name,
-                             const std::string& value) const {
-    // **** parse and check format, expect this argument to be single or double tick quoted ****
-    // **** for time,date,day or zombie
-    if (name.empty())
-        throw std::runtime_error("Alter: check_for_add : name is empty ?");
-
-    std::stringstream ss;
-    switch (theAttrType) {
-        case AlterCmd::ADD_TIME:
-            (void)TimeSeries::create(name);
-            break;
-        case AlterCmd::ADD_TODAY:
-            (void)TimeSeries::create(name);
-            break;
-        case AlterCmd::ADD_DATE:
-            (void)DateAttr::create(name);
-            break;
-        case AlterCmd::ADD_DAY:
-            (void)DayAttr::create(name);
-            break;
-        case AlterCmd::ADD_ZOMBIE:
-            (void)ZombieAttr::create(name);
-            break;
-        case AlterCmd::ADD_LATE:
-            (void)LateAttr::create(name);
-            break;
-        case AlterCmd::ADD_VARIABLE: {
-            // Create a Variable to check valid names
-            Variable check(name, value);
-            break;
-        }
-        case AlterCmd::ADD_LABEL: {
-            // Create a Label to check valid names
-            Label check(name, value);
-            break;
-        }
-        case AlterCmd::ADD_LIMIT: {
-            int int_value = 0;
-            try {
-                int_value = ecf::convert_to<int>(value);
-            }
-            catch (const ecf::bad_conversion&) {
-                ss << "AlterCmd add_limit expected value(" << value << ") to be convertible to an integer\n";
-                throw std::runtime_error(ss.str());
-            }
-            Limit check(name, int_value); // will throw if not valid
-            break;
-        }
-        case AlterCmd::ADD_INLIMIT: { // inlimit /obs/limits:hpcd 2 name=hpcd, path=/obs/limits, tokens=2(optional)
-            // options[0]  - add
-            // options[1]  - [ inlimit ]
-            // options[2]  - [ path_to_limit:limit_name ]  ---> name
-            // options[3]  - integer (optional)            ---> value
-            string path_to_limit; // This can be empty
-            string limitName;
-            if (!Extract::pathAndName(name, path_to_limit, limitName)) {
-                throw std::runtime_error("AlterCmd add inlimit Invalid inlimit : " + name);
-            }
-            int token_value = 1;
-            if (!value.empty()) {
-                try {
-                    token_value = ecf::convert_to<int>(value);
-                }
-                catch (const ecf::bad_conversion&) {
-                    ss << "AlterCmd add inlimit expected optional limit token '" << value
-                       << "' to be convertible to an integer\n";
-                    throw std::runtime_error(ss.str());
-                }
-            }
-            InLimit inlimit(limitName, path_to_limit, token_value); // will throw if not valid
-            break;
-        }
-        case AlterCmd::ADD_ATTR_ND:
-            break;
-    }
-}
-
-AlterCmd::Delete_attr_type AlterCmd::get_delete_attr_type(const std::string& attr_type) const {
-    AlterCmd::Delete_attr_type theAttrType = deleteAttrType(attr_type);
-    if (theAttrType == AlterCmd::DELETE_ATTR_ND) {
-        std::stringstream ss;
-        ss << "Alter: delete: The second argument must be one of [ ";
-        std::vector<std::string> valid;
-        validDeleteAttr(valid);
-        for (size_t i = 0; i < valid.size(); ++i) {
-            if (i != 0)
-                ss << " | ";
-            ss << valid[i];
-        }
-        ss << "] but found " << attr_type << "\n" << AlterCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-    return theAttrType;
-}
-
-void AlterCmd::createDelete(Cmd_ptr& cmd,
-                            const std::vector<std::string>& options,
-                            const std::vector<std::string>& paths) const {
-    // options[0] = delete
-    // options[1] = [ variable | time | today | date | day | cron | event | meter | label | trigger | complete |
-    //                repeat | limit | limit_path | inlimit | zombie | late ]
-    // options[2] = name ( of object to be deleted ) optional
-    // options[3] = limit_path (optional *ONLY* applicable for limit_path), specifies the path to be deleted
-
-    AlterCmd::Delete_attr_type theAttrType = get_delete_attr_type(options[1]);
-
-    // Generally an empty third argument means delete all attributes, otherwise delete the specific one.
-    std::string name, value;
-    try {
-        extract_name_and_value_for_delete(theAttrType, name, value, options, paths);
-        check_for_delete(theAttrType, name, value);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "AlterCmd: delete: Could not parse " << name << ". Error: " << e.what()
-           << "\n for time,today and date the new value should be a quoted string\n"
-           << dump_args(options, paths) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-    cmd = std::make_shared<AlterCmd>(paths, theAttrType, name, value);
-}
-
-void AlterCmd::extract_name_and_value_for_delete(AlterCmd::Delete_attr_type theAttrType,
-                                                 std::string& name,
-                                                 std::string& value,
-                                                 const std::vector<std::string>& options,
-                                                 const std::vector<std::string>& paths) const {
-    // Generally an empty third argument means delete all attributes, otherwise delete the specific one.
-    if (options.size() >= 3)
-        name = options[2];
-
-    // Deleting the limit path requires an additional arg
-    std::string path_value;
-
-    // if specified make sure its parses
-    if (theAttrType == AlterCmd::DEL_LIMIT_PATH) {
-        if (name.empty()) {
-            std::stringstream ss;
-            ss << "Delete limit_path failed. No limit name provided. Expected 5 args: delete limit_path <limit_name> "
-                  "<path-to-limit> <path_to_node>\n";
-            ss << dump_args(options, paths) << "\n";
-            throw std::runtime_error(ss.str());
-        }
-
-        std::vector<std::string> altered_path = paths;
-        if (options.size() == 4) {
-            // User has provided a limit path which does not start with '/'. Go with flow
-            path_value = options[3];
-        }
-        else {
-            // Since we have a limit path(i.e begins with'/') it will appear in the paths, as the first path
-            if (paths.size() <= 1) {
-                std::stringstream ss;
-                ss << "Delete limit_path failed: No path to limit provided. Expected 5 args: delete limit_path "
-                      "<limit_name> <path-to-limit> <path_to_node>\n"
-                   << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            path_value = paths[0];
-
-            // Change paths to remove the limit path.
-            altered_path.erase(altered_path.begin());
-        }
-        value = path_value;
-    }
-}
-
-void AlterCmd::check_for_delete(AlterCmd::Delete_attr_type theAttrType,
-                                const std::string& name,
-                                const std::string& value) const {
-    switch (theAttrType) {
-        case AlterCmd::DEL_VARIABLE: {
-            if (!name.empty())
-                Variable check(name, ""); // Create a Variable to check valid names
-            break;
-        }
-        case AlterCmd::DEL_TIME: {
-            if (!name.empty())
-                (void)TimeSeries::create(name); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_TODAY: {
-            if (!name.empty())
-                (void)TimeSeries::create(name); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_DATE: {
-            if (!name.empty())
-                (void)DateAttr::create(name); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_DAY: {
-            if (!name.empty())
-                (void)DayAttr::create(name); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_CRON: {
-            if (!name.empty()) {
-                CronAttr parsedCron = CronAttr::create(name); // will throw if not valid
-
-                // additional check since parsing is very forgiving. if parsed string is same as default
-                // then no cron was specified.
-                CronAttr emptyCron;
-                if (emptyCron.structureEquals(parsedCron)) {
-                    throw std::runtime_error("Delete cron Attribute failed. Check cron " + name);
-                }
-            }
-            break;
-        }
-        case AlterCmd::DEL_EVENT: {
-            if (!name.empty()) {
-                Event check(name); // will throw if not valid
-            }
-            break;
-        }
-        case AlterCmd::DEL_METER: {
-            if (!name.empty())
-                Meter check(name, 0, 100); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_LABEL: {
-            if (!name.empty())
-                Label check(name, "value"); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_TRIGGER:
-            break; // there can only be one trigger per node, so we delete by path
-        case AlterCmd::DEL_COMPLETE:
-            break; // there can only be one complete per node, so we delete by path
-        case AlterCmd::DEL_REPEAT:
-            break; // there can only be one repeat per node, so we delete by path
-        case AlterCmd::DEL_LATE:
-            break; // there can only be one late per node, so we delete by path
-        case AlterCmd::DEL_QUEUE: {
-            if (!name.empty()) {
-                std::vector<std::string> vec;
-                vec.emplace_back("a");
-                QueueAttr check(name, vec); // will throw if not valid
-            }
-            break;
-        }
-        case AlterCmd::DEL_GENERIC: {
-            if (!name.empty())
-                GenericAttr check(name); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_LIMIT: {
-            if (!name.empty())
-                Limit check(name, 10); // will throw if not valid
-            break;
-        }
-        case AlterCmd::DEL_INLIMIT: {
-            if (!name.empty()) {
-                // name can be:
-                //    limit_name
-                //    /path/to/limit:limit_name
-                string path_to_limit; // This can be empty
-                string limitName;
-                if (!Extract::pathAndName(name, path_to_limit, limitName)) {
-                    throw std::runtime_error("AlterCmd::DEL_INLIMIT : Invalid inlimit : " + name);
-                }
-                InLimit check(limitName, path_to_limit); // will throw if not valid
-            }
-            break;
-        }
-        case AlterCmd::DEL_ZOMBIE: {
-            if (!Child::valid_zombie_type(name)) {
-                throw std::runtime_error(
-                    "Delete Zombie Attribute failed. Expected one of [ ecf | path | user ] but found " + name);
-            }
-            break;
-        }
-        case AlterCmd::DEL_LIMIT_PATH: {
-            if (name.empty()) {
-                throw std::runtime_error("Delete limit_path failed. No limit name provided");
-            }
-            return;
-        }
-        case AlterCmd::DELETE_ATTR_ND:
-            break;
-    }
-}
-
-// =====================================================================================
-
-AlterCmd::Change_attr_type AlterCmd::get_change_attr_type(const std::string& attr_type) const {
-    AlterCmd::Change_attr_type theAttrType = changeAttrType(attr_type);
-    if (theAttrType == AlterCmd::CHANGE_ATTR_ND) {
-        std::stringstream ss;
-        ss << "AlterCmd: change: The third argument(" << attr_type << ") must be one of [ ";
-        std::vector<std::string> valid;
-        validChangeAttr(valid);
-        for (size_t i = 0; i < valid.size(); ++i) {
-            if (i != 0)
-                ss << " | ";
-            ss << valid[i];
-        }
-        ss << "]\n" << AlterCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-    return theAttrType;
-}
-
-void AlterCmd::createChange(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const {
-    // options[0] = change
-    // options[1] = [ variable | clock_type | clock_gain | clock_date | clock_sync | event | meter | label | trigger |
-    //                complete | repeat | limit_max | limit_value | defstatus | late ]
-    // options[2] = name
-    // options[3] = value
-
-    AlterCmd::Change_attr_type theAttrType = get_change_attr_type(options[1]);
-
-    std::string name, value;
-    extract_name_and_value_for_change(theAttrType, name, value, options, paths);
-    cmd = std::make_shared<AlterCmd>(paths, theAttrType, name, value);
-}
-
-void AlterCmd::extract_name_and_value_for_change(AlterCmd::Change_attr_type theAttrType,
-                                                 std::string& name,
-                                                 std::string& value,
-                                                 std::vector<std::string>& options,
-                                                 std::vector<std::string>& paths) const {
-    std::stringstream ss;
-    switch (theAttrType) {
-        case AlterCmd::VARIABLE: {
-            if (options.size() == 3 && paths.size() > 1) {
-                // The variable value may be a path, and hence it will be paths and not options parameter
-                options.push_back(paths[0]);
-                paths.erase(paths.begin()); // remove first path, since it has been added to options
-            }
-            if (options.size() < 3 || options.size() > 4) {
-                ss << "AlterCmd: change: expected 5 args : change variable <variable_name> <new_value> <path_to_node>";
-                ss << " but found only " << (options.size() + paths.size())
-                   << " arguments.\nThe value should be quoted if there are spaces\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            if (options.size() == 4)
-                value = options[3];
-            break;
-        }
-
-        case AlterCmd::CLOCK_TYPE: {
-            if (options.size() != 3) {
-                ss << "AlterCmd: change: expected at least four args i.e. change clock_type [ hybrid | real ] "
-                      "<path_to_suite>";
-                ss << " but found only " << (options.size() + paths.size()) << " arguments\n"
-                   << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::CLOCK_DATE: {
-            if (options.size() != 3) {
-                ss << "AlterCmd: change clock_date : expected at least four args :  change clock_date day.month.year "
-                      "<path_to_suite>";
-                ss << " but found only " << (options.size() + paths.size()) << " arguments\n"
-                   << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::CLOCK_GAIN: {
-            if (options.size() != 3) {
-                ss << "AlterCmd: change clock_gain : expected four args i.e. change clock_gain <int> <path_to_suite> ";
-                ss << " but found " << (options.size() + paths.size())
-                   << " arguments. The actual gain must be convertible to an integer\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::CLOCK_SYNC: {
-            if (options.size() != 2) {
-                ss << "AlterCmd: change clock_sync : expected three args i.e. change clock_sync  <path_to_suite> ";
-                ss << " but found " << (options.size() + paths.size()) << " arguments.\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-
-        case AlterCmd::EVENT: {
-            if (options.size() != 3 && options.size() != 4) {
-                ss << "AlterCmd: Change event : expected four/five args:  change event <name_or_number> <[set | clear "
-                      "| <nothing>]> <path_to_node>";
-                ss << " but found only " << (options.size() + paths.size()) << " arguments\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            if (options.size() == 4) {
-                value = options[3];
-            }
-            break;
-        }
-
-        case AlterCmd::METER: {
-            if (options.size() != 4) {
-                ss << "AlterCmd: change: expected five args: change meter meter_name meter_value  <path_to_node>";
-                ss << " but found only " << (options.size() + paths.size())
-                   << " arguments. The meter value must be convertible to an integer\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name  = options[2];
-            value = options[3];
-            break;
-        }
-
-        case AlterCmd::LABEL: {
-            if (options.size() == 3 && paths.size() == 1) {
-                // ECFLOW-648 allow label value to be empty
-                // HOWEVER , we cannot cope multiple paths, and setting value to empty.
-                // since empty quotes are removed by boost program options, hence if we have a label value which is
-                // path, and multiple paths
-                value.clear();
-            }
-            else {
-                // ECFLOW-480 take into account label values that is a path, adding quotes around the value does not
-                // help: Note boost program options will remove the quotes around the value
-                //      hence it's difficult to say what is an option and what is a path.
-                //      However since we expect 4(change,label,<label_name>,<label_value>) options, work around the
-                //      problem
-                if (options.size() == 3 && paths.size() > 1) {
-                    options.push_back(paths[0]);
-                    paths.erase(paths.begin()); // remove first path, since it has been added to options
-                }
-                if (options.size() != 4) {
-                    ss << "AlterCmd: change label expected at least five args : change label <label_name> "
-                          "<label_value> <path_to_node> ";
-                    ss << " but found  " << (options.size() + paths.size())
-                       << " arguments. the label value should be quoted\n";
-                    ss << dump_args(options, paths) << "\n";
-                    throw std::runtime_error(ss.str());
-                }
-                value = options[3];
-                if (value.find("\\n") != std::string::npos) {
-                    Str::replaceall(value, "\\n", "\n");
-                }
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::LATE: {
-            if (options.size() != 3) {
-                ss << "AlterCmd: change: expected three args: change late \"late -s +00:15  -a  20:00  -c +02:00\" "
-                      "<path_to_node>";
-                ss << " but found only " << (options.size() + paths.size()) << " arguments\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::TRIGGER: {
-            if (options.size() != 3) {
-                ss << "AlterCmd: change: expected four args : change trigger 'expression' <path_to_node>";
-                ss << " but found " << (options.size() + paths.size())
-                   << " arguments. The trigger expression must be quoted\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::COMPLETE: {
-            if (options.size() != 3) {
-                ss << "AlterCmd: change complete: expected four args: change complete 'expression'  <path_to_node> ";
-                ss << " but found " << (options.size() + paths.size()) << " arguments. The expression must be quoted\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::REPEAT: {
-            // *NOTE* a Node can only have *ONE* repeat, hence no need to provide name
-            if (options.size() != 3) {
-                ss << "AlterCmd: change repeat: expected four arg's : change repeat [ integer | string ] "
-                      "<path_to_node>";
-                ss << " but found only " << (options.size() + paths.size()) << " arguments.\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::LIMIT_MAX: {
-            if (options.size() != 4) {
-                ss << "AlterCmd: change: limit_max: : expected five arguments : change limit_max <limit_name> <int> "
-                      "<path_to_node>";
-                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name  = options[2];
-            value = options[3];
-            break;
-        }
-
-        case AlterCmd::LIMIT_VAL: {
-            if (options.size() != 4) {
-                ss << "AlterCmd: change: limit-value: expected five arguments : change limit_value <limit_name> <int> "
-                      "<path_to_node>";
-                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name  = options[2];
-            value = options[3];
-            break;
-        }
-
-        case AlterCmd::TIME: {
-            if (options.size() != 4) {
-                ss << "AlterCmd: change: time: expected five arguments : change time old_time new_time <path_to_node>";
-                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name  = options[2];
-            value = options[3];
-            break;
-        }
-
-        case AlterCmd::TODAY: {
-            if (options.size() != 4) {
-                ss << "AlterCmd: change: today: expected five arguments : change time old_today new_today "
-                      "<path_to_node>";
-                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name  = options[2];
-            value = options[3];
-            break;
-        }
-
-        case AlterCmd::DEFSTATUS: {
-            if (options.size() != 3) {
-                ss << "AlterCmd: change defstatus expected four args : change defstatus [ queued | complete | unknown "
-                      "| aborted | suspended ] <path_to_node>";
-                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
-                ss << dump_args(options, paths) << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            name = options[2];
-            break;
-        }
-
-        case AlterCmd::CHANGE_ATTR_ND:
-            break;
-        default:
-            break;
-    }
-}
-
-void AlterCmd::check_for_change(AlterCmd::Change_attr_type theAttrType,
-                                const std::string& name,
-                                const std::string& value) const {
-    std::stringstream ss;
-    switch (theAttrType) {
-        case AlterCmd::VARIABLE:
-            break;
-        case AlterCmd::CLOCK_TYPE: {
-            if (name != "hybrid" && name != "real") {
-                ss << "AlterCmd: change clock_type: expected third argument to be one of [ hybrid | real ] but found "
-                   << name << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-        case AlterCmd::CLOCK_DATE: {
-            // Check date is in correct format:
-            try {
-                int day, month, year;
-                DateAttr::getDate(name, day, month, year);
-                DateAttr::checkDate(day, month, year, false /* for clocks, we don't allow wild carding */);
-            }
-            catch (std::exception& e) {
-                ss << "AlterCmd:change  clock_date " << name << " is not valid. " << e.what();
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-
-        case AlterCmd::CLOCK_GAIN: {
-            try {
-                ecf::convert_to<int>(name);
-            }
-            catch (const ecf::bad_conversion&) {
-                ss << "AlterCmd:change  clock_gain expected '" << name << "' to be convertible to an integer\n";
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-
-        case AlterCmd::CLOCK_SYNC:
-            break;
-
-        case AlterCmd::EVENT: {
-            if (!value.empty() && value != Event::SET() && value != Event::CLEAR()) {
-                ss << "AlterCmd: Change event : expected  <[set | clear | <nothing>]> for the value";
-                throw std::runtime_error(ss.str());
-            }
-            // The name could be an integer
-            try {
-                ecf::convert_to<int>(name);
-            }
-            catch (const ecf::bad_conversion&) {
-                // name is not an integer, check name is valid
-                Event check_name(name); // will throw if name is not valid
-            }
-            break;
-        }
-
-        case AlterCmd::METER: {
-            Meter check(name, 0, 100); // Check meter name , by creating a meter
-            try {
-                ecf::convert_to<int>(value);
-            }
-            catch (const ecf::bad_conversion&) {
-                ss << "AlterCmd change meter : " << value << " to be convertible to an integer\n";
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-
-        case AlterCmd::LABEL: {
-            Label check(name, value); // Check name , by creating
-            break;
-        }
-
-        case AlterCmd::LATE: {
-            (void)LateAttr::create(name); // Check we can create the late
-            break;
-        }
-
-        case AlterCmd::TIME: {
-            (void)TimeSeries::create(name);
-            (void)TimeSeries::create(value);
-            break;
-        }
-
-        case AlterCmd::TODAY: {
-            (void)TimeSeries::create(name);
-            (void)TimeSeries::create(value);
-            break;
-        }
-
-        case AlterCmd::TRIGGER: {
-            std::string error_msg       = "AlterCmd: change trigger:";
-            std::unique_ptr<AstTop> ast = Expression::parse_no_throw(name, error_msg);
-            if (!ast.get()) {
-                ss << error_msg << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-
-        case AlterCmd::COMPLETE: {
-            std::string error_msg       = "AlterCmd: change complete:";
-            std::unique_ptr<AstTop> ast = Expression::parse_no_throw(name, error_msg);
-            if (!ast.get()) {
-                ss << error_msg << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-
-        case AlterCmd::REPEAT: {
-            // *NOTE* a Node can only have *ONE* repeat, hence no need to provide name
-            break;
-        }
-
-        case AlterCmd::LIMIT_MAX: {
-            int limit = 0;
-            try {
-                limit = ecf::convert_to<int>(value);
-            }
-            catch (const ecf::bad_conversion&) {
-                ss << "AlterCmd: change: limit-max: expected " << value << " to be convertible to an integer\n";
-                throw std::runtime_error(ss.str());
-            }
-            Limit check(name, limit); // Check name , by creating
-            break;
-        }
-
-        case AlterCmd::LIMIT_VAL: {
-            try {
-                ecf::convert_to<int>(value);
-            }
-            catch (const ecf::bad_conversion&) {
-                ss << "AlterCmd: change: limit_value: expected " << value << " to be convertible to an integer\n";
-                throw std::runtime_error(ss.str());
-            }
-            Limit check(name, 10); // Check name, by creating
-            break;
-        }
-
-        case AlterCmd::DEFSTATUS: {
-            if (!DState::isValid(name)) {
-                ss << "AlterCmd change defstatus : expected " << name
-                   << " to be a valid state,  i.e one of [ queued | complete | unknown | aborted | suspended ]\n";
-                throw std::runtime_error(ss.str());
-            }
-            break;
-        }
-
-        case AlterCmd::CHANGE_ATTR_ND:
-            break;
-        default:
-            break;
-    }
-}
-
-ecf::Flag::Type AlterCmd::get_flag_type(const std::string& flag_type) const {
-    Flag::Type theFlagType = Flag::string_to_flag_type(flag_type);
-    if (theFlagType == Flag::NOT_SET) {
-        std::stringstream ss;
-        ss << "AlterCmd: set/clear_flag: The second argument(" << flag_type << ") must be one of [ ";
-        std::vector<std::string> valid;
-        Flag::valid_flag_type(valid);
-        for (size_t i = 0; i < valid.size(); ++i) {
-            if (i != 0)
-                ss << " | ";
-            ss << valid[i];
-        }
-        ss << "]\n" << AlterCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-    return theFlagType;
-}
-
-void AlterCmd::create_flag(Cmd_ptr& cmd,
-                           const std::vector<std::string>& options,
-                           const std::vector<std::string>& paths,
-                           bool flag) const {
-    // options[0] = set_flag | clear_flag
-    // options[1] = [ force_aborted | user_edit | task_aborted | edit_failed | ecfcmd_failed | no_script | killed |
-    //                late | message | complete | queue_limit | task_waiting | locked | zombie ]
-
-    Flag::Type theFlagType = get_flag_type(options[1]);
-    cmd                    = std::make_shared<AlterCmd>(paths, theFlagType, flag);
-}
-
-void AlterCmd::check_sort_attr_type(const std::string& attr_type) const {
-    ecf::Attr::Type theAttrType = Attr::to_attr(attr_type);
-    if (theAttrType == Attr::UNKNOWN) {
-        std::stringstream ss;
-        ss << "AlterCmd: sort: The second argument must be one of [ ";
-        std::vector<std::string> valid = Attr::all_attrs();
-        for (size_t i = 0; i < valid.size(); ++i) {
-            if (i != 0)
-                ss << " | ";
-            ss << valid[i];
-        }
-        ss << "] but found " << attr_type << "\n" << AlterCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-}
-
-void AlterCmd::create_sort_attributes(Cmd_ptr& cmd,
-                                      const std::vector<std::string>& options,
-                                      const std::vector<std::string>& paths) const {
-    // options[0] - sort
-    // options[1] - [ event | meter | label | limit | variable | all ]
-    // options[2] - recursive
-    std::stringstream ss;
-    if (options.size() < 2) {
-        ss << "AlterCmd: add: At least three arguments expected. Found " << (options.size() + paths.size()) << "\n"
-           << dump_args(options, paths) << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    check_sort_attr_type(options[1]);
-    std::string name = options[1];
-
-    std::string value;
-    if (options.size() == 3) {
-        if (options[2] != "recursive") {
-            ss << "AlterCmd: sort: Expected third argument to be 'recursive' but found '" << options[2] << "\n"
-               << AlterCmd::desc();
-            throw std::runtime_error(ss.str());
-        }
-        value = "recursive";
-    }
-
-    cmd = std::make_shared<AlterCmd>(paths, name, value);
-}
-
-AlterCmd::AlterCmd(const std::vector<std::string>& paths,
-                   const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-                   const std::string& attrType,
-                   const std::string& name,
-                   const std::string& value)
-    : paths_(paths),
-      name_(name),
-      value_(value) {
-    if (alterType == "add") {
-
-        add_attr_type_ = get_add_attr_type(attrType);
-        check_for_add(add_attr_type_, name, value);
-        return;
-    }
-    else if (alterType == "change") {
-
-        change_attr_type_ = get_change_attr_type(attrType);
-        check_for_change(change_attr_type_, name, value);
-        return;
-    }
-    else if (alterType == "delete") {
-
-        del_attr_type_ = get_delete_attr_type(attrType);
-        check_for_delete(del_attr_type_, name, value);
-        return;
-    }
-    else if (alterType == "set_flag") {
-
-        flag_type_ = get_flag_type(attrType);
-        flag_      = true;
-        return;
-    }
-    else if (alterType == "clear_flag") {
-
-        flag_type_ = get_flag_type(attrType);
-        return;
-    }
-
-    std::stringstream ss;
-    ss << "AlterCmd constructor: The alterType argument must be one of [ change | delete | add | set_flag | clear_flag "
-          "| sort ] but found '"
-       << alterType << "'\n";
-    throw std::runtime_error(ss.str());
-}
-
-std::ostream& operator<<(std::ostream& os, const AlterCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(AlterCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(AlterCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/AlterCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/AlterCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/AlterCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/AlterCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,247 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_AlterCmd_HPP
-#define ecflow_base_cts_user_AlterCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-#include "ecflow/node/Flag.hpp"
-
-class AlterCmd final : public UserCmd {
-public:
-    enum Delete_attr_type {
-        DEL_VARIABLE,
-        DEL_TIME,
-        DEL_TODAY,
-        DEL_DATE,
-        DEL_DAY,
-        DEL_CRON,
-        DEL_EVENT,
-        DEL_METER,
-        DEL_LABEL,
-        DEL_TRIGGER,
-        DEL_COMPLETE,
-        DEL_REPEAT,
-        DEL_LIMIT,
-        DEL_LIMIT_PATH,
-        DEL_INLIMIT,
-        DEL_ZOMBIE,
-        DELETE_ATTR_ND,
-        DEL_LATE,
-        DEL_QUEUE,
-        DEL_GENERIC,
-    };
-
-    enum Change_attr_type {
-        VARIABLE,
-        CLOCK_TYPE,
-        CLOCK_DATE,
-        CLOCK_GAIN,
-        EVENT,
-        METER,
-        LABEL,
-        TRIGGER,
-        COMPLETE,
-        REPEAT,
-        LIMIT_MAX,
-        LIMIT_VAL,
-        DEFSTATUS,
-        CHANGE_ATTR_ND,
-        CLOCK_SYNC,
-        LATE,
-        TIME,
-        TODAY,
-    };
-
-    enum Add_attr_type {
-        ADD_TIME,
-        ADD_TODAY,
-        ADD_DATE,
-        ADD_DAY,
-        ADD_ZOMBIE,
-        ADD_VARIABLE,
-        ADD_ATTR_ND,
-        ADD_LATE,
-        ADD_LIMIT,
-        ADD_INLIMIT,
-        ADD_LABEL,
-    };
-
-    // Python
-    AlterCmd(const std::vector<std::string>& paths,
-             const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-             const std::string& attrType,
-             const std::string& name,
-             const std::string& value);
-    // add
-    AlterCmd(const std::string& path, Add_attr_type attr, const std::string& name, const std::string& value = "")
-        : paths_(std::vector<std::string>(1, path)),
-          name_(name),
-          value_(value),
-          add_attr_type_(attr) {}
-    AlterCmd(const std::vector<std::string>& paths,
-             Add_attr_type attr,
-             const std::string& name,
-             const std::string& value = "")
-        : paths_(paths),
-          name_(name),
-          value_(value),
-          add_attr_type_(attr) {}
-    // delete
-    AlterCmd(const std::string& path, Delete_attr_type del, const std::string& name = "", const std::string& value = "")
-        : paths_(std::vector<std::string>(1, path)),
-          name_(name),
-          value_(value),
-          del_attr_type_(del) {}
-    AlterCmd(const std::vector<std::string>& paths,
-             Delete_attr_type del,
-             const std::string& name  = "",
-             const std::string& value = "")
-        : paths_(paths),
-          name_(name),
-          value_(value),
-          del_attr_type_(del) {}
-    // change
-    AlterCmd(const std::string& path, Change_attr_type attr, const std::string& name, const std::string& value = "")
-        : paths_(std::vector<std::string>(1, path)),
-          name_(name),
-          value_(value),
-          change_attr_type_(attr) {}
-    AlterCmd(const std::vector<std::string>& paths,
-             Change_attr_type attr,
-             const std::string& name,
-             const std::string& value = "")
-        : paths_(paths),
-          name_(name),
-          value_(value),
-          change_attr_type_(attr) {}
-    // flag
-    AlterCmd(const std::string& path, ecf::Flag::Type ft, bool flag)
-        : paths_(std::vector<std::string>(1, path)),
-          flag_type_(ft),
-          flag_(flag) {}
-    AlterCmd(const std::vector<std::string>& paths, ecf::Flag::Type ft, bool flag)
-        : paths_(paths),
-          flag_type_(ft),
-          flag_(flag) {}
-    // sort
-    AlterCmd(const std::string& path, const std::string& name, const std::string& value)
-        : paths_(std::vector<std::string>(1, path)),
-          name_(name),
-          value_(value) {}
-    AlterCmd(const std::vector<std::string>& paths, const std::string& name, const std::string& value)
-        : paths_(paths),
-          name_(name),
-          value_(value) {}
-
-    AlterCmd() = default;
-
-    // Uses by equals only
-    const std::vector<std::string>& paths() const { return paths_; }
-    const std::string& name() const { return name_; }
-    const std::string& value() const { return value_; }
-    Delete_attr_type delete_attr_type() const { return del_attr_type_; }
-    Change_attr_type change_attr_type() const { return change_attr_type_; }
-    Add_attr_type add_attr_type() const { return add_attr_type_; }
-    ecf::Flag::Type flag_type() const { return flag_type_; }
-    bool flag() const { return flag_; }
-
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    void print(std::string& os, const std::string& path) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    STC_Cmd_ptr alter_server_state(AbstractServer*) const;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
-
-    void my_print(std::string& os, const std::vector<std::string>& paths) const;
-
-    Add_attr_type get_add_attr_type(const std::string&) const;
-    void createAdd(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const;
-    void extract_name_and_value_for_add(Add_attr_type,
-                                        std::string& name,
-                                        std::string& value,
-                                        std::vector<std::string>& options,
-                                        std::vector<std::string>& paths) const;
-    void check_for_add(Add_attr_type, const std::string& name, const std::string& value) const;
-
-    Delete_attr_type get_delete_attr_type(const std::string&) const;
-    void
-    createDelete(Cmd_ptr& cmd, const std::vector<std::string>& options, const std::vector<std::string>& paths) const;
-    void extract_name_and_value_for_delete(Delete_attr_type,
-                                           std::string& name,
-                                           std::string& value,
-                                           const std::vector<std::string>& options,
-                                           const std::vector<std::string>& paths) const;
-    void check_for_delete(Delete_attr_type, const std::string& name, const std::string& value) const;
-
-    Change_attr_type get_change_attr_type(const std::string&) const;
-    void createChange(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const;
-    void extract_name_and_value_for_change(Change_attr_type,
-                                           std::string& name,
-                                           std::string& value,
-                                           std::vector<std::string>& options,
-                                           std::vector<std::string>& paths) const;
-    void check_for_change(Change_attr_type, const std::string& name, const std::string& value) const;
-
-    ecf::Flag::Type get_flag_type(const std::string&) const;
-    void create_flag(Cmd_ptr& cmd,
-                     const std::vector<std::string>& options,
-                     const std::vector<std::string>& paths,
-                     bool flag) const;
-
-    void check_sort_attr_type(const std::string&) const;
-    void create_sort_attributes(Cmd_ptr& cmd,
-                                const std::vector<std::string>& options,
-                                const std::vector<std::string>& paths) const;
-
-    void alter_and_attr_type(std::string& alter_type, std::string& attr_type) const;
-
-private:
-    std::vector<std::string> paths_;
-    std::string name_;
-    std::string value_;
-    Add_attr_type add_attr_type_{ADD_ATTR_ND};
-    Delete_attr_type del_attr_type_{DELETE_ATTR_ND};
-    Change_attr_type change_attr_type_{CHANGE_ATTR_ND};
-    ecf::Flag::Type flag_type_{ecf::Flag::NOT_SET};
-    bool flag_{false}; // true means set false means clear
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(paths_),
-           CEREAL_NVP(name_),
-           CEREAL_NVP(value_),
-           CEREAL_NVP(add_attr_type_),
-           CEREAL_NVP(del_attr_type_),
-           CEREAL_NVP(change_attr_type_),
-           CEREAL_NVP(flag_type_),
-           CEREAL_NVP(flag_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const AlterCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(AlterCmd)
-
-#endif /* ecflow_base_cts_user_AlterCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/BeginCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/BeginCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/BeginCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/BeginCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,190 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-BeginCmd::BeginCmd(const std::string& suiteName, bool force) : suiteName_(suiteName), force_(force) {
-    // The begin command actually requires the suite name without the lead '/'
-    // i.e if we provide /suite --> change to suite
-    if (!suiteName_.empty() && suiteName_[0] == '/') {
-        suiteName_.erase(0, 1); // delete first character
-    }
-}
-
-void BeginCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::begin(suiteName_, force_));
-}
-
-void BeginCmd::print_only(std::string& os) const {
-    os += CtsApi::begin(suiteName_, force_);
-}
-
-bool BeginCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<BeginCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (suiteName_ != the_rhs->suiteName())
-        return false;
-    if (force_ != the_rhs->force())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-STC_Cmd_ptr BeginCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().begin_cmd_++;
-    defs_ptr defs = as->defs();
-
-    std::vector<Submittable*> tasks;
-
-    // If no suite name begin all suites, else begin the the specific suite
-    if (suiteName_.empty()) {
-
-        const std::vector<suite_ptr>& suiteVec = defs->suiteVec();
-        size_t theSuiteVecSize                 = suiteVec.size();
-        if (!force_) {
-            for (size_t s = 0; s < theSuiteVecSize; s++) {
-                /// check_suite_can_begin will throw if suite can't begin
-                defs->check_suite_can_begin(suiteVec[s]);
-            }
-        }
-        else {
-            defs->get_all_active_submittables(tasks);
-            as->zombie_ctrl().add_user_zombies(tasks, CtsApi::beginArg());
-
-            defs->reset_begin(); // Force should *only* be used for test
-        }
-
-        defs->beginAll();
-    }
-    else {
-
-        suite_ptr suite = defs->findSuite(suiteName_);
-        if (!suite.get()) {
-            std::stringstream ss;
-            ss << "BeginCmd::doHandleRequest:  Begin failed as suite '" << suiteName_ << "' is not loaded.\n";
-            throw std::runtime_error(ss.str());
-        }
-
-        /// check_suite_can_begin will throw if suite can't begin
-        if (!force_)
-            defs->check_suite_can_begin(suite);
-        else {
-
-            suite->get_all_active_submittables(tasks);
-            as->zombie_ctrl().add_user_zombies(tasks, CtsApi::beginArg());
-
-            suite->reset_begin(); // Force should *only* be used for test
-        }
-
-        defs->beginSuite(suite);
-    }
-
-    // The begin will clear the zombie flag: Hence reset it here.
-    for (auto task : tasks)
-        task->flag().set(ecf::Flag::ZOMBIE);
-
-    // After begin do the first Job submission. This will kick of those
-    // jobs that have no dependencies, or relative time of +00:00
-    return doJobSubmission(as);
-}
-
-const char* BeginCmd::arg() {
-    return CtsApi::beginArg();
-}
-const char* BeginCmd::desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Begin playing the definition in the server.\n"
-           "Expects zero or a single quoted string.\n"
-           "  arg1 = suite-name | Nothing | force\n"
-           "         play the chosen suite, if no arg specified, play all suites, in the definition\n"
-           "         force means reset the begin status on the suites and bypass checks.\n"
-           "         This is only required if suite-name is provide as the first argument\n"
-           "         Using force can cause the creation of zombies\n"
-           "Usage:\n"
-           "--begin                     # will begin all suites\n"
-           "--begin=\"--force\"         # reset and then begin all suites, bypassing any checks. Note: string must be "
-           "quoted\n"
-           "--begin=\"mySuite\"         # begin playing suite of name 'mySuite'\n"
-           "--begin=\"mySuite --force\" # reset and begin playing suite 'mySuite', bypass check";
-}
-
-void BeginCmd::addOption(boost::program_options::options_description& desc) const {
-    // allow options like
-    // client --begin=suitename       // begin <suitename>
-    // client --begin                 // means begin all suites
-    desc.add_options()(BeginCmd::arg(), po::value<string>()->implicit_value(string("")), BeginCmd::desc());
-}
-void BeginCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
-    std::string beginArg = vm[arg()].as<std::string>();
-    Str::removeQuotes(beginArg);
-
-    if (ace->debug()) {
-        cout << "  BeginCmd::create arg = " << beginArg << "\n";
-    }
-
-    std::string suiteName;
-    bool force = false;
-
-    if (!beginArg.empty()) {
-        std::vector<std::string> lineTokens;
-        Str::split(beginArg, lineTokens);
-        if (lineTokens.size() == 1) {
-            if (lineTokens[0] == "--force")
-                force = true;
-            else
-                suiteName = lineTokens[0];
-        }
-        else if (lineTokens.size() == 2) {
-            suiteName = lineTokens[0];
-            if (lineTokens[1] != "--force") {
-                std::stringstream ss;
-                ss << "BeginCmd: Expected second argument to be '--force' but found " << lineTokens[1] << "\n";
-                throw std::runtime_error(ss.str());
-            }
-            force = true;
-        }
-        else {
-            std::stringstream ss;
-            ss << "BeginCmd: Expect zero, one or 2 arguments, but found " << lineTokens.size() << " arguments\n"
-               << BeginCmd::desc() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    if (ace->debug()) {
-        std::cout << "  BeginCmd::create suiteName = " << suiteName << "\n";
-        std::cout << "  BeginCmd::create force = " << force << "\n";
-    }
-
-    cmd = std::make_shared<BeginCmd>(suiteName, force);
-}
-
-std::ostream& operator<<(std::ostream& os, const BeginCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(BeginCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(BeginCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/BeginCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/BeginCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/BeginCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/BeginCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_BeginCmd_HPP
-#define ecflow_base_cts_user_BeginCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-
-// class Begin:  if suiteName is empty we will begin all suites
-class BeginCmd final : public UserCmd {
-public:
-    explicit BeginCmd(const std::string& suiteName, bool force = false);
-    BeginCmd() = default;
-
-    const std::string& suiteName() const { return suiteName_; }
-    bool force() const { return force_; }
-
-    int timeout() const override { return 80; }
-
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-private:
-    std::string suiteName_;
-    bool force_{false}; // reset begin status on suites & bypass checks, can create zombies, used in test only
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(suiteName_), CEREAL_NVP(force_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const BeginCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(BeginCmd)
-
-#endif /* ecflow_base_cts_user_BeginCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CFileCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/CFileCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CFileCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CFileCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,384 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/CFileCmd.hpp"
-
-#include <sstream>
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/EcfFile.hpp"
-#include "ecflow/node/Submittable.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-CFileCmd::CFileCmd(const std::string& pathToNode, const std::string& file_type, const std::string& input_max_lines)
-    : pathToNode_(pathToNode),
-      max_lines_(File::MAX_LINES()) {
-    // std::cout << "CFileCmd::CFileCmd the_max_lines " << the_max_lines << "\n";
-
-    if (file_type == "script")
-        file_ = CFileCmd::ECF;
-    else if (file_type == "job")
-        file_ = CFileCmd::JOB;
-    else if (file_type == "jobout")
-        file_ = CFileCmd::JOBOUT;
-    else if (file_type == "manual")
-        file_ = CFileCmd::MANUAL;
-    else if (file_type == "kill")
-        file_ = CFileCmd::KILL;
-    else if (file_type == "stat")
-        file_ = CFileCmd::STAT;
-    else {
-        std::stringstream ss;
-        ss << "CFileCmd::CFileCmd: Unrecognised file type " << file_type
-           << " expected one of [script | job | jobout | manual | kill | stat] \n";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (!input_max_lines.empty()) {
-        try {
-            // Note: max_lines_ if type size_t, hence we cast to int to check for negative numbers
-            auto the_max_lines = ecf::convert_to<int>(input_max_lines);
-            if (the_max_lines <= 0)
-                the_max_lines = File::MAX_LINES();
-            max_lines_ = the_max_lines;
-        }
-        catch (const ecf::bad_conversion&) {
-            std::stringstream ss;
-            ss << "CFileCmd::CFileCmd: The third argument(" << input_max_lines
-               << ") must be convertible to an integer\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-}
-
-std::vector<CFileCmd::File_t> CFileCmd::fileTypesVec() {
-    std::vector<CFileCmd::File_t> vec;
-    vec.reserve(5);
-    vec.push_back(CFileCmd::ECF);
-    vec.push_back(CFileCmd::JOB);
-    vec.push_back(CFileCmd::JOBOUT);
-    vec.push_back(CFileCmd::MANUAL);
-    vec.push_back(CFileCmd::KILL);
-    vec.push_back(CFileCmd::STAT);
-    return vec;
-}
-
-std::string CFileCmd::toString(CFileCmd::File_t ft) {
-    switch (ft) {
-        case CFileCmd::ECF:
-            return "script";
-            break;
-        case CFileCmd::MANUAL:
-            return "manual";
-            break;
-        case CFileCmd::JOB:
-            return "job";
-            break;
-        case CFileCmd::JOBOUT:
-            return "jobout";
-            break;
-        case CFileCmd::KILL:
-            return "kill";
-            break;
-        case CFileCmd::STAT:
-            return "stat";
-            break;
-        default:
-            break;
-    }
-    return "script";
-}
-
-bool CFileCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<CFileCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (file_ != the_rhs->fileType()) {
-        return false;
-    }
-    if (max_lines_ != the_rhs->max_lines()) {
-        return false;
-    }
-    if (pathToNode_ != the_rhs->pathToNode()) {
-        return false;
-    }
-    return UserCmd::equals(rhs);
-}
-
-void CFileCmd::print(std::string& os) const {
-    user_cmd(os,
-             CtsApi::to_string(CtsApi::file(pathToNode_, toString(file_), ecf::convert_to<std::string>(max_lines_))));
-}
-void CFileCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::file(pathToNode_, toString(file_), ecf::convert_to<std::string>(max_lines_)));
-}
-
-STC_Cmd_ptr CFileCmd::doHandleRequest(AbstractServer* as) const {
-    // cout << "CFileCmd::doHandleRequest " << toString(file_) << " =======================================\n";
-    switch (file_) {
-        case CFileCmd::ECF:
-            as->update_stats().file_ecf_++;
-            break;
-        case CFileCmd::MANUAL:
-            as->update_stats().file_manual_++;
-            break;
-        case CFileCmd::JOB:
-            as->update_stats().file_job_++;
-            break;
-        case CFileCmd::JOBOUT:
-            as->update_stats().file_jobout_++;
-            break;
-        case CFileCmd::KILL:
-            as->update_stats().file_cmdout_++;
-            break;
-        case CFileCmd::STAT:
-            as->update_stats().file_cmdout_++;
-            break;
-    }
-
-    node_ptr node = find_node(as->defs().get(), pathToNode_); // will throw if defs not defined, or node not found
-
-    std::string fileContents;
-    Submittable* submittable = node->isSubmittable();
-    if (submittable) {
-
-        switch (file_) {
-            case CFileCmd::ECF: {
-                EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
-                ecf_file.script(fileContents);                    // will throw std::runtime_error for errors
-                break;
-            }
-
-            case CFileCmd::MANUAL: {
-                EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
-                ecf_file.manual(fileContents);                    // will throw std::runtime_error for errors
-                break;
-            }
-
-            case CFileCmd::JOB: {
-                std::string ecf_job_file;
-                submittable->findParentVariableValue(Str::ECF_JOB(), ecf_job_file);
-                if (!File::open(ecf_job_file, fileContents)) {
-                    std::stringstream ss;
-                    ss << "CFileCmd::doHandleRequest: Failed to open the job file('" << ecf_job_file << "') for task "
-                       << pathToNode_ << " (" << strerror(errno) << ")";
-                    throw std::runtime_error(ss.str());
-                }
-                break;
-            }
-
-            case CFileCmd::JOBOUT: {
-
-                // ECF_JOBOUT is either constructed from:
-                // - (generated variable) ECF_HOME/ECF_NAME.ECF_TRYNO (common/default)
-                // - (generated variable) ECF_OUT/ECF_NAME.ECF_TRYNO  (common, user must create any directories)
-                // - (user variable)                                  (if defined try first,user must create any
-                // directories) See: Submittable.cpp: SubGenVariables::update_generated_variables()
-                //
-                // Typically if ECF_OUT is specified, we should only look at that location
-                // however SMS also looked at the alternate location (and RD relied on this ECFLOW-177 )
-
-                // First try user variable, if defined this has priority ECFLOW-999
-                std::stringstream ss;
-                std::string user_jobout;
-                if (submittable->findParentUserVariableValue(Str::ECF_JOBOUT(), user_jobout)) {
-                    if (File::open(user_jobout, fileContents))
-                        break;
-                    ss << "Failed to open user specified job-out(ECF_JOBOUT='" << user_jobout << "') ";
-                }
-
-                const Variable& ecf_jobout_gen_var = submittable->findGenVariable(Str::ECF_JOBOUT());
-                if (!File::open(ecf_jobout_gen_var.theValue(), fileContents)) {
-
-                    // If that fails as a backup, look under ECF_HOME/ECF_NAME.ECF_TRYNO,   ECFLOW-177 preserve old SMS
-                    // behaviour
-                    std::string ecfhome_jobout;
-                    submittable->findParentUserVariableValue(Str::ECF_HOME(), ecfhome_jobout);
-                    ecfhome_jobout += submittable->absNodePath();
-                    ecfhome_jobout += ".";
-                    ecfhome_jobout += submittable->tryNo();
-
-                    if (ecfhome_jobout != ecf_jobout_gen_var.theValue()) {
-                        // Implies ECF_OUT was specified, hence *ALSO* look in ECF_HOME/ECF_NAME.ECF_TRYNO
-                        if (!File::open(ecfhome_jobout, fileContents)) {
-                            ss << "Failed to open the job-out (ECF_JOBOUT=ECF_OUT/ECF_NAME.ECF_TRYNO='"
-                               << ecf_jobout_gen_var.theValue() << "') ";
-                            ss << "*AND* (ECF_JOBOUT=ECF_HOME/ECF_NAME.ECF_TRYNO='" << ecfhome_jobout << "')";
-                            ss << " for task " << pathToNode_ << " (" << strerror(errno) << ")";
-                            throw std::runtime_error(ss.str());
-                        }
-                    }
-                    else {
-                        // ECF_OUT *not* specified implies ECF_JOBOUT = ECF_HOME/ECF_NAME.ECF_TRYNO
-                        ss << "Failed to open the job-out(ECF_JOBOUT=ECF_HOME/ECF_NAME.ECF_TRYNO='"
-                           << ecf_jobout_gen_var.theValue() << "') ";
-                        ss << " for task " << pathToNode_ << " (" << strerror(errno) << ")";
-                        throw std::runtime_error(ss.str());
-                    }
-                }
-
-                break;
-            }
-
-            case CFileCmd::KILL: {
-                std::string ecf_job_file;
-                submittable->findParentVariableValue(Str::ECF_JOB(), ecf_job_file);
-                std::string file = ecf_job_file + ".kill";
-                if (!File::open(file, fileContents)) {
-                    std::stringstream ss;
-                    ss << "CFileCmd::doHandleRequest: Failed to open the kill output file('" << file << "') for task "
-                       << pathToNode_ << " (" << strerror(errno) << ")";
-                    throw std::runtime_error(ss.str());
-                }
-                break;
-            }
-
-            case CFileCmd::STAT: {
-                std::string ecf_job_file;
-                submittable->findParentVariableValue(Str::ECF_JOB(), ecf_job_file);
-                std::string file = ecf_job_file + ".stat";
-                if (!File::open(file, fileContents)) {
-                    std::stringstream ss;
-                    ss << "CFileCmd::doHandleRequest: Failed to open the status output file('" << file << "') for task "
-                       << pathToNode_ << " (" << strerror(errno) << ")";
-                    throw std::runtime_error(ss.str());
-                }
-                break;
-            }
-
-            default:
-                assert(false);
-                break;
-        }
-    }
-    else {
-
-        if (file_ == CFileCmd::MANUAL) {
-            // The only valid option for Suite or Family is Manual
-
-            // First look for .man files in ECF_FILES and then ECF_HOME
-            std::string ecf_files;
-            node->findParentUserVariableValue(Str::ECF_FILES(), ecf_files);
-            if (!ecf_files.empty() && fs::is_directory(ecf_files)) {
-
-                std::string manFile = File::backwardSearch(ecf_files, node->absNodePath(), File::MAN_EXTN());
-                if (!manFile.empty()) {
-                    EcfFile the_file(node.get(), manFile);
-                    the_file.manual(
-                        fileContents); // pre-process & extract manual: will throw std::runtime_error for errors
-                }
-            }
-
-            if (fileContents.empty()) {
-                // Try under ECF_HOME
-                std::string ecf_home;
-                node->findParentUserVariableValue(Str::ECF_HOME(), ecf_home);
-                if (!ecf_home.empty() && fs::is_directory(ecf_home)) {
-
-                    std::string manFile = File::backwardSearch(ecf_home, node->absNodePath(), File::MAN_EXTN());
-                    EcfFile the_file(node.get(), manFile);
-                    the_file.manual(
-                        fileContents); // pre-process & extract manual: will throw std::runtime_error for errors
-                }
-                else {
-                    std::string errorMsg = "Failed to find the manual for Suite/Family  ";
-                    errorMsg += pathToNode_;
-                    errorMsg +=
-                        " ECF_HOME directory does not exist and/or ECF_FILES not defined or directory does not exist.";
-                    throw std::runtime_error(errorMsg);
-                }
-            }
-        }
-        else {
-            std::stringstream ss;
-            ss << "Option " << CFileCmd::toString(file_) << " is only valid for tasks";
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    /// The file could get very large, hence truncate at the start
-    if (Str::truncate_at_start(fileContents, max_lines_)) {
-        std::stringstream ss;
-        ss << "\n# >>>>>>>> File truncated down to " << max_lines_
-           << ". Truncated from the end of the file <<<<<<<<<\n";
-        fileContents += ss.str();
-    }
-
-    return PreAllocatedReply::string_cmd(fileContents);
-}
-
-bool CFileCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, pathToNode_);
-}
-
-const char* CFileCmd::arg() {
-    return CtsApi::fileArg();
-}
-const char* CFileCmd::desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Return the chosen file. Select from [ script<default> | job | jobout | manual | kill | stat ]\n"
-           "By default will return the script.\n"
-           "  arg1 = path to node\n"
-           "  arg2 = (optional) [ script<default> | job | jobout | manual | kill | stat ]\n"
-           "         kill will attempt to return output of ECF_KILL_CMD, i.e the file %ECF_JOB%.kill\n"
-           "         stat will attempt to return output of ECF_STATUS_CMD, i.e the file %ECF_JOB%.stat\n"
-           "  arg3 = (optional) max_lines = 10000 <default>";
-}
-
-void CFileCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(CFileCmd::arg(), po::value<vector<string>>()->multitoken(), CFileCmd::desc());
-}
-void CFileCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(CFileCmd::arg(), args);
-
-    if (args.size() < 1) {
-        std::stringstream ss;
-        ss << "CFileCmd: At least one arguments expected for File. Found " << args.size() << "\n"
-           << CFileCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string pathToNode = args[0];
-
-    std::string file_type = "script";
-    if (args.size() >= 2) {
-        file_type = args[1];
-    }
-
-    std::string max_lines;
-    if (args.size() == 3) {
-        max_lines = args[2];
-    }
-
-    cmd = std::make_shared<CFileCmd>(pathToNode, file_type, max_lines);
-}
-
-std::ostream& operator<<(std::ostream& os, const CFileCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(CFileCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(CFileCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CFileCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/CFileCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CFileCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CFileCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_CFileCmd_HPP
-#define ecflow_base_cts_user_CFileCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-//================================================================================
-// Paired with SStringCmd
-// Client---(CFileCmd)---->Server-----(SStringCmd)--->client:
-//================================================================================
-class CFileCmd final : public UserCmd {
-public:
-    enum File_t { ECF, JOB, JOBOUT, MANUAL, KILL, STAT };
-    CFileCmd(const std::string& pathToNode, File_t file, size_t max_lines)
-        : file_(file),
-          pathToNode_(pathToNode),
-          max_lines_(max_lines) {}
-    CFileCmd(const std::string& pathToNode, const std::string& file_type, const std::string& max_lines);
-    CFileCmd() = default;
-
-    // Uses by equals only
-    const std::string& pathToNode() const { return pathToNode_; }
-    File_t fileType() const { return file_; }
-    size_t max_lines() const { return max_lines_; }
-
-    static std::vector<CFileCmd::File_t> fileTypesVec();
-    static std::string toString(File_t);
-
-    bool handleRequestIsTestable() const override { return false; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-
-    File_t file_{ECF};
-    std::string pathToNode_;
-    size_t max_lines_{0};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(file_), CEREAL_NVP(pathToNode_), CEREAL_NVP(max_lines_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const CFileCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(CFileCmd)
-
-#endif /* ecflow_base_cts_user_CFileCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CSyncCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/CSyncCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CSyncCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CSyncCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,234 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/CSyncCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-void CSyncCmd::print(std::string& os) const {
-    /// Note: Be careful how the *debug* output is interpreted, since the:
-    /// client_handle_  > 0  state/modify numbers will be for a set of registered suites,
-    /// client_handle_ == 0  state/modify numbers is global i.e. for all suites.
-    switch (api_) {
-        case CSyncCmd::NEWS:
-            user_cmd(
-                os, CtsApi::to_string(CtsApi::news(client_handle_, client_state_change_no_, client_modify_change_no_)));
-            break;
-        case CSyncCmd::SYNC:
-            user_cmd(
-                os, CtsApi::to_string(CtsApi::sync(client_handle_, client_state_change_no_, client_modify_change_no_)));
-            break;
-        case CSyncCmd::SYNC_FULL:
-            user_cmd(os, CtsApi::sync_full(client_handle_));
-            break;
-        case CSyncCmd::SYNC_CLOCK:
-            user_cmd(os,
-                     CtsApi::to_string(
-                         CtsApi::sync_clock(client_handle_, client_state_change_no_, client_modify_change_no_)));
-            break;
-    }
-}
-
-std::string CSyncCmd::print_short() const {
-    std::string os;
-    print_only(os);
-    return os;
-}
-
-void CSyncCmd::print_only(std::string& os) const {
-    switch (api_) {
-        case CSyncCmd::NEWS:
-            os += CtsApi::to_string(CtsApi::news(client_handle_, client_state_change_no_, client_modify_change_no_));
-            break;
-        case CSyncCmd::SYNC:
-            os += CtsApi::to_string(CtsApi::sync(client_handle_, client_state_change_no_, client_modify_change_no_));
-            break;
-        case CSyncCmd::SYNC_FULL:
-            os += CtsApi::sync_full(client_handle_);
-            break;
-        case CSyncCmd::SYNC_CLOCK:
-            os += CtsApi::to_string(
-                CtsApi::sync_clock(client_handle_, client_state_change_no_, client_modify_change_no_));
-            break;
-    }
-}
-
-bool CSyncCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<CSyncCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (api_ != the_rhs->api())
-        return false;
-    if (client_handle_ != the_rhs->client_handle())
-        return false;
-    if (client_state_change_no_ != the_rhs->client_state_change_no())
-        return false;
-    if (client_modify_change_no_ != the_rhs->client_modify_change_no())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-const char* CSyncCmd::theArg() const {
-    switch (api_) {
-        case CSyncCmd::NEWS:
-            return CtsApi::newsArg();
-        case CSyncCmd::SYNC:
-            return CtsApi::syncArg();
-        case CSyncCmd::SYNC_FULL:
-            return CtsApi::sync_full_arg();
-        case CSyncCmd::SYNC_CLOCK:
-            return CtsApi::sync_clock_arg();
-    }
-    // should never get here:
-    return CtsApi::syncArg();
-}
-
-int CSyncCmd::timeout() const {
-    if (api_ == CSyncCmd::SYNC || api_ == CSyncCmd::SYNC_FULL || api_ == CSyncCmd::SYNC_CLOCK) {
-        return time_out_for_load_sync_and_get();
-    }
-    return 20; // CSyncCmd::NEWS
-}
-
-void CSyncCmd::do_log(AbstractServer* as) const {
-    if (api_ == CSyncCmd::NEWS) {
-
-        /// Log without adding a new line, to the log file
-        /// The SNewsCmd will append additional debug and then add new line
-        std::string ss;
-        print(ss);                           // Populate the stream with command details:
-        if (!log_no_newline(Log::MSG, ss)) { // log command without adding newline
-            // problems with opening or writing to log file, warn users, ECFLOW-536
-            as->defs()->flag().set(ecf::Flag::LOG_ERROR);
-            as->defs()->set_server().add_or_update_user_variables("ECF_LOG_ERROR", Log::instance()->log_error());
-        }
-        return;
-    }
-
-    ClientToServerCmd::do_log(as);
-}
-
-STC_Cmd_ptr CSyncCmd::doHandleRequest(AbstractServer* as) const {
-    // LogTimer timer(" CSyncCmd::doHandleRequest");
-
-    // If no defs not loaded, SSyncCmd and SNewsCmd do nothing. This is a valid state, hence don't error for this
-    // request
-    switch (api_) {
-        case CSyncCmd::NEWS: {
-            as->update_stats().news_++;
-            return PreAllocatedReply::news_cmd(client_handle_, client_state_change_no_, client_modify_change_no_, as);
-        }
-        case CSyncCmd::SYNC: {
-            as->update_stats().sync_++;
-            return PreAllocatedReply::sync_cmd(client_handle_, client_state_change_no_, client_modify_change_no_, as);
-        }
-        case CSyncCmd::SYNC_FULL: {
-            as->update_stats().sync_full_++;
-            return PreAllocatedReply::sync_full_cmd(client_handle_, as);
-        }
-        case CSyncCmd::SYNC_CLOCK: {
-            as->update_stats().sync_clock_++;
-            return PreAllocatedReply::sync_clock_cmd(
-                client_handle_, client_state_change_no_, client_modify_change_no_, as);
-        }
-    }
-
-    // should never get here:
-    return PreAllocatedReply::sync_cmd(client_handle_, client_state_change_no_, client_modify_change_no_, as);
-}
-
-void CSyncCmd::addOption(boost::program_options::options_description& desc) const {
-    if (api_ == CSyncCmd::NEWS) {
-        desc.add_options()(
-            CtsApi::newsArg(),
-            po::value<vector<unsigned int>>()->multitoken(),
-            "Returns true if state of server definition changed.\n"
-            "*Important* for use with c++/python interface only.\n"
-            "Requires Given a client handle, change and modify number determine if server changed since last call\n"
-            "This relies on user calling sync after news to update the locally stored modify and change numbers.\n"
-            "These numbers are then used in the next call to news.");
-        return;
-    }
-
-    if (api_ == CSyncCmd::SYNC) {
-        desc.add_options()(
-            CtsApi::syncArg(),
-            po::value<vector<unsigned int>>()->multitoken(),
-            "Incrementally synchronise the local definition with the one in the server.\n"
-            "*Important* for use with c++/python interface only.\n"
-            "Preference should be given to this method as only the changes are returned.\n"
-            "This reduces the network bandwidth required to keep in sync with the server\n"
-            "Requires a client handle, change and modify number, to get the incremental changes from server.\n"
-            "The change in server state is then and merged with the client definition.");
-        return;
-    }
-
-    if (api_ == CSyncCmd::SYNC_CLOCK) {
-        desc.add_options()(
-            CtsApi::sync_clock_arg(),
-            po::value<vector<unsigned int>>()->multitoken(),
-            "Incrementally synchronise the local definition with the one in the server.\n"
-            "*Important* for use with c++/python interface only.\n"
-            "Same as sync, but will *always* sync with suite clock if it has changed.\n"
-            "Preference should be given to this method as only the changes are returned.\n"
-            "This reduces the network bandwidth required to keep in sync with the server\n"
-            "Requires a client handle, change and modify number, to get the incremental changes from server.\n"
-            "The change in server state is then and merged with the client definition.");
-        return;
-    }
-
-    desc.add_options()(CtsApi::sync_full_arg(),
-                       po::value<unsigned int>(),
-                       "Returns the full definition from the server.\n"
-                       "*Important* for use with c++/python interface only.\n"
-                       "Requires a client_handle. The returned definition is stored on the client.");
-}
-
-void CSyncCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    if (ac->debug())
-        cout << "  CSyncCmd::create api = '" << api_ << "'.\n";
-
-    if (api_ == CSyncCmd::NEWS || api_ == CSyncCmd::SYNC || api_ == CSyncCmd::SYNC_CLOCK) {
-        vector<unsigned int> args = vm[theArg()].as<vector<unsigned int>>();
-        if (args.size() != 3)
-            throw std::runtime_error("CSyncCmd::create(SYNC/SYN_CLOCK/NEWS) expects 3 integer arguments, Client "
-                                     "handle, state change number, and modify change number");
-        unsigned int client_handle    = args[0];
-        unsigned int state_change_no  = args[1];
-        unsigned int modify_change_no = args[2];
-        cmd = std::make_shared<CSyncCmd>(api_, client_handle, state_change_no, modify_change_no);
-        return;
-    }
-
-    unsigned int client_handle = vm[theArg()].as<unsigned int>();
-    cmd                        = std::make_shared<CSyncCmd>(client_handle); // FULL_SYNC
-}
-
-std::ostream& operator<<(std::ostream& os, const CSyncCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(CSyncCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(CSyncCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CSyncCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/CSyncCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CSyncCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CSyncCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,78 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_CSyncCmd_HPP
-#define ecflow_base_cts_user_CSyncCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// Client---(CSyncCmd::SYNC_FULL)---->Server-----(SSyncCmd)--->client:
-// Client---(CSyncCmd::SYNC)--------->Server-----(SSyncCmd)--->client:
-// Client---(CSyncCmd::SYNC_CLOCK)--->Server-----(SSyncCmd)--->client:
-// Client---(CSyncCmd::NEWS)--------->Server-----(SNewsCmd)--->client:
-class CSyncCmd final : public UserCmd {
-public:
-    enum Api { NEWS, SYNC, SYNC_FULL, SYNC_CLOCK };
-
-    CSyncCmd(Api a,
-             unsigned int client_handle,
-             unsigned int client_state_change_no,
-             unsigned int client_modify_change_no)
-        : api_(a),
-          client_handle_(client_handle),
-          client_state_change_no_(client_state_change_no),
-          client_modify_change_no_(client_modify_change_no) {}
-    explicit CSyncCmd(unsigned int client_handle) : api_(SYNC_FULL), client_handle_(client_handle) {}
-    CSyncCmd() = default;
-
-    Api api() const { return api_; }
-    int client_state_change_no() const { return client_state_change_no_; }
-    int client_modify_change_no() const { return client_modify_change_no_; }
-    int client_handle() const { return client_handle_; }
-
-    void set_client_handle(int client_handle) override { client_handle_ = client_handle; } // used by group_cmd
-    void print(std::string&) const override;
-    std::string print_short() const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-    int timeout() const override;
-
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    /// Custom handling of command logging to add additional debug on same line
-    /// makes it easier to debug errors in syncing.
-    void do_log(AbstractServer*) const override;
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    Api api_{SYNC};
-    int client_handle_{0};
-    int client_state_change_no_{0};
-    int client_modify_change_no_{0};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(api_),
-           CEREAL_NVP(client_handle_),
-           CEREAL_NVP(client_state_change_no_),
-           CEREAL_NVP(client_modify_change_no_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const CSyncCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(CSyncCmd)
-
-#endif /* ecflow_base_cts_user_CSyncCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CheckPtCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/CheckPtCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CheckPtCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CheckPtCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,235 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/CheckPtCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Converter.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-void CheckPtCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::checkPtDefs(mode_, check_pt_interval_, check_pt_save_time_alarm_));
-}
-void CheckPtCmd::print_only(std::string& os) const {
-    os += CtsApi::checkPtDefs(mode_, check_pt_interval_, check_pt_save_time_alarm_);
-}
-
-bool CheckPtCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<CheckPtCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (mode_ != the_rhs->mode())
-        return false;
-    if (check_pt_interval_ != the_rhs->check_pt_interval())
-        return false;
-    if (check_pt_save_time_alarm_ != the_rhs->check_pt_save_time_alarm())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-bool CheckPtCmd::isWrite() const {
-    if (mode_ != ecf::CheckPt::UNDEFINED)
-        return true;
-    if (check_pt_interval_ != 0)
-        return true;
-    if (check_pt_save_time_alarm_ != 0)
-        return true;
-    return false;
-}
-
-bool CheckPtCmd::is_mutable() const {
-    // if save to takes to long, the the late flag is set. Even when command is read only
-    // Also if writing to checkpoint fails we set: ecf::Flag::CHECKPT_ERROR
-    // Likewise writing to the log file can also fail, hence we set: ecf::Flag::LOG_ERROR, when manually check pointing
-    // Even when command is read only ?
-    // This an exceptional situation!!
-    return true;
-}
-
-const char* CheckPtCmd::theArg() const {
-    return CtsApi::checkPtDefsArg();
-}
-
-STC_Cmd_ptr CheckPtCmd::doHandleRequest(AbstractServer* as) const {
-    // Placed here rather than in server. Since we want to record explicit request to check pt
-    // The update_stats() is used to record the number of requests per second, hence we do not
-    // want to skew this, and hence we ignore implicit request's via signal handling,
-    // or when server terminates( does implicit check pt also)
-    as->update_stats().checkpt_++;
-    if (!as->checkPtDefs(mode_, check_pt_interval_, check_pt_save_time_alarm_)) {
-        throw std::runtime_error("Could not save check point file. file system full or permissions ?");
-    }
-    return PreAllocatedReply::ok_cmd();
-}
-
-static const char* arg_desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-    return "Forces the definition file in the server to be written to disk *or* allow mode,\n"
-           "interval and alarm to be changed.\n"
-           "Whenever the check pt file is written to disk, it is measured.\n"
-           "If the time to save to disk is greater than the default of 30 seconds,\n"
-           "then an alarm is raised. This can be seen in the GUI as a late flag on the server.\n"
-           "Once the late flag has been set it will need to manually cleared in the GUI\n"
-           "or by using --alter functionality\n"
-           "Note excessive save times can interfere with job scheduling.\n"
-           "The alarm threshold can be changed. See below.\n"
-           "   arg1 = (optional) mode [ never | on_time | on_time:<integer> | always | <integer>]\n"
-           "     never     : Never check point the definition in the server\n"
-           "     on_time   : Turn on automatic check pointing at interval stored on server\n"
-           "     on_time<integer> : Turn on automatic check point, with the specified interval in seconds\n"
-           "     alarm<integer>   : Modify the alarm notification time for check pt saving to disk\n"
-           "     always    : Check point at any change in node tree, *NOT* recommended for large definitions\n"
-           "     <integer> : This specifies the interval in seconds when server should automatically check pt.\n"
-           "                 This will only take effect of mode is on_time/CHECK_ON_TIME\n"
-           "                 Should ideally be a value greater than 60 seconds, default is 120 seconds\n"
-           "Usage:\n"
-           "  --check_pt\n"
-           "    Immediately check point the definition held in the server\n"
-           "  --check_pt=never\n"
-           "    Switch off check pointing\n"
-           "  --check_pt=on_time\n"
-           "    Start automatic check pointing at the interval stored in the server\n"
-           "  --check_pt=180\n"
-           "    Change the check pt interval to 180 seconds\n"
-           "  --check_pt=on_time:90\n"
-           "    Change mode and interval, to automatic check pointing every 90 seconds\n"
-           "  --check_pt=alarm:35\n"
-           "    Change the alarm time for check pt saves. i.e if saving the check pt takes longer than 35 seconds\n"
-           "    set the late flag on the server.";
-}
-
-void CheckPtCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(CtsApi::checkPtDefsArg(), po::value<string>()->implicit_value(string("")), arg_desc());
-}
-
-static int parse_check_pt_interval(const std::string& the_arg) {
-    int check_pt_interval = 0;
-    try {
-        check_pt_interval = ecf::convert_to<int>(the_arg);
-    }
-    catch (...) {
-        std::stringstream ss;
-        ss << "check_pt: Illegal argument(" << the_arg
-           << "), expected [ never | on_time | on_time:<integer> | always | <integer>]\n"
-           << arg_desc();
-        throw std::runtime_error(ss.str());
-    }
-    if (check_pt_interval <= 0) {
-        std::stringstream ss;
-        ss << "check_pt: interval(" << check_pt_interval << ") must be greater than zero :\n" << arg_desc();
-        throw std::runtime_error(ss.str());
-    }
-    return check_pt_interval;
-}
-
-static int parse_check_pt_alarm_time(const std::string& the_arg, int colon_pos) {
-    std::string alarm_time = the_arg.substr(colon_pos + 1);
-
-    int check_pt_alarm_time = 0;
-    try {
-        check_pt_alarm_time = ecf::convert_to<int>(alarm_time);
-    }
-    catch (...) {
-        std::stringstream ss;
-        ss << "check_pt: Illegal argument(" << the_arg
-           << "), expected [ never | on_time | on_time:<integer> | alarm::integer> | always | <integer>]\n"
-           << arg_desc();
-        throw std::runtime_error(ss.str());
-    }
-    if (check_pt_alarm_time <= 0) {
-        std::stringstream ss;
-        ss << "check_pt: alarm time(" << check_pt_alarm_time << ") must be greater than zero :\n" << arg_desc();
-        throw std::runtime_error(ss.str());
-    }
-    return check_pt_alarm_time;
-}
-
-void CheckPtCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
-    if (ace->debug())
-        cout << "CheckPtCmd::create\n";
-
-    std::string the_arg = vm[theArg()].as<std::string>();
-
-    if (ace->debug())
-        cout << "  CheckPtCmd::create arg = " << the_arg << "\n";
-
-    ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED;
-    int check_pt_interval        = 0;
-    int check_pt_save_time_alarm = 0;
-
-    if (!the_arg.empty()) {
-        size_t colon_pos = the_arg.find(":");
-        if (colon_pos != std::string::npos) {
-            // could be mode:interval or alarm:integer
-            if (the_arg.find("alarm") != std::string::npos) {
-                check_pt_save_time_alarm = parse_check_pt_alarm_time(the_arg, colon_pos);
-            }
-            else {
-                std::string mode     = the_arg.substr(0, colon_pos);
-                std::string interval = the_arg.substr(colon_pos + 1);
-
-                if (mode == "never")
-                    m = ecf::CheckPt::NEVER;
-                else if (mode == "on_time")
-                    m = ecf::CheckPt::ON_TIME;
-                else if (mode == "always")
-                    m = ecf::CheckPt::ALWAYS;
-                else {
-                    std::stringstream ss;
-                    ss << "check_pt: Illegal argument(" << the_arg
-                       << "), expected [ never | on_time | on_time:<integer> | alarm:<integer> | always | <integer>]\n"
-                       << arg_desc();
-                    throw std::runtime_error(ss.str());
-                }
-                check_pt_interval = parse_check_pt_interval(interval);
-            }
-        }
-        else {
-            if (the_arg == "never")
-                m = ecf::CheckPt::NEVER;
-            else if (the_arg == "on_time")
-                m = ecf::CheckPt::ON_TIME;
-            else if (the_arg == "always")
-                m = ecf::CheckPt::ALWAYS;
-            else {
-                check_pt_interval = parse_check_pt_interval(the_arg);
-            }
-        }
-    }
-
-    // testing client interface
-    if (ace->under_test())
-        return;
-
-    if (ace->debug())
-        cout << "  CheckPtCmd::create mode = " << m << " check_pt_interval = " << check_pt_interval << "\n";
-
-    cmd = std::make_shared<CheckPtCmd>(m, check_pt_interval, check_pt_save_time_alarm);
-}
-
-std::ostream& operator<<(std::ostream& os, const CheckPtCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(CheckPtCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(CheckPtCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CheckPtCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/CheckPtCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CheckPtCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CheckPtCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_CheckPtCmd_HPP
-#define ecflow_base_cts_user_CheckPtCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-#include "ecflow/core/CheckPt.hpp"
-
-class CheckPtCmd final : public UserCmd {
-public:
-    CheckPtCmd(ecf::CheckPt::Mode m, int interval, int checkpt_save_time_alarm)
-        : mode_(m),
-          check_pt_interval_(interval),
-          check_pt_save_time_alarm_(checkpt_save_time_alarm) {}
-    CheckPtCmd() = default;
-
-    ecf::CheckPt::Mode mode() const { return mode_; }
-    int check_pt_interval() const { return check_pt_interval_; }
-    int check_pt_save_time_alarm() const { return check_pt_save_time_alarm_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-    bool isWrite() const override;
-    bool is_mutable() const override;
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-private:
-    ecf::CheckPt::Mode mode_{ecf::CheckPt::UNDEFINED};
-    int check_pt_interval_{0};
-    int check_pt_save_time_alarm_{0};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(mode_),
-           CEREAL_NVP(check_pt_interval_),
-           CEREAL_NVP(check_pt_save_time_alarm_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const CheckPtCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(CheckPtCmd)
-
-#endif /* ecflow_base_cts_user_CheckPtCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,517 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-/// *****************************************************************************
-/// Note: The Client Handle commands, change the server,
-///       However the changes cant really be considered as incremental
-///       Hence for all handle command, we will do a FULL SYNC
-///       Relying on the modify_change_no is to CRUDE, as it affects all handles
-///       Instead we will use a simple flag to indicate that a FULL sync is required
-/// *****************************************************************************
-
-void ClientHandleCmd::print(std::string& os) const {
-    switch (api_) {
-        case ClientHandleCmd::REGISTER:
-            user_cmd(os, CtsApi::to_string(CtsApi::ch_register(client_handle_, auto_add_new_suites_, suites_)));
-            break;
-        case ClientHandleCmd::DROP:
-            user_cmd(os, CtsApi::ch_drop(client_handle_));
-            break;
-        case ClientHandleCmd::DROP_USER: {
-            if (drop_user_.empty())
-                user_cmd(os, CtsApi::ch_drop_user(user()));
-            else
-                user_cmd(os, CtsApi::ch_drop_user(drop_user_));
-            break;
-        }
-        case ClientHandleCmd::ADD:
-            user_cmd(os, CtsApi::to_string(CtsApi::ch_add(client_handle_, suites_)));
-            break;
-        case ClientHandleCmd::REMOVE:
-            user_cmd(os, CtsApi::to_string(CtsApi::ch_remove(client_handle_, suites_)));
-            break;
-        case ClientHandleCmd::AUTO_ADD:
-            user_cmd(os, CtsApi::to_string(CtsApi::ch_auto_add(client_handle_, auto_add_new_suites_)));
-            break;
-        case ClientHandleCmd::SUITES:
-            user_cmd(os, CtsApi::ch_suites());
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-
-void ClientHandleCmd::print_only(std::string& os) const {
-    switch (api_) {
-        case ClientHandleCmd::REGISTER:
-            os += CtsApi::to_string(CtsApi::ch_register(client_handle_, auto_add_new_suites_, suites_));
-            break;
-        case ClientHandleCmd::DROP:
-            os += CtsApi::ch_drop(client_handle_);
-            break;
-        case ClientHandleCmd::DROP_USER: {
-            if (drop_user_.empty())
-                os += CtsApi::ch_drop_user(user());
-            else
-                os += CtsApi::ch_drop_user(drop_user_);
-            break;
-        }
-        case ClientHandleCmd::ADD:
-            os += CtsApi::to_string(CtsApi::ch_add(client_handle_, suites_));
-            break;
-        case ClientHandleCmd::REMOVE:
-            os += CtsApi::to_string(CtsApi::ch_remove(client_handle_, suites_));
-            break;
-        case ClientHandleCmd::AUTO_ADD:
-            os += CtsApi::to_string(CtsApi::ch_auto_add(client_handle_, auto_add_new_suites_));
-            break;
-        case ClientHandleCmd::SUITES:
-            os += CtsApi::ch_suites();
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-
-bool ClientHandleCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<ClientHandleCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (api_ != the_rhs->api())
-        return false;
-    if (drop_user_ != the_rhs->drop_user())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-const char* ClientHandleCmd::theArg() const {
-    switch (api_) {
-        case ClientHandleCmd::REGISTER:
-            return CtsApi::ch_register_arg();
-            break;
-        case ClientHandleCmd::DROP:
-            return CtsApi::ch_drop_arg();
-            break;
-        case ClientHandleCmd::DROP_USER:
-            return CtsApi::ch_drop_user_arg();
-            break;
-        case ClientHandleCmd::ADD:
-            return CtsApi::ch_add_arg();
-            break;
-        case ClientHandleCmd::REMOVE:
-            return CtsApi::ch_remove_arg();
-            break;
-        case ClientHandleCmd::AUTO_ADD:
-            return CtsApi::ch_auto_add_arg();
-            break;
-        case ClientHandleCmd::SUITES:
-            return CtsApi::ch_suites_arg();
-            break;
-    }
-    assert(false);
-    return nullptr;
-}
-
-bool ClientHandleCmd::cmd_updates_defs() const {
-    switch (api_) {
-        case ClientHandleCmd::REGISTER:
-            return true;
-            break;
-        case ClientHandleCmd::DROP:
-            return true;
-            break; // can be expensive for large defs
-        case ClientHandleCmd::DROP_USER:
-            return true;
-            break; // can be expensive for large defs
-        case ClientHandleCmd::ADD:
-            return true;
-            break;
-        case ClientHandleCmd::REMOVE:
-            return true;
-            break;
-        case ClientHandleCmd::AUTO_ADD:
-            return false;
-            break;
-        case ClientHandleCmd::SUITES:
-            return false;
-            break;
-    }
-    assert(false);
-    return false;
-}
-
-STC_Cmd_ptr ClientHandleCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().ch_cmd_++;
-
-    switch (api_) {
-        case ClientHandleCmd::REGISTER: {
-
-            // If existing handle is non zero drop it first
-            if (client_handle_ != 0) {
-                as->defs()->client_suite_mgr().remove_client_suite(client_handle_); // will throw if handle not found
-            }
-
-            unsigned int client_handle =
-                as->defs()->client_suite_mgr().create_client_suite(auto_add_new_suites_, suites_, user());
-            // #ifdef DEBUG
-            //  	   LOG(Log::DBG,as->defs()->client_suite_mgr().dump_max_change_no());
-            // #endif
-
-            // If this command is part of a group command, let the following sync command, know about the new handle
-            // So it return the defs with the right set of suites.
-            if (group_cmd_)
-                group_cmd_->set_client_handle(client_handle);
-
-            // return the handle to the client
-            return PreAllocatedReply::client_handle_cmd(client_handle);
-        }
-
-        case ClientHandleCmd::DROP: {
-            as->defs()->client_suite_mgr().remove_client_suite(client_handle_); // will throw if handle not found
-
-            // If this command is part of a group command, let the following sync command, know about the new handle
-            // So it return the defs with the right set of suites.
-            // If used with following sync, will return *FULL* defs. Can be expensive
-            if (group_cmd_)
-                group_cmd_->set_client_handle(0);
-
-            // return the 0 handle to the client. The client stores the handle locally. Reset to zero.
-            return PreAllocatedReply::client_handle_cmd(0);
-        }
-
-        case ClientHandleCmd::DROP_USER: {
-            // will throw if no users handles dropped
-            if (drop_user_.empty())
-                as->defs()->client_suite_mgr().remove_client_suites(user());
-            else
-                as->defs()->client_suite_mgr().remove_client_suites(drop_user_);
-
-            if (drop_user_.empty() || drop_user_ == user()) {
-
-                // If this command is part of a group command, let the following sync command, know about the new handle
-                // So it return the defs with the right set of suites.
-                // If used with following sync, will return *FULL* defs.
-                if (group_cmd_)
-                    group_cmd_->set_client_handle(0);
-
-                // return the 0 handle to the client. The client stores the handle locally. Reset to zero.
-                return PreAllocatedReply::client_handle_cmd(0);
-            }
-            break;
-        }
-
-        case ClientHandleCmd::ADD: {
-            as->defs()->client_suite_mgr().add_suites(client_handle_, suites_); // will throw if handle not found
-            break;
-        }
-
-        case ClientHandleCmd::REMOVE: {
-            as->defs()->client_suite_mgr().remove_suites(client_handle_, suites_); // will throw if handle not found
-            break;
-        }
-
-        case ClientHandleCmd::AUTO_ADD: {
-            as->defs()->client_suite_mgr().auto_add_new_suites(client_handle_,
-                                                               auto_add_new_suites_); // will throw if handle not found
-            break;
-        }
-
-        case ClientHandleCmd::SUITES: {
-            return PreAllocatedReply::client_handle_suites_cmd(as);
-        }
-
-        default:
-            assert(false);
-            break;
-    }
-    return PreAllocatedReply::ok_cmd();
-}
-
-void ClientHandleCmd::addOption(boost::program_options::options_description& desc) const {
-    switch (api_) {
-        case ClientHandleCmd::REGISTER: {
-            desc.add_options()(
-                CtsApi::ch_register_arg(),
-                po::value<vector<string>>()->multitoken(),
-                "Register interest in a set of suites.\n"
-                "If a definition has lots of suites, but the client. is only interested in a small subset,\n"
-                "Then using this command can reduce network bandwidth and synchronisation will be quicker.\n"
-                "This command will create a client handle, which must be used for any other changes.\n"
-                "The newly created handle can be shown with the --ch_suites command\n"
-                "Deleted suites will stay registered, and must be explicitly removed/dropped.\n"
-                "Note: Suites can be registered before they are loaded into the server\n"
-                "This command affects news() and sync() commands\n"
-                "   arg1 = true | false           # true means add new suites to my list, when they are created\n"
-                "   arg2 = names                  # should be a list of suite names, names not in the definition are "
-                "ignored\n"
-                "Usage:\n"
-                "   --ch_register=true s1 s2 s3   # register interest in suites s1,s2,s3 and any new suites\n"
-                "   --ch_register=false s1 s2 s3  # register interest in suites s1,s2,s3 only\n"
-                "   --ch_register=false           # register handle, suites will be added later on\n"
-                "   --ch_register=1 true s1 s2 s3 # drop handle 1 then register interest in suites s1,s2,s3 and any "
-                "new suites\n"
-                "                                 # The client handle as the first argument is typically used by "
-                "GUI/python"
-                "                                 # When the client handle is no zero, then it is dropped first\n"
-                "To list all suites and handles use --ch_suites");
-            break;
-        }
-
-        case ClientHandleCmd::DROP: {
-            desc.add_options()(CtsApi::ch_drop_arg(),
-                               po::value<int>(),
-                               "Drop/de-register the client handle.\n"
-                               "Un-used handle should be dropped otherwise they will stay, in the server.\n"
-                               "   arg1 = handle(integer)  # The handle must be an integer that is > 0\n"
-                               "Usage:\n"
-                               "   --ch_drop=10            # drop the client handle 10\n"
-                               "An error is returned if the handle had not previously been registered\n"
-                               "The handle stored on the local client is set to zero\n"
-                               "To list all suites and handles use --ch_suites");
-            break;
-        }
-
-        case ClientHandleCmd::DROP_USER: {
-            desc.add_options()(
-                CtsApi::ch_drop_user_arg(),
-                po::value<std::string>()->implicit_value(string("")),
-                "Drop/de-register all handles associated with the given user.\n"
-                "If no user provided will drop for current user. Client must ensure un-used handle are dropped\n"
-                "otherwise they will stay, in the server.\n"
-                "   arg1 = user           # The user to be drooped, if left empty drop current user \n"
-                "Usage:\n"
-                "   --ch_drop_user=ma0    # drop all handles associated with user ma0\n"
-                "   --ch_drop_user        # drop all handles associated with current user\n"
-                "An error is returned if no registered handles\n"
-                "To list all suites and handles use --ch_suites");
-            break;
-        }
-
-        case ClientHandleCmd::ADD: {
-            desc.add_options()(CtsApi::ch_add_arg(),
-                               po::value<vector<string>>()->multitoken(),
-                               "Add a set of suites, to an existing handle.\n"
-                               "   arg1 = handle(integer)  # The handle must be an integer that is > 0\n"
-                               "   arg2 = names            # should be a list of suite names, names not in the "
-                               "definition are ignored\n"
-                               "Usage:\n"
-                               "   --ch_add=10 s2 s3 s4    # add suites s2 s3,s4 to  handle 10\n"
-                               "An error is returned if the handle had not previously been registered\n"
-                               "The handle is created with --ch_register command\n"
-                               "To list all suites and handles use --ch_suites");
-            break;
-        }
-
-        case ClientHandleCmd::REMOVE: {
-            desc.add_options()(CtsApi::ch_remove_arg(),
-                               po::value<vector<string>>()->multitoken(),
-                               "Remove a set of suites, from an existing handle.\n"
-                               "   arg1 = handle(integer)   # The handle must be an integer that is > 0\n"
-                               "   arg2 = names             # should be a list of suite names, names not in the "
-                               "definition are ignored\n"
-                               "Usage:\n"
-                               "   --ch_rem=10 s2 s3 s4     # remove suites s2 s3,s4 from handle 10\n"
-                               "The handle is created with --ch_register command\n"
-                               "To list all suites and handles use --ch_suites");
-            break;
-        }
-
-        case ClientHandleCmd::AUTO_ADD: {
-            desc.add_options()(
-                CtsApi::ch_auto_add_arg(),
-                po::value<vector<string>>()->multitoken(),
-                "Change an existing handle so that new suites can be added automatically.\n"
-                "   arg1 = handle(integer)  # The handle must be an integer that is > 0\n"
-                "   arg2 = true | false     # true means add new suites to my list, when they are created\n"
-                "Usage:\n"
-                " --ch_auto_add=10 true     # modify handle 10 so that new suites, get added automatically to it\n"
-                " --ch_auto_add=10 false    # modify handle 10 so that no new suites are added\n"
-                "The handle is created with --ch_register command\n"
-                "To list all suites and handles use --ch_suites");
-            break;
-        }
-
-        case ClientHandleCmd::SUITES: {
-            desc.add_options()(CtsApi::ch_suites_arg(), "Shows all the client handles, and the suites they reference");
-            break;
-        }
-        default:
-            assert(false);
-            break;
-    }
-}
-
-void ClientHandleCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    if (ac->debug())
-        cout << "  ClientHandleCmd::create api = '" << api_ << "'.\n";
-
-    switch (api_) {
-
-        case ClientHandleCmd::REGISTER: {
-            vector<string> args = vm[theArg()].as<vector<string>>();
-            // args can be empty, otherwise first arg must be integer or bool true or false, subsequent args represent
-            // suite names
-            int client_handle        = 0;
-            bool auto_add_new_suites = false;
-            std::vector<std::string> suite_names;
-            suite_names.reserve(args.size());
-            if (!args.empty()) {
-                int suite_names_index = 1;
-                try {
-                    client_handle = ecf::convert_to<int>(args[0]);
-                    if (args.size() > 1) {
-                        if (args[1] == "true")
-                            auto_add_new_suites = true;
-                        else if (args[1] == "false")
-                            auto_add_new_suites = false;
-                        suite_names_index = 2;
-                    }
-                }
-                catch (...) {
-                    if (args[0] == "true")
-                        auto_add_new_suites = true;
-                    else if (args[0] == "false")
-                        auto_add_new_suites = false;
-                    else
-                        throw std::runtime_error(
-                            "ClientHandleCmd::create: First argument should be integer | true | false. See help");
-                }
-                for (size_t i = suite_names_index; i < args.size(); i++) {
-                    suite_names.push_back(args[i]);
-                }
-            }
-            cmd = std::make_shared<ClientHandleCmd>(client_handle, suite_names, auto_add_new_suites);
-            break;
-        }
-
-        case ClientHandleCmd::DROP: {
-            int client_handle = vm[theArg()].as<int>();
-            if (0 == client_handle)
-                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
-            cmd = std::make_shared<ClientHandleCmd>(client_handle);
-            break;
-        }
-
-        case ClientHandleCmd::DROP_USER: {
-            std::string the_user_to_drop = vm[theArg()].as<std::string>();
-            cmd                          = std::make_shared<ClientHandleCmd>(the_user_to_drop);
-            break;
-        }
-
-        case ClientHandleCmd::ADD: {
-            vector<string> args = vm[theArg()].as<vector<string>>();
-            if (args.size() < 2)
-                throw std::runtime_error(
-                    "To few arguments. First arg should be a integer handle, then a list of suite names. See help");
-            int client_handle = 0;
-            try {
-                client_handle = ecf::convert_to<int>(args[0]);
-            }
-            catch (std::exception&) {
-                throw std::runtime_error("The first argument must be an integer. See help");
-            }
-            if (0 == client_handle)
-                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
-            std::vector<std::string> suite_names;
-            suite_names.reserve(args.size());
-            for (size_t i = 1; i < args.size(); i++) {
-                suite_names.push_back(args[i]);
-            }
-            cmd = std::make_shared<ClientHandleCmd>(client_handle, suite_names, ClientHandleCmd::ADD);
-            break;
-        }
-
-        case ClientHandleCmd::REMOVE: {
-            vector<string> args = vm[theArg()].as<vector<string>>();
-            if (args.size() < 2)
-                throw std::runtime_error(
-                    "To few arguments. First arg should be a integer handle, then a list of suite names. See help");
-            int client_handle = 0;
-            try {
-                client_handle = ecf::convert_to<int>(args[0]);
-            }
-            catch (std::exception&) {
-                throw std::runtime_error("ClientHandleCmd::create: The first argument must be an integer. See help");
-            }
-            if (0 == client_handle)
-                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
-            std::vector<std::string> suite_names;
-            suite_names.reserve(args.size());
-            for (size_t i = 1; i < args.size(); i++) {
-                suite_names.push_back(args[i]);
-            }
-            cmd = std::make_shared<ClientHandleCmd>(client_handle, suite_names, ClientHandleCmd::REMOVE);
-            break;
-        }
-
-        case ClientHandleCmd::AUTO_ADD: {
-            vector<string> args = vm[theArg()].as<vector<string>>();
-            if (args.size() != 2)
-                throw std::runtime_error("Two argument expected. First arg should be a integer handle, second should "
-                                         "be true or false. See help");
-            int client_handle = 0;
-            try {
-                client_handle = ecf::convert_to<int>(args[0]);
-            }
-            catch (std::exception&) {
-                throw std::runtime_error("ClientHandleCmd::create: The first argument must be an integer. See help");
-            }
-            if (0 == client_handle)
-                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
-            bool auto_add_new_suites = false;
-            if (args[1] == "true")
-                auto_add_new_suites = true;
-            else if (args[1] == "false")
-                auto_add_new_suites = false;
-            else
-                throw std::runtime_error("ClientHandleCmd::create: First argument should be true | false. See help");
-            cmd = std::make_shared<ClientHandleCmd>(client_handle, auto_add_new_suites);
-            break;
-        }
-
-        case ClientHandleCmd::SUITES: {
-            cmd = std::make_shared<ClientHandleCmd>(ClientHandleCmd::SUITES);
-            break;
-        }
-
-        default:
-            assert(false);
-            break;
-    }
-}
-
-std::ostream& operator<<(std::ostream& os, const ClientHandleCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(ClientHandleCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(ClientHandleCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ClientHandleCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_ClientHandleCmd_HPP
-#define ecflow_base_cts_user_ClientHandleCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-class ClientHandleCmd final : public UserCmd {
-public:
-    enum Api { REGISTER, DROP, DROP_USER, ADD, REMOVE, AUTO_ADD, SUITES };
-
-    explicit ClientHandleCmd(Api api = AUTO_ADD) : api_(api) {}
-
-    ClientHandleCmd(int client_handle, const std::vector<std::string>& suites, bool add_add_new_suites)
-        : api_(REGISTER),
-          client_handle_(client_handle),
-          suites_(suites),
-          auto_add_new_suites_(add_add_new_suites) {}
-
-    explicit ClientHandleCmd(int client_handle) : api_(DROP), client_handle_(client_handle) {}
-
-    explicit ClientHandleCmd(const std::string& drop_user) : api_(DROP_USER), drop_user_(drop_user) {}
-
-    ClientHandleCmd(int client_handle, const std::vector<std::string>& suites, Api api)
-        : api_(api), // Must be ADD or REMOVE
-          client_handle_(client_handle),
-          suites_(suites) {}
-
-    ClientHandleCmd(int client_handle, bool add_add_new_suites)
-        : api_(AUTO_ADD),
-          client_handle_(client_handle),
-          auto_add_new_suites_(add_add_new_suites) {}
-
-    Api api() const { return api_; }
-    const std::string& drop_user() const { return drop_user_; }
-
-    bool cmd_updates_defs() const override;
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-    // called in the server
-    void set_group_cmd(const GroupCTSCmd* cmd) override { group_cmd_ = cmd; }
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    Api api_;
-    int client_handle_{0};
-    std::string drop_user_;
-    std::vector<std::string> suites_;
-    bool auto_add_new_suites_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(api_),
-           CEREAL_NVP(client_handle_),
-           CEREAL_NVP(drop_user_),
-           CEREAL_NVP(suites_),
-           CEREAL_NVP(auto_add_new_suites_));
-    }
-
-private:
-    const GroupCTSCmd* group_cmd_ = nullptr; // not persisted only used in server
-};
-
-std::ostream& operator<<(std::ostream& os, const ClientHandleCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(ClientHandleCmd)
-
-#endif /* ecflow_base_cts_user_ClientHandleCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CtsApi.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/CtsApi.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CtsApi.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CtsApi.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1110 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/CtsApi.hpp"
-
-#include <cassert>
-#include <sstream>
-
-#include "ecflow/core/Converter.hpp"
-
-std::string CtsApi::to_string(const std::vector<std::string>& vec) {
-    std::string ret;
-    size_t vec_size = vec.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (vec[i].empty())
-            continue;
-        ret += vec[i];
-        if (i != vec_size - 1)
-            ret += " "; // don't add space at the end
-    }
-    return ret;
-}
-
-std::string CtsApi::server_version() {
-    return std::string("--server_version");
-}
-const char* CtsApi::server_version_arg() {
-    return "server_version";
-}
-
-std::string CtsApi::get(const std::string& absNodePath) {
-    std::string ret = "--get";
-    if (!absNodePath.empty()) {
-        ret += "=";
-        ret += absNodePath;
-    }
-    return ret;
-}
-const char* CtsApi::getArg() {
-    return "get";
-}
-
-std::string CtsApi::get_state(const std::string& absNodePath) {
-    std::string ret = "--get_state";
-    if (!absNodePath.empty()) {
-        ret += "=";
-        ret += absNodePath;
-    }
-    return ret;
-}
-const char* CtsApi::get_state_arg() {
-    return "get_state";
-}
-
-std::string CtsApi::migrate(const std::string& absNodePath) {
-    std::string ret = "--migrate";
-    if (!absNodePath.empty()) {
-        ret += "=";
-        ret += absNodePath;
-    }
-    return ret;
-}
-const char* CtsApi::migrate_arg() {
-    return "migrate";
-}
-
-std::string CtsApi::stats() {
-    return "--stats";
-}
-const char* CtsApi::statsArg() {
-    return "stats";
-}
-std::string CtsApi::stats_server() {
-    return "--stats_server";
-}
-const char* CtsApi::stats_server_arg() {
-    return "stats_server";
-}
-std::string CtsApi::stats_reset() {
-    return "--stats_reset";
-}
-const char* CtsApi::stats_reset_arg() {
-    return "stats_reset";
-}
-
-std::string CtsApi::suites() {
-    return "--suites";
-}
-const char* CtsApi::suitesArg() {
-    return "suites";
-}
-
-std::vector<std::string>
-CtsApi::ch_register(int client_handle, bool auto_add_new_suites, const std::vector<std::string>& suites) {
-    std::vector<std::string> retVec;
-    retVec.reserve(suites.size() + 1);
-    std::string ret = "--ch_register=";
-    if (client_handle != 0) {
-        ret += ecf::convert_to<std::string>(client_handle);
-        retVec.push_back(ret);
-        if (auto_add_new_suites)
-            retVec.emplace_back("true");
-        else
-            retVec.emplace_back("false");
-    }
-    else {
-        if (auto_add_new_suites)
-            ret += "true";
-        else
-            ret += "false";
-        retVec.push_back(ret);
-    }
-    for (const auto& suite : suites) {
-        retVec.push_back(suite);
-    }
-    return retVec;
-}
-const char* CtsApi::ch_register_arg() {
-    return "ch_register";
-}
-
-std::string CtsApi::ch_suites() {
-    return "--ch_suites";
-}
-const char* CtsApi::ch_suites_arg() {
-    return "ch_suites";
-}
-
-std::string CtsApi::ch_drop(int client_handle) {
-    std::string ret = "--ch_drop=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    return ret;
-}
-const char* CtsApi::ch_drop_arg() {
-    return "ch_drop";
-}
-
-std::string CtsApi::ch_drop_user(const std::string& user) {
-    std::string ret = "--ch_drop_user";
-    if (!user.empty()) {
-        ret += "=";
-        ret += user;
-    }
-    return ret;
-}
-const char* CtsApi::ch_drop_user_arg() {
-    return "ch_drop_user";
-}
-
-std::vector<std::string> CtsApi::ch_add(int client_handle, const std::vector<std::string>& suites) {
-    std::vector<std::string> retVec;
-    retVec.reserve(suites.size() + 1);
-    std::string ret = "--ch_add=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    retVec.push_back(ret);
-    for (const auto& suite : suites) {
-        retVec.push_back(suite);
-    }
-    return retVec;
-}
-const char* CtsApi::ch_add_arg() {
-    return "ch_add";
-}
-
-std::vector<std::string> CtsApi::ch_remove(int client_handle, const std::vector<std::string>& suites) {
-    std::vector<std::string> retVec;
-    retVec.reserve(suites.size() + 1);
-    std::string ret = "--ch_rem=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    retVec.push_back(ret);
-    for (const auto& suite : suites) {
-        retVec.push_back(suite);
-    }
-    return retVec;
-}
-const char* CtsApi::ch_remove_arg() {
-    return "ch_rem";
-}
-
-std::vector<std::string> CtsApi::ch_auto_add(int client_handle, bool auto_add_new_suites) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-    std::string ret = "--ch_auto_add=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    retVec.push_back(ret);
-    if (auto_add_new_suites)
-        retVec.emplace_back("true");
-    else
-        retVec.emplace_back("false");
-    return retVec;
-}
-const char* CtsApi::ch_auto_add_arg() {
-    return "ch_auto_add";
-}
-
-std::vector<std::string>
-CtsApi::sync(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no) {
-    std::vector<std::string> retVec;
-    retVec.reserve(3);
-    std::string ret = "--sync=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    retVec.push_back(ret);
-    retVec.push_back(ecf::convert_to<std::string>(state_change_no));
-    retVec.push_back(ecf::convert_to<std::string>(modify_change_no));
-    return retVec;
-}
-const char* CtsApi::syncArg() {
-    return "sync";
-}
-
-std::vector<std::string>
-CtsApi::sync_clock(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no) {
-    std::vector<std::string> retVec;
-    retVec.reserve(3);
-    std::string ret = "--sync_clock=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    retVec.push_back(ret);
-    retVec.push_back(ecf::convert_to<std::string>(state_change_no));
-    retVec.push_back(ecf::convert_to<std::string>(modify_change_no));
-    return retVec;
-}
-const char* CtsApi::sync_clock_arg() {
-    return "sync_clock";
-}
-
-std::string CtsApi::sync_full(unsigned int client_handle) {
-    std::string ret = "--sync_full=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    return ret;
-}
-const char* CtsApi::sync_full_arg() {
-    return "sync_full";
-}
-
-std::vector<std::string>
-CtsApi::news(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no) {
-    std::vector<std::string> retVec;
-    retVec.reserve(3);
-    std::string ret = "--news=";
-    ret += ecf::convert_to<std::string>(client_handle);
-    retVec.push_back(ret);
-    retVec.push_back(ecf::convert_to<std::string>(state_change_no));
-    retVec.push_back(ecf::convert_to<std::string>(modify_change_no));
-    return retVec;
-}
-const char* CtsApi::newsArg() {
-    return "news";
-}
-
-std::vector<std::string> CtsApi::loadDefs(const std::string& filePath, bool force, bool check_only, bool print) {
-
-    std::string ret = "--load=";
-    ret += filePath;
-
-    std::vector<std::string> retVec;
-    retVec.reserve(3);
-    retVec.push_back(ret);
-    if (force)
-        retVec.emplace_back("force");
-    if (check_only)
-        retVec.emplace_back("check_only");
-    if (print)
-        retVec.emplace_back("print");
-    return retVec;
-}
-const char* CtsApi::loadDefsArg() {
-    return "load";
-}
-
-std::string CtsApi::restartServer() {
-    return "--restart";
-}
-const char* CtsApi::restartServerArg() {
-    return "restart";
-}
-
-std::string CtsApi::haltServer(bool auto_confirm) {
-    return (auto_confirm) ? "--halt=yes" : "--halt";
-}
-const char* CtsApi::haltServerArg() {
-    return "halt";
-}
-
-std::string CtsApi::shutdownServer(bool auto_confirm) {
-    return (auto_confirm) ? "--shutdown=yes" : "--shutdown";
-}
-const char* CtsApi::shutdownServerArg() {
-    return "shutdown";
-}
-
-std::string CtsApi::terminateServer(bool auto_confirm) {
-    return (auto_confirm) ? "--terminate=yes" : "--terminate";
-}
-const char* CtsApi::terminateServerArg() {
-    return "terminate";
-}
-
-std::string CtsApi::pingServer() {
-    return "--ping";
-}
-const char* CtsApi::pingServerArg() {
-    return "ping";
-}
-
-std::string CtsApi::server_load(const std::string& path_to_log_file) {
-    std::string ret = "--server_load";
-    if (!path_to_log_file.empty()) {
-        ret += "=";
-        ret += path_to_log_file;
-    }
-    return ret;
-}
-const char* CtsApi::server_load_arg() {
-    return "server_load";
-}
-
-std::string CtsApi::debug_server_on() {
-    return "--debug_server_on";
-}
-const char* CtsApi::debug_server_on_arg() {
-    return "debug_server_on";
-}
-std::string CtsApi::debug_server_off() {
-    return "--debug_server_off";
-}
-const char* CtsApi::debug_server_off_arg() {
-    return "debug_server_off";
-}
-
-std::string CtsApi::begin(const std::string& suiteName, bool force) {
-
-    // *both* are optional
-    std::string ret = "--begin";
-    if (suiteName.empty() && !force) {
-        return ret;
-    }
-    if (!suiteName.empty()) {
-        ret += "=";
-        ret += suiteName;
-    }
-    if (force) {
-        if (suiteName.empty()) {
-            ret += "=--force";
-        }
-        else {
-            ret += " --force"; // note the space separator
-        }
-    }
-    return ret;
-}
-const char* CtsApi::beginArg() {
-    return "begin";
-}
-
-std::string CtsApi::checkJobGenOnly(const std::string& absNodePath) {
-    std::string ret = "--checkJobGenOnly";
-    if (!absNodePath.empty()) {
-        ret += "=";
-        ret += absNodePath;
-    }
-    return ret;
-}
-const char* CtsApi::checkJobGenOnlyArg() {
-    return "checkJobGenOnly";
-}
-
-std::string CtsApi::job_gen(const std::string& absNodePath) {
-    std::string ret = "--job_gen";
-    if (!absNodePath.empty()) {
-        ret += "=";
-        ret += absNodePath;
-    }
-    return ret;
-}
-const char* CtsApi::job_genArg() {
-    return "job_gen";
-}
-
-std::vector<std::string> CtsApi::check(const std::vector<std::string>& paths) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2 + paths.size());
-    retVec.emplace_back("--check");
-    if (paths.empty())
-        retVec.emplace_back("_all_");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::check(const std::string& path) {
-    if (path.empty()) {
-        return CtsApi::check(std::vector<std::string>());
-    }
-    return CtsApi::check(std::vector<std::string>(1, path));
-}
-const char* CtsApi::check_arg() {
-    return "check";
-}
-
-std::vector<std::string> CtsApi::delete_node(const std::vector<std::string>& paths, bool force, bool auto_confirm) {
-    std::vector<std::string> retVec;
-    retVec.reserve(4 + paths.size());
-    retVec.emplace_back("--delete");
-    if (paths.empty()) {
-        retVec.emplace_back("_all_");
-    }
-    if (force) {
-        retVec.emplace_back("force");
-    }
-    if (auto_confirm) {             // By default delete prompts
-        retVec.emplace_back("yes"); // yes means we don't prompt, and have automatically confirmed the delete
-    }
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::delete_node(const std::string& absNodePath, bool force, bool auto_confirm) {
-    if (absNodePath.empty())
-        return CtsApi::delete_node(std::vector<std::string>(), force, auto_confirm);
-    return CtsApi::delete_node(std::vector<std::string>(1, absNodePath), force, auto_confirm);
-}
-const char* CtsApi::delete_node_arg() {
-    return "delete";
-}
-
-std::vector<std::string> CtsApi::suspend(const std::vector<std::string>& paths) {
-    std::vector<std::string> retVec;
-    retVec.reserve(1 + paths.size());
-    retVec.emplace_back("--suspend");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::suspend(const std::string& path) {
-    return CtsApi::suspend(std::vector<std::string>(1, path));
-}
-const char* CtsApi::suspend_arg() {
-    return "suspend";
-}
-
-std::vector<std::string> CtsApi::resume(const std::vector<std::string>& paths) {
-    std::vector<std::string> retVec;
-    retVec.reserve(1 + paths.size());
-    retVec.emplace_back("--resume");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::resume(const std::string& path) {
-    return CtsApi::resume(std::vector<std::string>(1, path));
-}
-const char* CtsApi::resume_arg() {
-    return "resume";
-}
-
-std::vector<std::string> CtsApi::kill(const std::vector<std::string>& paths) {
-    std::vector<std::string> retVec;
-    retVec.reserve(1 + paths.size());
-    retVec.emplace_back("--kill");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::kill(const std::string& path) {
-    return CtsApi::kill(std::vector<std::string>(1, path));
-}
-const char* CtsApi::kill_arg() {
-    return "kill";
-}
-
-std::vector<std::string> CtsApi::status(const std::vector<std::string>& paths) {
-    std::vector<std::string> retVec;
-    retVec.reserve(1 + paths.size());
-    retVec.emplace_back("--status");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::status(const std::string& path) {
-    return CtsApi::status(std::vector<std::string>(1, path));
-}
-const char* CtsApi::statusArg() {
-    return "status";
-}
-
-std::vector<std::string> CtsApi::edit_history(const std::vector<std::string>& paths) {
-    std::vector<std::string> retVec;
-    retVec.reserve(1 + paths.size());
-    retVec.emplace_back("--edit_history");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::edit_history(const std::string& path) {
-    return CtsApi::edit_history(std::vector<std::string>(1, path));
-}
-const char* CtsApi::edit_history_arg() {
-    return "edit_history";
-}
-
-std::vector<std::string> CtsApi::archive(const std::vector<std::string>& paths, bool force) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2 + paths.size());
-    retVec.emplace_back("--archive");
-    if (force)
-        retVec.emplace_back("force");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::archive(const std::string& path, bool force) {
-    return CtsApi::archive(std::vector<std::string>(1, path), force);
-}
-const char* CtsApi::archive_arg() {
-    return "archive";
-}
-
-std::vector<std::string> CtsApi::restore(const std::vector<std::string>& paths) {
-    std::vector<std::string> retVec;
-    retVec.reserve(1 + paths.size());
-    retVec.emplace_back("--restore");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::restore(const std::string& path) {
-    return CtsApi::restore(std::vector<std::string>(1, path));
-}
-const char* CtsApi::restore_arg() {
-    return "restore";
-}
-
-std::string CtsApi::why(const std::string& absNodePath) {
-    if (absNodePath.empty())
-        return "--why";
-    std::string ret = "--why=";
-    ret += absNodePath;
-    return ret;
-}
-const char* CtsApi::whyArg() {
-    return "why";
-}
-
-std::string CtsApi::zombieGet() {
-    return "--zombie_get";
-}
-const char* CtsApi::zombieGetArg() {
-    return "zombie_get";
-}
-
-std::vector<std::string>
-CtsApi::zombieFob(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
-    std::string ret = "--zombie_fob=";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 3);
-    if (!paths.empty())
-        ret += paths[0];
-    retVec.push_back(ret);
-    for (size_t i = 1; i < paths.size(); i++)
-        retVec.push_back(paths[i]);
-    if (!process_id.empty())
-        retVec.push_back(process_id); // Note: order is important, even if empty
-    if (!password.empty())
-        retVec.push_back(password); // Note: order is important, even if empty
-    return retVec;
-}
-std::string CtsApi::zombieFobCli(const std::string& path) {
-    std::string ret = "--zombie_fob=";
-    ret += path;
-    return ret;
-}
-std::vector<std::string> CtsApi::zombieFobCli(const std::vector<std::string>& paths) {
-    std::string ret = "--zombie_fob";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 1);
-    retVec.push_back(ret);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-const char* CtsApi::zombieFobArg() {
-    return "zombie_fob";
-}
-
-std::vector<std::string>
-CtsApi::zombieFail(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
-    std::string ret = "--zombie_fail=";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 3);
-    if (!paths.empty())
-        ret += paths[0];
-    retVec.push_back(ret);
-    for (size_t i = 1; i < paths.size(); i++)
-        retVec.push_back(paths[i]);
-    if (!process_id.empty())
-        retVec.push_back(process_id); // Note: order is important, even if empty
-    return retVec;
-}
-std::string CtsApi::zombieFailCli(const std::string& path) {
-    std::string ret = "--zombie_fail=";
-    ret += path;
-    return ret;
-}
-std::vector<std::string> CtsApi::zombieFailCli(const std::vector<std::string>& paths) {
-    std::string ret = "--zombie_fail";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 1);
-    retVec.push_back(ret);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-const char* CtsApi::zombieFailArg() {
-    return "zombie_fail";
-}
-
-std::vector<std::string>
-CtsApi::zombieAdopt(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
-    std::string ret = "--zombie_adopt=";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 3);
-    if (!paths.empty())
-        ret += paths[0];
-    retVec.push_back(ret);
-    for (size_t i = 1; i < paths.size(); i++)
-        retVec.push_back(paths[i]);
-    if (!process_id.empty())
-        retVec.push_back(process_id); // Note: order is important, even if empty
-    if (!password.empty())
-        retVec.push_back(password); // Note: order is important, even if empty
-    return retVec;
-}
-std::string CtsApi::zombieAdoptCli(const std::string& path) {
-    std::string ret = "--zombie_adopt=";
-    ret += path;
-    return ret;
-}
-std::vector<std::string> CtsApi::zombieAdoptCli(const std::vector<std::string>& paths) {
-    std::string ret = "--zombie_adopt";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 1);
-    retVec.push_back(ret);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-const char* CtsApi::zombieAdoptArg() {
-    return "zombie_adopt";
-}
-
-std::vector<std::string> CtsApi::zombieRemove(const std::vector<std::string>& paths,
-                                              const std::string& process_id,
-                                              const std::string& password) {
-    std::string ret = "--zombie_remove=";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 3);
-    if (!paths.empty())
-        ret += paths[0];
-    retVec.push_back(ret);
-    for (size_t i = 1; i < paths.size(); i++)
-        retVec.push_back(paths[i]);
-    if (!process_id.empty())
-        retVec.push_back(process_id); // Note: order is important, even if empty
-    if (!password.empty())
-        retVec.push_back(password); // Note: order is important, even if empty
-    return retVec;
-}
-std::string CtsApi::zombieRemoveCli(const std::string& path) {
-    std::string ret = "--zombie_remove=";
-    ret += path;
-    return ret;
-}
-std::vector<std::string> CtsApi::zombieRemoveCli(const std::vector<std::string>& paths) {
-    std::string ret = "--zombie_remove";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 1);
-    retVec.push_back(ret);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-const char* CtsApi::zombieRemoveArg() {
-    return "zombie_remove";
-}
-
-std::vector<std::string>
-CtsApi::zombieBlock(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
-    std::string ret = "--zombie_block=";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 3);
-    if (!paths.empty())
-        ret += paths[0];
-    retVec.push_back(ret);
-    for (size_t i = 1; i < paths.size(); i++)
-        retVec.push_back(paths[i]);
-    if (!process_id.empty())
-        retVec.push_back(process_id); // Note: order is important, even if empty
-    if (!password.empty())
-        retVec.push_back(password); // Note: order is important, even if empty
-    return retVec;
-}
-std::string CtsApi::zombieBlockCli(const std::string& path) {
-    std::string ret = "--zombie_block=";
-    ret += path;
-    return ret;
-}
-std::vector<std::string> CtsApi::zombieBlockCli(const std::vector<std::string>& paths) {
-    std::string ret = "--zombie_block";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 1);
-    retVec.push_back(ret);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-const char* CtsApi::zombieBlockArg() {
-    return "zombie_block";
-}
-
-std::vector<std::string>
-CtsApi::zombieKill(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
-    std::string ret = "--zombie_kill=";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 3);
-    if (!paths.empty())
-        ret += paths[0];
-    retVec.push_back(ret);
-    for (size_t i = 1; i < paths.size(); i++)
-        retVec.push_back(paths[i]);
-    if (!process_id.empty())
-        retVec.push_back(process_id); // Note: order is important, even if empty
-    if (!password.empty())
-        retVec.push_back(password); // Note: order is important, even if empty
-    return retVec;
-}
-std::string CtsApi::zombieKillCli(const std::string& path) {
-    std::string ret = "--zombie_kill=";
-    ret += path;
-    return ret;
-}
-std::vector<std::string> CtsApi::zombieKillCli(const std::vector<std::string>& paths) {
-    std::string ret = "--zombie_kill";
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 1);
-    retVec.push_back(ret);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-const char* CtsApi::zombieKillArg() {
-    return "zombie_kill";
-}
-
-std::vector<std::string> CtsApi::requeue(const std::vector<std::string>& paths, const std::string& option) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2 + paths.size());
-    retVec.emplace_back("--requeue");
-    if (!option.empty())
-        retVec.push_back(option);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::requeue(const std::string& absNodePath, const std::string& option) {
-    return CtsApi::requeue(std::vector<std::string>(1, absNodePath), option);
-}
-const char* CtsApi::requeueArg() {
-    return "requeue";
-}
-
-std::vector<std::string> CtsApi::run(const std::vector<std::string>& paths, bool force) {
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 2);
-    retVec.emplace_back("--run");
-    if (force)
-        retVec.emplace_back("force");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::run(const std::string& absNodePath, bool force) {
-    return CtsApi::run(std::vector<std::string>(1, absNodePath), force);
-}
-const char* CtsApi::runArg() {
-    return "run";
-}
-
-std::vector<std::string> CtsApi::order(const std::string& absNodePath, const std::string& orderType) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-    std::string ret = "--order=";
-    ret += absNodePath;
-    retVec.push_back(ret);
-    retVec.push_back(orderType);
-    return retVec;
-}
-const char* CtsApi::orderArg() {
-    return "order";
-}
-
-std::vector<std::string> CtsApi::replace(const std::string& absNodePath,
-                                         const std::string& path_to_client_defs,
-                                         bool create_parents_as_required,
-                                         bool force) {
-    std::vector<std::string> retVec;
-    retVec.reserve(3);
-
-    std::string ret = "--replace=";
-    ret += absNodePath;
-    retVec.push_back(ret);
-    retVec.push_back(path_to_client_defs);
-    if (create_parents_as_required)
-        retVec.emplace_back("parent");
-    if (force)
-        retVec.emplace_back("force");
-
-    return retVec;
-}
-const char* CtsApi::replace_arg() {
-    return "replace";
-}
-
-std::string CtsApi::checkPtDefs(ecf::CheckPt::Mode m, int check_pt_interval, int check_pt_save_time_alarm) {
-    std::string ret = "--check_pt";
-    if (m != ecf::CheckPt::UNDEFINED || check_pt_interval != 0 || check_pt_save_time_alarm != 0)
-        ret += "=";
-
-    switch (m) {
-        case ecf::CheckPt::NEVER:
-            ret += "never";
-            break;
-        case ecf::CheckPt::ON_TIME:
-            ret += "on_time";
-            break;
-        case ecf::CheckPt::ALWAYS:
-            ret += "always";
-            break;
-        case ecf::CheckPt::UNDEFINED:
-            break; // leave empty
-        default:
-            assert(false);
-            break;
-    }
-
-    if (check_pt_interval != 0) {
-        if (m != ecf::CheckPt::UNDEFINED)
-            ret += ":";
-        ret += ecf::convert_to<std::string>(check_pt_interval);
-    }
-    else {
-        if (m == ecf::CheckPt::UNDEFINED && check_pt_save_time_alarm != 0) {
-            ret += "alarm:";
-            ret += ecf::convert_to<std::string>(check_pt_save_time_alarm);
-        }
-    }
-    return ret;
-}
-const char* CtsApi::checkPtDefsArg() {
-    return "check_pt";
-}
-
-std::string CtsApi::restoreDefsFromCheckPt() {
-    return "--restore_from_checkpt";
-}
-const char* CtsApi::restoreDefsFromCheckPtArg() {
-    return "restore_from_checkpt";
-}
-
-std::string CtsApi::logMsg(const std::string& theMsgToLog) {
-    std::string ret = "--msg=";
-    ret += theMsgToLog;
-    return ret;
-}
-const char* CtsApi::logMsgArg() {
-    return "msg";
-}
-
-std::vector<std::string> CtsApi::force(const std::vector<std::string>& paths,
-                                       const std::string& state_or_event,
-                                       bool recursive,
-                                       bool set_repeats_to_last_value) {
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 3);
-
-    std::string ret = "--force=";
-    ret += state_or_event;
-    retVec.push_back(ret);
-    if (recursive)
-        retVec.emplace_back("recursive");
-    if (set_repeats_to_last_value)
-        retVec.emplace_back("full");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-
-std::vector<std::string> CtsApi::force(const std::string& path,
-                                       const std::string& state_or_event,
-                                       bool recursive,
-                                       bool set_repeats_to_last_value) {
-    return CtsApi::force(std::vector<std::string>(1, path), state_or_event, recursive, set_repeats_to_last_value);
-}
-const char* CtsApi::forceArg() {
-    return "force";
-}
-
-std::vector<std::string>
-CtsApi::freeDep(const std::vector<std::string>& paths, bool trigger, bool all, bool date, bool time) {
-
-    std::vector<std::string> retVec;
-    retVec.reserve(paths.size() + 4);
-
-    retVec.emplace_back("--free-dep");
-    if (all)
-        retVec.emplace_back("all");
-    else {
-        if (trigger)
-            retVec.emplace_back("trigger");
-        if (date)
-            retVec.emplace_back("date");
-        if (time)
-            retVec.emplace_back("time");
-    }
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::freeDep(const std::string& path, bool trigger, bool all, bool date, bool time) {
-
-    return CtsApi::freeDep(std::vector<std::string>(1, path), trigger, all, date, time);
-}
-const char* CtsApi::freeDepArg() {
-    return "free-dep";
-}
-
-std::vector<std::string>
-CtsApi::file(const std::string& absNodePath, const std::string& fileType, const std::string& max_lines) {
-    std::vector<std::string> retVec;
-    retVec.reserve(3);
-    std::string ret = "--file=";
-    ret += absNodePath;
-    retVec.push_back(ret);
-    retVec.push_back(fileType);
-    retVec.push_back(max_lines);
-    return retVec;
-}
-const char* CtsApi::fileArg() {
-    return "file";
-}
-
-std::vector<std::string> CtsApi::plug(const std::string& sourcePath, const std::string& destPath) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-
-    std::string ret = "--plug=";
-    ret += sourcePath;
-    retVec.push_back(ret);
-    retVec.push_back(destPath);
-
-    return retVec;
-}
-const char* CtsApi::plugArg() {
-    return "plug";
-}
-
-std::vector<std::string> CtsApi::alter(const std::vector<std::string>& paths,
-                                       const std::string& alterType,
-                                       const std::string& attrType,
-                                       const std::string& name,
-                                       const std::string& value) {
-    std::vector<std::string> retVec;
-    retVec.reserve(5 + paths.size());
-
-    retVec.emplace_back("--alter");
-    retVec.push_back(alterType);
-    retVec.push_back(attrType);
-    if (!name.empty())
-        retVec.push_back(name);
-    if (!value.empty())
-        retVec.push_back(value);
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-std::vector<std::string> CtsApi::alter(const std::string& path,
-                                       const std::string& alterType,
-                                       const std::string& attrType,
-                                       const std::string& name,
-                                       const std::string& value) {
-    return CtsApi::alter(std::vector<std::string>(1, path), alterType, attrType, name, value);
-}
-
-std::vector<std::string>
-CtsApi::alter_sort(const std::vector<std::string>& paths, const std::string& sortable_attribute_name, bool recursive) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2 + paths.size());
-
-    retVec.emplace_back("--alter");
-    retVec.emplace_back("sort");
-    retVec.push_back(sortable_attribute_name);
-    if (recursive)
-        retVec.emplace_back("recursive");
-    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
-    return retVec;
-}
-const char* CtsApi::alterArg() {
-    return "alter";
-}
-
-std::string CtsApi::reloadwsfile() {
-    return "--reloadwsfile";
-}
-const char* CtsApi::reloadwsfileArg() {
-    return "reloadwsfile";
-}
-
-std::string CtsApi::reloadpasswdfile() {
-    return "--reloadpasswdfile";
-}
-const char* CtsApi::reloadpasswdfile_arg() {
-    return "reloadpasswdfile";
-}
-
-std::string CtsApi::reloadcustompasswdfile() {
-    return "--reloadcustompasswdfile";
-}
-const char* CtsApi::reloadcustompasswdfile_arg() {
-    return "reloadcustompasswdfile";
-}
-
-std::string CtsApi::group(const std::string& cmds) {
-    std::string ret = "--group=";
-    ret += cmds;
-    return ret;
-}
-const char* CtsApi::groupArg() {
-    return "group";
-}
-
-std::vector<std::string> CtsApi::getLog(int lastLine) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-    retVec.emplace_back("--log=get");
-    if (lastLine != 0) {
-        std::stringstream ss;
-        ss << lastLine;
-        retVec.push_back(ss.str());
-    }
-    return retVec;
-}
-std::vector<std::string> CtsApi::new_log(const std::string& new_path) {
-    std::vector<std::string> retVec;
-    retVec.reserve(2);
-    retVec.emplace_back("--log=new");
-    if (!new_path.empty())
-        retVec.push_back(new_path);
-    return retVec;
-}
-std::string CtsApi::clearLog() {
-    return "--log=clear";
-}
-std::string CtsApi::flushLog() {
-    return "--log=flush";
-}
-std::string CtsApi::get_log_path() {
-    return "--log=path";
-}
-
-std::string CtsApi::forceDependencyEval() {
-    return "--force-dep-eval";
-}
-const char* CtsApi::forceDependencyEvalArg() {
-    return "force-dep-eval";
-}
-
-std::vector<std::string> CtsApi::edit_script(const std::string& path_to_task,
-                                             const std::string& edit_type,
-                                             const std::string& path_to_script,
-                                             bool create_alias,
-                                             bool run) {
-    std::vector<std::string> retVec;
-    std::string ret = "--edit_script=";
-    ret += path_to_task;
-    retVec.push_back(ret);
-    retVec.push_back(edit_type);
-    if (!path_to_script.empty())
-        retVec.push_back(path_to_script);
-    if (create_alias)
-        retVec.emplace_back("create_alias");
-    if (!run)
-        retVec.emplace_back("no_run");
-    return retVec;
-}
-const char* CtsApi::edit_script_arg() {
-    return "edit_script";
-}
-
-std::vector<std::string>
-CtsApi::query(const std::string& query_type, const std::string& path_to_attribute, const std::string& attribute) {
-    std::vector<std::string> retVec;
-    retVec.reserve(3);
-    std::string ret = "--query=";
-    ret += query_type;
-    retVec.push_back(ret);
-    if (query_type == "event" || query_type == "meter" || query_type == "variable") {
-        retVec.push_back(path_to_attribute + ":" + attribute);
-    }
-    else if (query_type == "trigger") {
-        retVec.push_back(path_to_attribute);
-        retVec.push_back(attribute);
-    }
-    else if (query_type == "repeat") {
-        retVec.push_back(path_to_attribute);
-        if (!attribute.empty())
-            retVec.push_back(attribute);
-    }
-    else if (query_type == "state" || query_type == "dstate") {
-        retVec.push_back(path_to_attribute);
-    }
-    return retVec;
-}
-const char* CtsApi::queryArg() {
-    return "query";
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CtsApi.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/CtsApi.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CtsApi.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CtsApi.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,286 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_CtsApi_HPP
-#define ecflow_base_cts_user_CtsApi_HPP
-
-///
-/// \brief (C)lient (t)o (s)erver API
-///
-
-#include <string>
-#include <vector>
-
-#include "ecflow/core/CheckPt.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-// The two variant api must correspond i.e '--get' and 'get' since this is used by boost program options
-// *************************************************************************************
-// Note:: if the api requires multiple parameters it must return a std::vector<std::string>
-// ***************************************************************************************
-class CtsApi {
-public:
-    CtsApi(const CtsApi&)                  = delete;
-    const CtsApi& operator=(const CtsApi&) = delete;
-
-    static std::string to_string(const std::vector<std::string>&);
-
-    static std::string server_version();
-
-    // For python
-    static defs_ptr load(defs_ptr defs) { return defs; }
-    static std::vector<std::string> loadDefs(const std::string& filePath,
-                                             bool force,
-                                             bool check_only,
-                                             bool print); // check_only & print are client side only
-    static std::string get(const std::string& absNodePath = "");
-    static std::string get_state(const std::string& absNodePath = "");
-    static std::string migrate(const std::string& absNodePath = "");
-    static std::vector<std::string>
-    sync(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no);
-    static std::vector<std::string>
-    sync_clock(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no);
-    static std::string sync_full(unsigned int client_handle);
-    static std::vector<std::string>
-    news(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no);
-
-    static std::vector<std::string>
-    ch_register(int client_handle, bool auto_add_new_suites, const std::vector<std::string>& suites);
-    static std::string ch_suites();
-    static std::string ch_drop(int client_handle);
-    static std::string ch_drop_user(const std::string& user);
-    static std::vector<std::string> ch_add(int client_handle, const std::vector<std::string>& suites);
-    static std::vector<std::string> ch_remove(int client_handle, const std::vector<std::string>& suites);
-    static std::vector<std::string> ch_auto_add(int client_handle, bool auto_add_new_suites);
-    static std::string suites(); // returns list if all suites, and client handles.
-
-    static std::string restartServer();
-    static std::string haltServer(bool auto_confirm = true);
-    static std::string shutdownServer(bool auto_confirm = true);
-    static std::string terminateServer(bool auto_confirm = true);
-    static std::string pingServer();
-    static std::string server_load(const std::string& path_to_log_file);
-    static std::string debug_server_on();
-    static std::string debug_server_off();
-
-    // odd one out, take multi-args but expects string
-    static std::string begin(const std::string& suiteName = "", bool force = false); // no suite begins all suites
-
-    static std::string job_gen(const std::string& absNodePath = "");
-    static std::string checkJobGenOnly(const std::string& absNodePath = "");
-
-    static std::vector<std::string> check(const std::string& absNodePath = "");
-    static std::vector<std::string> check(const std::vector<std::string>& paths);
-    static std::vector<std::string>
-    delete_node(const std::vector<std::string>& paths,
-                bool force        = false,
-                bool auto_confirm = true); // no paths specified ,delete all suites, for test
-    static std::vector<std::string>
-    delete_node(const std::string& absNodePath = "",
-                bool force                     = false,
-                bool auto_confirm              = true); // no node specified ,delete all suites, for test
-    static std::vector<std::string> suspend(const std::string& absNodePath);
-    static std::vector<std::string> suspend(const std::vector<std::string>& paths);
-    static std::vector<std::string> resume(const std::string& absNodePath);
-    static std::vector<std::string> resume(const std::vector<std::string>& paths);
-    static std::vector<std::string> kill(const std::string& absNodePath);
-    static std::vector<std::string> kill(const std::vector<std::string>& paths);
-    static std::vector<std::string> status(const std::string& absNodePath);
-    static std::vector<std::string> status(const std::vector<std::string>& paths);
-    static std::vector<std::string> edit_history(const std::vector<std::string>& paths);
-    static std::vector<std::string> edit_history(const std::string& absNodePath);
-    static std::vector<std::string> archive(const std::vector<std::string>& paths, bool force = false);
-    static std::vector<std::string> archive(const std::string& absNodePath, bool force = false);
-    static std::vector<std::string> restore(const std::vector<std::string>& paths);
-    static std::vector<std::string> restore(const std::string& absNodePath);
-
-    static std::string why(const std::string& absNodePath);
-    static std::string zombieGet();
-    static std::vector<std::string>
-    zombieFob(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
-    static std::vector<std::string>
-    zombieFail(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
-    static std::vector<std::string>
-    zombieAdopt(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
-    static std::vector<std::string>
-    zombieRemove(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
-    static std::vector<std::string>
-    zombieBlock(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
-    static std::vector<std::string>
-    zombieKill(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
-    static std::string zombieFobCli(const std::string& task_path);
-    static std::string zombieFailCli(const std::string& task_path);
-    static std::string zombieAdoptCli(const std::string& task_path);
-    static std::string zombieRemoveCli(const std::string& task_path);
-    static std::string zombieBlockCli(const std::string& task_path);
-    static std::string zombieKillCli(const std::string& task_path);
-    static std::vector<std::string> zombieFobCli(const std::vector<std::string>& paths);
-    static std::vector<std::string> zombieFailCli(const std::vector<std::string>& paths);
-    static std::vector<std::string> zombieAdoptCli(const std::vector<std::string>& paths);
-    static std::vector<std::string> zombieRemoveCli(const std::vector<std::string>& paths);
-    static std::vector<std::string> zombieBlockCli(const std::vector<std::string>& paths);
-    static std::vector<std::string> zombieKillCli(const std::vector<std::string>& paths);
-
-    static std::vector<std::string> replace(const std::string& absNodePath,
-                                            const std::string& path_to_client_defs,
-                                            bool create_parents_as_required = true,
-                                            bool force                      = false);
-    static std::vector<std::string> requeue(const std::vector<std::string>& paths,
-                                            const std::string& option /* [ "" | "force" | "abort" ] */);
-    static std::vector<std::string> requeue(const std::string& absNodePath,
-                                            const std::string& option /* [ "" | "force" | "abort" ] */);
-    static std::vector<std::string> run(const std::vector<std::string>& paths, bool force = false);
-    static std::vector<std::string> run(const std::string& absNodePath, bool force = false);
-    static std::vector<std::string> order(const std::string& absNodePath, const std::string& orderType);
-
-    static std::string checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
-                                   int check_pt_interval        = 0,
-                                   int check_pt_save_time_alarm = 0);
-    static std::string restoreDefsFromCheckPt();
-
-    static std::vector<std::string> force(const std::vector<std::string>& paths,
-                                          const std::string& state_or_event,
-                                          bool recursive                 = false,
-                                          bool set_repeats_to_last_value = false);
-    static std::vector<std::string> force(const std::string& path,
-                                          const std::string& state_or_event,
-                                          bool recursive                 = false,
-                                          bool set_repeats_to_last_value = false);
-
-    static std::vector<std::string> freeDep(const std::vector<std::string>& paths,
-                                            bool trigger = true,
-                                            bool all     = false,
-                                            bool date    = false,
-                                            bool time    = false);
-    static std::vector<std::string> freeDep(const std::string& absNodePath,
-                                            bool trigger = true,
-                                            bool all     = false,
-                                            bool date    = false,
-                                            bool time    = false);
-
-    static std::vector<std::string>
-    file(const std::string& absNodePath, const std::string& fileType, const std::string& max_lines);
-    static std::vector<std::string> plug(const std::string& sourcePath, const std::string& destPath);
-
-    static std::vector<std::string>
-    alter(const std::string& path,
-          const std::string& alterType, /* one of [ 'add' | 'change' | 'delete' | 'set_flag' | 'clear_flag' ] */
-          const std::string& attrType,
-          const std::string& name  = "",
-          const std::string& value = "");
-    static std::vector<std::string>
-    alter(const std::vector<std::string>& paths,
-          const std::string& alterType, /* one of [ 'add' | 'change' | 'delete' | 'set_flag' | 'clear_flag' ] */
-          const std::string& attrType,
-          const std::string& name  = "",
-          const std::string& value = "");
-    static std::vector<std::string>
-    alter_sort(const std::vector<std::string>& paths, const std::string& sortable_attribute_name, bool recursive);
-
-    static std::string reloadwsfile();
-    static std::string reloadpasswdfile();
-    static std::string reloadcustompasswdfile();
-
-    // "expect string of the form "shutdown; get" must be ';' separated
-    static std::string group(const std::string& cmds);
-
-    static std::string logMsg(const std::string& theMsgToLog);
-    static std::vector<std::string> getLog(int lastLines = 0);
-    static std::vector<std::string> new_log(const std::string& new_path);
-    static std::string get_log_path();
-    static std::string clearLog();
-    static std::string flushLog();
-    static std::string forceDependencyEval();
-
-    static std::string stats();
-    static std::string stats_server(); // used in test, as serialisation subject to change
-    static std::string stats_reset();
-
-    static std::vector<std::string> edit_script(const std::string& path_to_task,
-                                                const std::string& edit_type,
-                                                const std::string& path_to_script = "",
-                                                bool create_alias                 = false,
-                                                bool run                          = true);
-    static std::vector<std::string>
-    query(const std::string& query_type, const std::string& path_to_attribute, const std::string& attribute);
-
-    // Only to be used in Cmd
-    static const char* server_version_arg();
-    static const char* statsArg();
-    static const char* stats_server_arg();
-    static const char* stats_reset_arg();
-    static const char* suitesArg();
-    static const char* ch_register_arg();
-    static const char* ch_drop_arg();
-    static const char* ch_suites_arg();
-    static const char* ch_drop_user_arg();
-    static const char* ch_add_arg();
-    static const char* ch_remove_arg();
-    static const char* ch_auto_add_arg();
-
-    static const char* terminateServerArg();
-    static const char* restartServerArg();
-    static const char* haltServerArg();
-    static const char* shutdownServerArg();
-    static const char* pingServerArg();
-    static const char* server_load_arg();
-    static const char* debug_server_on_arg();
-    static const char* debug_server_off_arg();
-
-    static const char* getArg();
-    static const char* get_state_arg();
-    static const char* migrate_arg();
-    static const char* syncArg();
-    static const char* sync_clock_arg();
-    static const char* sync_full_arg();
-    static const char* newsArg();
-    static const char* loadDefsArg();
-    static const char* beginArg();
-    static const char* job_genArg();
-    static const char* check_arg();
-    static const char* checkJobGenOnlyArg();
-    static const char* delete_node_arg();
-    static const char* suspend_arg();
-    static const char* resume_arg();
-    static const char* kill_arg();
-    static const char* statusArg();
-    static const char* edit_history_arg();
-    static const char* archive_arg();
-    static const char* restore_arg();
-    static const char* whyArg();
-    static const char* zombieGetArg();
-    static const char* zombieFobArg();
-    static const char* zombieFailArg();
-    static const char* zombieAdoptArg();
-    static const char* zombieRemoveArg();
-    static const char* zombieBlockArg();
-    static const char* zombieKillArg();
-    static const char* replace_arg();
-    static const char* requeueArg();
-    static const char* runArg();
-    static const char* orderArg();
-    static const char* checkPtDefsArg();
-    static const char* restoreDefsFromCheckPtArg();
-    static const char* logMsgArg();
-    static const char* forceArg();
-    static const char* freeDepArg();
-    static const char* fileArg();
-    static const char* plugArg();
-    static const char* reloadwsfileArg();
-    static const char* reloadpasswdfile_arg();
-    static const char* reloadcustompasswdfile_arg();
-    static const char* groupArg();
-    static const char* forceDependencyEvalArg();
-    static const char* alterArg();
-    static const char* edit_script_arg();
-    static const char* queryArg();
-};
-
-#endif /* ecflow_base_cts_user_CtsApi_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CtsCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/CtsCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CtsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CtsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,790 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/Gnuplot.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-// *IMPORTANT*: STATS_RESET was introduced in release 4.0.5
-
-void CtsCmd::print(std::string& os) const {
-    switch (api_) {
-        case CtsCmd::GET_ZOMBIES:
-            user_cmd(os, CtsApi::zombieGet());
-            break;
-        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
-            user_cmd(os, CtsApi::restoreDefsFromCheckPt());
-            break;
-        case CtsCmd::RESTART_SERVER:
-            user_cmd(os, CtsApi::restartServer());
-            break;
-        case CtsCmd::SHUTDOWN_SERVER:
-            user_cmd(os, CtsApi::shutdownServer());
-            break;
-        case CtsCmd::HALT_SERVER:
-            user_cmd(os, CtsApi::haltServer());
-            break;
-        case CtsCmd::TERMINATE_SERVER:
-            user_cmd(os, CtsApi::terminateServer());
-            break;
-        case CtsCmd::RELOAD_WHITE_LIST_FILE:
-            user_cmd(os, CtsApi::reloadwsfile());
-            break;
-        case CtsCmd::RELOAD_PASSWD_FILE:
-            user_cmd(os, CtsApi::reloadpasswdfile());
-            break;
-        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
-            user_cmd(os, CtsApi::reloadcustompasswdfile());
-            break;
-        case CtsCmd::FORCE_DEP_EVAL:
-            user_cmd(os, CtsApi::forceDependencyEval());
-            break;
-        case CtsCmd::PING:
-            user_cmd(os, CtsApi::pingServer());
-            break;
-        case CtsCmd::STATS:
-            user_cmd(os, CtsApi::stats());
-            break;
-        case CtsCmd::STATS_SERVER:
-            user_cmd(os, CtsApi::stats_server());
-            break;
-        case CtsCmd::STATS_RESET:
-            user_cmd(os, CtsApi::stats_reset());
-            break;
-        case CtsCmd::SUITES:
-            user_cmd(os, CtsApi::suites());
-            break;
-        case CtsCmd::DEBUG_SERVER_ON:
-            user_cmd(os, CtsApi::debug_server_on());
-            break;
-        case CtsCmd::DEBUG_SERVER_OFF:
-            user_cmd(os, CtsApi::debug_server_off());
-            break;
-        case CtsCmd::SERVER_LOAD:
-            user_cmd(os, CtsApi::server_load(""));
-            break;
-        case CtsCmd::NO_CMD:
-            assert(false);
-            os += "CtsCmdCtsCmd::NO_CMD  !!!!";
-            break;
-        default:
-            assert(false);
-            os += "CtsCmd did not match api_ !!!!";
-            break;
-    }
-}
-
-void CtsCmd::print_only(std::string& os) const {
-    switch (api_) {
-        case CtsCmd::GET_ZOMBIES:
-            os += CtsApi::zombieGet();
-            break;
-        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
-            os += CtsApi::restoreDefsFromCheckPt();
-            break;
-        case CtsCmd::RESTART_SERVER:
-            os += CtsApi::restartServer();
-            break;
-        case CtsCmd::SHUTDOWN_SERVER:
-            os += CtsApi::shutdownServer();
-            break;
-        case CtsCmd::HALT_SERVER:
-            os += CtsApi::haltServer();
-            break;
-        case CtsCmd::TERMINATE_SERVER:
-            os += CtsApi::terminateServer();
-            break;
-        case CtsCmd::RELOAD_WHITE_LIST_FILE:
-            os += CtsApi::reloadwsfile();
-            break;
-        case CtsCmd::RELOAD_PASSWD_FILE:
-            os += CtsApi::reloadpasswdfile();
-            break;
-        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
-            os += CtsApi::reloadcustompasswdfile();
-            break;
-        case CtsCmd::FORCE_DEP_EVAL:
-            os += CtsApi::forceDependencyEval();
-            break;
-        case CtsCmd::PING:
-            os += CtsApi::pingServer();
-            break;
-        case CtsCmd::STATS:
-            os += CtsApi::stats();
-            break;
-        case CtsCmd::STATS_SERVER:
-            os += CtsApi::stats_server();
-            break;
-        case CtsCmd::STATS_RESET:
-            os += CtsApi::stats_reset();
-            break;
-        case CtsCmd::SUITES:
-            os += CtsApi::suites();
-            break;
-        case CtsCmd::DEBUG_SERVER_ON:
-            os += CtsApi::debug_server_on();
-            break;
-        case CtsCmd::DEBUG_SERVER_OFF:
-            os += CtsApi::debug_server_off();
-            break;
-        case CtsCmd::SERVER_LOAD:
-            os += CtsApi::server_load("");
-            break;
-        case CtsCmd::NO_CMD:
-            assert(false);
-            os += "CtsCmdCtsCmd::NO_CMD  !!!!";
-            break;
-        default:
-            assert(false);
-            os += "CtsCmd did not match api_ !!!!";
-            break;
-    }
-}
-
-bool CtsCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<CtsCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (api_ != the_rhs->api())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-bool CtsCmd::isWrite() const {
-    switch (api_) {
-        case CtsCmd::GET_ZOMBIES:
-            return false;
-            break; // read only
-        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::RESTART_SERVER:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::SHUTDOWN_SERVER:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::HALT_SERVER:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::TERMINATE_SERVER:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::RELOAD_WHITE_LIST_FILE:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::RELOAD_PASSWD_FILE:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::FORCE_DEP_EVAL:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::PING:
-            return false;
-            break; // read only
-        case CtsCmd::STATS:
-            return false;
-            break; // read only
-        case CtsCmd::STATS_SERVER:
-            return false;
-            break; // read only
-        case CtsCmd::STATS_RESET:
-            return true;
-            break; // requires write privilege
-        case CtsCmd::SUITES:
-            return false;
-            break; // read only
-        case CtsCmd::DEBUG_SERVER_ON:
-            return false;
-            break; // read only
-        case CtsCmd::DEBUG_SERVER_OFF:
-            return false;
-            break; // read only
-        case CtsCmd::SERVER_LOAD:
-            return false;
-            break; // read only
-        case CtsCmd::NO_CMD:
-            assert(false);
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    assert(false);
-    return false;
-}
-
-bool CtsCmd::cmd_updates_defs() const {
-    switch (api_) {
-        case CtsCmd::GET_ZOMBIES:
-            return false;
-            break;
-        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
-            return true;
-            break;
-        case CtsCmd::RESTART_SERVER:
-            return true;
-            break;
-        case CtsCmd::SHUTDOWN_SERVER:
-            return true;
-            break;
-        case CtsCmd::HALT_SERVER:
-            return true;
-            break;
-        case CtsCmd::TERMINATE_SERVER:
-            return true;
-            break;
-        case CtsCmd::RELOAD_WHITE_LIST_FILE:
-            return false;
-            break;
-        case CtsCmd::RELOAD_PASSWD_FILE:
-            return false;
-            break;
-        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
-            return false;
-            break;
-        case CtsCmd::FORCE_DEP_EVAL:
-            return true;
-            break;
-        case CtsCmd::PING:
-            return false;
-            break;
-        case CtsCmd::STATS:
-            return false;
-            break;
-        case CtsCmd::STATS_SERVER:
-            return false;
-            break;
-        case CtsCmd::STATS_RESET:
-            return false;
-            break;
-        case CtsCmd::SUITES:
-            return false;
-            break;
-        case CtsCmd::DEBUG_SERVER_ON:
-            return false;
-            break;
-        case CtsCmd::DEBUG_SERVER_OFF:
-            return false;
-            break;
-        case CtsCmd::SERVER_LOAD:
-            return false;
-            break;
-        case CtsCmd::NO_CMD:
-            assert(false);
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    assert(false);
-    return false;
-}
-
-int CtsCmd::timeout() const {
-    if (api_ == CtsCmd::PING)
-        return 10;
-    return ClientToServerCmd::timeout();
-}
-
-const char* CtsCmd::theArg() const {
-    switch (api_) {
-        case CtsCmd::GET_ZOMBIES:
-            return CtsApi::zombieGetArg();
-            break;
-        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
-            return CtsApi::restoreDefsFromCheckPtArg();
-            break;
-        case CtsCmd::RESTART_SERVER:
-            return CtsApi::restartServerArg();
-            break;
-        case CtsCmd::SHUTDOWN_SERVER:
-            return CtsApi::shutdownServerArg();
-            break;
-        case CtsCmd::HALT_SERVER:
-            return CtsApi::haltServerArg();
-            break;
-        case CtsCmd::TERMINATE_SERVER:
-            return CtsApi::terminateServerArg();
-            break;
-        case CtsCmd::RELOAD_WHITE_LIST_FILE:
-            return CtsApi::reloadwsfileArg();
-            break;
-        case CtsCmd::RELOAD_PASSWD_FILE:
-            return CtsApi::reloadpasswdfile_arg();
-            break;
-        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
-            return CtsApi::reloadcustompasswdfile_arg();
-            break;
-        case CtsCmd::FORCE_DEP_EVAL:
-            return CtsApi::forceDependencyEvalArg();
-            break;
-        case CtsCmd::PING:
-            return CtsApi::pingServerArg();
-            break;
-        case CtsCmd::STATS:
-            return CtsApi::statsArg();
-            break;
-        case CtsCmd::STATS_SERVER:
-            return CtsApi::stats_server_arg();
-            break;
-        case CtsCmd::STATS_RESET:
-            return CtsApi::stats_reset_arg();
-            break;
-        case CtsCmd::SUITES:
-            return CtsApi::suitesArg();
-            break;
-        case CtsCmd::DEBUG_SERVER_ON:
-            return CtsApi::debug_server_on_arg();
-            break;
-        case CtsCmd::DEBUG_SERVER_OFF:
-            return CtsApi::debug_server_off_arg();
-            break;
-        case CtsCmd::SERVER_LOAD:
-            return CtsApi::server_load_arg();
-            break;
-        case CtsCmd::NO_CMD:
-            assert(false);
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    assert(false);
-    return nullptr;
-}
-
-STC_Cmd_ptr CtsCmd::doHandleRequest(AbstractServer* as) const {
-    switch (api_) {
-        case CtsCmd::GET_ZOMBIES: {
-            as->update_stats().zombie_get_++;
-            return PreAllocatedReply::zombie_get_cmd(as);
-        }
-
-        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT: {
-            as->update_stats().restore_defs_from_checkpt_++;
-            as->restore_defs_from_checkpt(); // this can throw, i.e. if server not halted, or defs has suites, etc
-            break;
-        }
-
-        case CtsCmd::RESTART_SERVER: {
-            as->update_stats().restart_server_++;
-            as->restart();
-            return doJobSubmission(as);
-        }
-        case CtsCmd::SHUTDOWN_SERVER:
-            as->update_stats().shutdown_server_++;
-            as->shutdown();
-            break;
-        case CtsCmd::HALT_SERVER:
-            as->update_stats().halt_server_++;
-            as->halted();
-            break;
-        case CtsCmd::TERMINATE_SERVER:
-            as->checkPtDefs();
-            break;
-        case CtsCmd::RELOAD_WHITE_LIST_FILE: {
-            as->update_stats().reload_white_list_file_++;
-            std::string errorMsg;
-            if (!as->reloadWhiteListFile(errorMsg)) {
-                throw std::runtime_error(errorMsg);
-            }
-            break;
-        }
-        case CtsCmd::RELOAD_PASSWD_FILE: {
-            as->update_stats().reload_passwd_file_++;
-            std::string errorMsg;
-            if (!as->reloadPasswdFile(errorMsg)) {
-                throw std::runtime_error(errorMsg);
-            }
-            break;
-        }
-        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE: {
-            as->update_stats().reload_passwd_file_++;
-            std::string errorMsg;
-            if (!as->reloadCustomPasswdFile(errorMsg)) {
-                throw std::runtime_error(errorMsg);
-            }
-            break;
-        }
-        case CtsCmd::FORCE_DEP_EVAL: {
-            // The Default JobsParam does *not* allow Job creation, & hence => does not submit jobs
-            // The default does *not* allow job spawning
-            Jobs jobs(as->defs());
-            JobsParam jobsParam; // create jobs =  false, spawn_jobs = false
-            if (!jobs.generate(jobsParam))
-                throw std::runtime_error(jobsParam.getErrorMsg());
-            break;
-        }
-        case CtsCmd::PING:
-            as->update_stats().ping_++;
-            break;
-        case CtsCmd::STATS: {
-            as->update_stats().stats_++;
-            std::stringstream ss;
-            as->stats().update_for_serialisation();
-            as->stats().no_of_suites_ = as->defs()->suiteVec().size();
-            as->stats().show(ss); // ECFLOW-880, allow stats to be changed in server, by only returning string
-            return PreAllocatedReply::string_cmd(ss.str());
-            break;
-        }
-        case CtsCmd::STATS_SERVER: {
-            as->update_stats().stats_++;
-            return PreAllocatedReply::stats_cmd(as);
-            break; // Only to be used in test, as subject to change, returns Stats struct
-        }
-        case CtsCmd::STATS_RESET:
-            as->update_stats().reset();
-            break; // we could have done as->update_stats().stats_++, to honor reset, we dont
-        case CtsCmd::SUITES:
-            as->update_stats().suites_++;
-            return PreAllocatedReply::suites_cmd(as);
-            break;
-        case CtsCmd::DEBUG_SERVER_ON:
-            as->update_stats().debug_server_on_++;
-            as->debug_server_on();
-            break;
-        case CtsCmd::DEBUG_SERVER_OFF:
-            as->update_stats().debug_server_off_++;
-            as->debug_server_off();
-            break;
-        case CtsCmd::SERVER_LOAD: {
-            as->update_stats().server_load_cmd_++;
-            return PreAllocatedReply::server_load_cmd(Log::instance()->path());
-        }
-        case CtsCmd::NO_CMD:
-            assert(false);
-            break;
-        default:
-            assert(false);
-            break;
-    }
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-static const char* server_load_desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Generates gnuplot files that show the server load graphically.\n"
-           "This is done by parsing the log file. If no log file is provided,\n"
-           "then the log file path is obtained from the server. If the returned\n"
-           "log file path is not accessible an error is returned\n"
-           "This command produces a three files in the CWD.\n"
-           "    o <host>.<port>.gnuplot.dat\n"
-           "    o <host>.<port>.gnuplot.script\n"
-           "    o <host>.<port>.png\n\n"
-           "The generated script can be manually changed, to see different rendering\n"
-           "effects. i.e. just run 'gnuplot <host>.<port>.gnuplot.script'\n\n"
-           "  arg1 = <optional> path to log file\n\n"
-           "If the path to log file is known, it is *preferable* to use this,\n"
-           "rather than requesting the log path from the server.\n\n"
-           "Usage:\n"
-           "   --server_load=/path/to_log_file  # Parses log and generate gnuplot files\n"
-           "   --server_load                    # Log file path is requested from server\n"
-           "                                    # which is then used to generate gnuplot files\n"
-           "                                    # *AVOID* if log file path is accessible\n\n"
-           "Now use any png viewer to see the output i.e\n\n"
-           "> display   <host>.<port>.png\n"
-           "> feh       <host>.<port>.png\n"
-           "> eog       <host>.<port>.png\n"
-           "> xdg-open  <host>.<port>.png\n"
-           "> w3m       <host>.<port>.png\n";
-}
-
-void CtsCmd::addOption(boost::program_options::options_description& desc) const {
-    switch (api_) {
-        case CtsCmd::GET_ZOMBIES: {
-            desc.add_options()(CtsApi::zombieGetArg(),
-                               "Returns the list of zombies from the server.\n"
-                               "Results reported to standard output.");
-            break;
-        }
-        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT: {
-            desc.add_options()(CtsApi::restoreDefsFromCheckPtArg(),
-                               "Ask the server to load the definition from an check pt file.\n"
-                               "The server must be halted and the definition in the server must be deleted\n"
-                               "first, otherwise an error is returned");
-            break;
-        }
-        case CtsCmd::RESTART_SERVER: {
-            desc.add_options()(CtsApi::restartServerArg(),
-                               "Start job scheduling, communication with jobs, and respond to all requests.\n"
-                               "The following table shows server behaviour in the different states.\n"
-                               "|----------------------------------------------------------------------------------|\n"
-                               "| Server State | User Request | Task Request |Job Scheduling | Auto-Check-pointing |\n"
-                               "|--------------|--------------|--------------|---------------|---------------------|\n"
-                               "|     RUNNING  |    yes       |      yes     |      yes      |      yes            |\n"
-                               "|    SHUTDOWN  |    yes       |      yes     |      no       |      yes            |\n"
-                               "|      HALTED  |    yes       |      no      |      no       |      no             |\n"
-                               "|--------------|--------------|--------------|---------------|---------------------|");
-            break;
-        }
-        case CtsCmd::SHUTDOWN_SERVER: {
-            desc.add_options()(CtsApi::shutdownServerArg(),
-                               po::value<string>()->implicit_value(string("")),
-                               "Stop server from scheduling new jobs.\n"
-                               "  arg1 = yes(optional) # use to bypass confirmation prompt,i.e\n"
-                               "  --shutdown=yes\n"
-                               "The following table shows server behaviour in the different states.\n"
-                               "|----------------------------------------------------------------------------------|\n"
-                               "| Server State | User Request | Task Request |Job Scheduling | Auto-Check-pointing |\n"
-                               "|--------------|--------------|--------------|---------------|---------------------|\n"
-                               "|     RUNNING  |    yes       |      yes     |      yes      |      yes            |\n"
-                               "|    SHUTDOWN  |    yes       |      yes     |      no       |      yes            |\n"
-                               "|      HALTED  |    yes       |      no      |      no       |      no             |\n"
-                               "|--------------|--------------|--------------|---------------|---------------------|");
-            break;
-        }
-        case CtsCmd::HALT_SERVER: {
-            desc.add_options()(CtsApi::haltServerArg(),
-                               po::value<string>()->implicit_value(string("")),
-                               "Stop server communication with jobs, and new job scheduling.\n"
-                               "Also stops automatic check pointing\n"
-                               "  arg1 = yes(optional) # use to bypass confirmation prompt,i.e.\n"
-                               "  --halt=yes\n"
-                               "The following table shows server behaviour in the different states.\n"
-                               "|----------------------------------------------------------------------------------|\n"
-                               "| Server State | User Request | Task Request |Job Scheduling | Auto-Check-pointing |\n"
-                               "|--------------|--------------|--------------|---------------|---------------------|\n"
-                               "|     RUNNING  |    yes       |      yes     |      yes      |      yes            |\n"
-                               "|    SHUTDOWN  |    yes       |      yes     |      no       |      yes            |\n"
-                               "|      HALTED  |    yes       |      no      |      no       |      no             |\n"
-                               "|--------------|--------------|--------------|---------------|---------------------|");
-            break;
-        }
-        case CtsCmd::TERMINATE_SERVER: {
-            desc.add_options()(CtsApi::terminateServerArg(),
-                               po::value<string>()->implicit_value(string("")),
-                               "Terminate the server.\n"
-                               "  arg1 = yes(optional) # use to bypass confirmation prompt.i.e\n"
-                               "  --terminate=yes");
-            break;
-        }
-        case CtsCmd::RELOAD_WHITE_LIST_FILE: {
-            desc.add_options()(CtsApi::reloadwsfileArg(),
-                               "Reload the white list file.\n"
-                               "The white list file is used to authenticate 'user' commands.\n"
-                               "File path is specified by ECF_LISTS environment, read by the server on *startup*.\n"
-                               "Hence the contents of the file can be changed but not the location\n"
-                               "If ECF_LISTS is not specified, or is specified and is 'ecf.lists' then by default\n"
-                               "it will open <host>.<port>.ecf.lists.If a path like /var/tmp/ecf.lists was specified\n"
-                               "for ECF_LISTS, then this is the path used for reloading the white list file\n"
-                               "On startup, if the file is not present or is present but is empty (i.e just contains "
-                               "the version number)\n"
-                               "then all users have read/write access\n"
-                               "However on reload it will raises an error if file does not exist, or fails to parse\n"
-                               "Expected format for this file is:\n\n"
-                               "# comment\n"
-                               "4.4.14  # version number, this must be present, even if no users specified\n\n"
-                               "# Users with read/write access\n"
-                               "user1   # comment\n"
-                               "user2   # comment\n\n"
-                               "*       # use this form if you want all users to have read/write access\n\n"
-                               "# Users with read  access, must have - before user name\n"
-                               "-user3  # comment\n"
-                               "-user4\n\n"
-                               "-*      # use this form if you want all users to have read access");
-            break;
-        }
-        case CtsCmd::RELOAD_PASSWD_FILE: {
-            desc.add_options()(
-                CtsApi::reloadpasswdfile_arg(),
-                "Reload the server password file. To be used when ALL users have a password\n"
-                "Although the password file can be reloaded(i.e to add/remove users), its location can't be changed\n"
-                "The password file is located by the ECF_PASSWD environment variable, both for the client and server\n"
-                "On the server the default file name is <host>.<port>.ecf.passwd\n"
-                "On the client the default file name is ecf.passwd\n"
-                "The format of the file is same for client and server:\n\n"
-                "4.5.0\n"
-                "# comment\n"
-                "<user> <host> <port> <passwd> # comment\n\n"
-                "i.e\n"
-                "4.5.0 # the version\n"
-                "fred machine1 3142 xxyyyd\n"
-                "fred machine2 3133 xxyyyd # comment\n"
-                "bill machine2 3133 xxyggyyd\n\n"
-                "The same user may appear multiple times. i.e with different host/port. This allows the password file\n"
-                "to be used for multiple servers\n"
-                "For the password authentication to work. It must be:\n"
-                "  - Defined for the client and server\n"
-                "  - Creating an empty password file,(i.e with just the version) will mean, no client can reload it.\n"
-                "    Hence at least the server administrator needs to be added to the file\n"
-                "  - The password file permission's must be set for reading by the user only\n"
-                "Usage:\n"
-                " --reloadpasswdfile");
-            break;
-        }
-        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE: {
-            desc.add_options()(
-                CtsApi::reloadcustompasswdfile_arg(),
-                "Reload the server custom password file. For those user's who don't use login name\n"
-                "This should be used when most users use the machine login name, but a few users specify their own "
-                "user name,\n"
-                "in this case these user must provide a password.\n"
-                "Although the password file can be reloaded(i.e to add/remove users), its location can't be changed\n"
-                "The password file is located by the ECF_CUSTOM_PASSWD environment variable, both for the client and "
-                "server\n"
-                "On the server the default file name is <host>.<port>.ecf.custom_passwd\n"
-                "On the client the default file name is ecf.custom_passwd\n"
-                "The format of the file is same for client and server:\n\n"
-                "4.5.0\n"
-                "# comment\n"
-                "<user> <host> <port> <passwd> # comment\n\n"
-                "i.e\n"
-                "4.5.0 # the version\n"
-                "fred machine1 3142 xxyyyd\n"
-                "fred machine2 3133 xxyyyd # comment\n"
-                "bill machine2 3133 xxyggyyd\n\n"
-                "The same user may appear multiple times. i.e with different host/port. This allows the password file\n"
-                "to be used for multiple servers\n"
-                "For the password authentication to work. It must be:\n"
-                "  - Defined for the client and server\n"
-                "  - Creating an empty password file,(i.e with just the version) will mean, no client can reload it.\n"
-                "    Hence at least the server administrator needs to be added to the file\n"
-                "  - The password file permission's must be set for reading by the user only\n"
-                "Usage:\n"
-                " --reloadcustompasswdfile");
-            break;
-        }
-
-        case CtsCmd::FORCE_DEP_EVAL: {
-            desc.add_options()(CtsApi::forceDependencyEvalArg(), "Force dependency evaluation. Used for DEBUG only.");
-            break;
-        }
-        case CtsCmd::PING: {
-            desc.add_options()(
-                CtsApi::pingServerArg(),
-                "Check if server is running on given host/port. Result reported to standard output.\n"
-                "Usage:\n"
-                "  --ping --host=mach --port=3144  # Check if server alive on host mach & port 3144\n"
-                "  --ping --host=fred              # Check if server alive on host fred and port ECF_PORT,\n"
-                "                                  # otherwise default port of 3141\n"
-                "  --ping                          # Check if server alive by using environment variables\n"
-                "                                  # ECF_HOST and ECF_PORT\n"
-                "If ECF_HOST not defined uses 'localhost', if ECF_PORT not defined assumes 3141");
-            break;
-        }
-        case CtsCmd::STATS: {
-            desc.add_options()(CtsApi::statsArg(), "Returns the server statistics as a string.");
-            break;
-        }
-        case CtsCmd::STATS_SERVER: {
-            desc.add_options()(CtsApi::stats_server_arg(),
-                               "Returns the server statistics as a struct and string. For test use only.");
-            break;
-        }
-        case CtsCmd::STATS_RESET: {
-            desc.add_options()(CtsApi::stats_reset_arg(), "Resets the server statistics.");
-            break;
-        }
-        case CtsCmd::SUITES: {
-            desc.add_options()(CtsApi::suitesArg(), "Returns the list of suites, in the order defined in the server.");
-            break;
-        }
-        case CtsCmd::DEBUG_SERVER_ON: {
-            desc.add_options()(CtsApi::debug_server_on_arg(), "Enables debug output from the server");
-            break;
-        }
-        case CtsCmd::DEBUG_SERVER_OFF: {
-            desc.add_options()(CtsApi::debug_server_off_arg(), "Disables debug output from the server");
-            break;
-        }
-        case CtsCmd::SERVER_LOAD: {
-            desc.add_options()(
-                CtsApi::server_load_arg(), po::value<std::string>()->implicit_value(string("")), server_load_desc());
-            break;
-        }
-        case CtsCmd::NO_CMD:
-            assert(false);
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-
-bool CtsCmd::handleRequestIsTestable() const {
-    if (api_ == CtsCmd::TERMINATE_SERVER)
-        return false;
-    if (api_ == CtsCmd::RESTORE_DEFS_FROM_CHECKPT)
-        return false;
-    return true;
-}
-
-void CtsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    if (ac->debug())
-        cout << "  CtsCmd::create api = '" << api_ << "'.\n";
-
-    assert(api_ != CtsCmd::NO_CMD);
-
-    if (api_ == CtsCmd::HALT_SERVER || api_ == CtsCmd::SHUTDOWN_SERVER || api_ == CtsCmd::TERMINATE_SERVER) {
-
-        std::string do_prompt = vm[theArg()].as<std::string>();
-        if (do_prompt.empty()) {
-            if (api_ == CtsCmd::HALT_SERVER)
-                prompt_for_confirmation("Are you sure you want to halt the server ? ");
-            else if (api_ == CtsCmd::SHUTDOWN_SERVER)
-                prompt_for_confirmation("Are you sure you want to shut down the server ? ");
-            else
-                prompt_for_confirmation("Are you sure you want to terminate the server ? ");
-        }
-        else if (do_prompt != "yes")
-            throw std::runtime_error(
-                "Halt, shutdown and terminate expected 'yes' as the only argument to bypass the confirmation prompt");
-    }
-    else if (api_ == CtsCmd::SERVER_LOAD) {
-
-        std::string log_file = vm[theArg()].as<std::string>();
-        if (ac->debug())
-            std::cout << "  CtsCmd::create CtsCmd::SERVER_LOAD " << log_file << "\n";
-
-        if (!log_file.empty()) {
-
-            // testing client interface
-            if (ac->under_test())
-                return;
-
-            // No need to call server. Parse the log file to create gnu_plot file.
-            Gnuplot gnuplot(log_file, ac->host(), ac->port());
-            gnuplot.show_server_load();
-
-            return; // Don't create command, since with log file, it is client specific only
-        }
-    }
-    cmd = std::make_shared<CtsCmd>(api_);
-}
-
-std::ostream& operator<<(std::ostream& os, const CtsCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(CtsCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(CtsCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CtsCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/CtsCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CtsCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CtsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,88 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_CtsCmd_HPP
-#define ecflow_base_cts_user_CtsCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// This command is used to encapsulate all commands that are
-// simple signals to the server. This helps to cut down on the
-// number of global symbols used by boost serialisation.
-// =========================================================================
-// *** IMPORTANT ***: If any of these commands in the future need arguments,
-// *** then ensure to place a DUMMY enum in its place.
-// *** This will allow a *newer* development client to still send message to a older server.
-// *** i.e like terminating the server
-// *** IMPORTANT: For any new commands, must be added to the end, for each major release
-// *** - STATS_RESET was introduced in release 4.0.5
-// =========================================================================
-class CtsCmd final : public UserCmd {
-public:
-    enum Api {
-        NO_CMD,
-        RESTORE_DEFS_FROM_CHECKPT,
-        RESTART_SERVER,
-        SHUTDOWN_SERVER,
-        HALT_SERVER,
-        TERMINATE_SERVER,
-        RELOAD_WHITE_LIST_FILE,
-        FORCE_DEP_EVAL,
-        PING,
-        GET_ZOMBIES,
-        STATS,
-        SUITES,
-        DEBUG_SERVER_ON,
-        DEBUG_SERVER_OFF,
-        SERVER_LOAD,
-        STATS_RESET,
-        RELOAD_PASSWD_FILE,
-        STATS_SERVER,
-        RELOAD_CUSTOM_PASSWD_FILE
-    };
-
-    explicit CtsCmd(Api a) : api_(a) {}
-    CtsCmd() = default;
-
-    Api api() const { return api_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    bool isWrite() const override;
-    bool cmd_updates_defs() const override;
-    bool terminate_cmd() const override { return api_ == TERMINATE_SERVER; }
-    bool ping_cmd() const override { return api_ == PING; }
-    int timeout() const override;
-
-    bool handleRequestIsTestable() const override;
-
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    Api api_{NO_CMD};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const CtsCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(CtsCmd)
-
-#endif /* ecflow_base_cts_user_CtsCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,387 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/JobCreationCtrl.hpp"
-#include "ecflow/node/Jobs.hpp"
-#ifdef DEBUG
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool CtsNodeCmd::why_cmd(std::string& nodePath) const {
-    if (api_ == CtsNodeCmd::WHY) {
-        nodePath = absNodePath_;
-        return true;
-    }
-    return false;
-}
-
-void CtsNodeCmd::print(std::string& os) const {
-    switch (api_) {
-        case CtsNodeCmd::GET: {
-            user_cmd(os, CtsApi::get(absNodePath_));
-#ifdef DEBUG
-            std::stringstream ss;
-            if (Ecf::server())
-                ss << " [server(" << Ecf::state_change_no() << " " << Ecf::modify_change_no() << ")]";
-            os += ss.str();
-#endif
-            break;
-        }
-        case CtsNodeCmd::GET_STATE:
-            user_cmd(os, CtsApi::get_state(absNodePath_));
-            break;
-        case CtsNodeCmd::MIGRATE:
-            user_cmd(os, CtsApi::migrate(absNodePath_));
-            break;
-        case CtsNodeCmd::JOB_GEN:
-            user_cmd(os, CtsApi::job_gen(absNodePath_));
-            break;
-        case CtsNodeCmd::WHY:
-            user_cmd(os, CtsApi::why(absNodePath_));
-            break;
-        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
-            user_cmd(os, CtsApi::checkJobGenOnly(absNodePath_));
-            break;
-        case CtsNodeCmd::NO_CMD:
-            break;
-        default:
-            throw std::runtime_error("CtsNodeCmd::print: Unrecognised command");
-            break;
-    }
-}
-void CtsNodeCmd::print_only(std::string& os) const {
-    switch (api_) {
-        case CtsNodeCmd::GET:
-            os += CtsApi::get(absNodePath_);
-            break;
-        case CtsNodeCmd::GET_STATE:
-            os += CtsApi::get_state(absNodePath_);
-            break;
-        case CtsNodeCmd::MIGRATE:
-            os += CtsApi::migrate(absNodePath_);
-            break;
-        case CtsNodeCmd::JOB_GEN:
-            os += CtsApi::job_gen(absNodePath_);
-            break;
-        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
-            os += CtsApi::checkJobGenOnly(absNodePath_);
-            break;
-        case CtsNodeCmd::WHY:
-            os += CtsApi::why(absNodePath_);
-            break;
-        case CtsNodeCmd::NO_CMD:
-            break;
-        default:
-            throw std::runtime_error("CtsNodeCmd::print_only : Unrecognised command");
-            break;
-    }
-}
-
-bool CtsNodeCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<CtsNodeCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (api_ != the_rhs->api())
-        return false;
-    if (absNodePath_ != the_rhs->absNodePath())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-bool CtsNodeCmd::isWrite() const {
-    switch (api_) {
-        case CtsNodeCmd::GET:
-            return false;
-            break; // read only
-        case CtsNodeCmd::GET_STATE:
-            return false;
-            break; // read only
-        case CtsNodeCmd::MIGRATE:
-            return false;
-            break; // read only
-        case CtsNodeCmd::JOB_GEN:
-            return true;
-            break; // requires write privilege
-        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
-            return false;
-            break; // read only
-        case CtsNodeCmd::WHY:
-            return false;
-            break; // read only
-        case CtsNodeCmd::NO_CMD:
-            break;
-        default:
-            throw std::runtime_error("CtsNodeCmd::isWrite: Unrecognised command");
-            break;
-    }
-    assert(false);
-    return false;
-}
-
-const char* CtsNodeCmd::theArg() const {
-    switch (api_) {
-        case CtsNodeCmd::GET:
-            return CtsApi::getArg();
-            break;
-        case CtsNodeCmd::GET_STATE:
-            return CtsApi::get_state_arg();
-            break;
-        case CtsNodeCmd::MIGRATE:
-            return CtsApi::migrate_arg();
-            break;
-        case CtsNodeCmd::JOB_GEN:
-            return CtsApi::job_genArg();
-            break;
-        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
-            return CtsApi::checkJobGenOnlyArg();
-            break;
-        case CtsNodeCmd::WHY:
-            return CtsApi::whyArg();
-            break;
-        case CtsNodeCmd::NO_CMD:
-            break;
-        default:
-            throw std::runtime_error("CtsNodeCmd::theArg: Unrecognised command");
-            break;
-    }
-    assert(false);
-    return nullptr;
-}
-
-PrintStyle::Type_t CtsNodeCmd::show_style() const {
-    if (api_ == CtsNodeCmd::GET)
-        return PrintStyle::DEFS;
-    else if (api_ == CtsNodeCmd::GET_STATE)
-        return PrintStyle::STATE;
-    else if (api_ == CtsNodeCmd::MIGRATE)
-        return PrintStyle::MIGRATE;
-    return ClientToServerCmd::show_style();
-}
-
-int CtsNodeCmd::timeout() const {
-    if (api_ == CtsNodeCmd::GET) {
-        return time_out_for_load_sync_and_get();
-    }
-    if (api_ == CtsNodeCmd::MIGRATE) {
-        return 120;
-    }
-    return ClientToServerCmd::timeout();
-}
-
-STC_Cmd_ptr CtsNodeCmd::doHandleRequest(AbstractServer* as) const {
-    Defs* defs = as->defs().get();
-
-    switch (api_) {
-
-        case CtsNodeCmd::GET:
-        case CtsNodeCmd::MIGRATE:
-        case CtsNodeCmd::GET_STATE: {
-            // The client will configure the output display
-            as->update_stats().get_defs_++;
-            if (absNodePath_.empty()) {
-                // with migrate we need to get edit history.
-                return PreAllocatedReply::defs_cmd(as, (api_ == MIGRATE)); // if true, save edit history
-            }
-            // however request for a particular node, thats not there, treated as an error
-            node_ptr theNodeToReturn = find_node(defs, absNodePath_);
-            return PreAllocatedReply::node_cmd(as, theNodeToReturn);
-        }
-
-        case CtsNodeCmd::CHECK_JOB_GEN_ONLY: {
-            as->update_stats().node_check_job_gen_only_++;
-            job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
-            jobCtrl->set_node_path(absNodePath_);
-            defs->check_job_creation(jobCtrl);
-            if (!jobCtrl->get_error_msg().empty()) {
-                throw std::runtime_error(jobCtrl->get_error_msg());
-            }
-            break;
-        }
-
-        case CtsNodeCmd::JOB_GEN: {
-            as->update_stats().node_job_gen_++;
-
-            if (as->state() == SState::RUNNING) {
-
-                if (absNodePath_.empty()) {
-                    // If no path specified do a full job generation over all suites
-                    return doJobSubmission(as);
-                }
-
-                // Generate jobs for the given node, downwards
-                node_ptr theNode = find_node_for_edit(defs, absNodePath_);
-                Jobs jobs(theNode.get());
-                jobs.generate();
-            }
-            break;
-        }
-
-        case CtsNodeCmd::WHY: {
-            /// Why is actually invoked on client side.
-            /// Added as a command because:
-            ///    o documentation
-            ///    o allows use with group command, without any other changes
-            break;
-        }
-
-        case CtsNodeCmd::NO_CMD:
-        default:
-            throw std::runtime_error("CtsNodeCmd::doHandleRequest: Unrecognised command");
-            break;
-    }
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-bool CtsNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, absNodePath_);
-}
-
-static const char* job_gen_only_desc() {
-    return "Test hierarchical Job generation only, for chosen Node.\n"
-           "The jobs are generated independent of the dependencies\n"
-           "This will generate the jobs *only*, i.e. no job submission. Used for checking job generation only\n"
-           "  arg = node path | arg = NULL\n"
-           "     If no node path specified generates for all Tasks in the definition. For Test only";
-}
-
-static const char* job_gen_desc() { // dependency_dependent_job_submission
-    return "Job submission for chosen Node *based* on dependencies.\n"
-           "The server traverses the node tree every 60 seconds, and if the dependencies are free\n"
-           "does job generation and submission. Sometimes the user may free time/date dependencies\n"
-           "to avoid waiting for the server poll, this commands allows early job generation\n"
-           "  arg = node path | arg = NULL\n"
-           "     If no node path specified generates for full definition.";
-}
-
-static const char* why_desc() {
-    return "Show the reason why a node is not running.\n"
-           "Can only be used with the group command. The group command must include a \n"
-           "'get' command(i.e returns the server defs)\n"
-           "The why command take a optional string argument representing a node path\n"
-           "Will return reason why the node is holding and for all its children.\n"
-           "If no arguments supplied will report on all nodes\n"
-           "  arg = node path | arg = NULL\n"
-           "Usage:\n"
-           "  --group=\"get; why\"               # returns why for all holding nodes\n"
-           "  --group=\"get; why=/suite/family\" # returns why for a specific node";
-}
-
-static const char* get_desc() {
-    return "Get the suite definition or node tree in form that is re-parse able\n"
-           "Get all suite node tree's from the server and write to standard out.\n"
-           "The output is parse-able, and can be used to re-load the definition\n"
-           "  arg = NULL | arg = node path\n"
-           "Usage:\n"
-           "  --get     # gets the definition from the server,and writes to standard out\n"
-           "  --get=/s1 # gets the suite from the server,and writes to standard out";
-}
-
-static const char* get_state_desc() {
-    return "Get state data. For the whole suite definition or individual nodes.\n"
-           "This will include event, meter, node state, trigger and time state.\n"
-           "The output is written to standard out.\n"
-           "  arg = NULL | arg = node path\n"
-           "Usage:\n"
-           "  --get_state     # gets the definition from the server,and writes to standard out\n"
-           "  --get_state=/s1 # gets the suite from the server,and writes to standard out";
-}
-
-const char* migrate_desc() {
-    return "Used to print state of the definition returned from the server to standard output.\n"
-           "The node state is shown in the comments.\n"
-           "This is the format used in the check point file, but with indentation.\n"
-           "Since this is essentially the defs format with state in the comments,"
-           "it allows the definition to be migrated to future version of ecflow.\n"
-           "The output includes edit history but excludes externs.\n"
-           "When the definition is reloaded *NO* checking is done.\n"
-           "\n"
-           "The following shows a summary of the features associated with each choice:\n"
-           "                       --get  --get_state  --migrate\n"
-           "Auto generate externs    Yes    Yes          No\n"
-           "Checking on reload       Yes    Yes          No\n"
-           "Edit History             No     No           Yes\n"
-           "Show trigger AST         No     Yes          No\n\n"
-           "Usage:\n"
-           "    --migrate         # show all suites\n"
-           "    --migrate=/s1     # show state for suite s1\n";
-}
-
-void CtsNodeCmd::addOption(boost::program_options::options_description& desc) const {
-    switch (api_) {
-        case CtsNodeCmd::GET: {
-            desc.add_options()(CtsApi::getArg(), po::value<string>()->implicit_value(string()), get_desc());
-            break;
-        }
-        case CtsNodeCmd::GET_STATE: {
-            desc.add_options()(
-                CtsApi::get_state_arg(), po::value<string>()->implicit_value(string()), get_state_desc());
-            break;
-        }
-        case CtsNodeCmd::MIGRATE: {
-            desc.add_options()(CtsApi::migrate_arg(), po::value<string>()->implicit_value(string()), migrate_desc());
-            break;
-        }
-        case CtsNodeCmd::JOB_GEN: {
-            desc.add_options()(CtsApi::job_genArg(), po::value<string>()->implicit_value(string()), job_gen_desc());
-            break;
-        }
-        case CtsNodeCmd::CHECK_JOB_GEN_ONLY: {
-            desc.add_options()(
-                CtsApi::checkJobGenOnlyArg(), po::value<string>()->implicit_value(string()), job_gen_only_desc());
-            break;
-        }
-        case CtsNodeCmd::WHY: {
-            desc.add_options()(CtsApi::whyArg(), po::value<string>()->implicit_value(string()), why_desc());
-            break;
-        }
-        case CtsNodeCmd::NO_CMD:
-            assert(false);
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-
-void CtsNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    assert(api_ != CtsNodeCmd::NO_CMD);
-
-    if (ac->debug())
-        cout << "  CtsNodeCmd::create = '" << theArg() << "'.\n";
-
-    std::string absNodePath = vm[theArg()].as<std::string>();
-
-    cmd = std::make_shared<CtsNodeCmd>(api_, absNodePath);
-}
-
-std::ostream& operator<<(std::ostream& os, const CtsNodeCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(CtsNodeCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(CtsNodeCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/CtsNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,74 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_CtsNodeCmd_HPP
-#define ecflow_base_cts_user_CtsNodeCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// Collection of commands, that all take a abs node path as their only arg
-// Reduce number of global symbols caused by boost serialisation
-// Previously they were all separate commands
-//
-// Client---(CtsNodeCmd(GET))---->Server-----(DefsCmd | SNodeCmd )--->client:
-// When doHandleRequest is called in the server it will return DefsCmd
-// The DefsCmd is used to transport the node tree hierarchy to/from the server
-//
-// CHECK_JOB_GEN_ONLY command will traverse hierarchically from the given node path
-// and force generation of jobs. (i.e independently of dependencies).
-// This is used in *testing* only, so that we can compare/test/verify
-// job generation with the old version.
-// if absNodepath is empty we will generate jobs for all tasks
-class CtsNodeCmd final : public UserCmd {
-public:
-    enum Api { NO_CMD, JOB_GEN, CHECK_JOB_GEN_ONLY, GET, WHY, GET_STATE, MIGRATE };
-    CtsNodeCmd(Api a, const std::string& absNodePath) : api_(a), absNodePath_(absNodePath) {}
-    explicit CtsNodeCmd(Api a) : api_(a) { assert(a != NO_CMD); }
-    CtsNodeCmd() = default;
-
-    Api api() const { return api_; }
-    const std::string& absNodePath() const { return absNodePath_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    PrintStyle::Type_t show_style() const override;
-
-    int timeout() const override;
-    bool isWrite() const override;
-    bool handleRequestIsTestable() const override { return !terminate_cmd(); }
-    bool why_cmd(std::string& nodePath) const override;
-    bool get_cmd() const override { return api_ == GET; }
-
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-
-private:
-    Api api_{NO_CMD};
-    std::string absNodePath_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_), CEREAL_NVP(absNodePath_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const CtsNodeCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(CtsNodeCmd)
-
-#endif /* ecflow_base_cts_user_UserCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/DeleteCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/DeleteCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/DeleteCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/DeleteCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,226 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/DeleteCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-DeleteCmd::DeleteCmd(const std::string& absNodePath, bool force) : group_cmd_(nullptr), force_(force) {
-    if (!absNodePath.empty())
-        paths_.push_back(absNodePath);
-}
-
-void DeleteCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::delete_node(paths_, force_)));
-}
-
-void DeleteCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::delete_node(paths_, force_));
-}
-
-void DeleteCmd::print(std::string& os, const std::string& path) const {
-    std::vector<std::string> paths(1, path);
-    user_cmd(os, CtsApi::to_string(CtsApi::delete_node(paths, force_)));
-}
-
-bool DeleteCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<DeleteCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (paths_ != the_rhs->paths())
-        return false;
-    if (force_ != the_rhs->force())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-const char* DeleteCmd::theArg() const {
-    return CtsApi::delete_node_arg();
-}
-
-STC_Cmd_ptr DeleteCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().node_delete_++;
-
-    if (paths_.empty()) {
-        if (!force_)
-            check_for_active_or_submitted_tasks(as, nullptr);
-        else
-            as->zombie_ctrl().add_user_zombies(as->defs(), CtsApi::delete_node_arg());
-        as->clear_defs();
-
-        // If this command is part of a group command, let the following sync command, know about the new handle
-        if (group_cmd_)
-            group_cmd_->set_client_handle(0);
-
-        // This will reset client defs and set client handle to zero on the client side.
-        return PreAllocatedReply::delete_all_cmd();
-    }
-    else {
-        std::stringstream ss;
-        Defs* defs = as->defs().get();
-
-        for (const auto& path : paths_) {
-
-            node_ptr theNodeToDelete = defs->findAbsNode(path);
-            if (!theNodeToDelete.get()) {
-                ss << "DeleteCmd:Delete: Could not find node at path '" << path << "'\n";
-                continue;
-            }
-            // since node is to be deleted, we need to record the paths.
-            add_node_path_for_edit_history(path);
-
-            if (!force_)
-                check_for_active_or_submitted_tasks(as, theNodeToDelete.get());
-            else
-                as->zombie_ctrl().add_user_zombies(theNodeToDelete.get(), CtsApi::delete_node_arg());
-
-            if (!defs->deleteChild(theNodeToDelete.get())) {
-                std::string errorMsg = "Delete: Cannot delete node " + theNodeToDelete->debugNodePath();
-                throw std::runtime_error(errorMsg);
-            }
-        }
-
-        std::string error_msg = ss.str();
-        if (!error_msg.empty()) {
-            throw std::runtime_error(error_msg);
-        }
-    }
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-bool DeleteCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
-
-void DeleteCmd::check_for_active_or_submitted_tasks(AbstractServer* as, Node* theNodeToDelete) {
-    vector<Task*> taskVec;
-    if (theNodeToDelete) {
-        theNodeToDelete->getAllTasks(taskVec);
-    }
-    else {
-        as->defs()->getAllTasks(taskVec);
-    }
-
-    vector<Task*> activeVec, submittedVec;
-    for (Task* t : taskVec) {
-        if (t->state() == NState::ACTIVE)
-            activeVec.push_back(t);
-        if (t->state() == NState::SUBMITTED)
-            submittedVec.push_back(t);
-    }
-    if (!activeVec.empty() || !submittedVec.empty()) {
-        std::stringstream ss;
-        if (theNodeToDelete)
-            ss << "Cannot delete node " << theNodeToDelete->debugNodePath() << "\n";
-        else
-            ss << "Cannot delete all nodes.\n";
-        if (!activeVec.empty()) {
-            ss << " There are " << activeVec.size() << " active tasks. First : " << activeVec.front()->absNodePath()
-               << "\n";
-        }
-        if (!submittedVec.empty()) {
-            ss << " There are " << submittedVec.size()
-               << " submitted tasks. First : " << submittedVec.front()->absNodePath() << "\n";
-        }
-        ss << "Please use the 'force' option to bypass this check, at the expense of creating zombies\n";
-        throw std::runtime_error(ss.str());
-    }
-}
-
-static const char* delete_node_desc() {
-    return "Deletes the specified node(s) or _ALL_ existing definitions( i.e delete all suites) in the server.\n"
-           "  arg1 = [ force | yes ](optional)  # Use this parameter to bypass checks, i.e. for active or submitted "
-           "tasks\n"
-           "  arg2 = yes(optional)              # Use 'yes' to bypass the confirmation prompt\n"
-           "  arg3 = node paths | _all_         # _all_ means delete all suites\n"
-           "                                    # node paths must start with a leading '/'\n"
-           "Usage:\n"
-           "  --delete=_all_                    # Delete all suites in server. Use with care.\n"
-           "  --delete=/suite/f1/t1             # Delete node at /suite/f1/t1. This will prompt\n"
-           "  --delete=force /suite/f1/t1       # Delete node at /suite/f1/t1 even if active or submitted\n"
-           "  --delete=force yes /s1 /s2        # Delete suites s1,s2 even if active or submitted, bypassing prompt";
-}
-
-void DeleteCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(CtsApi::delete_node_arg(), po::value<vector<string>>()->multitoken(), delete_node_desc());
-}
-
-void DeleteCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[theArg()].as<vector<string>>();
-    if (ac->debug())
-        dumpVecArgs(theArg(), args);
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
-
-    bool force      = false;
-    bool all        = false;
-    bool do_prompt  = true;
-    size_t vec_size = options.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (args[i] == "_all_")
-            all = true;
-        if (args[i] == "force")
-            force = true;
-        if (args[i] == "yes")
-            do_prompt = false;
-    }
-
-    if (!all && paths.empty()) {
-        std::stringstream ss;
-        ss << "Delete: No paths specified. Paths must begin with a leading '/' character\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (do_prompt) {
-        std::string confirm;
-        if (paths.empty())
-            confirm = "Are you sure you want to delete all the suites ? ";
-        else {
-            confirm          = "Are you sure want to delete nodes at paths:\n";
-            size_t path_size = paths.size();
-            for (size_t i = 0; i < path_size; i++) {
-                confirm += "  " + paths[i];
-                if (i == path_size - 1)
-                    confirm += " ? ";
-                else
-                    confirm += "\n";
-            }
-        }
-        prompt_for_confirmation(confirm);
-    }
-
-    cmd = std::make_shared<DeleteCmd>(paths, force);
-}
-
-std::ostream& operator<<(std::ostream& os, const DeleteCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(DeleteCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(DeleteCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/DeleteCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/DeleteCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/DeleteCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/DeleteCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_DeleteCmd_HPP
-#define ecflow_base_cts_user_DeleteCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// DELETE If paths_ empty will delete all suites (beware) else will delete the chosen nodes.
-class DeleteCmd final : public UserCmd {
-public:
-    explicit DeleteCmd(const std::vector<std::string>& paths, bool force = false)
-        : group_cmd_(nullptr),
-          paths_(paths),
-          force_(force) {}
-    explicit DeleteCmd(const std::string& absNodePath, bool force = false);
-    DeleteCmd() = default;
-
-    const std::vector<std::string>& paths() const { return paths_; }
-    bool force() const { return force_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    void print(std::string& os, const std::string& path) const override;
-
-    bool equals(ClientToServerCmd*) const override;
-    bool isWrite() const override { return true; }
-
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-    // called in the server
-    void set_group_cmd(const GroupCTSCmd* cmd) override { group_cmd_ = cmd; }
-
-    static void check_for_active_or_submitted_tasks(AbstractServer* as, Node* theNodeToDelete);
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after handlerequest
-
-private:
-    const GroupCTSCmd* group_cmd_{nullptr}; // not persisted only used in server
-    std::vector<std::string> paths_;
-    bool force_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(paths_), CEREAL_NVP(force_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const DeleteCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(DeleteCmd)
-
-#endif /* ecflow_base_cts_user_DeleteCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/EditScriptCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/EditScriptCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/EditScriptCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/EditScriptCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,472 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/EditScriptCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/EcfFile.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool EditScriptCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<EditScriptCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (path_to_node_ != the_rhs->path_to_node()) {
-        return false;
-    }
-    if (edit_type_ != the_rhs->edit_type()) {
-        return false;
-    }
-    if (alias_ != the_rhs->alias()) {
-        return false;
-    }
-    if (run_ != the_rhs->run()) {
-        return false;
-    }
-    return UserCmd::equals(rhs);
-}
-
-static std::string to_string(EditScriptCmd::EditType et) {
-    switch (et) {
-        case EditScriptCmd::EDIT:
-            return "edit";
-            break;
-        case EditScriptCmd::PREPROCESS:
-            return "pre_process";
-            break;
-        case EditScriptCmd::SUBMIT:
-            return "submit";
-            break;
-        case EditScriptCmd::PREPROCESS_USER_FILE:
-            return "pre_process_file";
-            break;
-        case EditScriptCmd::SUBMIT_USER_FILE:
-            return "submit_file";
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    return "edit";
-}
-static std::vector<std::string> valid_edit_types() {
-    std::vector<std::string> edit_types;
-    edit_types.reserve(5);
-    edit_types.emplace_back("edit");
-    edit_types.emplace_back("pre_process");
-    edit_types.emplace_back("submit");
-    edit_types.emplace_back("pre_process_file");
-    edit_types.emplace_back("submit_file");
-    return edit_types;
-}
-
-void EditScriptCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::edit_script(path_to_node_, to_string(edit_type()), "", alias_, run_)));
-}
-
-void EditScriptCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::edit_script(path_to_node_, to_string(edit_type()), "", alias_, run_));
-}
-
-bool EditScriptCmd::isWrite() const {
-    switch (edit_type_) {
-        case EditScriptCmd::EDIT:
-            return false;
-            break;
-        case EditScriptCmd::PREPROCESS:
-            return false;
-            break;
-        case EditScriptCmd::PREPROCESS_USER_FILE:
-            return false;
-            break;
-        case EditScriptCmd::SUBMIT:
-            return true;
-            break;
-        case EditScriptCmd::SUBMIT_USER_FILE:
-            return true;
-            break;
-        default:
-            assert(false);
-            break;
-    }
-    return false;
-}
-
-STC_Cmd_ptr EditScriptCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().edit_script_++;
-
-    node_ptr node =
-        find_node_for_edit(as->defs().get(), path_to_node_); // will throw if defs not defined, or node not found
-    Submittable* submittable = node->isSubmittable();
-    if (!submittable)
-        throw std::runtime_error("EditScriptCmd failed. Cannot locate task or alias at path " + path_to_node_);
-
-    /// record any changes made to suite. Needed for incremental updates
-    SuiteChangedPtr changed(node.get());
-
-    switch (edit_type_) {
-        case EditScriptCmd::EDIT: {
-
-            /// Find all the used variable in the script, i.e 'ecf file'
-            EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
-
-            /// This will throw std::runtime_error  for parse errors
-            /// Returns the script with the used variables added at the front of the file
-            // **********************************************************************
-            // Custom handling of dynamic variables, i.e ECF_TRYNO, ECF_PASS and
-            // any variable that embeds a try number, i.e. ECF_JOB, ECF_JOBOUT
-            // This is required since the try number is *always* incremented *before* job submission,
-            // hence the value extracted from the job file will not be accurate, hence we exclude it.
-            // This way at job submission we use the latest/correct value, which is in-sync with JOB OUTPUT
-            // Note: Otherwise the job output will not be in sync
-            //
-            // Custom handling of ECF_PORT,ECF_HOST,ECF_NAME do not show these variables, these veriables
-            // including ECF_PASS appear in the script. If the user accidentally edits them,
-            // Child communication with the server will be broken. Hence not shown
-            //
-            // This special handling is done in: EcfFile::get_used_variables
-            // **********************************************************************
-            std::string ret_file_contents;
-            ecf_file.edit_used_variables(ret_file_contents);
-            return PreAllocatedReply::string_cmd(ret_file_contents);
-        }
-
-        case EditScriptCmd::PREPROCESS: {
-
-            /// PRE_PROCESS the ecf file accessible by the server
-            /// We only *ONLY* want %include pre-processed and *NOT* variable substitution
-            /// The used variable will be listed at the top, the user can then edit these.
-            /// Hence it is NOT until -> EditScriptCmd::SUBMIT_USER_FILE do we need to variable substitute
-            EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
-
-            /// This function can throw std::runtime error if pre_processing fails
-            /// This *WILL* also include the used variables
-            std::string ret_file_contents;
-            ecf_file.pre_process(ret_file_contents);
-            return PreAllocatedReply::string_cmd(ret_file_contents);
-        }
-
-        case EditScriptCmd::PREPROCESS_USER_FILE: {
-
-            /// The file contents('user_file_contents_') here could have been edited by the user on the client side.
-            EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
-
-            /// This function can throw std::runtime error if pre_processing fails
-            /// Does full pre-processing:
-            ///   - include pre-processing
-            ///   - variable substitution
-            ///   - remove comment and manual sections
-            ///   - ignore %noop
-            std::string ret_file_contents;
-            ecf_file.pre_process_user_file(user_file_contents_, ret_file_contents);
-            vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
-            return PreAllocatedReply::string_cmd(ret_file_contents);
-        }
-
-        case EditScriptCmd::SUBMIT: {
-
-            if (submittable->state() == NState::ACTIVE || submittable->state() == NState::SUBMITTED) {
-                std::stringstream ss;
-                ss << "Node " << path_to_node_ << " is already " << NState::toString(submittable->state()) << " : ";
-                throw std::runtime_error("EditScriptCmd:: failed for submit: " + ss.str());
-            }
-
-            /// Using the User edited variables, generate the job using the ECF/USR file accessible from the server
-            /// Convert from vector to map
-            NameValueMap user_variables_map;
-            for (const auto& user_variable : user_variables_) {
-                user_variables_map.insert(std::make_pair(user_variable.first, user_variable.second));
-            }
-
-            /// Do job submission, but creating .usr file first
-            /// This will *NOT* timeout, unlike server Job generation
-            JobsParam jobsParam(as->poll_interval(), true /* create jobs */); // spawn_jobs = true
-            jobsParam.set_user_edit_variables(user_variables_map);
-
-            // Custom handling of dynamic variables, i.e ECF_TRYNO, ECF_PASS and
-            // any variable that embeds a try number, i.e. ECF_JOB, ECF_JOBOUT
-            // This is required since the try number is *always* incremented *before* job submission,
-            // hence the value extracted from the job file will *not* be accurate, hence we exclude it form user
-            // variables
-            if (!submittable->submitJob(jobsParam)) {
-                throw std::runtime_error("EditScriptCmd:: failed for submit: " + jobsParam.getErrorMsg());
-            }
-            submittable->flag().set(ecf::Flag::USER_EDIT);
-            break;
-        }
-
-        case EditScriptCmd::SUBMIT_USER_FILE: {
-            /// The file contents('user_file_contents_') here could have been edited by the user on the client side.
-            /// ECF_HOME
-            /// If the selected node is an Alias, Just submit it. Since aliases can *NOT* have other aliases as children
-            if (!alias_ || submittable->isAlias()) {
-                if (submittable->state() == NState::ACTIVE || submittable->state() == NState::SUBMITTED) {
-                    std::stringstream ss;
-                    ss << "Node " << path_to_node_ << " is already " << NState::toString(submittable->state()) << " : ";
-                    throw std::runtime_error("EditScriptCmd:: failed for submit: " + ss.str());
-                }
-
-                /// Convert from vector to map
-                NameValueMap user_variables_map;
-                for (const auto& user_variable : user_variables_) {
-                    user_variables_map.insert(std::make_pair(user_variable.first, user_variable.second));
-                }
-
-                /// Do job submission, *USING* the user supplied file , will create .usr file
-                /// This will *NOT* timeout, unlike server Job generation
-                JobsParam jobsParam(as->poll_interval(), true /* create jobs */); //  spawn_jobs = true
-                jobsParam.set_user_edit_variables(user_variables_map);
-                jobsParam.set_user_edit_file(user_file_contents_);
-
-                if (!submittable->submitJob(jobsParam)) {
-                    vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
-                    throw std::runtime_error("EditScriptCmd::SUBMIT_USER_FILE: failed : " + jobsParam.getErrorMsg());
-                }
-                submittable->flag().set(ecf::Flag::USER_EDIT);
-            }
-            else {
-                // CREATE a Child Alias. The create alias and parent it to the Task., and choose to run or not.
-                Task* task = submittable->isTask();
-                if (!task) {
-                    vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
-                    throw std::runtime_error("EditScriptCmd::SUBMIT_USER_FILE: Aliases can only be created for a task. "
-                                             "Selected path is a Alias. Please select a Task path");
-                }
-                alias_ptr alias = task->add_alias(user_file_contents_, user_variables_);
-
-                if (run_) {
-                    /// This will *NOT* timeout, unlike server Job generation
-                    JobsParam jobsParam(as->poll_interval(), true /* create jobs */); // spawn jobs = true
-                    if (!alias->submitJob(jobsParam)) {
-                        vector<string>().swap(
-                            user_file_contents_); // clear user_file_contents_ and minimise its capacity
-                        throw std::runtime_error("EditScriptCmd::SUBMIT_USER_FILE: failed for Alias : " +
-                                                 jobsParam.getErrorMsg());
-                    }
-                    alias->flag().set(ecf::Flag::USER_EDIT);
-                }
-            }
-            break;
-        }
-
-        default:
-            assert(false);
-            break;
-    }
-
-    // Clear up memory allocated *ASAP*
-    // When dealing with several thousands strings, this makes a *HUGE* difference
-    vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-bool EditScriptCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, path_to_node_);
-}
-
-const char* EditScriptCmd::arg() {
-    return CtsApi::edit_script_arg();
-}
-const char* EditScriptCmd::desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Allows user to edit, pre-process and submit the script.\n"
-           "Will allow pre-processing of arbitrary file with 'pre_process_file' option\n"
-           " arg1 = path to task  # The path to the task/alias\n"
-           " arg2 = [ edit | pre_process | submit | pre_process_file | submit_file ]\n"
-           "    edit : will return the script file to standard out. The script will\n"
-           "           include used variables enclosed between %comment/%end at the\n"
-           "           start of the file\n"
-           "    pre_process: Will return the script file to standard out.The script will\n"
-           "                 include used variables enclosed between %comment/%end at the\n"
-           "                 start of the file and with all %include expanded\n"
-           "    submit: Will extract the used variables from the supplied file, i.e\n"
-           "            between the %comment/%end and use these them to generate the\n"
-           "            job using the ecf file accessible from the server\n"
-           "    pre_process_file: Will pre process the user supplied file.\n"
-           "                      Will expand includes,variable substitution,\n"
-           "                      remove manual & comment sections.\n"
-           "    submit_file: Like submit, but the supplied file, is submitted by the server\n"
-           "                 The last 2 options allow complete freedom to debug the script file\n"
-           " arg3 = [ path_to_script_file ]\n"
-           "          needed for option [  pre_process_file | submit_file ]\n"
-           " arg4 = create_alias (optional) default value is false, for use with 'submit_file' option\n"
-           " arg5 = no_run (optional) default value is false, i.e immediately run the alias\n"
-           "        is no_run is specified the alias in only created\n"
-           "Usage:\n"
-           "--edit_script=/path/to/task edit > script_file\n"
-           "   server returns script with the used variables to standard out\n"
-           "   The user can choose to edit this file\n\n"
-           "--edit_script=/path/to/task pre_process > pre_processed_script_file\n"
-           "  server will pre process the ecf file accessible from the server\n"
-           "  (i.e expand all %includes) and return the file to standard out\n\n"
-           "--edit_script=/path/to/task submit script_file\n"
-           "  Will extract the used variables in the 'script_file' and will uses these\n"
-           "  variables during variable substitution of the ecf file accessible by the\n"
-           "  server. This is then submitted as a job\n\n"
-           "--edit_script=/path/to/task pre_process_file file_to_pre_process\n"
-           "  The server will pre-process the user supplied file and return the contents\n"
-           "  to standard out. This pre-processing is the same as job file processing,\n"
-           "  but on a arbitrary file\n\n"
-           "--edit_script=/path/to/task submit_file file_to_submit\n"
-           "  Will extract the used variables in the 'file_to_submit' and will uses these\n"
-           "  variables during variable substitution, the file is then submitted for job\n"
-           "  generation by the server\n\n"
-           "--edit_script=/path/to/task submit_file file_to_submit create_alias\n"
-           "  Like the the previous example but will create and run as an alias";
-}
-
-void EditScriptCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(EditScriptCmd::arg(), po::value<vector<string>>()->multitoken(), EditScriptCmd::desc());
-}
-
-void EditScriptCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(EditScriptCmd::arg(), args);
-
-    std::stringstream ss;
-    if (args.size() < 2) {
-        ss << "EditScriptCmd:At least 2 arguments required:\n" << EditScriptCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-
-    string path_to_task               = args[0];
-    string edit_type_str              = args[1];
-    EditScriptCmd::EditType edit_type = EditScriptCmd::EDIT;
-
-    /// Check edit_type is valid
-    bool ok                             = false;
-    std::vector<std::string> edit_types = valid_edit_types();
-    for (const auto& i : edit_types) {
-        if (edit_type_str == i) {
-            if (edit_type_str == "edit")
-                edit_type = EditScriptCmd::EDIT;
-            else if (edit_type_str == "pre_process")
-                edit_type = EditScriptCmd::PREPROCESS;
-            else if (edit_type_str == "submit")
-                edit_type = EditScriptCmd::SUBMIT;
-            else if (edit_type_str == "pre_process_file")
-                edit_type = EditScriptCmd::PREPROCESS_USER_FILE;
-            else if (edit_type_str == "submit_file")
-                edit_type = EditScriptCmd::SUBMIT_USER_FILE;
-            else {
-                assert(false);
-            }
-            ok = true;
-            break;
-        }
-    }
-
-    if (!ok) {
-        ss << "The second argument(" << args[1] << ") to edit_script must be one of [ ";
-        for (size_t i = 0; i < edit_types.size(); ++i) {
-            if (i != 0)
-                ss << " | ";
-            ss << edit_types[i];
-        }
-        ss << "]\n" << EditScriptCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-
-    if (args.size() == 2) {
-        if (edit_type == EditScriptCmd::EDIT || edit_type == EditScriptCmd::PREPROCESS) {
-            cmd = std::make_shared<EditScriptCmd>(path_to_task, edit_type);
-            return;
-        }
-        else {
-            ss << "When two arguments specified, the second argument must be one of [ edit | pre_process ]\n"
-               << EditScriptCmd::desc();
-            throw ss.str();
-        }
-    }
-
-    bool create_alias = false; // for use with "submit_file" option only
-    bool run_alias    = true;  // for use with "submit_file" option only
-    for (size_t i = 0; i < args.size(); i++) {
-        if (i > 2 && args[i] == "create_alias")
-            create_alias = true;
-        if (i > 2 && args[i] == "no_run")
-            run_alias = false;
-    }
-    if ((create_alias || !run_alias) && edit_type != EditScriptCmd::SUBMIT_USER_FILE) {
-        ss << "The create_alias option is only valid when the second argument is 'submit_file' \n"
-           << EditScriptCmd::desc();
-        throw ss.str();
-    }
-
-    if (args.size() >= 3 && args.size() <= 5) {
-        string path_to_script = args[2];
-        std::vector<std::string> script_lines;
-
-        if (!fs::exists(path_to_script)) {
-            ss << "The script file specified '" << path_to_script << "' does not exist\n";
-            throw std::runtime_error(ss.str());
-        }
-        if (!File::splitFileIntoLines(path_to_script, script_lines)) {
-            ss << "Could not open script file " << path_to_script << " (" << strerror(errno) << ")";
-            throw std::runtime_error(ss.str());
-        }
-
-        if (edit_type == EditScriptCmd::SUBMIT || edit_type == EditScriptCmd::SUBMIT_USER_FILE) {
-            // extract the Used variables from the script file
-            NameValueMap used_variables_as_map;
-            EcfFile::extract_used_variables(used_variables_as_map, script_lines);
-
-            // Convert MAP to Vec
-            NameValueVec used_variables_as_vec;
-            for (const NameValueMap::value_type& pair : used_variables_as_map) {
-                used_variables_as_vec.push_back(std::make_pair(pair.first, pair.second));
-            }
-
-            if (edit_type == EditScriptCmd::SUBMIT) {
-                cmd = std::make_shared<EditScriptCmd>(path_to_task, used_variables_as_vec); // SUMBIT
-                return;
-            }
-
-            cmd = std::make_shared<EditScriptCmd>(
-                path_to_task, used_variables_as_vec, script_lines, create_alias, run_alias); // SUBMIT_USER_FILE
-            return;
-        }
-        else if (edit_type == EditScriptCmd::PREPROCESS_USER_FILE) {
-
-            cmd = std::make_shared<EditScriptCmd>(path_to_task, script_lines);
-            return;
-        }
-    }
-
-    ss << "Wrong number of arguments specified\n" << EditScriptCmd::desc();
-    throw std::runtime_error(ss.str());
-}
-
-std::ostream& operator<<(std::ostream& os, const EditScriptCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(EditScriptCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(EditScriptCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/EditScriptCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/EditScriptCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/EditScriptCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/EditScriptCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_EditScriptCmd_HPP
-#define ecflow_base_cts_user_EditScriptCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-//================================================================================
-// Paired with SStringCmd
-// Client---(EditScriptCmd)---->Server-----(SStringCmd)--->client:
-//================================================================================
-class EditScriptCmd final : public UserCmd {
-public:
-    enum EditType { EDIT, PREPROCESS, SUBMIT, PREPROCESS_USER_FILE, SUBMIT_USER_FILE };
-    EditScriptCmd(const std::string& path_to_node, EditType et) // EDIT or PREPROCESS
-        : edit_type_(et),
-          path_to_node_(path_to_node) {}
-
-    EditScriptCmd(const std::string& path_to_node, const NameValueVec& user_variables)
-        : edit_type_(SUBMIT),
-          path_to_node_(path_to_node),
-          user_variables_(user_variables) {}
-
-    EditScriptCmd(const std::string& path_to_node, const std::vector<std::string>& user_file_contents)
-        : edit_type_(PREPROCESS_USER_FILE),
-          path_to_node_(path_to_node),
-          user_file_contents_(user_file_contents) {}
-
-    EditScriptCmd(const std::string& path_to_node,
-                  const NameValueVec& user_variables,
-                  const std::vector<std::string>& user_file_contents,
-                  bool create_alias,
-                  bool run_alias)
-        : edit_type_(SUBMIT_USER_FILE),
-          path_to_node_(path_to_node),
-          user_file_contents_(user_file_contents),
-          user_variables_(user_variables),
-          alias_(create_alias),
-          run_(run_alias) {}
-
-    EditScriptCmd() = default;
-
-    // Uses by equals only
-    const std::string& path_to_node() const { return path_to_node_; }
-    EditType edit_type() const { return edit_type_; }
-    bool alias() const { return alias_; }
-    bool run() const { return run_; }
-
-    bool handleRequestIsTestable() const override { return false; }
-    bool isWrite() const override;
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override {
-        std::vector<std::string>().swap(user_file_contents_);
-    } /// run in the server, after doHandleRequest
-
-private:
-    EditType edit_type_{EDIT};
-    std::string path_to_node_;
-    mutable std::vector<std::string> user_file_contents_;
-    NameValueVec user_variables_;
-    bool alias_{false};
-    bool run_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(edit_type_),
-           CEREAL_NVP(path_to_node_),
-           CEREAL_NVP(user_file_contents_),
-           CEREAL_NVP(user_variables_),
-           CEREAL_NVP(alias_),
-           CEREAL_NVP(run_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const EditScriptCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(EditScriptCmd)
-
-#endif /* ecflow_base_cts_user_EditScriptCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ForceCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/ForceCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ForceCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ForceCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,321 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/ForceCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-// ===================================================================================
-
-bool ForceCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<ForceCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (paths_ != the_rhs->paths()) {
-        return false;
-    }
-    if (stateOrEvent_ != the_rhs->stateOrEvent()) {
-        return false;
-    }
-    if (recursive_ != the_rhs->recursive()) {
-        return false;
-    }
-    if (setRepeatToLastValue_ != the_rhs->setRepeatToLastValue()) {
-        return false;
-    }
-    return UserCmd::equals(rhs);
-}
-
-void ForceCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::force(paths_, stateOrEvent_, recursive_, setRepeatToLastValue_)));
-}
-
-std::string ForceCmd::print_short() const {
-    std::vector<std::string> paths;
-    if (!paths_.empty())
-        paths.emplace_back(paths_[0]);
-
-    std::string os;
-    my_print_only(os, paths);
-
-    if (paths_.size() > 1) {
-        os += " : truncated : ";
-        os += ecf::convert_to<std::string>(paths_.size() - 1);
-        os += " paths *not* shown";
-    }
-    return os;
-}
-
-void ForceCmd::print_only(std::string& os) const {
-    my_print_only(os, paths_);
-}
-
-void ForceCmd::print(std::string& os, const std::string& path) const {
-    std::vector<std::string> paths(1, path);
-    my_print(os, paths);
-}
-
-void ForceCmd::my_print(std::string& os, const std::vector<std::string>& paths) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::force(paths, stateOrEvent_, recursive_, setRepeatToLastValue_)));
-}
-
-void ForceCmd::my_print_only(std::string& os, const std::vector<std::string>& paths) const {
-    os += CtsApi::to_string(CtsApi::force(paths, stateOrEvent_, recursive_, setRepeatToLastValue_));
-}
-
-STC_Cmd_ptr ForceCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().force_++;
-
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-
-    bool is_event_state = Event::isValidState(stateOrEvent_);
-    bool is_node_state  = NState::isValid(stateOrEvent_);
-    if (!is_node_state && !is_event_state) {
-        std::stringstream ss;
-        ss << "ForceCmd: failed. Invalid node state or event " << stateOrEvent_ << " expected one of "
-           << "[ unknown | complete | queued | submitted | active | aborted | clear | set ]";
-        throw std::runtime_error(ss.str());
-    }
-
-    use_EditHistoryMgr_ =
-        false; // will add edit history ourselves. Quicker than EditHistoryMgr when we have > 200000 paths
-
-    Defs* defs = as->defs().get();
-    string the_path;
-    string the_event;
-    std::stringstream error_ss;
-    for (const auto& path : paths_) {
-
-        the_path = path;
-        the_event.clear();
-        if (is_event_state) {
-            Extract::pathAndName(path, the_path, the_event);
-            if (the_path.empty() || the_event.empty()) {
-                error_ss << "ForceCmd: When 'set' or 'clear' is specified the path needs to include name of the event "
-                            "i.e --force=/path/to_task:event_name set\n";
-                continue;
-            }
-        }
-
-        node_ptr node = defs->findAbsNode(the_path);
-        if (!node.get()) {
-            error_ss << "ForceCmd: Could not find node at path " << the_path << "\n";
-            continue;
-        }
-
-        SuiteChangedPtr changed(node.get()); // Cater for suites in handles
-        node->flag().set(ecf::Flag::MESSAGE);
-        add_edit_history(defs, the_path);
-
-        if (is_node_state) {
-            /// We want this to have side effects. i.e bubble up state and re-queue if complete and has repeat's
-            /// **** However if state is SET to complete, we want to MISS the next time slot.
-            /// **** we need to mark the time dependency as *expired*, otherwise, it will be automatically reset to
-            /// QUEUED state
-            NState::State new_state = NState::toState(stateOrEvent_);
-            if (new_state == NState::COMPLETE) {
-                node->miss_next_time_slot();
-            }
-
-            if (new_state != NState::ACTIVE && new_state != NState::SUBMITTED) {
-                as->zombie_ctrl().add_user_zombies(node.get(), CtsApi::forceArg());
-            }
-
-            if (recursive_)
-                node->set_state_hierarchically(new_state, true /* force */);
-            else
-                node->set_state(new_state, true /* force */);
-
-            // force queued allows a job to re-run preserving job output.
-            // However other nodes may reference this nodes events/meters/late in trigger expression, hence
-            // reset events,meters and late flag ECFLOW-1617
-            if (new_state == NState::QUEUED)
-                node->reset_late_event_meters();
-        }
-        else {
-            // The recursive option is *NOT* applicable to events, hence ignore. According to Axel !!!!
-            if (stateOrEvent_ == Event::SET()) {
-                if (!node->set_event(the_event)) {
-                    error_ss << "ForceCmd: force set: failed for node(" << node->absNodePath() << ") cannot find event("
-                             << the_event << ")\n";
-                    continue;
-                }
-            }
-            else if (stateOrEvent_ == Event::CLEAR()) {
-                if (!node->clear_event(the_event)) {
-                    error_ss << "ForceCmd: force clear: failed for node(" << node->absNodePath()
-                             << ") cannot find event(" << the_event << ")\n";
-                    continue;
-                }
-            }
-            else
-                throw std::runtime_error("ForceCmd: Invalid parameter");
-        }
-
-        if (recursive_ && setRepeatToLastValue_) {
-            node->setRepeatToLastValueHierarchically();
-        }
-    }
-
-    std::string error_msg = error_ss.str();
-    if (!error_msg.empty()) {
-        throw std::runtime_error(error_msg);
-    }
-
-    /// Change of state, do immediate job generation
-    return doJobSubmission(as);
-}
-
-bool ForceCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
-
-const char* ForceCmd::arg() {
-    return CtsApi::forceArg();
-}
-const char* ForceCmd::desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Force a node to a given state, or set its event.\n"
-           "When a task is set to complete, it may be automatically re-queued if it has\n"
-           "multiple future time dependencies. However each time we force a complete it will\n"
-           "expire any time based attribute on that node. When the last time based attribute\n"
-           "expires, the node will stay in a complete state.\n"
-           "This behaviour allow Repeat values to be incremented interactively.\n"
-           "A repeat attribute is incremented when all the child nodes are complete\n"
-           "in this case the child nodes are automatically re-queued.\n"
-           "  arg1 = [ unknown | complete | queued | submitted | active | aborted | clear | set ]\n"
-           "  arg2 = (optional) recursive\n"
-           "         Applies state to node and recursively to all its children\n"
-           "  arg3 = (optional) full\n"
-           "         Set repeat variables to last value, only works in conjunction\n"
-           "         with recursive option\n"
-           "  arg4 = path_to_node or path_to_node:<event>: paths must begin with '/'\n"
-           "Usage:\n"
-           "  --force=complete /suite/t1 /suite/t2   # Set task t1 & t2 to complete\n"
-           "  --force=clear /suite/task:ev           # Clear the event 'ev' on task /suite/task\n"
-           "  --force=complete recursive /suite/f1   # Recursively set complete all children of /suite/f1\n"
-           "Effect:\n"
-           "  Consider the effect of forcing complete when the current time is at 09:00\n"
-           "  suite s1\n"
-           "     task t1; time 12:00             # will complete straight away\n"
-           "     task t2; time 10:00 13:00 01:00 # will complete on fourth attempt\n\n"
-           "  --force=complete /s1/t1 /s1/t2\n"
-           "  When we have a time range(i.e as shown with task t2), it is re-queued and the\n"
-           "  next time slot is incremented for each complete, until it expires, and the task completes.\n"
-           "  Use the Why command, to show next run time (i.e. next time slot)";
-}
-
-void ForceCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(ForceCmd::arg(), po::value<vector<string>>()->multitoken(), ForceCmd::desc());
-}
-void ForceCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(ForceCmd::arg(), args);
-
-    if (args.size() < 2) {
-        std::stringstream ss;
-        ss << "ForceCmd: At least two arguments expected for Force. Found " << args.size() << "\n"
-           << ForceCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(
-        args, options, paths, true /*treat_colon_in_path_as_path*/); // relative order is still preserved
-    if (paths.empty()) {
-        std::stringstream ss;
-        ss << "ForceCmd: No paths specified. Paths must begin with a leading '/' character\n"
-           << ForceCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-    if (options.empty()) {
-        std::stringstream ss;
-        ss << "ForceCmd: Invalid argument list. Expected of:\n"
-           << "[ unknown | complete | queued | submitted | active | aborted | clear | set]\n"
-           << ForceCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    bool is_valid_state       = false;
-    bool is_valid_event_state = false;
-    bool setRepeatToLastValue = false;
-    bool recursive            = false;
-    std::string stateOrEvent;
-    size_t options_size = options.size();
-    for (size_t i = 0; i < options_size; i++) {
-        if (Str::caseInsCompare(options[i], "recursive"))
-            recursive = true;
-        else if (Str::caseInsCompare(options[i], "full"))
-            setRepeatToLastValue = true;
-        else if (NState::isValid(options[i])) {
-            is_valid_state = true;
-            stateOrEvent   = options[i];
-        }
-        else if (Event::isValidState(options[i])) {
-            is_valid_event_state = true;
-            stateOrEvent         = options[i];
-        }
-        else {
-            std::stringstream ss;
-            ss << "ForceCmd: Invalid argument \n" << ForceCmd::desc() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    if (!is_valid_state && !is_valid_event_state) {
-        std::stringstream ss;
-        ss << "ForceCmd: Invalid node state or event expected one of:\n"
-           << "[ unknown | complete | queued | submitted | active | aborted | clear | set]\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (is_valid_event_state) {
-        // When set or clear used the path needs to include the name of the event:
-        size_t path_size = paths.size();
-        for (size_t i = 0; i < path_size; i++) {
-            string the_event, the_path;
-            Extract::pathAndName(paths[i], the_path, the_event);
-            if (the_path.empty() || the_event.empty()) {
-                std::stringstream ss;
-                ss << "ForceCmd: When 'set' or 'clear' is specified the path needs to include name of the event i.e\n";
-                ss << " --force=/path/to_task:event_name set\n";
-                throw std::runtime_error(ss.str());
-            }
-        }
-    }
-    cmd = std::make_shared<ForceCmd>(paths, stateOrEvent, recursive, setRepeatToLastValue);
-}
-
-std::ostream& operator<<(std::ostream& os, const ForceCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(ForceCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(ForceCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ForceCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/ForceCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ForceCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ForceCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_ForceCmd_HPP
-#define ecflow_base_cts_user_ForceCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// Set the state on the affected node ONLY.
-// If recursive is used set the state, on node and  _ALL_ nodes _beneath
-// setRepeatToLastValue set, only make sense when used with recursive.
-// stateOrEvent, string is one of:
-// < unknown | suspended | complete | queued | submitted | active | aborted | clear | set >
-class ForceCmd final : public UserCmd {
-public:
-    ForceCmd(const std::vector<std::string>& paths,
-             const std::string& stateOrEvent,
-             bool recursive,
-             bool setRepeatToLastValue)
-        : paths_(paths),
-          stateOrEvent_(stateOrEvent),
-          recursive_(recursive),
-          setRepeatToLastValue_(setRepeatToLastValue) {}
-    ForceCmd(const std::string& path, const std::string& stateOrEvent, bool recursive, bool setRepeatToLastValue)
-        : paths_(std::vector<std::string>(1, path)),
-          stateOrEvent_(stateOrEvent),
-          recursive_(recursive),
-          setRepeatToLastValue_(setRepeatToLastValue) {}
-    ForceCmd() = default;
-
-    // Uses by equals only
-    const std::vector<std::string> paths() const { return paths_; }
-    const std::string& stateOrEvent() const { return stateOrEvent_; }
-    bool recursive() const { return recursive_; }
-    bool setRepeatToLastValue() const { return setRepeatToLastValue_; }
-
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    std::string print_short() const override;
-    void print_only(std::string&) const override;
-    void print(std::string& os, const std::string& path) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
-
-    void my_print(std::string& os, const std::vector<std::string>& paths) const;
-    void my_print_only(std::string& os, const std::vector<std::string>& paths) const;
-
-private:
-    std::vector<std::string> paths_;
-    std::string stateOrEvent_;
-    bool recursive_{false};
-    bool setRepeatToLastValue_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(paths_),
-           CEREAL_NVP(stateOrEvent_),
-           CEREAL_NVP(recursive_),
-           CEREAL_NVP(setRepeatToLastValue_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ForceCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(ForceCmd)
-
-#endif /* ecflow_base_cts_user_ForceCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/FreeDepCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/FreeDepCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/FreeDepCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/FreeDepCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,183 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/FreeDepCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-//=======================================================================================
-
-bool FreeDepCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<FreeDepCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (paths_ != the_rhs->paths()) {
-        return false;
-    }
-    if (all_ != the_rhs->all()) {
-        return false;
-    }
-    if (trigger_ != the_rhs->trigger()) {
-        return false;
-    }
-    if (date_ != the_rhs->date()) {
-        return false;
-    }
-    if (time_ != the_rhs->time()) {
-        return false;
-    }
-    return UserCmd::equals(rhs);
-}
-
-void FreeDepCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::freeDep(paths_, trigger_, all_, date_, time_)));
-}
-void FreeDepCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::freeDep(paths_, trigger_, all_, date_, time_));
-}
-void FreeDepCmd::print(std::string& os, const std::string& path) const {
-    std::vector<std::string> paths(1, path);
-    user_cmd(os, CtsApi::to_string(CtsApi::freeDep(paths, trigger_, all_, date_, time_)));
-}
-
-STC_Cmd_ptr FreeDepCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().free_dep_++;
-
-    Defs* defs = as->defs().get();
-    std::stringstream ss;
-    size_t vec_size = paths_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-
-        node_ptr node = find_node_for_edit_no_throw(defs, paths_[i]);
-        if (!node.get()) {
-            ss << "FreeDepCmd: Could not find node at path " << paths_[i] << "\n";
-            LOG(Log::ERR, "FreeDepCmd: Could not find node at path " << paths_[i]);
-            continue;
-        }
-
-        SuiteChangedPtr changed(node.get());
-        if (all_) {
-            node->freeTrigger();
-            node->freeHoldingDateDependencies();
-            node->freeHoldingTimeDependencies();
-        }
-        else {
-            if (trigger_)
-                node->freeTrigger();
-            if (date_)
-                node->freeHoldingDateDependencies();
-            if (time_)
-                node->freeHoldingTimeDependencies();
-        }
-    }
-
-    std::string error_msg = ss.str();
-    if (!error_msg.empty()) {
-        throw std::runtime_error(error_msg);
-    }
-
-    return doJobSubmission(as);
-}
-
-bool FreeDepCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
-
-const char* FreeDepCmd::arg() {
-    return CtsApi::freeDepArg();
-}
-const char* FreeDepCmd::desc() {
-    return "Free dependencies for a node. Defaults to triggers\n"
-           "After freeing the time related dependencies (i.e time,today,cron)\n"
-           "the next time slot will be missed.\n"
-           "  arg1 = (optional) trigger\n"
-           "  arg2 = (optional) all\n"
-           "         Free trigger, date and all time dependencies\n"
-           "  arg3 = (optional) date\n"
-           "         Free date dependencies\n"
-           "  arg4 = (optional) time\n"
-           "         Free all time dependencies i.e time, day, today, cron\n"
-           "  arg5 = List of paths. At least one required. Must start with a leading '/'\n"
-           "Usage:\n"
-           "  --free-dep=/s1/t1 /s2/t2   # free trigger dependencies for task's t1,t2\n"
-           "  --free-dep=all /s1/f1/t1   # free all dependencies of /s1/f1/t1\n"
-           "  --free-dep=date /s1/f1     # free holding date dependencies of /s1/f1";
-}
-
-void FreeDepCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(FreeDepCmd::arg(), po::value<vector<string>>()->multitoken(), FreeDepCmd::desc());
-}
-void FreeDepCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(FreeDepCmd::arg(), args);
-
-    if (args.size() < 1) {
-        std::stringstream ss;
-        ss << "FreeDepCmd: At least one arguments expected for Free dependencies. Found " << args.size() << "\n"
-           << FreeDepCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
-    if (paths.empty()) {
-        std::stringstream ss;
-        ss << "FreeDepCmd: No paths specified. Paths must begin with a leading '/' character\n"
-           << FreeDepCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    bool trigger    = options.empty(); // If no options default to freeing trigger dependencies
-    bool all        = false;
-    bool date       = false;
-    bool time       = false;
-    size_t vec_size = options.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (options[i] == "trigger")
-            trigger = true;
-        else if (options[i] == "all")
-            all = true;
-        else if (options[i] == "date")
-            date = true;
-        else if (options[i] == "time")
-            time = true;
-        else {
-            std::stringstream ss;
-            ss << "FreeDepCmd: Invalid argument(" << options[i] << ")\n" << FreeDepCmd::desc() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    assert(trigger || all || date || time); // at least one must be true
-    cmd = std::make_shared<FreeDepCmd>(paths, trigger, all, date, time);
-}
-
-std::ostream& operator<<(std::ostream& os, const FreeDepCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(FreeDepCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(FreeDepCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/FreeDepCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/FreeDepCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/FreeDepCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/FreeDepCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_FreeDepCmd_HPP
-#define ecflow_base_cts_user_FreeDepCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// Free Dependencies
-class FreeDepCmd final : public UserCmd {
-public:
-    explicit FreeDepCmd(const std::vector<std::string>& paths,
-                        bool trigger = true,
-                        bool all     = false, // day, date, time, today, trigger, cron
-                        bool date    = false,
-                        bool time    = false // includes time, day, date, today, cron
-                        )
-        : paths_(paths),
-          trigger_(trigger),
-          all_(all),
-          date_(date),
-          time_(time) {}
-
-    explicit FreeDepCmd(const std::string& path,
-                        bool trigger = true,
-                        bool all     = false, // day, date, time, today, trigger, cron
-                        bool date    = false,
-                        bool time    = false // includes time, day, date, today, cron
-                        )
-        : paths_(std::vector<std::string>(1, path)),
-          trigger_(trigger),
-          all_(all),
-          date_(date),
-          time_(time) {}
-
-    FreeDepCmd() = default;
-
-    // Uses by equals only
-    const std::vector<std::string>& paths() const { return paths_; }
-    bool trigger() const { return trigger_; }
-    bool all() const { return all_; }
-    bool date() const { return date_; }
-    bool time() const { return time_; }
-
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    void print(std::string& os, const std::string& path) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
-
-private:
-    std::vector<std::string> paths_;
-    bool trigger_{true};
-    bool all_{false};
-    bool date_{false};
-    bool time_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(paths_),
-           CEREAL_NVP(trigger_),
-           CEREAL_NVP(all_),
-           CEREAL_NVP(date_),
-           CEREAL_NVP(time_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const FreeDepCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(FreeDepCmd)
-
-#endif /* ecflow_base_cts_user_FreeDepCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,408 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
-
-#include <iostream>
-#include <memory>
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/ClientOptionsParser.hpp"
-#include "ecflow/base/cts/CtsCmdRegistry.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/ErrorCmd.hpp"
-#include "ecflow/base/stc/GroupSTCCmd.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/CommandLine.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-// #define DEBUG_GROUP_CMD 1
-
-//======================================================================================
-
-GroupCTSCmd::GroupCTSCmd(const std::string& cmdSeries, AbstractClientEnv* clientEnv) {
-    std::vector<std::string> individualCmdVec;
-    Str::split(cmdSeries, individualCmdVec, ";");
-    if (individualCmdVec.empty())
-        throw std::runtime_error("GroupCTSCmd::GroupCTSCmd: Please provide a list of ';' separated commands\n");
-    if (clientEnv->debug()) {
-        for (const auto& i : individualCmdVec) {
-            cout << "  CHILD COMMAND = " << i << "\n";
-        }
-    }
-
-    // Create a list of allowable commands for a group. i.e excludes help, group
-    po::options_description desc("Allowed group options");
-    CtsCmdRegistry cmdRegistry(false /* don't add group option */);
-    cmdRegistry.addCmdOptions(desc);
-
-    std::string subCmd;
-    for (auto aCmd : individualCmdVec) {
-        // massage the commands so that, we add -- at the start of each command.
-        // This is required by the boost program options.
-        ecf::algorithm::trim(aCmd);
-
-        subCmd.clear();
-        if (aCmd.find("--") == std::string::npos)
-            subCmd = "--";
-        subCmd += aCmd;
-
-        // handle case like: alter add variable FRED "fre d ddy" /suite
-        // If we have quote marks, then treat as one string,
-        // by replacing spaces with /b, then replacing back after the split
-        // This can only handle one level of quotes  hence can't cope with "fred \"joe fred\"
-        bool start_quote     = false;
-        bool replaced_spaces = false;
-        for (char& i : subCmd) {
-            if (start_quote) {
-                if (i == '"' || i == '\'')
-                    start_quote = false;
-                else if (i == ' ') {
-                    i               = '\b'; // "fre d ddy"  => "fre\bd\bddy"
-                    replaced_spaces = true;
-                }
-            }
-            else {
-                if (i == '"' || i == '\'')
-                    start_quote = true;
-            }
-        }
-
-        // Each sub command can have, many args
-        std::vector<std::string> subCmdArgs;
-        Str::split(subCmd, subCmdArgs);
-
-        if (replaced_spaces) {
-            for (auto& str : subCmdArgs) {
-                for (char& j : str) {
-                    if (j == '\b')
-                        j = ' '; // "fre\bd\bddy"  => "fre d ddy"
-                }
-            }
-        }
-
-        // The first will be the command, then the args. However from boost 1.59
-        // we must use --cmd=value, instead of --cmd value
-        if (!subCmdArgs.empty() && subCmdArgs.size() > 1 && subCmdArgs[0].find("=") == std::string::npos) {
-            subCmdArgs[0] += "=";
-            subCmdArgs[0] += subCmdArgs[1];
-            subCmdArgs.erase(subCmdArgs.begin() + 1); // remove, since we have added to first
-        }
-
-        /// Hack because we *can't* create program option with vector of strings, which can be empty
-        /// Hence if command is just show, add a dummy arg.
-        // if (aCmd == "show")  subCmdArgs.push_back("<dummy_arg>");
-
-        std::vector<std::string> theArgs;
-        theArgs.emplace_back("ClientInvoker");
-        std::copy(subCmdArgs.begin(), subCmdArgs.end(), std::back_inserter(theArgs));
-
-        // Create a Argv array from a vector of strings
-        CommandLine cl(theArgs);
-
-        if (clientEnv->debug()) {
-            cout << "  PROCESSING COMMAND = '" << subCmd << "' " << cl << "\n";
-        }
-
-        // Treat each sub command  separately
-        boost::program_options::variables_map group_vm;
-
-        // 1) Parse the CLI options
-        po::parsed_options parsed_options =
-            po::command_line_parser(cl.tokens())
-                .options(desc)
-                .style(po::command_line_style::unix_style ^ po::command_line_style::allow_short)
-                .extra_style_parser(ClientOptionsParser{})
-                .run();
-
-        // 2) Store the CLI options into the variable map
-        po::store(parsed_options, group_vm);
-        po::notify(group_vm);
-
-        Cmd_ptr childCmd;
-        cmdRegistry.parse(childCmd, group_vm, clientEnv);
-        addChild(childCmd);
-    }
-}
-
-bool GroupCTSCmd::isWrite() const {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        if (subCmd->isWrite())
-            return true;
-    }
-    return false;
-}
-
-bool GroupCTSCmd::cmd_updates_defs() const {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        if (subCmd->cmd_updates_defs())
-            return true;
-    }
-    return false;
-}
-
-bool GroupCTSCmd::get_cmd() const {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        if (subCmd->get_cmd())
-            return true;
-    }
-    return false;
-}
-
-PrintStyle::Type_t GroupCTSCmd::show_style() const {
-    // Only return non default style( PrintStyle::NOTHING ) if sub command
-    // contains a show cmd
-    for (Cmd_ptr subCmd : cmdVec_) {
-        if (subCmd->show_cmd())
-            return subCmd->show_style();
-    }
-    return PrintStyle::NOTHING;
-}
-
-bool GroupCTSCmd::task_cmd() const {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        if (subCmd->task_cmd())
-            return true;
-    }
-    return false;
-}
-
-bool GroupCTSCmd::terminate_cmd() const {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        if (subCmd->terminate_cmd())
-            return true;
-    }
-    return false;
-}
-
-bool GroupCTSCmd::why_cmd(std::string& nodePath) const {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        if (subCmd->why_cmd(nodePath))
-            return true;
-    }
-    return false;
-}
-
-void GroupCTSCmd::print(std::string& os) const {
-    std::string ret;
-    size_t the_size = cmdVec_.size();
-    for (size_t i = 0; i < the_size; i++) {
-        if (i != 0)
-            ret += "; ";
-        cmdVec_[i]->print_only(ret); //  avoid overhead of user@host for each child command
-    }
-    user_cmd(os, CtsApi::group(ret));
-}
-
-std::string GroupCTSCmd::print_short() const {
-    std::string ret;
-    size_t the_size = cmdVec_.size();
-    for (size_t i = 0; i < the_size; i++) {
-        if (i != 0)
-            ret += "; ";
-        ret +=
-            cmdVec_[i]
-                ->print_short(); // limit number of paths shown and avoid overhead of user@host for each child command
-    }
-    return CtsApi::group(ret);
-}
-
-bool GroupCTSCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<GroupCTSCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-
-    const std::vector<Cmd_ptr>& rhsCmdVec = the_rhs->cmdVec();
-    if (cmdVec_.size() != rhsCmdVec.size())
-        return false;
-
-    for (size_t i = 0; i < cmdVec_.size(); i++) {
-        if (!cmdVec_[i]->equals(rhsCmdVec[i].get())) {
-            return false;
-        }
-    }
-
-    return UserCmd::equals(rhs);
-}
-
-void GroupCTSCmd::addChild(Cmd_ptr childCmd) {
-    assert(childCmd.get()); // Dont add NULL children
-    cmdVec_.push_back(childCmd);
-}
-
-void GroupCTSCmd::setup_user_authentification(const std::string& user, const std::string& passwd) {
-    UserCmd::setup_user_authentification(user, passwd);
-    for (auto& i : cmdVec_) {
-        i->setup_user_authentification(user, passwd);
-    }
-}
-
-bool GroupCTSCmd::setup_user_authentification(AbstractClientEnv& env) {
-    if (!UserCmd::setup_user_authentification(env))
-        return false;
-    for (auto& i : cmdVec_) {
-        if (!i->setup_user_authentification(env))
-            return false;
-    }
-    return true;
-}
-
-void GroupCTSCmd::setup_user_authentification() {
-    UserCmd::setup_user_authentification();
-    for (auto& i : cmdVec_) {
-        i->setup_user_authentification();
-    }
-}
-
-void GroupCTSCmd::add_edit_history(Defs* defs) const {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        subCmd->add_edit_history(defs);
-    }
-}
-
-void GroupCTSCmd::cleanup() {
-    for (Cmd_ptr subCmd : cmdVec_) {
-        subCmd->cleanup();
-    }
-}
-
-bool GroupCTSCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& errorMsg) const {
-    // Can only run Group cmd if all child commands authenticate
-    size_t cmd_vec_size = cmdVec_.size();
-    for (size_t i = 0; i < cmd_vec_size; i++) {
-        if (!cmdVec_[i]->authenticate(as, errorMsg)) {
-
-            // Log authentication failure:
-            std::string ss;
-            ss += "GroupCTSCmd::authenticate failed: for ";
-            cmdVec_[i]->print(ss);
-            std::stringstream stream;
-            stream << errorMsg;
-            ss += stream.str();
-            log(Log::ERR, ss); // will automatically add end of line
-
-#ifdef DEBUG_GROUP_CMD
-            std::cout << "GroupCTSCmd::authenticate failed for " << ss << "\n";
-#endif
-            return false;
-        }
-    }
-    return true;
-}
-
-// in the server
-void GroupCTSCmd::set_client_handle(int client_handle) const {
-    size_t cmd_vec_size = cmdVec_.size();
-    if (cmd_vec_size >= 2) {
-        cmdVec_[1]->set_client_handle(client_handle);
-    }
-}
-
-STC_Cmd_ptr GroupCTSCmd::doHandleRequest(AbstractServer* as) const {
-#ifdef DEBUG_GROUP_CMD
-    std::cout << "GroupCTSCmd::doHandleRequest cmdVec_.size() = " << cmdVec_.size() << "\n";
-#endif
-    // ecf::LogTimer timer(" GroupCTSCmd::doHandleRequest");
-
-    as->update_stats().group_cmd_++;
-
-    std::shared_ptr<GroupSTCCmd> theReturnedGroupCmd = std::make_shared<GroupSTCCmd>();
-
-    // For the command to succeed all children MUST succeed
-    size_t cmd_vec_size = cmdVec_.size();
-    for (size_t i = 0; i < cmd_vec_size; i++) {
-#ifdef DEBUG_GROUP_CMD
-        std::cout << "  GroupCTSCmd::doHandleRequest calling ";
-        string ret;
-        cmdVec_[i]->print(ret);
-        cout << ret << "\n"; // std::cout << "\n";
-#endif
-        // Let child know about Group command.
-        // Only used by ClientHandleCmd and DeleteCmd to transfer client_handle to the sync cmd, in *this* group
-        cmdVec_[i]->set_group_cmd(this);
-
-        STC_Cmd_ptr theReturnCmd;
-        try {
-            theReturnCmd = cmdVec_[i]->doHandleRequest(as);
-        }
-        catch (std::exception& e) {
-            cmdVec_[i]->cleanup(); // recover memory asap, important when cmd has a large number of paths.
-            theReturnedGroupCmd->addChild(std::make_shared<ErrorCmd>(e.what()));
-            continue;
-        }
-        cmdVec_[i]->cleanup(); // recover memory asap, important when cmd has a large number of paths.
-
-#ifdef DEBUG_GROUP_CMD
-        std::cout << " return Cmd = ";
-        theReturnCmd->print(std::cout);
-        std::cout << " to client\n";
-#endif
-
-        if (theReturnCmd->is_returnable_in_group_cmd()) {
-            theReturnedGroupCmd->addChild(theReturnCmd);
-            continue;
-        }
-    }
-
-    if (theReturnedGroupCmd->cmdVec().empty()) {
-        // Nothing to return, i.e. no Defs, Node or Log file
-        return PreAllocatedReply::ok_cmd();
-    }
-
-    return theReturnedGroupCmd;
-}
-
-const char* GroupCTSCmd::arg() {
-    return CtsApi::groupArg();
-}
-const char* GroupCTSCmd::desc() {
-    return "Allows a series of ';' separated commands to be grouped and executed as one.\n"
-           "Some commands like halt, shutdown and terminate will prompt the user. To bypass the prompt\n"
-           "provide 'yes' as an additional parameter. See example below.\n"
-           "  arg = string\n"
-           "Usage:\n"
-           "   --group=\"halt=yes; reloadwsfile; restart;\"\n"
-           "                                 # halt server,bypass the confirmation prompt,\n"
-           "                                 # reload white list file, restart server\n"
-           "   --group=\"get; show\"           # get server defs, and write to standard output\n"
-           "   --group=\"get=/s1; show state\" # get suite 's1', and write state to standard output";
-}
-
-void GroupCTSCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(GroupCTSCmd::arg(), po::value<string>(), GroupCTSCmd::desc());
-}
-
-void GroupCTSCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    if (clientEnv->debug())
-        cout << "  " << arg() << ": Group Cmd '" << vm[arg()].as<std::string>() << "'\n";
-
-    // Parse and split commands and then parse individually. Assumes commands are separated by ';'
-    std::string cmdSeries = vm[GroupCTSCmd::arg()].as<std::string>();
-
-    cmd = std::make_shared<GroupCTSCmd>(cmdSeries, clientEnv);
-}
-
-std::ostream& operator<<(std::ostream& os, const GroupCTSCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(GroupCTSCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(GroupCTSCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/GroupCTSCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_GroupCTSCmd_HPP
-#define ecflow_base_cts_user_GroupCTSCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// The group command allows a series of commands to be be executed:
-//
-// Client---(GroupCTSCmd)---->Server-----(GroupSTCCmd | StcCmd(OK) | Error )--->client:
-//
-// If client->server contains GetDefs cmd and log file commands, then a group
-// command will be created for returning to the client
-//
-// If group command contains multiple [ CtsNodeCmd(GET) | LogCmd --get ] commands then
-// all the results are returned back to the client, HOWEVER when client calls
-// Cmd::defs() | Cmd::get_string() only the first data is returned.
-//
-class GroupCTSCmd final : public UserCmd {
-public:
-    GroupCTSCmd(const std::string& list_of_commands, AbstractClientEnv* clientEnv);
-    explicit GroupCTSCmd(Cmd_ptr cmd) : cli_(false) { addChild(cmd); }
-    GroupCTSCmd() = default;
-
-    bool isWrite() const override;
-    bool cmd_updates_defs() const override;
-
-    PrintStyle::Type_t show_style() const override;
-    bool get_cmd() const override;
-    bool task_cmd() const override;
-    bool terminate_cmd() const override;
-    bool why_cmd(std::string&) const override;
-    bool group_cmd() const override { return true; }
-
-    void set_client_handle(int client_handle) const; // used in group sync with client register
-
-    void print(std::string&) const override;
-    std::string print_short() const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    void addChild(Cmd_ptr childCmd);
-    const std::vector<Cmd_ptr>& cmdVec() const { return cmdVec_; }
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-    void add_edit_history(Defs*) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    void setup_user_authentification(const std::string& user, const std::string& passwd) override;
-    bool setup_user_authentification(AbstractClientEnv&) override;
-    void setup_user_authentification() override;
-
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    void cleanup() override; // cleanup all children
-
-private:
-    std::vector<Cmd_ptr> cmdVec_;
-    bool cli_{true};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(cmdVec_), CEREAL_NVP(cli_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const GroupCTSCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(GroupCTSCmd)
-
-#endif /* ecflow_base_cts_user_GroupCTSCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,231 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-LoadDefsCmd::LoadDefsCmd(const defs_ptr& defs, bool force) : force_(force) {
-    if (defs) {
-        defs->handle_migration();
-        defs->save_as_string(defs_, PrintStyle::NET);
-    }
-}
-
-LoadDefsCmd::LoadDefsCmd(const std::string& defs_filename,
-                         bool force,
-                         bool check_only,
-                         bool print,
-                         bool stats,
-                         const std::vector<std::pair<std::string, std::string>>& client_env)
-    : force_(force),
-      defs_filename_(defs_filename) {
-    if (defs_filename_.empty()) {
-        std::stringstream ss;
-        ss << "LoadDefsCmd::LoadDefsCmd: The pathname to the definition file must be provided\n" << LoadDefsCmd::desc();
-        throw std::runtime_error(ss.str());
-    }
-
-    defs_ptr defs = Defs::create();
-    std::string errMsg, warningMsg;
-
-    bool load_ok = false;
-
-    if (defs_filename.find("suite") != std::string::npos && defs_filename.find("endsuite") != std::string::npos) {
-        load_ok        = defs->restore_from_string(defs_filename, errMsg, warningMsg);
-        defs_filename_ = "";
-    }
-    else if (fs::exists(defs_filename)) {
-        // defs_filename is actually a file, open the file and read it. This is the method
-        // when loading definitions with ecflow_client
-
-        // At the end of the parse check the trigger/complete expressions and resolve in-limits
-
-        load_ok = defs->restore(defs_filename_, errMsg, warningMsg);
-    }
-
-    if (load_ok) {
-        defs->handle_migration();
-        defs->set_server().add_or_update_user_variables(client_env); // use in test environment
-
-        if (print) {
-            PrintStyle print_style(PrintStyle::NET); // should be same as MIGRATE, only differ on reload
-            cout << defs;
-        }
-        if (stats) {
-            cout << defs->stats();
-        }
-
-        if (!check_only && !stats && !print)
-            defs->save_as_string(defs_, PrintStyle::NET); // NET only takes affect on restore
-
-        // Output any warning to standard output
-        cout << warningMsg;
-    }
-    else {
-        std::stringstream ss;
-        ss << "\nLoadDefsCmd::LoadDefsCmd. Failed to parse file/definition " << defs_filename_ << "\n";
-        ss << errMsg;
-        throw std::runtime_error(ss.str());
-    }
-}
-
-bool LoadDefsCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<LoadDefsCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (!UserCmd::equals(rhs))
-        return false;
-    if (defs_ != the_rhs->defs_as_string())
-        return false;
-    return true;
-}
-
-STC_Cmd_ptr LoadDefsCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().load_defs_++;
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-
-    if (!defs_.empty()) {
-
-        // Parse the string and load the defs file into memory.
-        std::string errMsg, warningMsg;
-        defs_ptr defs = Defs::create();
-        if (!defs->restore_from_string(defs_, errMsg, warningMsg)) {
-            std::stringstream ss;
-            ss << "LoadDefsCmd::doHandleRequest : Could not parse file " << defs_filename_ << " : " << errMsg;
-            throw std::runtime_error(ss.str());
-        }
-
-        // After the updateDefs, defs will be left with NO suites.
-        // Can't really used defs after this point
-        // *NOTE* Externs are not persisted. Hence calling check() will report
-        // all errors, references are not resolved.
-        as->updateDefs(defs, force_);
-
-        LOG_ASSERT(defs->suiteVec().size() == 0, "Expected suites to be transferred to server defs");
-    }
-    LOG_ASSERT(as->defs()->externs().size() == 0, "Expected server to have no externs");
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-void LoadDefsCmd::print(std::string& os) const {
-    /// If defs_filename_ is empty, the Defs was a in memory defs.
-    if (defs_filename_.empty()) {
-        user_cmd(
-            os, CtsApi::to_string(CtsApi::loadDefs("<in-memory-defs>", force_, false /*check_only*/, false /*print*/)));
-        return;
-    }
-    user_cmd(os, CtsApi::to_string(CtsApi::loadDefs(defs_filename_, force_, false /*check_only*/, false /*print*/)));
-}
-void LoadDefsCmd::print_only(std::string& os) const {
-    if (defs_filename_.empty()) {
-        os += CtsApi::to_string(CtsApi::loadDefs("<in-memory-defs>", force_, false /*check_only*/, false /*print*/));
-        return;
-    }
-    os += CtsApi::to_string(CtsApi::loadDefs(defs_filename_, force_, false /*check_only*/, false /*print*/));
-}
-
-const char* LoadDefsCmd::arg() {
-    return CtsApi::loadDefsArg();
-}
-const char* LoadDefsCmd::desc() {
-    return "Check and load definition or checkpoint file into server.\n"
-           "The loaded definition will be checked for valid trigger and complete expressions,\n"
-           "additionally in-limit references to limits will be validated.\n"
-           "If the server already has the 'suites' of the same name, then a error message is issued.\n"
-           "The suite's can be overwritten if the force option is used.\n"
-           "To just check the definition and not send to server, use 'check_only'\n"
-           "This command can also be used to load a checkpoint file into the server\n"
-           "  arg1 = path to the definition file or checkpoint file\n"
-           "  arg2 = (optional) [ force | check_only | print | stats ]  # default = false for all\n"
-           "Usage:\n"
-           "--load=/my/home/exotic.def               # will error if suites of same name exists\n"
-           "--load=/my/home/exotic.def force         # overwrite suite's of same name in the server\n"
-           "--load=/my/home/exotic.def check_only    # Just check, don't send to server\n"
-           "--load=/my/home/exotic.def stats         # Show defs statistics, don't send to server\n"
-           "--load=host1.3141.check                  # Load checkpoint file to the server\n"
-           "--load=host1.3141.check print            # print definition to standard out in defs format\n";
-}
-
-void LoadDefsCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(LoadDefsCmd::arg(), po::value<vector<string>>()->multitoken(), LoadDefsCmd::desc());
-}
-
-void LoadDefsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-    if (clientEnv->debug())
-        dumpVecArgs(LoadDefsCmd::arg(), args);
-
-    bool check_only = false;
-    bool force      = false;
-    bool print      = false;
-    bool stats      = false;
-    std::string defs_filename;
-    for (const auto& arg : args) {
-        if (arg == "force")
-            force = true;
-        else if (arg == "check_only")
-            check_only = true;
-        else if (arg == "print")
-            print = true;
-        else if (arg == "stats")
-            stats = true;
-        else
-            defs_filename = arg;
-    }
-    if (clientEnv->debug())
-        cout << "  LoadDefsCmd::create: Defs file '" << defs_filename << "'.\n";
-
-    cmd = LoadDefsCmd::create(defs_filename, force, check_only, print, stats, clientEnv);
-}
-
-Cmd_ptr LoadDefsCmd::create(const std::string& defs_filename,
-                            bool force,
-                            bool check_only,
-                            bool print,
-                            bool stats,
-                            AbstractClientEnv* clientEnv) {
-    // For test allow the server environment to be changed, i.e. allow us to inject ECF_CLIENT
-    // The server will also update the env on the defs, server will override client env, where they clash
-
-    // The constructor can throw if parsing of defs_filename fail's
-    std::shared_ptr<LoadDefsCmd> load_cmd =
-        std::make_shared<LoadDefsCmd>(defs_filename, force, check_only, print, stats, clientEnv->env());
-
-    // Don't send to server if checking, i.e cmd not set
-    if (check_only || stats || print)
-        return Cmd_ptr();
-
-    return load_cmd;
-}
-
-std::ostream& operator<<(std::ostream& os, const LoadDefsCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(LoadDefsCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(LoadDefsCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/LoadDefsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_LoadDefsCmd_HPP
-#define ecflow_base_cts_user_LoadDefsCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// Will *load* the suites, into the server.
-// Additionally the server will try to resolve extern's. The extern are references
-// to Node, events, meters, limits, variables defined on another suite.
-class LoadDefsCmd final : public UserCmd {
-public:
-    explicit LoadDefsCmd(const defs_ptr& defs, bool force = false);
-    explicit LoadDefsCmd(const std::string& defs_filename,
-                         bool force      = false,
-                         bool check_only = false /* not persisted */,
-                         bool print      = false /* not persisted */,
-                         bool stats      = false /* not persisted */,
-                         const std::vector<std::pair<std::string, std::string>>& client_env =
-                             std::vector<std::pair<std::string, std::string>>());
-    LoadDefsCmd() = default;
-
-    // Uses by equals only
-    const std::string& defs_as_string() const { return defs_; }
-
-    bool isWrite() const override { return true; }
-    int timeout() const override { return time_out_for_load_sync_and_get(); }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-    static Cmd_ptr create(const std::string& defs_filename,
-                          bool force,
-                          bool check_only,
-                          bool print,
-                          bool stats,
-                          AbstractClientEnv* clientEnv);
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the command as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    bool force_{false};
-    std::string defs_;
-    std::string defs_filename_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(force_), CEREAL_NVP(defs_), CEREAL_NVP(defs_filename_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const LoadDefsCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(LoadDefsCmd)
-
-#endif /* ecflow_base_cts_user_LoadDefsCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/LogCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/LogCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/LogCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/LogCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,305 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/LogCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace ecf;
-using namespace std;
-namespace po = boost::program_options;
-
-LogCmd::LogCmd(LogApi a, int get_last_n_lines) : api_(a), get_last_n_lines_(get_last_n_lines) {
-    if (get_last_n_lines_ == 0)
-        get_last_n_lines_ = Log::get_last_n_lines_default();
-}
-
-LogCmd::LogCmd() : get_last_n_lines_(Log::get_last_n_lines_default()) {
-}
-
-LogCmd::LogCmd(const std::string& path)
-    : api_(NEW),
-      get_last_n_lines_(Log::get_last_n_lines_default()),
-      new_path_(path) {
-    // ECFLOW-154, If path to new log file is specified, it should only be checked by the server,
-    //             as that could be on a different machine.
-    // ECFLOW-174, Never get the full log, as this can make server consume to much memory
-    //             default taken from get_last_n_lines_default
-    // ECFLOW-377, should remove leading/trailing spaces from path
-    ecf::algorithm::trim(new_path_);
-}
-
-void LogCmd::print(std::string& os) const {
-    switch (api_) {
-        case LogCmd::GET:
-            user_cmd(os, CtsApi::to_string(CtsApi::getLog(get_last_n_lines_)));
-            break;
-        case LogCmd::CLEAR:
-            user_cmd(os, CtsApi::clearLog());
-            break;
-        case LogCmd::FLUSH:
-            user_cmd(os, CtsApi::flushLog());
-            break;
-        case LogCmd::NEW:
-            user_cmd(os, CtsApi::to_string(CtsApi::new_log(new_path_)));
-            break;
-        case LogCmd::PATH:
-            user_cmd(os, CtsApi::get_log_path());
-            break;
-        default:
-            throw std::runtime_error("LogCmd::print: Unrecognised log api command,");
-    }
-}
-void LogCmd::print_only(std::string& os) const {
-    switch (api_) {
-        case LogCmd::GET:
-            os += CtsApi::to_string(CtsApi::getLog(get_last_n_lines_));
-            break;
-        case LogCmd::CLEAR:
-            os += CtsApi::clearLog();
-            break;
-        case LogCmd::FLUSH:
-            os += CtsApi::flushLog();
-            break;
-        case LogCmd::NEW:
-            os += CtsApi::to_string(CtsApi::new_log(new_path_));
-            break;
-        case LogCmd::PATH:
-            os += CtsApi::get_log_path();
-            break;
-        default:
-            throw std::runtime_error("LogCmd::print: Unrecognised log api command,");
-    }
-}
-
-bool LogCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<LogCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (api_ != the_rhs->api())
-        return false;
-    if (get_last_n_lines_ != the_rhs->get_last_n_lines())
-        return false;
-    if (new_path_ != the_rhs->new_path())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-// changed for release 4.1.0
-bool LogCmd::isWrite() const {
-    switch (api_) {
-        case LogCmd::GET:
-            return false;
-            break;
-        case LogCmd::CLEAR:
-            return false;
-            break;
-        case LogCmd::FLUSH:
-            return false;
-            break;
-        case LogCmd::NEW:
-            return true;
-            break;
-        case LogCmd::PATH:
-            return false;
-            break;
-        default:
-            throw std::runtime_error("LogCmd::isWrite: Unrecognised log api command,");
-    }
-    return false;
-}
-
-STC_Cmd_ptr LogCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().log_cmd_++;
-
-    switch (api_) {
-        case LogCmd::GET:
-            return PreAllocatedReply::string_cmd(Log::instance()->contents(get_last_n_lines_));
-        case LogCmd::CLEAR:
-            Log::instance()->clear();
-            break;
-        case LogCmd::FLUSH:
-            Log::instance()->flush();
-            break;
-        case LogCmd::NEW: {
-            if (!new_path_.empty()) {
-                Log::instance()->new_path(new_path_); // will throw for errors
-
-                // *NOTE* calling --log=new <path> should be treated the *SAME* as editing ECF_LOG in the GUI
-                //        This is done adding it as a *USER* variable. This overloads the server variables
-                //        It also allows us to see the change in GUI. Note: Defs/server_variables are not synced
-                // ECFLOW-376
-                as->defs()->set_server().add_or_update_user_variables(Str::ECF_LOG(), Log::instance()->path());
-            }
-            else {
-                // User could have overridden ECF_LOG variable
-                // *FIRST* look at user variables, then look at *server* variables.
-                std::string log_file_name = as->defs()->server().find_variable(Str::ECF_LOG());
-
-                // ECFLOW-377 should remove leading/trailing spaces from path
-                ecf::algorithm::trim(log_file_name);
-
-                Log::instance()->new_path(log_file_name); // will throw for errors
-            }
-
-            as->stats().ECF_LOG_ = Log::instance()->path(); // do NOT update number of requests
-            break;
-        }
-        case LogCmd::PATH:
-            return PreAllocatedReply::string_cmd(Log::instance()->path());
-        default:
-            throw std::runtime_error("Unrecognised log api command,");
-    }
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* LogCmd::arg() {
-    return "log";
-}
-const char* LogCmd::desc() {
-    return "Get,clear,flush or create a new log file.\n"
-           "The user must ensure that a valid path is specified.\n"
-           "Specifying '--log=get' with a large number of lines from the server,\n"
-           "can consume a lot of **memory**. The log file can be a very large file,\n"
-           "hence we use a default of 100 lines, optionally the number of lines can be specified.\n"
-           " arg1 = [ get | clear | flush | new | path ]\n"
-           "  get -   Outputs the log file to standard out.\n"
-           "          defaults to return the last 100 lines\n"
-           "          The second argument can specify how many lines to return\n"
-           "  clear - Clear the log file of its contents.\n"
-           "  flush - Flush and close the log file. (only temporary) next time\n"
-           "          server writes to log, it will be opened again. Hence it best\n"
-           "          to halt the server first\n"
-           "  new -   Flush and close the existing log file, and start using the\n"
-           "          the path defined for ECF_LOG. By changing this variable\n"
-           "          a new log file path can be used\n"
-           "          Alternatively an explicit path can also be provided\n"
-           "          in which case ECF_LOG is also updated\n"
-           "  path -  Returns the path name to the existing log file\n"
-           " arg2 = [ new_path | optional last n lines ]\n"
-           "         if get specified can specify lines to get. Value must be convertible to an integer\n"
-           "         Otherwise if arg1 is 'new' then the second argument must be a path\n"
-           "Usage:\n"
-           "  --log=get                        # Write the last 100 lines of the log file to standard out\n"
-           "  --log=get 200                    # Write the last 200 lines of the log file to standard out\n"
-           "  --log=clear                      # Clear the log file. The log is now empty\n"
-           "  --log=flush                      # Flush and close log file, next request will re-open log file\n"
-           "  --log=new /path/to/new/log/file  # Close and flush log file, and create a new log file, updates ECF_LOG\n"
-           "  --log=new                        # Close and flush log file, and create a new log file using ECF_LOG "
-           "variable\n";
-}
-
-void LogCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(LogCmd::arg(), po::value<vector<string>>()->multitoken(), LogCmd::desc());
-}
-
-void LogCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(LogCmd::arg(), args);
-
-    if (!args.empty() && args[0] == "get") {
-
-        if (args.size() != 1 && args.size() != 2) {
-            std::stringstream ss;
-            ss << "LogCmd: Please use '--log==get 100' to get the log file contents from the server\n";
-            ss << "optionally an integer can be provide to specify the last number of lines\n";
-            throw std::runtime_error(ss.str());
-        }
-
-        if (args.size() == 1) {
-            // This will retrieve Log::get_last_n_lines_default() lines from the log file.
-            cmd = Cmd_ptr(new LogCmd(LogCmd::GET, Log::get_last_n_lines_default()));
-            return;
-        }
-
-        int value = Log::get_last_n_lines_default();
-        if (args.size() == 2) {
-            try {
-                value = ecf::convert_to<int>(args[1]);
-            }
-            catch (const ecf::bad_conversion&) {
-                throw std::runtime_error("LogCmd: Second argument must be a integer, i.e. --log get 100\n");
-            }
-        }
-
-        cmd = std::make_shared<LogCmd>(LogCmd::GET, value);
-        return;
-    }
-
-    if (!args.empty() && args[0] == "clear") {
-
-        if (args.size() != 1) {
-            std::stringstream ss;
-            ss << "LogCmd: Too many arguments. Please use " << CtsApi::clearLog() << " to clear the log file\n";
-            throw std::runtime_error(ss.str());
-        }
-        cmd = std::make_shared<LogCmd>(LogCmd::CLEAR);
-        return;
-    }
-    if (!args.empty() && args[0] == "flush") {
-
-        if (args.size() != 1) {
-            std::stringstream ss;
-            ss << "LogCmd: Too many arguments. Please use " << CtsApi::flushLog() << " to flush the log file\n";
-            throw std::runtime_error(ss.str());
-        }
-        cmd = std::make_shared<LogCmd>(LogCmd::FLUSH);
-        return;
-    }
-    if (!args.empty() && args[0] == "path") {
-
-        if (args.size() != 1) {
-            std::stringstream ss;
-            ss << "LogCmd: Too many arguments. Please use " << CtsApi::get_log_path() << " to get the log file path\n";
-            throw std::runtime_error(ss.str());
-        }
-        cmd = std::make_shared<LogCmd>(LogCmd::PATH);
-        return;
-    }
-    if (!args.empty() && args[0] == "new") {
-
-        if (args.size() > 2) {
-            std::stringstream ss;
-            ss << "LogCmd: Too many arguments.  Expected --log=new   OR   --log=new /path/to/newlog/file\n";
-            throw std::runtime_error(ss.str());
-        }
-        std::string path;
-        if (args.size() == 2) {
-            path = args[1];
-        }
-        cmd = std::make_shared<LogCmd>(path);
-        return;
-    }
-
-    std::stringstream ss;
-    ss << "LogCmd: The arguments have not been specified correctly\n" << LogCmd::desc();
-    throw std::runtime_error(ss.str());
-}
-
-std::ostream& operator<<(std::ostream& os, const LogCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(LogCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(LogCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/LogCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/LogCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/LogCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/LogCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_LogCmd_HPP
-#define ecflow_base_cts_user_LogCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-/// The LogCmd is paired with SStringCmd
-/// Client---(LogCmd)---->Server-----(SStringCmd)--->client:
-/// When doHandleRequest is called in the server it will return SStringCmd
-/// The SStringCmd is used to transport the log file contents to the client
-class LogCmd final : public UserCmd {
-public:
-    enum LogApi { GET, CLEAR, FLUSH, NEW, PATH };
-    explicit LogCmd(LogApi a,
-                    int get_last_n_lines = 0); // for zero we take default from log. Avoid adding dependency on log.hpp
-    explicit LogCmd(const std::string& path);  // NEW
-    LogCmd();
-
-    LogApi api() const { return api_; }
-    int get_last_n_lines() const { return get_last_n_lines_; }
-    const std::string& new_path() const { return new_path_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    bool isWrite() const override;
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    LogApi api_{LogCmd::GET};
-    int get_last_n_lines_; // default to 100 -> ECFLOW-174
-    std::string new_path_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_), CEREAL_NVP(get_last_n_lines_), CEREAL_NVP(new_path_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const LogCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(LogCmd)
-
-#endif /* ecflow_base_cts_user_LogCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/LogMessageCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/LogMessageCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/LogMessageCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/LogMessageCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,77 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/LogMessageCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-void LogMessageCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::logMsg(msg_));
-}
-void LogMessageCmd::print_only(std::string& os) const {
-    os += CtsApi::logMsg(msg_);
-}
-
-bool LogMessageCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<LogMessageCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (msg_ != the_rhs->msg())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-STC_Cmd_ptr LogMessageCmd::doHandleRequest(AbstractServer* as) const {
-    // ***** No need to log message here, already done via print, in base ****
-    as->update_stats().log_msg_cmd_++;
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* LogMessageCmd::arg() {
-    return CtsApi::logMsgArg();
-}
-const char* LogMessageCmd::desc() {
-    return "Writes the input string to the log file.\n"
-           "  arg1 = string\n"
-           "Usage:\n"
-           "  --msg=\"place me in the log file\"";
-}
-
-void LogMessageCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(LogMessageCmd::arg(), po::value<string>(), LogMessageCmd::desc());
-}
-
-void LogMessageCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
-    string msg = vm[arg()].as<string>();
-    if (ace->debug()) {
-        cout << "  LogMessageCmd::create arg = " << msg << "\n";
-    }
-    cmd = std::make_shared<LogMessageCmd>(msg);
-}
-
-std::ostream& operator<<(std::ostream& os, const LogMessageCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(LogMessageCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(LogMessageCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/LogMessageCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/LogMessageCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/LogMessageCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/LogMessageCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,50 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_LogMessageCmd_HPP
-#define ecflow_base_cts_user_LogMessageCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-/// Simply writes the message to the log file
-class LogMessageCmd final : public UserCmd {
-public:
-    explicit LogMessageCmd(const std::string& msg) : msg_(msg) {}
-    LogMessageCmd() = default;
-
-    const std::string& msg() const { return msg_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    std::string msg_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(msg_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const LogMessageCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(LogMessageCmd)
-
-#endif /* ecflow_base_cts_user_LogMessageCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/MoveCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/MoveCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/MoveCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/MoveCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,203 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/MoveCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/Openssl.hpp"
-    #include "ecflow/base/SslClient.hpp"
-#endif
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-namespace {
-
-/// Class to manage locking: Only unlock if acquired the lock,
-class Lock {
-public:
-    Lock(const std::string& user, AbstractServer* as) : as_(as) { ok_ = as->lock(user); }
-    ~Lock() {
-        if (ok_)
-            as_->unlock();
-    }
-    bool ok() const { return ok_; }
-
-private:
-    bool ok_;
-    AbstractServer* as_;
-};
-
-} // namespace
-
-//=======================================================================================
-
-MoveCmd::MoveCmd(const std::pair<std::string, std::string>& host_port, Node* src, const std::string& dest)
-    : src_node_(src->print(PrintStyle::NET)),
-      src_host_(host_port.first),
-      src_port_(host_port.second),
-      src_path_(src->absNodePath()),
-      dest_(dest) {
-}
-
-MoveCmd::MoveCmd()  = default;
-MoveCmd::~MoveCmd() = default;
-
-bool MoveCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<MoveCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (dest_ != the_rhs->dest()) {
-        return false;
-    }
-    if (src_node_ != the_rhs->src_node()) {
-        return false;
-    }
-    return UserCmd::equals(rhs);
-}
-
-void MoveCmd::print(std::string& os) const {
-    std::string ss;
-    ss += "Plug(Move) source(";
-    ss += src_host_;
-    ss += ":";
-    ss += src_port_;
-    ss += ":";
-    ss += src_path_;
-    ss += ") destination(";
-    ss += dest_;
-    ss += ")";
-    user_cmd(os, ss);
-}
-
-bool MoveCmd::check_source() const {
-    return !src_node_.empty();
-}
-
-STC_Cmd_ptr MoveCmd::doHandleRequest(AbstractServer* as) const {
-    Defs* defs = as->defs().get();
-
-    Lock lock(user(), as);
-    if (!lock.ok()) {
-        std::string errorMsg = "Plug(Move) command failed. User ";
-        errorMsg += as->lockedUser();
-        errorMsg += " already has an exclusive lock";
-        throw std::runtime_error(errorMsg);
-    }
-
-    if (!check_source()) {
-        throw std::runtime_error("Plug(Move) command failed. No source specified");
-    }
-
-    std::string error_msg;
-    node_ptr src_node = Node::create(src_node_, error_msg);
-    if (!error_msg.empty() || !src_node) {
-        throw std::runtime_error("Plug(Move) command failed. Error in source:\n" + error_msg);
-    }
-
-    // destNode can be NULL when we are moving a suite
-    node_ptr destNode;
-    if (!dest_.empty()) {
-
-        destNode = defs->findAbsNode(dest_);
-        if (!destNode.get()) {
-            std::string errorMsg = "Plug(Move) command failed. The destination path ";
-            errorMsg += dest_;
-            errorMsg += " does not exist on server";
-            throw std::runtime_error(errorMsg);
-        }
-    }
-    else {
-        if (!src_node->isSuite()) {
-            throw std::runtime_error("::Destination path can only be empty when moving a whole suite to a new server");
-        }
-    }
-
-    if (destNode.get()) {
-
-        // The destNode containing suite may be in a handle
-        SuiteChanged0 suiteChanged(destNode);
-
-        // If the destination is task, replace with its parent
-        Node* thedestNode = destNode.get();
-        if (thedestNode->isTask())
-            thedestNode = thedestNode->parent();
-
-        // check its ok to add
-        std::string errorMsg;
-        if (!thedestNode->isAddChildOk(src_node.get(), errorMsg)) {
-            std::string msg = "Plug(Move) command failed. ";
-            msg += errorMsg;
-            throw std::runtime_error(msg);
-        }
-
-        // pass ownership
-        if (!thedestNode->addChild(src_node)) {
-            // This should never fail !!!! else we have lost/ and leaked source node !!!!
-            throw std::runtime_error("Fatal error plug(move) command failed. cannot addChild");
-        }
-
-        add_node_for_edit_history(destNode);
-    }
-    else {
-
-        if (!src_node->isSuite())
-            throw std::runtime_error("plug(move): Source node was expected to be a suite");
-
-        // convert node_ptr to suite_ptr
-        suite_ptr the_source_suite = std::dynamic_pointer_cast<Suite>(src_node);
-
-        // The sourceSuite may be in a handle or pre-registered suite
-        SuiteChanged suiteChanged(the_source_suite);
-
-        defs->addSuite(the_source_suite);
-
-        add_node_for_edit_history(the_source_suite);
-    }
-
-    defs->set_most_significant_state();
-
-    // Ownership for src_node has been passed on.
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* MoveCmd::arg() {
-    return "move";
-}
-const char* MoveCmd::desc() {
-    return "The move command is an internal cmd, Called by the plug cmd. Does not appear on public api.";
-}
-
-void MoveCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(MoveCmd::arg(), po::value<vector<string>>()->multitoken(), MoveCmd::desc());
-}
-
-void MoveCmd::create(Cmd_ptr&, boost::program_options::variables_map&, AbstractClientEnv*) const {
-    assert(false);
-}
-
-std::ostream& operator<<(std::ostream& os, const MoveCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(MoveCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(MoveCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/MoveCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/MoveCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/MoveCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/MoveCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,67 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_MoveCmd_HPP
-#define ecflow_base_cts_user_MoveCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-class MoveCmd final : public UserCmd {
-public:
-    MoveCmd(const std::pair<std::string, std::string>& host_port, Node* src, const std::string& dest);
-    MoveCmd();
-    ~MoveCmd() override;
-
-    Node* source() const;
-    const std::string& src_node() const { return src_node_; }
-    const std::string& dest() const { return dest_; }
-
-    bool handleRequestIsTestable() const override { return false; }
-    bool isWrite() const override { return true; }
-
-    void print(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    bool check_source() const;
-
-private:
-    std::string src_node_;
-    std::string src_host_;
-    std::string src_port_;
-    std::string src_path_;
-    std::string dest_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(src_node_),
-           CEREAL_NVP(src_host_),
-           CEREAL_NVP(src_port_),
-           CEREAL_NVP(src_path_),
-           CEREAL_NVP(dest_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const MoveCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(MoveCmd)
-
-#endif /* ecflow_base_cts_user_MoveCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,130 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool OrderNodeCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<OrderNodeCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (absNodepath_ != the_rhs->absNodepath())
-        return false;
-    if (option_ != the_rhs->option())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-void OrderNodeCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::order(absNodepath_, NOrder::toString(option_))));
-}
-void OrderNodeCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::order(absNodepath_, NOrder::toString(option_)));
-}
-
-STC_Cmd_ptr OrderNodeCmd::doHandleRequest(AbstractServer* as) const {
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-
-    as->update_stats().order_node_++;
-
-    Defs* defs       = as->defs().get();
-    node_ptr theNode = find_node_for_edit(defs, absNodepath_);
-
-    Node* theParent = theNode->parent();
-    if (theParent)
-        theParent->order(theNode.get(), option_);
-    else
-        defs->order(theNode.get(), option_);
-
-    return doJobSubmission(as);
-}
-
-bool OrderNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, absNodepath_);
-}
-
-const char* OrderNodeCmd::arg() {
-    return CtsApi::orderArg();
-}
-const char* OrderNodeCmd::desc() {
-    return "Re-orders the nodes held by the server\n"
-           "  arg1 = node path\n"
-           "  arg2 = [ top | bottom | alpha | order | up | down | runtime]\n"
-           "It should be noted that in the absence of triggers and time/date dependencies,\n"
-           "the tasks are submitted in order.\n"
-           "This changes the order and hence affects the submission order::\n\n"
-           "   o top     raises the node within its parent, so that it is first\n"
-           "   o bottom  lowers the node within its parent, so that it is last\n"
-           "   o alpha   Arranges for all the peers of selected note to be sorted alphabetically (case-insensitive)\n"
-           "   o order   Arranges for all the peers of selected note to be sorted in reverse "
-           "alphabet(case-insensitive)\n"
-           "   o up      Moves the selected node up one place amongst its peers\n"
-           "   o down    Moves the selected node down one place amongst its peers\n\n"
-           "   o runtime Orders the nodes according to state change runtime\n"
-           "             for families by accumulated runtime of its children\n"
-           "             useful to submit the task that take longer earlier\n\n"
-           "This command can fail because:\n"
-           "- The node path does not exist in the server\n"
-           "- The order_type is not does not match one of arg2\n"
-           "Usage:\n"
-           "  --order=/suite/f1 top  # move node f1 to the top";
-}
-
-void OrderNodeCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(OrderNodeCmd::arg(), po::value<vector<string>>()->multitoken(), OrderNodeCmd::desc());
-}
-void OrderNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[OrderNodeCmd::arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(OrderNodeCmd::arg(), args);
-
-    if (args.size() != 2) {
-        std::stringstream ss;
-        ss << "OrderNodeCmd: Two arguments expected. Please specify one of:\n";
-        ss << OrderNodeCmd::arg() << " pathToNode top\n";
-        ss << OrderNodeCmd::arg() << " pathToNode bottom\n";
-        ss << OrderNodeCmd::arg() << " pathToNode alpha\n";
-        ss << OrderNodeCmd::arg() << " pathToNode order\n";
-        ss << OrderNodeCmd::arg() << " pathToNode up\n";
-        ss << OrderNodeCmd::arg() << " pathToNode down\n";
-        ss << OrderNodeCmd::arg() << " pathToNode runtime\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (!NOrder::isValid(args[1])) {
-        throw std::runtime_error("OrderNodeCmd: Invalid second option: please specify one of [ top, bottom, alpha, "
-                                 "order, up, down, runtime]\n");
-    }
-
-    cmd = std::make_shared<OrderNodeCmd>(args[0], NOrder::toOrder(args[1]));
-}
-
-std::ostream& operator<<(std::ostream& os, const OrderNodeCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(OrderNodeCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(OrderNodeCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/OrderNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_OrderNodeCmd_HPP
-#define ecflow_base_cts_user_OrderNodeCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-#include "ecflow/core/NOrder.hpp"
-
-class OrderNodeCmd final : public UserCmd {
-public:
-    OrderNodeCmd(const std::string& absNodepath, NOrder::Order op) : absNodepath_(absNodepath), option_(op) {}
-    OrderNodeCmd() = default;
-
-    const std::string& absNodepath() const { return absNodepath_; }
-    NOrder::Order option() const { return option_; }
-
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-
-private:
-    std::string absNodepath_;
-    NOrder::Order option_{NOrder::TOP};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(absNodepath_), CEREAL_NVP(option_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const OrderNodeCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(OrderNodeCmd)
-
-#endif /* ecflow_base_cts_user_OrderNodeCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/PathsCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/PathsCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/PathsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/PathsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,689 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-
-#include <algorithm>
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/cts/user/DeleteCmd.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-PathsCmd::PathsCmd(Api api, const std::string& absNodePath, bool force) : api_(api), force_(force) {
-    if (!absNodePath.empty())
-        paths_.push_back(absNodePath);
-}
-
-void PathsCmd::print(std::string& os) const {
-    my_print(os, paths_);
-}
-
-std::string PathsCmd::print_short() const {
-    std::vector<std::string> paths;
-    if (!paths_.empty())
-        paths.emplace_back(paths_[0]);
-
-    std::string os;
-    my_print_only(os, paths);
-    if (paths_.size() > 1) {
-        os += " : truncated : ";
-        os += ecf::convert_to<std::string>(paths_.size() - 1);
-        os += " paths *not* shown";
-    }
-    return os;
-}
-
-void PathsCmd::print_only(std::string& os) const {
-    my_print_only(os, paths_);
-}
-
-void PathsCmd::print(std::string& os, const std::string& path) const {
-    std::vector<std::string> paths(1, path);
-    my_print(os, paths);
-}
-
-void PathsCmd::my_print(std::string& os, const std::vector<std::string>& paths) const {
-    switch (api_) {
-        case PathsCmd::SUSPEND:
-            user_cmd(os, CtsApi::to_string(CtsApi::suspend(paths)));
-            break;
-        case PathsCmd::RESUME:
-            user_cmd(os, CtsApi::to_string(CtsApi::resume(paths)));
-            break;
-        case PathsCmd::KILL:
-            user_cmd(os, CtsApi::to_string(CtsApi::kill(paths)));
-            break;
-        case PathsCmd::STATUS:
-            user_cmd(os, CtsApi::to_string(CtsApi::status(paths)));
-            break;
-        case PathsCmd::CHECK:
-            user_cmd(os, CtsApi::to_string(CtsApi::check(paths)));
-            break;
-        case PathsCmd::EDIT_HISTORY:
-            user_cmd(os, CtsApi::to_string(CtsApi::edit_history(paths)));
-            break;
-        case PathsCmd::ARCHIVE:
-            user_cmd(os, CtsApi::to_string(CtsApi::archive(paths, force_)));
-            break;
-        case PathsCmd::RESTORE:
-            user_cmd(os, CtsApi::to_string(CtsApi::restore(paths)));
-            break;
-        case PathsCmd::NO_CMD:
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-void PathsCmd::my_print_only(std::string& os, const std::vector<std::string>& paths) const {
-    switch (api_) {
-        case PathsCmd::SUSPEND:
-            os += CtsApi::to_string(CtsApi::suspend(paths));
-            break;
-        case PathsCmd::RESUME:
-            os += CtsApi::to_string(CtsApi::resume(paths));
-            break;
-        case PathsCmd::KILL:
-            os += CtsApi::to_string(CtsApi::kill(paths));
-            break;
-        case PathsCmd::STATUS:
-            os += CtsApi::to_string(CtsApi::status(paths));
-            break;
-        case PathsCmd::CHECK:
-            os += CtsApi::to_string(CtsApi::check(paths));
-            break;
-        case PathsCmd::EDIT_HISTORY:
-            os += CtsApi::to_string(CtsApi::edit_history(paths));
-            break;
-        case PathsCmd::ARCHIVE:
-            os += CtsApi::to_string(CtsApi::archive(paths, force_));
-            break;
-        case PathsCmd::RESTORE:
-            os += CtsApi::to_string(CtsApi::restore(paths));
-            break;
-        case PathsCmd::NO_CMD:
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-
-bool PathsCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<PathsCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (api_ != the_rhs->api())
-        return false;
-    if (paths_ != the_rhs->paths())
-        return false;
-    if (force_ != the_rhs->force())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-bool PathsCmd::isWrite() const {
-    switch (api_) {
-        case PathsCmd::SUSPEND:
-            return true;
-            break; // requires write privilege
-        case PathsCmd::RESUME:
-            return true;
-            break; // requires write privilege
-        case PathsCmd::KILL:
-            return true;
-            break; // requires write privilege, modifies Flag::KILLCMD_FAILED
-        case PathsCmd::STATUS:
-            return true;
-            break; // requires write privilege, modifies Flag::STATUSCMD_FAILED
-        case PathsCmd::CHECK:
-            return false;
-            break; // read only
-        case PathsCmd::EDIT_HISTORY: {
-            if (paths_.size() == 1 && paths_[0] == "clear")
-                return true; // requires write privilege
-            return false;
-            break; // read only
-        }
-        case PathsCmd::ARCHIVE:
-            return true;
-            break; // requires write privilege
-        case PathsCmd::RESTORE:
-            return true;
-            break; // requires write privilege
-        case PathsCmd::NO_CMD:
-            break;
-        default:
-            break;
-    }
-    assert(false);
-    return false;
-}
-
-const char* PathsCmd::theArg() const {
-    switch (api_) {
-        case PathsCmd::SUSPEND:
-            return CtsApi::suspend_arg();
-            break;
-        case PathsCmd::RESUME:
-            return CtsApi::resume_arg();
-            break;
-        case PathsCmd::KILL:
-            return CtsApi::kill_arg();
-            break;
-        case PathsCmd::STATUS:
-            return CtsApi::statusArg();
-            break;
-        case PathsCmd::CHECK:
-            return CtsApi::check_arg();
-            break;
-        case PathsCmd::EDIT_HISTORY:
-            return CtsApi::edit_history_arg();
-            break;
-        case PathsCmd::ARCHIVE:
-            return CtsApi::archive_arg();
-            break;
-        case PathsCmd::RESTORE:
-            return CtsApi::restore_arg();
-            break;
-        case PathsCmd::NO_CMD:
-            break;
-        default:
-            break;
-    }
-    assert(false);
-    return nullptr;
-}
-
-STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
-    // LogTimer timer(" PathsCmd::doHandleRequest");
-
-    Defs* defs = as->defs().get();
-    std::stringstream ss;
-    switch (api_) {
-
-        case PathsCmd::SUSPEND: {
-            use_EditHistoryMgr_ =
-                false; // will add edit history ourselves. Quicker than EditHistoryMgr when we have > 200000 paths
-
-            as->update_stats().node_suspend_++;
-            for (const auto& path : paths_) {
-                node_ptr theNode = defs->findAbsNode(path);
-                if (!theNode.get()) {
-                    ss << "PathsCmd:Suspend: Could not find node at path '" << path << "'\n";
-                    LOG(Log::ERR, "Suspend: Could not find node at path " << path);
-                    continue;
-                }
-                SuiteChangedPtr changed(theNode.get());
-                theNode->suspend();
-                theNode->flag().set(ecf::Flag::MESSAGE);
-                add_edit_history(defs, path);
-                assert(isWrite()); // should only add edit history for write-able commands
-            }
-            break;
-        }
-
-        case PathsCmd::RESUME: {
-            use_EditHistoryMgr_ =
-                false; // will add edit history ourselves. Quicker than EditHistoryMgr when we have > 200000 paths
-
-            // At the end of resume, we need to traverse node tree, and do job submission
-            as->update_stats().node_resume_++;
-            for (const auto& path : paths_) {
-                node_ptr theNode = defs->findAbsNode(path);
-                if (!theNode.get()) {
-                    ss << "PathsCmd:Resume: Could not find node at path '" << path << "'\n";
-                    LOG(Log::ERR, "Resume: Could not find path " << path);
-                    continue;
-                }
-                SuiteChangedPtr changed(theNode.get());
-                theNode->resume();
-                theNode->flag().set(ecf::Flag::MESSAGE);
-                add_edit_history(defs, path);
-                assert(isWrite()); // should only add edit history for write-able commands
-
-                as->increment_job_generation_count(); // in case we throw below
-            }
-            break;
-        }
-
-        case PathsCmd::KILL: {
-            as->update_stats().node_kill_++;
-            for (const auto& path : paths_) {
-                node_ptr theNode = find_node_for_edit_no_throw(defs, path);
-                if (!theNode.get()) {
-                    ss << "PathsCmd:Kill: Could not find node at path '" << path << "'\n";
-                    LOG(Log::ERR, "Kill: Could not find node at path " << path);
-                    continue;
-                }
-                SuiteChanged0 changed(theNode);
-                theNode->kill(); // this can throw std::runtime_error
-            }
-            break;
-        }
-
-        case PathsCmd::EDIT_HISTORY: {
-            as->update_stats().node_edit_history_++;
-            if (paths_.empty())
-                throw std::runtime_error("No paths/options specified for edit history");
-            if (paths_.size() == 1 && paths_[0] == "clear") {
-                defs->clear_edit_history();
-                break;
-            }
-            // Only first path used
-            return PreAllocatedReply::string_vec_cmd(as->defs()->get_edit_history(paths_[0]));
-        }
-
-        case PathsCmd::ARCHIVE: {
-            use_EditHistoryMgr_ = false; // will add edit history ourselves
-
-            as->update_stats().node_archive_++;
-            if (paths_.empty())
-                throw std::runtime_error("No paths specified for archive");
-
-            // make sure paths don't overlap, Should not find same path up the hierarchy, which is also in paths_
-            std::vector<NodeContainer*> containers_to_archive;
-            containers_to_archive.reserve(paths_.size());
-            for (const auto& path : paths_) {
-                node_ptr theNode = defs->findAbsNode(path);
-                if (!theNode.get()) {
-                    ss << "PathsCmd:ARCHIVE: Could not find node at path '" << path << "'\n";
-                    LOG(Log::ERR, "ARCHIVE: Could not find node at path " << path);
-                    continue;
-                }
-                NodeContainer* container = theNode->isNodeContainer();
-                if (!container)
-                    continue;
-
-                bool unique  = true;
-                Node* parent = theNode->parent();
-                while (parent) {
-                    std::string abs_node_path = parent->absNodePath();
-                    if (find(paths_.begin(), paths_.end(), abs_node_path) != paths_.end()) {
-                        unique = false;
-                        break; // parent also in paths, so don't archive child
-                    }
-                    parent = parent->parent();
-                }
-                if (unique)
-                    containers_to_archive.push_back(container);
-            }
-
-            size_t vec_size = containers_to_archive.size();
-            for (size_t i = 0; i < vec_size; i++) {
-                NodeContainer* the_container = containers_to_archive[i];
-
-                if (!force_)
-                    DeleteCmd::check_for_active_or_submitted_tasks(as, the_container);
-                else
-                    as->zombie_ctrl().add_user_zombies(the_container, CtsApi::archive_arg());
-
-                SuiteChanged1 changed(the_container->suite());
-
-                the_container->flag().set(ecf::Flag::MESSAGE);
-                add_edit_history(defs, the_container->absNodePath());
-                assert(isWrite()); // should only add edit history for write-able commands
-
-                the_container->archive(); // this can throw std::runtime_error
-            }
-            break;
-        }
-
-        case PathsCmd::RESTORE: {
-            as->update_stats().node_restore_++;
-            if (paths_.empty())
-                throw std::runtime_error("No paths specified for restore");
-            for (const auto& path : paths_) {
-                node_ptr theNode = find_node_for_edit_no_throw(defs, path);
-                if (!theNode.get()) {
-                    ss << "PathsCmd:RESTORE: Could not find node at path '" << path << "'\n";
-                    LOG(Log::ERR, "RESTORE: Could not find node at path " << path);
-                    continue;
-                }
-                NodeContainer* container = theNode->isNodeContainer();
-                if (!container)
-                    continue;
-
-                SuiteChanged1 changed(container->suite());
-                container->restore(); // this can throw std::runtime_error
-            }
-            break;
-        }
-
-        case PathsCmd::STATUS: {
-            as->update_stats().node_status_++;
-            for (const auto& path : paths_) {
-                node_ptr theNode = find_node_for_edit_no_throw(defs, path);
-                if (!theNode.get()) {
-                    ss << "PathsCmd:Status: Could not find node at path '" << path << "'\n";
-                    LOG(Log::ERR, "Status: Could not find node at path " << path);
-                    continue;
-                }
-                if (!theNode->suite()->begun()) {
-                    std::stringstream mss;
-                    mss << "Status failed. For " << path << " The suite " << theNode->suite()->name()
-                        << " must be 'begun' first\n";
-                    throw std::runtime_error(mss.str());
-                }
-                SuiteChangedPtr changed(theNode.get());
-                theNode->status(); // this can throw std::runtime_error
-            }
-            break;
-        }
-
-        case PathsCmd::CHECK: {
-            as->update_stats().check_++;
-
-            if (paths_.empty()) {
-                // check all the defs,
-                std::string error_msg, warning_msg;
-                if (!defs->check(error_msg, warning_msg)) {
-                    error_msg += "\n";
-                    error_msg += warning_msg;
-                    return PreAllocatedReply::string_cmd(error_msg);
-                }
-                return PreAllocatedReply::string_cmd(warning_msg); // can be empty
-            }
-            else {
-                std::string acc_warning_msg;
-                for (const auto& path : paths_) {
-
-                    node_ptr theNodeToCheck = defs->findAbsNode(path);
-                    if (!theNodeToCheck.get()) {
-                        ss << "PathsCmd:Check: Could not find node at path '" << path << "'\n";
-                        LOG(Log::ERR, "Check: Could not find node at path " << path);
-                        continue;
-                    }
-
-                    std::string error_msg, warning_msg;
-                    if (!theNodeToCheck->check(error_msg, warning_msg)) {
-                        error_msg += "\n";
-                        error_msg += warning_msg;
-                        return PreAllocatedReply::string_cmd(error_msg);
-                    }
-                    acc_warning_msg += warning_msg;
-                }
-                std::string paths_not_fnd_error_msg = ss.str();
-                if (!paths_not_fnd_error_msg.empty())
-                    throw std::runtime_error(paths_not_fnd_error_msg);
-                return PreAllocatedReply::string_cmd(acc_warning_msg);
-            }
-            break;
-        }
-
-        case PathsCmd::NO_CMD:
-            assert(false);
-            break;
-
-        default:
-            assert(false);
-            break;
-    }
-
-    std::string error_msg = ss.str();
-    if (!error_msg.empty()) {
-        throw std::runtime_error(error_msg);
-    }
-
-    if (PathsCmd::RESUME == api_) {
-        // After resume we need to do job submission.
-        return doJobSubmission(as);
-    }
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-bool PathsCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
-
-static const char* get_check_desc() {
-    return "Checks the expression and limits in the server. Will also check trigger references.\n"
-           "Trigger expressions that reference paths that don't exist, will be reported as errors.\n"
-           "(Note: On the client side unresolved paths in trigger expressions must\n"
-           "have an associated 'extern' specified)\n"
-           "  arg = [ _all_ | / | list of node paths ]\n"
-           "Usage:\n"
-           "  --check=_all_           # Checks all the suites\n"
-           "  --check=/               # Checks all the suites\n"
-           "  --check=/s1 /s2/f1/t1   # Check suite /s1 and task t1";
-}
-
-static const char* get_kill_desc() {
-    return "Kills the job associated with the node.\n"
-           "If a family or suite is selected, will kill hierarchically.\n"
-           "Kill uses the ECF_KILL_CMD variable. After variable substitution it is invoked as a command.\n"
-           "The command should be written in such a way that the output is written to %ECF_JOB%.kill\n"
-           "as this allow the --file command to report the output: .e.e.\n"
-           " /home/ma/emos/bin/ecfkill %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1::\n"
-           "Usage::\n"
-           "   --kill=/s1/f1/t1 /s1/f2/t2 # kill the jobs for tasks t1 and t2\n"
-           "   --file=/s1/f1/t1 kill      # write to standard out the '.kill' file for task /s1/f1/t1";
-}
-const char* get_status_desc() {
-    return "Shows the status of a job associated with a task, in %ECF_JOB%.stat file\n"
-           "If a family or suite is selected, will invoke status command hierarchically.\n"
-           "Status uses the ECF_STATUS_CMD variable. After variable substitution it is invoked as a command.\n"
-           "The command should be written in such a way that the output is written to %ECF_JOB%.stat\n"
-           "This will allow the output of status command to be shown by the --file command\n"
-           "i.e /home/ma/emos/bin/ecfstatus  %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.stat 2>&1::\n"
-           "If the process id cannot be found on the remote system, then the status command can also\n"
-           "arrange for the task to be aborted\n"
-           "The status command can fail for the following reasons:\n"
-           " - ECF_STATUS_CMD not found\n"
-           " - variable substitution fails\n"
-           " - state is active but it can't find process id, i.e. ECF_RID\n"
-           " - the status command does not exit cleanly\n"
-           "When this happens a flag is set, STATUSCMD_FAILED, which is visible in the GUI\n"
-           "Usage::\n"
-           "   --status=/s1/f1/t1     # ECF_STATUS_CMD should output to %ECF_JOB%.stat\n"
-           "   --file=/s1/f1/t1 stat  # Return contents of %ECF_JOB%.stat file";
-}
-const char* get_edit_history_desc() {
-    return "Returns the edit history associated with a Node.\n"
-           "Can also be used to clear the edit history.\n"
-           "Usage::\n"
-           "   --edit_history=/s1/f1/t1  # return history of changes for the given node\n"
-           "   --edit_history=clear      # clear/purge *ALL* edit history from all nodes.\n";
-}
-const char* suspend_desc() {
-    return "Suspend the given node. This prevents job generation for the given node, or any child node.\n"
-           "Usage::\n"
-           "   --suspend=/s1/f1/t1   # suspend task s1/f1/t1\n"
-           "   --suspend=/s1 /s2     # suspend suites /s1 and /s2\n";
-}
-const char* resume_desc() {
-    return "Resume the given node. This allows job generation for the given node, or any child node.\n"
-           "Usage::\n"
-           "   --resume=/s1/f1/t1   # resume task s1/f1/t1\n"
-           "   --resume=/s1 /s2     # resume suites /s1 and /s2\n";
-}
-const char* archive_desc() {
-    return "Archives suite or family nodes *IF* they have child nodes(otherwise does nothing).\n"
-           "Saves the suite/family nodes to disk, and then removes the child nodes from the definition.\n"
-           "This saves memory in the server, when dealing with huge definitions that are not needed.\n"
-           "It improves time taken to checkpoint and reduces network bandwidth.\n"
-           "If the node is re-queued or begun, the child nodes are automatically restored.\n"
-           "Use --restore to reload the archived nodes manually\n"
-           "Care must be taken if you have trigger reference to the archived nodes\n"
-           "The nodes are saved to the file ECF_HOME/<hostname>.<port>.<ECF_NAME>.check,\n"
-           "where '/' has been replaced with ':' in ECF_NAME\n\n"
-           "Nodes like (family and suites) can also to automatically archived by using,\n"
-           "the 'autoarchive' attribute. The attribute is only applied once the node is complete\n\n"
-           "suite autoarchive\n"
-           " family f1\n"
-           "    autoarchive +01:00 # archive one hour after complete\n"
-           "    task t1\n"
-           " endfamily\n"
-           " family f2\n"
-           "     autoarchive 01:00 # archive at 1 am in morning after complete\n"
-           "    task t1\n"
-           " endfamily\n"
-           " family f3\n"
-           "    autoarchive 10     # archive 10 days after complete\n"
-           "    task t1\n"
-           " endfamily\n"
-           " family f4\n"
-           "    autoarchive 0      # archive immediately (upto 60s) after complete\n"
-           "    task t1\n"
-           "  endfamily\n"
-           "endsuite\n"
-           "\n"
-           "Usage::\n"
-           "   --archive=/s1           # archive suite s1\n"
-           "   --archive=/s1/f1 /s2    # archive family /s1/f1 and suite /s2\n"
-           "   --archive=force /s1 /s2 # archive suites /s1,/s2 even if they have active tasks";
-}
-const char* restore_desc() {
-    return "Manually restore archived nodes.\n"
-           "Restore will fail if:\n"
-           "  - Node has not been archived\n"
-           "  - Node has children, (since archived nodes have no children)\n"
-           "  - If the file ECF_HOME/<host>.<port>.<ECF_NAME>.check does not exist\n"
-           "Nodes can be restored manually(as in this command) but also automatically\n\n"
-           "Automatic restore is done using the 'autorestore' attribute.\n"
-           "Once the node containing the 'autorestore' completes, the attribute is applied\n\n"
-           " suite s\n"
-           "   family farchive_now\n"
-           "     autoarchive 0      # archive immediately after complete\n"
-           "     task tx\n"
-           "   endfamily\n"
-           "   family frestore_from_task\n"
-           "     task t1\n"
-           "        trigger ../farchive_now<flag>archived\n"
-           "        autorestore ../farchive_now  # call autorestore when t1 completes\n"
-           "   endfamily\n"
-           " endsuite\n\n"
-           "In this example task '/s/frestore_from_task/t1' is only triggered if 'farchive_now'\n"
-           "is archived, then when t1 completes it will restore family 'farchive_now'\n"
-           "Usage::\n"
-           "   --restore=/s1/f1   # restore family /s1/f1\n"
-           "   --restore=/s1 /s2  # restore suites /s1 and /s2";
-}
-
-void PathsCmd::addOption(boost::program_options::options_description& desc) const {
-    switch (api_) {
-        case PathsCmd::CHECK: {
-            desc.add_options()(CtsApi::check_arg(), po::value<vector<string>>()->multitoken(), get_check_desc());
-            break;
-        }
-        case PathsCmd::SUSPEND: {
-            desc.add_options()(CtsApi::suspend_arg(), po::value<vector<string>>()->multitoken(), suspend_desc());
-            break;
-        }
-        case PathsCmd::RESUME: {
-            desc.add_options()(CtsApi::resume_arg(), po::value<vector<string>>()->multitoken(), resume_desc());
-            break;
-        }
-        case PathsCmd::KILL: {
-            desc.add_options()(CtsApi::kill_arg(), po::value<vector<string>>()->multitoken(), get_kill_desc());
-            break;
-        }
-        case PathsCmd::STATUS: {
-            desc.add_options()(CtsApi::statusArg(), po::value<vector<string>>()->multitoken(), get_status_desc());
-            break;
-        }
-        case PathsCmd::EDIT_HISTORY: {
-            desc.add_options()(
-                CtsApi::edit_history_arg(), po::value<vector<string>>()->multitoken(), get_edit_history_desc());
-            break;
-        }
-        case PathsCmd::ARCHIVE: {
-            desc.add_options()(CtsApi::archive_arg(), po::value<vector<string>>()->multitoken(), archive_desc());
-            break;
-        }
-        case PathsCmd::RESTORE: {
-            desc.add_options()(CtsApi::restore_arg(), po::value<vector<string>>()->multitoken(), restore_desc());
-            break;
-        }
-        case PathsCmd::NO_CMD:
-            assert(false);
-            break;
-        default:
-            assert(false);
-            break;
-    }
-}
-
-void PathsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    assert(api_ != PathsCmd::NO_CMD);
-
-    vector<string> args = vm[theArg()].as<vector<string>>();
-    if (ac->debug())
-        dumpVecArgs(theArg(), args);
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
-
-    bool force = false;
-    if (api_ == PathsCmd::CHECK) {
-
-        bool all        = false;
-        size_t vec_size = options.size();
-        for (size_t i = 0; i < vec_size; i++) {
-            if (args[i] == "_all_")
-                all = true;
-        }
-        if (!all && paths.empty()) {
-            std::stringstream ss;
-            ss << "Check: Please specify one of [ _all_ | / | /<path/to/anode> ]. Paths must begin with a leading '/' "
-                  "character\n";
-            throw std::runtime_error(ss.str());
-        }
-        if (paths.size() == 1 && paths[0] == "/") {
-            // treat as _all_
-            paths.clear();
-        }
-    }
-    else if (api_ == PathsCmd::EDIT_HISTORY) {
-
-        if (paths.empty()) {
-            if (options.size() == 1 && options[0] == "clear")
-                paths.emplace_back("clear");
-            else {
-                std::stringstream ss;
-                ss << theArg() << ":  No paths or option specified. Paths must begin with a leading '/' character\n";
-                throw std::runtime_error(ss.str());
-            }
-        }
-    }
-    else {
-        if (paths.empty()) {
-            std::stringstream ss;
-            ss << theArg() << ":  No paths specified. Paths must begin with a leading '/' character\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    cmd = std::make_shared<PathsCmd>(api_, paths, force);
-}
-
-std::ostream& operator<<(std::ostream& os, const PathsCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(PathsCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(PathsCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/PathsCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/PathsCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/PathsCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/PathsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_PathsCmd_HPP
-#define ecflow_base_cts_user_PathsCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// DELETE If paths_ empty will delete all suites (beware) else will delete the chosen nodes.
-class PathsCmd final : public UserCmd {
-public:
-    enum Api { NO_CMD, SUSPEND, RESUME, KILL, STATUS, CHECK, EDIT_HISTORY, ARCHIVE, RESTORE };
-
-    PathsCmd(Api api, const std::vector<std::string>& paths, bool force = false)
-        : api_(api),
-          paths_(paths),
-          force_(force) {}
-    PathsCmd(Api api, const std::string& absNodePath, bool force = false);
-    explicit PathsCmd(Api api) : api_(api) { assert(api != NO_CMD); }
-    PathsCmd() = default;
-
-    Api api() const { return api_; }
-    const std::vector<std::string>& paths() const { return paths_; }
-    bool force() const { return force_; }
-
-    void print(std::string&) const override;
-    std::string print_short() const override;
-    void print_only(std::string&) const override;
-    void print(std::string& os, const std::string& path) const override;
-
-    bool equals(ClientToServerCmd*) const override;
-    bool isWrite() const override;
-
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after handlerequest
-
-    void my_print(std::string& os, const std::vector<std::string>& paths) const;
-    void my_print_only(std::string& os, const std::vector<std::string>& paths) const;
-
-private:
-    Api api_{NO_CMD};
-    std::vector<std::string> paths_;
-    bool force_{false};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_), CEREAL_NVP(paths_), CEREAL_NVP(force_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const PathsCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(PathsCmd)
-
-#endif /* ecflow_base_cts_user_PathsCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/PlugCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/PlugCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/PlugCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/PlugCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,302 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/PlugCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/Client.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/cts/user/MoveCmd.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/NodePath.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/Openssl.hpp"
-    #include "ecflow/base/SslClient.hpp"
-#endif
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-namespace {
-
-/// Class to manage locking: Only unlock if acquired the lock,
-class Lock {
-public:
-    Lock(const std::string& user, AbstractServer* as) : as_(as) { ok_ = as->lock(user); }
-    ~Lock() {
-        if (ok_)
-            as_->unlock();
-    }
-    bool ok() const { return ok_; }
-
-private:
-    bool ok_;
-    AbstractServer* as_;
-};
-
-static void restore(NodeContainer* container) {
-    if (container && container->get_flag().is_set(ecf::Flag::ARCHIVED)) {
-        container->restore();
-        std::vector<family_ptr> family_vec = container->familyVec();
-        for (family_ptr node : family_vec) {
-            restore(node->isNodeContainer());
-        }
-    }
-}
-
-} // namespace
-
-//=======================================================================================
-
-bool PlugCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<PlugCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (source_ != the_rhs->source()) {
-        return false;
-    }
-    if (dest_ != the_rhs->dest()) {
-        return false;
-    }
-    return UserCmd::equals(rhs);
-}
-
-void PlugCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::plug(source_, dest_)));
-}
-
-void PlugCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::plug(source_, dest_));
-}
-
-STC_Cmd_ptr PlugCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().plug_++;
-    Defs* defs = as->defs().get();
-
-    Lock lock(user(), as);
-    if (!lock.ok()) {
-        std::string errorMsg = "Plug command failed. User ";
-        errorMsg += as->lockedUser();
-        errorMsg += " already has an exclusive lock";
-        throw std::runtime_error(errorMsg);
-    }
-
-    node_ptr sourceNode = defs->findAbsNode(source_);
-    if (!sourceNode.get())
-        throw std::runtime_error("Plug command failed. Could not find source path " + source_);
-
-    // Moving a node which is active, or submitted, will lead to zombie's. hence prevent
-    if (sourceNode->state() == NState::ACTIVE || sourceNode->state() == NState::SUBMITTED) {
-        std::string errorMsg = "Plug command failed. The source node ";
-        errorMsg += source_;
-        errorMsg += " is ";
-        errorMsg += NState::toString(sourceNode->state());
-        throw std::runtime_error(errorMsg);
-    }
-
-    if (sourceNode->isAlias()) {
-        std::string errorMsg = "Plug command failed. The source node ";
-        errorMsg += source_;
-        errorMsg += " is a Alias. Alias cannot be moved";
-        throw std::runtime_error(errorMsg);
-    }
-
-    // If the source node or *any* of its children are archived restore them first.
-    // Must be done in a top down manner.
-    restore(sourceNode->isNodeContainer());
-
-    // Check to see if dest node is on the same server
-    std::string host, port, destPath;
-    node_ptr destNode = defs->findAbsNode(dest_);
-    if (!destNode.get()) {
-
-        // Dest could still be on the same server. Extract host and port
-        // expect: host:port/suite/family/node
-        if (!NodePath::extractHostPort(dest_, host, port)) {
-            std::string errorMsg = "Plug command failed. The destination path ";
-            errorMsg += dest_;
-            errorMsg += " does not exist on server, and could not extract host/port from the destination path";
-            throw std::runtime_error(errorMsg);
-        }
-
-        // Remove the host:port from the path
-        destPath = NodePath::removeHostPortFromPath(dest_);
-
-        std::pair<std::string, std::string> hostPortPair = as->hostPort();
-        if ((hostPortPair.first == host || host == "localhost") && hostPortPair.second == port) {
-
-            // Matches local server, try to find dest node again.
-            destNode = defs->findAbsNode(destPath);
-            if (!destNode) {
-                std::string errorMsg = "Plug command failed. The destination path ";
-                errorMsg += dest_;
-                errorMsg += " does not exist on server ";
-                errorMsg += hostPortPair.first;
-                throw std::runtime_error(errorMsg);
-            }
-        }
-        // dest_ is on another server.
-    }
-
-    if (!destNode.get()) {
-
-        // Since host/port does not match local server, move source node to remote server
-        try {
-            if (destPath.empty()) {
-                // Note destPath can be empty, when moving a suite
-                if (!sourceNode->isSuite()) {
-                    throw std::runtime_error(
-                        "Destination path can only be empty when moving a whole suite to a new server");
-                }
-            }
-
-            {
-                // MoveCmd should inherit user and passwd, from PlugCmd
-                Cmd_ptr cts_cmd = Cmd_ptr(new MoveCmd(as->hostPort(), sourceNode.get(), destPath));
-                cts_cmd->setup_user_authentification(user(), passwd());
-
-                // Server is acting like a client, Send MoveCmd to another server
-                // The source should end up being copied, when sent to remote server
-                ServerReply server_reply;
-                boost::asio::io_service io_service;
-#ifdef ECF_OPENSSL
-                if (!as->ssl().empty()) {
-                    ecf::Openssl openssl;
-                    if (!openssl.enable_no_throw(host, port, as->ssl()))
-                        throw std::runtime_error("PlugCmd::doHandleRequest Could not enable ssl for " + as->ssl());
-                    openssl.init_for_client();
-
-                    SslClient theClient(io_service, openssl.context(), cts_cmd, host, port);
-                    io_service.run();
-                    theClient.handle_server_response(server_reply, false /* debug */);
-                    if (server_reply.client_request_failed()) {
-                        throw std::runtime_error(server_reply.error_msg());
-                    }
-                }
-                else {
-#endif
-                    Client theClient(io_service, cts_cmd, host, port);
-                    io_service.run();
-                    theClient.handle_server_response(server_reply, false /* debug */);
-                    if (server_reply.client_request_failed()) {
-                        throw std::runtime_error(server_reply.error_msg());
-                    }
-                }
-#ifdef ECF_OPENSSL
-            }
-#endif
-
-            // The move command was ok, remove the source node, and delete its memory
-            sourceNode->remove();
-
-            // Updated defs state
-            defs->set_most_significant_state();
-
-            return PreAllocatedReply::ok_cmd();
-        }
-        catch (std::exception& e) {
-            std::stringstream ss;
-            ss << "MoveCmd Failed for " << host << ":" << port << "  " << e.what() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-
-    // source and destination on same defs file
-    // See if its a sibling move:
-    SuiteChanged1 suiteChanged(destNode->suite());
-    SuiteChanged1 suiteChanged1(sourceNode->suite());
-
-    if (sourceNode->parent() == destNode->parent()) {
-        Node* parent = sourceNode->parent();
-        if (parent)
-            parent->move_peer(sourceNode.get(), destNode.get());
-        else
-            defs->move_peer(sourceNode.get(), destNode.get());
-    }
-    else {
-
-        // If the destination is task, replace with its parent
-        Node* theDestNode = destNode.get();
-        if (theDestNode->isTask())
-            theDestNode = theDestNode->parent();
-
-        // Before we do remove the source node, check its ok to add it as a child
-        std::string errorMsg;
-        if (!theDestNode->isAddChildOk(sourceNode.get(), errorMsg)) {
-            throw std::runtime_error("Plug command failed. " + errorMsg);
-        }
-
-        if (!theDestNode->addChild(sourceNode->remove())) {
-            // This should never fail !!!! else we have lost/ and leaked source node !!!!
-            throw std::runtime_error("Fatal error plug command failed.");
-        }
-    }
-
-    add_node_for_edit_history(destNode);
-
-    // Updated defs state
-    defs->set_most_significant_state();
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* PlugCmd::arg() {
-    return CtsApi::plugArg();
-}
-const char* PlugCmd::desc() {
-    return "Plug command is used to move nodes.\n"
-           "The destination node can be on another server In which case the destination\n"
-           "path should be of the form '<host>:<port>/suite/family/task\n"
-           "  arg1 = path to source node\n"
-           "  arg2 = path to the destination node\n"
-           "This command can fail because:\n"
-           "- Source node is in a 'active' or 'submitted' state\n"
-           "- Another user already has an lock\n"
-           "- source/destination paths do not exist on the corresponding servers\n"
-           "- If the destination node path is empty, i.e. only host:port is specified,\n"
-           "  then the source node must correspond to a suite.\n"
-           "- If the source node is added as a child, then its name must be unique\n"
-           "  amongst its peers\n"
-           "Usage:\n"
-           "  --plug=/suite macX:3141  # move the suite to ecFlow server on host(macX) and port(3141)";
-}
-
-void PlugCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(PlugCmd::arg(), po::value<vector<string>>()->multitoken(), PlugCmd::desc());
-}
-
-void PlugCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (ace->debug())
-        dumpVecArgs(PlugCmd::arg(), args);
-
-    if (args.size() != 2) {
-        std::stringstream ss;
-        ss << "PlugCmd: Two arguments are expected, found " << args.size() << "\n" << PlugCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string sourceNode = args[0];
-    std::string destNode   = args[1];
-
-    cmd = std::make_shared<PlugCmd>(sourceNode, destNode);
-}
-
-CEREAL_REGISTER_TYPE(PlugCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(PlugCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/PlugCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/PlugCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/PlugCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/PlugCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_PlugCmd_HPP
-#define ecflow_base_cts_user_PlugCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-class PlugCmd final : public UserCmd {
-public:
-    PlugCmd(const std::string& source, const std::string& dest) : source_(source), dest_(dest) {}
-    PlugCmd() = default;
-
-    // Uses by equals only
-    const std::string& source() const { return source_; }
-    const std::string& dest() const { return dest_; }
-
-    int timeout() const override { return 120; }
-    bool handleRequestIsTestable() const override { return false; }
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-private:
-    std::string source_;
-    std::string dest_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(source_), CEREAL_NVP(dest_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const PlugCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(PlugCmd)
-
-#endif /* ecflow_base_cts_user_PlugCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/QueryCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/QueryCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/QueryCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/QueryCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,338 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/QueryCmd.hpp"
-
-#include <iostream>
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Extract.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-QueryCmd::~QueryCmd() = default;
-
-void QueryCmd::print(std::string& os) const {
-    // path_to_task_ is only used in logging, so we know which task initiated the query, can be empty when invoked via
-    // cmd line
-    user_cmd(os, CtsApi::to_string(CtsApi::query(query_type_, path_to_attribute_, attribute_)) + path_to_task_);
-}
-void QueryCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::query(query_type_, path_to_attribute_, attribute_));
-    os += path_to_task_;
-}
-
-bool QueryCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<QueryCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (query_type_ != the_rhs->query_type())
-        return false;
-    if (path_to_attribute_ != the_rhs->path_to_attribute())
-        return false;
-    if (attribute_ != the_rhs->attribute())
-        return false;
-    if (path_to_task_ != the_rhs->path_to_task())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-void QueryCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(QueryCmd::arg(), po::value<vector<string>>()->multitoken(), QueryCmd::desc());
-}
-
-void QueryCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (clientEnv->debug()) {
-        dumpVecArgs(QueryCmd::arg(), args);
-        cout << "  QueryCmd::create " << QueryCmd::arg() << " task_path(" << clientEnv->task_path() << ")\n";
-    }
-
-    std::string query_type;
-    std::string path_to_attribute;
-    std::string attribute;
-
-    if (args.size())
-        query_type = args[0];
-    if (query_type == "event" || query_type == "meter" || query_type == "label" || query_type == "variable" ||
-        query_type == "limit" || query_type == "limit_max") {
-        // second argument must be <path>:event_or_meter_or_label_or_variable_or_limit
-        std::string path_and_name;
-        if (args.size() == 2) {
-            path_and_name = args[1];
-            if (!Extract::pathAndName(path_and_name, path_to_attribute, attribute)) {
-                throw std::runtime_error("QueryCmd: second argument must be of the form <path>:name for query\n, where "
-                                         "name is [event | meter | label | variable | limit | limit_max ] name " +
-                                         query_type + " : could not extract from:" + path_and_name);
-            }
-        }
-        else {
-            std::stringstream ss;
-            ss << "QueryCmd: second argument must be of the form <path>:name for query\n where name is [event | meter "
-                  "| label | variable | limit | limit_max] name "
-               << query_type;
-            ss << " args size = " << args.size() << " expected 2 arguments";
-            throw std::runtime_error(ss.str());
-        }
-        if (attribute.empty())
-            throw std::runtime_error("QueryCmd: no attribute specified: query type: " + query_type +
-                                     " path+attribute: " + path_and_name + "\n" + string(QueryCmd::desc()));
-    }
-    else if (query_type == "trigger") {
-        for (size_t i = 1; i < args.size(); i++) {
-            if (i == 1)
-                path_to_attribute = args[i];
-            if (i == 2) {
-                attribute = args[i];
-                (void)Expression::parse(attribute, "QueryCmd:"); // will throw if expression does not parse
-            }
-        }
-        if (attribute.empty())
-            throw std::runtime_error("QueryCmd: no attribute specified: query type: trigger\n" +
-                                     string(QueryCmd::desc()));
-    }
-    else if (query_type == "state" || query_type == "dstate") {
-        // for state and dstate attribute is empty
-        if (args.size() > 1)
-            path_to_attribute = args[1];
-        if (args.size() > 2)
-            throw std::runtime_error("QueryCmd: invalid (state | dstate) query : " + args[2]);
-    }
-    else if (query_type == "repeat") {
-        // for repeat attribute can only be next or prev
-        if (args.size() > 1)
-            path_to_attribute = args[1];
-        if (args.size() == 3) {
-            attribute = args[2];
-            if (attribute != "next" && attribute != "prev") {
-                throw std::runtime_error("QueryCmd: invalid (repeat) query expected 'next' or 'prev' but found " +
-                                         attribute);
-            }
-        }
-        if (args.size() > 3)
-            throw std::runtime_error("QueryCmd: invalid (repeat) query : " + args[3]);
-    }
-    else
-        throw std::runtime_error("QueryCmd: first argument must be one of [ state | dstate | repeat | event | meter | "
-                                 "variable | trigger ] but found:" +
-                                 query_type);
-
-    if (path_to_attribute.empty() || (!path_to_attribute.empty() && path_to_attribute[0] != '/')) {
-        throw std::runtime_error("QueryCmd: invalid path to attribute: " + path_to_attribute);
-    }
-
-    // path_to_task can be empty if invoked via the command line. ( used for logging, i.e identifying which task invoked
-    // this command) However if invoked from the shell/python we expect the path_to_task(ECF_NAME) to have been set
-    std::string path_to_task = clientEnv->task_path(); // can be empty, when cmd called from command line
-    if (!path_to_task.empty() && path_to_task[0] != '/') {
-        throw std::runtime_error("QueryCmd: invalid path to task: " + path_to_task);
-    }
-
-    cmd = std::make_shared<QueryCmd>(query_type, path_to_attribute, attribute, path_to_task);
-}
-
-const char* QueryCmd::arg() {
-    return CtsApi::queryArg();
-}
-
-const char* QueryCmd::desc() {
-    return "Query the status of attributes\n"
-           " i.e state,dstate,repeat,event,meter,label,variable or trigger expression without blocking\n"
-           " - state     return [unknown | complete | queued |             aborted | submitted | active] to standard "
-           "out\n"
-           " - dstate    return [unknown | complete | queued | suspended | aborted | submitted | active] to standard "
-           "out\n"
-           " - repeat    returns current value as a string to standard out\n"
-           " - event     return 'set' | 'clear' to standard out\n"
-           " - meter     return value of the meter to standard out\n"
-           " - limit     return current value of limit to standard out\n"
-           " - limit_max return limit max value to standard out\n"
-           " - label     return new value otherwise the old value\n"
-           " - variable  return value of the variable, repeat or generated variable to standard out,\n"
-           "             will search up the node tree\n"
-           " - trigger   returns 'true' if the expression is true, otherwise 'false'\n\n"
-           "If this command is called within a '.ecf' script we will additionally log the task calling this command\n"
-           "This is required to aid debugging for excessive use of this command\n"
-           "The command will fail if the node path to the attribute does not exist in the definition and if:\n"
-           " - repeat   The repeat is not found\n"
-           " - event    The event is not found\n"
-           " - meter    The meter is not found\n"
-           " - limit/limit_max The limit is not found\n"
-           " - label    The label is not found\n"
-           " - variable No user or generated variable or repeat of that name found on node, or any of its parents\n"
-           " - trigger  Trigger does not parse, or reference to nodes/attributes in the expression are not valid\n"
-           "Arguments:\n"
-           "  arg1 = [ state | dstate | repeat | event | meter | label | variable | trigger | limit | limit_max ]\n"
-           "  arg2 = <path> | <path>:name where name is name of a event, meter, label, limit or variable\n"
-           "  arg3 = trigger expression | prev | next # prev,next only used when arg1 is repeat\n\n"
-           "Usage:\n"
-           " ecflow_client --query state /                                     # return top level state to standard "
-           "out\n"
-           " ecflow_client --query state /path/to/node                         # return node state to standard out\n"
-           " ecflow_client --query dstate /path/to/node                        # state that can included suspended\n"
-           " ecflow_client --query repeat /path/to/node                        # return the current value as a string\n"
-           " ecflow_client --query repeat /path/to/node prev                   # return the previous value as a "
-           "string\n"
-           " ecflow_client --query repeat /path/to/node next                   # return the next value as a string\n"
-           " ecflow_client --query event /path/to/task/with/event:event_name   # return set | clear to standard out\n"
-           " ecflow_client --query meter /path/to/task/with/meter:meter_name   # returns the current value of the "
-           "meter to standard out\n"
-           " ecflow_client --query limit /path/to/task/with/limit:limit_name   # returns the current value of the "
-           "limit to standard out\n"
-           " ecflow_client --query limit_max /path/to/task/with/limit:limit_name # returns the max value of the limit "
-           "to standard out\n"
-           " ecflow_client --query label /path/to/task/with/label:label_name   # returns the current value of the "
-           "label to standard out\n"
-           " ecflow_client --query variable /path/to/task/with/var:var_name    # returns the variable value to "
-           "standard out\n"
-           " ecflow_client --query trigger /path/to/node/with/trigger \"/suite/task == complete\" # return true if "
-           "expression evaluates false otherwise\n";
-}
-
-STC_Cmd_ptr QueryCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().query_++;
-
-    Defs* defs = as->defs().get();
-
-    if (path_to_attribute_ == "/") {
-        if (query_type_ == "state") {
-            return PreAllocatedReply::string_cmd(NState::toString(defs->state()));
-        }
-        std::stringstream ss;
-        ss << "QueryCmd: The only valid query for the server is 'state', i.e. ecflow_client --query state /";
-        throw std::runtime_error(ss.str());
-    }
-
-    node_ptr node = find_node(defs, path_to_attribute_);
-
-    if (query_type_ == "event") {
-        const Event& event = node->findEventByNameOrNumber(attribute_);
-        if (event.empty()) {
-            std::stringstream ss;
-            ss << "QueryCmd: Cannot find event " << attribute_ << " on node " << path_to_attribute_;
-            throw std::runtime_error(ss.str());
-        }
-        if (event.value())
-            return PreAllocatedReply::string_cmd(Event::SET());
-        return PreAllocatedReply::string_cmd(Event::CLEAR());
-    }
-
-    if (query_type_ == "meter") {
-        const Meter& meter = node->findMeter(attribute_);
-        if (meter.empty()) {
-            std::stringstream ss;
-            ss << "QueryCmd: Cannot find meter " << attribute_ << " on node " << path_to_attribute_;
-            throw std::runtime_error(ss.str());
-        }
-        return PreAllocatedReply::string_cmd(ecf::convert_to<std::string>(meter.value()));
-    }
-
-    if (query_type_ == "limit") {
-        limit_ptr limit = node->find_limit(attribute_);
-        if (!limit.get())
-            throw std::runtime_error("QueryCmd: Could not find limit " + attribute_);
-        return PreAllocatedReply::string_cmd(ecf::convert_to<std::string>(limit->value()));
-    }
-    if (query_type_ == "limit_max") {
-        limit_ptr limit = node->find_limit(attribute_);
-        if (!limit.get())
-            throw std::runtime_error("QueryCmd: Could not find limit " + attribute_);
-        return PreAllocatedReply::string_cmd(ecf::convert_to<std::string>(limit->theLimit()));
-    }
-
-    if (query_type_ == "label") {
-        const Label& label = node->find_label(attribute_);
-        if (label.empty()) {
-            std::stringstream ss;
-            ss << "QueryCmd: Cannot find label " << attribute_ << " on node " << path_to_attribute_;
-            throw std::runtime_error(ss.str());
-        }
-        if (label.new_value().empty())
-            return PreAllocatedReply::string_cmd(label.value());
-        return PreAllocatedReply::string_cmd(label.new_value());
-    }
-
-    if (query_type_ == "variable") {
-        std::string the_value;
-        if (node->findParentVariableValue(attribute_, the_value)) {
-            return PreAllocatedReply::string_cmd(the_value);
-        }
-        std::stringstream ss;
-        ss << "QueryCmd: Cannot find variable, repeat or generated var' of name " << attribute_ << " on node "
-           << path_to_attribute_ << " or its parents";
-        throw std::runtime_error(ss.str());
-    }
-
-    if (query_type_ == "trigger") {
-        std::unique_ptr<AstTop> ast =
-            node->parse_and_check_expressions(attribute_, true, "QueryCmd:"); // will throw for errors
-        if (ast->evaluate())
-            return PreAllocatedReply::string_cmd("true");
-        return PreAllocatedReply::string_cmd("false");
-    }
-
-    if (query_type_ == "state") {
-        return PreAllocatedReply::string_cmd(NState::toString(node->state()));
-    }
-
-    if (query_type_ == "dstate") {
-        return PreAllocatedReply::string_cmd(DState::to_string(node->dstate()));
-    }
-
-    if (query_type_ == "repeat") {
-        const Repeat& repeat = node->repeat();
-        if (repeat.empty()) {
-            std::stringstream ss;
-            ss << "QueryCmd: Cannot find repeat on node " << path_to_attribute_;
-            throw std::runtime_error(ss.str());
-        }
-        if (attribute_.empty())
-            return PreAllocatedReply::string_cmd(repeat.valueAsString());
-        if (attribute_ == "next")
-            return PreAllocatedReply::string_cmd(repeat.next_value_as_string());
-        if (attribute_ == "prev")
-            return PreAllocatedReply::string_cmd(repeat.prev_value_as_string());
-        std::stringstream ss;
-        ss << "QueryCmd: invalid repeat attribute expected next | prev but found " << attribute_;
-        throw std::runtime_error(ss.str());
-    }
-    else {
-        std::stringstream ss;
-        ss << "QueryCmd: unrecognised query_type " << query_type_;
-        throw std::runtime_error(ss.str());
-    }
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-std::ostream& operator<<(std::ostream& os, const QueryCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(QueryCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(QueryCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/QueryCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/QueryCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/QueryCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/QueryCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_QueryCmd_HPP
-#define ecflow_base_cts_user_QueryCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-class QueryCmd final : public UserCmd {
-public:
-    QueryCmd(const std::string& query_type,
-             const std::string& path_to_attribute,
-             const std::string& attribute,
-             const std::string& path_to_task)
-        : query_type_(query_type),
-          path_to_attribute_(path_to_attribute),
-          attribute_(attribute),
-          path_to_task_(path_to_task) {}
-    QueryCmd() : UserCmd() {}
-    ~QueryCmd() override;
-
-    const std::string& query_type() const { return query_type_; }
-    const std::string& path_to_attribute() const { return path_to_attribute_; }
-    const std::string& attribute() const { return attribute_; }
-    const std::string& path_to_task() const { return path_to_task_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    bool handleRequestIsTestable() const override { return false; }
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-private:
-    std::string query_type_; // [ state | dstate | event | meter | label | trigger ]
-    std::string path_to_attribute_;
-    std::string attribute_;    // [ event_name | meter_name | label_name | variable_name | trigger expression] empty for
-                               // state and dstate
-    std::string path_to_task_; // The task the invoked this command, needed for logging
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(query_type_),
-           CEREAL_NVP(path_to_attribute_),
-           CEREAL_NVP(attribute_),
-           CEREAL_NVP(path_to_task_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const QueryCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(QueryCmd)
-
-#endif /* ecflow_base_cts_user_QueryCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,242 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-ReplaceNodeCmd::ReplaceNodeCmd(const std::string& node_path, bool createNodesAsNeeded, defs_ptr client_defs, bool force)
-    : createNodesAsNeeded_(createNodesAsNeeded),
-      force_(force),
-      pathToNode_(node_path) {
-    if (!client_defs.get()) {
-        throw std::runtime_error("ReplaceNodeCmd::ReplaceNodeCmd: client definition is empty");
-    }
-
-    // Client defs has been created in memory.
-    // warn about naff expression and unresolved in-limit references to Limit's
-    std::string errMsg, warningMsg;
-    if (!client_defs->check(errMsg, warningMsg)) {
-        throw std::runtime_error(errMsg);
-    }
-
-    // Make sure pathToNode exists in the client defs
-    node_ptr nodeToReplace = client_defs->findAbsNode(node_path);
-    if (!nodeToReplace.get()) {
-        std::stringstream ss;
-        ss << "ReplaceNodeCmd::ReplaceNodeCmd: Cannot replace child since path " << node_path;
-        ss << ", does not exist in the client definition ";
-        throw std::runtime_error(ss.str());
-    }
-
-    client_defs->save_as_string(clientDefs_, PrintStyle::NET);
-
-    // Out put any warning's to standard output
-    cout << warningMsg;
-}
-
-ReplaceNodeCmd::ReplaceNodeCmd(const std::string& node_path,
-                               bool createNodesAsNeeded,
-                               const std::string& path_to_defs,
-                               bool force)
-    : createNodesAsNeeded_(createNodesAsNeeded),
-      force_(force),
-      pathToNode_(node_path),
-      path_to_defs_(path_to_defs) {
-    // Parse the file and load the defs file into memory.
-    std::string errMsg, warningMsg;
-    defs_ptr client_defs = Defs::create();
-    bool ok              = false;
-    if (path_to_defs.find("suite") != std::string::npos && path_to_defs.find("endsuite") != std::string::npos) {
-        ok = client_defs->restore_from_string(path_to_defs, errMsg, warningMsg);
-    }
-    else {
-        ok = client_defs->restore(path_to_defs, errMsg, warningMsg);
-    }
-    if (!ok) {
-        std::stringstream ss;
-        ss << "ReplaceNodeCmd::ReplaceNodeCmd: Could not parse file " << path_to_defs << " : " << errMsg;
-        throw std::runtime_error(ss.str());
-    }
-
-    // Make sure pathToNode exists in the client defs
-    node_ptr nodeToReplace = client_defs->findAbsNode(node_path);
-    if (!nodeToReplace.get()) {
-        std::stringstream ss;
-        ss << "ReplaceNodeCmd::ReplaceNodeCmd: Cannot replace child since path " << node_path;
-        ss << ", does not exist in the client definition " << path_to_defs;
-        throw std::runtime_error(ss.str());
-    }
-
-    client_defs->save_as_string(clientDefs_, PrintStyle::NET);
-
-    // Out put any warning's to standard output
-    cout << warningMsg;
-}
-
-bool ReplaceNodeCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<ReplaceNodeCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (!UserCmd::equals(rhs))
-        return false;
-    if (createNodesAsNeeded_ != the_rhs->createNodesAsNeeded()) {
-        return false;
-    }
-    if (force_ != the_rhs->force())
-        return false;
-    if (pathToNode_ != the_rhs->pathToNode())
-        return false;
-    if (path_to_defs_ != the_rhs->path_to_defs())
-        return false;
-    if (clientDefs_ != the_rhs->the_client_defs())
-        return false;
-    return true;
-}
-
-STC_Cmd_ptr ReplaceNodeCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().replace_++;
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-    Defs* defs = as->defs().get();
-
-    std::string errMsg, warningMsg;
-    defs_ptr client_defs = Defs::create();
-    if (!client_defs->restore_from_string(clientDefs_, errMsg, warningMsg)) {
-        std::stringstream ss;
-        ss << "ReplaceNodeCmd::doHandleRequest : Could not create client defs : " << errMsg;
-        throw std::runtime_error(ss.str());
-    }
-
-    if (force_) {
-        node_ptr node = defs->findAbsNode(pathToNode_);
-        as->zombie_ctrl().add_user_zombies(node.get(), CtsApi::replace_arg());
-    }
-
-    // If we return a node_ptr then we have changed the data model, and therefore must flag node as changed.
-    std::string errorMsg;
-    node_ptr client_node_to_add = defs->replaceChild(pathToNode_, client_defs, createNodesAsNeeded_, force_, errorMsg);
-    if (!client_node_to_add) {
-        throw std::runtime_error(errorMsg);
-    }
-
-    // ECFLOW-835, flag node as changed, before check for trigger expressions.
-    add_node_for_edit_history(defs, pathToNode_);
-
-    // Although we have change the data model, Check if the trigger expressions are still valid.
-    // Note:: trigger AST are not copied. If you use trigger in the test environment
-    //        then copying the nodes will copy the trigger reference, which will be out of sync
-    std::string warning_msg;
-    if (!client_node_to_add->suite()->check(errorMsg, warning_msg)) {
-        throw std::runtime_error(errorMsg);
-    }
-
-    return doJobSubmission(as);
-}
-
-bool ReplaceNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, pathToNode_);
-}
-
-void ReplaceNodeCmd::print(std::string& os) const {
-    std::string path_to_client_defs = path_to_defs_;
-    if (path_to_client_defs.empty())
-        path_to_client_defs = "<empty>"; // defs must have been loaded in memory via python api
-    user_cmd(os, CtsApi::to_string(CtsApi::replace(pathToNode_, path_to_client_defs, createNodesAsNeeded_, force_)));
-}
-void ReplaceNodeCmd::print_only(std::string& os) const {
-    std::string path_to_client_defs = path_to_defs_;
-    if (path_to_client_defs.empty())
-        path_to_client_defs = "<empty>"; // defs must have been loaded in memory via python api
-    os += CtsApi::to_string(CtsApi::replace(pathToNode_, path_to_client_defs, createNodesAsNeeded_, force_));
-}
-
-const char* ReplaceNodeCmd::arg() {
-    return CtsApi::replace_arg();
-}
-const char* ReplaceNodeCmd::desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Replaces a node in the server, with the given path\n"
-           "Can also be used to add nodes in the server\n"
-           "  arg1 = path to node\n"
-           "         must exist in the client defs(arg2). This is also the node we want to\n"
-           "         replace in the server\n"
-           "  arg2 = path to client definition file\n"
-           "         provides the definition of the new node\n"
-           "  arg3 = (optional) [ parent | false ] (default = parent)\n"
-           "         create parent families or suite as needed, when arg1 does not\n"
-           "         exist in the server\n"
-           "  arg4 = (optional) force (default = false) \n"
-           "         Force the replacement even if it causes zombies to be created\n"
-           "Replace can fail if:\n"
-           "- The node path(arg1) does not exist in the provided client definition(arg2)\n"
-           "- The client definition(arg2) must be free of errors\n"
-           "- If the third argument is not provided, then node path(arg1) must exist in the server\n"
-           "- Nodes to be replaced are in active/submitted state, in which case arg4(force) can be used\n\n"
-           "Replace will preserve the suspended status, if this is not required please re-queue first\n"
-           "After replace is done, we check trigger expressions. These are reported to standard output.\n"
-           "It is up to the user to correct invalid trigger expressions, otherwise the tasks will *not* run.\n"
-           "Please note, you can use --check to check trigger expression and limits in the server.\n"
-           "For more information use --help check.\n\n"
-           "Usage:\n"
-           "  --replace=/suite/f1/t1 /tmp/client.def  parent      # Add/replace node tree /suite/f1/t1\n"
-           "  --replace=/suite/f1/t1 /tmp/client.def  false force # replace t1 even if its active or submitted";
-}
-
-void ReplaceNodeCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(ReplaceNodeCmd::arg(), po::value<vector<string>>()->multitoken(), ReplaceNodeCmd::desc());
-}
-void ReplaceNodeCmd::create(Cmd_ptr& cmd,
-                            boost::program_options::variables_map& vm,
-                            AbstractClientEnv* clientEnv) const {
-    vector<string> args = vm[arg()].as<vector<string>>();
-
-    if (clientEnv->debug())
-        dumpVecArgs(ReplaceNodeCmd::arg(), args);
-
-    if (args.size() < 2) {
-        std::stringstream ss;
-        ss << "ReplaceNodeCmd: At least two arguments expected, found " << args.size()
-           << " Please specify <path-to-Node>  <defs files> parent(optional) force(optional), i.e\n"
-           << "--" << arg() << "=/suite/fa/t AdefsFile.def  parent force\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::string pathToNode     = args[0];
-    std::string pathToDefsFile = args[1];
-    bool createNodesAsNeeded   = true; // parent arg
-    bool force                 = false;
-    if (args.size() == 3 && args[2] == "false")
-        createNodesAsNeeded = false;
-    if (args.size() == 4 && args[3] == "force")
-        force = true;
-
-    cmd = std::make_shared<ReplaceNodeCmd>(pathToNode, createNodesAsNeeded, pathToDefsFile, force);
-}
-
-std::ostream& operator<<(std::ostream& os, const ReplaceNodeCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(ReplaceNodeCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(ReplaceNodeCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_ReplaceNodeCmd_HPP
-#define ecflow_base_cts_user_ReplaceNodeCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-class ReplaceNodeCmd final : public UserCmd {
-public:
-    ReplaceNodeCmd(const std::string& node_path, bool createNodesAsNeeded, defs_ptr client_defs, bool force);
-    ReplaceNodeCmd(const std::string& node_path, bool createNodesAsNeeded, const std::string& path_to_defs, bool force);
-    ReplaceNodeCmd() = default;
-
-    const std::string& the_client_defs() const { return clientDefs_; }
-    const std::string& pathToNode() const { return pathToNode_; }
-    const std::string& path_to_defs() const { return path_to_defs_; }
-    bool createNodesAsNeeded() const { return createNodesAsNeeded_; }
-    bool force() const { return force_; }
-
-    bool isWrite() const override { return true; }
-    int timeout() const override { return 300; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-    // void set_client_env(const std::vector<std::pair<std::string,std::string> >& env ) { client_env_ = env;} // only
-    // used in test
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::string().swap(clientDefs_); } /// run in the server, after command send to client
-
-    bool createNodesAsNeeded_{false};
-    bool force_{false};
-    std::string pathToNode_;
-    std::string path_to_defs_; // Can be empty if defs loaded in memory via python api
-    std::string clientDefs_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(createNodesAsNeeded_),
-           CEREAL_NVP(force_),
-           CEREAL_NVP(pathToNode_),
-           CEREAL_NVP(path_to_defs_),
-           CEREAL_NVP(clientDefs_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ReplaceNodeCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(ReplaceNodeCmd)
-
-#endif /* ecflow_base_cts_user_ReplaceNodeCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,259 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool RequeueNodeCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<RequeueNodeCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (paths_ != the_rhs->paths())
-        return false;
-    if (option_ != the_rhs->option())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-static std::string to_string(RequeueNodeCmd::Option option) {
-    switch (option) {
-        case RequeueNodeCmd::NO_OPTION:
-            return string();
-        case RequeueNodeCmd::FORCE:
-            return "force";
-        case RequeueNodeCmd::ABORT:
-            return "abort";
-        default:
-            assert(false);
-            break;
-    }
-    return string();
-}
-
-void RequeueNodeCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::requeue(paths_, to_string(option_))));
-}
-void RequeueNodeCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::requeue(paths_, to_string(option_)));
-}
-
-void RequeueNodeCmd::print(std::string& os, const std::string& path) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::requeue(std::vector<std::string>(1, path), to_string(option_))));
-}
-
-STC_Cmd_ptr RequeueNodeCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().requeue_node_++;
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-
-    // The clear_suspended_in_child_nodes *only* incremented for child nodes.
-    // Hence we only clear suspended for child nodes.
-    Node::Requeue_args args(Node::Requeue_args::FULL,
-                            true /* reset repeats */,
-                            0 /* clear_suspended_in_child_nodes */,
-                            true /* reset_next_time_slot */,
-                            true /* reset relative duration */);
-
-    Defs* defs = as->defs().get();
-    std::stringstream ss;
-    size_t vec_size = paths_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-
-        node_ptr theNodeToRequeue = find_node_for_edit_no_throw(defs, paths_[i]);
-        if (!theNodeToRequeue.get()) {
-            ss << "RequeueNodeCmd: Could not find node at path " << paths_[i] << "\n";
-            LOG(Log::ERR, "RequeueNodeCmd: Could not find node at path " << paths_[i]);
-            continue;
-        }
-
-        if (!theNodeToRequeue->suite()->begun()) {
-            std::stringstream mss;
-            mss << "RequeueNodeCmd::doHandleRequest: For node " << paths_[i] << ". The suite "
-                << theNodeToRequeue->suite()->name() << " must be 'begun' first\n";
-            throw std::runtime_error(mss.str());
-        }
-
-        SuiteChangedPtr changed(theNodeToRequeue.get());
-
-        if (option_ == RequeueNodeCmd::ABORT) {
-            // ONLY Re-queue the aborted tasks
-            std::vector<Task*> taskVec;
-            theNodeToRequeue->getAllTasks(taskVec);
-            for (auto& task : taskVec) {
-                if (task->state() == NState::ABORTED) {
-                    task->requeue(args);
-                    task->set_most_significant_state_up_node_tree(); // Must in loop and not outside ECFLOW-428
-                }
-            }
-
-            // Call handleStateChange on parent, to avoid requeue same node again.
-            Node* parent = theNodeToRequeue->parent();
-            if (parent)
-                parent->handleStateChange(); // ECFLOW-359
-        }
-        else if (option_ == RequeueNodeCmd::NO_OPTION) {
-            // ONLY Re-queue if there no tasks in submitted or active states
-            std::vector<Task*> taskVec;
-            theNodeToRequeue->getAllTasks(taskVec);
-            for (auto& task : taskVec) {
-                if (task->state() == NState::SUBMITTED || task->state() == NState::ACTIVE) {
-                    return PreAllocatedReply::ok_cmd();
-                }
-            }
-
-            // The NO_REQUE_IF_SINGLE_TIME_DEP is typically cleared at the *end* requeue, however there are cases
-            // where we need to reset it *BEFORE* re-queue. Since it is tied to missing the next time slot
-            // i.e take this case:
-            //     time 10:00  15:00 00:30
-            // If we force complete, we set NO_REQUE_IF_SINGLE_TIME_DEP, which is used to advance next valid time slot
-            // (i.e no reset), however when we reach the *end* time i.e 15:00
-            // calling force complete now leaves node in a complete state and with NO_REQUE_IF_SINGLE_TIME_DEP set.
-            // Therefore *any* *MANUAL* re-queue afterward will NOT reset the next valid time slot.
-            // To overcome this manual re-queue will always clear NO_REQUE_IF_SINGLE_TIME_DEP and hence reset next valid
-            // time slot
-            theNodeToRequeue->requeue(args);
-            theNodeToRequeue->set_most_significant_state_up_node_tree();
-
-            // Call handleStateChange on parent, to avoid requeue same node again.
-            Node* parent = theNodeToRequeue->parent();
-            if (parent)
-                parent->handleStateChange(); // ECFLOW-359
-        }
-        else if (option_ == RequeueNodeCmd::FORCE) {
-
-            as->zombie_ctrl().add_user_zombies(theNodeToRequeue.get(), CtsApi::requeueArg());
-
-            // Please note: that if any tasks under theNodeToRequeue are in
-            // active or submitted states, then we will have created zombie jobs
-            // The GUI: that calls this command should call a separate request
-            // the returns the active/submitted tasks first. This can then be
-            // presented to the user, who can elect to kill them if required.
-            theNodeToRequeue->requeue(args);
-            theNodeToRequeue->set_most_significant_state_up_node_tree();
-
-            // Call handleStateChange on parent, to avoid requeue same node again.
-            Node* parent = theNodeToRequeue->parent();
-            if (parent)
-                parent->handleStateChange(); // ECFLOW-359
-        }
-    }
-
-    std::string error_msg = ss.str();
-    if (!error_msg.empty()) {
-        throw std::runtime_error(error_msg);
-    }
-
-    // Do an immediate job submission, so that any re-queued tasks are submitted
-    return doJobSubmission(as);
-}
-
-bool RequeueNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
-
-const char* RequeueNodeCmd::arg() {
-    return CtsApi::requeueArg();
-}
-const char* RequeueNodeCmd::desc() {
-    return "Re queues the specified node(s)\n"
-           "  If any child of the specified node(s) is in a suspended state, this state is cleared\n"
-           "Repeats are reset to their starting values, relative time attributes are reset.\n"
-           "  arg1 = (optional) [ abort | force ]\n"
-           "         abort  = re-queue only aborted tasks below node\n"
-           "         force  = Force the re-queueing even if there are nodes that are active or submitted\n"
-           "         <null> = Checks if any tasks are in submitted or active states below the node\n"
-           "                  if so does nothing. Otherwise re-queues the node.\n"
-           "  arg2 = list of node paths. The node paths must begin with a leading '/' character\n\n"
-           "Usage:\n"
-           "  --requeue=abort /suite/f1  # re-queue all aborted tasks of /suite/f1\n"
-           "  --requeue=force /suite/f1  # forcibly re-queue /suite/f1 and all its children.May cause zombies.\n"
-           "  --requeue=/s1/f1/t1 /s1/t2 # Re-queue node '/suite/f1/t1' and '/s1/t2'";
-}
-
-void RequeueNodeCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(RequeueNodeCmd::arg(), po::value<vector<string>>()->multitoken(), RequeueNodeCmd::desc());
-}
-void RequeueNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    vector<string> args = vm[RequeueNodeCmd::arg()].as<vector<string>>();
-
-    if (ac->debug())
-        dumpVecArgs(RequeueNodeCmd::arg(), args);
-
-    if (args.size() < 1) {
-        std::stringstream ss;
-        ss << "RequeueNodeCmd: At least 1 argument(path to node) expected. Please specify one of:\n";
-        ss << RequeueNodeCmd::arg() << " pathToNode\n";
-        ss << RequeueNodeCmd::arg() << " abort pathToNode\n";
-        ss << RequeueNodeCmd::arg() << " force pathToNode\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
-    if (paths.empty()) {
-        std::stringstream ss;
-        ss << "RequeueNodeCmd: No paths specified. At least one path expected. Paths must begin with a leading '/' "
-              "character\n"
-           << RequeueNodeCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    RequeueNodeCmd::Option option = RequeueNodeCmd::NO_OPTION;
-    size_t vec_size               = options.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        if (options[i] == "abort") {
-            option = RequeueNodeCmd::ABORT;
-            if (ac->debug())
-                cout << "  ABORT selected\n";
-        }
-        else if (options[i] == "force") {
-            option = RequeueNodeCmd::FORCE;
-            if (ac->debug())
-                cout << "  FORCE selected\n";
-        }
-        else {
-            std::stringstream ss;
-            ss << "RequeueNodeCmd: RequeueNodeCmd: Expected : [force | abort ] paths.\n"
-               << RequeueNodeCmd::desc() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    if (options.size() > 1) {
-        std::stringstream ss;
-        ss << "RequeueNodeCmd: Expected only a single option i.e [ force | abort ]\n" << RequeueNodeCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    cmd = std::make_shared<RequeueNodeCmd>(paths, option);
-}
-
-std::ostream& operator<<(std::ostream& os, const RequeueNodeCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(RequeueNodeCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(RequeueNodeCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_RequeueNodeCmd_HPP
-#define ecflow_base_cts_user_RequeueNodeCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-class RequeueNodeCmd final : public UserCmd {
-public:
-    enum Option { NO_OPTION, ABORT, FORCE };
-
-    explicit RequeueNodeCmd(const std::vector<std::string>& paths, Option op = NO_OPTION)
-        : paths_(paths),
-          option_(op) {}
-
-    explicit RequeueNodeCmd(const std::string& absNodepath, Option op = NO_OPTION)
-        : paths_(std::vector<std::string>(1, absNodepath)),
-          option_(op) {}
-
-    RequeueNodeCmd() = default;
-
-    const std::vector<std::string>& paths() const { return paths_; }
-    Option option() const { return option_; }
-
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    void print(std::string& os, const std::string& path) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
-
-private:
-    mutable std::vector<std::string> paths_; // mutable to allow swap to clear & reclaim memory, as soon as possible
-    Option option_{NO_OPTION};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(paths_), CEREAL_NVP(option_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const RequeueNodeCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(RequeueNodeCmd)
-
-#endif /* ecflow_base_cts_user_RequeueNodeCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/RunNodeCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/RunNodeCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/RunNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/RunNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,187 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/RunNodeCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-bool RunNodeCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<RunNodeCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (paths_ != the_rhs->paths())
-        return false;
-    if (force_ != the_rhs->force())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-void RunNodeCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::run(paths_, force_)));
-}
-void RunNodeCmd::print_only(std::string& os) const {
-    os += CtsApi::to_string(CtsApi::run(paths_, force_));
-}
-void RunNodeCmd::print(std::string& os, const std::string& path) const {
-    user_cmd(os, CtsApi::to_string(CtsApi::run(std::vector<std::string>(1, path), force_)));
-}
-
-STC_Cmd_ptr RunNodeCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().run_node_++;
-    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
-
-    Defs* defs = as->defs().get();
-    std::stringstream ss;
-    size_t vec_size = paths_.size();
-    for (size_t i = 0; i < vec_size; i++) {
-        node_ptr node = find_node_for_edit_no_throw(defs, paths_[i]);
-        if (!node.get()) {
-            ss << "RunNodeCmd: Could not find node at path " << paths_[i] << "\n";
-            LOG(Log::ERR, "RunNodeCmd: Could not find node at path " << paths_[i]);
-            continue;
-        }
-
-        if (!node->suite()->begun()) {
-            std::stringstream mss;
-            mss << "RunNodeCmd failed: For " << paths_[i] << ". The suite " << node->suite()->name()
-                << " must be 'begun' first\n";
-            throw std::runtime_error(mss.str());
-        }
-
-        SuiteChangedPtr changed(node.get());
-
-        // Please note: that if any tasks under theNode are in
-        // active or submitted states, then we will have created zombies jobs
-        // The GUI: that calls this command should call a separate request
-        // the returns the active/submitted tasks first. This can then be
-        // presented to the user, who can elect to kill them if required.
-        bool createJobs = true;
-        if (test_)
-            createJobs = false;
-
-        /// This will *NOT* timeout, unlike server Job generation
-        JobsParam jobsParam(as->poll_interval(),
-                            createJobs); // default here is to spawn jobs , spawn jobs = true
-                                         // At the task level, if create jobs is false, we will not spawn jobs
-#ifdef DEBUG_JOB_SUBMISSION
-        jobsParam.logDebugMessage(" from RunNodeCmd::doHandleRequest");
-#endif
-
-        if (force_)
-            as->zombie_ctrl().add_user_zombies(node.get(), CtsApi::runArg());
-
-        // Avoid re-running the task again on the same time slot
-        node->miss_next_time_slot();
-
-        if (!node->run(jobsParam, force_)) {
-            LOG(Log::ERR, "RunNodeCmd: Failed for " << paths_[i] << " : " << jobsParam.getErrorMsg());
-        }
-    }
-
-    std::string error_msg = ss.str();
-    if (!error_msg.empty()) {
-        throw std::runtime_error(error_msg);
-    }
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-bool RunNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    return do_authenticate(as, cmd, paths_);
-}
-
-const char* RunNodeCmd::arg() {
-    return CtsApi::runArg();
-}
-const char* RunNodeCmd::desc() {
-    return "Ignore triggers, limits, time or date dependencies, just run the Task.\n"
-           "When a job completes, it may be automatically re-queued if it has a cron\n"
-           "or multiple time dependencies. If we have multiple time based attributes,\n"
-           "then each run, will expire the time.\n"
-           "When we run before the time, we want to avoid re-running the task then\n"
-           "a flag is set, so that it is not automatically re-queued.\n"
-           "A repeat attribute is incremented when all the child nodes are complete\n"
-           "in this case the child nodes are automatically re-queued.\n"
-           "Hence this command can be aid, in allowing a Repeat attribute to be incremented\n"
-           "  arg1 = (optional)force\n"
-           "         Forcibly run, even if there are nodes that are active or submitted\n"
-           "         This can result in zombie creation\n"
-           "  arg2 = node path(s). The paths must begin with a leading '/' character.\n"
-           "         If the path is /suite/family will recursively run all tasks\n"
-           "         When providing multiple paths avoid running the same task twice\n"
-           "Example:\n"
-           "  --run=/suite/t1                    # run task t1\n"
-           "Effect:\n"
-           "     task t1; time 12:00             # will complete if run manually\n"
-           "     task t2; time 10:00 13:00 01:00 # will run 4 times before completing\n"
-           " When we have a time range(i.e as shown with task t2), then next time slot\n"
-           " is incremented for each run, until it expires, and the task completes.\n"
-           " Use the Why command, to show next run time (i.e. next time slot)";
-}
-
-void RunNodeCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(RunNodeCmd::arg(), po::value<vector<string>>()->multitoken(), RunNodeCmd::desc());
-}
-void RunNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
-    vector<string> args = vm[RunNodeCmd::arg()].as<vector<string>>();
-
-    if (ace->debug())
-        dumpVecArgs(RunNodeCmd::arg(), args);
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
-    if (paths.empty()) {
-        std::stringstream ss;
-        ss << "RunNodeCmd: No paths specified. Paths must begin with a leading '/' character\n"
-           << RunNodeCmd::desc() << "\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    bool force = false;
-    if (!options.empty()) {
-        if (options.size() != 1) {
-            std::stringstream ss;
-            ss << "RunNodeCmd: Invalid arguments. Expected a single optional 'force'\n" << RunNodeCmd::desc() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-        if (options[0].find("force") != std::string::npos)
-            force = true;
-        else {
-            std::stringstream ss;
-            ss << "RunNodeCmd: Expected force <path(s)>\n" << RunNodeCmd::desc() << "\n";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    cmd = std::make_shared<RunNodeCmd>(paths, force);
-}
-
-std::ostream& operator<<(std::ostream& os, const RunNodeCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(RunNodeCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(RunNodeCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/RunNodeCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/RunNodeCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/RunNodeCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/RunNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,68 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_RunNodeCmd_HPP
-#define ecflow_base_cts_user_RunNodeCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// The absNodepath must be provided
-class RunNodeCmd final : public UserCmd {
-public:
-    RunNodeCmd(const std::string& absNodepath, bool force, bool test = false)
-        : paths_(std::vector<std::string>(1, absNodepath)),
-          force_(force),
-          test_(test) {}
-
-    RunNodeCmd(const std::vector<std::string>& paths, bool force, bool test = false)
-        : paths_(paths),
-          force_(force),
-          test_(test) {}
-
-    RunNodeCmd() = default;
-
-    const std::vector<std::string>& paths() const { return paths_; }
-    bool force() const { return force_; }
-
-    bool isWrite() const override { return true; }
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    void print(std::string& os, const std::string& path) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
-
-private:
-    std::vector<std::string> paths_;
-    bool force_{false};
-    bool test_{false}; // only for test, hence we don't serialise this
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(paths_), CEREAL_NVP(force_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const RunNodeCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(RunNodeCmd)
-
-#endif /* ecflow_base_cts_user_RunNodeCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,78 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Version.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-void ServerVersionCmd::print(std::string& os) const {
-    user_cmd(os, CtsApi::server_version());
-}
-void ServerVersionCmd::print_only(std::string& os) const {
-    os += CtsApi::server_version();
-}
-
-bool ServerVersionCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<ServerVersionCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-const char* ServerVersionCmd::theArg() const {
-    return CtsApi::server_version_arg();
-}
-
-STC_Cmd_ptr ServerVersionCmd::doHandleRequest(AbstractServer* as) const {
-    as->update_stats().server_version_++;
-    return PreAllocatedReply::string_cmd(Version::raw());
-}
-
-static const char* arg_desc() {
-    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-    return "Returns the version number of the server\n"
-           "Usage:\n"
-           "  --server_version\n"
-           "    Writes the version to standard output\n";
-}
-
-void ServerVersionCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(CtsApi::server_version_arg(), arg_desc());
-}
-
-void ServerVersionCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
-    if (ace->debug())
-        cout << "  ServerVersionCmd::create\n";
-
-    // testing client interface
-    if (ace->under_test())
-        return;
-
-    cmd = std::make_shared<ServerVersionCmd>();
-}
-
-std::ostream& operator<<(std::ostream& os, const ServerVersionCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(ServerVersionCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(ServerVersionCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ServerVersionCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_ServerVersionCmd_HPP
-#define ecflow_base_cts_user_ServerVersionCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// ========================================================================
-// This Command should NEVER be changed
-// This will allow new client to ask OLD server about its version
-// ========================================================================
-class ServerVersionCmd final : public UserCmd {
-public:
-    ServerVersionCmd() = default;
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ServerVersionCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(ServerVersionCmd)
-
-#endif /* ecflow_base_cts_user_ServerVersionCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ShowCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/ShowCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ShowCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ShowCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,114 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/ShowCmd.hpp"
-
-#include <iostream>
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-bool ShowCmd::equals(ClientToServerCmd* rhs) const {
-    return (dynamic_cast<ShowCmd*>(rhs)) ? UserCmd::equals(rhs) : false;
-}
-
-void ShowCmd::print(std::string& os) const {
-    user_cmd(os, "show");
-}
-void ShowCmd::print_only(std::string& os) const {
-    os += "show";
-}
-
-STC_Cmd_ptr ShowCmd::doHandleRequest(AbstractServer* as) const {
-    /// Should never get called since, show command is only called on client side.
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* ShowCmd::arg() {
-    return "show";
-}
-const char* ShowCmd::desc() {
-    return "Used to print state of the definition returned from the server to standard output.\n"
-           "This command can *only* be used in a group command, and will only work if it is\n"
-           "preceded with a get command. See examples below.\n"
-           "   arg1 = [ defs | state | migrate ] \n"
-           "The output of show has several options: i.e\n"
-           "  o no arguments: With no arguments, print the definition structure to standard output\n"
-           "    Extern's are automatically added, allowing the output to be reloaded into the server\n"
-           "    i.e --group=\"get ; show\"\n"
-           "  o state:\n"
-           "    This will output definition structure along with all the state information.\n"
-           "    This will include the trigger expressions, abstract syntax tree as comments.\n"
-           "    Excludes the edit history\n"
-           "  o migrate:\n"
-           "    This will output definition structure along with all the state information.\n"
-           "    The node state is shown in the comments.\n"
-           "    This format allows the definition to be migrated to future version of ecflow.\n"
-           "    The output includes edit history but excludes externs.\n"
-           "    When the definition is reloaded *NO* checking is done.\n"
-           "\n"
-           "The following shows a summary of the features associated with each choice\n"
-           "                        DEFS          STATE      MIGRATE\n"
-           "Auto generate externs   Yes           Yes        No\n"
-           "Checking on reload      Yes           Yes        No\n"
-           "Edit History            No            No         Yes\n"
-           "trigger AST             No            Yes        No\n"
-           "\n"
-           "Usage:\n"
-           "    --group=\"get ; show\"\n"
-           "    --group=\"get ; show defs\"    # same as the previous example\n"
-           "    --group=\"get ; show state\"   # Show all state for the node tree\n"
-           "    --group=\"get ; show migrate\" # Shows state and allows migration\n"
-           "    --group=\"get=/s1; show\"      # show state for the node only\n"
-           "    --group=\"get=/s1; show state\"";
-}
-
-void ShowCmd::addOption(boost::program_options::options_description& desc) const {
-    desc.add_options()(ShowCmd::arg(), po::value<string>()->implicit_value(string()), ShowCmd::desc());
-}
-void ShowCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
-    std::string show_state = vm[ShowCmd::arg()].as<std::string>();
-
-    if (ac->debug())
-        cout << "  ShowCmd::create api = '" << show_state << "'.\n";
-
-    PrintStyle::Type_t style = PrintStyle::DEFS;
-    if (!show_state.empty()) {
-        if (show_state == "state")
-            style = PrintStyle::STATE;
-        else if (show_state == "migrate")
-            style = PrintStyle::MIGRATE;
-        else if (show_state == "defs")
-            style = PrintStyle::DEFS;
-        else
-            throw std::runtime_error(
-                "ShowCmd::create invalid show option expected one of [ defs | state | migrate ] but found " +
-                show_state);
-    }
-    cmd = std::make_shared<ShowCmd>(style);
-}
-
-std::ostream& operator<<(std::ostream& os, const ShowCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(ShowCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(ShowCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ShowCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/ShowCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ShowCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ShowCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_ShowCmd_HPP
-#define ecflow_base_cts_user_ShowCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-// Does Nothing in the server, however allows client code to display the
-// returned Defs in different showStyles
-// This class has no need for persistence, i.e client side only
-class ShowCmd final : public UserCmd {
-public:
-    explicit ShowCmd(PrintStyle::Type_t s = PrintStyle::DEFS) : style_(s) {}
-
-    // returns the showStyle
-    bool show_cmd() const override { return true; }
-    PrintStyle::Type_t show_style() const override { return style_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override { return arg(); }
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    static const char* arg();  // used for argument parsing
-    static const char* desc(); // The description of the argument as provided to user
-
-    // The Show Cmd is processed on the client side,
-    // Likewise the doHandleRequest does nothing,
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-
-    PrintStyle::Type_t style_;
-
-    // Persistence is still required since show command can be *USED* in a *GROUP* command
-    // However its ONLY used on the client side, hence no need to serialise data members
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ShowCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(ShowCmd)
-
-#endif /* ecflow_base_cts_user_ShowCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/UserCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/UserCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/UserCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/UserCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,250 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-
-#include <iostream>
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/User.hpp"
-
-using namespace std;
-using namespace boost;
-using namespace ecf;
-
-bool UserCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<UserCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (user_ != the_rhs->user())
-        return false;
-    return ClientToServerCmd::equals(rhs);
-}
-
-bool UserCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
-    // The user should NOT be empty. Rather than asserting and killing the server, fail authentication
-    // ECFLOW-577 and ECFLOW-512. When user_ empty ??
-    if (!user_.empty() && as->authenticateReadAccess(user_, cu_, pswd_)) {
-
-        // Does this user command require write access
-        if (isWrite()) {
-            // command requires write access. Check user has write access
-            if (as->authenticateWriteAccess(user_)) {
-                return true;
-            }
-            std::string msg = "[ authentication failed ] User ";
-            msg += user_;
-            msg += " has no *write* access. Please see your administrator.";
-            throw std::runtime_error(msg);
-        }
-        else {
-            // read request, and we have read access
-            return true;
-        }
-    }
-
-    std::string msg = "[ authentication failed ] User '";
-    msg += user_;
-    msg += "' is not allowed any access.";
-    throw std::runtime_error(msg);
-
-    return false;
-}
-
-bool UserCmd::do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::string& path) const {
-    if (!user_.empty() && as->authenticateReadAccess(user_, cu_, pswd_, path)) {
-
-        // Does this user command require write access
-        if (isWrite()) {
-            // command requires write access. Check user has write access, add access to suite/node/path
-            if (as->authenticateWriteAccess(user_, path)) {
-                return true;
-            }
-            std::string msg = "[ authentication failed ] User ";
-            msg += user_;
-            msg += " has no *write* access. path(";
-            msg += path;
-            msg += ")Please see your administrator.";
-            throw std::runtime_error(msg);
-        }
-        else {
-            // read request, and we have read access
-            return true;
-        }
-    }
-
-    std::string msg = "[ authentication failed ] User '";
-    msg += user_;
-    msg += "' is not allowed any access. path(";
-    msg += path;
-    msg += ")";
-    throw std::runtime_error(msg);
-
-    return false;
-}
-
-bool UserCmd::do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::vector<std::string>& paths) const {
-    if (!user_.empty() && as->authenticateReadAccess(user_, cu_, pswd_, paths)) {
-
-        // Does this user command require write access
-        if (isWrite()) {
-            // command requires write access. Check user has write access
-            if (as->authenticateWriteAccess(user_, paths)) {
-                return true;
-            }
-            std::string msg = "[ authentication failed ] User ";
-            msg += user_;
-            msg += " has no *write* access to paths(";
-            for (const auto& path : paths) {
-                msg += path;
-                msg += ",";
-            }
-            msg += ") Please see your administrator.";
-            throw std::runtime_error(msg);
-        }
-        else {
-            // read request, and we have read access
-            return true;
-        }
-    }
-
-    std::string msg = "[ authentication failed ] User '";
-    msg += user_;
-    msg += "' is not allowed any access. paths(";
-    for (const auto& path : paths) {
-        msg += path;
-        msg += ",";
-    }
-    msg += ")";
-    throw std::runtime_error(msg);
-
-    return false;
-}
-
-void UserCmd::setup_user_authentification(const std::string& user, const std::string& passwd) {
-    user_ = user;
-    pswd_ = passwd; // assumes this has been crypted()
-    assert(!hostname().empty());
-    assert(!user_.empty());
-}
-
-bool UserCmd::setup_user_authentification(AbstractClientEnv& clientEnv) {
-    // A Custom user is one where:
-    //   o/ ECF_USER environment used
-    //   o/ --user on the command line
-    //   o/ ClientInvoker::set_user_name()
-    // Having a custom user name is an exception, to avoid having ALL user to provide a password
-    // we have a CUSTOM password file ECF_CUSTOM_PASSWD,   <host>.<port>.ecf.custom_passwd
-    const std::string& user_name = clientEnv.get_user_name(); // Using ECF_USER || --user <user> || set_user_name()/GUI
-    if (!user_name.empty()) {
-        cu_ = true; // inform server side custom USER used, server will expect password in ECF_CUSTOM_PASSWD files
-        const std::string& passwd = clientEnv.get_custom_user_password(user_name);
-        if (passwd.empty()) {
-            // cout << "invalid user as password is empty, must have a password when user specified \n";
-            return false; // invalid user as password is empty, must have a password when user specified
-        }
-
-        setup_user_authentification(user_name, passwd);
-        return true;
-    }
-
-    // User name is same as login name, if ECF_PASSWD is defined on server side *ALL* user must provide a password.
-    std::string the_user      = User::login_name();
-    const std::string& passwd = clientEnv.get_user_password(the_user);
-    setup_user_authentification(the_user, passwd);
-    return true;
-}
-
-void UserCmd::setup_user_authentification() {
-    if (user_.empty()) {
-        setup_user_authentification(User::login_name(), Str::EMPTY());
-    }
-}
-
-void UserCmd::prompt_for_confirmation(const std::string& prompt) {
-    cout << prompt;
-    char reply[256];
-    cin.getline(reply, 256);
-    if (reply[0] != 'y' && reply[0] != 'Y') {
-        exit(1);
-    }
-}
-
-void UserCmd::user_cmd(std::string& os, const std::string& the_cmd) const {
-    os += the_cmd;
-    os += " :";
-    os += user_;
-    os += '@';
-    os += hostname();
-}
-
-// #define DEBUG_ME 1
-
-void UserCmd::split_args_to_options_and_paths(const std::vector<std::string>& args,
-                                              std::vector<std::string>& options,
-                                              std::vector<std::string>& paths,
-                                              bool treat_colon_in_path_as_path) {
-    // ** ECFLOW-137 **, if the trigger expression have a leading '/' then it gets parsed into the paths
-    //                   vector and not options
-    // This is because boost program options does *NOT* seem to preserve the leading quotes around the
-    // trigger/complete expression,  i.e "/suite/t2 == complete"   is read as /suite/t2 == complete
-    // However in paths we do not expect to see any spaces
-
-    // Note: Node names are not allowed ':', hence ':' in a node path is always to reference a node attribute,
-    // event,limit in this case However we need to deal with special situations:
-    //   o --alter add inlimit /path/to/node/withlimit:limit_name 10  /s1  # TREAT /path/to/node/withlimit:limit_name as
-    //   a OPTION o --change trigger "/suite/task:a" /path/to/a/node                # TREAT "/suite/task:a" as a OPTION
-    //   o --force=clear /suite/task:ev                                    # TREAT /suite/task:ev as a PATH
-    // We need to distinguish between the two, hence use treat_colon_in_path_as_path
-    size_t vec_size = args.size();
-    if (treat_colon_in_path_as_path) {
-        for (size_t i = 0; i < vec_size; i++) {
-            if (args[i].empty())
-                continue;
-            if (args[i][0] == '/' && args[i].find(" ") == std::string::npos) {
-                // --force=clear /suite/task:ev  -> treat '/suite/task:ev' as a path
-                paths.push_back(args[i]);
-            }
-            else {
-                options.push_back(args[i]);
-            }
-        }
-    }
-    else {
-        // Treat ':' is path as a option, TREAT '/path/to/node/withlimit:limit_name' as a option
-        for (size_t i = 0; i < vec_size; i++) {
-            if (args[i][0] == '/' && args[i].find(" ") == std::string::npos && args[i].find(":") == std::string::npos) {
-                paths.push_back(args[i]);
-            }
-            else {
-                options.push_back(args[i]);
-            }
-        }
-    }
-#ifdef DEBUG_ME
-    std::cout << "split_args_to_options_and_paths\n";
-    for (size_t i = 0; i < args.size(); ++i) {
-        std::cout << "args[" << i << "]=" << args[i] << "\n";
-    }
-    for (size_t i = 0; i < options.size(); ++i) {
-        std::cout << "options[" << i << "]=" << options[i] << "\n";
-    }
-    for (size_t i = 0; i < paths.size(); ++i) {
-        std::cout << "paths[" << i << "]=" << paths[i] << "\n";
-    }
-#endif
-}
-
-int UserCmd::time_out_for_load_sync_and_get() {
-    return 600;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/UserCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/UserCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/UserCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/UserCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,65 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_UserCmd_HPP
-#define ecflow_base_cts_user_UserCmd_HPP
-
-#include "ecflow/base/Cmd.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-
-//=================================================================================
-// User Command
-// ================================================================================
-class UserCmd : public ClientToServerCmd {
-public:
-    UserCmd() = default;
-
-    const std::string& user() const { return user_; }
-    const std::string& passwd() const { return pswd_; }
-
-    void setup_user_authentification(const std::string& user, const std::string& passwd) override;
-    bool setup_user_authentification(AbstractClientEnv&) override;
-    void setup_user_authentification() override;
-
-protected:
-    bool equals(ClientToServerCmd*) const override;
-    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
-    bool do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::string& path) const;
-    bool do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::vector<std::string>& paths) const;
-
-    /// Prompt the user for confirmation: If user responds with no, will exit client
-    static void prompt_for_confirmation(const std::string& prompt);
-
-    /// All user commands will be pre_fixed with "--" and post_fixed with :user@host
-    void user_cmd(std::string& os, const std::string& the_cmd) const;
-
-    static int time_out_for_load_sync_and_get();
-
-    // The order is preserved during the split. Paths assumed to start with '/' char
-    static void split_args_to_options_and_paths(const std::vector<std::string>& args,
-                                                std::vector<std::string>& options,
-                                                std::vector<std::string>& paths,
-                                                bool treat_colon_in_path_as_path = false);
-
-private:
-    std::string user_;
-    std::string pswd_;
-    bool cu_ = false; // custom user, i.e used set_user_name() || ECF_USER || --user -> only check this password
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<ClientToServerCmd>(this), CEREAL_NVP(user_));
-        CEREAL_OPTIONAL_NVP(ar, pswd_, [this]() { return !pswd_.empty(); }); // conditionally save
-        CEREAL_OPTIONAL_NVP(ar, cu_, [this]() { return cu_; });              // conditionally save
-    }
-};
-
-#endif /* ecflow_base_cts_user_UserCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ZombieCmd.cpp 5.13.0-1/Base/src/ecflow/base/cts/user/ZombieCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ZombieCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ZombieCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,348 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/cts/user/ZombieCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/base/AbstractClientEnv.hpp"
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-void ZombieCmd::print(std::string& os) const {
-    switch (user_action_) {
-        case User::FOB:
-            user_cmd(os, CtsApi::to_string(CtsApi::zombieFob(paths_, process_id_, password_)));
-            break;
-        case User::FAIL:
-            user_cmd(os, CtsApi::to_string(CtsApi::zombieFail(paths_, process_id_, password_)));
-            break;
-        case User::ADOPT:
-            user_cmd(os, CtsApi::to_string(CtsApi::zombieAdopt(paths_, process_id_, password_)));
-            break;
-        case User::REMOVE:
-            user_cmd(os, CtsApi::to_string(CtsApi::zombieRemove(paths_, process_id_, password_)));
-            break;
-        case User::BLOCK:
-            user_cmd(os, CtsApi::to_string(CtsApi::zombieBlock(paths_, process_id_, password_)));
-            break;
-        case User::KILL:
-            user_cmd(os, CtsApi::to_string(CtsApi::zombieKill(paths_, process_id_, password_)));
-            break;
-        default:
-            break;
-    }
-}
-
-void ZombieCmd::print_only(std::string& os) const {
-    switch (user_action_) {
-        case User::FOB:
-            os += CtsApi::to_string(CtsApi::zombieFob(paths_, process_id_, password_));
-            break;
-        case User::FAIL:
-            os += CtsApi::to_string(CtsApi::zombieFail(paths_, process_id_, password_));
-            break;
-        case User::ADOPT:
-            os += CtsApi::to_string(CtsApi::zombieAdopt(paths_, process_id_, password_));
-            break;
-        case User::REMOVE:
-            os += CtsApi::to_string(CtsApi::zombieRemove(paths_, process_id_, password_));
-            break;
-        case User::BLOCK:
-            os += CtsApi::to_string(CtsApi::zombieBlock(paths_, process_id_, password_));
-            break;
-        case User::KILL:
-            os += CtsApi::to_string(CtsApi::zombieKill(paths_, process_id_, password_));
-            break;
-        default:
-            break;
-    }
-}
-
-bool ZombieCmd::equals(ClientToServerCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<ZombieCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (paths_ != the_rhs->paths())
-        return false;
-    if (process_id_ != the_rhs->process_or_remote_id())
-        return false;
-    if (password_ != the_rhs->password())
-        return false;
-    return UserCmd::equals(rhs);
-}
-
-STC_Cmd_ptr ZombieCmd::doHandleRequest(AbstractServer* as) const {
-    switch (user_action_) {
-        case User::FOB:
-            as->update_stats().zombie_fob_++;
-            break;
-        case User::FAIL:
-            as->update_stats().zombie_fail_++;
-            break;
-        case User::ADOPT:
-            as->update_stats().zombie_adopt_++;
-            break;
-        case User::REMOVE:
-            as->update_stats().zombie_remove_++;
-            break;
-        case User::BLOCK:
-            as->update_stats().zombie_block_++;
-            break;
-        case User::KILL:
-            as->update_stats().zombie_kill_++;
-            break;
-    }
-
-    // To uniquely identify a zombie we need path to task and remote_id, This information
-    // is available from the zombie class via get command. However we do not want to expose the password.
-    // Hence the Command level interface  will make do with just the path to the task.
-    // The first zombie whose corresponding task where password does *NOT* match is acted upon
-    if (process_id_.empty() && password_.empty()) {
-        for (const auto& path : paths_) {
-            node_ptr node = as->defs()->findAbsNode(path);
-            Task* task    = nullptr;
-            if (node.get())
-                task = node->isTask();
-            switch (user_action_) {
-                case User::FOB:
-                    as->zombie_ctrl().fobCli(path, task);
-                    break;
-                case User::FAIL:
-                    as->zombie_ctrl().failCli(path, task);
-                    break;
-                case User::ADOPT:
-                    as->zombie_ctrl().adoptCli(path, task);
-                    break;
-                case User::REMOVE:
-                    as->zombie_ctrl().removeCli(path, task);
-                    break;
-                case User::BLOCK:
-                    as->zombie_ctrl().blockCli(path, task);
-                    break;
-                case User::KILL:
-                    as->zombie_ctrl().killCli(path, task);
-                    break;
-            }
-        }
-    }
-    else {
-        // expect a single path, process_id and password only apply for a single task
-        if (paths_.size() == 1) {
-            switch (user_action_) {
-                case User::FOB:
-                    as->zombie_ctrl().fob(paths_[0], process_id_, password_);
-                    break;
-                case User::FAIL:
-                    as->zombie_ctrl().fail(paths_[0], process_id_, password_);
-                    break;
-                case User::ADOPT:
-                    as->zombie_ctrl().adopt(paths_[0], process_id_, password_);
-                    break;
-                case User::REMOVE:
-                    as->zombie_ctrl().remove(paths_[0], process_id_, password_);
-                    break;
-                case User::BLOCK:
-                    as->zombie_ctrl().block(paths_[0], process_id_, password_);
-                    break;
-                case User::KILL:
-                    as->zombie_ctrl().kill(paths_[0], process_id_, password_);
-                    break;
-            }
-        }
-        else {
-            return PreAllocatedReply::error_cmd("ZombieCmd: process_or_remote_id and password cannot be used when "
-                                                "multiple paths are specified. Please specify a single path");
-        }
-    }
-
-    return PreAllocatedReply::ok_cmd();
-}
-
-const char* ZombieCmd::theArg() const {
-
-    switch (user_action_) {
-        case User::FOB:
-            return CtsApi::zombieFobArg();
-            break;
-        case User::FAIL:
-            return CtsApi::zombieFailArg();
-            break;
-        case User::ADOPT:
-            return CtsApi::zombieAdoptArg();
-            break;
-        case User::REMOVE:
-            return CtsApi::zombieRemoveArg();
-            break;
-        case User::BLOCK:
-            return CtsApi::zombieBlockArg();
-            break;
-        case User::KILL:
-            return CtsApi::zombieKillArg();
-            break;
-        default:
-            break;
-    }
-    assert(false);
-    return nullptr;
-}
-
-void ZombieCmd::addOption(boost::program_options::options_description& desc) const {
-    switch (user_action_) {
-
-        case User::FOB: {
-            desc.add_options()(
-                CtsApi::zombieFobArg(),
-                po::value<vector<string>>()->multitoken(),
-                "Locates the task in the servers list of zombies, and sets to fob.\n"
-                "This default behaviour of the child commands(label,event,meter) is to fob\n"
-                "Next time the child commands (init,event,meter,label,abort,complete,wait,queue) communicate\n"
-                "with the server, they will complete successfully (but without updating the node tree)\n"
-                "allowing the job to finish.\n"
-                "The references to the zombie in the server is automatically deleted after 1 hour\n"
-                "  args = list of task paths, at least one expected\n"
-                "  --zombie_fob=/path/to/task1 /path/to/task2");
-            break;
-        }
-        case User::FAIL: {
-            desc.add_options()(CtsApi::zombieFailArg(),
-                               po::value<vector<string>>()->multitoken(),
-                               "Locates the task in the servers list of zombies, and sets to fail.\n"
-                               "Next time a child command (init,event,meter,label,abort,complete) which "
-                               "matches zombie, communicates with the server, will be set to fail.\n"
-                               "Depending on the job setup this may force a abort, the abort will also fail.\n"
-                               "Hence job structure should use 'set -e' in the error trapping functions to prevent\n"
-                               "infinite recursion.\n"
-                               "The references to the zombie in the server is automatically deleted after 1 hour\n"
-                               "  args = list of task paths, at least one expected\n"
-                               "  --zombie_fail=/path/to/task  /path/to/task2");
-            break;
-        }
-        case User::ADOPT: {
-            desc.add_options()(CtsApi::zombieAdoptArg(),
-                               po::value<vector<string>>()->multitoken(),
-                               "Locates the task in the servers list of zombies, and sets to adopt.\n"
-                               "Next time a child command (init,event,meter,label,abort,complete,wait queue) "
-                               "communicates with the server, the password on the zombie is adopted by the task.\n"
-                               "This is only allowed if the process id matches, otherwise an error is issued.\n"
-                               "The zombie reference stored in the server is then deleted.\n"
-                               "  args = list of task paths, at least one expected\n"
-                               "  --zombie_adopt=/path/to/task  /path/to/task2");
-            break;
-        }
-        case User::REMOVE: {
-            desc.add_options()(
-                CtsApi::zombieRemoveArg(),
-                po::value<vector<string>>()->multitoken(),
-                "Locates the task in the servers list of zombies, and removes it.\n"
-                "Since a job typically has many child commands (i.e init, complete, event, meter, label, wait, queue)\n"
-                "the zombie may reappear\n"
-                "  args = list of task paths, at least one expected\n"
-                "  --zombie_remove=/path/to/task  /path/to/task2");
-            break;
-        }
-        case User::BLOCK: {
-            desc.add_options()(CtsApi::zombieBlockArg(),
-                               po::value<vector<string>>()->multitoken(),
-                               "Locates the task in the servers list of zombies, and sets flags to block it.\n"
-                               "This is default behaviour of the child commands(init,abort,complete,wait,queue)\n"
-                               "when the server cannot match the passwords. Each child commands will continue\n"
-                               "attempting to connect to the server for 24 hours, and will then return an error.\n"
-                               "The connection timeout can be configured with environment ECF_TIMEOUT\n"
-                               "  args = list of task paths, at least one expected\n"
-                               "  --zombie_block=/path/to/task  /path/to/task2");
-            break;
-        }
-        case User::KILL: {
-            desc.add_options()(CtsApi::zombieKillArg(),
-                               po::value<vector<string>>()->multitoken(),
-                               "Locates the task in the servers list of zombies, and sets flags to kill\n"
-                               "The kill is done using ECF_KILL_CMD, but using the process_id from the zombie\n"
-                               "The job is allowed to continue until the kill is received\n"
-                               "Can only kill zombies that have an associated Task, hence path zombies\n"
-                               "must be killed manually.\n"
-                               "  arg = list of task paths, at least one expected\n"
-                               "  --zombie_kill=/path/to/task  /path/to/task2");
-            break;
-        }
-        default:
-            assert(false);
-            break;
-    }
-}
-
-void ZombieCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
-    vector<string> args = vm[theArg()].as<vector<string>>();
-    if (ace->debug())
-        dumpVecArgs(theArg(), args);
-
-    // For Command Line Interface only the task_path is provided. Just have to make do.
-    // arg = process_or_remote_id   ( empty for CLI and when multiple paths specified)
-    // arg = password               ( empty for CLI and when multiple paths specified)
-    // arg = paths
-    std::string process_or_remote_id;
-    std::string password;
-
-    std::vector<std::string> options, paths;
-    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
-    if (paths.empty()) {
-        std::stringstream ss;
-        ss << "ZombieCmd: No paths specified. At least one path expected. Paths must begin with a leading '/' "
-              "character\n";
-        throw std::runtime_error(ss.str());
-    }
-    if (paths.size() > 1 && !options.empty()) {
-        std::stringstream ss;
-        ss << "ZombieCmd: process_or_remote_id and password cannot be used when multiple paths are specified. Please "
-              "specify a single path\n";
-        throw std::runtime_error(ss.str());
-    }
-    if (options.size() >= 3) {
-        std::stringstream ss;
-        ss << "ZombieCmd: to many options expected only process_or_remote_id and password and a list of paths.\n";
-        throw std::runtime_error(ss.str());
-    }
-    if (options.size() == 1)
-        process_or_remote_id = options[0];
-    if (options.size() == 2)
-        password = options[1];
-
-    if (ace->get_cli()) {
-        // We are using command line, expect only paths
-        if (!process_or_remote_id.empty()) {
-            throw std::runtime_error(
-                "ZombieCmd:: With the command line interface, we expected only paths i.e /path/to/task");
-        }
-        if (!password.empty()) {
-            throw std::runtime_error(
-                "ZombieCmd:: With the command line interface, we expected only paths i.e /path/to/task");
-        }
-    }
-
-    cmd = std::make_shared<ZombieCmd>(user_action_, paths, process_or_remote_id, password);
-}
-
-std::ostream& operator<<(std::ostream& os, const ZombieCmd& c) {
-    std::string ret;
-    c.print(ret);
-    os << ret;
-    return os;
-}
-
-CEREAL_REGISTER_TYPE(ZombieCmd)
-CEREAL_REGISTER_DYNAMIC_INIT(ZombieCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/cts/user/ZombieCmd.hpp 5.13.0-1/Base/src/ecflow/base/cts/user/ZombieCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/cts/user/ZombieCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/cts/user/ZombieCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,65 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_user_ZombieCmd_HPP
-#define ecflow_base_cts_user_ZombieCmd_HPP
-
-#include "ecflow/base/cts/user/UserCmd.hpp"
-#include "ecflow/core/User.hpp"
-
-class ZombieCmd final : public UserCmd {
-public:
-    ZombieCmd(ecf::User::Action uc,
-              const std::vector<std::string>& paths,
-              const std::string& process_id,
-              const std::string& password)
-        : user_action_(uc),
-          process_id_(process_id),
-          password_(password),
-          paths_(paths) {}
-    explicit ZombieCmd(ecf::User::Action uc = ecf::User::BLOCK) : user_action_(uc) {}
-
-    const std::vector<std::string>& paths() const { return paths_; }
-    const std::string& process_or_remote_id() const { return process_id_; }
-    const std::string& password() const { return password_; }
-
-    void print(std::string&) const override;
-    void print_only(std::string&) const override;
-    bool equals(ClientToServerCmd*) const override;
-
-    const char* theArg() const override;
-    void addOption(boost::program_options::options_description& desc) const override;
-    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
-
-private:
-    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
-    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after handlerequest
-
-    ecf::User::Action user_action_;
-    std::string process_id_; // should be empty for multiple paths and when using CLI
-    std::string password_;   // should be empty for multiple paths and when using CLI
-    std::vector<std::string> paths_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const /*version*/) {
-        ar(cereal::base_class<UserCmd>(this),
-           CEREAL_NVP(user_action_),
-           CEREAL_NVP(process_id_),
-           CEREAL_NVP(password_),
-           CEREAL_NVP(paths_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ZombieCmd&);
-
-CEREAL_FORCE_DYNAMIC_INIT(ZombieCmd)
-
-#endif /* ecflow_base_cts_user_ZombieCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/ssl_connection.cpp 5.13.0-1/Base/src/ecflow/base/ssl_connection.cpp
--- 5.12.4-1/Base/src/ecflow/base/ssl_connection.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ssl_connection.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,76 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/ssl_connection.hpp"
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Log.hpp"
-
-ssl_connection::~ssl_connection() {
-#ifdef DEBUG_CONNECTION
-    if (Ecf::server())
-        std::cout << "SERVER: ssl_connection::~ssl_connection socket_.is_open() = " << socket_.is_open() << "\n\n";
-    else
-        std::cout << "CLIENT: ssl_connection::~ssl_connection socket_.is_open() = " << socket_.is_open() << "\n\n";
-#endif
-}
-
-ssl_connection::ssl_connection(boost::asio::io_service& io_service, boost::asio::ssl::context& context)
-    : socket_(io_service, context) {
-#ifdef DEBUG_CONNECTION
-    if (Ecf::server())
-        std::cout << "SERVER: ssl_connection::ssl_connection\n";
-    else
-        std::cout << "CLIENT: ssl_connection::ssl_connection\n";
-#endif
-    socket_.set_verify_mode(boost::asio::ssl::verify_peer);
-
-    // If we want server to verify client certificate, the use as below:
-    // However this requires that certificate is installed.
-    // if (Ecf::server())
-    // socket_.set_verify_mode(boost::asio::ssl::verify_peer|boost::asio::ssl::verify_fail_if_no_peer_cert); else
-    // socket_.set_verify_mode(boost::asio::ssl::verify_peer);
-    socket_.set_verify_callback([this](bool preverified, boost::asio::ssl::verify_context& ctx) {
-        return this->verify_certificate(preverified, ctx);
-    });
-}
-
-bool ssl_connection::verify_certificate(bool preverified, boost::asio::ssl::verify_context& ctx) {
-    // The verify callback can be used to check whether the certificate that is
-    // being presented is valid for the peer. For example, RFC 2818 describes
-    // the steps involved in doing this for HTTPS. Consult the OpenSSL
-    // documentation for more details. Note that the callback is called once
-    // for each certificate in the certificate chain, starting from the root
-    // certificate authority.
-
-    // In this example we will simply print the certificate's subject name.
-    char subject_name[256];
-    X509* cert = X509_STORE_CTX_get_current_cert(ctx.native_handle());
-    X509_NAME_oneline(X509_get_subject_name(cert), subject_name, 256);
-    // std::cout << "Verifying " << subject_name << "\n";
-
-    return preverified;
-}
-
-void ssl_connection::log_error(const char* msg) {
-    const char* in_context = ", in client";
-    if (Ecf::server())
-        in_context = ", in server";
-    ecf::LogToCout logToCout;
-    LOG(ecf::Log::ERR, msg << in_context);
-}
-
-void ssl_connection::log_archive_error(const char* msg, const std::exception& ae, const std::string& data) {
-    const char* in_context = ", in client";
-    if (Ecf::server())
-        in_context = ", in server";
-    ecf::LogToCout logToCout;
-    LOG(ecf::Log::ERR, msg << ae.what() << in_context << " data:\n" << data);
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/ssl_connection.hpp 5.13.0-1/Base/src/ecflow/base/ssl_connection.hpp
--- 5.12.4-1/Base/src/ecflow/base/ssl_connection.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/ssl_connection.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,232 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_ssl_connection_HPP
-#define ecflow_base_ssl_connection_HPP
-
-#if defined(HPUX)
-    #include <sys/select.h> // hp-ux uses pselect
-#endif
-
-#include <iomanip>
-#include <memory>
-#include <sstream>
-
-#include <boost/asio.hpp>
-#include <boost/asio/ssl.hpp>
-
-#include "ecflow/core/Serialization.hpp"
-
-// #define DEBUG_CONNECTION 1
-#ifdef DEBUG_CONNECTION
-    #include "ecflow/core/Ecf.hpp"
-#endif
-
-///
-/// \brief Serves as the connection between client server
-///
-/// \note If you change this file then Connection.hpp may also need changing
-///
-
-typedef boost::asio::ssl::stream<boost::asio::ip::tcp::socket> ssl_socket;
-
-/// The connection class provides serialisation primitives on top of a socket.
-/**
- * Each message sent using this class consists of:
- * @li An 8-byte header containing the length of the serialized data in
- * hexadecimal.
- * @li The serialized data.
- */
-
-class ssl_connection {
-public:
-    ~ssl_connection();
-
-    ssl_connection(boost::asio::io_service& io_service, boost::asio::ssl::context& context);
-    bool verify_certificate(bool preverified, boost::asio::ssl::verify_context& ctx);
-
-    /// Get the underlying socket. Used for making a connection or for accepting
-    /// an incoming connection.
-    ssl_socket::lowest_layer_type& socket_ll() { return socket_.lowest_layer(); }
-    ssl_socket& socket() { return socket_; }
-
-    /// Asynchronously write a data structure to the socket.
-    template <typename T, typename Handler>
-    void async_write(const T& t, Handler handler) {
-
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: ssl_connection::async_write\n";
-        else
-            std::cout << "CLIENT: ssl_connection::async_write\n";
-        std::cout << "   Serialise the data first so we know how large it is\n";
-#endif
-        // Serialise the data first so we know how large it is.
-        try {
-            ecf::save_as_string(outbound_data_, t);
-        }
-        catch (const std::exception& ae) {
-            // Unable to decode data. Something went wrong, inform the caller.
-            log_archive_error("ssl_connection::async_write, exception ", ae, outbound_data_);
-            boost::system::error_code error(boost::asio::error::invalid_argument);
-            boost::asio::post(socket_.get_executor(), [handler, error]() { handler(error); });
-            return;
-        }
-
-#ifdef DEBUG_CONNECTION
-        std::cout << "   Format the header:\n";
-#endif
-        // Format the header.
-        std::ostringstream header_stream;
-        header_stream << std::setw(header_length) << std::hex << outbound_data_.size();
-        if (!header_stream || header_stream.str().size() != header_length) {
-            // Something went wrong, inform the caller.
-            log_error("ssl_connection::async_write, could not format header");
-            boost::system::error_code error(boost::asio::error::invalid_argument);
-            boost::asio::post(socket_.get_executor(), [handler, error]() { handler(error); });
-            return;
-        }
-        outbound_header_ = header_stream.str();
-
-#ifdef DEBUG_CONNECTION
-        std::cout << "   Write the HEADER and serialised DATA to the socket\n";
-        std::cout << "   outbound_header_.size(" << outbound_header_.size() << ")\n";
-        std::cout << "   outbound_header_:'" << outbound_header_ << "' # this is the size in hex\n";
-        std::cout << "   outbound_data_.size(" << outbound_data_.size() << ")\n";
-        std::cout << "   hdr+data:'" << outbound_header_ << outbound_data_ << "'\n";
-#endif
-
-        // Write the serialized data to the socket. We use "gather-write" to send
-        // both the header and the data in a single write operation.
-        std::vector<boost::asio::const_buffer> buffers;
-        buffers.reserve(2);
-        buffers.emplace_back(boost::asio::buffer(outbound_header_));
-        buffers.emplace_back(boost::asio::buffer(outbound_data_));
-        boost::asio::async_write(
-            socket_, buffers, [handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
-                handler(error);
-            });
-
-#ifdef DEBUG_CONNECTION
-        std::cout << "   END\n";
-#endif
-    }
-
-    /// Asynchronously read a data structure from the socket.
-    template <typename T, typename Handler>
-    void async_read(T& t, Handler handler) {
-
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: ssl_connection::async_read\n";
-        else
-            std::cout << "CLIENT: ssl_connection::async_read\n";
-#endif
-
-        // Issue a read operation to read exactly the number of bytes in a header.
-        boost::asio::async_read(
-            socket_,
-            boost::asio::buffer(inbound_header_),
-            [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
-                this->handle_read_header(error, t, handler);
-            });
-    }
-
-private:
-    /// Handle a completed read of a message header.
-    template <typename T, typename Handler>
-    void handle_read_header(const boost::system::error_code& e, T& t, Handler handler) {
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: ssl_onnection::handle_read_header\n";
-        else
-            std::cout << "CLIENT: ssl_connection::handle_read_header\n";
-        std::cout << "   header:'" << std::string(inbound_header_, header_length)
-                  << "'  # this size of payload in hex\n";
-#endif
-        if (e) {
-            handler(e);
-        }
-        else {
-            // Determine the length of the serialized data.
-            std::istringstream is(std::string(inbound_header_, header_length));
-            std::size_t inbound_data_size = 0;
-            if (!(is >> std::hex >> inbound_data_size)) {
-
-                // Header doesn't seem to be valid. Inform the caller.
-                std::string err = "ssl_connection::handle_read_header: invalid header : " +
-                                  std::string(inbound_header_, header_length);
-                log_error(err.c_str());
-                handler(boost::asio::error::invalid_argument);
-                return;
-            }
-
-            // Start an asynchronous call to receive the data.
-            inbound_data_.resize(inbound_data_size);
-            boost::asio::async_read(
-                socket_,
-                boost::asio::buffer(inbound_data_),
-                [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
-                    this->handle_read_data(error, t, handler);
-                });
-        }
-    }
-
-    /// Handle a completed read of message data.
-    template <typename T, typename Handler>
-    void handle_read_data(const boost::system::error_code& e, T& t, Handler handler) {
-#ifdef DEBUG_CONNECTION
-        if (Ecf::server())
-            std::cout << "SERVER: ssl_connection::handle_read_data\n";
-        else
-            std::cout << "CLIENT: ssl_connection::handle_read_data\n";
-#endif
-
-        if (e) {
-            handler(e);
-        }
-        else {
-            // Extract the data structure from the data just received.
-            std::string archive_data(&inbound_data_[0], inbound_data_.size());
-            try {
-#ifdef DEBUG_CONNECTION
-                std::cout << "   inbound_data_.size(" << inbound_data_.size() << ") typeid(" << typeid(t).name()
-                          << ")\n";
-                std::cout << "   '" << archive_data << "'\n";
-#endif
-                ecf::restore_from_string(archive_data, t);
-            }
-            catch (std::exception& e) {
-                log_archive_error("ssl_connection::handle_read_data, Unable to decode data :", e, archive_data);
-                handler(boost::asio::error::invalid_argument);
-                return;
-            }
-
-            // Inform caller that data has been received ok.
-            handler(e);
-        }
-    }
-
-private:
-    static void log_error(const char* msg);
-    static void log_archive_error(const char* msg, const std::exception& ae, const std::string& data);
-
-private:
-    ssl_socket socket_;                  /// The underlying socket.
-    std::string outbound_header_;        /// Holds an out-bound header.
-    std::string outbound_data_;          /// Holds the out-bound data.
-    enum { header_length = 8 };          /// The size of a fixed length header.
-    char inbound_header_[header_length]; /// Holds an in-bound header.
-    std::vector<char> inbound_data_;     /// Holds the in-bound data.
-};
-
-typedef std::shared_ptr<ssl_connection> ssl_connection_ptr;
-
-#endif /* ecflow_base_ssl_connection_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/BlockClientZombieCmd.hpp"
-
-#include <iostream>
-
-std::string BlockClientZombieCmd::print() const {
-    switch (zombie_type_) {
-        case ecf::Child::USER:
-            return "cmd:BlockClientZombieCmd: user";
-        case ecf::Child::PATH:
-            return "cmd:BlockClientZombieCmd: path";
-        case ecf::Child::ECF:
-            return "cmd:BlockClientZombieCmd: ecf";
-        case ecf::Child::ECF_PID:
-            return "cmd:BlockClientZombieCmd: ecf_pid";
-        case ecf::Child::ECF_PID_PASSWD:
-            return "cmd:BlockClientZombieCmd: ecf_pid_passwd";
-        case ecf::Child::ECF_PASSWD:
-            return "cmd:BlockClientZombieCmd: ecf_passwd";
-        case ecf::Child::NOT_SET:
-            return "cmd:BlockClientZombieCmd: not_set";
-    }
-    assert(false); // unknown command
-    return "cmd:Unknown??";
-}
-
-// Client context
-bool BlockClientZombieCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        std::cout << "  BlockClientZombieCmd::handle_server_response BLOCK_CLIENT_ZOMBIE "
-                  << ecf::Child::to_string(zombie_type_) << "\n";
-    server_reply.set_block_client_zombie_detected(); // requires further work, by ClientInvoker
-    return false;                                    // false means fall through and try again, i.e BLOCK client
-}
-
-bool BlockClientZombieCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<BlockClientZombieCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (zombie_type_ != the_rhs->zombie_type())
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::ostream& operator<<(std::ostream& os, const BlockClientZombieCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/BlockClientZombieCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_BlockClientZombieCmd_HPP
-#define ecflow_base_stc_BlockClientZombieCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/core/Child.hpp"
-
-//
-// This command send the zombie type to the client
-// For the moment we simply block for zombie, but the client
-// in the future could do different things depending on the zombie type
-//
-class BlockClientZombieCmd final : public ServerToClientCmd {
-public:
-    explicit BlockClientZombieCmd(ecf::Child::ZombieType zt) : zombie_type_(zt) {}
-    BlockClientZombieCmd() = default;
-
-    void init(ecf::Child::ZombieType zt) { zombie_type_ = zt; } // server context
-    ecf::Child::ZombieType zombie_type() const { return zombie_type_; }
-
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool
-    handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override; // client context
-
-    bool is_returnable_in_group_cmd() const override { return false; } /// used by group command
-
-private:
-    ecf::Child::ZombieType zombie_type_{ecf::Child::NOT_SET};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(zombie_type_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const BlockClientZombieCmd&);
-
-#endif /* ecflow_base_stc_BlockClientZombieCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/DefsCache.cpp 5.13.0-1/Base/src/ecflow/base/stc/DefsCache.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/DefsCache.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/DefsCache.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/DefsCache.hpp"
-
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-
-// =====================================================================================================
-// #define DEBUG_SERVER_SYNC 1
-// #define DEBUG_CLIENT_SYNC 1
-#ifdef DEBUG_SERVER_SYNC
-    #include <iostream>
-#endif
-
-using namespace std;
-using namespace boost;
-
-// ===========================================================================================
-// CACHE: the deserialization costs, so that if multiple clients request the full defs
-//        we can improve the performance, by only performing that once for each state change.
-std::string DefsCache::full_server_defs_as_string_ = "";
-unsigned int DefsCache::state_change_no_           = 0;
-unsigned int DefsCache::modify_change_no_          = 0;
-
-void DefsCache::update_cache_if_state_changed(Defs* defs) {
-    // See if there was a state change *OR* if cache is empty
-    if (state_change_no_ != Ecf::state_change_no() || modify_change_no_ != Ecf::modify_change_no() ||
-        full_server_defs_as_string_.empty()) {
-        update_cache(defs);
-    }
-#ifdef DEBUG_SERVER_SYNC
-    else {
-        cout << ": *cache* up to date";
-    }
-#endif
-}
-
-void DefsCache::update_cache(Defs* defs) {
-#ifdef DEBUG_SERVER_SYNC
-    cout << ": *updating* cache";
-#endif
-    defs->save_as_string(full_server_defs_as_string_, PrintStyle::NET); // update cache
-    state_change_no_  = Ecf::state_change_no();
-    modify_change_no_ = Ecf::modify_change_no();
-}
-
-defs_ptr DefsCache::restore_defs_from_string(const std::string& archive_data) {
-#ifdef DEBUG_CLIENT_SYNC
-    cout << ": DefsCache::restore_defs_from_string: archive_data.size(" << archive_data.size() << ")";
-#endif
-
-    defs_ptr defs = Defs::create();
-    try {
-        // cout << "archive_data:\n" << archive_data << "\n";
-        defs->restore_from_string(archive_data);
-    }
-    catch (std::exception& e) {
-        ecf::LogToCout logToCout;
-        LOG(ecf::Log::ERR, "DefsCache::restore_defs_from_string " << e.what());
-        throw;
-    }
-
-#ifdef DEBUG_CLIENT_SYNC
-    if (defs.get())
-        cout << ": valid defs";
-    else
-        cout << ": *empty* defs?";
-#endif
-    return defs;
-}
-
-defs_ptr DefsCache::restore_defs_from_string() {
-    // Used in Test when no client/server
-    return restore_defs_from_string(full_server_defs_as_string_);
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/DefsCache.hpp 5.13.0-1/Base/src/ecflow/base/stc/DefsCache.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/DefsCache.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/DefsCache.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,67 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_DefsCache_HPP
-#define ecflow_base_cts_DefsCache_HPP
-
-#include "ecflow/node/NodeFwd.hpp"
-
-//================================================================================
-// Cache the de-serialisation cost, in the *SERVER* when returning the FULL definition
-// When there are no state changes, we can just return the cache string for other clients
-// Thereby saving time in the server and client for de-serialisation.
-// Here we are trading memory for speed:
-//
-//  Current for each client request we have:
-//      client1:  --------------> get---------------> Server
-//                serialise---------<----de-serialize
-//
-//      client2:  --------------> get---------------> Server
-//                serialise---------<----de-serialize
-//
-//      client3:  --------------> get---------------> Server
-//                serialise---------<----de-serialize
-//
-// By caching the de-serialisation process, we can speed up the downloads.
-// However whenever there is a state change we need to update the cache
-//
-//      client1:  --------------> get---------------> Server
-//                serialise------<----de-serialisation
-//
-//      client2:  --------------> get---------------> Server
-//                serialise---------<----return cache
-//
-//      client3:  --------------> get---------------> Server
-//                serialise---------<----return cache
-//================================================================================
-class DefsCache {
-public:
-    DefsCache()                            = delete;
-    DefsCache(const DefsCache&)            = delete;
-    DefsCache& operator=(const DefsCache&) = delete;
-
-    // Server side
-    static void update_cache_if_state_changed(Defs* defs);
-    static void update_cache(Defs* defs);
-
-    // Client side
-    static defs_ptr restore_defs_from_string(const std::string&);
-    static defs_ptr restore_defs_from_string(); // used in test
-
-private:
-    friend class SSyncCmd;
-    friend class DefsCmd;
-
-    static std::string full_server_defs_as_string_;
-    static unsigned int state_change_no_;  // detect state change in defs across clients
-    static unsigned int modify_change_no_; // detect state change in defs across clients
-};
-
-#endif /* ecflow_base_cts_DefsCache_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/DefsCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/DefsCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/DefsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/DefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,92 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/DefsCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace boost;
-
-//=====================================================================================
-// The defs command returns the full definition back to the client
-
-DefsCmd::DefsCmd(AbstractServer* as, bool save_edit_history) {
-    init(as, save_edit_history); // save edit history
-}
-
-void DefsCmd::init(AbstractServer* as, bool save_edit_history) {
-    /// Return the current value of the state change no. So the that
-    /// the next call to get the SSYncCmd , we need only return what's changed
-    Defs* server_defs = as->defs().get();
-    server_defs->set_state_change_no(Ecf::state_change_no());
-    server_defs->set_modify_change_no(Ecf::modify_change_no());
-    server_defs->save_edit_history(save_edit_history);
-
-    // The CACHE is only updated if state/modify numbers change, hence does not take into account suite CLOCK
-    // However DefsCmd should always return the most up to date server contents.
-    DefsCache::update_cache(server_defs);
-}
-
-bool DefsCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<DefsCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (!ServerToClientCmd::equals(rhs))
-        return false;
-    return true;
-}
-
-std::string DefsCmd::print() const {
-    return "cmd:DefsCmd [ defs ]";
-}
-
-// Called in client
-bool DefsCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        std::cout << "  DefsCmd::handle_server_response show_state = " << PrintStyle::to_string(cts_cmd->show_style())
-                  << "\n";
-
-    // If we asked for the defs node tree from the server, then this is what we should have got back.
-    // ** Keep existing defs in memory, until a new one is requested. This allows clients
-    // ** to continue using this defs, in between other api calls, until a new defs is requested.
-
-    defs_ptr defs = DefsCache::restore_defs_from_string(full_server_defs_as_string_);
-
-    if (server_reply.cli() && !cts_cmd->group_cmd()) {
-        /// This Could be part of a group command, hence ONLY show defs if NOT group command
-        PrintStyle style(cts_cmd->show_style());
-
-        if (!PrintStyle::is_persist_style(cts_cmd->show_style())) {
-            /// Auto generate externs, before writing to standard out. This can be expensive since
-            /// All the trigger references need to to be resolved. & AST need to be created first
-            /// The old spirit based parsing, horrendously, slow. Can't use Spirit QI, till IBM pull support it
-            defs->auto_add_externs();
-        }
-        std::cout << *defs;
-    }
-    else {
-        server_reply.set_sync(true);      // always in sync when getting the full defs
-        server_reply.set_full_sync(true); // Done a full sync, as opposed to incremental
-        server_reply.set_client_defs(defs);
-    }
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const DefsCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/DefsCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/DefsCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/DefsCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/DefsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_cts_DefsCmd_HPP
-#define ecflow_base_cts_DefsCmd_HPP
-
-#include "ecflow/base/stc/DefsCache.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-class AbstractServer;
-
-//================================================================================
-// Paired with CtsNodeCmd(GET)
-// Client---CtsNodeCmd(GET)---->Server-----(DefsCmd | SNodeCmd)--->client:
-//================================================================================
-class DefsCmd final : public ServerToClientCmd {
-public:
-    explicit DefsCmd(AbstractServer* as, bool save_edit_history = false);
-    DefsCmd() = default;
-
-    void init(AbstractServer* as, bool save_edit_history);
-
-    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    void cleanup() override {
-        std::string().swap(full_server_defs_as_string_);
-    } /// run in the server, after command send to client
-
-private:
-    std::string full_server_defs_as_string_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this));
-
-        if (Archive::is_saving::value) {
-            // Avoid copying the string. As this could be very large
-            ar& DefsCache::full_server_defs_as_string_;
-        }
-        else {
-            ar & full_server_defs_as_string_;
-        }
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const DefsCmd&);
-
-#endif /* ecflow_base_cts_DefsCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/ErrorCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/ErrorCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/ErrorCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/ErrorCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/ErrorCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/Log.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-ErrorCmd::ErrorCmd(const std::string& errorMsg) {
-    init(errorMsg);
-}
-
-void ErrorCmd::init(const std::string& errorMsg) {
-    // #ifdef DEBUG
-    // std::cout << ErrorCmd::init " << errorMsg << "\n";
-    // LogToCout toCoutAsWell;
-    // #endif
-
-    LOG_ASSERT(!errorMsg.empty(), "");
-    error_msg_ = errorMsg;
-
-    // Log the error, Remove any "/n" as the log file will add this automatically
-    size_t pos = error_msg_.rfind("\n");
-    if (pos != string::npos)
-        error_msg_.erase(error_msg_.begin() + pos);
-    ecf::log(Log::ERR, error_msg_); // will automatically add end of line
-}
-
-std::string ErrorCmd::print() const {
-    std::string os;
-    os += "cmd:Error [ ";
-    os += error_msg_;
-    os += " ]";
-    return os;
-}
-
-bool ErrorCmd::equals(ServerToClientCmd* rhs) const {
-    return (dynamic_cast<ErrorCmd*>(rhs)) ? ServerToClientCmd::equals(rhs) : false;
-}
-
-bool ErrorCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        std::cout << "  ErrorCmd::handle_server_response " << error_msg_ << "\n";
-
-    std::string ss;
-    ss += "Error: request( ";
-    ss += cts_cmd->print_short();
-    ss += " ) failed!  Server reply: ";
-    ss += error_msg_;
-    ss += "\n";
-    server_reply.set_error_msg(server_reply.get_error_msg() + ss); // append in-case multiple errors from group cmd
-    return false;
-}
-
-std::ostream& operator<<(std::ostream& os, const ErrorCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/ErrorCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/ErrorCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/ErrorCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/ErrorCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_ErrorCmd_HPP
-#define ecflow_base_stc_ErrorCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-class ErrorCmd final : public ServerToClientCmd {
-public:
-    explicit ErrorCmd(const std::string& errorMsg);
-    ErrorCmd() : ServerToClientCmd() {}
-
-    void init(const std::string& errorMsg);
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
-
-    std::string error() const override { return error_msg_; }   /// Used by test
-    bool ok() const override { return false; }                  /// Used by group command
-    void cleanup() override { std::string().swap(error_msg_); } /// run in the server, after command send to client
-
-private:
-    std::string error_msg_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(error_msg_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ErrorCmd&);
-
-#endif /* ecflow_base_stc_ErrorCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/GroupSTCCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/GroupSTCCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/GroupSTCCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/GroupSTCCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,163 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/GroupSTCCmd.hpp"
-
-#include "ecflow/base/WhyCmd.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-std::string GroupSTCCmd::print() const {
-    return "cmd:GroupSTCCmd";
-}
-
-bool GroupSTCCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<GroupSTCCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-
-    const std::vector<STC_Cmd_ptr>& rhsCmdVec = the_rhs->cmdVec();
-    if (cmdVec_.size() != rhsCmdVec.size())
-        return false;
-
-    for (size_t i = 0; i < cmdVec_.size(); i++) {
-        if (!cmdVec_[i]->equals(rhsCmdVec[i].get())) {
-            return false;
-        }
-    }
-
-    return ServerToClientCmd::equals(rhs);
-}
-
-bool GroupSTCCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        std::cout << "  GroupSTCCmd::handle_server_response\n";
-
-    bool ret_flag = true;
-    for (STC_Cmd_ptr subCmd : cmdVec_) {
-        if (!subCmd->handle_server_response(server_reply, cts_cmd, debug))
-            ret_flag = false; // one of the commands failed
-    }
-    if (!server_reply.cli())
-        return ret_flag;
-
-    /// CLI called from the command line.
-    /// This assumes the DefsCmd::handle_server_response() | SNodeCmd::handle_server_response has been called
-    /// this will populate ServerReply with the defs/node returned from the server
-    defs_ptr defs = server_reply.client_defs();
-    node_ptr node = server_reply.client_node();
-
-    if (defs.get() || node.get()) {
-        if (debug)
-            std::cout << "   GroupSTCCmd::handle_server_response *get* | *sync* | *sync_full* called\n";
-
-        /// client --group="get; show"         # where get will call DefsCmd will return defs, from the server
-        /// client --group="get; show state"   # where get will call DefsCmd will return defs, from the server
-        /// client --group="get /s1; show state"   # where get will call DefsCmd will return defs, from the server
-        /// client --group="sync_full; show"       # similar to get return defs, from the server
-        /// client --group="sync 1 0 0; show"      # where sync will call SyncCmd will return defs, from the server
-        ///                                        # will return those suites with handle 1
-
-        // Print out the data that was received from server. as a part of get request.
-        // The server cannot do a show, it MUST be done at the Client side
-        // The show request is only valid if the out bound request to the server
-        PrintStyle::Type_t style = cts_cmd->show_style();
-        if (style != PrintStyle::NOTHING) {
-            if (debug)
-                std::cout << "   GroupSTCCmd::handle_server_response *show* was called " << PrintStyle::to_string(style)
-                          << "\n";
-            PrintStyle print_style(style);
-            if (defs.get()) {
-
-                /// Auto generate externs, before writing to standard out. This can be expensive since
-                /// All the trigger references need to to be resolved. & AST need to be created first
-                /// The old spirit based parsing is horrendously, slow. Can't use Spirit QI, till IBM support it
-                if (!PrintStyle::is_persist_style(cts_cmd->show_style())) {
-                    defs->auto_add_externs();
-                }
-
-                std::cout << *defs.get();
-            }
-            else {
-                if (node.get()) {
-                    Suite* suite = node->isSuite();
-                    if (suite)
-                        std::cout << *suite << "\n";
-                    Family* fam = node->isFamily();
-                    if (fam)
-                        std::cout << *fam << "\n";
-                    Task* task = node->isTask();
-                    if (task)
-                        std::cout << *task << "\n";
-                }
-            }
-        }
-    }
-
-    std::string nodePath;
-    if (cts_cmd->why_cmd(nodePath) && defs.get()) {
-        if (debug)
-            std::cout << "  GroupSTCCmd::handle_server_response *why* was called\n";
-
-        /// client --group="get; why"          # where get will call DefsCmd will return defs, from the server
-        /// client --group="get; why <path>"   # where get will call DefsCmd will return defs, from the server
-        WhyCmd cmd(defs, nodePath);
-        std::cout << cmd.why() << "\n";
-    }
-
-    return ret_flag;
-}
-
-void GroupSTCCmd::addChild(STC_Cmd_ptr childCmd) {
-    LOG_ASSERT(childCmd.get(), ""); // Dont add NULL children
-    cmdVec_.push_back(childCmd);
-}
-
-// these two must be opposite of each other
-bool GroupSTCCmd::ok() const {
-    for (const auto& i : cmdVec_) {
-        if (!i->ok())
-            return false; // if child is ErrorCmd will return false
-    }
-    return true;
-}
-
-void GroupSTCCmd::cleanup() {
-    /// After the command has run this function can be used to reclaim memory
-    for (auto& cmd : cmdVec_) {
-        cmd->cleanup();
-    }
-}
-
-std::string GroupSTCCmd::error() const {
-    std::string ret;
-    for (const auto& i : cmdVec_) {
-        std::string error_str = i->error();
-        if (!error_str.empty()) {
-            ret += error_str;
-            ret += "\n";
-        }
-    }
-    return ret;
-}
-
-std::ostream& operator<<(std::ostream& os, const GroupSTCCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/GroupSTCCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/GroupSTCCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/GroupSTCCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/GroupSTCCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_GroupSTCCmd_HPP
-#define ecflow_base_stc_GroupSTCCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-class GroupSTCCmd final : public ServerToClientCmd {
-public:
-    GroupSTCCmd() : ServerToClientCmd() {}
-
-    void cleanup() override; /// After the command has run this function can be used to reclaim memory
-
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-
-    void addChild(STC_Cmd_ptr childCmd);
-    const std::vector<STC_Cmd_ptr>& cmdVec() const { return cmdVec_; }
-
-    // these two must be opposite of each other
-    bool ok() const override;
-    std::string error() const override;
-
-private:
-    std::vector<STC_Cmd_ptr> cmdVec_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(cmdVec_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const GroupSTCCmd&);
-
-#endif /* ecflow_base_stc_GroupSTCCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/PreAllocatedReply.cpp 5.13.0-1/Base/src/ecflow/base/stc/PreAllocatedReply.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/PreAllocatedReply.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/PreAllocatedReply.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,200 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-
-#include "ecflow/base/stc/BlockClientZombieCmd.hpp"
-#include "ecflow/base/stc/DefsCmd.hpp"
-#include "ecflow/base/stc/ErrorCmd.hpp"
-#include "ecflow/base/stc/GroupSTCCmd.hpp"
-#include "ecflow/base/stc/SClientHandleCmd.hpp"
-#include "ecflow/base/stc/SClientHandleSuitesCmd.hpp"
-#include "ecflow/base/stc/SNewsCmd.hpp"
-#include "ecflow/base/stc/SNodeCmd.hpp"
-#include "ecflow/base/stc/SServerLoadCmd.hpp"
-#include "ecflow/base/stc/SStatsCmd.hpp"
-#include "ecflow/base/stc/SStringCmd.hpp"
-#include "ecflow/base/stc/SStringVecCmd.hpp"
-#include "ecflow/base/stc/SSuitesCmd.hpp"
-#include "ecflow/base/stc/SSyncCmd.hpp"
-#include "ecflow/base/stc/StcCmd.hpp"
-#include "ecflow/base/stc/ZombieGetCmd.hpp"
-
-STC_Cmd_ptr PreAllocatedReply::stc_cmd_                  = std::make_shared<StcCmd>();
-STC_Cmd_ptr PreAllocatedReply::defs_cmd_                 = std::make_shared<DefsCmd>();
-STC_Cmd_ptr PreAllocatedReply::node_cmd_                 = std::make_shared<SNodeCmd>();
-STC_Cmd_ptr PreAllocatedReply::stats_cmd_                = std::make_shared<SStatsCmd>();
-STC_Cmd_ptr PreAllocatedReply::suites_cmd_               = std::make_shared<SSuitesCmd>();
-STC_Cmd_ptr PreAllocatedReply::zombie_get_cmd_           = std::make_shared<ZombieGetCmd>();
-STC_Cmd_ptr PreAllocatedReply::error_cmd_                = std::make_shared<ErrorCmd>();
-STC_Cmd_ptr PreAllocatedReply::client_handle_cmd_        = std::make_shared<SClientHandleCmd>();
-STC_Cmd_ptr PreAllocatedReply::client_handle_suites_cmd_ = std::make_shared<SClientHandleSuitesCmd>();
-STC_Cmd_ptr PreAllocatedReply::string_cmd_               = std::make_shared<SStringCmd>();
-STC_Cmd_ptr PreAllocatedReply::string_vec_cmd_           = std::make_shared<SStringVecCmd>();
-STC_Cmd_ptr PreAllocatedReply::server_load_cmd_          = std::make_shared<SServerLoadCmd>();
-STC_Cmd_ptr PreAllocatedReply::news_cmd_                 = std::make_shared<SNewsCmd>();
-STC_Cmd_ptr PreAllocatedReply::sync_cmd_                 = std::make_shared<SSyncCmd>();
-STC_Cmd_ptr PreAllocatedReply::block_client_zombie_cmd_  = std::make_shared<BlockClientZombieCmd>();
-
-STC_Cmd_ptr PreAllocatedReply::ok_cmd() {
-    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
-    cmd->init(StcCmd::OK);
-    return stc_cmd_;
-}
-STC_Cmd_ptr PreAllocatedReply::block_client_server_halted_cmd() {
-    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
-    cmd->init(StcCmd::BLOCK_CLIENT_SERVER_HALTED);
-    return stc_cmd_;
-}
-STC_Cmd_ptr PreAllocatedReply::block_client_on_home_server_cmd() {
-    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
-    cmd->init(StcCmd::BLOCK_CLIENT_ON_HOME_SERVER);
-    return stc_cmd_;
-}
-STC_Cmd_ptr PreAllocatedReply::delete_all_cmd() {
-    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
-    cmd->init(StcCmd::DELETE_ALL);
-    return stc_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::block_client_zombie_cmd(ecf::Child::ZombieType zt) {
-    auto* cmd = dynamic_cast<BlockClientZombieCmd*>(block_client_zombie_cmd_.get());
-    cmd->init(zt);
-    return block_client_zombie_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::defs_cmd(AbstractServer* as, bool save_edit_history) {
-    auto* cmd = dynamic_cast<DefsCmd*>(defs_cmd_.get());
-    cmd->init(as, save_edit_history);
-    return defs_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::node_cmd(AbstractServer* as, node_ptr node) {
-    auto* cmd = dynamic_cast<SNodeCmd*>(node_cmd_.get());
-    cmd->init(as, node);
-    return node_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::stats_cmd(AbstractServer* as) {
-    auto* cmd = dynamic_cast<SStatsCmd*>(stats_cmd_.get());
-    cmd->init(as);
-    return stats_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::suites_cmd(AbstractServer* as) {
-    auto* cmd = dynamic_cast<SSuitesCmd*>(suites_cmd_.get());
-    cmd->init(as);
-    return suites_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::zombie_get_cmd(AbstractServer* as) {
-    auto* cmd = dynamic_cast<ZombieGetCmd*>(zombie_get_cmd_.get());
-    cmd->init(as);
-    return zombie_get_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::error_cmd(const std::string& error_msg) {
-    auto* cmd = dynamic_cast<ErrorCmd*>(error_cmd_.get());
-    cmd->init(error_msg);
-    return error_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::client_handle_cmd(int handle) {
-    auto* cmd = dynamic_cast<SClientHandleCmd*>(client_handle_cmd_.get());
-    cmd->init(handle);
-    return client_handle_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::client_handle_suites_cmd(AbstractServer* as) {
-    auto* cmd = dynamic_cast<SClientHandleSuitesCmd*>(client_handle_suites_cmd_.get());
-    cmd->init(as);
-    return client_handle_suites_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::string_cmd(const std::string& any_string) {
-    auto* cmd = dynamic_cast<SStringCmd*>(string_cmd_.get());
-    cmd->init(any_string);
-    return string_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::string_vec_cmd(const std::vector<std::string>& vec) {
-    auto* cmd = dynamic_cast<SStringVecCmd*>(string_vec_cmd_.get());
-    cmd->init(vec);
-    return string_vec_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::server_load_cmd(const std::string& log_file_path) {
-    auto* cmd = dynamic_cast<SServerLoadCmd*>(server_load_cmd_.get());
-    cmd->init(log_file_path);
-    return server_load_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::news_cmd(unsigned int client_handle,
-                                        unsigned int client_state_change_no,
-                                        unsigned int client_modify_change_no,
-                                        AbstractServer* as) {
-    auto* cmd = dynamic_cast<SNewsCmd*>(news_cmd_.get());
-    cmd->init(client_handle, client_state_change_no, client_modify_change_no, as);
-    return news_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::sync_cmd(unsigned int client_handle,
-                                        unsigned int client_state_change_no,
-                                        unsigned int client_modify_change_no,
-                                        AbstractServer* as) {
-    auto* cmd = dynamic_cast<SSyncCmd*>(sync_cmd_.get());
-    cmd->init(client_handle,
-              client_state_change_no,
-              client_modify_change_no,
-              false /*full sync*/,
-              false /*sync suite clock*/,
-              as);
-    return sync_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::sync_clock_cmd(unsigned int client_handle,
-                                              unsigned int client_state_change_no,
-                                              unsigned int client_modify_change_no,
-                                              AbstractServer* as) {
-    auto* cmd = dynamic_cast<SSyncCmd*>(sync_cmd_.get());
-    cmd->init(client_handle,
-              client_state_change_no,
-              client_modify_change_no,
-              false /*full sync*/,
-              true /*sync suite clock*/,
-              as);
-    return sync_cmd_;
-}
-
-STC_Cmd_ptr PreAllocatedReply::sync_full_cmd(unsigned int client_handle, AbstractServer* as) {
-    auto* cmd = dynamic_cast<SSyncCmd*>(sync_cmd_.get()); // can reuse the same command
-    cmd->init(client_handle, 0, 0, true /*full sync*/, false /*sync suite clock*/, as);
-    return sync_cmd_;
-}
-
-// ==============================================================================
-// Serialisation export
-
-CEREAL_REGISTER_TYPE(DefsCmd)
-CEREAL_REGISTER_TYPE(SNodeCmd)
-CEREAL_REGISTER_TYPE(SStringCmd)
-CEREAL_REGISTER_TYPE(SStringVecCmd)
-CEREAL_REGISTER_TYPE(SServerLoadCmd)
-CEREAL_REGISTER_TYPE(GroupSTCCmd)
-CEREAL_REGISTER_TYPE(ErrorCmd)
-CEREAL_REGISTER_TYPE(StcCmd)
-CEREAL_REGISTER_TYPE(SSyncCmd)
-CEREAL_REGISTER_TYPE(SNewsCmd)
-CEREAL_REGISTER_TYPE(SStatsCmd)
-CEREAL_REGISTER_TYPE(SSuitesCmd)
-CEREAL_REGISTER_TYPE(SClientHandleCmd)
-CEREAL_REGISTER_TYPE(SClientHandleSuitesCmd)
-CEREAL_REGISTER_TYPE(ZombieGetCmd)
-CEREAL_REGISTER_TYPE(BlockClientZombieCmd)
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/PreAllocatedReply.hpp 5.13.0-1/Base/src/ecflow/base/stc/PreAllocatedReply.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/PreAllocatedReply.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/PreAllocatedReply.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,82 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_PreAllocatedReply_HPP
-#define ecflow_base_stc_PreAllocatedReply_HPP
-
-#include <string>
-
-#include "ecflow/base/Cmd.hpp"
-#include "ecflow/core/Child.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-class AbstractServer;
-
-// class PreAllocatedReply:
-// This class pre allocates the replies back to the client
-// This will help to reduce memory fragmentation.
-// Since the commands are re-used those commands with state,
-// should be cleared first
-class PreAllocatedReply {
-public:
-    PreAllocatedReply()                                    = delete;
-    PreAllocatedReply(const PreAllocatedReply&)            = delete;
-    PreAllocatedReply& operator=(const PreAllocatedReply&) = delete;
-
-    static STC_Cmd_ptr ok_cmd();
-    static STC_Cmd_ptr block_client_server_halted_cmd();
-    static STC_Cmd_ptr block_client_on_home_server_cmd();
-    static STC_Cmd_ptr block_client_zombie_cmd(ecf::Child::ZombieType zt);
-    static STC_Cmd_ptr delete_all_cmd();
-
-    static STC_Cmd_ptr defs_cmd(AbstractServer*, bool save_edit_history);
-    static STC_Cmd_ptr node_cmd(AbstractServer*, node_ptr);
-    static STC_Cmd_ptr stats_cmd(AbstractServer*);
-    static STC_Cmd_ptr suites_cmd(AbstractServer*);
-    static STC_Cmd_ptr zombie_get_cmd(AbstractServer*);
-    static STC_Cmd_ptr error_cmd(const std::string& error_msg);
-    static STC_Cmd_ptr client_handle_cmd(int handle);
-    static STC_Cmd_ptr client_handle_suites_cmd(AbstractServer*);
-    static STC_Cmd_ptr string_cmd(const std::string& any_string);
-    static STC_Cmd_ptr string_vec_cmd(const std::vector<std::string>&);
-    static STC_Cmd_ptr server_load_cmd(const std::string& any_string);
-    static STC_Cmd_ptr news_cmd(unsigned int client_handle,
-                                unsigned int client_state_change_no,
-                                unsigned int client_modify_change_no,
-                                AbstractServer* as);
-    static STC_Cmd_ptr sync_cmd(unsigned int client_handle,
-                                unsigned int client_state_change_no,
-                                unsigned int client_modify_change_no,
-                                AbstractServer* as);
-    static STC_Cmd_ptr sync_clock_cmd(unsigned int client_handle,
-                                      unsigned int client_state_change_no,
-                                      unsigned int client_modify_change_no,
-                                      AbstractServer* as);
-    static STC_Cmd_ptr sync_full_cmd(unsigned int client_handle, AbstractServer* as);
-
-private:
-    static STC_Cmd_ptr stc_cmd_;
-    static STC_Cmd_ptr defs_cmd_;
-    static STC_Cmd_ptr node_cmd_;
-    static STC_Cmd_ptr stats_cmd_;
-    static STC_Cmd_ptr suites_cmd_;
-    static STC_Cmd_ptr zombie_get_cmd_;
-    static STC_Cmd_ptr error_cmd_;
-    static STC_Cmd_ptr client_handle_cmd_;
-    static STC_Cmd_ptr client_handle_suites_cmd_;
-    static STC_Cmd_ptr string_cmd_;
-    static STC_Cmd_ptr string_vec_cmd_;
-    static STC_Cmd_ptr server_load_cmd_;
-    static STC_Cmd_ptr news_cmd_;
-    static STC_Cmd_ptr sync_cmd_;
-    static STC_Cmd_ptr block_client_zombie_cmd_;
-};
-
-#endif /* ecflow_base_stc_PreAllocatedReply_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SClientHandleCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/core/Converter.hpp"
-
-using namespace ecf;
-using namespace std;
-
-bool SClientHandleCmd::equals(ServerToClientCmd* rhs) const {
-    return (dynamic_cast<SClientHandleCmd*>(rhs)) ? ServerToClientCmd::equals(rhs) : false;
-}
-
-std::string SClientHandleCmd::print() const {
-    string os;
-    os += "cmd:SClientHandleCmd [ ";
-    os += ecf::convert_to<std::string>(handle_);
-    os += " ]";
-    return os;
-}
-
-bool SClientHandleCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        cout << "  SClientHandleCmd::handle_server_response handle_ = " << handle_ << "\n";
-    server_reply.set_client_handle(handle_);
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SClientHandleCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SClientHandleCmd_HPP
-#define ecflow_base_stc_SClientHandleCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-class SClientHandleCmd final : public ServerToClientCmd {
-public:
-    explicit SClientHandleCmd(int handle) : handle_(handle) {}
-    SClientHandleCmd() : ServerToClientCmd() {}
-
-    void init(int handle) { handle_ = handle; }
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
-
-private:
-    int handle_{0};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(handle_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SClientHandleCmd&);
-
-#endif /* ecflow_base_stc_SClientHandleCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,120 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SClientHandleSuitesCmd.hpp"
-
-#include <iomanip> // for setw
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/node/ClientSuiteMgr.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-SClientHandleSuitesCmd::SClientHandleSuitesCmd(AbstractServer* as) {
-    init(as);
-}
-
-void SClientHandleSuitesCmd::init(AbstractServer* as) {
-    // This command can be re-used hence clear existing data members
-    users_.clear();
-    client_handles_.clear();
-
-    ClientSuiteMgr& client_suite_mgr                   = as->defs()->client_suite_mgr();
-    const std::vector<ecf::ClientSuites>& clientSuites = client_suite_mgr.clientSuites();
-
-    size_t client_suites_size = clientSuites.size();
-    client_handles_.reserve(client_suites_size);
-    for (size_t c = 0; c < client_suites_size; c++) {
-
-        // The handle suites are already ordered same as Defs suites
-        std::vector<std::string> suite_names;
-        clientSuites[c].suites(suite_names);
-
-        client_handles_.emplace_back(clientSuites[c].handle(), suite_names);
-
-        // Create user, and his list of handles
-        bool fnd_user = false;
-        for (auto& user : users_) {
-            if (user.first == clientSuites[c].user()) {
-                user.second.push_back(clientSuites[c].handle());
-                fnd_user = true;
-                break;
-            }
-        }
-        if (!fnd_user) {
-            std::vector<unsigned int> handles;
-            handles.push_back(clientSuites[c].handle());
-            users_.emplace_back(clientSuites[c].user(), handles);
-        }
-    }
-}
-
-bool SClientHandleSuitesCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SClientHandleSuitesCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SClientHandleSuitesCmd::print() const {
-    return "cmd:SClientHandleSuitesCmd ";
-}
-
-bool SClientHandleSuitesCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        std::cout << "  SClientHandleSuitesCmd::handle_server_response\n";
-
-    if (server_reply.cli() && !cts_cmd->group_cmd()) {
-        /// This Could be part of a group command, hence ONLY if NOT group command
-
-        // print out:
-        // user  handle suites
-        // user1 1 s1 s2 s3
-        //       2 s1 s2
-        // user2 1 s1 s2 s3
-        //       2 s1 s2
-        for (size_t u = 0; u < users_.size(); u++) {
-            if (u == 0) {
-                cout << "\n";
-                cout << left << setw(10) << "User" << setw(6) << "handle"
-                     << "  suites\n";
-            }
-            cout << left << setw(10) << users_[u].first;
-            for (size_t h = 0; h < users_[u].second.size(); h++) {
-                unsigned int handle = users_[u].second[h];
-                for (const auto& client_handle : client_handles_) {
-                    if (handle == client_handle.first) {
-                        if (h != 0)
-                            cout << "          "; // 10 spaces to align handles
-                        cout << right << setw(6) << handle << "  ";
-                        const std::vector<std::string>& suites = client_handle.second;
-                        for (const auto& suite : suites) {
-                            cout << suite << "  ";
-                        }
-                        cout << "\n";
-                    }
-                }
-            }
-        }
-    }
-    else {
-        server_reply.set_client_handle_suites(client_handles_);
-    }
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SClientHandleSuitesCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SClientHandleSuitesCmd_HPP
-#define ecflow_base_stc_SClientHandleSuitesCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-class AbstractServer;
-
-//================================================================================
-class SClientHandleSuitesCmd final : public ServerToClientCmd {
-public:
-    explicit SClientHandleSuitesCmd(AbstractServer* as);
-    SClientHandleSuitesCmd() : ServerToClientCmd() {}
-
-    void init(AbstractServer* as);
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-
-private:
-    std::vector<std::pair<std::string, std::vector<unsigned int>>> users_;          // users , list of handles
-    std::vector<std::pair<unsigned int, std::vector<std::string>>> client_handles_; // handle, list of suites
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(users_), CEREAL_NVP(client_handles_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SClientHandleSuitesCmd&);
-
-#endif /* ecflow_base_stc_SClientHandleSuitesCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SNewsCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SNewsCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SNewsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SNewsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,250 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SNewsCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-
-/// Custom handling of command logging so that we can add additional debug.
-/// Rely's on CSyncCmd not adding newline when logging the command
-#define DEBUG_NEWS 1
-
-SNewsCmd::SNewsCmd(unsigned int client_handle,
-                   unsigned int client_state_change_no,
-                   unsigned int client_modify_change_no,
-                   AbstractServer* as) {
-    init(client_handle, client_state_change_no, client_modify_change_no, as);
-}
-
-/// Called in the server
-void SNewsCmd::init(unsigned int client_handle, // a reference to a set of suites used by client
-                    unsigned int client_state_change_no,
-                    unsigned int client_modify_change_no,
-                    AbstractServer* as) {
-    news_ = ServerReply::NO_NEWS;
-
-    // =====================================================================================
-    // The code to determine changes here must also relate to SSyncCmd
-    // ======================================================================================
-
-    if (client_handle == 0) {
-
-        // Here Ecf::modify_change_no() and  Ecf::state_change_no() represent the max change numbers over *all* the
-        // suites
-
-        /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
-        /// *** i.e the value should be less or equal to server. However if::
-        /// ***   o/ Server **dies** we can get the case, where client numbers are greater than server numbers.
-        /// ***   o/ Server changes number overflows, since it unsigned, and re-start's with 0
-        /// *** When no handle are involved, we can get by with a full sync
-        /// *** Note: whenever the server starts, the state and modify numbers start from zero
-        if ((client_modify_change_no > Ecf::modify_change_no()) || (client_state_change_no > Ecf::state_change_no())) {
-
-            news_ = ServerReply::DO_FULL_SYNC;
-
-#if DEBUG_NEWS
-            std::stringstream ss;
-            ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-               << ") : client no > server no ! :DO_FULL_SYNC]";
-            log_append(ss.str());
-#else
-            log_append("");
-#endif
-            return;
-        }
-
-        if (client_modify_change_no < Ecf::modify_change_no()) {
-
-            news_ = ServerReply::NEWS;
-
-#if DEBUG_NEWS
-            std::stringstream ss;
-            ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-               << ") : *Large* scale changes(" << (Ecf::modify_change_no() - client_modify_change_no) << ") :NEWS]";
-            log_append(ss.str());
-#else
-            log_append("");
-#endif
-            return;
-        }
-
-        if (client_state_change_no < Ecf::state_change_no()) {
-
-            news_ = ServerReply::NEWS;
-
-#if DEBUG_NEWS
-            std::stringstream ss;
-            ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-               << ") : *Small* scale changes(" << (Ecf::state_change_no() - client_state_change_no) << ") :NEWS]";
-            log_append(ss.str());
-#else
-            log_append("");
-#endif
-            return;
-        }
-
-#if DEBUG_NEWS
-        log_append(" [:NO_NEWS]");
-#else
-        log_append("");
-#endif
-        return;
-    }
-
-    // =============================================================================================
-    // Handle used: Determine the max modify and state change no, for suites in our handle
-    // =============================================================================================
-
-    /// *** If we can't find the handle, then it may be that the server died ?
-    /// *** It is up to the client to do a full sync *including* re-registering suites
-    ClientSuiteMgr& client_suite_mgr = as->defs()->client_suite_mgr();
-    if (!client_suite_mgr.valid_handle(client_handle)) {
-
-        news_ = ServerReply::DO_FULL_SYNC;
-
-#if DEBUG_NEWS
-        std::stringstream ss;
-        ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no() << ") : Cannot find handle("
-           << client_handle << ") :DO_FULL_SYNC]";
-        log_append(ss.str());
-#else
-        log_append("");
-#endif
-
-        return;
-    }
-
-    /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
-    /// *** i.e the value should be less or equal to server. However if
-    /// ***   o/ Server **dies** we can get the case, where client numbers are greater than server numbers.
-    /// ***   o/ Server changes number overflows, since it unsigned, and re-start's with 0
-    /// *** we can get the case, where client numbers are greater than server numbers and also the
-    /// *** handle will not exist in the server,
-    /// *** It is up to the client to do a full sync *including* re-registering suites
-    /// *** Note: whenever the server starts, the state and modify numbers start from zero
-    unsigned int max_client_handle_modify_change_no = 0;
-    unsigned int max_client_handle_state_change_no  = 0;
-    client_suite_mgr.max_change_no(
-        client_handle, max_client_handle_state_change_no, max_client_handle_modify_change_no);
-
-    if ((client_modify_change_no > max_client_handle_modify_change_no) ||
-        (client_state_change_no > max_client_handle_state_change_no)) {
-
-        news_ = ServerReply::DO_FULL_SYNC;
-
-#if DEBUG_NEWS
-        std::stringstream ss;
-        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
-           << ")  server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-           << ") : client no > server no ! :DO_FULL_SYNC]";
-        log_append(ss.str());
-#else
-        log_append("");
-#endif
-
-        return;
-    }
-
-    /// Changes where user adds a new handle/auto adds/removes require a full update, but only for changed handle
-    if (client_suite_mgr.handle_changed(client_handle)) {
-
-        news_ = ServerReply::NEWS;
-
-#if DEBUG_NEWS
-        std::stringstream ss;
-        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
-           << ") server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-           << ") : *Large* scale changes (new handle or suites added or removed) :NEWS]";
-        log_append(ss.str());
-#else
-        log_append("");
-#endif
-
-        return;
-    }
-
-    // The client handle represents a subset of the suites.
-    if (client_modify_change_no < max_client_handle_modify_change_no) {
-
-        news_ = ServerReply::NEWS;
-
-#if DEBUG_NEWS
-        std::stringstream ss;
-        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
-           << ") server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-           << ") : *Large* scale changes :NEWS]";
-        log_append(ss.str());
-#else
-        log_append("");
-#endif
-
-        return;
-    }
-
-    // This should also reflect changes made just to the defs(state/suspended) and also the server state
-    if (client_state_change_no < max_client_handle_state_change_no) {
-
-        news_ = ServerReply::NEWS;
-
-#if DEBUG_NEWS
-        std::stringstream ss;
-        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
-           << ") server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
-           << ") : *Small* scale changes :NEWS]";
-        log_append(ss.str());
-#else
-        log_append("");
-#endif
-
-        return;
-    }
-
-#if DEBUG_NEWS
-    log_append(" [:NO_NEWS]");
-#else
-    log_append("");
-#endif
-}
-
-/// Called in the client
-bool SNewsCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr /*cts_cmd*/, bool debug) const {
-    if (debug)
-        std::cout << "  SNewsCmd::handle_server_response news_ = " << news_ << "\n";
-    server_reply.set_news(news_);
-    return true;
-}
-
-bool SNewsCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SNewsCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (news_ != the_rhs->news())
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SNewsCmd::print() const {
-    std::stringstream ss;
-    ss << "cmd:SNewsCmd [ " << news_ << " ] ";
-    return ss.str();
-}
-
-std::ostream& operator<<(std::ostream& os, const SNewsCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SNewsCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SNewsCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SNewsCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SNewsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SNewsCmd_HPP
-#define ecflow_base_stc_SNewsCmd_HPP
-
-///
-/// \brief class SNewsCmd is used to determine any change in the server
-///
-/// The *client_state_change_no* was passed from the client to the server
-/// The *client_modify_change_no* was passed from the client to the server
-///
-/// The code here needs to coordinate with SSyncCmd
-///
-/// Paired with CtsCmd(NEWS)
-/// Client---CtsCmd(NEWS)---->Server-----(SNewsCmd)--->client:
-///
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-class AbstractServer;
-
-class SNewsCmd final : public ServerToClientCmd {
-public:
-    // The constructor is *called* in the server.
-    SNewsCmd(unsigned int client_handle, // a reference to a set of suites used by client
-             unsigned int client_state_change_no,
-             unsigned int client_modify_change_no,
-             AbstractServer* as);
-    SNewsCmd() : ServerToClientCmd() {}
-
-    void init(unsigned int client_handle, // a reference to a set of suites used by client
-              unsigned int client_state_change_no,
-              unsigned int client_modify_change_no,
-              AbstractServer* as);
-
-    ServerReply::News_t news() const { return news_; } // used by equals only
-    bool get_news() const { return (news_ != ServerReply::NO_NEWS); }
-
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-
-private:
-    ServerReply::News_t news_{ServerReply::NO_NEWS};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(news_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SNewsCmd&);
-
-#endif /* ecflow_base_stc_SNewsCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SNodeCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SNodeCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,117 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SNodeCmd.hpp"
-
-#include <iostream>
-#include <stdexcept>
-
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace boost;
-
-//=====================================================================================
-// This command returns the requested node back to the client
-// Note: In the case where defs has not been loaded, it can be NULL
-
-SNodeCmd::SNodeCmd(AbstractServer* as, node_ptr node) {
-    init(as, node);
-}
-
-void SNodeCmd::init(AbstractServer* as, node_ptr node) {
-    the_node_str_.clear();
-    if (node.get()) {
-        the_node_str_ = node->print(PrintStyle::NET);
-    }
-}
-
-node_ptr SNodeCmd::get_node_ptr(std::string& error_msg) const {
-    return Node::create(the_node_str_, error_msg);
-}
-
-bool SNodeCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SNodeCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (!ServerToClientCmd::equals(rhs))
-        return false;
-    return true;
-}
-
-std::string SNodeCmd::print() const {
-    std::string os;
-    os += "cmd:SNodeCmd [ ";
-    std::string error_msg;
-    node_ptr node = get_node_ptr(error_msg);
-    if (node.get())
-        os += node->absNodePath();
-    else
-        os += "node == NULL";
-    os += " ]";
-    return os;
-}
-
-// Called in client
-bool SNodeCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        std::cout << "  SNodeCmd::handle_server_response\n";
-
-    std::string error_msg;
-    node_ptr node = get_node_ptr(error_msg);
-    if (!node.get()) {
-        std::string ss;
-        ss += "SNodeCmd::handle_server_response: Error Node could not be retrieved from server. Request ";
-        ss += cts_cmd->print_short();
-        ss += " failed.\n";
-        ss += error_msg;
-        throw std::runtime_error(ss);
-    }
-
-    if (server_reply.cli() && !cts_cmd->group_cmd()) {
-        /// This Could be part of a group command, hence ONLY show Node if NOT group command
-        PrintStyle style(cts_cmd->show_style());
-
-        Suite* suite = node->isSuite();
-        if (suite) {
-            if (!PrintStyle::is_persist_style(cts_cmd->show_style())) {
-                /// Auto generate externs, before writing to standard out. This can be expensive since
-                /// All the trigger references need to to be resolved. & AST need to be created first
-                /// The old spirit based parsing, horrendously, slow. Can't use Spirit QI, till IBM pull support it
-                ///
-                /// We need a fabricate a defs to show the externs, used by the suite
-                Defs defs;
-                defs.addSuite(std::dynamic_pointer_cast<Suite>(node));
-                defs.auto_add_externs();
-                std::cout << defs.print(cts_cmd->show_style());
-                return true;
-            }
-
-            // with defs_state MIGRATE on --load we will recover the state.
-            if (PrintStyle::is_persist_style(cts_cmd->show_style()))
-                std::cout << "defs_state " << PrintStyle::to_string(cts_cmd->show_style()) << "\n"; // see ECFLOW-1233
-            std::cout << *suite << "\n";
-            return true;
-        }
-        cout << node->print() << "\n";
-    }
-    else {
-        server_reply.set_client_node(node);
-    }
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SNodeCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SNodeCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SNodeCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SNodeCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SNodeCmd_HPP
-#define ecflow_base_stc_SNodeCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-class AbstractServer;
-
-//================================================================================
-// Paired with CtsNodeCmd(Get)
-// Client---CtsNodeCmd(GET)---->Server-----(SNodeCmd | SNodeCmd)--->client:
-//================================================================================
-class SNodeCmd final : public ServerToClientCmd {
-public:
-    SNodeCmd(AbstractServer* as, node_ptr node);
-    SNodeCmd() = default;
-
-    void init(AbstractServer* as, node_ptr node);
-
-    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    void cleanup() override { std::string().swap(the_node_str_); } /// run in the server, after command send to client
-
-private:
-    node_ptr get_node_ptr(std::string& error_msg) const;
-    std::string the_node_str_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(the_node_str_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SNodeCmd&);
-
-#endif /* ecflow_base_stc_SNodeCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SServerLoadCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SServerLoadCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SServerLoadCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SServerLoadCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SServerLoadCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/Gnuplot.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-bool SServerLoadCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SServerLoadCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (log_file_path_ != the_rhs->log_file_path())
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SServerLoadCmd::print() const {
-    std::string os;
-    os += "cmd:SServerLoadCmd [ ";
-    os += log_file_path_;
-    os += " ]";
-    return os;
-}
-
-bool SServerLoadCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        cout << "  SServerLoadCmd::handle_server_response log_file_path = " << log_file_path() << "\n";
-    Gnuplot gnuplot(log_file_path(), server_reply.host(), server_reply.port());
-    gnuplot.show_server_load();
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SServerLoadCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SServerLoadCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SServerLoadCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SServerLoadCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SServerLoadCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SServerLoadCmd_HPP
-#define ecflow_base_stc_SServerLoadCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-///================================================================================
-/// Paired with CtsCmd::SERVER_LOAD
-/// Client---(CtsCmd::SERVER_LOAD)---->Server-----(SServerLoadCmd)--->client:
-///================================================================================
-class SServerLoadCmd final : public ServerToClientCmd {
-public:
-    explicit SServerLoadCmd(const std::string& log_file_path) : log_file_path_(log_file_path) {}
-    SServerLoadCmd() : ServerToClientCmd() {}
-
-    void init(const std::string& s) { log_file_path_ = s; }
-    const std::string& log_file_path() const { return log_file_path_; }
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-    void cleanup() override { std::string().swap(log_file_path_); } /// run in the server, after command send to client
-
-private:
-    std::string log_file_path_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(log_file_path_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SServerLoadCmd&);
-
-#endif /* ecflow_base_stc_SServerLoadCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SStatsCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SStatsCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SStatsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SStatsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SStatsCmd.hpp"
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-SStatsCmd::SStatsCmd(AbstractServer* as) {
-    init(as);
-}
-
-void SStatsCmd::init(AbstractServer* as) {
-    as->stats().update_for_serialisation();
-    stats_               = as->stats();
-    stats_.no_of_suites_ = as->defs()->suiteVec().size();
-}
-
-bool SStatsCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SStatsCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SStatsCmd::print() const {
-    return "cmd:SStatsCmd ";
-}
-
-bool SStatsCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr /*cts_cmd*/, bool debug) const {
-    if (debug)
-        std::cout << "  SStatsCmd::handle_server_response\n";
-    if (server_reply.cli())
-        stats_.show();
-    else {
-        server_reply.set_stats(stats_);
-    }
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SStatsCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SStatsCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SStatsCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SStatsCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SStatsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SStatsCmd_HPP
-#define ecflow_base_stc_SStatsCmd_HPP
-
-#include "ecflow/base/Stats.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-class AbstractServer;
-
-//================================================================================
-// Paired with CtsCmd(SERVER_STATS)
-// Client---(CtsCmd(SERVER_STATS))---->Server-----(SStatsCmd)--->client:
-// ****** Used in Test ONLY, since Stats is subject to change for each release
-// ****** see ECFLOW-880, we use CtsCmd(STATS) to return server stats as a string
-// ****** this allows the format to change in the server(with out affecting protocol)
-//================================================================================
-class SStatsCmd final : public ServerToClientCmd {
-public:
-    explicit SStatsCmd(AbstractServer* as);
-    SStatsCmd() : ServerToClientCmd() {}
-
-    void init(AbstractServer* as);
-
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-
-private:
-    Stats stats_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(stats_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SStatsCmd&);
-
-#endif /* ecflow_base_stc_SStatsCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SStringCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SStringCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SStringCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SStringCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SStringCmd.hpp"
-
-#include <iostream>
-
-using namespace std;
-using namespace boost;
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-bool SStringCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SStringCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (str_ != the_rhs->get_string())
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SStringCmd::print() const {
-    return "cmd:SStringCmd ";
-}
-
-bool SStringCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        cout << "  SStringCmd::handle_server_response str.size()= " << str_.size() << "\n";
-    if (server_reply.cli())
-        // The following uses std::endl to ensure the output is flushed.
-        // This is necessary when called from the Python API, otherwise the output cannot be captured systematically.
-        std::cout << str_ << std::endl;
-    else
-        server_reply.set_string(str_);
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SStringCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SStringCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SStringCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SStringCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SStringCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,50 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SStringCmd_HPP
-#define ecflow_base_stc_SStringCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-///================================================================================
-/// Paired with CFileCmd
-/// Client---(CFileCmd)---->Server-----(SStringCmd)--->client:
-/// Only valid when the clients request a CFileCmd *OR* Log file
-/// Other times this will be empty.
-/// CFileCmd:: The file Contents(script,job,jobout,manual)
-///     Can be potentially very large
-/// LogCmd: The log file Can be potentially very large
-///     Only really valid if the out bound request was a LogCmd(LogCmd::GET)
-///================================================================================
-class SStringCmd final : public ServerToClientCmd {
-public:
-    explicit SStringCmd(const std::string& s) : str_(s) {}
-    SStringCmd() : ServerToClientCmd() {}
-
-    void init(const std::string& s) { str_ = s; }
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    const std::string& get_string() const override { return str_; }
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-    void cleanup() override { std::string().swap(str_); } /// run in the server, after command send to client
-
-private:
-    std::string str_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(str_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SStringCmd&);
-
-#endif /* ecflow_base_stc_SStringCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SStringVecCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SStringVecCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SStringVecCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SStringVecCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SStringVecCmd.hpp"
-
-#include <iostream>
-
-using namespace std;
-using namespace boost;
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-bool SStringVecCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SStringVecCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (vec_ != the_rhs->get_string_vec())
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SStringVecCmd::print() const {
-    return "cmd:SStringVecCmd ";
-}
-
-bool SStringVecCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        cout << "  SStringVecCmd::handle_server_response str.size()= " << vec_.size() << "\n";
-    if (server_reply.cli()) {
-        for (const auto& i : vec_) {
-            std::cout << i << "\n";
-        }
-    }
-    else
-        server_reply.set_string_vec(vec_);
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SStringVecCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SStringVecCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SStringVecCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SStringVecCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SStringVecCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SStringVecCmd_HPP
-#define ecflow_base_stc_SStringVecCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-///================================================================================
-class SStringVecCmd final : public ServerToClientCmd {
-public:
-    explicit SStringVecCmd(const std::vector<std::string>& s) : vec_(s) {}
-    SStringVecCmd() : ServerToClientCmd() {}
-
-    void init(const std::vector<std::string>& s) { vec_ = s; }
-    const std::vector<std::string>& get_string_vec() const { return vec_; }
-
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-    void cleanup() override {
-        std::vector<std::string>().swap(vec_);
-    } /// run in the server, after command send to client
-
-private:
-    std::vector<std::string> vec_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(vec_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SStringVecCmd&);
-
-#endif /* ecflow_base_stc_SStringVecCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SSuitesCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SSuitesCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SSuitesCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SSuitesCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SSuitesCmd.hpp"
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-
-//////////////////////////////////////////////////////////////////////////////////////////////////
-
-SSuitesCmd::SSuitesCmd(AbstractServer* as) {
-    init(as);
-}
-
-void SSuitesCmd::init(AbstractServer* as) {
-    // This command can be re-used hence clear existing data members
-    suites_.clear();
-
-    const std::vector<suite_ptr>& suiteVec = as->defs()->suiteVec();
-    size_t suite_vec_size                  = suiteVec.size();
-    suites_.reserve(suite_vec_size);
-    for (size_t i = 0; i < suite_vec_size; i++) {
-        suites_.push_back(suiteVec[i]->name());
-    }
-}
-
-bool SSuitesCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SSuitesCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SSuitesCmd::print() const {
-    return "cmd:SSuitesCmd ";
-}
-
-bool SSuitesCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug)
-        std::cout << "  SSuitesCmd::handle_server_response\n";
-
-    if (server_reply.cli() && !cts_cmd->group_cmd()) {
-        /// This Could be part of a group command, hence ONLY if NOT group command
-        if (suites_.empty()) {
-            cout << "No suites\n";
-        }
-
-        size_t max_suite_name_size = 0;
-        size_t the_size            = suites_.size();
-        for (size_t i = 0; i < the_size; i++) {
-            max_suite_name_size = std::max(max_suite_name_size, suites_[i].size());
-        }
-        max_suite_name_size += 1;
-
-        int newline_at = 4;
-        for (size_t i = 0; i < the_size; i++) {
-            cout << left << setw(max_suite_name_size) << suites_[i];
-            if (i != 0 && (i % newline_at) == 0) {
-                cout << "\n";
-                newline_at += 5;
-            }
-        }
-        cout << "\n";
-    }
-    else {
-        server_reply.set_string_vec(suites_);
-    }
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const SSuitesCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SSuitesCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SSuitesCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SSuitesCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SSuitesCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SSuitesCmd_HPP
-#define ecflow_base_stc_SSuitesCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-class AbstractServer;
-
-//================================================================================
-// Paired with CtsCmd(SUITES)
-// Client---(CtsCmd(SUITES))---->Server-----(SSuitesCmd)--->client:
-//================================================================================
-class SSuitesCmd final : public ServerToClientCmd {
-public:
-    explicit SSuitesCmd(AbstractServer* as);
-    SSuitesCmd() : ServerToClientCmd() {}
-
-    void init(AbstractServer* as);
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-    void cleanup() override {
-        std::vector<std::string>().swap(suites_);
-    } /// run in the server, after command send to client
-
-private:
-    std::vector<std::string> suites_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(suites_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SSuitesCmd&);
-
-#endif /* ecflow_base_stc_SSuitesCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SSyncCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/SSyncCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SSyncCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SSyncCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,363 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/SSyncCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-// =====================================================================================================
-// #define DEBUG_SERVER_SYNC 1  # Also update DefsCache::DEBUG_SERVER_SYNC
-// #define DEBUG_CLIENT_SYNC 1  # Also update DefsCache::DEBUG_CLIENT_SYNC
-
-SSyncCmd::SSyncCmd(unsigned int client_handle,
-                   unsigned int client_state_change_no,
-                   unsigned int client_modify_change_no,
-                   AbstractServer* as)
-    : incremental_changes_(client_state_change_no) {
-    init(client_handle, client_state_change_no, client_modify_change_no, false, false, as);
-}
-
-void SSyncCmd::reset_data_members(unsigned int client_state_change_no, bool sync_suite_clock) {
-    full_defs_ = false;
-    incremental_changes_.init(client_state_change_no,
-                              sync_suite_clock); // persisted, used for returning INCREMENTAL changes
-    server_defs_.clear();                        // persisted, used for returning FULL definition
-    full_server_defs_as_string_.clear(); // semi-persisted, i.e on load & not on saving used to return cached defs
-}
-
-void SSyncCmd::init(unsigned int client_handle, // a reference to a set of suites used by client
-                    unsigned int client_state_change_no,
-                    unsigned int client_modify_change_no,
-                    bool do_full_sync,
-                    bool sync_suite_clock,
-                    AbstractServer* as) {
-    // ********************************************************
-    // This is called in the server
-    // ********************************************************
-#ifdef DEBUG_SERVER_SYNC
-    cout << "SSyncCmd::init: client(" << client_state_change_no << "," << client_modify_change_no << ") server("
-         << Ecf::state_change_no() << "," << Ecf::modify_change_no() << ") sync_suite_clock(" << sync_suite_clock
-         << ")";
-#endif
-
-    // Reset all data members since this command can be re-used
-    reset_data_members(client_state_change_no, sync_suite_clock);
-
-    // explicit request
-    if (do_full_sync) {
-#ifdef DEBUG_SERVER_SYNC
-        cout << ": *Flag do_full_sync set* ";
-#endif
-        full_sync(client_handle, as);
-        return;
-    }
-
-    if (client_handle == 0) {
-#ifdef DEBUG_SERVER_SYNC
-        cout << ": No *handle* ";
-#endif
-
-        /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
-        /// *** i.e the value should be less or equal to server. However if the server **dies** we can
-        /// *** get the case, where client numbers are greater than server numbers.
-        /// *** When no handle are involved, we get by with a full sync
-        /// *** Note: whenever the server starts, the state and modify numbers start from zero
-        if (client_modify_change_no > Ecf::modify_change_no() || client_state_change_no > Ecf::state_change_no()) {
-#ifdef DEBUG_SERVER_SYNC
-            cout << ": client modify no > server modify no: Server died/restored? ";
-#endif
-            full_sync(client_handle, as);
-            return;
-        }
-
-        if (client_modify_change_no < Ecf::modify_change_no()) {
-#ifdef DEBUG_SERVER_SYNC
-            cout << ": *Large* scale changes: modify numbers not in sync ";
-#endif
-            full_sync(client_handle, as);
-            return;
-        }
-
-        //      // small scale changes.
-        //      // When we going to get thousand of memento, quicker to do a full sync
-        //      if (Ecf::state_change_no()-client_state_change_no > 200000) {
-        //         full_sync(client_handle,as);
-        //         return;
-        //      }
-
-        // small scale changes. Collate changes over *defs* and all suites.
-        // Suite stores the maximum state change, over *all* its children, this is used by client handle mechanism
-        // and here to avoid traversing down the hierarchy.
-        // ******** We must trap all child changes under the suite. See class SuiteChanged
-        // ******** otherwise some attribute sync's will be missed
-        as->defs()->collateChanges(client_handle, incremental_changes_);
-        incremental_changes_.set_server_state_change_no(Ecf::state_change_no());
-        incremental_changes_.set_server_modify_change_no(Ecf::modify_change_no());
-#ifdef DEBUG_SERVER_SYNC
-        if (incremental_changes_.size())
-            cout << ":*small* scale changes: no of changes(" << incremental_changes_.size() << ")\n";
-        else
-            cout << ": *No changes*\n";
-#endif
-        //      LOG(Log::DBG,"SSyncCmd::init incremental_changes_.size() " << incremental_changes_.size() << "
-        //      Ecf::state_change_no()-client_state_change_no " << Ecf::state_change_no()-client_state_change_no );
-        return;
-    }
-
-    //==========================================================================================
-    // Handle used
-    //==========================================================================================
-    ClientSuiteMgr& client_suite_mgr = as->defs()->client_suite_mgr();
-#ifdef DEBUG_SERVER_SYNC
-    cout << ": *handle* used " << client_handle << " : ";
-    std::vector<string> suites;
-    client_suite_mgr.suites(client_handle, suites);
-    for (const std::string& name : suites) {
-        std::cout << name << " ";
-    }
-#endif
-
-    /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
-    /// *** i.e the value should be less or equal to server. However if the server **dies** we can
-    /// *** get the case, where client numbers are greater than server numbers. In this case we do a full sync
-    /// *** It is up to the client to catch the exception. and do a full sync *including* re-registering suites
-    /// *** Note: whenever the server starts, the state and modify numbers start from zero
-    unsigned int max_client_handle_modify_change_no = 0;
-    unsigned int max_client_handle_state_change_no  = 0;
-    client_suite_mgr.max_change_no(
-        client_handle, max_client_handle_state_change_no, max_client_handle_modify_change_no);
-#ifdef DEBUG_SERVER_SYNC
-    cout << ": server_handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no << ")";
-#endif
-
-    if (client_modify_change_no > max_client_handle_modify_change_no ||
-        client_state_change_no > max_client_handle_state_change_no) {
-#ifdef DEBUG_SERVER_SYNC
-        cout << ": client no > server no: Server died/restored?";
-#endif
-        full_sync(client_handle, as);
-        return;
-    }
-
-    if (client_modify_change_no < max_client_handle_modify_change_no) {
-#ifdef DEBUG_SERVER_SYNC
-        cout << ": *Large* scale changes : modify numbers not in sync";
-#endif
-        full_sync(client_handle, as);
-        return;
-    }
-
-    if (client_suite_mgr.handle_changed(client_handle)) {
-        // *Large* scale handle changes, i.e. created handle/ added or removed suites
-#ifdef DEBUG_SERVER_SYNC
-        cout << ": *Large* scale changes: added/removed suites to handle";
-#endif
-        full_sync(client_handle, as);
-        return;
-    }
-
-    // small scale changes
-    as->defs()->collateChanges(client_handle, incremental_changes_);
-    incremental_changes_.set_server_state_change_no(max_client_handle_state_change_no);
-    incremental_changes_.set_server_modify_change_no(max_client_handle_modify_change_no);
-#ifdef DEBUG_SERVER_SYNC
-    if (incremental_changes_.size())
-        cout << ": *small* scale changes: no of changes(" << incremental_changes_.size() << ")\n";
-    else
-        cout << ": *No changes*\n";
-#endif
-}
-
-void SSyncCmd::full_sync(unsigned int client_handle, AbstractServer* as) {
-    Defs* server_defs = as->defs().get();
-
-    if (0 == client_handle) {
-        // Have already checked for no defs.
-        server_defs->set_state_change_no(Ecf::state_change_no());
-        server_defs->set_modify_change_no(Ecf::modify_change_no());
-
-        DefsCache::update_cache_if_state_changed(server_defs);
-        full_defs_ = true;
-#ifdef DEBUG_SERVER_SYNC
-        cout << ": *no handle* returning FULL defs(*cached* string, size("
-             << DefsCache::full_server_defs_as_string_.size() << "))" << endl;
-#endif
-        return;
-    }
-
-#ifdef DEBUG_SERVER_SYNC
-    cout << ": returning handle based FULL defs";
-#endif
-    // Only return the defs state and suites that the client has registered in the client handle
-    // *HOWEVER* if the client has registered *ALL* the suites, just return the server defs
-    //           *with* the updated change numbers
-    //
-    // *OTHERWISE* this compute the **maximum** state and modify change numbers over
-    // the suites managed by the client handle and then set it on the newly created defs file.
-    // **** It also takes special precaution *NOT* to change Ecf::state_change_no() and Ecf::modify_change_no()
-    // **** so that we avoid changing max modify no for suites not in our handle
-    // **** Will clear the handle_changed flag
-    //
-    // **** Although we create a new defs, we use the same suites. This presents
-    // **** a problem with the suites defs() pointer. To avoid corrupting the server defs
-    // **** we set the suite defs ptr to the the real server defs.
-    // **** --> The defs serialisation will setup the suite defs pointers. <---
-    // **** An alternative would be to clone the entire suites, since this can have
-    // **** hundreds of tasks. It would be very expensive.
-    // **** This means that server_defs_ will fail invarint_checking before serialisation
-    defs_ptr the_server_defs = server_defs->client_suite_mgr().create_defs(client_handle, as->defs());
-    if (the_server_defs.get() == server_defs) {
-        DefsCache::update_cache_if_state_changed(server_defs);
-        full_defs_ = true;
-#ifdef DEBUG_SERVER_SYNC
-        cout << ": The handle has *ALL* the suites: return the FULL defs(*cached* string, size("
-             << DefsCache::full_server_defs_as_string_.size() << "))";
-#endif
-    }
-    else {
-        the_server_defs->save_as_string(server_defs_, PrintStyle::NET);
-    }
-
-#ifdef DEBUG_SERVER_SYNC
-    if (the_server_defs)
-        cout << ": no of suites(" << the_server_defs->suiteVec().size() << ")" << endl;
-    else
-        cout << ": NULL defs!" << endl;
-#endif
-}
-
-void SSyncCmd::cleanup() {
-    /// run in the server, after command sent to client
-    incremental_changes_.cleanup();
-    std::string().swap(server_defs_);
-    std::string().swap(full_server_defs_as_string_); // will typically be empty in server
-}
-
-bool SSyncCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<SSyncCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string SSyncCmd::print() const {
-    return "cmd:SSyncCmd";
-}
-
-bool SSyncCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr /*cts_cmd*/, bool debug) const {
-    // Update server_reply.client_defs_, with the changes returned from the server
-    do_sync(server_reply, debug);
-
-    return true;
-}
-
-bool SSyncCmd::do_sync(ServerReply& server_reply, bool debug) const {
-    // ****************************************************
-    // On the client side
-    // ****************************************************
-    if (!server_defs_.empty()) {
-        // *FULL* sync
-        // to keep pace with the state changes. Passed back later on, get further changes
-        // If non zero handle will contain suites specified in the client handle, including their max change numbers
-        defs_ptr server_defs = Defs::create();
-        server_defs->restore_from_string(server_defs_); // this can throw
-
-        server_reply.client_defs_ = server_defs;
-        server_reply.set_sync(true);
-        server_reply.set_full_sync(true);
-        if (debug)
-            cout << "  SSyncCmd::do_sync::*FULL sync*, client side state/modify numbers("
-                 << server_defs->state_change_no() << "," << server_defs->modify_change_no() << ")\n";
-#ifdef DEBUG_CLIENT_SYNC
-        cout << "SSyncCmd::do_sync: defs *FULL sync*, client side state/modify numbers("
-             << server_defs->state_change_no() << "," << server_defs->modify_change_no() << ")\n";
-#endif
-        return true;
-    }
-
-    if (full_defs_) {
-        if (full_server_defs_as_string_.empty()) {
-            // TEST path.(i.e no client server): re-use static string
-#ifdef DEBUG_CLIENT_SYNC
-            cout << "SSyncCmd::do_sync: TEST PATH: *FULL CACHE sync* : using static cache";
-#endif
-            server_reply.client_defs_ = DefsCache::restore_defs_from_string();
-        }
-        else {
-#ifdef DEBUG_CLIENT_SYNC
-            cout << "SSyncCmd::do_sync: *FULL CACHE sync* : using cache returned from server: cache_size("
-                 << full_server_defs_as_string_.size() << ")";
-#endif
-            server_reply.client_defs_ = DefsCache::restore_defs_from_string(full_server_defs_as_string_);
-        }
-        server_reply.set_sync(true);
-        server_reply.set_full_sync(true);
-        if (debug)
-            cout << "  SSyncCmd::do_sync::*FULL CACHE sync*, client side state/modify numbers("
-                 << server_reply.client_defs_->state_change_no() << "," << server_reply.client_defs_->modify_change_no()
-                 << ")\n";
-#ifdef DEBUG_CLIENT_SYNC
-        cout << ": client side state/modify numbers(" << server_reply.client_defs_->state_change_no() << ","
-             << server_reply.client_defs_->modify_change_no() << ")\n";
-#endif
-        return true;
-    }
-
-    // Can only sync, *if* we have definition on the client side
-    if (server_reply.client_defs_.get()) {
-        // *INCREMENTAL* sync
-
-        if (server_reply.client_defs_->in_notification()) {
-            // For debug: place a break point here: It appear as Change manager observers, has called another client to
-            // server command
-            std::cout << "SSyncCmd::do_sync ERROR!!!!! called in the middle of notification(server->client sync)\n";
-            std::cout << "It appears that change observer have called *ANOTHER* client->server command in the middle "
-                         "synchronising client definition\n";
-        }
-        /// - Sets notification flag, so that observers can also query if they are in the middle of notification.
-        ChangeStartNotification start_notification(server_reply.client_defs_);
-
-        // Apply mementos to the client side defs, to bring in sync with server defs
-        // If *no* server loaded, then no changes applied
-        // Returns true if are any memento's, i.e. server changed.
-        server_reply.set_full_sync(false);
-        bool changes_made_to_client = incremental_changes_.incremental_sync(
-            server_reply.client_defs_, server_reply.changed_nodes(), server_reply.client_handle());
-        server_reply.set_sync(changes_made_to_client);
-
-        if (debug)
-            cout << "  SSyncCmd::do_sync::*INCREMENTAL sync*, client side state/modify numbers("
-                 << incremental_changes_.get_server_state_change_no() << ","
-                 << incremental_changes_.get_server_modify_change_no() << ") changes_made_to_client("
-                 << changes_made_to_client << ")\n";
-
-#ifdef DEBUG_CLIENT_SYNC
-        cout << "SSyncCmd::do_sync::*INCREMENTAL sync*, client side state/modify numbers("
-             << incremental_changes_.get_server_state_change_no() << ","
-             << incremental_changes_.get_server_modify_change_no() << ") changes_made_to_client("
-             << changes_made_to_client << "), changed_node_paths(" << server_reply.changed_nodes().size() << ")\n";
-#endif
-        return changes_made_to_client;
-    }
-    return false;
-}
-
-std::ostream& operator<<(std::ostream& os, const SSyncCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/SSyncCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/SSyncCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/SSyncCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/SSyncCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,110 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_SSyncCmd_HPP
-#define ecflow_base_stc_SSyncCmd_HPP
-
-#include "ecflow/base/stc/DefsCache.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/node/DefsDelta.hpp"
-
-class AbstractServer;
-
-///
-/// \brief the class SSyncCmd is used to transfer changes made in the server to the client.
-///  The client can then apply the changes to the client side defs.
-///
-/// *** This class should be used in conjunction with the news command.
-/// *** i.e The news command is used to test for server changes. This command
-/// *** will then get those changes and merge them with client side defs, bringing
-/// *** client and server defs in sync.
-///
-/// The *client_state_change_no* was passed from the client to the server
-/// The *client_modify_change_no* was passed from the client to the server
-///
-/// This class make use of DefsCache as a performance optimisation.
-///
-
-class SSyncCmd final : public ServerToClientCmd {
-public:
-    // The constructor is *called* in the server.
-    // This will collate the incremental changes made so far relative to the client_state_change_no.
-    // For large scale change we use client_modify_change_no this will require a full update
-    SSyncCmd(unsigned int client_handle, // a reference to a set of suites used by client
-             unsigned int client_state_change_no,
-             unsigned int client_modify_change_no,
-             AbstractServer* as);
-
-    SSyncCmd() : ServerToClientCmd(), incremental_changes_(0) {}
-
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-
-    // Client side functions:
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-
-    /// do_sync() is invoked on the *client side*, Can throw std::runtime_error
-    /// Either does a *FULL* or *INCREMENTAL sync depending on the
-    /// changes in the server. Returns true if client defs changed.
-    bool do_sync(ServerReply& server_reply, bool debug = false) const;
-
-private:
-    friend class PreAllocatedReply;
-    void init(unsigned int client_handle, // a reference to a set of suites used by client
-              unsigned int client_state_change_no,
-              unsigned int client_modify_change_no,
-              bool full_sync,
-              bool sync_suite_clock,
-              AbstractServer* as);
-
-    /// For use when doing a full sync
-    void init(unsigned int client_handle, AbstractServer* as);
-
-    void reset_data_members(unsigned int client_state_change_no, bool sync_suite_clock);
-    void full_sync(unsigned int client_handle, AbstractServer* as);
-    void cleanup() override; /// run in the server, after command sent to client
-
-private:
-    bool full_defs_{false};
-    DefsDelta incremental_changes_;
-    std::string server_defs_;                // for returning a subset of the suites
-    std::string full_server_defs_as_string_; // semi-persisted, i.e on load & not on saving, used to return cached defs
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this),
-           CEREAL_NVP(full_defs_),           // returning full defs as a string
-           CEREAL_NVP(incremental_changes_), // state changes, small scale changes
-
-           /// When the server_defs_ was created the def's pointer on the suites was reset back to real server defs
-           /// This is not correct for server_defs_, since we use the *same* suites
-           /// **** This is OK since by default the Defs serialisation will fix up the suite's def's pointers ***
-           /// The alternative is to clone all the suites, which is very expensive
-           CEREAL_NVP(server_defs_)); // large scale changes, if non zero handle, a small subset of the suites
-
-        // when full_defs_ is set 'server_defs_' will be empty.
-        if (Archive::is_saving::value) {
-            // Avoid copying the string. As this could be very large
-            if (full_defs_) {
-                ar& DefsCache::full_server_defs_as_string_;
-            }
-            else
-                ar & full_server_defs_as_string_;
-        }
-        else {
-            ar & full_server_defs_as_string_;
-        }
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const SSyncCmd&);
-
-#endif /* ecflow_base_stc_SSyncCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/ServerToClientCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/ServerToClientCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/ServerToClientCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/ServerToClientCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-#include "ecflow/core/Str.hpp"
-
-using namespace ecf;
-
-ServerToClientCmd::~ServerToClientCmd() = default;
-
-const std::string& ServerToClientCmd::get_string() const {
-    return Str::EMPTY();
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/ServerToClientCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/ServerToClientCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/ServerToClientCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/ServerToClientCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,52 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_ServerToClientCmd_HPP
-#define ecflow_base_stc_ServerToClientCmd_HPP
-
-#include "ecflow/base/Cmd.hpp"
-#include "ecflow/base/ServerReply.hpp"
-#include "ecflow/core/Serialization.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-//================================================================================
-// Start of Server->client
-//================================================================================
-class ServerToClientCmd {
-public:
-    virtual ~ServerToClientCmd();
-
-    virtual void cleanup() {} /// After the command has run this function can be used to reclaim memory
-
-    virtual std::string print() const = 0;
-    virtual bool equals(ServerToClientCmd*) const { return true; }
-
-    virtual const std::string&
-    get_string() const;                      /// Used by group command, can return any string, including file contents
-    virtual bool ok() const { return true; } /// Used by group command
-    virtual bool is_returnable_in_group_cmd() const { return true; } /// used by group command
-
-    virtual std::string error() const { return std::string(); } /// Used by test
-
-    // Called in client, if any data to be returned , the set on class ServerReply
-    // Cmd_ptr cts_cmd  can used for additional context.
-    // return true, if client should exit, returns false, if further work required, ie blocking, errors, etc
-    virtual bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const = 0;
-
-protected:
-    ServerToClientCmd() = default;
-
-private:
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {}
-};
-
-#endif /* ecflow_base_stc_ServerToClientCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/StcCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/StcCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/StcCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/StcCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,113 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/StcCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-
-std::string StcCmd::print() const {
-    switch (api_) {
-        case StcCmd::OK:
-            return "cmd:Ok";
-        case StcCmd::BLOCK_CLIENT_SERVER_HALTED:
-            return "cmd:Server_halted";
-        case StcCmd::BLOCK_CLIENT_ON_HOME_SERVER:
-            return "cmd:Wait";
-        case StcCmd::DELETE_ALL:
-            return "cmd:delete_all";
-        case StcCmd::END_OF_FILE:
-            return "cmd:end_of_file";
-        case StcCmd::INVALID_ARGUMENT:
-            return "cmd:Invalid_argument";
-        default:
-            assert(false);
-            break;
-    }
-    assert(false); // unknown command
-    return "cmd:Unknown??";
-}
-
-// Client context
-bool StcCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    bool ret = false;
-    switch (api_) {
-        case StcCmd::OK: {
-            if (debug)
-                std::cout << "  StcCmd::handle_server_response OK\n";
-            ret = true;
-            break;
-        }
-        case StcCmd::BLOCK_CLIENT_SERVER_HALTED: {
-            if (debug)
-                std::cout << "  StcCmd::handle_server_response BLOCK_CLIENT_SERVER_HALTED\n";
-            server_reply.set_block_client_server_halted(); // requires further work, by ClientInvoker
-            break;
-        }
-        case StcCmd::BLOCK_CLIENT_ON_HOME_SERVER: {
-            if (debug)
-                std::cout << "  StcCmd::handle_server_response BLOCK_CLIENT_ON_HOME_SERVER\n";
-            server_reply.set_block_client_on_home_server(); // requires further work, by ClientInvoker
-            break;
-        }
-        case StcCmd::DELETE_ALL: {
-            if (debug)
-                std::cout << "  StcCmd::handle_server_response DELETE_ALL\n";
-            server_reply.set_client_defs(defs_ptr());
-            server_reply.set_client_node(node_ptr());
-            server_reply.set_client_handle(0);
-            ret = true;
-            break;
-        }
-        case StcCmd::END_OF_FILE: {
-            if (debug)
-                std::cout << "  StcCmd::handle_server_response END_OF_FILE\n";
-            server_reply.set_eof(); // requires further work, by ClientInvoker
-            std::string ss;
-            ss += "Error: request( ";
-            ss += cts_cmd->print_short();
-            ss += " ) failed! Server replied with: EOF(Server did not reply or mixing ssl and non-ssl)\n";
-            server_reply.set_error_msg(ss);
-            break;
-        }
-        case StcCmd::INVALID_ARGUMENT: {
-            // This is created on the client side, after detecting a INVALID_ARGUMENT reply from the server
-            // This keeps compatibility with 4 servers
-            if (debug)
-                std::cout << "  StcCmd::handle_server_response INVALID_ARGUMENT\n";
-            server_reply.set_invalid_argument(); // requires further work, by ClientInvoker
-            std::string ss;
-            ss += "Error: request( ";
-            ss += cts_cmd->print_short();
-            ss += " ) failed! Server replied with: invalid_argument(Could not decode client protocol)\n";
-            server_reply.set_error_msg(ss);
-            break;
-        }
-        default:
-            assert(false);
-            break;
-    }
-    return ret;
-}
-
-bool StcCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<StcCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    if (api_ != the_rhs->api())
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::ostream& operator<<(std::ostream& os, const StcCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/StcCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/StcCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/StcCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/StcCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,58 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_StcCmd_HPP
-#define ecflow_base_stc_StcCmd_HPP
-
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-
-// Command that are simple replies to the client.
-// Originally we had separate commands. However this lead
-// TOC overflow on the AIX. Hence in order to minimise global
-// symbols due to use of boost serialisation, will use a single command
-class StcCmd final : public ServerToClientCmd {
-public:
-    enum Api {
-        OK,
-        BLOCK_CLIENT_SERVER_HALTED,
-        BLOCK_CLIENT_ON_HOME_SERVER,
-        DELETE_ALL,
-        INVALID_ARGUMENT, // Created on the Client side
-        END_OF_FILE
-    };
-    explicit StcCmd(Api a) : api_(a) {}
-    StcCmd() = default;
-
-    void init(Api a) { api_ = a; }
-    Api api() const { return api_; }
-
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
-
-    /// Other legitimate ServerToClientCmd commands also return ok() as true
-    bool ok() const override { return api_ == OK; } // used by group command
-
-    // avoid adding OK to group command. Since groupCmd will return true from GroupSTCCmd::ok() *IF* there are no errors
-    bool is_returnable_in_group_cmd() const override { return api_ == DELETE_ALL; }
-
-private:
-    Api api_{OK};
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(api_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const StcCmd&);
-
-#endif /* ecflow_base_stc_StcCmd_HPP */
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/ZombieGetCmd.cpp 5.13.0-1/Base/src/ecflow/base/stc/ZombieGetCmd.cpp
--- 5.12.4-1/Base/src/ecflow/base/stc/ZombieGetCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/ZombieGetCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,67 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/base/stc/ZombieGetCmd.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/core/Converter.hpp"
-
-using namespace std;
-using namespace boost;
-
-ZombieGetCmd::ZombieGetCmd(AbstractServer* as) {
-    init(as);
-}
-
-// called in the server
-void ZombieGetCmd::init(AbstractServer* as) {
-    zombies_.clear();
-    as->zombie_ctrl().get(zombies_);
-}
-
-bool ZombieGetCmd::equals(ServerToClientCmd* rhs) const {
-    auto* the_rhs = dynamic_cast<ZombieGetCmd*>(rhs);
-    if (!the_rhs)
-        return false;
-    return ServerToClientCmd::equals(rhs);
-}
-
-std::string ZombieGetCmd::print() const {
-    string os;
-    os += "cmd:ZombieGetCmd [ ";
-    os += ecf::convert_to<std::string>(zombies_.size());
-    os += " ]";
-    return os;
-}
-
-// Called in client
-bool ZombieGetCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
-    if (debug) {
-        std::cout << "  ZombieGetCmd::handle_server_response zombies.size() = " << zombies_.size() << "\n";
-    }
-
-    if (server_reply.cli()) {
-        std::cout << Zombie::pretty_print(zombies_);
-    }
-    else {
-        if (debug) {
-            std::cout << Zombie::pretty_print(zombies_);
-        }
-        server_reply.set_zombies(zombies_);
-    }
-    return true;
-}
-
-std::ostream& operator<<(std::ostream& os, const ZombieGetCmd& c) {
-    os << c.print();
-    return os;
-}
diff -pruN 5.12.4-1/Base/src/ecflow/base/stc/ZombieGetCmd.hpp 5.13.0-1/Base/src/ecflow/base/stc/ZombieGetCmd.hpp
--- 5.12.4-1/Base/src/ecflow/base/stc/ZombieGetCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/src/ecflow/base/stc/ZombieGetCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,47 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_stc_ZombieGetCmd_HPP
-#define ecflow_base_stc_ZombieGetCmd_HPP
-
-#include "ecflow/attribute/Zombie.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-class AbstractServer;
-
-//================================================================================
-// Paired with CtsCmd(GET_ZOMBIES)
-// Client---CtsCmd(GET_ZOMBIES)---->Server-----(ZombieGetCmd)--->client:
-//================================================================================
-class ZombieGetCmd final : public ServerToClientCmd {
-public:
-    explicit ZombieGetCmd(AbstractServer*);
-    ZombieGetCmd() : ServerToClientCmd() {}
-
-    void init(AbstractServer*);
-    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
-    std::string print() const override;
-    bool equals(ServerToClientCmd*) const override;
-    void cleanup() override {
-        std::vector<Zombie>().swap(zombies_);
-    } /// run in the server, after command send to client
-
-private:
-    std::vector<Zombie> zombies_;
-
-    friend class cereal::access;
-    template <class Archive>
-    void serialize(Archive& ar, std::uint32_t const version) {
-        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(zombies_));
-    }
-};
-
-std::ostream& operator<<(std::ostream& os, const ZombieGetCmd&);
-
-#endif /* ecflow_base_stc_ZombieGetCmd_HPP */
diff -pruN 5.12.4-1/Base/test/MockServer.hpp 5.13.0-1/Base/test/MockServer.hpp
--- 5.12.4-1/Base/test/MockServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/MockServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,163 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_test_MockServer_HPP
-#define ecflow_base_test_MockServer_HPP
-
-#include <cassert>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/core/Ecf.hpp" // In server we increment modify and state change numbers,
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-
-/// Act as stand in for a server since Request require at least a AbstractServer
-class MockServer : public AbstractServer {
-public:
-    // For the MockServer don't delete the Defs. since we past in a fixture defs
-    struct null_deleter
-    {
-        void operator()(void const*) const {}
-    };
-
-    // Only in server side do we increment state/modify numbers, controlled by: Ecf::set_server(true)
-    explicit MockServer(Defs* defs) : defs_(defs_ptr(defs, MockServer::null_deleter())) { Ecf::set_server(true); }
-    explicit MockServer(defs_ptr defs) : defs_(defs) { Ecf::set_server(true); }
-    ~MockServer() override { Ecf::set_server(false); }
-
-    void set_server_state(SState::State ss) {
-        serverState_    = ss;
-        stats().status_ = static_cast<int>(serverState_);
-        defs_->set_server().set_state(serverState_);
-    }
-
-    // AbstractServer functions
-    SState::State state() const override { return serverState_; }
-    std::pair<std::string, std::string> hostPort() const override {
-        assert(defs_.get());
-        return defs_->server().hostPort();
-    }
-    defs_ptr defs() const override { return defs_; }
-    void updateDefs(defs_ptr d, bool force) override {
-        assert(defs_.get());
-        defs_->absorb(d.get(), force);
-    }
-    void clear_defs() override {
-        if (defs_.get())
-            defs_->clear();
-    } // dont delete since we pass in Fixture defs. Otherwise it will crash
-    bool checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
-                     int check_pt_interval        = 0,
-                     int check_pt_save_time_alarm = 0) override {
-        return true;
-    }
-    void restore_defs_from_checkpt() override {}
-    void nodeTreeStateChanged() override {}
-    bool allowTaskCommunication() const override { return (serverState_ != SState::HALTED) ? true : false; }
-    void shutdown() override { set_server_state(SState::SHUTDOWN); }
-    void halted() override { set_server_state(SState::HALTED); }
-    void restart() override { set_server_state(SState::RUNNING); }
-    bool reloadWhiteListFile(std::string&) override { return true; }
-    bool reloadPasswdFile(std::string& errorMsg) override { return true; }
-    bool reloadCustomPasswdFile(std::string& errorMsg) override { return true; }
-    bool authenticateReadAccess(const std::string&, bool custom_user, const std::string& passwd) override {
-        return true;
-    }
-    bool authenticateReadAccess(const std::string&,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::string&) override {
-        return true;
-    }
-    bool authenticateReadAccess(const std::string&,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::vector<std::string>&) override {
-        return true;
-    }
-    bool authenticateWriteAccess(const std::string&) override { return true; }
-    bool authenticateWriteAccess(const std::string&, const std::string&) override { return true; }
-    bool authenticateWriteAccess(const std::string&, const std::vector<std::string>&) override { return true; }
-
-    bool lock(const std::string& user) override {
-        if (userWhoHasLock_.empty()) {
-            userWhoHasLock_           = user;
-            stats().locked_by_user_   = user;
-            server_state_to_preserve_ = state();
-            shutdown();
-            return true;
-        }
-        else if (userWhoHasLock_ == user && serverState_ == SState::SHUTDOWN) {
-            // Same user attempting multiple locks
-            return true;
-        }
-        return false;
-    }
-    void unlock() override {
-        userWhoHasLock_.clear();
-        stats().locked_by_user_.clear();
-        switch (server_state_to_preserve_) {
-            case SState::RUNNING:
-                restart();
-                break;
-            case SState::SHUTDOWN:
-                shutdown();
-                break;
-            case SState::HALTED:
-                halted();
-                break;
-        }
-    }
-    const std::string& lockedUser() const override { return userWhoHasLock_; }
-
-    void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
-                                             bool user_cmd_context) const override {
-        if (state() == SState::RUNNING && defs_.get()) {
-            JobsParam jobsParam(poll_interval(), false /* as->allow_job_creation_during_tree_walk() */);
-            Jobs jobs(defs_);
-            if (!jobs.generate(jobsParam))
-                ecf::log(ecf::Log::ERR, jobsParam.getErrorMsg()); // will automatically add end of line
-        }
-    }
-    int poll_interval() const override { return 60; }
-    void debug_server_on() override {}
-    void debug_server_off() override {}
-    bool debug() const override { return true; }
-
-private:
-    defs_ptr defs_;
-    std::string userWhoHasLock_;
-    SState::State serverState_{SState::RUNNING};
-    SState::State server_state_to_preserve_{SState::RUNNING};
-};
-
-/// This class is used to create a Mock Server, so that we can make direct
-/// data model changes without using commands.
-/// In particular it will:
-///   o Ecf::set_server(true): This controls incrementing of state/modify change numbers
-///                            which should *only* be done on the server side
-///   o Update Suite state/modify change number
-class MockSuiteChangedServer {
-public:
-    MockSuiteChangedServer()                              = delete;
-    MockSuiteChangedServer(const MockSuiteChangedServer&) = delete;
-    explicit MockSuiteChangedServer(suite_ptr suite) : suiteChanged_(suite) { Ecf::set_server(true); }
-    ~MockSuiteChangedServer() { Ecf::set_server(false); }
-
-    MockSuiteChangedServer& operator=(const MockSuiteChangedServer&) = delete;
-
-private:
-    ecf::SuiteChanged suiteChanged_;
-};
-
-#endif /* ecflow_base_test_MockServer_HPP */
diff -pruN 5.12.4-1/Base/test/TestAlterCmd.cpp 5.13.0-1/Base/test/TestAlterCmd.cpp
--- 5.12.4-1/Base/test/TestAlterCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestAlterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1275 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_AlterCmd)
-
-class TestStateChanged {
-public:
-    explicit TestStateChanged(suite_ptr s)
-        : suite_(s),
-          initial_suite_state_change_no_(s->state_change_no()),
-          initial_suite_modify_change_no_(s->modify_change_no()) {
-        Ecf::set_server(true);
-    }
-
-    ~TestStateChanged() {
-        Ecf::set_server(false);
-        BOOST_CHECK_MESSAGE(suite_->state_change_no() != initial_suite_state_change_no_ ||
-                                suite_->modify_change_no() != initial_suite_modify_change_no_,
-                            "Suite " << suite_->name() << " has no change in attributes. Forget to increment change no?"
-                                     << " suite_->state_change_no(" << suite_->state_change_no() << ")-"
-                                     << "-initial_suite_state_change_no_(" << initial_suite_state_change_no_ << ") "
-                                     << " suite_->modify_change_no(" << suite_->modify_change_no() << ")-"
-                                     << "-initial_suite_modify_change_no_(" << initial_suite_modify_change_no_ << ")");
-    }
-
-private:
-    suite_ptr suite_;
-    unsigned int initial_suite_state_change_no_;
-    unsigned int initial_suite_modify_change_no_;
-};
-
-class TestDefsStateChanged {
-public:
-    explicit TestDefsStateChanged(Defs* s) : defs_(s), initial_state_change_no_(s->defs_only_max_state_change_no()) {}
-
-    ~TestDefsStateChanged() {
-        Ecf::set_server(false);
-        BOOST_CHECK_MESSAGE(defs_->defs_only_max_state_change_no() != initial_state_change_no_,
-                            "Defs has no change in attributes. Forget to increment change no?");
-    }
-
-private:
-    Defs* defs_;
-    unsigned int initial_state_change_no_;
-};
-
-BOOST_AUTO_TEST_CASE(test_add_log5) {
-    // create once for all test below, then remove at the end
-    Log::create("test_add_log5.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_type_hybrid) {
-    cout << "Base:: ...test_alter_cmd_for_clock_type_hybrid\n";
-
-    // In this test the suite has NO Clock attribute. It should get added automatically
-    // when a new clock is added, we should sync with the computer clock
-    Defs defs;
-    suite_ptr s = Suite::create("suite");
-    defs.addSuite(s);
-
-    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
-    std::string error_msg;
-    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-
-    { // Change clock type
-      // =====================================================================================================
-        defs.beginAll();
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "hybrid", "")));
-        clock_ptr v = s->clockAttr();
-        BOOST_CHECK_MESSAGE(v && v->hybrid(), "expected clock to be added and be hybrid");
-
-        // Altering the suite clock attributes, should force suite calendar to  align to todays date and time
-        boost::posix_time::ptime date_now = Calendar::second_clock_time();
-        int day_of_month                  = date_now.date().day();
-        int month                         = date_now.date().month();
-        int year                          = date_now.date().year();
-        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
-                            "Calendar should be updated after re-queue/begin. Expected "
-                                << day_of_month << " but found " << s->calendar().day_of_month());
-        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
-                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
-                                                                                         << s->calendar().month());
-        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_type_real) {
-    cout << "Base:: ...test_alter_cmd_for_clock_type_real\n";
-
-    // In this test the suite has NO Clock attribute. It should get added automatically
-    // when a new clock is added, we should sync with the computer clock
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-
-    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
-    std::string error_msg;
-    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-
-    { // Change clock type
-      // =====================================================================================================
-        defs.beginAll();
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "real", "")));
-        clock_ptr v = s->clockAttr();
-        BOOST_CHECK_MESSAGE(v && !v->hybrid(), "expected clock to be added and be real");
-
-        // Altering the suite clock attributes, should force suite calendar to  align to todays date and time
-        boost::posix_time::ptime date_now = Calendar::second_clock_time();
-        int day_of_month                  = date_now.date().day();
-        int month                         = date_now.date().month();
-        int year                          = date_now.date().year();
-        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
-                            "Calendar should be updated after re-queue/begin. Expected "
-                                << day_of_month << " but found " << s->calendar().day_of_month());
-        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
-                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
-                                                                                         << s->calendar().month());
-        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_sync) {
-    cout << "Base:: ...test_alter_cmd_for_clock_sync\n";
-
-    // Add a suite with a hybrid clock set to the past, on switch to real time, should have todays date
-    // Since the clock exists on the suite, with another date, we must explicitly sync with computer
-    // alternatively user can change clock date and clock gain to align with computer
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    ClockAttr clockAttr(true); // add hybrid clock
-    clockAttr.date(1, 1, 2009);
-    s->addClock(clockAttr);
-
-    BOOST_REQUIRE_MESSAGE(s->clockAttr(), "Expected clock");
-    BOOST_REQUIRE_MESSAGE(s->clockAttr()->hybrid(), "Expected hybrid clock");
-    std::string error_msg;
-    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-
-    { // Change clock type
-      // =====================================================================================================
-        defs.beginAll();
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "real", "")));
-        clock_ptr v = s->clockAttr();
-        BOOST_CHECK_MESSAGE(v && !v->hybrid(), "expected clock to be added and be real");
-
-        // When we reque, the date should be unchanged
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd("/" + s->name())));
-        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 1,
-                            "Calendar should be updated after re-queue/begin. Expected day of month "
-                                << 1 << " but found " << s->calendar().day_of_month());
-        BOOST_CHECK_MESSAGE(s->calendar().month() == 1,
-                            "Calendar should be updated after re-queue/begin. Expected month "
-                                << 1 << " but found " << s->calendar().month());
-        BOOST_CHECK_MESSAGE(s->calendar().year() == 2009,
-                            "Calendar should be updated after re-queued/begin, Expected year " << 2009 << " but found "
-                                                                                               << s->calendar().year());
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-
-        // After a clk sync, data should match computer
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_SYNC, "", "")));
-
-        boost::posix_time::ptime date_now = Calendar::second_clock_time();
-        int day_of_month                  = date_now.date().day();
-        int month                         = date_now.date().month();
-        int year                          = date_now.date().year();
-        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
-                            "Calendar should be updated after re-queue/begin. Expected "
-                                << day_of_month << " but found " << s->calendar().day_of_month());
-        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
-                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
-                                                                                         << s->calendar().month());
-        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_date) {
-    cout << "Base:: ...test_alter_cmd_for_clock_date\n";
-
-    // In this test the suite has NO Clock attribute. It should get added automatically
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
-    std::string error_msg;
-    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-
-    // Change clock date
-    // =====================================================================================================
-    TestStateChanged changed(s);
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_DATE, "12.12.2012", "")));
-    clock_ptr v = s->clockAttr();
-    BOOST_CHECK_MESSAGE(v.get(), "expected clock to be added");
-
-    // Check that calendar is updated  by the Alter
-    {
-        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 12, "Calendar should be updated");
-        BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated");
-        BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated");
-
-        defs.beginAll();
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(s->absNodePath())));
-        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 12, "Calendar should be updated after re-queued");
-        BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated after re-queued");
-        BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated after re-queued");
-
-        // Now re sync with the computers clock, the suite calendar should align to todays date and time
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_SYNC, "", "")));
-
-        boost::posix_time::ptime date_now = Calendar::second_clock_time();
-        int day_of_month                  = date_now.date().day();
-        int month                         = date_now.date().month();
-        int year                          = date_now.date().year();
-        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
-                            "Calendar should be updated after re-queue/begin. Expected "
-                                << day_of_month << " but found " << s->calendar().day_of_month());
-        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
-                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
-                                                                                         << s->calendar().month());
-        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_gain) {
-    cout << "Base:: ...test_alter_cmd_for_clock_gain\n";
-
-    // In this test the suite has NO Clock attribute. It should get added automatically
-    Defs defs;
-    std::string suitename = "suite";
-    suite_ptr s           = defs.add_suite(suitename);
-    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
-    std::string error_msg;
-    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-
-    { // Change clock gain
-      // =====================================================================================================
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(suitename, AlterCmd::CLOCK_GAIN, "86400", ""))); // add 24 hours in seconds
-        clock_ptr v = s->clockAttr();
-        BOOST_CHECK_MESSAGE(v.get(), "expected clock to be added");
-        BOOST_CHECK_MESSAGE(v && v->gain() == 86400, "expected clock gain to be 86400 but found " << v->gain());
-
-        // Check that calendar is updated by the alter
-        {
-            // add one day, to current date, to simulate a gain of 24 hours
-            boost::posix_time::ptime date_now = Calendar::second_clock_time();
-            boost::gregorian::date newDate    = date_now.date();
-            boost::gregorian::date_duration one_day(1);
-            newDate += one_day;
-            int day_of_month = newDate.day();
-            int month        = newDate.month();
-            int year         = newDate.year();
-            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
-                                "Calendar should be updated after alter. Expected " << day_of_month << " but found "
-                                                                                    << s->calendar().day_of_month());
-            BOOST_CHECK_MESSAGE(s->calendar().month() == month,
-                                "Calendar should be updated after alter. Expected " << month << " but found "
-                                                                                    << s->calendar().month());
-            BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after alter");
-
-            // This should init calendar with todays date + 86400 seconds. i.e +1 day.
-            defs.beginAll();
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd("/" + suitename)));
-            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
-                                "Calendar should be updated after re-queue/begin. Expected "
-                                    << day_of_month << " but found " << s->calendar().day_of_month());
-            BOOST_CHECK_MESSAGE(s->calendar().month() == month,
-                                "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
-                                                                                             << s->calendar().month());
-            BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
-
-            // Now re sync with the computers clock,When we reque, the suite calendar should align to todays date and
-            // time
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_SYNC, "", "")));
-            day_of_month = date_now.date().day();
-            month        = date_now.date().month();
-            year         = date_now.date().year();
-            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
-                                "Calendar should be updated after re-queue/begin. Expected "
-                                    << day_of_month << " but found " << s->calendar().day_of_month());
-            BOOST_CHECK_MESSAGE(s->calendar().month() == month,
-                                "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
-                                                                                             << s->calendar().month());
-            BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
-            BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_cmd) {
-    cout << "Base:: ...test_alter_cmd\n";
-
-    Defs defs;
-    suite_ptr s   = defs.add_suite("suite");
-    task_ptr task = s->add_task("t1");
-    task_ptr t2   = s->add_task("t2");
-    {
-        ClockAttr clockAttr(false); // real clock
-        clockAttr.date(1, 1, 2009);
-        clockAttr.set_gain_in_seconds(3600);
-        s->addClock(clockAttr);
-        s->addDefStatus(DState::SUSPENDED); // avoid AlterCmd from job submission
-    }
-
-    std::string error_msg;
-    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
-
-    { // Change server state. This will cause Flag::MESSAGE to be set on the defs
-        TestDefsStateChanged chenged(&defs);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "_fred_", "value")));
-        BOOST_CHECK_MESSAGE(defs.server().find_variable("_fred_") == "value", "expected to find value");
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::VARIABLE, "_fred_", "_value_")));
-        BOOST_CHECK_MESSAGE(defs.server().find_variable("_fred_") == "_value_", "expected to find _value_");
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::DEL_VARIABLE, "_fred_")));
-        BOOST_CHECK_MESSAGE(defs.server().find_variable("_fred_") == "", "expected to find empty string");
-
-        BOOST_CHECK_MESSAGE(defs.get_edit_history("/").size() == 3,
-                            "expected edit_history of 3 to be added but found " << defs.get_edit_history("/").size());
-
-        {
-            // test set and clear flags of the definition
-            // Note: we cannot really test Flag::Message clear, since that act of clearing, sets the message
-            std::vector<Flag::Type> flag_list = Flag::list();
-            for (auto& i : flag_list) {
-                // When any user command(including setting flags) invoked, we set Flag::MESSAGE on the defs.
-                // Hence setting flag Flag::MESSAGE has no effect. Likewise clearing has no affect since it get set
-                if (i == Flag::MESSAGE)
-                    continue;
-
-                TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", i, true)));
-                BOOST_CHECK_MESSAGE(defs.flag().is_set(i), "Expected flag " << i << " to be set ");
-
-                TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", i, false)));
-                BOOST_CHECK_MESSAGE(!defs.flag().is_set(i), "Expected flag " << i << " to be clear ");
-            }
-        }
-    }
-
-    { // Change clock type
-      // =====================================================================================================
-        defs.beginAll();
-        BOOST_CHECK_MESSAGE(s->calendar().hybrid() == false, "expected calendar to be real after begin");
-        BOOST_CHECK_MESSAGE(s->calendar().hybrid() == s->clockAttr()->hybrid(),
-                            "Calendar and Clock attribute must be in sync after begin");
-
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "hybrid", "")));
-        clock_ptr v = s->clockAttr();
-        BOOST_CHECK_MESSAGE(v && v->hybrid(), "expected clock to be hybrid");
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 1,
-                            "expected edit_history of 1 to be added but found "
-                                << defs.get_edit_history(s->absNodePath()).size());
-
-        // Check that calendar is in sync with clock attribute after the alter
-        {
-            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == s->clockAttr()->hybrid(),
-                                "Calendar and Clock attribute must be in sync after alter");
-            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == true,
-                                "expected calendar to be re-initialised to be hybrid after alter");
-        }
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "real", "")));
-        BOOST_CHECK_MESSAGE(v && !v->hybrid(), "expected clock to be real");
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 2,
-                            "expected edit_history of 2 to be added but found "
-                                << defs.get_edit_history(s->absNodePath()).size());
-
-        // Check that calendar is in sync with clock attribute after the alter
-        {
-            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == s->clockAttr()->hybrid(),
-                                "Calendar and Clock attribute must be in sync after alter");
-            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == false,
-                                "expected calendar to be re-initialised to be real after alter");
-        }
-    }
-
-    { // Change clock date
-      // =====================================================================================================
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_DATE, "12.12.2012", "")));
-        clock_ptr v = s->clockAttr();
-        BOOST_CHECK_MESSAGE((v->day() == 12 && v->month() == 12 && v->year() == 2012),
-                            "expected clock date to be 12.12.2012 but found " << v->toString());
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 3,
-                            "expected edit_history of 3 to be added but found "
-                                << defs.get_edit_history(s->absNodePath()).size());
-
-        // Check that calendar is updated after alter
-        {
-            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 12, "Calendar should be updated after re-queued");
-            BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated after re-queued");
-            BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated after re-queued");
-        }
-    }
-
-    { // Change clock gain
-      // =====================================================================================================
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_GAIN, "86400", ""))); // add 24 hours in seconds
-        clock_ptr v = s->clockAttr();
-        BOOST_CHECK_MESSAGE(v && v->gain() == 86400, "expected clock gain to be 3333 but found " << v->gain());
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 4,
-                            "expected edit_history of 4 to be added but found "
-                                << defs.get_edit_history(s->absNodePath()).size());
-
-        // Check that calendar is updated after the alter
-        {
-            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 13, "Calendar should be updated after re-queued");
-            BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated after re-queued");
-            BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated after re-queued");
-        }
-    }
-
-    // test add, the deleting of a specific attribute
-    {
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "12.12.2010")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "sunday")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "23:00")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "23:00")));
-        BOOST_CHECK_MESSAGE(task->dates().size() == 1, "expected 1 date to be added but found " << s->dates().size());
-        BOOST_CHECK_MESSAGE(task->days().size() == 1, "expected 1 day to be added but found " << s->days().size());
-        BOOST_CHECK_MESSAGE(task->timeVec().size() == 1,
-                            "expected 1 time to be added but found " << s->timeVec().size());
-        BOOST_CHECK_MESSAGE(task->todayVec().size() == 1,
-                            "expected 1 today attr, to be added but found " << s->todayVec().size());
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 4,
-                            "expected edit_history of 4 to be added but found "
-                                << defs.get_edit_history(task->absNodePath()).size());
-    }
-    {
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DATE, "12.12.2010")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DAY, "sunday")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TIME, "23:00")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TODAY, "23:00")));
-        BOOST_CHECK_MESSAGE(task->dates().size() == 0, "expected 0 dates,   but found " << s->dates().size());
-        BOOST_CHECK_MESSAGE(task->days().size() == 0, "expected 0 day       but found " << s->days().size());
-        BOOST_CHECK_MESSAGE(task->timeVec().size() == 0, "expected 0 time   but found " << s->timeVec().size());
-        BOOST_CHECK_MESSAGE(task->todayVec().size() == 0, "expected 0 today but found " << s->todayVec().size());
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 8,
-                            "expected edit_history of 8 to be added but found "
-                                << defs.get_edit_history(task->absNodePath()).size());
-    }
-
-    { // test delete all
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "12.12.2010")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "12.*.2010")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "8.*.2010")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "sunday")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "monday")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "tuesday")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "09:00")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "22:00")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "23:00")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "02:00")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "03:00")));
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 10,
-                            "expected edit_history of 10 to be added but found "
-                                << defs.get_edit_history(task->absNodePath()).size());
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DATE)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DAY)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TIME)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TODAY)));
-        BOOST_CHECK_MESSAGE(task->dates().size() == 0, "expected 0 dates,   but found " << s->dates().size());
-        BOOST_CHECK_MESSAGE(task->days().size() == 0, "expected 0 day       but found " << s->days().size());
-        BOOST_CHECK_MESSAGE(task->timeVec().size() == 0, "expected 0 time   but found " << s->timeVec().size());
-        BOOST_CHECK_MESSAGE(task->todayVec().size() == 0, "expected 0 today but found " << s->todayVec().size());
-
-        /// Edit history should be truncated to max of 20
-        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 10,
-                            "expected edit_history to be truncated to 10, but found "
-                                << defs.get_edit_history(task->absNodePath()).size());
-    }
-
-    { // test add variables
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED1", "_val_")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED2", "_val_")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED3", "_val_")));
-        BOOST_CHECK_MESSAGE(s->variables().size() == 3, "expected 3 variable but found " << s->variables().size());
-
-        // test delete variables
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_VARIABLE, "FRED1")));
-        BOOST_CHECK_MESSAGE(s->variables().size() == 2, "expected 2 variable but found " << s->variables().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_VARIABLE)));
-        BOOST_CHECK_MESSAGE(s->variables().size() == 0, "expected 0 variable but found " << s->variables().size());
-
-        // test change variable
-        s->add_variable("FRED1", "BILL");
-        {
-            TestHelper::invokeRequest(&defs,
-                                      Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::VARIABLE, "FRED1", "BILL1")));
-            const Variable& v = s->findVariable("FRED1");
-            BOOST_CHECK_MESSAGE(!v.empty() && v.theValue() == "BILL1",
-                                "expected to find variable FRED1, with value BILL1");
-        }
-        {
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::VARIABLE, "FRED1")));
-            const Variable& v = s->findVariable("FRED1");
-            BOOST_CHECK_MESSAGE(!v.empty() && v.theValue() == "", "expected to find variable FRED1, with empty value");
-        }
-    }
-
-    { // test add variable to multiple nodes
-        std::vector<node_ptr> all_nodes;
-        defs.get_all_nodes(all_nodes);
-        std::vector<std::string> paths;
-        for (auto& all_node : all_nodes)
-            paths.push_back(all_node->absNodePath());
-        BOOST_CHECK_MESSAGE(paths.size() >= 2, "expected at least 2 nodes");
-
-        for (auto& all_node : all_nodes) {
-            if (all_node->variables().size() > 0) {
-                TestHelper::invokeRequest(&defs,
-                                          Cmd_ptr(new AlterCmd(all_node->absNodePath(), AlterCmd::DEL_VARIABLE)));
-            }
-        }
-
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::ADD_VARIABLE, "FRED1", "_val_")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::ADD_VARIABLE, "FRED2", "_val_")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::ADD_VARIABLE, "FRED3", "_val_")));
-        for (auto& all_node : all_nodes) {
-            BOOST_CHECK_MESSAGE(all_node->variables().size() == 3,
-                                "expected 3 variable but found " << all_node->variables().size());
-        }
-
-        // test change variable
-        {
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::VARIABLE, "FRED1", "BILL1")));
-            for (size_t i = 0; i < all_nodes.size(); i++) {
-                const Variable& v = s->findVariable("FRED1");
-                BOOST_CHECK_MESSAGE(!v.empty() && v.theValue() == "BILL1",
-                                    "expected to find variable FRED1, with value BILL1");
-            }
-        }
-
-        // test delete variables
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::DEL_VARIABLE, "FRED1")));
-        for (auto& all_node : all_nodes) {
-            BOOST_CHECK_MESSAGE(all_node->variables().size() == 2,
-                                "expected 2 variable but found " << all_node->variables().size());
-        }
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::DEL_VARIABLE)));
-        for (auto& all_node : all_nodes) {
-            BOOST_CHECK_MESSAGE(all_node->variables().size() == 0,
-                                "expected 0 variable but found " << all_node->variables().size());
-        }
-    }
-
-    { // test add event
-        TestStateChanged changed(s);
-        s->addEvent(Event(1, "event1"));
-        s->addEvent(Event(2, "event2"));
-        s->addEvent(Event(3, "event3"));
-        BOOST_CHECK_MESSAGE(s->events().size() == 3, "expected 3  but found " << s->events().size());
-
-        // test delete event
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_EVENT, "event1")));
-        BOOST_CHECK_MESSAGE(s->events().size() == 2, "expected 2  but found " << s->events().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_EVENT)));
-        BOOST_CHECK_MESSAGE(s->events().size() == 0, "expected 0  but found " << s->events().size());
-
-        // test change event
-        s->addEvent(Event(1, "event1"));
-        s->addEvent(Event(2, "event2"));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::EVENT, "event1", Event::SET())));
-        {
-            const Event& v = s->findEventByNameOrNumber("event1");
-            BOOST_CHECK_MESSAGE(v.value() == 1, "expected to find  event with value set");
-        }
-
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::EVENT, "event1", Event::CLEAR())));
-        {
-            const Event& v = s->findEventByNameOrNumber("event1");
-            BOOST_CHECK_MESSAGE(!v.empty() && v.value() == 0, "expected to find  event with value cleared");
-        }
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::EVENT, "event1", "")));
-        {
-            const Event& v = s->findEventByNameOrNumber("event1");
-            BOOST_CHECK_MESSAGE(v.value() == 1, "expected to find  event with value set");
-        }
-    }
-
-    { // test add meter
-        // TestStateChanged changed(s);
-        s->addMeter(Meter("meter", 0, 100, 100));
-        s->addMeter(Meter("meter1", 0, 100, 100));
-        s->addMeter(Meter("meter2", 0, 100, 100));
-        BOOST_CHECK_MESSAGE(s->meters().size() == 3, "expected 3  but found " << s->meters().size());
-
-        // test delete meter
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_METER, "meter")));
-        BOOST_CHECK_MESSAGE(s->meters().size() == 2, "expected 2  but found " << s->meters().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_METER)));
-        BOOST_CHECK_MESSAGE(s->meters().size() == 0, "expected 0 meters but found " << s->meters().size());
-
-        // test change meter value
-        s->addMeter(Meter("meter", 0, 100, 100));
-        BOOST_CHECK_MESSAGE(s->meters().size() == 1, "expected 1 meter but found " << s->meters().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::METER, "meter", "10")));
-        const Meter& v = s->findMeter("meter");
-        BOOST_CHECK_MESSAGE(v.value() == 10, "expected to find meter with value 10");
-    }
-
-    { // test add label
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "labelValue")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label1", "labelValue")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label2", "labelValue")));
-        BOOST_CHECK_MESSAGE(s->labels().size() == 3, "expected 3  but found " << s->labels().size());
-
-        // test delete label
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LABEL, "label")));
-        BOOST_CHECK_MESSAGE(s->labels().size() == 2, "expected 2  but found " << s->labels().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LABEL)));
-        BOOST_CHECK_MESSAGE(s->labels().size() == 0, "expected 0  but found " << s->labels().size());
-
-        // test change label value
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "labelValue")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LABEL, "label", "--fred--")));
-        std::string label_value;
-        BOOST_CHECK_MESSAGE(s->getLabelNewValue("label", label_value), "Expected to find label");
-        BOOST_CHECK_MESSAGE(label_value == "--fred--", "expected to find label with value --fred--");
-
-        // change label to be empty, ECFLOW-648
-        label_value.clear();
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LABEL, "label", "")));
-        BOOST_CHECK_MESSAGE(s->getLabelNewValue("label", label_value), "Expected to find label");
-        BOOST_CHECK_MESSAGE(label_value.empty(), "expected to find label with empty value");
-    }
-
-    { // test add Trigger
-        TestStateChanged changed(s);
-        task->add_trigger("t1 == complete");
-        BOOST_CHECK_MESSAGE(task->get_trigger(), "expected  trigger to be added");
-
-        // test delete trigger
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TRIGGER)));
-        BOOST_CHECK_MESSAGE(!task->get_trigger(), "expected  trigger to be deleted");
-
-        // test change trigger expression
-        task->add_trigger("t1 == complete");
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TRIGGER, "x == complete", "")));
-
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TRIGGER, "t2 == complete", "")));
-        BOOST_CHECK_MESSAGE(task->triggerExpression() == "trigger t2 == complete",
-                            "expected trigger to be changed found " << task->triggerExpression());
-    }
-
-    { // test add complete expression
-        TestStateChanged changed(s);
-        task->add_complete("t1 == complete");
-        BOOST_CHECK_MESSAGE(task->get_complete(), "expected complete to be added");
-
-        // test delete complete
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_COMPLETE)));
-        BOOST_CHECK_MESSAGE(!task->get_complete(), "expected complete to be deleted");
-
-        // test change complete expression
-        task->add_complete("t1 == complete");
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::COMPLETE, "x == complete", "")));
-
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::COMPLETE, "t2 == complete", "")));
-        BOOST_CHECK_MESSAGE(task->completeExpression() == "complete t2 == complete",
-                            "expected complete expression to be changed found " << task->completeExpression());
-    }
-
-    { // test add limit
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit", "10")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit1", "10")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit2", "10")));
-        BOOST_CHECK_MESSAGE(s->limits().size() == 3, "expected 3  but found " << s->limits().size());
-
-        // test delete limit
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LIMIT, "limit2")));
-        BOOST_CHECK_MESSAGE(s->limits().size() == 2, "expected 2  but found " << s->limits().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LIMIT)));
-        BOOST_CHECK_MESSAGE(s->limits().size() == 0, "expected 0  but found " << s->limits().size());
-
-        // test change limit max value
-        s->addLimit(Limit("limit", 10));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_MAX, "limit", "90")));
-        limit_ptr v = s->find_limit("limit");
-        BOOST_CHECK_MESSAGE(v.get() && v->theLimit() == 90, "expected to find limit with max value of 90");
-
-        // test change limit value
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_VAL, "limit", "33")));
-        BOOST_CHECK_MESSAGE(v.get() && v->value() == 33, "expected to find limit with value of 33");
-
-        // Test delete limit path
-        std::set<std::string> paths;
-        paths.insert("made_up_path");
-        Limit limit_path("limit_name", 10);
-        limit_path.set_paths(paths);
-
-        s->addLimit(limit_path);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LIMIT_PATH, "limit_name", "made_up_path")));
-        limit_ptr lm = s->find_limit("limit_name");
-        BOOST_CHECK_MESSAGE(lm.get() && lm->paths().empty(), "Expected no paths but found " << lm->paths().size());
-    }
-
-    { // test add in-limit
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "limit_name")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "limit_name1", "11")));
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit:limit_name2")));
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit:limit_name3", "10")));
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit:limitA", "10")));
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit/a:limitA", "10")));
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit/aa:limitA", "10")));
-        BOOST_CHECK_MESSAGE(s->inlimits().size() == 7, "expected 7  but found " << s->inlimits().size());
-
-        // test delete in-limit
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "limit_name")));
-        BOOST_CHECK_MESSAGE(s->inlimits().size() == 6, "expected 6 but found " << s->inlimits().size());
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/to/limit:limitA")));
-        BOOST_CHECK_MESSAGE(s->inlimits().size() == 5, "expected 5 but found " << s->inlimits().size());
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/to/limit/a:limitA")));
-        BOOST_CHECK_MESSAGE(s->inlimits().size() == 4, "expected 4 but found " << s->inlimits().size());
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/to/limit/aa:limitA")));
-        BOOST_CHECK_MESSAGE(s->inlimits().size() == 3, "expected 3 but found " << s->inlimits().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT)));
-        BOOST_CHECK_MESSAGE(s->inlimits().size() == 0, "expected 0  but found " << s->inlimits().size());
-    }
-
-    { // test add repeat
-        TestStateChanged changed(s);
-        s->addRepeat(RepeatDate("YMD", 20090916, 20090930, 1));
-        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
-
-        // test delete repeat
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
-        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
-
-        // test change repeat value
-        s->addRepeat(RepeatDate("YMD", 20090916, 20090930, 1));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "20090917", "")));
-        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "20090917",
-                            "expected 20090917 but found " << s->repeat().valueAsString());
-    }
-    {
-        s->deleteRepeat();
-        TestStateChanged changed(s);
-        s->addRepeat(RepeatDateList("YMD", {20090916, 20090930}));
-        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
-
-        // test delete repeat
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
-        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
-
-        // test change repeat value, the changed value *MUST* correspond to one of the existing values
-        s->addRepeat(RepeatDateList("YMD", {20090916, 20090930, 20190930}));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "20090930", "")));
-        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "20090930",
-                            "expected 20090930 but found " << s->repeat().valueAsString());
-    }
-    {
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT))); // delete previous repeat
-
-        std::vector<std::string> stringList;
-        stringList.reserve(3);
-        stringList.emplace_back("a");
-        stringList.emplace_back("b");
-        stringList.emplace_back("c");
-
-        s->addRepeat(RepeatEnumerated("AEnum", stringList));
-        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
-
-        // test delete repeat
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
-        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
-
-        // test change repeat value
-        s->addRepeat(RepeatEnumerated("AEnum", stringList));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "1", "")));
-        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "b",
-                            "expected 'b' but found " << s->repeat().valueAsString());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "c", "")));
-        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "c",
-                            "expected 'c' but found " << s->repeat().valueAsString());
-    }
-    {
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT))); // delete previous repeat
-
-        std::vector<std::string> stringList;
-        stringList.reserve(3);
-        stringList.emplace_back("a");
-        stringList.emplace_back("b");
-        stringList.emplace_back("c");
-
-        s->addRepeat(RepeatString("RepeatString", stringList));
-        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
-
-        // test delete repeat
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
-        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
-
-        // test change repeat value
-        s->addRepeat(RepeatString("RepeatString", stringList));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "1", "")));
-        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "b",
-                            "expected 'b' but found " << s->repeat().valueAsString());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "c", "")));
-        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "c",
-                            "expected 'c' but found " << s->repeat().valueAsString());
-    }
-
-    {
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT))); // delete previous repeat
-
-        std::vector<std::string> stringList;
-        stringList.reserve(3);
-        stringList.emplace_back("a");
-        stringList.emplace_back("b");
-        stringList.emplace_back("c");
-
-        s->addRepeat(RepeatInteger("rep", 0, 100, 1));
-        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
-
-        // test delete repeat
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
-        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
-
-        // test change repeat value
-        s->addRepeat(RepeatInteger("rep", 0, 100, 1));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "22", "")));
-        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "22",
-                            "expected '22' but found " << s->repeat().valueAsString());
-    }
-
-    { // add cron
-        TestStateChanged changed(s);
-        ecf::CronAttr cronAttr;
-        ecf::TimeSlot start(0, 0);
-        ecf::TimeSlot finish(10, 0);
-        ecf::TimeSlot incr(0, 5);
-        std::vector<int> weekdays;
-        for (int i = 0; i < 7; ++i)
-            weekdays.push_back(i);
-        std::vector<int> daysOfMonth;
-        for (int i = 1; i < 32; ++i)
-            daysOfMonth.push_back(i);
-        std::vector<int> months;
-        for (int i = 1; i < 13; ++i)
-            months.push_back(i);
-        cronAttr.addTimeSeries(start, finish, incr);
-        cronAttr.addWeekDays(weekdays);
-        cronAttr.addDaysOfMonth(daysOfMonth);
-        cronAttr.addMonths(months);
-        task->addCron(cronAttr);
-
-        BOOST_CHECK_MESSAGE(task->crons().size() == 1, "expected cron to be added");
-
-        // test delete cron
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_CRON)));
-        BOOST_CHECK_MESSAGE(task->crons().size() == 0, "expected cron to be delete");
-    }
-
-    { // test suite changed
-        TestStateChanged changed(s);
-
-        // test add zombie
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_ZOMBIE, "user:fob:init:300")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_ZOMBIE, "path:fob:init:300")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_ZOMBIE, "ecf:fob:init:300")));
-        BOOST_CHECK_MESSAGE(s->zombies().size() == 3, "expected 3  but found " << s->zombies().size());
-
-        // test delete zombie
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_ZOMBIE, "ecf")));
-        BOOST_CHECK_MESSAGE(s->zombies().size() == 2, "expected 2  but found " << s->zombies().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_ZOMBIE, "path")));
-        BOOST_CHECK_MESSAGE(s->zombies().size() == 1, "expected 1  but found " << s->zombies().size());
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_ZOMBIE, "user")));
-        BOOST_CHECK_MESSAGE(s->zombies().size() == 0, "expected 0  but found " << s->zombies().size());
-    }
-
-    { // free password
-        TestStateChanged changed(s);
-        std::string returnedValue;
-        BOOST_CHECK_MESSAGE(!task->findVariableValue(Str::ECF_PASS(), returnedValue),
-                            "Expected no variable of name ECF_PASS");
-
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new AlterCmd(
-                task->absNodePath(), AlterCmd::ADD_VARIABLE, Str::ECF_PASS(), Submittable::FREE_JOBS_PASSWORD())));
-
-        BOOST_CHECK_MESSAGE(task->findVariableValue(Str::ECF_PASS(), returnedValue),
-                            "Expected to find variable ECF_PASS on the task");
-        BOOST_CHECK_MESSAGE(returnedValue == Submittable::FREE_JOBS_PASSWORD(),
-                            "Expected variable value of name " << Submittable::FREE_JOBS_PASSWORD() << " but found "
-                                                               << returnedValue);
-    }
-
-    {
-        // test set and clear flags
-        // Note: we cannot really test Flag::Message clear, since that act of clearing, sets the message
-        std::vector<Flag::Type> flag_list = Flag::list();
-        for (auto& i : flag_list) {
-            // When any user command(including setting flags) invoked, we set Flag::MESSAGE on the defs.
-            // Hence setting flag Flag::MESSAGE has no effect. Likewise clearing has no affect since it get set
-            if (i == Flag::MESSAGE)
-                continue;
-
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), i, true)));
-            BOOST_CHECK_MESSAGE(s->flag().is_set(i), "Expected flag " << i << " to be set ");
-
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), i, false)));
-            BOOST_CHECK_MESSAGE(!s->flag().is_set(i), "Expected flag " << i << " to be clear ");
-        }
-    }
-
-    BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 10,
-                        "expected edit_history to be truncated to 10, but found "
-                            << defs.get_edit_history(s->absNodePath()).size());
-
-    {
-        // clear edit history
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new PathsCmd(PathsCmd::EDIT_HISTORY, "clear")), false);
-        BOOST_CHECK_MESSAGE(defs.get_edit_history().size() == 0,
-                            "expected edit_history to be cleared but found" << defs.get_edit_history().size());
-    }
-
-    { // Change suite def status
-      // =====================================================================================================
-        TestStateChanged changed(s);
-        std::vector<std::string> dstates = DState::allStates();
-        for (const auto& dstate : dstates) {
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEFSTATUS, dstate)));
-        }
-        // reset back to suspended
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEFSTATUS, "suspended")));
-    }
-
-    // ================================ LATE ==================================================================
-    { // test add late
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LATE, "late -s 10:10 -a 23:10 -c +23:10")));
-        BOOST_CHECK_MESSAGE(s->get_late(), "expected late to be added");
-
-        // test change late
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LATE, "late -s 10:10")));
-        BOOST_CHECK_MESSAGE(s->get_late() && s->get_late()->toString() == "late -s +10:10",
-                            "expected 'late -s 10:10' but found " << s->get_late()->toString());
-
-        // test delete variable
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LATE)));
-        BOOST_CHECK_MESSAGE(!s->get_late(), "expected late to be deleted");
-    }
-    {
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LATE, "-s 10:10 -a 23:10 -c +23:10")));
-        BOOST_CHECK_MESSAGE(s->get_late(), "expected late to be added");
-
-        // test change late
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LATE, "-s 10:10 -a 12:00")));
-        BOOST_CHECK_MESSAGE(s->get_late() && s->get_late()->toString() == "late -s +10:10 -a 12:00",
-                            "expected 'late -s +10:10 -a 12:00' but found " << s->get_late()->toString());
-
-        // test delete variable
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LATE)));
-        BOOST_CHECK_MESSAGE(!s->get_late(), "expected late to be deleted");
-    }
-
-    // ================================ TIME ==================================================================
-    {
-        // test add time
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "+23:10")));
-        BOOST_CHECK_MESSAGE(task->timeVec().size() == 1, "expected 1 time   but found " << task->timeVec().size());
-
-        // test change time
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TIME, "+23:10", "10:10")));
-        BOOST_CHECK_MESSAGE(task->timeVec()[0].toString() == "time 10:10",
-                            "expected 'time 10:10' but found " << task->timeVec()[0].toString());
-
-        // test delete time
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TIME)));
-        BOOST_CHECK_MESSAGE(task->timeVec().size() == 0, "expected 0 time but found " << task->timeVec().size());
-    }
-
-    // ================================ TODAY ==================================================================
-    {
-        // test add today
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "+10:10 23:00 00:01")));
-        BOOST_CHECK_MESSAGE(task->todayVec().size() == 1, "expected 1 today but found " << task->todayVec().size());
-
-        // test change today
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TODAY, "+10:10 23:00 00:01", "+10:10")));
-        BOOST_CHECK_MESSAGE(task->todayVec()[0].toString() == "today +10:10",
-                            "expected 'today +10:10' but found " << task->todayVec()[0].toString());
-
-        // test delete today
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TODAY)));
-        BOOST_CHECK_MESSAGE(task->todayVec().size() == 0, "expected 0 time but found " << task->todayVec().size());
-    }
-
-    // ================================ Generic ==================================================================
-    // Cannot add generic via Alter
-    {
-        s->add_generic(GenericAttr("a"));
-        s->add_generic(GenericAttr("b"));
-        s->add_generic(GenericAttr("3"));
-        BOOST_CHECK_MESSAGE(s->generics().size() == 3, "Expected 3 generics but found " << s->generics().size());
-
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_GENERIC, "a")));
-        BOOST_CHECK_MESSAGE(s->generics().size() == 2, "Expected 2 generics but found " << s->generics().size());
-
-        // test delete variable
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_GENERIC)));
-        BOOST_CHECK_MESSAGE(s->generics().size() == 0, "Expected no generics but found " << s->generics().size());
-    }
-}
-
-void add_sortable_attributes(Node* node) {
-    node->add_variable("varz", "-");
-    node->add_variable("vary", "-");
-    node->add_variable("vara", "-");
-    node->addEvent(Event("zevent"));
-    node->addEvent(Event("aevent"));
-    node->addEvent(Event(1));
-    node->addEvent(Event(2));
-    node->addMeter(Meter("zmeter", 1, 100));
-    node->addMeter(Meter("ameter", 1, 100));
-    node->addLabel(Label("zlabel", "-"));
-    node->addLabel(Label("alabel", "-"));
-    node->addLimit(Limit("zlimit", 10));
-    node->addLimit(Limit("ylimit", 10));
-    node->addLimit(Limit("xlimit", 10));
-}
-void add_sorted_attributes(Node* node) {
-    node->add_variable("vara", "-");
-    node->add_variable("vary", "-");
-    node->add_variable("varz", "-");
-    node->addEvent(Event(1));
-    node->addEvent(Event(2));
-    node->addEvent(Event("aevent"));
-    node->addEvent(Event("zevent"));
-    node->addMeter(Meter("ameter", 1, 100));
-    node->addMeter(Meter("zmeter", 1, 100));
-    node->addLabel(Label("alabel", "-"));
-    node->addLabel(Label("zlabel", "-"));
-    node->addLimit(Limit("xlimit", 10));
-    node->addLimit(Limit("ylimit", 10));
-    node->addLimit(Limit("zlimit", 10));
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_sort_attributes) {
-    cout << "Base:: ...test_alter_sort_attributes\n";
-
-    Defs defs;
-    defs.set_server().add_or_update_user_variables("z", "z");
-    defs.set_server().add_or_update_user_variables("y", "y");
-    defs.set_server().add_or_update_user_variables("x", "x");
-    suite_ptr s = defs.add_suite("suite");
-    add_sortable_attributes(s.get());
-    family_ptr f1 = s->add_family("f1");
-    add_sortable_attributes(f1.get());
-    task_ptr t1 = f1->add_task("t1");
-    add_sortable_attributes(t1.get());
-
-    Defs sorted_defs;
-    sorted_defs.flag().set(ecf::Flag::MESSAGE); // take into account alter
-    sorted_defs.set_server().add_or_update_user_variables("x", "x");
-    sorted_defs.set_server().add_or_update_user_variables("y", "y");
-    sorted_defs.set_server().add_or_update_user_variables("z", "z");
-    suite_ptr ss = sorted_defs.add_suite("suite");
-    add_sorted_attributes(ss.get());
-    family_ptr sf1 = ss->add_family("f1");
-    add_sorted_attributes(sf1.get());
-    task_ptr st1 = sf1->add_task("t1");
-    add_sorted_attributes(st1.get());
-    sorted_defs.sort_attributes(ecf::Attr::VARIABLE, false /*recursive*/); // just sort the server variables
-
-    {
-        TestDefsStateChanged chenged(&defs);
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "event", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "meter", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "label", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "limit", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "variable", "recursive")));
-        DebugEquality debug_equality; // only as affect in DEBUG build
-        BOOST_CHECK_MESSAGE(defs == sorted_defs, "Sort failed expected\n" << sorted_defs << "\nbut found\n" << defs);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_sort_attributes_for_task) {
-    cout << "Base:: ...test_alter_sort_attributes_for_task\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    add_sortable_attributes(s.get());
-    family_ptr f1 = s->add_family("f1");
-    add_sortable_attributes(f1.get());
-    task_ptr t1 = f1->add_task("t1");
-    add_sortable_attributes(t1.get());
-
-    Defs sorted_defs; // sorted_defs.flag().set(ecf::Flag::MESSAGE); // take into account alter
-    suite_ptr ss = sorted_defs.add_suite("suite");
-    add_sortable_attributes(ss.get());
-    family_ptr sf1 = ss->add_family("f1");
-    add_sortable_attributes(sf1.get());
-    task_ptr st1 = sf1->add_task("t1");
-    add_sorted_attributes(st1.get());
-    st1->flag().set(ecf::Flag::MESSAGE);
-    {
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "event", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "meter", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "label", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "limit", "recursive")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "variable", "recursive")));
-        DebugEquality debug_equality; // only as affect in DEBUG build
-        BOOST_CHECK_MESSAGE(defs == sorted_defs, "Sort failed expected\n" << sorted_defs << "\nbut found\n" << defs);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alter_cmd_errors) {
-    cout << "Base:: ...test_alter_cmd_errors\n";
-
-    Defs defs;
-    suite_ptr s = defs.add_suite("suite");
-    s->add_task("t1");
-
-    { // test add variables
-        TestStateChanged changed(s);
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED1", "_val_")));
-        BOOST_CHECK_MESSAGE(s->variables().size() == 1, "expected 1 variable but found " << s->variables().size());
-
-        // test delete variables, with a non existent path
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/idont/exist", AlterCmd::DEL_VARIABLE, "FRED1")));
-
-        // ECFLOW-380 test change read only server variables
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_HOST", "a")));
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_PORT", "a")));
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_PID", "a")));
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_VERSION", "a")));
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_LISTS", "a")));
-
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit"))); // no limit value
-        TestHelper::invokeFailureRequest(
-            &defs,
-            Cmd_ptr(new AlterCmd(
-                s->absNodePath(), AlterCmd::ADD_LIMIT, "limit", "xx"))); // value not convertible to integer
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, ".1", "10"))); // not a valid name
-
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, ""))); // no inlimit value
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/limit"))); // limit path, but no name
-        TestHelper::invokeFailureRequest(&defs,
-                                         Cmd_ptr(new AlterCmd(s->absNodePath(),
-                                                              AlterCmd::ADD_INLIMIT,
-                                                              "/path/tolimit:limit",
-                                                              "xx"))); // tokens must be convertible to an integer
-
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/tolimit:limit", "1")));
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/tolimit"))); // no limit name
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/tolimit:"))); // no limit name
-        TestHelper::invokeFailureRequest(
-            &defs,
-            Cmd_ptr(
-                new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/tolimit:12 34"))); // invalid limit name
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "1")));
-        TestHelper::invokeFailureRequest(
-            &defs,
-            Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "value"))); // duplicate label name
-    }
-
-    /// Destroy singleton's to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_destroy_log5) {
-    Log::destroy();
-    fs::remove("test_add_log5.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestArchiveAndRestoreCmd.cpp 5.13.0-1/Base/test/TestArchiveAndRestoreCmd.cpp
--- 5.12.4-1/Base/test/TestArchiveAndRestoreCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestArchiveAndRestoreCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,357 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/DeleteCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Pid.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_ArchiveAndRestoreCmd)
-
-BOOST_AUTO_TEST_CASE(test_add_log4) {
-    // create once for all test below, then remove at the end
-    Log::create("test_add_log4.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_CASE(test_archive_and_restore_suite) {
-    cout << "Base:: ...test_archive_and_restore_suite\n";
-
-    // Please note: after archive we delete the children, hence any references to child refer to a different object
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_HOME ....
-    //  family f1
-    //     task t1
-
-    // We use Pid::unique_name, to allow multiple invocation of this test
-    Defs theDefs;
-    std::string ecf_home = File::test_data("Base/test", "Base");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_suite"));
-    suite->add_family("f1")->add_task("t1");
-    // cout << theDefs << "\n";
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, suite->absNodePath())));
-    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
-    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()), "Archive path" << suite->archive_path() << " not created");
-    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children not removed");
-    // cout << theDefs << "\n";
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
-    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::RESTORED), "Restored flag not set");
-    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
-    BOOST_CHECK_MESSAGE(!fs::exists(suite->archive_path()), "Archived file has not been deleted after restore");
-    BOOST_CHECK_MESSAGE(!suite->nodeVec().empty(), "Children are not restored");
-
-    // Archive again but restore via begin
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, suite->absNodePath())));
-    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
-    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()), "Archive path" << suite->archive_path() << " not created");
-    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children not removed");
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new BeginCmd(suite->absNodePath(), true))); // nodes will be active
-    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
-    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::RESTORED), "restored flag not *cleared");
-    BOOST_CHECK_MESSAGE(!fs::exists(suite->archive_path()), "Archived file has not been deleted after restore");
-    BOOST_CHECK_MESSAGE(!suite->nodeVec().empty(), "Children are not restored");
-
-    // PrintStyle::setStyle(PrintStyle::MIGRATE);
-    // cout << theDefs << "\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_archive_and_restore_family) {
-    cout << "Base:: ...test_archive_and_restore_family\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_HOME ....
-    //  family f1
-    //     family f2
-    //       family f3
-    //          task t1
-
-    Defs theDefs;
-    std::string ecf_home = File::test_data("Base/test", "Base");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_family"));
-    family_ptr f3   = suite->add_family("f1")->add_family("f2")->add_family("f3");
-    f3->add_task("t1");
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, f3->absNodePath())));
-    BOOST_CHECK_MESSAGE(f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
-    BOOST_CHECK_MESSAGE(fs::exists(f3->archive_path()), "Archive path" << f3->archive_path() << " not created");
-    BOOST_CHECK_MESSAGE(f3->nodeVec().empty(), "Children not removed");
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, f3->absNodePath())));
-    BOOST_CHECK_MESSAGE(f3->flag().is_set(ecf::Flag::RESTORED), "restored flag not set");
-    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
-    BOOST_CHECK_MESSAGE(!fs::exists(f3->archive_path()), "Archived file has not been deleted after restore");
-    BOOST_CHECK_MESSAGE(!f3->nodeVec().empty(), "Children are not restored");
-
-    // Archive again but restore via begin
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, f3->absNodePath())));
-    BOOST_CHECK_MESSAGE(f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
-    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::RESTORED), "Restored flag not cleared");
-    BOOST_CHECK_MESSAGE(fs::exists(f3->archive_path()), "Archive path" << suite->archive_path() << " not created");
-    BOOST_CHECK_MESSAGE(f3->nodeVec().empty(), "Children not removed");
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new BeginCmd(suite->absNodePath(), true))); // nodes will be active
-    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
-    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::RESTORED), "Restored flag not *cleared");
-    BOOST_CHECK_MESSAGE(!fs::exists(f3->archive_path()), "Archived file has not been deleted after restore");
-    BOOST_CHECK_MESSAGE(!f3->nodeVec().empty(), "Children are not restored");
-
-    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
-    //   cout << theDefs << "\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_archive_and_restore_all) {
-    cout << "Base:: ...test_archive_and_restore_all\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_HOME ....
-    //  family f1
-    //     task t1; task t2
-    //     family f2
-    //       task t1; task t2
-    //       family f3
-    //         task t1; task t2
-    //         family f4
-    //           task t1; task t2
-
-    Defs theDefs;
-    {
-        std::string ecf_home = File::test_data("Base/test", "Base");
-        theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-        suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_all"));
-        family_ptr f1   = suite->add_family("f1");
-        f1->add_task("t1");
-        f1->add_task("t2");
-        family_ptr f2 = f1->add_family("f2");
-        f2->add_task("t1");
-        f2->add_task("t2");
-        family_ptr f3 = f2->add_family("f3");
-        f3->add_task("t1");
-        f3->add_task("t2");
-        family_ptr f4 = f3->add_family("f4");
-        f4->add_task("t1");
-        f4->add_task("t2");
-        TestHelper::invokeRequest(&theDefs,
-                                  Cmd_ptr(new BeginCmd(suite->absNodePath(), false))); // al nodes wil be active
-    }
-    // cout << theDefs << "\n";
-
-    // ****************************************************************************************
-    // *** Each time we restore, we have a new set of pointers *FOR* the children of archived/restored NODE
-    // *** Hence use paths
-    // ****************************************************************************************
-    std::vector<node_ptr> nodes;
-    theDefs.get_all_nodes(nodes);
-    std::vector<std::string> nc_vec;
-    for (auto& node : nodes) {
-        NodeContainer* nc = node->isNodeContainer();
-        if (!nc)
-            continue;
-        nc_vec.push_back(nc->absNodePath());
-    }
-
-    for (const auto& i : nc_vec) {
-        // cout << "archive and restore " << nc_vec[i]  << "\n";
-        {
-            TestHelper::invokeRequest(
-                &theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, i, true))); // use force since jobs are active
-            node_ptr node = theDefs.findAbsNode(i);
-            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
-            NodeContainer* nc = node->isNodeContainer();
-            BOOST_CHECK_MESSAGE(nc->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(fs::exists(nc->archive_path()), "Archive path" << nc->archive_path() << " not created");
-            BOOST_CHECK_MESSAGE(nc->nodeVec().empty(), "Children not removed " << nc->absNodePath());
-
-            TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, i)));
-            node = theDefs.findAbsNode(i);
-            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
-            nc = node->isNodeContainer();
-            BOOST_CHECK_MESSAGE(nc->flag().is_set(ecf::Flag::RESTORED),
-                                "restored flag should be set " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::ARCHIVED),
-                                "Archived flag not *cleared " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(!fs::exists(nc->archive_path()),
-                                "Archived file has not been deleted after restore " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(!nc->nodeVec().empty(), "Children are not restored " << nc->absNodePath());
-        }
-        {
-            // Archive again but restore via re-queue
-            TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, i, true)));
-            node_ptr node = theDefs.findAbsNode(i);
-            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
-            NodeContainer* nc = node->isNodeContainer();
-            BOOST_CHECK_MESSAGE(nc->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::RESTORED),
-                                "Restored flag should be clear " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(fs::exists(nc->archive_path()), "Archive path" << nc->archive_path() << " not created");
-            BOOST_CHECK_MESSAGE(nc->nodeVec().empty(), "Children not removed " << nc->absNodePath());
-
-            TestHelper::invokeRequest(&theDefs, Cmd_ptr(new RequeueNodeCmd(i, RequeueNodeCmd::FORCE)));
-            node = theDefs.findAbsNode(i);
-            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
-            nc = node->isNodeContainer();
-            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::RESTORED),
-                                "Restored flag not *cleared " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::ARCHIVED),
-                                "Archived flag not *cleared " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(!fs::exists(nc->archive_path()),
-                                "Archived file has not been deleted after restore " << nc->absNodePath());
-            BOOST_CHECK_MESSAGE(!nc->nodeVec().empty(), "Children are not restored " << nc->absNodePath());
-        }
-    }
-    // cout << theDefs << "\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_archive_and_restore_overlap) {
-    cout << "Base:: ...test_archive_and_restore_overlap\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_HOME ....
-    //  family f1
-    //     task t1
-
-    Defs theDefs;
-    std::string ecf_home = File::test_data("Base/test", "Base");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_overlap"));
-    std::string f1_abs_node_path;
-    {
-        family_ptr f1 = suite->add_family("f1");
-        f1->add_task("t1");
-        f1_abs_node_path = f1->absNodePath();
-    }
-
-    // Archive suite and its immediate child. This should be detected and we should only archive the suite and not the
-    // family
-    std::vector<std::string> paths;
-    paths.push_back(suite->absNodePath()); // archive suite
-    paths.push_back(f1_abs_node_path);     // archive family its child at the same time, should be ignored
-
-    TestHelper::invokeRequest(&theDefs,
-                              Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, paths))); // family_ptr f1 removed from the suite
-    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
-    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()), "Archive path " << suite->archive_path() << " not created");
-    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children not removed");
-    BOOST_CHECK_MESSAGE(!theDefs.findAbsNode(f1_abs_node_path), "f1 should have been removed");
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
-    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::RESTORED), "Restored flag not set");
-    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
-    BOOST_CHECK_MESSAGE(!fs::exists(suite->archive_path()), "Archived file has not been deleted after restore");
-    BOOST_CHECK_MESSAGE(!suite->nodeVec().empty(), "Children are not restored");
-    node_ptr f1 = theDefs.findAbsNode(f1_abs_node_path);
-    BOOST_CHECK_MESSAGE(f1, "f1 should have been restored");
-    BOOST_CHECK_MESSAGE(!f1->flag().is_set(ecf::Flag::RESTORED), "Family f1 should not have restored flag set");
-}
-
-BOOST_AUTO_TEST_CASE(test_archive_and_delete_suite) {
-    cout << "Base:: ...test_archive_and_delete_suite\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_HOME ....
-    //  family f1
-    //     task t1
-    // Here we are archiving the family and then the suite
-    // We then delete the suite and check that both archived files are removed.
-
-    // We use Pid::unique_name, to allow multiple invocation of this test
-    Defs theDefs;
-    std::string ecf_home = File::test_data("Base/test", "Base");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-    suite_ptr suite   = theDefs.add_suite(Pid::unique_name("test_archive_and_delete_suite"));
-    family_ptr family = suite->add_family("f1");
-    family->add_task("t1");
-    // cout << theDefs << "\n";
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, family->absNodePath())));
-    BOOST_CHECK_MESSAGE(family->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set on family");
-    BOOST_CHECK_MESSAGE(family->has_archive(), "Archived flag not set on family");
-    std::string family_archive_path = family->archive_path();
-    BOOST_CHECK_MESSAGE(fs::exists(family_archive_path), "Archive path" << family->archive_path() << " not created");
-    BOOST_CHECK_MESSAGE(family->nodeVec().empty(), "Children of family not removed after archive");
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, suite->absNodePath())));
-    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set on suite");
-    BOOST_CHECK_MESSAGE(suite->has_archive(), "Archived flag not set on family");
-    std::string suite_archive_path = suite->archive_path();
-    BOOST_CHECK_MESSAGE(fs::exists(suite_archive_path), "Archive path" << suite->archive_path() << " not created");
-    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children of suite not removed after archive");
-
-    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new DeleteCmd(suite->absNodePath())));
-    BOOST_CHECK_MESSAGE(!fs::exists(suite_archive_path), "Suite Archived file not removed after DeleteCmd");
-    BOOST_CHECK_MESSAGE(!fs::exists(family_archive_path), "Family Archived file not removed after DeleteCmd");
-}
-
-BOOST_AUTO_TEST_CASE(test_archive_and_restore_errors) {
-    cout << "Base:: ...test_archive_and_restore_errors\n";
-
-    // Create the defs file corresponding to the text below
-    // suite suite
-    //  edit ECF_HOME ....
-    //  family f1
-    //     task t1
-
-    // We use Pid::unique_name, to allow multiple invocation of this test
-    Defs theDefs;
-    std::string ecf_home = File::test_data("Base/test", "Base");
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_errors"));
-    family_ptr f1   = suite->add_family("f1");
-    f1->add_task("t1");
-
-    // FLAG ecf::Flag::ARCHIVED should be set, for restore to work
-    TestHelper::invokeFailureRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
-
-    // set  ecf::Flag::ARCHIVED, but now suite has children, the suite should have no children for restore
-    suite->flag().set(ecf::Flag::ARCHIVED);
-    TestHelper::invokeFailureRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
-
-    // remove the suite children, should no fail since the restore file is missing
-    f1->remove();
-    TestHelper::invokeFailureRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
-
-    /// Destroy singleton's to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_destroy_log4) {
-    Log::destroy();
-    fs::remove("test_add_log4.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestBase_main.cpp 5.13.0-1/Base/test/TestBase_main.cpp
--- 5.12.4-1/Base/test/TestBase_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestBase_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Base
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/Base/test/TestClientHandleCmd.cpp 5.13.0-1/Base/test/TestClientHandleCmd.cpp
--- 5.12.4-1/Base/test/TestClientHandleCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,369 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// The client handle commands do not change state & modify change number, hence need to bypass these checks
-static bool bypass_state_modify_change_check = false;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_ClientHandleCmd)
-
-BOOST_AUTO_TEST_CASE(test_add_log3) {
-    // create once for all test below, then remove at the end
-    Log::create("test_add_log3.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_CASE(test_client_handle_cmd_empty_server) {
-    cout << "Base:: ...test_client_handle_cmd_empty_server\n";
-
-    std::vector<std::string> suite_names;
-    suite_names.reserve(5);
-    for (int i = 0; i < 5; i++)
-        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
-
-    defs_ptr new_defs = Defs::create();
-
-    // Register new handle on an EMPTY server. register the suite
-    for (const auto& suite_name : suite_names) {
-        std::vector<std::string> names;
-        names.push_back(suite_name);
-        TestHelper::invokeRequest(
-            new_defs.get(), Cmd_ptr(new ClientHandleCmd(0, names, false)), bypass_state_modify_change_check);
-    }
-
-    // We should have 5 handle, 1,2,3,4,5
-
-    // std::cout << "   expect failure when dropping(DROP_USER) on handle that does not exist, handle 6" << endl;
-    TestHelper::invokeFailureRequest(new_defs.get(), Cmd_ptr(new ClientHandleCmd(6)));
-
-    // std::cout << "   expect failure for auto add,on handle that does not exist, handle 6" << endl;
-    TestHelper::invokeFailureRequest(new_defs.get(), Cmd_ptr(new ClientHandleCmd(6, true /* auto add */)));
-
-    // std::cout << "   expect failure for ADD,on handle that does not exist, handle 6" << endl;
-    TestHelper::invokeFailureRequest(new_defs.get(),
-                                     Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::ADD)));
-
-    // std::cout << "   expect failure for REMOVE, on handle that does not exist, handle 6" << endl;
-    TestHelper::invokeFailureRequest(new_defs.get(),
-                                     Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::REMOVE)));
-
-    for (int handle = 1; handle < 6; handle++) {
-
-        // std::cout << "   expect success for dropping handle " << handle << endl;
-        TestHelper::invokeRequest(
-            new_defs.get(), Cmd_ptr(new ClientHandleCmd(handle)), bypass_state_modify_change_check);
-
-        // std::cout << "   expect failure for auto add,on handle that does not exist, handle " << handle << endl;
-        TestHelper::invokeFailureRequest(new_defs.get(), Cmd_ptr(new ClientHandleCmd(6, true /* auto add */)));
-
-        // std::cout << "   expect failure for ADD,on handle that does not exist, handle " << handle <<endl;
-        TestHelper::invokeFailureRequest(new_defs.get(),
-                                         Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::ADD)));
-
-        // std::cout << "   expect failure for REMOVE, on handle that does not exist, handle " << handle << "\n" <<
-        // endl;
-        TestHelper::invokeFailureRequest(new_defs.get(),
-                                         Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::REMOVE)));
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_client_handle_cmd_register_and_drop) {
-    cout << "Base:: ...test_client_handle_cmd_register_and_drop\n";
-
-    std::vector<std::string> suite_names;
-    suite_names.reserve(6);
-    for (int i = 0; i < 5; i++)
-        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
-
-    Defs defs;
-    for (const auto& suite_name : suite_names)
-        defs.addSuite(Suite::create(suite_name));
-
-    // Register new handle
-    for (size_t j = 0; j < suite_names.size(); j++) {
-        std::vector<std::string> names;
-        names.push_back(suite_names[j]);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new ClientHandleCmd(0, names, false)), bypass_state_modify_change_check);
-        BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == j + 1,
-                            "Expected " << j + 1 << " Client suites but found "
-                                        << defs.client_suite_mgr().clientSuites().size());
-    }
-
-    // Drop the handles. take a copy, since we about to delete clientSuites
-    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
-    for (auto& clientSuite : clientSuites) {
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new ClientHandleCmd(clientSuite.handle())), bypass_state_modify_change_check);
-    }
-    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().empty(),
-                        "Expected  no client handles, but found " << defs.client_suite_mgr().clientSuites().size());
-}
-
-BOOST_AUTO_TEST_CASE(test_client_handle_cmd_register__with_drop) {
-    cout << "Base:: ...test_client_handle_cmd_register_with_drop\n";
-
-    std::vector<std::string> suite_names;
-    suite_names.reserve(6);
-    for (int i = 0; i < 5; i++)
-        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
-
-    Defs defs;
-    for (const auto& suite_name : suite_names)
-        defs.addSuite(Suite::create(suite_name));
-
-    // Register new handle
-    for (size_t j = 0; j < suite_names.size(); j++) {
-        std::vector<std::string> names;
-        names.push_back(suite_names[j]);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new ClientHandleCmd(0, names, false)), bypass_state_modify_change_check);
-        BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == j + 1,
-                            "Expected " << j + 1 << " Client suites but found "
-                                        << defs.client_suite_mgr().clientSuites().size());
-    }
-
-    // Register new handle and drop existing handle at the same time. The number of registered should stay the same
-    for (size_t j = 0; j < suite_names.size(); j++) {
-        std::vector<std::string> names;
-        names.push_back(suite_names[j]);
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new ClientHandleCmd(j + 1, names, false)), bypass_state_modify_change_check);
-        BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == suite_names.size(),
-                            "Expected " << suite_names.size() << " Client suites but found "
-                                        << defs.client_suite_mgr().clientSuites().size());
-    }
-
-    // Drop the handles. take a copy, since we about to delete clientSuites
-    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
-    for (auto& clientSuite : clientSuites) {
-        TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new ClientHandleCmd(clientSuite.handle())), bypass_state_modify_change_check);
-    }
-    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().empty(),
-                        "Expected  no client handles, but found " << defs.client_suite_mgr().clientSuites().size());
-}
-
-BOOST_AUTO_TEST_CASE(test_client_handle_cmd_auto_add) {
-    cout << "Base:: ...test_client_handle_cmd_auto_add\n";
-
-    std::vector<std::string> suite_names;
-    suite_names.reserve(6);
-    for (int i = 0; i < 5; i++)
-        suite_names.push_back("s" + std::to_string(i));
-
-    Defs defs;
-    for (const auto& suite_name : suite_names)
-        defs.addSuite(Suite::create(suite_name));
-
-    // Register new handle, with no suites, but with auto add new suites
-    std::vector<std::string> names;
-    TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new ClientHandleCmd(0, names, false /* auto_add */)), bypass_state_modify_change_check);
-    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == 1,
-                        "Expected 1 Client suites but found " << defs.client_suite_mgr().clientSuites().size());
-    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().front().auto_add_new_suites() == false,
-                        "Expected auto add to be disabled");
-
-    // Now enable auto add
-    TestHelper::invokeRequest(
-        &defs,
-        Cmd_ptr(new ClientHandleCmd(defs.client_suite_mgr().clientSuites().front().handle(), true /* auto add */)),
-        bypass_state_modify_change_check);
-    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().front().auto_add_new_suites(),
-                        "Expected auto add to be enabled");
-
-    // now add new suite, they should get added to the new client handles
-    names.clear();
-    for (int i = 5; i < 10; i++)
-        names.push_back("s" + std::to_string(i));
-    for (const auto& name : names)
-        defs.addSuite(Suite::create(name));
-
-    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
-    std::vector<std::string> handle_suites;
-    clientSuites[0].suites(handle_suites);
-    BOOST_CHECK_MESSAGE(handle_suites == names, "Expected suites to be automatically added to our handle");
-
-    // Delete the suite s5,s6,s7,s8,s9
-    for (int i = 5; i < 10; i++) {
-        suite_ptr suite = defs.findSuite("s" + std::to_string(i));
-        BOOST_CHECK_MESSAGE(suite.get(), "Failed to find suite s" << i);
-        suite->remove();
-    }
-
-    { // Even when suites have been removed, we still keep registered suite
-      // These have to be explicitly deleted by the user
-        std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
-        std::vector<std::string> handle_suites;
-        clientSuites[0].suites(handle_suites);
-        BOOST_CHECK_MESSAGE(handle_suites.size() == 5,
-                            "Expected handle to have 5 suites but found" << handle_suites.size());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_client_handle_cmd_add_remove) {
-    cout << "Base:: ...test_client_handle_cmd_add_remove\n";
-
-    std::vector<std::string> suite_names;
-    suite_names.reserve(6);
-    for (int i = 0; i < 5; i++)
-        suite_names.push_back("s" + std::to_string(i));
-
-    defs_ptr defs = Defs::create();
-    for (const auto& suite_name : suite_names)
-        defs->addSuite(Suite::create(suite_name));
-    std::vector<std::string> empty_vec;
-
-    // Register new handle, with no suites,
-    {
-        TestHelper::invokeRequest(
-            defs.get(), Cmd_ptr(new ClientHandleCmd(0, empty_vec, false)), bypass_state_modify_change_check);
-        BOOST_CHECK_MESSAGE(defs->client_suite_mgr().clientSuites().size() == 1,
-                            "Expected 1 Client suites but found " << defs->client_suite_mgr().clientSuites().size());
-        BOOST_CHECK_MESSAGE(!defs->client_suite_mgr().handle_changed(1),
-                            "Expected No handle change, when no real suites added");
-
-        defs_ptr created_defs = defs->client_suite_mgr().create_defs(1, defs); // clear the handle change
-        BOOST_CHECK_MESSAGE(created_defs, "Expected defs to be created");
-        BOOST_CHECK_MESSAGE(created_defs->suiteVec().empty(), "Expected no suites");
-        BOOST_CHECK_MESSAGE(!defs->client_suite_mgr().handle_changed(1),
-                            "Expected handle changed to be cleared after create_defs()");
-    }
-
-    // Now add suites to the existing handle, then check they match.
-    std::vector<std::string> handle_suites;
-    {
-        TestHelper::invokeRequest(defs.get(),
-                                  Cmd_ptr(new ClientHandleCmd(defs->client_suite_mgr().clientSuites().front().handle(),
-                                                              suite_names,
-                                                              ClientHandleCmd::ADD)),
-                                  bypass_state_modify_change_check);
-        defs->client_suite_mgr().clientSuites().front().suites(handle_suites);
-        BOOST_CHECK_MESSAGE(handle_suites == suite_names, "Expected suites to be added to our handle");
-        BOOST_CHECK_MESSAGE(defs->client_suite_mgr().handle_changed(1),
-                            "Expected handle changed when adding new suites to our handle");
-
-        defs_ptr created_defs = defs->client_suite_mgr().create_defs(1, defs); // clear the handle change
-        BOOST_CHECK_MESSAGE(created_defs, "Expected defs to be created");
-        BOOST_CHECK_MESSAGE(created_defs.get() == defs.get(),
-                            "When *ALL* suites registered, the returned defs should be the same");
-        BOOST_CHECK_MESSAGE(created_defs->suiteVec().size() == suite_names.size(), "Not all suites created");
-    }
-
-    // Now remove the suites from the handle
-    {
-        TestHelper::invokeRequest(defs.get(),
-                                  Cmd_ptr(new ClientHandleCmd(defs->client_suite_mgr().clientSuites().front().handle(),
-                                                              suite_names,
-                                                              ClientHandleCmd::REMOVE)),
-                                  bypass_state_modify_change_check);
-        handle_suites.clear();
-        defs->client_suite_mgr().clientSuites().front().suites(handle_suites);
-        BOOST_CHECK_MESSAGE(handle_suites == empty_vec,
-                            "Expected no suites in our handle but found " << handle_suites.size());
-        BOOST_CHECK_MESSAGE(defs->client_suite_mgr().handle_changed(1),
-                            "Expected handle changed when adding new removing suites");
-
-        defs_ptr created_defs = defs->client_suite_mgr().create_defs(1, defs); // clear the handle change
-        BOOST_CHECK_MESSAGE(created_defs, "Expected defs to be created");
-        BOOST_CHECK_MESSAGE(created_defs->suiteVec().empty(), "Expected no suites");
-        BOOST_CHECK_MESSAGE(!defs->client_suite_mgr().handle_changed(1),
-                            "Expected handle changed to be cleared after create_defs()");
-    }
-}
-
-static bool check_ordering(Defs& defs) {
-    // make sure order of suites in handles is the same as server order
-    const std::vector<suite_ptr>& suite_vec = defs.suiteVec();
-    std::vector<std::string> suite_names;
-    for (const auto& i : suite_vec)
-        suite_names.push_back(i->name());
-
-    // Drop the handles. take a copy, since we about to delete clientSuites
-    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
-    for (auto& clientSuite : clientSuites) {
-        std::vector<std::string> names;
-        names.reserve(6);
-        clientSuite.suites(names);
-        if (names != suite_names)
-            return false;
-    }
-    return true;
-}
-
-BOOST_AUTO_TEST_CASE(test_client_handle_suite_ordering) {
-    cout << "Base:: ...test_client_handle_suite_ordering\n";
-    // ensure order of suites in a handle is the same as server suites
-
-    std::vector<std::string> suite_names;
-    suite_names.reserve(6);
-    for (int i = 0; i < 5; i++)
-        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
-
-    Defs defs;
-    for (const auto& suite_name : suite_names)
-        defs.addSuite(Suite::create(suite_name));
-
-    // Register 3 new handle
-    TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, true)), bypass_state_modify_change_check);
-    TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, true)), bypass_state_modify_change_check);
-    TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, true)), bypass_state_modify_change_check);
-    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == 3,
-                        "Expected 3 Client suites but found " << defs.client_suite_mgr().clientSuites().size());
-
-    // After registration make sure ordering is the same
-    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after registration of handles");
-
-    // Check ordering after OrderNodeCmd
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::DOWN)));
-    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::DOWN");
-
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::UP)));
-    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::UP");
-
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::BOTTOM)));
-    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::BOTTOM");
-
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::TOP)));
-    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::TOP");
-
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::ALPHA)));
-    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::ALPHA");
-
-    // check ordering after adding new suites, notice we auto add new suites to all our handles
-    defs.add_suite("sxx");
-    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after adding a new suite");
-}
-
-BOOST_AUTO_TEST_CASE(test_destroy_log3) {
-    Log::destroy();
-    fs::remove("test_add_log3.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestCmd.cpp 5.13.0-1/Base/test/TestCmd.cpp
--- 5.12.4-1/Base/test/TestCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,128 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/task/AbortCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_Cmd)
-
-BOOST_AUTO_TEST_CASE(test_simple_cmd) {
-    cout << "Base:: ...test_simple_cmd\n";
-    TestLog test_log("test_simple_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    // Create the defs file. Note that the default ECF_TRIES = 3
-    //   suite suite
-    //     family f
-    //       task t1
-    //       task t2
-    //     endfamily
-    //   endsuite
-    Defs defs;
-    string suite_f_t1     = "suite/f/t1";
-    std::string suitename = "suite";
-    family_ptr f          = Family::create("f");
-    task_ptr t1           = Task::create("t1");
-    task_ptr t2           = Task::create("t2");
-    suite_ptr s           = Suite::create(suitename);
-    {
-        f->addTask(t1);
-        f->addTask(t2);
-        s->addFamily(f);
-        defs.addSuite(s);
-    }
-
-    // ***********************************************************************
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename, false)));
-        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
-        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
-        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
-        BOOST_CHECK_MESSAGE(t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(t2->state()));
-    }
-
-    // ***********************************************************************
-    // Create a request to abort  Node: suite1/f/t1, Since the default ECF_TRIES is > 0, the aborted tasks
-    // should be re-submitted, until the task try number > ECF_TRIES
-    {
-        std::string varValue;
-        if (t1->findParentUserVariableValue(Str::ECF_TRIES(), varValue)) {
-            auto ecf_tries = ecf::convert_to<int>(varValue);
-            while (true) {
-                TestHelper::invokeRequest(
-                    &defs,
-                    Cmd_ptr(new AbortCmd(
-                        suite_f_t1, Submittable::DUMMY_JOBS_PASSWORD(), Submittable::DUMMY_PROCESS_OR_REMOTE_ID(), 1)));
-                TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
-                BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
-                                    "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
-                BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
-                                    "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
-                BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
-                                    "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
-                // std::cout << "tryNo = " << t1->try_no() << " ECF_TRIES = " <<  ecf_tries << "\n";
-                if (t1->try_no() == ecf_tries)
-                    break;
-            }
-
-            /// Since we have exceeded the try number, abort should mean abort
-            TestHelper::invokeRequest(
-                &defs,
-                Cmd_ptr(new AbortCmd(
-                    suite_f_t1, Submittable::DUMMY_JOBS_PASSWORD(), Submittable::DUMMY_PROCESS_OR_REMOTE_ID(), 1)));
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)), false);
-            BOOST_CHECK_MESSAGE(t1->state() == NState::ABORTED,
-                                "expected state NState::ABORTED, but found to be " << NState::toString(t1->state()));
-            BOOST_CHECK_MESSAGE(f->state() == NState::ABORTED,
-                                "expected state NState::ABORTED, but found to be " << NState::toString(f->state()));
-            BOOST_CHECK_MESSAGE(s->state() == NState::ABORTED,
-                                "expected state NState::ABORTED, but found to be " << NState::toString(s->state()));
-        }
-    }
-
-    {
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestDeleteNodeCmd.cpp 5.13.0-1/Base/test/TestDeleteNodeCmd.cpp
--- 5.12.4-1/Base/test/TestDeleteNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestDeleteNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,269 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MockServer.hpp"
-#include "MyDefsFixture.hpp"
-#include "ecflow/base/cts/user/DeleteCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_DeleteNodeCmd)
-
-BOOST_AUTO_TEST_CASE(test_delete_node_cmd) {
-    cout << "Base:: ...test_delete_node_cmd\n";
-    TestLog test_log(
-        "test_delete_node_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    MyDefsFixture fixtureDef;
-    MockServer mockServer(&fixtureDef.defsfile_);
-
-    // IMPORTANT: ******************************************************************************
-    // If the DeleteCmd is given a EMPTY list of paths, it will delete *EVERYTHING*
-    // *****************************************************************************************
-
-    // Delete all Aliases
-    {
-        std::vector<alias_ptr> vec;
-        fixtureDef.defsfile_.get_all_aliases(vec);
-        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 aliases but found " << vec.size());
-
-        std::vector<std::string> paths;
-        paths.reserve(vec.size());
-        for (alias_ptr t : vec) {
-            paths.push_back(t->absNodePath());
-        }
-
-        size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
-        BOOST_CHECK_MESSAGE(!paths.empty(), "Expected paths to be specified, *OTHERWISE* we delete all nodes");
-        DeleteCmd cmd(paths);
-        cmd.setup_user_authentification();
-        STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-        BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete aliases");
-        {
-            // ECFLOW-434
-            const std::vector<std::string>& edit_history = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
-            size_t edit_history_size_after               = edit_history_size_before + paths.size();
-            if (edit_history_size_after > Defs::max_edit_history_size_per_node())
-                edit_history_size_after = Defs::max_edit_history_size_per_node();
-            BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
-                                "Expected   " << edit_history_size_after << " edit history but found "
-                                              << edit_history.size());
-        }
-
-        std::vector<alias_ptr> afterDeleteVec;
-        fixtureDef.defsfile_.get_all_aliases(afterDeleteVec);
-        BOOST_REQUIRE_MESSAGE(afterDeleteVec.empty(),
-                              "Expected all aliases to be deleted but found " << afterDeleteVec.size());
-    }
-
-    // Delete all tasks
-    {
-        std::vector<Task*> vec;
-        fixtureDef.defsfile_.getAllTasks(vec);
-        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 tasks but found " << vec.size());
-
-        std::vector<std::string> paths;
-        paths.reserve(vec.size());
-        for (Task* t : vec) {
-            paths.push_back(t->absNodePath());
-        }
-
-        BOOST_CHECK_MESSAGE(!paths.empty(), "Expected paths to be specified, *OTHERWISE* we delete all nodes");
-        size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
-        DeleteCmd cmd(paths);
-        cmd.setup_user_authentification();
-        STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-        BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete tasks");
-        {
-            const std::vector<std::string>& edit_history = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
-            size_t edit_history_size_after               = edit_history_size_before + paths.size();
-            if (edit_history_size_after > Defs::max_edit_history_size_per_node())
-                edit_history_size_after = Defs::max_edit_history_size_per_node();
-            BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
-                                "Expected   " << edit_history_size_after << " edit history but found "
-                                              << edit_history.size());
-        }
-
-        std::vector<Task*> afterDeleteVec;
-        fixtureDef.defsfile_.getAllTasks(afterDeleteVec);
-        BOOST_REQUIRE_MESSAGE(afterDeleteVec.empty(),
-                              "Expected all tasks to be deleted but found " << afterDeleteVec.size());
-    }
-
-    // Delete all Families
-    {
-        // DONT use getAllFamilies as this will return hierarchical families
-        // we don't want to delete families twice
-        //		std::vector<Family*> vec;
-        //		fixtureDef.defsfile_.getAllFamilies(vec);
-    }
-
-    // Delete all Suites
-    {
-        std::vector<suite_ptr> vec = fixtureDef.defsfile_.suiteVec();
-        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 Suites but found " << vec.size());
-        for (suite_ptr s : vec) {
-            {
-                // Delete all Families
-                // *********************************************************************************************
-                // **EXPLICITLY** check for empty paths otherwise we can end up deleting ALL suites accidentally
-                // if DeleteCmd is given an empty list, we will delete all nodes including the suites
-                // *********************************************************************************************
-                std::vector<family_ptr> familyVec = s->familyVec();
-                // 	DONT USE:
-                //        for(family_ptr f: s->familyVec()) {
-                //  As with this will invalidate the iterators.
-                std::vector<std::string> paths;
-                paths.reserve(vec.size());
-                for (family_ptr f : familyVec) {
-                    paths.push_back(f->absNodePath());
-                }
-
-                if (!paths.empty()) {
-                    size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
-                    DeleteCmd cmd(paths);
-                    cmd.setup_user_authentification();
-                    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-                    BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete families");
-                    BOOST_REQUIRE_MESSAGE(s->familyVec().empty(),
-                                          "Expected all Families to be deleted but found " << s->familyVec().size());
-                    {
-                        const std::vector<std::string>& edit_history =
-                            fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
-                        size_t edit_history_size_after = edit_history_size_before + paths.size();
-                        if (edit_history_size_after > Defs::max_edit_history_size_per_node())
-                            edit_history_size_after = Defs::max_edit_history_size_per_node();
-                        BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
-                                            "Expected   " << edit_history_size_after << " edit history but found "
-                                                          << edit_history.size());
-                    }
-                }
-            }
-
-            // delete the suite
-            size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
-            std::string absNodePath         = s->absNodePath();
-            DeleteCmd cmd(absNodePath);
-            cmd.setup_user_authentification();
-            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-            BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete suite at path " << absNodePath);
-            {
-                const std::vector<std::string>& edit_history = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
-                size_t edit_history_size_after               = edit_history_size_before + 1;
-                if (edit_history_size_after > Defs::max_edit_history_size_per_node())
-                    edit_history_size_after = Defs::max_edit_history_size_per_node();
-                BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
-                                    "Expected   " << edit_history_size_after << " edit history but found "
-                                                  << edit_history.size());
-            }
-        }
-
-        BOOST_REQUIRE_MESSAGE(fixtureDef.defsfile_.suiteVec().empty(),
-                              "Expected all Suites to be deleted but found " << fixtureDef.defsfile_.suiteVec().size());
-    }
-
-    {
-        // Clear edit history
-        fixtureDef.defsfile_.clear_edit_history();
-        BOOST_CHECK_MESSAGE(fixtureDef.defsfile_.get_edit_history().size() == 0, "Expected edit history to be empty");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_delete_node_edit_history_ECFLOW_1684) {
-    cout << "Base:: ...test_delete_node_edit_history_ECFLOW_1684\n";
-
-    // This test will ensure that if a suite/family node is deleted, we *remove* any *OLD* edit history associated
-    // with the node, AND and of its children
-
-    // Create log file for the commands to work. auto destroy at end of scope
-    TestLog test_log("test_delete_node_edit_history.log");
-
-    MyDefsFixture fixtureDef;
-    MockServer mockServer(&fixtureDef.defsfile_);
-
-    // suspend all suites and tasks, then check we have some edit history
-    {
-        size_t edit_history_root_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
-        size_t edit_history_before           = fixtureDef.defsfile_.get_edit_history().size();
-        BOOST_CHECK_MESSAGE(edit_history_root_size_before == 0,
-                            "Expected edit_history_root_size_before == 0 but found " << edit_history_root_size_before);
-        BOOST_CHECK_MESSAGE(edit_history_before == 0,
-                            "Expected edit_history_before == 0 but found " << edit_history_before);
-
-        std::vector<Task*> task_vec;
-        fixtureDef.defsfile_.getAllTasks(task_vec);
-        BOOST_CHECK_MESSAGE(task_vec.size() > 0, "Expected > 0 tasks but found " << task_vec.size());
-        std::vector<std::string> paths;
-        paths.reserve(task_vec.size());
-        for (Task* t : task_vec) {
-            paths.push_back(t->absNodePath());
-        }
-        BOOST_CHECK_MESSAGE(!paths.empty(), "Expected paths to be specified, *OTHERWISE* we delete all nodes");
-
-        std::vector<suite_ptr> suite_vec = fixtureDef.defsfile_.suiteVec();
-        for (suite_ptr s : suite_vec) {
-            paths.push_back(s->absNodePath());
-        }
-
-        PathsCmd cmd(PathsCmd::SUSPEND, paths);
-        cmd.setup_user_authentification();
-        STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-        BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to suspend tasks");
-        {
-            size_t edit_history_root_size_after = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
-            size_t edit_history_after           = fixtureDef.defsfile_.get_edit_history().size();
-
-            BOOST_CHECK_MESSAGE(edit_history_root_size_after == 0,
-                                "Expected edit_history_root_size_after == 0 but found "
-                                    << edit_history_root_size_after);
-            BOOST_CHECK_MESSAGE(edit_history_after == paths.size(),
-                                "Expected edit_history_after to be same number of suspended tasks and suites("
-                                    << paths.size() << ") but found " << edit_history_after);
-        }
-    }
-
-    // Delete all Suites, this should delete edit history associated with suites and child tasks
-    {
-        std::vector<suite_ptr> vec = fixtureDef.defsfile_.suiteVec();
-        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 Suites but found " << vec.size());
-        for (suite_ptr s : vec) {
-            std::string absNodePath = s->absNodePath();
-            DeleteCmd cmd(absNodePath);
-            cmd.setup_user_authentification();
-            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-            BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete suite at path " << absNodePath);
-        }
-        BOOST_REQUIRE_MESSAGE(fixtureDef.defsfile_.suiteVec().empty(),
-                              "Expected all Suites to be deleted but found " << fixtureDef.defsfile_.suiteVec().size());
-
-        size_t edit_history_root_size_after = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
-        size_t edit_history_after           = fixtureDef.defsfile_.get_edit_history().size();
-
-        BOOST_CHECK_MESSAGE(edit_history_root_size_after == vec.size(),
-                            "Expected edit_history size of root node to be same as number of deleted suites("
-                                << vec.size() << ") but found " << edit_history_root_size_after);
-        BOOST_CHECK_MESSAGE(edit_history_after == 1,
-                            "Expected edit_history_after == 1 to *ONLY* have root node, but found "
-                                << edit_history_after << "\n"
-                                << fixtureDef.defsfile_.dump_edit_history());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestForceCmd.cpp 5.13.0-1/Base/test/TestForceCmd.cpp
--- 5.12.4-1/Base/test/TestForceCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestForceCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1104 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp> // IWYU pragma: keep
-
-#include "MockServer.hpp"
-#include "MyDefsFixture.hpp"
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/ForceCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/core/PrintStyle.hpp" // IWYU pragma: keep
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_ForceCmd)
-
-static defs_ptr create_defs() {
-    defs_ptr theDefs = Defs::create();
-    suite_ptr suite  = theDefs->add_suite("s1");
-    family_ptr f1    = suite->add_family("f1");
-    task_ptr t1      = f1->add_task("t1");
-    t1->addTime(TimeAttr(10, 30));
-    t1->add_alias_only();
-    task_ptr t2 = f1->add_task("t2");
-    t2->add_alias_only();
-    return theDefs;
-}
-
-BOOST_AUTO_TEST_CASE(test_add_log2) {
-    // create once for all test below, then remove at the end
-    Log::create("test_add_log2.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_CASE(test_force_cmd) {
-    cout << "Base:: ...test_force_cmd\n";
-
-    defs_ptr the_defs = create_defs();
-    the_defs->beginAll();
-    node_ptr s1 = the_defs->findAbsNode("/s1");
-    node_ptr f1 = the_defs->findAbsNode("/s1/f1");
-    node_ptr t1 = the_defs->findAbsNode("/s1/f1/t1");
-    node_ptr t2 = the_defs->findAbsNode("/s1/f1/t2");
-
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
-    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
-
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t2->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t2, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(
-        !t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set since there are NO time depedencies");
-    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
-    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
-
-    the_defs->requeue();
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(s1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(s1, NState::COMPLETE);
-    TestHelper::test_state(f1, NState::COMPLETE);
-    TestHelper::test_state(t1, NState::COMPLETE);
-
-    Node::Requeue_args args(Node::Requeue_args::FULL,
-                            true /* reset repeats*/,
-                            0 /* clear_suspended_in_child_nodes */,
-                            false /* reset_next_time_slot_ */,
-                            true /* reset relative duration */);
-    s1->requeue(args);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
-    BOOST_CHECK_MESSAGE(!t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
-    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
-    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
-
-    node_ptr alias = the_defs->findAbsNode("/s1/f1/t1/alias0");
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(alias->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(alias, NState::COMPLETE);
-}
-
-static void
-doForce(MockServer& mockServer, Node* fnode, const std::string& stateOrEvent, const std::vector<Node*>& nodes) {
-    ForceCmd cmd(fnode->absNodePath(), stateOrEvent, true /*recursive */, true /* set Repeat to last value */);
-    cmd.setup_user_authentification();
-    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force for node " << fnode->debugNodePath());
-
-    for (auto node : nodes) {
-        if (NState::isValid(stateOrEvent)) {
-            NState::State state = NState::toState(stateOrEvent);
-
-            // Force Cmd recursive does **NOT** apply to aliases.
-            if (node->isAlias()) {
-                // The alias should still be in default QUEUED state
-                BOOST_CHECK_MESSAGE(node->state() == NState::QUEUED,
-                                    "Expected state NState::QUEUED for alias but found "
-                                        << NState::toString(node->state()) << " for alias " << node->debugNodePath());
-            }
-            else {
-                BOOST_CHECK_MESSAGE(node->state() == state,
-                                    "Expected state " << NState::toString(state) << " but found "
-                                                      << NState::toString(node->state()) << " for node "
-                                                      << node->debugNodePath());
-            }
-        }
-        else
-            BOOST_CHECK_MESSAGE(false, "oops");
-
-        if (!(node->repeat().empty())) {
-            BOOST_CHECK_MESSAGE(!node->repeat().valid(), "Expected repeat to be set to last value. ie in valid");
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_force_cmd_recursive) {
-    cout << "Base:: ...test_force_cmd_recursive\n";
-
-    defs_ptr the_defs = create_defs();
-    node_ptr suite    = the_defs->findAbsNode("/s1");
-    std::vector<Node*> nodes;
-    suite->getAllNodes(nodes);
-
-    MockServer mockServer(the_defs);
-    std::vector<std::string> all_states = NState::allStates();
-    for (const std::string& state : all_states) {
-        doForce(mockServer, suite.get(), state, nodes);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_force_cmd_bubbles_up_state_changes) {
-    cout << "Base:: ...test_force_cmd_bubbles_up_state_changes\n";
-
-    defs_ptr the_defs = create_defs();
-    std::vector<Node*> nodes;
-    std::vector<Task*> tasks;
-    the_defs->getAllNodes(nodes);
-    the_defs->getAllTasks(tasks);
-    node_ptr suite = the_defs->findAbsNode("/s1");
-
-    MockServer mockServer(the_defs);
-
-    std::vector<std::string> all_states = NState::allStates();
-    for (const std::string& state : all_states) {
-
-        // 		cout << "Setting all tasks to state " << state << "\n";
-        for (Task* task : tasks) {
-            ForceCmd cmd(task->absNodePath(), state, false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force for node " << task->debugNodePath());
-        }
-
-        // Check that state change set on task has bubbled up to the suite.
-        // Since the state has been set on *all* tasks
-        // 		cout << "Suite state = " << NState::toString(suite->state()) << "\n";
-        NState::State expected_state = NState::toState(state);
-        BOOST_CHECK_MESSAGE(suite->state() == expected_state,
-                            "Expected state " << NState::toString(expected_state) << " but found "
-                                              << NState::toString(suite->state()) << " for suite "
-                                              << suite->debugNodePath());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_force_cmd_alias_does_not_bubble_up_state_changes) {
-    cout << "Base:: ...test_force_cmd_alias_does_not_bubble_up_state_changes\n";
-
-    defs_ptr the_defs = create_defs();
-    std::vector<Node*> nodes;
-    std::vector<alias_ptr> aliases;
-    the_defs->getAllNodes(nodes);
-    the_defs->get_all_aliases(aliases);
-    node_ptr suite = the_defs->findAbsNode("/s1");
-
-    // initialize by setting all nodes to state QUEUED
-    for (Node* n : nodes) {
-        n->set_state(NState::QUEUED);
-    }
-
-    MockServer mockServer(the_defs);
-    std::vector<std::string> all_states = NState::allStates();
-    for (const std::string& state : all_states) {
-
-        for (alias_ptr alias : aliases) {
-            ForceCmd cmd(alias->absNodePath(), state, false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force for alias " << alias->debugNodePath());
-        }
-
-        // Check that state change set on alias has *NOT* bubbled up to the suite.
-        BOOST_CHECK_MESSAGE(suite->state() == NState::QUEUED,
-                            "Expected suite to have state QUEUED but found " << NState::toString(suite->state()));
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_force_events) {
-    cout << "Base:: ...test_force_events\n";
-
-    MyDefsFixture fixtureDef;
-    MockServer mockServer(&fixtureDef.defsfile_);
-
-    node_ptr suite = fixtureDef.fixtureDefsFile().findAbsNode("/suiteName");
-    BOOST_REQUIRE_MESSAGE(suite.get(), "Could not find suite");
-    std::vector<Node*> nodes;
-    suite->getAllNodes(nodes);
-
-    /// Set and clear events
-    for (Node* node : nodes) {
-        for (const Event& e : node->events()) {
-            std::string path = node->absNodePath() + ":" + e.name_or_number();
-            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force event for node " << node->debugNodePath());
-        }
-        for (const Event& e : node->events()) {
-            BOOST_CHECK_MESSAGE(e.value(), "Event not set as expected for node " << node->debugNodePath());
-        }
-    }
-    for (Node* node : nodes) {
-        for (const Event& e : node->events()) {
-            std::string path = node->absNodePath() + ":" + e.name_or_number();
-            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force event for node " << node->debugNodePath());
-        }
-        for (const Event& e : node->events()) {
-            BOOST_CHECK_MESSAGE(!e.value(), "Event not cleared as expected for node " << node->debugNodePath());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_force_events_errors) {
-    cout << "Base:: ...test_force_events_errors\n";
-
-    MyDefsFixture fixtureDef;
-    MockServer mockServer(&fixtureDef.defsfile_);
-
-    node_ptr suite = fixtureDef.fixtureDefsFile().findAbsNode("/suiteName");
-    BOOST_REQUIRE_MESSAGE(suite.get(), "Could not find suite");
-    std::vector<Node*> nodes;
-    suite->getAllNodes(nodes);
-
-    /// Make a path that does not exist
-    for (Node* node : nodes) {
-        for (const Event& e : node->events()) {
-            std::string path = node->absNodePath() + "/path/doesnot/exist" + ":" + e.name_or_number();
-            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
-        }
-    }
-    for (Node* node : nodes) {
-        for (const Event& e : node->events()) {
-            std::string path = node->absNodePath() + "/path/doesnot/exist" + ":" + e.name_or_number();
-            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
-        }
-    }
-
-    /// Make path that does not contain a event
-    for (Node* node : nodes) {
-        if (node->events().empty()) {
-            std::string path = node->absNodePath();
-            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
-        }
-    }
-    for (Node* node : nodes) {
-        if (node->events().empty()) {
-            std::string path = node->absNodePath();
-            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
-        }
-    }
-
-    /// Make a event that does not exist
-    for (Node* node : nodes) {
-        for (const Event& e : node->events()) {
-            std::string path = node->absNodePath() + ":" + e.name_or_number() + "made_up";
-            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
-        }
-    }
-    for (Node* node : nodes) {
-        for (const Event& e : node->events()) {
-            std::string path = node->absNodePath() + ":" + e.name_or_number() + "made_up";
-            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
-            cmd.setup_user_authentification();
-            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive) {
-    // This test is custom. When the user interactively forces a node to the
-    // complete state, and that node has pending time activities. The default
-    // behaviour, is the node is re-queued again, and hence the propagation up the
-    // node tree does not happen. This is test checks that the node does *not* exhibit
-    // this functionality. What we want is that task is set to complete, without
-    // forcing a re-queue, this is then propagated up the node tree. Which forces the
-    // family to complete, and hence update the repeat variable.
-    cout << "Base:: ...test_force_interactive\n";
-
-    //   suite s1
-    //     family daily
-    //       repeat date YMD 20101215 20101217 1
-    //       task t1
-    //         time 11:30
-    //     endfamily
-    //   endsuite
-    // make sure time is set *before* 11:30, so that time dependency holds the task
-    defs_ptr the_defs = Defs::create();
-    suite_ptr suite   = Suite::create("s1");
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(1 /*hour*/, 0 /*minutes*/);
-    suite->addClock(clockAttr);
-    family_ptr f1 = Family::create("daily");
-    f1->addRepeat(RepeatDate("date", 20101215, 20101217));
-    task_ptr t1 = Task::create("t1");
-    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(11, 30)));
-    f1->addTask(t1);
-    suite->addFamily(f1);
-    the_defs->addSuite(suite);
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, before test");
-    BOOST_CHECK_MESSAGE(!suite->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_REQUIRE_MESSAGE(f1->repeat().value() == 20101215,
-                          "Repeat value expected is 20101215 but found " << f1->repeat().value());
-
-    // Force the task t1 to complete state.
-    // Since task t1 is complete, the family 'daily' should complete.
-    // This will cause the repeat to take the next value anf forcing a requeue
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_REQUIRE_MESSAGE(f1->repeat().value() == 20101216,
-                          "Repeat value expected is 20101216 but found " << f1->repeat().value());
-
-    // Reque should mean flag was cleared + on suite should never get set, since flag is stopped at repeat
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, since task was REQUED");
-    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, since family was REQUED");
-    BOOST_CHECK_MESSAGE(!suite->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, since repeat should stop flag "
-                        "propagation up node tree");
-
-    // Force the task t1 to complete again
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_REQUIRE_MESSAGE(f1->repeat().value() == 20101217,
-                          "Repeat value expected is 20101217 but found " << f1->repeat().value());
-
-    // Do for the last time,
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    TestHelper::test_state(f1, NState::COMPLETE);
-    TestHelper::test_state(suite, NState::COMPLETE);
-
-    // Since we completed, without a requeue, we should expect flag to stay set.
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set, since there was no reque");
-
-    // Flag propagation should stop at the repeat
-    BOOST_CHECK_MESSAGE(!suite->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP *NOT* to be set");
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot) {
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user has a single time slot. We should stay complete and NOT requee
-    //
-    cout << "Base:: ...test_force_interactive_next_time_slot\n";
-
-    //   suite s1
-    //       task t1
-    //          time 10:00
-    //   endsuite
-    // make sure time is set *before* 10:00, so that time dependency holds the task
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    task_ptr t1     = suite->add_task("t1");
-    t1->addTime(TimeAttr(10, 0));
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
-    suite->addClock(clockAttr);
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
-
-    // since we started at 09:30 the next time slot should be 10:00
-    const TimeSlot& next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
-                        "Expected next time slot of 10:00 but found " << next_time_slot.toString());
-
-    // Force the task t1 to complete state. Since we had ONLY a SINGLE time dependency we should stay complete
-    // It should also advance the next time slot
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(!t1->timeVec().back().time_series().is_valid(), "Expected 10:00 time slot to have expired");
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-
-    // call again should, should be do difference, EXPECT no change, if its complete, seting complete, avoids another
-    // state change
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)),
-        false /*dont Check change numbers*/);
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(!t1->timeVec().back().time_series().is_valid(), "Expected 10:00 time slot to have expired");
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-
-    /// we will now Re-queue, Since the time is still 09:30, we expect next_time slot to be 10:00
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
-                        "After Re-queue, Expected next time slot of 10:00 but found " << next_time_slot.toString());
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_1) {
-    // Start TIME at 9:30
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user set of time slots. In this case the node should complete and then
-    // requee and miss the next time. If this is repeated, eventually we should reach the
-    // end of the time slot. In which case the node should *not* re-queue and stay complete
-    //
-    // When the node is then re-queued check that the time has been correctly reset.
-    cout << "Base:: ...test_force_interactive_next_time_slot_1\n";
-
-    //   suite s1
-    //       task t1
-    //          time 10:00
-    //          time 11:00
-    //          time 12:00
-    //          time 13:00
-    //   endsuite
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    task_ptr t1     = suite->add_task("t1");
-    t1->addTime(TimeAttr(10, 0));
-    t1->addTime(TimeAttr(11, 0));
-    t1->addTime(TimeAttr(12, 0));
-    t1->addTime(TimeAttr(13, 0));
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // *start* at 9:30
-    suite->addClock(clockAttr);
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
-
-    // get all the time attributes
-    const TimeSeries& ts_10 = t1->timeVec()[0].time_series();
-    const TimeSeries& ts_11 = t1->timeVec()[1].time_series();
-    const TimeSeries& ts_12 = t1->timeVec()[2].time_series();
-    const TimeSeries& ts_13 = t1->timeVec()[3].time_series();
-    BOOST_CHECK_MESSAGE(ts_10.is_valid(), "Expected time 10 to be valid since we started at 9:30 ");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
-
-    const TimeSlot& time_10 = t1->timeVec()[0].time_series().get_next_time_slot();
-    const TimeSlot& time_11 = t1->timeVec()[1].time_series().get_next_time_slot();
-    const TimeSlot& time_12 = t1->timeVec()[2].time_series().get_next_time_slot();
-    const TimeSlot& time_13 = t1->timeVec()[3].time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(time_10 == TimeSlot(10, 0),
-                        "Expected next time slot of 10:00 but found " << time_10.toString());
-    BOOST_CHECK_MESSAGE(time_11 == TimeSlot(11, 0),
-                        "Expected next time slot of 11:00 but found " << time_11.toString());
-    BOOST_CHECK_MESSAGE(time_12 == TimeSlot(12, 0),
-                        "Expected next time slot of 12:00 but found " << time_12.toString());
-    BOOST_CHECK_MESSAGE(time_13 == TimeSlot(13, 0),
-                        "Expected next time slot of 13:00 but found " << time_13.toString());
-
-    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired  ");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid.");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
-
-    // Repeat
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
-
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
-
-    // Repeat *last* time, since all times have expired, we expect task to stay complete.
-    // Addtionally since we have *not* re-queued the flag NO_REQUE_IF_SINGLE_TIME_DEP should have remained set
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_13.is_valid(), "Expected time 13 to be expired due to force cmd");
-
-    /// we will now Re-queue, Since the time is still 10:30, we expect valid from 11:00 and not 10:00
-    /// We should also have cleared NO_REQUE_IF_SINGLE_TIME_DEP
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(ts_10.is_valid(), "Expected time 10 to be in valid since we started clock at 9:30 ");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_2) {
-    // Start TIME at 9:30
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user has a time range. In this case the node should complete and then
-    // requee and miss the next time slot. If this is repeated, eventually we should reach the
-    // end of the time slot. In which case the node should *not* reque and stay complete
-    //
-    // When the node is then requeed check that the next time slot has been correctly reset.
-    cout << "Base:: ...test_force_interactive_next_time_slot_2\n";
-
-    //   suite s1
-    //       task t1
-    //          time 10:00 14:00 01:00
-    //   endsuite
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    task_ptr t1     = suite->add_task("t1");
-    t1->addTime(TimeAttr(TimeSlot(10, 0), TimeSlot(14, 0), TimeSlot(1, 0)));
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 99:30
-    suite->addClock(clockAttr);
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
-
-    // since we started at 09:30 the next time slot should be 10:00
-    const TimeSlot& next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
-                        "Expected next time slot of 10:00 but found " << next_time_slot.toString());
-
-    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
-    // It should also advance the next time slot
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
-                        "Expected next time slot of 11:00 but found " << next_time_slot.toString());
-
-    // Repeat, to make sure next_time_slot is advanced
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(12, 0),
-                        "Expected next time slot of 12:00 but found " << next_time_slot.toString());
-
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(13, 0),
-                        "Expected next time slot of 13:00 but found " << next_time_slot.toString());
-
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(14, 0),
-                        "Expected next time slot of 14:00 but found " << next_time_slot.toString());
-
-    // Repeat, ** THIS time we have *exceeded* the time range, it should no longer requeue, and should stay complete
-    //         Additionally since there is no reque we expect NO_REQUE_IF_SINGLE_TIME_DEP to remain set
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(15, 0),
-                        "Expected next time slot of 15:00 but found " << next_time_slot.toString());
-
-    /// we will now Re-queue, Since the time is still 10:30, we expect next_time slot to be 11:00 and not 10:00
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
-                        "After Re-queue, Expected next time slot of 10:00 but found " << next_time_slot.toString());
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_3) {
-    // Start TIME at 10:30
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user set of time slots. In this case the node should complete and then
-    // requee and miss the next time. If this is repeated, eventually we should reach the
-    // end of the time slot. In which case the node should *not* re-queue and stay complete
-    //
-    // When the node is then re-queued check that the time has been correctly reset.
-    cout << "Base:: ...test_force_interactive_next_time_slot_3\n";
-
-    //   suite s1
-    //       task t1
-    //          time 10:00
-    //          time 11:00
-    //          time 12:00
-    //          time 13:00
-    //   endsuite
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    task_ptr t1     = suite->add_task("t1");
-    t1->addTime(TimeAttr(10, 0));
-    t1->addTime(TimeAttr(11, 0));
-    t1->addTime(TimeAttr(12, 0));
-    t1->addTime(TimeAttr(13, 0));
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(10 /*hour*/, 30 /*minutes*/); // *start* at 10:30
-    suite->addClock(clockAttr);
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
-
-    // get all the time attributes
-    const TimeSeries& ts_10 = t1->timeVec()[0].time_series();
-    const TimeSeries& ts_11 = t1->timeVec()[1].time_series();
-    const TimeSeries& ts_12 = t1->timeVec()[2].time_series();
-    const TimeSeries& ts_13 = t1->timeVec()[3].time_series();
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be in-valid since we started clock at 10:30 ");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 10:30");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 10:30");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 10:30");
-
-    const TimeSlot& time_10 = t1->timeVec()[0].time_series().get_next_time_slot();
-    const TimeSlot& time_11 = t1->timeVec()[1].time_series().get_next_time_slot();
-    const TimeSlot& time_12 = t1->timeVec()[2].time_series().get_next_time_slot();
-    const TimeSlot& time_13 = t1->timeVec()[3].time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(time_10 == TimeSlot(10, 0),
-                        "Expected next time slot of 10:00 but found " << time_10.toString());
-    BOOST_CHECK_MESSAGE(time_11 == TimeSlot(11, 0),
-                        "Expected next time slot of 11:00 but found " << time_11.toString());
-    BOOST_CHECK_MESSAGE(time_12 == TimeSlot(12, 0),
-                        "Expected next time slot of 12:00 but found " << time_12.toString());
-    BOOST_CHECK_MESSAGE(time_13 == TimeSlot(13, 0),
-                        "Expected next time slot of 13:00 but found " << time_13.toString());
-
-    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired, since we just completed.");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
-
-    // Repeat
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
-
-    // Repeat *last* time, since all times have expired, we expect task to complete.
-    // Addtionally since we have *not* re-queued the flag NO_REQUE_IF_SINGLE_TIME_DEP should have remained set
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
-    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
-    BOOST_CHECK_MESSAGE(!ts_13.is_valid(), "Expected time 13 to be expired due to force cmd");
-
-    /// we will now Re-queue, Since the time is still 10:30, we expect valid from 11:00 and not 10:00
-    /// We should also have cleared NO_REQUE_IF_SINGLE_TIME_DEP
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be in valid since we started clock at 10:30 ");
-    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid");
-    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
-    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_4) {
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user has a time range. In this case the node should complete and then
-    // requee and miss the next time slot. If this is repeated, eventually we should reach the
-    // end of the time slot. In which case the node should *not* reque and stay complete
-    //
-    // When the node is then requeed check that the next time slot has been correctly reset.
-    cout << "Base:: ...test_force_interactive_next_time_slot_4\n";
-
-    //   suite s1
-    //       task t1
-    //          time 10:00 14:00 01:00
-    //   endsuite
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    task_ptr t1     = suite->add_task("t1");
-    t1->addTime(TimeAttr(TimeSlot(10, 0), TimeSlot(14, 0), TimeSlot(1, 0)));
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(10 /*hour*/, 30 /*minutes*/); // start at 10:30
-    suite->addClock(clockAttr);
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
-
-    // since we started at 10:30 the next time slot should be 11:00
-    const TimeSlot& next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
-                        "Expected next time slot of 11:00 but found " << next_time_slot.toString());
-
-    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
-    // It should also advance the next time slot
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(12, 0),
-                        "Expected next time slot of 12:00 but found " << next_time_slot.toString());
-
-    // Repeat, to make sure next_time_slot is advanced
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(13, 0),
-                        "Expected next time slot of 13:00 but found " << next_time_slot.toString());
-
-    // Repeat, to make sure next_time_slot is advanced
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(14, 0),
-                        "Expected next time slot of 14:00 but found " << next_time_slot.toString());
-
-    // Repeat, ** THIS time we have *exceeded* the time range, it should no longer requeue, and should stay complete
-    //         Additionally since there is no reque we expect NO_REQUE_IF_SINGLE_TIME_DEP to remain set
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(15, 0),
-                        "Expected next time slot of 15:00 but found " << next_time_slot.toString());
-
-    /// we will now Re-queue, Since the time is still 10:30, we expect next_time slot to be 11:00 and not 10:00
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
-                        "After Re-queue, Expected next time slot of 11:00 but found " << next_time_slot.toString());
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_for_cron) {
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user has a time range. In this case the node should complete and then
-    // requee and miss the next time slot. If this is repeated, eventually we should reach the
-    // end of the time slot.
-    //
-    // When the node is then requeed check that the next time slot has been correctly reset.
-    cout << "Base:: ...test_force_interactive_next_time_slot_for_cron\n";
-
-    //   suite s1
-    //       task t1
-    //          cron 10:00 13:00 01:00
-    //   endsuite
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
-    suite->addClock(clockAttr);
-
-    task_ptr t1 = suite->add_task("t1");
-    ecf::CronAttr cronAttr;
-    cronAttr.addTimeSeries(TimeSlot(10, 0), TimeSlot(13, 0), TimeSlot(1, 0));
-    t1->addCron(cronAttr);
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
-
-    // since we started at 09:30 the next time slot should be 10:00
-    const TimeSlot& next_time_slot = t1->crons().back().time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
-                        "Expected next time slot of 10:00 but found " << next_time_slot.toString());
-
-    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
-    // It should also advance the next time slot
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
-                        "Expected next time slot of 11:00 but found " << next_time_slot.toString());
-
-    // Repeat, to make sure next_time_slot is advanced
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(12, 0),
-                        "Expected next time slot of 12:00 but found " << next_time_slot.toString());
-
-    // Repeat, to make sure next_time_slot is advanced
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(13, 0),
-                        "Expected next time slot of 13:00 but found " << next_time_slot.toString());
-
-    // Repeat, ** THIS time we have *exceeded* the time range, However the cron *ALWAYS* re-queues
-    //         Additionally since there is no reque we expect NO_REQUE_IF_SINGLE_TIME_DEP to remain set
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(14, 0),
-                        "Expected next time slot of 14:00 but found " << next_time_slot.toString());
-
-    /// we will now Re-queue, Since the time is still 09:30, we expect next_time slot to be 10:00 and not 14:00
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
-                        "After Re-queue, Expected next time slot of 10:00 but found " << next_time_slot.toString());
-}
-
-BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_for_cron_on_family) {
-    // This test is custom. When the user interactively forces a node to the complete state,
-    // But where the user has a time range. In this case the node should complete and then
-    // requee and miss the next time slot. If this is repeated, eventually we should reach the
-    // end of the time slot.
-    //
-    // When the node is then requeed check that the next time slot has been correctly reset.
-    cout << "Base:: ...test_force_interactive_next_time_slot_for_cron_on_family\n";
-
-    //   suite s1
-    //     family
-    //       cron 10:00 13:00 01:00
-    //       task t1
-    //          time 11:00
-    //       task t2
-    //          time 12:00
-    //   endsuite
-    Defs the_defs;
-    suite_ptr suite = the_defs.add_suite("s1");
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
-    suite->addClock(clockAttr);
-
-    family_ptr f1 = suite->add_family("f1");
-    ecf::CronAttr cronAttr;
-    cronAttr.addTimeSeries(TimeSlot(10, 0), TimeSlot(13, 0), TimeSlot(1, 0));
-    f1->addCron(cronAttr);
-
-    task_ptr t1 = f1->add_task("t1");
-    t1->addTime(TimeAttr(11, 0));
-
-    task_ptr t2 = f1->add_task("t2");
-    t2->addTime(TimeAttr(12, 0));
-
-    // before test flags should be clear
-    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-    BOOST_CHECK_MESSAGE(!t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
-
-    /// begin the suite
-    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    TestHelper::test_state(t2, NState::QUEUED);
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
-
-    // since we started at 09:30 the next time slot should be 11:00
-    const TimeSlot& t1_next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
-    const TimeSlot& t2_next_time_slot = t2->timeVec().back().time_series().get_next_time_slot();
-    BOOST_CHECK_MESSAGE(t1_next_time_slot == TimeSlot(11, 0),
-                        "Expected next time slot of 11:00 but found " << t1_next_time_slot.toString());
-    BOOST_CHECK_MESSAGE(t2_next_time_slot == TimeSlot(12, 0),
-                        "Expected next time slot of 12:00 but found " << t2_next_time_slot.toString());
-
-    // Force the task t1 & t2 to complete state. Since we only have a single time dependency it should expire
-    // It should also advance the next time slot
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    TestHelper::test_state(t2, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(!t1->timeVec().back().time_series().is_valid(), "Expected 11:00 time slot to be expired ");
-
-    // Forcing t2 to complete as well should, end up requeueing t1,t2 due to parent cron
-    TestHelper::invokeRequest(
-        &the_defs,
-        Cmd_ptr(
-            new ForceCmd(t2->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::QUEUED);
-    TestHelper::test_state(t2, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(t1->timeVec().back().time_series().is_valid(), "Expected 11:00 time slot to be valid ");
-    BOOST_CHECK_MESSAGE(t2->timeVec().back().time_series().is_valid(), "Expected 12:00 time slot to be valid ");
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-    BOOST_CHECK_MESSAGE(!t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_destroy_log2) {
-    Log::destroy();
-    fs::remove("test_add_log2.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestFreeDepCmd.cpp 5.13.0-1/Base/test/TestFreeDepCmd.cpp
--- 5.12.4-1/Base/test/TestFreeDepCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestFreeDepCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,342 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "MockServer.hpp"
-#include "ecflow/base/cts/user/FreeDepCmd.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_FreeDepCmd)
-
-BOOST_AUTO_TEST_CASE(test_free_dep_cmd) {
-    cout << "Base:: ...test_free_dep_cmd\n";
-    TestLog test_log("test_free_dep_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    // Create a test and add the date and time dependencies
-    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 30, 0));
-    ptime time_plus_hour   = theLocalTime + hours(1);
-    ptime time_plus_2_hour = theLocalTime + hours(2);
-    date todaysDate        = theLocalTime.date();
-    date tomorrows_date    = todaysDate + date_duration(1);
-    date tomorrows_date_1  = todaysDate + date_duration(2);
-
-    // Get tomorrow as a day so that isFree fails.
-    tm day_1 = to_tm(tomorrows_date);
-    tm day_2 = to_tm(tomorrows_date_1);
-
-    suite_ptr suite;
-    task_ptr task;
-    Defs theDefs;
-    {
-        suite = theDefs.add_suite("test_time");
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task           = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_hour.time_of_day())));
-        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_2_hour.time_of_day())));
-        task->addTime(ecf::TimeAttr(
-            ecf::TimeSlot(1, 1), ecf::TimeSlot(1, 3), ecf::TimeSlot(0, 1), true /*relative to suite start*/
-            ));
-        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_hour.time_of_day())));
-        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_2_hour.time_of_day())));
-        task->addDate(DateAttr(tomorrows_date));
-        task->addDate(DateAttr(tomorrows_date_1));
-        task->addDay(DayAttr(static_cast<DayAttr::Day_t>(day_1.tm_wday)));
-        task->addDay(DayAttr(static_cast<DayAttr::Day_t>(day_2.tm_wday)));
-        task->add_trigger("t2 == complete");
-
-        CronAttr cronAttr;
-        cronAttr.addTimeSeries(ecf::TimeSlot(time_plus_hour.time_of_day()),
-                               ecf::TimeSlot(time_plus_2_hour.time_of_day()),
-                               ecf::TimeSlot(0, 1));
-        task->addCron(cronAttr);
-
-        fam->add_task("t2");
-        //  	cout << theDefs << "\n";
-    }
-    std::vector<task_ptr> vec;
-    theDefs.get_all_tasks(vec);
-    BOOST_REQUIRE_MESSAGE(vec.size() == 2, "Error in number of tasks");
-
-    // This will initialise the calendar from the Clock attribute
-    theDefs.beginAll();
-
-    // First all trigger should fail to evaluate AND all dependencies should NOT be free
-    BOOST_REQUIRE_MESSAGE(task->triggerAst(), "Expected trigger abstract syntax tree for task " << task->absNodePath());
-    BOOST_REQUIRE_MESSAGE(!task->triggerAst()->evaluate(), "Trigger should not evaluate");
-
-    const Calendar& cal = suite->calendar();
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
-    }
-    for (const ecf::TodayAttr& attr : task->todayVec()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Today should not be free");
-    }
-    for (const ecf::CronAttr& attr : task->crons()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Cron should not be free");
-    }
-    for (const DateAttr& attr : task->dates()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Date should not be free");
-    }
-    for (const DayAttr& attr : task->days()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), "Day should not be free");
-    }
-
-    // Invoke the FreeDepCmd
-    MockServer mockServer(&theDefs);
-
-    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
-    cmd.setup_user_authentification();
-    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
-
-    // Dependencies should now all be free now.
-    BOOST_REQUIRE_MESSAGE(task->get_trigger()->isFree(), "Trigger should evaluate");
-    bool at_least_one_free = false;
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
-
-    at_least_one_free = false;
-    for (const ecf::TodayAttr& attr : task->todayVec()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Today should be free");
-
-    at_least_one_free = false;
-    for (const ecf::CronAttr& attr : task->crons()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Cron should be free");
-
-    at_least_one_free = false;
-    for (const DateAttr& attr : task->dates()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Date should be free");
-
-    at_least_one_free = false;
-    for (const DayAttr& attr : task->days()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Day should be free");
-}
-
-BOOST_AUTO_TEST_CASE(test_free_dep_cmd_single_time_slot) {
-    cout << "Base:: ...test_free_dep_cmd_single_time_slot\n";
-    TestLog test_log("test_free_dep_cmd_single_time_slot.log"); // will create log file, and destroy log and remove file
-                                                                // at end of scope
-
-    // We add a time dependency *AFTER* the suite/calendar time
-    // This checks that we DO NOT re-queue a task with a future time dependency
-    // when a time dependency has been freed
-    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 30, 0));
-    ptime time_plus_2minute = theLocalTime + minutes(2);
-
-    suite_ptr suite;
-    task_ptr task;
-    Defs theDefs;
-    {
-        suite = theDefs.add_suite("test_time");
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite->addClock(clockAttr);
-        task = suite->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_2minute.time_of_day())));
-    }
-
-    // This will initialise the calendar from the Clock attribute
-    theDefs.beginAll();
-
-    // expect task to be holding at 9:30
-    const Calendar& cal = suite->calendar();
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
-    }
-
-    // Invoke the FreeDepCmd
-    MockServer mockServer(&theDefs);
-    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
-    cmd.setup_user_authentification();
-    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
-
-    // expect task to be free
-    bool at_least_one_free = false;
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
-
-    // The crux of the test. Should not requeue.
-    BOOST_CHECK_MESSAGE(task->state() == NState::ACTIVE,
-                        "Free dependency should have done an immediate job submission. Expected active state");
-    task->complete();
-    BOOST_CHECK_MESSAGE(task->state() == NState::COMPLETE,
-                        "Expected Complete but found "
-                            << NState::toString(task->state())
-                            << ", free dependency should avoid re-queue for a future single time dependency.");
-}
-
-BOOST_AUTO_TEST_CASE(test_free_dep_cmd_with_time_series) {
-    cout << "Base:: ...test_free_dep_cmd_with_time_series\n";
-    TestLog test_log("test_free_dep_cmd_with_time_series.log"); // will create log file, and destroy log and remove file
-                                                                // at end of scope
-
-    // We start the suite *IN BETWEEN* a time series, and the force free dependency
-    // This checks that we DO NOT re-queue a task with a future time dependency
-    // when a time dependency has been freed
-    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 29, 0));
-    suite_ptr suite;
-    task_ptr task;
-    Defs theDefs;
-    {
-        suite = theDefs.add_suite("test_time");
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite->addClock(clockAttr);
-        task = suite->add_task("t");
-        task->addTime(ecf::TimeAttr(
-            ecf::TimeSlot(9, 28), ecf::TimeSlot(9, 30), ecf::TimeSlot(0, 2), false /*relative to suite start*/
-            ));
-    }
-
-    // This will initialise the calendar from the Clock attribute
-    theDefs.beginAll();
-
-    // expect task to be holding, at 9:29
-    const Calendar& cal = suite->calendar();
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
-    }
-
-    // Invoke the FreeDepCmd
-    MockServer mockServer(&theDefs);
-    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
-    cmd.setup_user_authentification();
-    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
-
-    // expect task to be free
-    bool at_least_one_free = false;
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
-
-    // The crux of the test. Should not requeue, as we should have advanced the time slot beyond the END point
-    // i.e FreeDepCmd will advance the time slot, beyond end time
-    BOOST_CHECK_MESSAGE(task->state() == NState::ACTIVE,
-                        "Free dependency should have done an immediate job submission. Expected active state");
-    task->complete();
-    BOOST_CHECK_MESSAGE(task->state() == NState::COMPLETE,
-                        "Expected Complete but found "
-                            << NState::toString(task->state())
-                            << ", free dependency should avoid re-queue for a future single time dependency.");
-}
-
-BOOST_AUTO_TEST_CASE(test_free_dep_cmd_with_time_series_2) {
-    cout << "Base:: ...test_free_dep_cmd_with_time_series_2\n";
-    TestLog test_log("test_free_dep_cmd_with_time_series_2.log"); // will create log file, and destroy log and remove
-                                                                  // file at end of scope
-
-    // We start the suite *IN BETWEEN* a time series, and the force free dependency
-    // This time we have a larger range, and *SHOULD* re-queue, even if we miss a time slot
-    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 29, 0));
-    suite_ptr suite;
-    task_ptr task;
-    Defs theDefs;
-    {
-        suite = theDefs.add_suite("test_time");
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite->addClock(clockAttr);
-        task = suite->add_task("t");
-        task->addTime(ecf::TimeAttr(
-            ecf::TimeSlot(9, 28), ecf::TimeSlot(9, 34), ecf::TimeSlot(0, 2), false /*relative to suite start*/
-            ));
-    }
-
-    // This will initialise the calendar from the Clock attribute
-    // Will initialise  nextTimeSlot=09:30
-    theDefs.beginAll();
-
-    // expect task to be holding, at 9:29
-    const Calendar& cal = suite->calendar();
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
-    }
-
-    // Invoke the FreeDepCmd. This will update next nextTimeSlot to 09:32
-    MockServer mockServer(&theDefs);
-    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
-    cmd.setup_user_authentification();
-    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
-    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
-
-    // expect task to be free
-    bool at_least_one_free = false;
-    for (const ecf::TimeAttr& attr : task->timeVec()) {
-        if (attr.isFree(cal)) {
-            at_least_one_free = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
-
-    // The crux of the test. Even if we advance the time slot we should *STILL* be in range
-    BOOST_CHECK_MESSAGE(task->state() == NState::ACTIVE,
-                        "Free dependency should have done an immediate job submission. Expected active state");
-    task->complete();
-    BOOST_CHECK_MESSAGE(task->state() == NState::QUEUED,
-                        "Expected QUEUED but found "
-                            << NState::toString(task->state())
-                            << ", free dependency should avoid re-queue for a future single time dependency.");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestHelper.hpp 5.13.0-1/Base/test/TestHelper.hpp
--- 5.12.4-1/Base/test/TestHelper.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestHelper.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,125 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_base_test_TestHelper_HPP
-#define ecflow_base_test_TestHelper_HPP
-
-#include <boost/test/test_tools.hpp>
-
-#include "MockServer.hpp"
-#include "ecflow/base/ClientToServerRequest.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/node/Node.hpp"
-
-// defines statics utility functions used by more than one test
-class TestHelper {
-public:
-    static std::string invokeRequest(Defs* defs, Cmd_ptr theCmd, bool check_change_numbers = true) {
-
-        // Check that state change happens
-        unsigned int state_change_no  = Ecf::state_change_no();
-        unsigned int modify_change_no = Ecf::modify_change_no();
-
-        // Setup command for invocation
-        ClientToServerRequest cmd_request;
-        cmd_request.set_cmd(theCmd);
-        // std::cout << cmd_request << "\n";
-
-        MockServer server(defs);
-        STC_Cmd_ptr result = cmd_request.handleRequest(&server);
-        BOOST_CHECK_MESSAGE(result, "ClientToServerRequest " << cmd_request << " returned NULL\n");
-        BOOST_CHECK_MESSAGE(result->error().empty(), cmd_request << " " << result->error());
-        if (check_change_numbers) {
-            BOOST_CHECK_MESSAGE(state_change_no != Ecf::state_change_no() ||
-                                    modify_change_no != Ecf::modify_change_no(),
-                                "State & modify change numbers unaltered by command " << cmd_request);
-
-            // Some tests(TestSSyncCmd_CH1.cpp), create defs where invariants like change numbers are deliberately
-            // different
-            std::string error_msg;
-            BOOST_CHECK_MESSAGE(defs->checkInvariants(error_msg),
-                                "invokeRequest checkInvariants failed " << error_msg << " for cmd " << cmd_request);
-        }
-        if (result)
-            return result->get_string();
-        return std::string();
-    }
-
-    static std::string invokeRequest(AbstractServer* server, Cmd_ptr theCmd, bool check_change_numbers = true) {
-
-        // Check that state change happens
-        unsigned int state_change_no  = Ecf::state_change_no();
-        unsigned int modify_change_no = Ecf::modify_change_no();
-
-        // Setup command for invocation
-        ClientToServerRequest cmd_request;
-        cmd_request.set_cmd(theCmd);
-        // std::cout << cmd_request << "\n";
-
-        STC_Cmd_ptr result = cmd_request.handleRequest(server);
-        BOOST_CHECK_MESSAGE(result, "ClientToServerRequest " << cmd_request << " returned NULL\n");
-        BOOST_CHECK_MESSAGE(result->error().empty(), cmd_request << " " << result->error());
-        if (check_change_numbers) {
-            BOOST_CHECK_MESSAGE(state_change_no != Ecf::state_change_no() ||
-                                    modify_change_no != Ecf::modify_change_no(),
-                                "State & modify change numbers unaltered by command " << cmd_request);
-
-            // Some tests(TestSSyncCmd_CH1.cpp), create defs where invariants like change numbers are deliberately
-            // different
-            std::string error_msg;
-            BOOST_CHECK_MESSAGE(server->defs()->checkInvariants(error_msg),
-                                "invokeRequest checkInvariants failed " << error_msg << " for cmd " << cmd_request);
-        }
-        if (result)
-            return result->get_string();
-        return std::string();
-    }
-
-    static void invokeFailureRequest(Defs* defs, Cmd_ptr theCmd) {
-
-        ClientToServerRequest cmd_request;
-        cmd_request.set_cmd(theCmd);
-
-        MockServer server(defs);
-
-        // We expect this to fail
-        BOOST_CHECK_THROW(cmd_request.handleRequest(&server), std::runtime_error);
-    }
-
-    static void invokeFailureRequest(MockServer& server, Cmd_ptr theCmd) {
-
-        ClientToServerRequest cmd_request;
-        cmd_request.set_cmd(theCmd);
-
-        BOOST_CHECK_THROW(cmd_request.handleRequest(&server), std::runtime_error);
-
-        //		STC_Cmd_ptr result = cmd_request.handleRequest(&server);
-        //		BOOST_CHECK_MESSAGE( !result->ok(), "ClientToServerRequest " << cmd_request << " was expected to
-        // fail \n");
-    }
-
-    static void test_state(node_ptr n, NState::State expected) {
-        BOOST_REQUIRE_MESSAGE(n->state() == expected,
-                              "Expected state " << NState::toString(expected) << " but found "
-                                                << NState::toString(n->state()) << " for " << n->debugNodePath());
-    }
-
-    static void test_state(node_ptr n, DState::State expected) {
-        BOOST_REQUIRE_MESSAGE(n->dstate() == expected,
-                              "Expected state " << DState::toString(expected) << " but found "
-                                                << DState::toString(n->dstate()) << " for " << n->debugNodePath());
-    }
-
-private:
-    TestHelper() = default;
-};
-
-#endif /* ecflow_base_test_TestHelper_HPP */
diff -pruN 5.12.4-1/Base/test/TestInLimitAndLimit.cpp 5.13.0-1/Base/test/TestInLimitAndLimit.cpp
--- 5.12.4-1/Base/test/TestInLimitAndLimit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestInLimitAndLimit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1296 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/ForceCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/core/PrintStyle.hpp" // IWYU pragma: keep
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_InLimitAndLimit)
-
-BOOST_AUTO_TEST_CASE(test_add_log) {
-    // create once for all test below, then remove at the end
-    Log::create("test_add_log.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_CASE(test_add_limit) {
-    cout << "Base:: ...test_add_limit\n";
-    suite_ptr suite = Suite::create("suite");
-    suite->addLimit(Limit("fast", 1)); // " Adding limit first time should be ok");
-    BOOST_REQUIRE_THROW(suite->addLimit(Limit("fast", 1)),
-                        std::runtime_error); //" Adding same limit second time should fail");
-
-    suite->addInLimit(InLimit("fast", "/suite")); //" Adding in-limit first time should be ok");
-    BOOST_REQUIRE_THROW(suite->addInLimit(InLimit("fast", "/suite")),
-                        std::runtime_error); // " Adding in-limit second time should fail");
-
-    // adding inlimit with limit node only and submission should fail
-    BOOST_REQUIRE_THROW(
-        suite->addInLimit(InLimit("limit", "/suite", 1, true, /*limit_this_node_only*/ true /*limit submission*/)),
-        std::runtime_error); // " Adding in-limit second time should fail");
-}
-
-BOOST_AUTO_TEST_CASE(test_limit_increment) {
-    cout << "Base:: ...test_limit_increment\n";
-
-    // Test than when a job is submitted multiple times, it should only consume 1 token
-    //
-    // Create the defs file
-    // suite suite
-    //     limit fast 10
-    //    family f
-    //          inlimit /suite:fast
-    //          task t1
-    //    endfamily
-    // endsuite
-    Defs defs;
-    std::string limitName   = "fast";
-    std::string pathToLimit = "/suite";
-    std::string suitename   = "suite";
-    suite_ptr s             = defs.add_suite(suitename);
-    family_ptr f            = s->add_family("f");
-    task_ptr t1             = f->add_task("t1");
-    {
-        f->addInLimit(InLimit(limitName, pathToLimit));
-        s->addLimit(Limit(limitName, 10));
-    }
-    // cerr << defs << "\n";
-
-    {
-        // Resolve dependencies:: BEFORE calling beginCmd, should be a NO OP
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 tasks to submit but found " << jobsParam.submitted().size());
-    }
-
-    {
-        // Create a request to begin suite
-        // make sure chosen suite can begin to resolve dependencies.
-        // beginning the suite will:
-        //     1/ set all children to the QUEUED state
-        //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-        //
-        //  Resolve dependencies. Only one task should be submitted due to Limit
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
-        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
-        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
-        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
-    }
-
-    {
-        // Resolve dependencies. No task should submit since we have reached the limit
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
-    }
-
-    {
-        // Try resubmitting the an active task, it should still only consume 1 token in the limit
-        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
-
-        // Hack the state, to allow job to re- resubmitted
-        t1->setStateOnly(NState::QUEUED);
-
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 1,
-                            "Expected 1 task to submit but found " << jobsParam.submitted().size());
-
-        // Limit should still have only consumed one token
-        limit_ptr limit = s->find_limit(limitName);
-        BOOST_CHECK_MESSAGE(limit.get(), "Limit not found");
-        BOOST_CHECK_MESSAGE(limit->value() == 1, "Expected limit of value 1, but found " << limit->value());
-        BOOST_CHECK_MESSAGE(limit->paths().size() == 1,
-                            "Expected Only 1 task path in limit but found " << limit->paths().size());
-    }
-}
-
-//===============================================================================
-// This TEST is used to test limit and inLimit.
-// Both examples taken from the documentation
-BOOST_AUTO_TEST_CASE(test_limit) {
-    cout << "Base:: ...test_limit\n";
-
-    ///////////////////////////////////////////////////////////////////////////
-    // Create the defs file
-    //	suite suite
-    //     limit fast 1
-    //	   family f
-    //          inlimit /suite:fast
-    //	   		task t1
-    //	   		task t2
-    //	   endfamily
-    //	endsuite
-    Defs defs;
-    std::string limitName   = "fast";
-    std::string pathToLimit = "/suite";
-    std::string suitename   = "suite";
-    family_ptr f            = Family::create("f");
-    task_ptr t1             = Task::create("t1");
-    task_ptr t2             = Task::create("t2");
-    suite_ptr s             = Suite::create(suitename);
-    {
-        f->addTask(t1);
-        f->addTask(t2);
-        f->addInLimit(InLimit(limitName, pathToLimit));
-
-        s->addFamily(f);
-        s->addLimit(Limit(limitName, 1));
-
-        defs.addSuite(s);
-    }
-    // cerr << defs << "\n";
-
-    //*******************************************************************************
-    // Resolve dependencies:: BEFORE calling beginCmd, should be a NO OP
-    {
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 tasks to submit but found " << jobsParam.submitted().size());
-    }
-
-    // ***********************************************************************
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    //
-    //  Resolve dependencies. Only one task should be submitted due to Limit
-    //
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
-        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
-        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
-        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
-        BOOST_CHECK_MESSAGE(t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(t2->state()));
-    }
-
-    //*******************************************************************************
-    // Resolve dependencies. No task should submit since we have reached the limit
-    {
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
-    }
-
-    {
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_limit1) {
-    cout << "Base:: ...test_limit1\n";
-    ////////////////////////////////////////////////////////////////////////////////////////////////////
-    // Create the defs file
-    //	suite suite
-    //     limit disk 50
-    //	   family f
-    //          inlimit /suite:disk 20
-    //	   		task t1
-    //	   		task t2
-    //	   		task t3
-    //	   endfamily
-    //	endsuite
-    //
-    //  Test that only 2 Tasks can run
-    Defs defs;
-    std::string limitName   = "disk";
-    std::string pathToLimit = "/suite";
-    std::string suitename   = "suite";
-    family_ptr f            = Family::create("f");
-    task_ptr t1             = Task::create("t1");
-    task_ptr t2             = Task::create("t2");
-    task_ptr t3             = Task::create("t3");
-    suite_ptr s             = Suite::create(suitename);
-    {
-        f->addTask(t1);
-        f->addTask(t2);
-        f->addTask(t3);
-        f->addInLimit(InLimit(limitName, pathToLimit, 20));
-
-        s->addFamily(f);
-        s->addLimit(Limit(limitName, 50));
-
-        defs.addSuite(s);
-    }
-    // cerr << defs << "\n";
-
-    //*******************************************************************************
-    // Resolve dependencies:: BEFORE calling beginCmd, should be a NO OP
-    {
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 tasks to submit but found " << jobsParam.submitted().size());
-    }
-
-    // ***********************************************************************
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    //
-    //  Resolve dependencies. Only TWO task should be active due to Limit
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
-        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
-        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
-        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
-        BOOST_CHECK_MESSAGE(t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(t2->state()));
-        BOOST_CHECK_MESSAGE(t3->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(t3->state()));
-    }
-
-    //*******************************************************************************
-    // Resolve dependencies. No task should submit since we have reached the limit
-    {
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
-        if (jobsParam.submitted().size() != 0) {
-            for (Submittable* t : jobsParam.submitted()) {
-                cerr << "Submittable " << t->absNodePath() << "\n";
-            }
-        }
-    }
-
-    {
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_limit_references_after_delete) {
-    /// In-limit have a reference to a limit. This limit can be on another node. If that node is deleted
-    /// The limits are also deleted, hence we need to ensure in-limit reference to limits that are being
-    /// deleted are cleared. Currently we use shared_ptr to achieve this
-    cout << "Base:: ...test_limit_references_after_delete\n";
-
-    ////////////////////////////////////////////////////////////////////////////////////////////////////
-    //  Create the defs file
-    //	suite suiteLimits    # the limit we want delete
-    //     limit limit1  1
-    //     limit limit2  1
-    //     limit limit3  1
-    //	endsuite
-    //
-    //	suite suite
-    //	   family f
-    //          inlimit /suiteLimits:limit1    # check limits references cleared after suiteLimits is deleted
-    //	   		task t1
-    //	   endfamily
-    //	   family f1
-    //          inlimit /suiteLimits:limit2
-    //	   		task t1
-    //	   endfamily
-    //	   family f2
-    //          inlimit /suiteLimits:limit3
-    //	   		task t1
-    //	   endfamily
-    //	endsuite
-    //
-    // In this test case we will delete the suiteLimits, and then test to ensure the the in-limits
-    // in suite have been reset.
-    Defs defs;
-    {
-        suite_ptr suite = Suite::create("suiteLimits");
-        suite->addLimit(Limit("limit1", 1));
-        suite->addLimit(Limit("limit2", 1));
-        suite->addLimit(Limit("limit3", 1));
-        defs.addSuite(suite);
-    }
-
-    InLimit in_limit1("limit1", "/suiteLimits");
-    InLimit in_limit2("limit2", "/suiteLimits");
-    InLimit in_limit3("limit3", "/suiteLimits");
-    {
-        suite_ptr suite = Suite::create("suite");
-
-        family_ptr fam = Family::create("f");
-        fam->addTask(Task::create("t1"));
-        fam->addInLimit(in_limit1);
-        suite->addFamily(fam);
-
-        family_ptr fam2 = Family::create("f1");
-        fam2->addTask(Task::create("t1"));
-        fam2->addInLimit(in_limit2);
-        suite->addFamily(fam2);
-
-        family_ptr fam3 = Family::create("f2");
-        fam3->addTask(Task::create("t1"));
-        fam3->addInLimit(in_limit3);
-        suite->addFamily(fam3);
-
-        defs.addSuite(suite);
-    }
-
-    // First check that in-limit reference have been setup
-    node_ptr f  = defs.findAbsNode("/suite/f");
-    node_ptr f1 = defs.findAbsNode("/suite/f1");
-    node_ptr f2 = defs.findAbsNode("/suite/f2");
-    BOOST_REQUIRE_MESSAGE(f.get() && f1.get() && f2.get(), "Failed to find family than contain the inlimits");
-
-    BOOST_REQUIRE_MESSAGE(f->findInLimitByNameAndPath(in_limit1) && f1->findInLimitByNameAndPath(in_limit2) &&
-                              f2->findInLimitByNameAndPath(in_limit3),
-                          "Failed to find in-limits on the families" << defs);
-
-    // Now check they all reference the limits
-    BOOST_REQUIRE_MESSAGE(f->findLimitViaInLimit(in_limit1),
-                          "Inlimit does not reference its limit. Post process failed ?");
-    BOOST_REQUIRE_MESSAGE(f1->findLimitViaInLimit(in_limit2),
-                          "Inlimit does not reference its limit. Post process failed ?");
-    BOOST_REQUIRE_MESSAGE(f2->findLimitViaInLimit(in_limit3),
-                          "Inlimit does not reference its limit. Post process failed ?");
-
-    // Ok Now delete suiteLimits, as this is where the limits reside
-    // *** It is extremely important that shared_ptr for '/suiteLimit' is in its own
-    // *** scope, otherwise it will keep the 'suite' live, and NOT delete the limits
-    {
-        node_ptr suiteLimits = defs.findAbsNode("/suiteLimits");
-        BOOST_REQUIRE_MESSAGE(suiteLimits.get(), "Could not find the suite we want to delete?");
-        BOOST_REQUIRE_MESSAGE(defs.deleteChild(suiteLimits.get()), "Deletion failed?");
-        BOOST_REQUIRE_MESSAGE(!defs.findAbsNode("/suiteLimits").get(), "Deletion failed?");
-    }
-
-    BOOST_REQUIRE_MESSAGE(!f->findLimitViaInLimit(in_limit1), "In-limit still references limit that has been deleted?");
-    BOOST_REQUIRE_MESSAGE(!f1->findLimitViaInLimit(in_limit2),
-                          "In-limit still references limit that has been deleted?");
-    BOOST_REQUIRE_MESSAGE(!f2->findLimitViaInLimit(in_limit3),
-                          "In-limit still references limit that has been deleted?");
-}
-
-BOOST_AUTO_TEST_CASE(test_limits_after_force_cmd) {
-    cout << "Base:: ...test_limits_after_force_cmd\n";
-
-    // Create the following defs
-    // suite s1
-    //   limit A 10
-    //   family f1
-    //     inlimit A
-    //     task t1
-    //     task t2
-    //   family f2
-    //     inlimit A
-    //     task t1
-    //     task t2
-
-    // When all the tasks are running/submitted state, limit A should have consumed 4 tokens
-    // However if we how force family f2 to be complete, then the limit should be reset back to 2 tokens.
-    // Repeating for family f1, should result with a Limit with no tokens
-    Defs defs;
-    suite_ptr s1 = defs.add_suite("s1");
-    s1->addLimit(Limit("A", 10));
-    family_ptr f1 = s1->add_family("f1");
-    f1->addInLimit(InLimit("A", "/s1"));
-    task_ptr f1_t1 = f1->add_task("t1");
-    task_ptr f1_t2 = f1->add_task("t2");
-    family_ptr f2  = s1->add_family("f2");
-    f2->addInLimit(InLimit("A", "/s1"));
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-    // cout << defs;
-
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    //
-    //  Resolve dependencies. All tasks are within the limit and hence should start
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
-
-        limit_ptr the_limit = s1->find_limit("A");
-        BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
-        BOOST_CHECK_MESSAGE(the_limit->value() == 4, "Expected limit value to be 4 but found " << the_limit->value());
-    }
-
-    {
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new ForceCmd(
-                f2->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
-
-        limit_ptr the_limit = s1->find_limit("A");
-        BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
-        BOOST_CHECK_MESSAGE(the_limit->value() == 2, "Expected limit value to be 2 but found " << the_limit->value());
-    }
-
-    {
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new ForceCmd(
-                f1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-        BOOST_CHECK_MESSAGE(s1->state() == NState::COMPLETE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
-
-        limit_ptr the_limit = s1->find_limit("A");
-        BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
-        BOOST_CHECK_MESSAGE(the_limit->value() == 0, "Expected limit value to be 0 but found " << the_limit->value());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_limits_after_requeue_family_ECFLOW_196) {
-    cout << "Base:: ...test_limits_after_requeue_family_ECFLOW_196\n";
-
-    // This test is used to ensure that, requeue causes node to release tokens held by the Limits
-
-    // Create the following defs
-    // suite s1
-    //   limit A 10
-    //   family f1
-    //     inlimit A
-    //     task t1
-    //     task t2
-    //   family f2
-    //     inlimit A
-    //     task t1
-    //     task t2
-
-    // When all the tasks are running/submitted state, limit A should have consumed 4 tokens
-    // However if we how force family f2 to be requeud, then the limit should be reset back to 2 tokens.
-    Defs defs;
-    suite_ptr s1 = defs.add_suite("s1");
-    s1->addLimit(Limit("A", 10));
-    family_ptr f1 = s1->add_family("f1");
-    f1->addInLimit(InLimit("A", "/s1"));
-    task_ptr f1_t1 = f1->add_task("t1");
-    task_ptr f1_t2 = f1->add_task("t2");
-    family_ptr f2  = s1->add_family("f2");
-    f2->addInLimit(InLimit("A", "/s1"));
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-    // cout << defs;
-
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    //
-    //  Resolve dependencies. All tasks are within the limit and hence should start
-    int expected_limit_value = 4;
-    limit_ptr the_limit      = s1->find_limit("A");
-    BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
-
-        BOOST_CHECK_MESSAGE(the_limit->value() == expected_limit_value,
-                            "Expected limit value to be 4 but found " << the_limit->value());
-    }
-
-    {
-        expected_limit_value = 2;
-        // We now want to re-queue node f2, and check to see that limit tokens are released after the re-queue
-        // However, the Mock server, will call resolve dependencies after re-queue command , and place nodes *back* into
-        // active state, to *STOP* this, we will add a trigger, so that the dependencies will not resolve, and hence
-        // nodes stay queued
-        f2->add_trigger("1 == 0");
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(f2->absNodePath(), RequeueNodeCmd::FORCE)));
-
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
-
-        BOOST_CHECK_MESSAGE(the_limit->value() == expected_limit_value,
-                            "Expected limit value to be 2 but found " << the_limit->value());
-    }
-
-    {
-        expected_limit_value = 0;
-        // We now want to re-queue node f1, and check to see that limit tokens are released after the re-queue
-        // However, the Mock server, will call resolve dependencies after re-queue command , and place nodes *back* into
-        // active state, to *STOP* this, we will add a trigger, so that the dependencies will not resolve, and hence
-        // nodes stay queued
-        f1->add_trigger("1 == 0");
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(f1->absNodePath(), RequeueNodeCmd::FORCE)));
-
-        BOOST_CHECK_MESSAGE(s1->state() == NState::QUEUED,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::QUEUED,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::QUEUED,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::QUEUED,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
-
-        BOOST_CHECK_MESSAGE(the_limit->value() == expected_limit_value,
-                            "Expected limit value to be 0 but found " << the_limit->value());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_limits_after_requeue_task_ECFLOW_196) {
-    cout << "Base:: ...test_limits_after_requeue_task_ECFLOW_196\n";
-
-    // This test is used to ensure that, requeue causes node to release tokens held by the Limits
-
-    // Create the following def, i.e using internal and external limits
-    // suite s0
-    //   limit X 5
-    // suite s1
-    //   limit A 10
-    //   limit B 5
-    //   family f1
-    //     inlimit A
-    //     inlimit B
-    //     inlimit X /s0/
-    //     task t1
-    //     task t2
-    //   family f2
-    //     inlimit A
-    //     inlimit B
-    //     inlimit X /s0/
-    //     task t1
-    //     task t2
-
-    // When all the tasks are running/submitted state, limit A should have consumed 4 tokens
-    // However if we how force task to reque, then the token should be released
-    Defs defs;
-    suite_ptr s0 = defs.add_suite("s0");
-    s0->addLimit(Limit("X", 10));
-
-    suite_ptr s1 = defs.add_suite("s1");
-    s1->addLimit(Limit("A", 10));
-    s1->addLimit(Limit("B", 5));
-    family_ptr f1 = s1->add_family("f1");
-    f1->addInLimit(InLimit("A", "/s1"));
-    f1->addInLimit(InLimit("B", "/s1"));
-    f1->addInLimit(InLimit("X", "/s0"));
-    task_ptr f1_t1 = f1->add_task("t1");
-    task_ptr f1_t2 = f1->add_task("t2");
-    family_ptr f2  = s1->add_family("f2");
-    f2->addInLimit(InLimit("A", "/s1"));
-    f2->addInLimit(InLimit("B", "/s1"));
-    f2->addInLimit(InLimit("X", "/s0"));
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-
-    std::vector<task_ptr> tasks;
-    tasks.push_back(f1_t1);
-    tasks.push_back(f1_t2);
-    tasks.push_back(f2_t1);
-    tasks.push_back(f2_t2);
-    // cout << defs;
-
-    limit_ptr the_A_limit = s1->find_limit("A");
-    limit_ptr the_B_limit = s1->find_limit("B");
-    limit_ptr the_X_limit = s0->find_limit("X");
-    BOOST_CHECK_MESSAGE(the_A_limit && the_B_limit && the_X_limit, "Could not find limits");
-
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    //
-    //  Resolve dependencies. All tasks are within the limit and hence should start
-    int expected_limit_value = 4;
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
-
-        BOOST_CHECK_MESSAGE(the_A_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_A_limit->value());
-        BOOST_CHECK_MESSAGE(the_B_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_B_limit->value());
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-    }
-
-    {
-        // We now want to re-queue node tasks, and check to see that limit tokens are released after the re-queue
-        // However, the Mock server, will call resolve dependencies after re-queue command , and place nodes *back* into
-        // active state, to *STOP* this, we will add a trigger, so that the dependencies will not resolve, and hence
-        // nodes stay queued
-        f1->add_trigger("1 == 0");
-        f2->add_trigger("1 == 0");
-
-        for (auto& task : tasks) {
-            TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(task->absNodePath(), RequeueNodeCmd::FORCE)));
-            expected_limit_value--;
-            BOOST_CHECK_MESSAGE(the_A_limit->value() == expected_limit_value,
-                                "Expected limit value " << expected_limit_value << " but found "
-                                                        << the_A_limit->value());
-            BOOST_CHECK_MESSAGE(the_B_limit->value() == expected_limit_value,
-                                "Expected limit value " << expected_limit_value << " but found "
-                                                        << the_B_limit->value());
-            BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                                "Expected limit value " << expected_limit_value << " but found "
-                                                        << the_X_limit->value());
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_inlimit_with_family_ECFLOW_878) {
-    cout << "Base:: ...test_inlimit_with_family_ECFLOW_878\n";
-
-    // This test places a limit on the families. Should ignore the tasks
-    // With this test only 1 family can start at a time
-    //
-    // Create the following def. with inlimit -n, we limit node only
-    // suite s0
-    //   limit X 1   # Only allow one family at a time to start
-    // suite s1
-    //   family f1
-    //     inlimit -n X
-    //     task t1
-    //     task t2
-    //   family f2
-    //     inlimit -n X
-    //     task t1
-    //     task t2
-    //   family f3
-    //     inlimit -n X
-    //     task t1
-    //     task t2
-
-    Defs defs;
-    suite_ptr s0 = defs.add_suite("s0");
-    s0->addLimit(Limit("X", 1));
-
-    suite_ptr s1  = defs.add_suite("s1");
-    family_ptr f1 = s1->add_family("f1");
-    f1->addInLimit(InLimit("X", "/s0", 1, true));
-    task_ptr f1_t1 = f1->add_task("t1");
-    task_ptr f1_t2 = f1->add_task("t2");
-    family_ptr f2  = s1->add_family("f2");
-    f2->addInLimit(InLimit("X", "/s0", 1, true));
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-    family_ptr f3  = s1->add_family("f3");
-    f3->addInLimit(InLimit("X", "/s0", 1, true));
-    task_ptr f3_t1 = f3->add_task("t1");
-    task_ptr f3_t2 = f3->add_task("t2");
-
-    // cout << defs;
-    limit_ptr the_X_limit = s0->find_limit("X");
-    BOOST_CHECK_MESSAGE(the_X_limit, "Could not find limits");
-
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    //
-    //  Resolve dependencies. Only 2 task should start
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
-
-        //      PrintStyle::setStyle(PrintStyle::MIGRATE);
-        //      cout << defs;
-
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
-
-        int expected_limit_value = 1;
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-
-        // should only have 1 path, and it should be path to family f1
-        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
-        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
-        BOOST_CHECK_MESSAGE(x_limit_paths.find(f1->absNodePath()) != x_limit_paths.end(),
-                            "Expected to find path " << f1->absNodePath());
-
-        //      // why f2_t1 is queued
-        //      cout << "why ============================================";
-        //      std::vector<std::string> vec;
-        //      f2_t1->bottom_up_why(vec);
-        //      for(size_t i =0; i < vec.size(); i++) {
-        //         cout << "why:" << i << " " << vec[i] << "\n";
-        //      }
-    }
-
-    // Now set tasks f1_t1, f1_t2 to complete, this should release the limit, so that next family can run
-    {
-        std::vector<std::string> task_paths;
-        task_paths.push_back(f1_t1->absNodePath());
-        task_paths.push_back(f1_t2->absNodePath());
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
-
-        int expected_limit_value = 1;
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-
-        // Paths should be empty
-        // should only have 1 path, and it should be path to family f1
-        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
-        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
-        BOOST_CHECK_MESSAGE(x_limit_paths.find(f2->absNodePath()) != x_limit_paths.end(),
-                            "Expected to find path " << f2->absNodePath());
-    }
-
-    // Now set tasks f2_t1, f2_t2 to complete, this should release the limit, so that next family can run
-    {
-        std::vector<std::string> task_paths;
-        task_paths.push_back(f2_t1->absNodePath());
-        task_paths.push_back(f2_t2->absNodePath());
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f3_t2->state()));
-
-        int expected_limit_value = 1;
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-
-        // should only have 1 path, and it should be path to family f3
-        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
-        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
-        BOOST_CHECK_MESSAGE(x_limit_paths.find(f3->absNodePath()) != x_limit_paths.end(),
-                            "Expected to find path " << f3->absNodePath());
-    }
-
-    // Now set tasks f3_t1, f3_t2 to complete, this should release the limit
-    {
-        std::vector<std::string> task_paths;
-        task_paths.push_back(f3_t1->absNodePath());
-        task_paths.push_back(f3_t2->absNodePath());
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f3_t2->state()));
-
-        int expected_limit_value = 0;
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-
-        // Paths should be empty
-        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
-        BOOST_CHECK_MESSAGE(the_X_limit->paths().empty(), "Expected no paths, but found" << x_limit_paths.size());
-    }
-
-    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
-    //   cout << defs;
-}
-
-BOOST_AUTO_TEST_CASE(test_inlimit_ECFLOW_878) {
-    cout << "Base:: ...test_inlimit_ECFLOW_878\n";
-
-    // This test places a limit on the families. Should ignore the tasks
-    // With this test only 1 family can start at a time.
-    // However we *ALSO* want to constrain the tasks, to only 1 task at a time
-    //
-    // Create the following def. with inlimit -n, we limit node only
-    // suite s0
-    //   limit X 1   # Only allow one family at a time to start
-    //   limit T 1   # Only allow one task at a time to start
-    // suite s1
-    //   family f1
-    //     inlimit -n X
-    //     inlimit T
-    //     task t1
-    //     task t2
-    //   family f2
-    //     inlimit -n X
-    //     inlimit T
-    //     task t1
-    //     task t2
-    //   family f3
-    //     inlimit -n X
-    //     inlimit T
-    //     task t1
-    //     task t2
-
-    Defs defs;
-    suite_ptr s0 = defs.add_suite("s0");
-    s0->addLimit(Limit("X", 1));
-    s0->addLimit(Limit("T", 1));
-
-    suite_ptr s1  = defs.add_suite("s1");
-    family_ptr f1 = s1->add_family("f1");
-    f1->addInLimit(InLimit("X", "/s0", 1, true));
-    f1->addInLimit(InLimit("T", "/s0", 1));
-    task_ptr f1_t1 = f1->add_task("t1");
-    task_ptr f1_t2 = f1->add_task("t2");
-    family_ptr f2  = s1->add_family("f2");
-    f2->addInLimit(InLimit("X", "/s0", 1, true));
-    f2->addInLimit(InLimit("T", "/s0", 1));
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-    family_ptr f3  = s1->add_family("f3");
-    f3->addInLimit(InLimit("X", "/s0", 1, true));
-    f3->addInLimit(InLimit("T", "/s0", 1));
-    task_ptr f3_t1 = f3->add_task("t1");
-    task_ptr f3_t2 = f3->add_task("t2");
-
-    // cout << defs;
-    limit_ptr the_X_limit = s0->find_limit("X");
-    limit_ptr the_T_limit = s0->find_limit("T");
-    BOOST_CHECK_MESSAGE(the_X_limit && the_T_limit, "Could not find limits");
-
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    //
-    //  Resolve dependencies. Only 1 task should start
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
-
-        // PrintStyle::setStyle(PrintStyle::MIGRATE);
-        // cout << defs;
-
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
-
-        int expected_limit_value = 1;
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-
-        // should only have 1 path, and it should be path to family f1
-        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
-        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
-        BOOST_CHECK_MESSAGE(x_limit_paths.find(f1->absNodePath()) != x_limit_paths.end(),
-                            "Expected to find path " << f1->absNodePath());
-
-        const std::set<std::string>& t_limit_paths = the_T_limit->paths();
-        BOOST_CHECK_MESSAGE(t_limit_paths.size() == 1, "Expected one path in limit but found " << t_limit_paths.size());
-
-        //      // why f2_t1 is queued
-        //      cout << "why ============================================";
-        //      std::vector<std::string> vec;
-        //      f2_t1->bottom_up_why(vec);
-        //      for(size_t i =0; i < vec.size(); i++) {
-        //         cout << "why:" << i << " " << vec[i] << "\n";
-        //      }
-    }
-
-    // Now set tasks f1_t1 complete, this should release  t1_t2
-    {
-        std::vector<std::string> task_paths;
-        task_paths.push_back(f1_t1->absNodePath());
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
-
-        int expected_limit_value = 1;
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-
-        // should only have 1 path, and it should be path to family f1
-        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
-        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
-        BOOST_CHECK_MESSAGE(x_limit_paths.find(f1->absNodePath()) != x_limit_paths.end(),
-                            "Expected to find path " << f1->absNodePath());
-
-        const std::set<std::string>& t_limit_paths = the_T_limit->paths();
-        BOOST_CHECK_MESSAGE(t_limit_paths.size() == 1, "Expected one path in limit but found " << t_limit_paths.size());
-    }
-
-    // Now set tasks f1_t2 complete, this should release  f2_1
-    {
-        std::vector<std::string> task_paths;
-        task_paths.push_back(f1_t2->absNodePath());
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
-
-        int expected_limit_value = 1;
-        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_X_limit->value());
-
-        // should only have 1 path, and it should be path to family f2
-        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
-        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
-        BOOST_CHECK_MESSAGE(x_limit_paths.find(f2->absNodePath()) != x_limit_paths.end(),
-                            "Expected to find path " << f2->absNodePath());
-
-        const std::set<std::string>& t_limit_paths = the_T_limit->paths();
-        BOOST_CHECK_MESSAGE(t_limit_paths.size() == 1, "Expected one path in limit but found " << t_limit_paths.size());
-    }
-
-    // PrintStyle::setStyle(PrintStyle::MIGRATE);
-    // cout << defs;
-}
-
-BOOST_AUTO_TEST_CASE(test_inlimit_submission_only) {
-    cout << "Base:: ...test_inlimit_submission_only \n";
-
-    // Create the following def. with inlimit -s, we limit submission
-    // suite s0
-    //   limit T 1   # Only allow one task at a time to start
-    // suite s1
-    //   family f1
-    //     inlimit -s T
-    //     task t1
-    //     task t2
-    //   family f2
-    //     inlimit -s T
-    //     task t1
-    //     task t2
-    //   family f3
-    //     inlimit -s T
-    //     task t1
-    //     task t2
-
-    Defs defs;
-    suite_ptr s0 = defs.add_suite("s0");
-    s0->addLimit(Limit("T", 1));
-
-    suite_ptr s1  = defs.add_suite("s1");
-    family_ptr f1 = s1->add_family("f1");
-    f1->addInLimit(InLimit("T", "/s0", 1, false, true));
-    task_ptr f1_t1 = f1->add_task("t1");
-    task_ptr f1_t2 = f1->add_task("t2");
-    family_ptr f2  = s1->add_family("f2");
-    f2->addInLimit(InLimit("T", "/s0", 1, false, true));
-    task_ptr f2_t1 = f2->add_task("t1");
-    task_ptr f2_t2 = f2->add_task("t2");
-    family_ptr f3  = s1->add_family("f3");
-    f3->addInLimit(InLimit("T", "/s0", 1, false, true));
-    task_ptr f3_t1 = f3->add_task("t1");
-    task_ptr f3_t2 = f3->add_task("t2");
-
-    // cout << defs;
-    limit_ptr the_T_limit = s0->find_limit("T");
-    BOOST_CHECK_MESSAGE(the_T_limit, "Could not find limits");
-
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will:
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state  queued->submitted->active
-    //        Hence under test scenario there is no delay between submitted->active , hence limit is incremented and
-    //        decrement
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
-
-        // PrintStyle::setStyle(PrintStyle::MIGRATE);
-        // cout << defs;
-
-        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
-        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
-        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
-        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE , but found to be " << NState::toString(f1_t2->state()));
-        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE , but found to be " << NState::toString(f2->state()));
-        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE , but found to be " << NState::toString(f2_t1->state()));
-        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE , but found to be " << NState::toString(f2_t2->state()));
-        BOOST_CHECK_MESSAGE(f3->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE , but found to be " << NState::toString(f3->state()));
-        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE , but found to be " << NState::toString(f3_t1->state()));
-        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE , but found to be " << NState::toString(f3_t2->state()));
-
-        // The active state *decrements* the inlimit/limit value
-        int expected_limit_value = 0;
-        BOOST_CHECK_MESSAGE(the_T_limit->value() == expected_limit_value,
-                            "Expected limit value to be " << expected_limit_value << " but found "
-                                                          << the_T_limit->value());
-
-        //      // why f2_t1 is queued
-        //      cout << "why ============================================";
-        //      std::vector<std::string> vec;
-        //      f2_t1->bottom_up_why(vec);
-        //      for(size_t i =0; i < vec.size(); i++) {
-        //         cout << "why:" << i << " " << vec[i] << "\n";
-        //      }
-    }
-
-    // PrintStyle::setStyle(PrintStyle::MIGRATE);
-    // cout << defs;
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_destroy_log) {
-    Log::destroy();
-    fs::remove("test_add_log.log");
-    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestJobGenPerf.cpp 5.13.0-1/Base/test/TestJobGenPerf.cpp
--- 5.12.4-1/Base/test/TestJobGenPerf.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestJobGenPerf.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,186 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-#include <vector>
-
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/JobProfiler.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// #define DEBUG 1
-
-// This relies on Pyext/samples/TestJobGenPerf.py to make any defs amenable
-// for this test program.
-//
-// The defs is in /var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf
-//
-// Timing for /var/tmp/ma0/DEFS/metabuilder.def
-// First/base point: real:10.15  user: 5.58  sys: 1.62
-// After ECFLOW-846: real: 4.46  user: 3.72  sys: 0.74  # Only open/close include file once
-// After ECFLOW-864: real: 4.36  user: 3.68  sys: 0.68  # minimise stat calls
-//
-//     strace -c ./Base/bin/gcc-4.8/release/perf_job_gen ./metabuilder.def
-//
-//                            % time     seconds  usecs/call     calls    errors syscall
-//                            ------ ----------- ----------- --------- --------- ----------------
-//   Before ECFLOW-864:        22.77    0.001159           0    132329     50737 stat
-//   After  ECFLOW-864:        21.35    0.001097           0    125644     50737 stat
-//
-//
-// After ECFLOW-1244:
-//  - cacheing of stat of include files
-//  - re-arranging EcfFile data member for hotness
-//  - re-arrange search for generation variables, most common first
-//  - replace ecffile_->countEcfMicro _. EcfFile::countEcfMicro(..) remove reference since function is static
-//
-// time Base/bin/gcc-5.3.0/release/perf_job_gen ./metabuilder.def : submitted 5808 out of 7941( fastest of 10 attempts)
-// - ECFLOW-1244: real: 2.84s user: 2.41s sys: 0.40s
-//
-// perf stat -r 10 -d Base/bin/gcc-5.3.0/release/perf_job_gen ./metabuilder.def
-// Performance counter stats for 'Base/bin/gcc-5.3.0/release/perf_job_gen ./metabuilder.def' (10 runs):
-//
-//       2908.895909      task-clock (msec)         #    0.933 CPUs utilized            ( +-  1.02% )
-//                89      context-switches          #    0.031 K/sec                    ( +-  7.13% )
-//                 2      cpu-migrations            #    0.001 K/sec                    ( +- 25.00% )
-//            11,500      page-faults               #    0.004 M/sec                    ( +-  0.03% )
-//    10,900,694,824      cycles                    #    3.747 GHz                      ( +-  0.93% )  (37.44%)
-//     4,810,738,973      stalled-cycles-frontend   #   44.13% frontend cycles idle     ( +-  2.34% )  (49.98%)
-//   <not supported>      stalled-cycles-backend
-//    13,845,775,843      instructions              #    1.27  insns per cycle
-//                                                  #    0.35  stalled cycles per insn  ( +-  0.03% )  (62.51%)
-//     3,777,695,721      branches                  # 1298.670 M/sec                    ( +-  0.05% )  (62.56%)
-//       107,367,375      branch-misses             #    2.84% of all branches          ( +-  0.15% )  (62.70%)
-//     3,410,593,440      L1-dcache-loads           # 1172.470 M/sec                    ( +-  0.09% )  (49.60%)
-//       260,536,494      L1-dcache-load-misses     #    7.64% of all L1-dcache hits    ( +-  0.13% )  (24.94%)
-//       101,191,979      LLC-loads                 #   34.787 M/sec                    ( +-  0.20% )  (24.90%)
-//   <not supported>      LLC-load-misses
-//
-//       3.118979324 seconds time elapsed                                          ( +-  2.80% )
-
-int main(int argc, char* argv[]) {
-    if (argc != 2) {
-        cout << "TestJobGenPerf.cpp --> " << argv[0] << "\n";
-        cout << "Expect single argument which is path to a defs file\n";
-        return 1;
-    }
-
-    // delete the log file if it exists.
-    std::string log_path = File::test_data("Base/test/TestJobGenPerf.log", "Base");
-    fs::remove(log_path);
-    std::string path = argv[1];
-
-#ifdef DEBUG
-    cout << "Loading file " << path << " log file " << log_path << "\n";
-#endif
-    Defs defs;
-    std::string errorMsg, warningMsg;
-    if (!defs.restore(path, errorMsg, warningMsg)) {
-        cout << errorMsg << "\n";
-        cout << warningMsg << "\n";
-        return 1;
-    }
-
-    //   std::vector<std::string> suites_to_remove;
-    //   suites_to_remove.push_back("codes_ui");
-    //   suites_to_remove.push_back("libemos_test");
-    //   suites_to_remove.push_back("metview");
-    //   suites_to_remove.push_back("ecflow");
-    //   suites_to_remove.push_back("mir_bundle");
-    // #ifdef DEBUG
-    //   cout << "remove dodgy suites, these are based on localhost\n";
-    // #endif
-    //   for(size_t i = 0; i < suites_to_remove.size(); ++i) {
-    //      suite_ptr suite = defs.findSuite(suites_to_remove[i]);
-    //      if (suite) suite->remove();
-    //   }
-    //   cout << defs ;
-    //   exit(0);
-
-    // Check number of tasks, if the submitted output below is too low
-    std::vector<Task*> tasks;
-    defs.getAllTasks(tasks);
-
-    // #ifdef DEBUG
-    //    cout << "Total number of tasks: " << tasks.size() << "\n";
-    //    cout << "begin-all\n";
-    // #endif
-
-    defs.beginAll();
-
-    // #ifdef DEBUG
-    //    cout << "Free all dependencies, free suspended time and trigger dependencies\n";
-    // #endif
-
-    std::vector<node_ptr> all_nodes;
-    defs.get_all_nodes(all_nodes);
-    for (size_t i = 0; i < all_nodes.size(); ++i) {
-        if (all_nodes[i]->isSuspended())
-            all_nodes[i]->resume();
-        all_nodes[i]->freeTrigger();
-        all_nodes[i]->freeHoldingDateDependencies();
-        all_nodes[i]->freeHoldingTimeDependencies();
-
-        const std::vector<InLimit>& inlimits = all_nodes[i]->inlimits();
-        for (const auto& inlim : inlimits)
-            all_nodes[i]->deleteInlimit(inlim.name());
-
-        if (all_nodes[i]->state() == NState::COMPLETE && all_nodes[i]->isTask()) {
-            all_nodes[i]->set_state(NState::QUEUED);
-        }
-    }
-
-    // Create a new log, file, place after begin to avoid queued state
-    TestLog test_log(log_path); // will create log file, and destroy log and remove file at end of scope
-
-    // This controls the log output when job generation > submitJobsInterval
-    JobProfiler::set_task_threshold(100); // 100ms where 1000ms is one second
-
-    JobsParam jobParam(20 /*submitJobsInterval*/, true /*createJobs*/, false /* spawn jobs */);
-    Jobs job(&defs);
-    if (!job.generate(jobParam))
-        cout << " generate failed: " << jobParam.getErrorMsg();
-    cout << "submitted " << jobParam.submitted().size() << " out of " << tasks.size() << "\n";
-
-    if (jobParam.submitted().size() != tasks.size()) {
-        for (size_t i = 0; i < tasks.size(); i++) {
-            if (tasks[i]->state() != NState::SUBMITTED &&
-                tasks[i]->findVariable("ECF_DUMMY_TASK") == Variable::EMPTY()) {
-                // We are NOT a dummy task
-                cout << "task " << tasks[i]->absNodePath() << " state: " << NState::toString(tasks[i]->state()) << "\n";
-
-                Node* parent = tasks[i]->parent();
-                while (parent) {
-                    cout << " node " << parent->absNodePath() << " state: " << NState::toString(parent->state())
-                         << "\n";
-                    parent = parent->parent();
-                }
-
-                std::vector<std::string> theReasonWhy;
-                tasks[i]->bottom_up_why(theReasonWhy, false /*html tags*/);
-                for (const auto& r : theReasonWhy) {
-                    cout << "  Reason: " << r << "\n";
-                }
-            }
-        }
-    }
-
-    return 0;
-}
diff -pruN 5.12.4-1/Base/test/TestLogCmd.cpp 5.13.0-1/Base/test/TestLogCmd.cpp
--- 5.12.4-1/Base/test/TestLogCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestLogCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,105 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/LogCmd.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace boost;
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_LogCmd)
-
-BOOST_AUTO_TEST_CASE(test_log_cmd) {
-    cout << "Base:: ...test_log_cmd\n";
-
-    {
-        LogCmd log_cmd;
-        BOOST_REQUIRE_MESSAGE(log_cmd.api() == LogCmd::GET, " expected GET as the default");
-        BOOST_REQUIRE_MESSAGE(log_cmd.new_path() == "", "expected empty path but found " << log_cmd.new_path());
-    }
-
-    {
-        LogCmd log_cmd("/a/path");
-        BOOST_REQUIRE_MESSAGE(log_cmd.api() == LogCmd::NEW, " expected NEW as the default api when path provided");
-        BOOST_REQUIRE_MESSAGE(log_cmd.new_path() == "/a/path", "expected 'a/path' but found " << log_cmd.new_path());
-    }
-
-    // ECFLOW-377
-    {
-        LogCmd log_cmd("/a/path ");
-        BOOST_CHECK_MESSAGE(log_cmd.new_path() == "/a/path",
-                            "expected '/a/path' but found '" << log_cmd.new_path() << "'");
-    }
-    {
-        LogCmd log_cmd(" /a/path");
-        BOOST_CHECK_MESSAGE(log_cmd.new_path() == "/a/path",
-                            "expected '/a/path' but found '" << log_cmd.new_path() << "'");
-    }
-    {
-        LogCmd log_cmd(" /a/path ");
-        BOOST_CHECK_MESSAGE(log_cmd.new_path() == "/a/path",
-                            "expected '/a/path' but found '" << log_cmd.new_path() << "'");
-    }
-
-    // Create a new log file, equivalent --log=new .../Base/test/new_logfile.txt
-    // LogCmd::doHandleRequest needs log file to have been created first
-    std::string old_log_file = File::test_data("Base/test/old_logfile.txt", "Base");
-    Log::instance()->create(old_log_file);
-
-    std::string new_log_file =
-        File::test_data("Base/test/new_logfile.txt ", "Base"); // ECFLOW-377 note extra space at the end
-    std::string expected_new_log_file = File::test_data("Base/test/new_logfile.txt", "Base"); // space removed
-
-    // ECFLOW-376 --log=new <path> should be treated same as changing ECF_LOG from the gui. i.e added as a user
-    // variable. hence visible in GUI
-    Defs defs;
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new LogCmd(new_log_file)), false /* check_change_numbers */);
-    BOOST_CHECK_MESSAGE(defs.server().find_variable("ECF_LOG") == expected_new_log_file,
-                        "expected to find ECF_LOG with value '" << expected_new_log_file << "' but found '"
-                                                                << defs.server().find_variable("ECF_LOG") << "'");
-    std::string value;
-    BOOST_CHECK_MESSAGE(defs.server().find_user_variable("ECF_LOG", value) && (value == expected_new_log_file),
-                        "expected to find ECF_LOG in the *USER* variables '" << expected_new_log_file << "' but found '"
-                                                                             << value << "'");
-    BOOST_CHECK_MESSAGE(Log::instance()->path() == expected_new_log_file,
-                        "expected to find ECF_LOG with value '" << expected_new_log_file << "' but found '"
-                                                                << defs.server().find_variable("ECF_LOG") << "'");
-
-    // Update ECF_LOG to have a *SPACE* at the end.  ECFLOW-377
-    defs.set_server().add_or_update_user_variables(Str::ECF_LOG(), new_log_file);
-    BOOST_CHECK_MESSAGE(defs.server().find_variable("ECF_LOG") == new_log_file,
-                        "expected to find ECF_LOG with value '" << new_log_file << "' but found '"
-                                                                << defs.server().find_variable("ECF_LOG") << "'");
-
-    // INVOKE log command where we update log file from ECF_LOG, equivalent --log=new
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new LogCmd(LogCmd::NEW)), false /* check_change_numbers */);
-    BOOST_CHECK_MESSAGE(Log::instance()->path() == expected_new_log_file,
-                        "expected to find Log::instance()->path() with value '"
-                            << expected_new_log_file << "' but found '" << defs.server().find_variable("ECF_LOG")
-                            << "'");
-
-    // tidy up
-    Log::instance()->destroy();
-    fs::remove(old_log_file);          // remove generated log file
-    fs::remove(expected_new_log_file); // remove generated log file
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestMeterCmd.cpp 5.13.0-1/Base/test/TestMeterCmd.cpp
--- 5.12.4-1/Base/test/TestMeterCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestMeterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,123 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_MeterCmd)
-
-BOOST_AUTO_TEST_CASE(test_meter_cmd) {
-    cout << "Base:: ...test_meter_cmd\n";
-    TestLog test_log("test_meter_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    // Create the defs file.
-    // suite suite
-    //    family f
-    //          task t1
-    //              meter m 0 100 100
-    //    endfamily
-    // endsuite
-    Defs defs;
-    string suite_f_t1      = "suite/f/t1";
-    task_ptr t1            = Task::create("t1");
-    std::string meter_name = "m";
-    {
-        t1->addMeter(Meter(meter_name, 0, 100, 100));
-        suite_ptr s  = Suite::create("suite");
-        family_ptr f = Family::create("f");
-        f->addTask(t1);
-        s->addFamily(f);
-        defs.addSuite(s);
-    }
-
-    // Meter which doesn't exist should be silently ignore
-    int meter_value = 10;
-    TestHelper::invokeRequest(&defs,
-                              Cmd_ptr(new MeterCmd(suite_f_t1,
-                                                   Submittable::DUMMY_JOBS_PASSWORD(),
-                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                   1,
-                                                   "FRED",
-                                                   meter_value)),
-                              false /* expect change number not to change */
-    );
-
-    /// Test setting meter value
-    TestHelper::invokeRequest(&defs,
-                              Cmd_ptr(new MeterCmd(suite_f_t1,
-                                                   Submittable::DUMMY_JOBS_PASSWORD(),
-                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                   1,
-                                                   meter_name,
-                                                   meter_value)));
-    const Meter& the_meter = t1->findMeter(meter_name);
-    BOOST_CHECK_MESSAGE(!the_meter.empty(), "Meter not found");
-    BOOST_CHECK_MESSAGE(the_meter.value() == meter_value,
-                        "Expected meter value " << meter_value << " but found " << the_meter.value());
-
-    /// Set a meter value less than the current value.
-    meter_value = 9;
-    TestHelper::invokeRequest(&defs,
-                              Cmd_ptr(new MeterCmd(suite_f_t1,
-                                                   Submittable::DUMMY_JOBS_PASSWORD(),
-                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                   1,
-                                                   meter_name,
-                                                   meter_value)));
-    BOOST_CHECK_MESSAGE(the_meter.value() == meter_value,
-                        "Expected meter value " << meter_value << " but found " << the_meter.value());
-
-    /// Set a meter value greater than max meter, this should be ignored
-    /// Avoid failing task, if meter,  value is out of range. Just log a warning message
-    meter_value = 2000;
-    TestHelper::invokeRequest(&defs,
-                              Cmd_ptr(new MeterCmd(suite_f_t1,
-                                                   Submittable::DUMMY_JOBS_PASSWORD(),
-                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                   1,
-                                                   meter_name,
-                                                   meter_value)),
-                              false /* expect change number not to change */);
-    BOOST_CHECK_MESSAGE(the_meter.value() == 9, "Expected meter value 9 but found " << the_meter.value());
-
-    /// Set to valid value
-    meter_value = 20;
-    TestHelper::invokeRequest(&defs,
-                              Cmd_ptr(new MeterCmd(suite_f_t1,
-                                                   Submittable::DUMMY_JOBS_PASSWORD(),
-                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                   1,
-                                                   meter_name,
-                                                   meter_value)));
-    BOOST_CHECK_MESSAGE(the_meter.value() == meter_value,
-                        "Expected meter value " << meter_value << " but found " << the_meter.value());
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestProgramOptions.cpp 5.13.0-1/Base/test/TestProgramOptions.cpp
--- 5.12.4-1/Base/test/TestProgramOptions.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestProgramOptions.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,151 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/program_options.hpp>
-#include <boost/test/unit_test.hpp>
-
-using namespace std;
-namespace po = boost::program_options;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_ProgramOptions)
-
-BOOST_AUTO_TEST_CASE(test_program_options_implicit_value) {
-    cout << "Base:: ...test_program_options_implicit_value\n";
-
-    // Declare the supported options.
-    po::options_description desc("Allowed options");
-    desc.add_options()("help", "produce help message")(
-        "arg1", po::value<string>()->implicit_value(string("")), "optional arg1 description");
-
-    {
-        char* argv[] = {const_cast<char*>("test_program_options_implicit_value"),
-                        const_cast<char*>("--help"),
-                        const_cast<char*>("--arg1")};
-
-        po::variables_map vm;
-        po::store(po::parse_command_line(3, argv, desc), vm); // populate variable map
-        po::notify(vm);                                       // raise any errors
-
-        BOOST_CHECK_MESSAGE(vm.count("help"), "Expected help");
-        BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
-        BOOST_CHECK_MESSAGE(vm["arg1"].as<string>() == "", "Expected arg1 to be empty");
-    }
-    //   {
-    //      // This test fails on boost 1.59, can't cope --arg1 10, only --arg1=10 *******
-    //      // See: ECFLOW-509 and https://svn.boost.org/trac/boost/ticket/11893
-    //      char* argv[] = {
-    //            const_cast<char*>("test_program_options_implicit_value"),
-    //            const_cast<char*>("--arg1"),
-    //            const_cast<char*>("10")
-    //      };
-    //
-    //      po::variables_map vm;
-    ////      po::store(po::parse_command_line(3, argv, desc,
-    ////                        po::command_line_style::unix_style ^ po::command_line_style::allow_short ^
-    ////                        po::command_line_style::long_allow_adjacent |
-    ////                        po::command_line_style::short_allow_adjacent |
-    ////                        po::command_line_style::allow_long_disguise
-    ////                ), vm);
-    //
-    //      po::store(po::command_line_parser(3,argv).options(desc).style(
-    //                       po::command_line_style::long_allow_next |
-    //                       po::command_line_style::allow_long_disguise |
-    //                       po::command_line_style::long_allow_adjacent).run(),
-    //                vm);
-    //      po::notify(vm);
-    //
-    //      BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
-    //      BOOST_CHECK_MESSAGE(vm["arg1"].as<string>() == "10", "Expected arg1 with value of 10 but found '" <<
-    //      vm["arg1"].as<string>() << "'");
-    //   }
-
-    {
-        char* argv[] = {const_cast<char*>("test_program_options_implicit_value"), const_cast<char*>("--arg1=11")};
-
-        po::variables_map vm;
-        po::store(po::parse_command_line(2, argv, desc), vm);
-        po::notify(vm);
-
-        BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
-        BOOST_CHECK_MESSAGE(vm["arg1"].as<string>() == "11",
-                            "Expected arg1 with value of 11 but found " << vm["arg1"].as<string>());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_program_options_multitoken) {
-    cout << "Base:: ...test_program_options_multitoken\n";
-
-    // Declare the supported options.
-    po::options_description desc("Allowed options");
-    desc.add_options()("help",
-                       "produce help message")("arg1", po::value<vector<string>>()->multitoken(), "arg1 description");
-
-    char* argv[] = {const_cast<char*>("test_program_options_multitoken"),
-                    const_cast<char*>("--help"),
-                    const_cast<char*>("--arg1"),
-                    const_cast<char*>("a"),
-                    const_cast<char*>("b")};
-
-    po::variables_map vm;
-    po::store(po::parse_command_line(5, argv, desc), vm);
-    po::notify(vm);
-
-    BOOST_CHECK_MESSAGE(vm.count("help"), "Expected help");
-    BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
-
-    std::vector<string> expected;
-    expected.emplace_back("a");
-    expected.emplace_back("b");
-    BOOST_CHECK_MESSAGE(vm["arg1"].as<vector<string>>() == expected, "multi-token not as expected");
-}
-
-BOOST_AUTO_TEST_CASE(test_program_options_multitoken_with_negative_values) {
-    cout << "Base:: ...test_program_options_multitoken_with_negative_values\n";
-
-    // Declare the supported options.
-    po::options_description desc("Allowed options");
-    desc.add_options()("help",
-                       "produce help message")("arg1", po::value<vector<string>>()->multitoken(), "arg1 description");
-
-    char* argv[] = {const_cast<char*>("test_program_options_multitoken_1"),
-                    const_cast<char*>("--help"),
-                    const_cast<char*>("--arg1"),
-                    const_cast<char*>("-1"),
-                    const_cast<char*>("-w")};
-
-    //  --alter delete cron -w 0,1 10:00 /s1     # -w treated as option
-    //  --alter=/s1 change meter name -1         # -1 treated as option
-    // Note: negative numbers get treated as options: i.e trying to change meter value to a negative number
-    //  To avoid negative numbers from being treated as option use, we need to change command line style:
-    //       po::command_line_style::unix_style ^ po::command_line_style::allow_short
-
-    po::variables_map vm;
-    po::store(
-        po::parse_command_line(5, argv, desc, po::command_line_style::unix_style ^ po::command_line_style::allow_short),
-        vm);
-    po::notify(vm);
-
-    BOOST_CHECK_MESSAGE(vm.count("help"), "Expected help");
-    BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
-
-    std::vector<string> expected;
-    expected.emplace_back("-1");
-    expected.emplace_back("-w");
-    BOOST_CHECK_MESSAGE(vm["arg1"].as<vector<string>>() == expected, "multi-token not as expected");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestQueryCmd.cpp 5.13.0-1/Base/test/TestQueryCmd.cpp
--- 5.12.4-1/Base/test/TestQueryCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestQueryCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,216 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/task/LabelCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/cts/user/QueryCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_QueryCmd)
-
-BOOST_AUTO_TEST_CASE(test_query_cmd) {
-    cout << "Base:: ...test_query_cmd\n";
-    TestLog test_log("test_query_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    // Create the defs file.
-    // suite suite
-    //    limit limit_x 12
-    //    repeat date YMD 20090916 20200916
-    //    family f
-    //          edit var2 var2
-    //          task t1
-    //              edit var1 var1
-    //              meter m 0 100 100
-    //              event event
-    //              trigger t2 == complete
-    //          task t2
-    //              label name value new_value
-    //              label name2 value2
-    //    endfamily
-    //    task task
-    // endsuite
-    Defs defs;
-    string suite_f_t1 = "suite/f/t1";
-    task_ptr t1       = Task::create("t1");
-    task_ptr t2;
-    task_ptr task          = Task::create("task");
-    string suite_task      = "suite/task";
-    std::string meter_name = "m";
-    std::string event_name = "event";
-    std::string label_name = "name";
-    std::string limit_name = "limit_x";
-    {
-        t1->addMeter(Meter(meter_name, 0, 100, 100));
-        t1->addEvent(Event(event_name));
-        t1->add_variable("var1", "var1");
-
-        suite_ptr s = defs.add_suite("suite");
-        s->addLimit(Limit(limit_name, 12));
-
-        s->addRepeat(RepeatDate("YMD", 20090916, 20200916, 1));
-        family_ptr f = s->add_family("f");
-        f->add_variable("var2", "var2");
-        f->addTask(t1);
-        t2 = f->add_task("t2");
-        t2->add_label(label_name, "value", "");
-        s->addTask(task);
-    }
-
-    defs.beginAll(); // this will clear label new_value
-
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("state", "/suite/f/t11", "", "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("dstate", "/suite/f/t11", "", "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(
-        &defs, Cmd_ptr(new QueryCmd("repeat", "/suite/f/t1", "", "/suite/f/t1"))); // no repeat on /suite/f/t1
-    TestHelper::invokeFailureRequest(
-        &defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "fred", "/suite"))); // Only next | prev are valid
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("event", "/suite/f/t1", "eventxx", "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("event", "/suite", event_name, "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("event", "xxxx/f/t1", event_name, "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("limit", "xxxx/f/t1", limit_name, "/suite")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("limit_max", "xxxx/f/t1", limit_name, "/suite")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("meter", "/suite/f/t1", "meterxx", "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("meter", "/suite", meter_name, "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(
-        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t1", label_name, "/suite/f/t1"))); // no label on t1
-    TestHelper::invokeFailureRequest(
-        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t2", "fred", "/suite/f/t2"))); // wrong label name
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("trigger", "/suite", "1 == ", "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "1 == ", "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "XXXX", "/suite/f/t1")));
-    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("xxxxx", "/suite/f/t1", event_name, "/suite/f/t1")));
-
-    // t3 does not exist
-    TestHelper::invokeFailureRequest(&defs,
-                                     Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "t3 == complete", "/suite/f/t1")));
-
-    // QueryCmd is read only, hence change numbers should not change
-    std::string res;
-    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("state", "/suite", "", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "queued", "expected query state to return queued but found: " << res);
-
-    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("dstate", "/suite/f", "", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "queued", "expected query state to return queued but found: " << res);
-
-    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "", "/suite")), false);
-    BOOST_CHECK_MESSAGE(res == "20090916", "expected query repeat to return '20090916' but found : " << res);
-
-    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "prev", "/suite")), false);
-    BOOST_CHECK_MESSAGE(res == "20090916", "expected query repeat to return '20090916' but found : " << res);
-
-    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "next", "/suite")), false);
-    BOOST_CHECK_MESSAGE(res == "20090917", "expected query repeat to return '20090917' but found : " << res);
-
-    // Note: we pick a task outside of a repeat, since setting a task to complete, inside a repeat will cause it to
-    // requeue Avoid using ForceCmd to avoid side affects
-    std::vector<std::string> states = NState::allStates();
-    for (const auto& state : states) {
-        task->setStateOnly(NState::toState(state));
-        res = TestHelper::invokeRequest(
-            &defs, Cmd_ptr(new QueryCmd("state", task->absNodePath(), "", task->absNodePath())), false);
-        BOOST_CHECK_MESSAGE(res == state, "expected query state to return " << state << " but found: " << res);
-    }
-
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, task->absNodePath())));
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("dstate", task->absNodePath(), "", task->absNodePath())), false);
-    BOOST_CHECK_MESSAGE(res == "suspended", "expected query state to return suspend but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("event", "/suite/f/t1", event_name, "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "clear", "expected query event to return clear but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("meter", "/suite/f/t1", meter_name, "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "0", "expected query meter to return 0 but found: " << res);
-
-    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("limit", "/suite", limit_name, "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "0", "expected query limit to return 0 but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("limit_max", "/suite", limit_name, "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "12", "expected query limit_max to return 12 but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t2", label_name, "/suite/f/t2")), false);
-    BOOST_CHECK_MESSAGE(res == "value", "expected query label to return 'value' but found: " << res);
-    res = TestHelper::invokeRequest(&defs,
-                                    Cmd_ptr(new LabelCmd("/suite/f/t2",
-                                                         Submittable::DUMMY_JOBS_PASSWORD(),
-                                                         Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                         1,
-                                                         label_name,
-                                                         "new_value")));
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t2", label_name, "/suite/f/t2")), false);
-    BOOST_CHECK_MESSAGE(res == "new_value", "expected query label to return 'new_value' but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "t2 == complete", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "false", "expected query trigger to return false but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "1 == 1", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f/t1:var1 == 0", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f:var2 == 0", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f/t1:m == 0", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f/t1:event", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "false", "expected query trigger to return false but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite", "/suite:YMD == 20090916", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "var1", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "var1", "expected query variable to return var2 but found: " << res);
-
-    res = TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "var2", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "var2", "expected query variable to return var2 but found: " << res);
-
-    res =
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "YMD", "/suite/f/t1")), false);
-    BOOST_CHECK_MESSAGE(res == "20090916", "expected query variable to return 20090916 but found: " << res);
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestQueueCmd.cpp 5.13.0-1/Base/test/TestQueueCmd.cpp
--- 5.12.4-1/Base/test/TestQueueCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestQueueCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,251 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/base/cts/task/QueueCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_QueueCmd)
-
-BOOST_AUTO_TEST_CASE(test_queue_cmd) {
-    cout << "Base:: ...test_queue_cmd\n";
-    TestLog test_log("test_queue_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    // Create the defs file.
-    // suite suite
-    //    queue q1 s1 s2 s3
-    //    family f
-    //          queue q2 f1 f2 f3
-    //          task t
-    //             queue q3 t1 t2 t3
-    //    endfamily
-    // endsuite
-    Defs defs;
-    string suite_f_t = "/suite/f/t";
-
-    suite_ptr s = defs.add_suite("suite");
-    QueueAttr q1("q1", {"s1", "s2", "s3"});
-    s->add_queue(q1);
-    QueueAttr& q1_ref = s->findQueue("q1");
-    BOOST_REQUIRE_MESSAGE(!q1_ref.empty(), "queue not found");
-    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 0, "Expected to 0 index but found " << q1_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q1_ref.value() == "s1", "Expected to s1 but found " << q1_ref.value());
-
-    family_ptr f = s->add_family("f");
-    QueueAttr q2("q2", {"f1", "f2", "f3"});
-    f->add_queue(q2);
-    QueueAttr& q2_ref = f->findQueue("q2");
-    BOOST_REQUIRE_MESSAGE(!q2_ref.empty(), "queue not found");
-    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 0, "Expected to 0 index but found " << q2_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q2_ref.value() == "f1", "Expected to f1 but found " << q2_ref.value());
-
-    task_ptr t = f->add_task("t");
-    QueueAttr q3("q3", {"t1", "t2", "t3"});
-    t->add_queue(q3);
-    QueueAttr& q3_ref = t->findQueue("q3");
-    BOOST_REQUIRE_MESSAGE(!q3_ref.empty(), "queue not found");
-    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 0, "Expected to 0 index but found " << q3_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q3_ref.value() == "t1", "Expected to t1 but found " << q3_ref.value());
-
-    // cout << defs;
-
-    /////////////////////////////////////////////////////////////////////////////////////////////////////
-    // Update q1, this on the suite. hence we should find it up the hierarchy
-    std::string step = TestHelper::invokeRequest(&defs,
-                                                 Cmd_ptr(new QueueCmd(suite_f_t,
-                                                                      Submittable::DUMMY_JOBS_PASSWORD(),
-                                                                      Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                                      1,
-                                                                      "q1",
-                                                                      "active")));
-    BOOST_CHECK_MESSAGE(step == "s1", "Expected step s1 but found " << step);
-    BOOST_CHECK_MESSAGE(NState::ACTIVE == q1_ref.state(step),
-                        "Expected ACTIVE step but found " << NState::toString(q1_ref.state(step)));
-    q1_ref.aborted(step);
-    BOOST_CHECK_MESSAGE(NState::ABORTED == q1_ref.state(step),
-                        "Expected ABORTED step but found " << NState::toString(q1_ref.state(step)));
-    q1_ref.complete(step);
-    BOOST_CHECK_MESSAGE(NState::COMPLETE == q1_ref.state(step),
-                        "Expected COMPLETE step but found " << NState::toString(q1_ref.state(step)));
-    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 1, "Expected 1 for index but found " << q1_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q1_ref.value() == "s2", "Expected s2 for value but found " << q1_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q1",
-                                                          "active")));
-    BOOST_CHECK_MESSAGE(step == "s2", "Expected step s2 but found " << step);
-    BOOST_CHECK_MESSAGE(NState::ACTIVE == q1_ref.state(step),
-                        "Expected ACTIVE step but found " << NState::toString(q1_ref.state(step)));
-    q1_ref.aborted(step);
-    BOOST_CHECK_MESSAGE(NState::ABORTED == q1_ref.state(step),
-                        "Expected ABORTED step but found " << NState::toString(q1_ref.state(step)));
-    BOOST_CHECK_MESSAGE(q1_ref.no_of_aborted() == "1", "Expected  1 aborted step but found " << q1_ref.no_of_aborted());
-    q1_ref.complete(step);
-    BOOST_CHECK_MESSAGE(q1_ref.no_of_aborted() == "",
-                        "Expected *NO* aborted step but found " << q1_ref.no_of_aborted());
-    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 2, "Expected 2 for index but found " << q1_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q1_ref.value() == "s3", "Expected to s3 but found " << q1_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q1",
-                                                          "active")));
-    BOOST_CHECK_MESSAGE(step == "s3", "Expected step s3 but found " << step);
-    BOOST_CHECK_MESSAGE(NState::ACTIVE == q1_ref.state(step),
-                        "Expected ACTIVE step but found " << NState::toString(q1_ref.state(step)));
-    q1_ref.aborted(step);
-    BOOST_CHECK_MESSAGE(NState::ABORTED == q1_ref.state(step),
-                        "Expected ABORTED step but found " << NState::toString(q1_ref.state(step)));
-    q1_ref.complete(step);
-    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 3, "Expected 3 for index but found " << q1_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q1_ref.value() == "<NULL>", "Expected to <NULL> but found " << q1_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q1",
-                                                          "active")),
-                                     false);
-    BOOST_CHECK_MESSAGE(step == "<NULL>", "Expected step <NULL> but found " << step);
-    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 3, "Expected 3 for index but found " << q1_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q1_ref.value() == "<NULL>", "Expected to <NULL> but found " << q1_ref.value());
-
-    /////////////////////////////////////////////////////////////////////////////////////////////////////
-    // Update q2, this on the family, In this we sill specify path to the queue
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q2",
-                                                          "active",
-                                                          "",
-                                                          "/suite/f")));
-    BOOST_CHECK_MESSAGE(step == "f1", "Expected step f1 but found " << step);
-    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 1, "Expected 1 for index but found " << q2_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q2_ref.value() == "f2", "Expected to f2 but found " << q2_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q2",
-                                                          "active",
-                                                          "",
-                                                          "/suite/f")));
-    BOOST_CHECK_MESSAGE(step == "f2", "Expected step f2 but found " << step);
-    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 2, "Expected 2 for index but found " << q2_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q2_ref.value() == "f3", "Expected to f3 but found " << q2_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q2",
-                                                          "active",
-                                                          "",
-                                                          "/suite/f")));
-    BOOST_CHECK_MESSAGE(step == "f3", "Expected step f3 but found " << step);
-    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 3, "Expected 3 for index but found " << q2_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q2_ref.value() == "<NULL>", "Expected to <NULL> but found " << q2_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q2",
-                                                          "active",
-                                                          "",
-                                                          "/suite/f")),
-                                     false);
-    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 3, "Expected 3 for index but found " << q2_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q2_ref.value() == "<NULL>", "Expected to <NULL> but found " << q2_ref.value());
-
-    /////////////////////////////////////////////////////////////////////////////////////////////////////
-    // Update q3, this on the task
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q3",
-                                                          "active")));
-    BOOST_CHECK_MESSAGE(step == "t1", "Expected step t1 but found " << step);
-    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 1, "Expected 1 for index but found " << q3_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q3_ref.value() == "t2", "Expected to t2 but found " << q3_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q3",
-                                                          "active")));
-    BOOST_CHECK_MESSAGE(step == "t2", "Expected step t2 but found " << step);
-    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 2, "Expected 2 for index but found " << q3_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q3_ref.value() == "t3", "Expected to t3 but found " << q3_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q3",
-                                                          "active")));
-    BOOST_CHECK_MESSAGE(step == "t3", "Expected step t3 but found " << step);
-    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 3, "Expected 3 for index but found " << q3_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q3_ref.value() == "<NULL>", "Expected to <NULL> but found " << q3_ref.value());
-
-    step = TestHelper::invokeRequest(&defs,
-                                     Cmd_ptr(new QueueCmd(suite_f_t,
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          "q3",
-                                                          "active")),
-                                     false);
-    BOOST_CHECK_MESSAGE(step == "<NULL>", "Expected step <NULL> but found " << step);
-    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 3, "Expected 3 for index but found " << q3_ref.index_or_value());
-    BOOST_CHECK_MESSAGE(q3_ref.value() == "<NULL>", "Expected to <NULL> but found " << q3_ref.value());
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestRequest.cpp 5.13.0-1/Base/test/TestRequest.cpp
--- 5.12.4-1/Base/test/TestRequest.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestRequest.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,472 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MyDefsFixture.hpp"
-#include "TestHelper.hpp"
-#include "ecflow/base/ServerToClientResponse.hpp"
-#include "ecflow/base/cts/task/AbortCmd.hpp"
-#include "ecflow/base/cts/task/CompleteCmd.hpp"
-#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
-#include "ecflow/base/cts/task/EventCmd.hpp"
-#include "ecflow/base/cts/task/InitCmd.hpp"
-#include "ecflow/base/cts/task/LabelCmd.hpp"
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-#include "ecflow/base/cts/task/QueueCmd.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/CFileCmd.hpp"
-#include "ecflow/base/cts/user/CSyncCmd.hpp"
-#include "ecflow/base/cts/user/CheckPtCmd.hpp"
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
-#include "ecflow/base/cts/user/EditScriptCmd.hpp"
-#include "ecflow/base/cts/user/ForceCmd.hpp"
-#include "ecflow/base/cts/user/FreeDepCmd.hpp"
-#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
-#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
-#include "ecflow/base/cts/user/LogCmd.hpp"
-#include "ecflow/base/cts/user/LogMessageCmd.hpp"
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/cts/user/PlugCmd.hpp"
-#include "ecflow/base/cts/user/QueryCmd.hpp"
-#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/base/cts/user/RunNodeCmd.hpp"
-#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
-#include "ecflow/base/cts/user/ShowCmd.hpp"
-#include "ecflow/base/cts/user/ZombieCmd.hpp"
-#include "ecflow/base/stc/BlockClientZombieCmd.hpp"
-#include "ecflow/base/stc/DefsCmd.hpp"
-#include "ecflow/base/stc/ErrorCmd.hpp"
-#include "ecflow/base/stc/GroupSTCCmd.hpp"
-#include "ecflow/base/stc/SNewsCmd.hpp"
-#include "ecflow/base/stc/SNodeCmd.hpp"
-#include "ecflow/base/stc/SServerLoadCmd.hpp"
-#include "ecflow/base/stc/SStringCmd.hpp"
-#include "ecflow/base/stc/SSyncCmd.hpp"
-#include "ecflow/base/stc/StcCmd.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_FIXTURE_TEST_SUITE(U_Base, MyDefsFixture)
-
-BOOST_AUTO_TEST_SUITE(T_Request)
-
-// Can't delete the fixture defs, hence use a NULL deleter to avoid freeing memory twice.
-// Required since DefsCmd and LoadDefsCmd requires a shared_ptr.
-struct null_deleter
-{
-    void operator()(void const*) const {}
-};
-
-static void
-populateCmdVec(std::vector<Cmd_ptr>& cmd_vec, std::vector<STC_Cmd_ptr>& stc_cmd_vec, MockServer* mock_server) {
-    std::vector<std::string> suite_names;
-    suite_names.emplace_back("suiteName");
-    MyDefsFixture fixture;
-    defs_ptr client_defs = fixture.create_defs();
-    client_defs->clear_externs(); // server defs should not have externs
-
-    // Client --> Server commands
-    // make sure begin cmd is first. As this will init calendar. + other commands rely on it
-    // i.e RequeueNodeCmd assumes calendar has been initialized
-    cmd_vec.push_back(Cmd_ptr(new ShowCmd()));
-    cmd_vec.push_back(Cmd_ptr(new ServerVersionCmd()));
-    cmd_vec.push_back(Cmd_ptr(new ReplaceNodeCmd("suiteName", false, client_defs, true)));
-    cmd_vec.push_back(Cmd_ptr(new LoadDefsCmd(client_defs, true /*force*/)));
-    cmd_vec.push_back(
-        Cmd_ptr(new BeginCmd("suiteName"))); // after loading new defs, must call begin, for downstream cmds
-    cmd_vec.push_back(
-        Cmd_ptr(new BeginCmd("EmptySuite"))); // after loading new defs, must call begin for downstream cmds
-    cmd_vec.push_back(Cmd_ptr(new LogMessageCmd("LogMessageCmd")));
-    cmd_vec.push_back(Cmd_ptr(new LogCmd(LogCmd::CLEAR))); // server replies back OK/Error Cmd
-    cmd_vec.push_back(Cmd_ptr(new LogCmd(LogCmd::GET)));   // server replies back OK/Error | SStringCmd
-    cmd_vec.push_back(Cmd_ptr(new LogCmd(LogCmd::PATH)));  // server replies back Error |SStringCmd
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RESTORE_DEFS_FROM_CHECKPT)));
-    cmd_vec.push_back(Cmd_ptr(new CheckPtCmd()));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::PING)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::DEBUG_SERVER_ON)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::DEBUG_SERVER_OFF)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::SHUTDOWN_SERVER)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::HALT_SERVER)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::TERMINATE_SERVER)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_WHITE_LIST_FILE)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_PASSWD_FILE)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::STATS)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::STATS_SERVER)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::STATS_RESET)));
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::SUITES)));
-    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(CSyncCmd::NEWS, 0, 0, 0)));
-    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(CSyncCmd::SYNC, 0, 0, 0)));
-    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(CSyncCmd::SYNC_CLOCK, 0, 0, 0)));
-    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(0))); // SYNC_FULL
-    cmd_vec.push_back(Cmd_ptr(new RequeueNodeCmd("/suiteName", RequeueNodeCmd::NO_OPTION)));
-    cmd_vec.push_back(Cmd_ptr(new OrderNodeCmd("/suiteName", NOrder::ALPHA)));
-    cmd_vec.push_back(Cmd_ptr(new RunNodeCmd("/suiteName", true /* force for test */, true /* for test */)));
-    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, "EmptySuite")));
-    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::RESUME, "EmptySuite")));
-    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::KILL, "EmptySuite")));
-    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::STATUS, "EmptySuite")));
-    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::CHECK, "/suiteName")));
-    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::CHECK, "")));                  // check the full defs
-    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::EDIT_HISTORY, "/suiteName"))); // check the full defs
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::WHY, "/suiteName")));
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET, "/suiteName")));
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE, "/suiteName")));
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE, "/suiteName")));
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::CHECK_JOB_GEN_ONLY, "EmptySuite"))); // will *reset* begin
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET, "")));                          // return the full defs
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE, "")));
-    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE, "")));
-    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::FOB,
-                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                            Submittable::DUMMY_JOBS_PASSWORD())));
-    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::FAIL,
-                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                            Submittable::DUMMY_JOBS_PASSWORD())));
-    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::ADOPT,
-                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                            Submittable::DUMMY_JOBS_PASSWORD())));
-    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::REMOVE,
-                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                            Submittable::DUMMY_JOBS_PASSWORD())));
-    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::KILL,
-                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                            Submittable::DUMMY_JOBS_PASSWORD())));
-    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(0, suite_names, true)));                    // register
-    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1, suite_names, ClientHandleCmd::ADD)));    // add
-    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1, suite_names, ClientHandleCmd::REMOVE))); // remove
-    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1, true)));                                 // auto_add new suites
-    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1)));                                       // de-register/drop
-
-    cmd_vec.push_back(Cmd_ptr(new CtsCmd(
-        CtsCmd::RESTART_SERVER))); // make sure server is restarted or child cmds fail, as server will not allow comms
-
-    cmd_vec.push_back(Cmd_ptr(new InitCmd("suiteName/familyName/taskName",
-                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                          1)));
-    cmd_vec.push_back(Cmd_ptr(new EventCmd("suiteName/familyName/taskName",
-                                           Submittable::DUMMY_JOBS_PASSWORD(),
-                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                           1,
-                                           "eventName")));
-    cmd_vec.push_back(Cmd_ptr(new MeterCmd("suiteName/familyName/heir_familyName/taskName",
-                                           Submittable::DUMMY_JOBS_PASSWORD(),
-                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                           1,
-                                           "myMeter",
-                                           100)));
-    cmd_vec.push_back(Cmd_ptr(new CompleteCmd("suiteName/familyName/taskName",
-                                              Submittable::DUMMY_JOBS_PASSWORD(),
-                                              Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                              1)));
-    cmd_vec.push_back(Cmd_ptr(new AbortCmd("suiteName/familyName/taskName",
-                                           Submittable::DUMMY_JOBS_PASSWORD(),
-                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                           1)));
-    cmd_vec.push_back(Cmd_ptr(new CtsWaitCmd("suiteName/familyName/taskName",
-                                             Submittable::DUMMY_JOBS_PASSWORD(),
-                                             Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                             1,
-                                             "1 eq 1")));
-    cmd_vec.push_back(Cmd_ptr(new LabelCmd("suiteName/familyName/taskName",
-                                           Submittable::DUMMY_JOBS_PASSWORD(),
-                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                           1,
-                                           "labelName",
-                                           "label value")));
-    cmd_vec.push_back(Cmd_ptr(new QueueCmd("/suiteName/familyName/taskName",
-                                           Submittable::DUMMY_JOBS_PASSWORD(),
-                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                           1,
-                                           "queue1",
-                                           "active",
-                                           "",
-                                           "/suiteName")));
-
-    std::vector<Variable> to_add{Variable("name", "value"), Variable("name2", "value")};
-    std::vector<std::string> to_del{"name", "name2"};
-    cmd_vec.push_back(Cmd_ptr(new InitCmd("suiteName/familyName/taskName",
-                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                          1,
-                                          to_add)));
-    cmd_vec.push_back(Cmd_ptr(new CompleteCmd("suiteName/familyName/taskName",
-                                              Submittable::DUMMY_JOBS_PASSWORD(),
-                                              Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                              1,
-                                              to_del)));
-
-    cmd_vec.push_back(Cmd_ptr(new ForceCmd("/suiteName", "complete", true, true)));
-    cmd_vec.push_back(Cmd_ptr(new FreeDepCmd("/suiteName")));
-    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::ECF, 10)));
-    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::JOB, 100)));
-    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::JOBOUT, 100)));
-    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::MANUAL, 100)));
-    cmd_vec.push_back(Cmd_ptr(new EditScriptCmd()));
-    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_DATE, "12.*.*")));
-    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_DAY, "sunday")));
-    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_TIME, "+12:00")));
-    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_TIME, "+10:00 20:00 00:30")));
-    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_TODAY, "10:00 20:00 00:30")));
-    cmd_vec.push_back(Cmd_ptr(new PlugCmd()));
-    cmd_vec.push_back(Cmd_ptr(new QueryCmd("event", "/suiteName/t1", "event", "")));
-
-    std::shared_ptr<GroupCTSCmd> theGroupCmd = std::make_shared<GroupCTSCmd>();
-    theGroupCmd->addChild(Cmd_ptr(new ServerVersionCmd()));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::PING)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::SHUTDOWN_SERVER)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::HALT_SERVER)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::TERMINATE_SERVER)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_WHITE_LIST_FILE)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_PASSWD_FILE)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::SERVER_LOAD)));
-    theGroupCmd->addChild(Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, "EmptySuite")));
-    theGroupCmd->addChild(Cmd_ptr(new PathsCmd(PathsCmd::RESUME, "EmptySuite")));
-    theGroupCmd->addChild(Cmd_ptr(new PathsCmd(PathsCmd::KILL, "EmptySuite")));
-    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET, "EmptySuite")));
-    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE, "EmptySuite")));
-    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE, "EmptySuite")));
-    theGroupCmd->addChild(Cmd_ptr(new ShowCmd()));
-    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::FOB,
-                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                Submittable::DUMMY_JOBS_PASSWORD())));
-    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::FAIL,
-                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                Submittable::DUMMY_JOBS_PASSWORD())));
-    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::ADOPT,
-                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                Submittable::DUMMY_JOBS_PASSWORD())));
-    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::REMOVE,
-                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                Submittable::DUMMY_JOBS_PASSWORD())));
-    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::KILL,
-                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                Submittable::DUMMY_JOBS_PASSWORD())));
-    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::BLOCK,
-                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
-                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                Submittable::DUMMY_JOBS_PASSWORD())));
-    theGroupCmd->addChild(Cmd_ptr(new RequeueNodeCmd("/suiteName", RequeueNodeCmd::NO_OPTION)));
-    theGroupCmd->addChild(Cmd_ptr(new OrderNodeCmd("/suiteName", NOrder::ALPHA)));
-    theGroupCmd->addChild(Cmd_ptr(new RunNodeCmd("/suiteName", true /*force for test*/, true /* for test */)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RESTART_SERVER)));
-    theGroupCmd->addChild(Cmd_ptr(new InitCmd("suiteName/familyName/taskName",
-                                              Submittable::DUMMY_JOBS_PASSWORD(),
-                                              Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                              1)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::CHECK_JOB_GEN_ONLY, "EmptySuite"))); // will *reset* begin
-    theGroupCmd->addChild(Cmd_ptr(new EventCmd("suiteName/familyName/taskName",
-                                               Submittable::DUMMY_JOBS_PASSWORD(),
-                                               Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                               1,
-                                               "eventName")));
-    theGroupCmd->addChild(Cmd_ptr(new MeterCmd("suiteName/familyName/heir_familyName/taskName",
-                                               Submittable::DUMMY_JOBS_PASSWORD(),
-                                               Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                               1,
-                                               "myMeter",
-                                               100)));
-    theGroupCmd->addChild(Cmd_ptr(new CompleteCmd("suiteName/familyName/taskName",
-                                                  Submittable::DUMMY_JOBS_PASSWORD(),
-                                                  Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                  1)));
-    theGroupCmd->addChild(Cmd_ptr(new AbortCmd("suiteName/familyName/taskName",
-                                               Submittable::DUMMY_JOBS_PASSWORD(),
-                                               Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                               1)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE)));
-    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE)));
-    theGroupCmd->addChild(
-        Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL))); // will force deletion of any Node which has autocomplete
-    theGroupCmd->addChild(Cmd_ptr(new LoadDefsCmd(client_defs, true /*force*/)));
-    theGroupCmd->addChild(Cmd_ptr(new BeginCmd("suiteName")));
-    theGroupCmd->addChild(Cmd_ptr(new BeginCmd("EmptySuite")));
-    theGroupCmd->addChild(Cmd_ptr(new LogCmd(LogCmd::GET)));
-    theGroupCmd->addChild(Cmd_ptr(new LogCmd(LogCmd::CLEAR)));
-    theGroupCmd->addChild(Cmd_ptr(new LogMessageCmd("LogMessageCmd")));
-    theGroupCmd->addChild(Cmd_ptr(new ForceCmd("/suiteName", "complete", true, true)));
-    theGroupCmd->addChild(Cmd_ptr(new FreeDepCmd("/suiteName", false, true)));
-
-    BOOST_CHECK_MESSAGE(theGroupCmd->isWrite(), "Expected isWrite() to return true");
-    BOOST_CHECK_MESSAGE(theGroupCmd->get_cmd(), "Expected get_cmd() to return true");
-    BOOST_CHECK_MESSAGE(theGroupCmd->task_cmd(), "Expected task_cmd() to return true");
-    BOOST_CHECK_MESSAGE(theGroupCmd->terminate_cmd(), "Expected terminate_cmd() to return true");
-    BOOST_CHECK_MESSAGE(theGroupCmd->group_cmd(), "Expected group_cmd() to return true");
-    cmd_vec.push_back(theGroupCmd);
-
-    // Server --> Client commands
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new ErrorCmd("The error")));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new StcCmd(StcCmd::OK)));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_SERVER_HALTED)));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_ON_HOME_SERVER)));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new BlockClientZombieCmd(ecf::Child::ECF)));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new SStringCmd("Dummy contents")));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new SServerLoadCmd("/path/to/log_file")));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new SSyncCmd(0, 0, 0, mock_server)));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new SNewsCmd(0, 0, 0, mock_server)));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new DefsCmd(mock_server)));
-    stc_cmd_vec.push_back(STC_Cmd_ptr(new SNodeCmd(mock_server, node_ptr())));
-
-    std::shared_ptr<GroupSTCCmd> theSTCGroupCmd = std::make_shared<GroupSTCCmd>();
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new ErrorCmd()));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new StcCmd(StcCmd::OK)));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_SERVER_HALTED)));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_ON_HOME_SERVER)));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new BlockClientZombieCmd(ecf::Child::ECF)));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new SStringCmd()));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new SServerLoadCmd()));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new DefsCmd(mock_server)));
-    theSTCGroupCmd->addChild(STC_Cmd_ptr(new SNodeCmd(mock_server, node_ptr())));
-    stc_cmd_vec.push_back(theSTCGroupCmd);
-}
-
-static void test_persistence(const Defs& theFixtureDefs) {
-    auto* fixtureDefs = const_cast<Defs*>(&theFixtureDefs);
-    fixtureDefs->clear_externs();       // server does not have externs
-    MockServer mockServer(fixtureDefs); // creates shared ptr with a NULL deleter
-
-    std::vector<Cmd_ptr> cmd_vec;
-    std::vector<STC_Cmd_ptr> stc_cmd_vec;
-    populateCmdVec(cmd_vec, stc_cmd_vec, &mockServer);
-
-    int getRequest       = 0;
-    int terminateRequest = 0;
-    int groupRequest     = 0;
-    for (const Cmd_ptr& theCmd : cmd_vec) {
-
-        // std::cout << "TheCmd "; theCmd->print(std::cout); std::cout << "\n";
-        if (theCmd->connect_to_different_servers()) {
-            BOOST_CHECK_MESSAGE(theCmd->task_cmd(),
-                                "Currently only tasks commands, are allowed to connect to different servers");
-        }
-
-        ClientToServerRequest cmd_request;
-        cmd_request.set_cmd(theCmd);
-        {
-            if (theCmd.get()->handleRequestIsTestable()) {
-                // test handleRequest while were at it.
-                // Avoid TERMINATE_SERVER cmd as this will prematurely cause an exit, wont appear as an error
-                // cerr << "cmd_request = " << cmd_request << "\n";
-                try {
-                    STC_Cmd_ptr ok_or_error_cmd = cmd_request.handleRequest(&mockServer);
-                    if (ok_or_error_cmd) {
-                        // Commands like ErrorCmd, OkCmd don't return a cmd_ptr from handleRequest
-                        // those that do, check OkCmd returned, else if ErrorCmd show the error
-                        BOOST_CHECK_MESSAGE(ok_or_error_cmd->ok(),
-                                            "Request '" << cmd_request << "' returned " << ok_or_error_cmd->error());
-                    }
-                }
-                catch (std::exception& e) {
-                    BOOST_CHECK_MESSAGE(false, "Unexpected exception : " << e.what() << " : " << cmd_request);
-                }
-            }
-        }
-
-        // cout << " Saving = " << cmd_request << "\n";
-        std::string saved_request;
-        {
-            BOOST_REQUIRE_NO_THROW(ecf::save("request.txt", cmd_request)); // save as filename
-            ecf::save_as_string(saved_request, cmd_request);               // save as string
-            // cout << saved_request << "\n";                                // Take a peek at json output
-        }
-
-        // cout << " Restoring = " << cmd_request << "\n";
-        {
-            ClientToServerRequest restoredRequest;
-            BOOST_REQUIRE_NO_THROW(ecf::restore("request.txt", restoredRequest));
-            BOOST_REQUIRE_MESSAGE(restoredRequest == cmd_request,
-                                  "restoredRequest " << restoredRequest << " cmd_request " << cmd_request);
-
-            if (restoredRequest.getRequest())
-                getRequest++;
-            if (restoredRequest.terminateRequest())
-                terminateRequest++;
-            if (restoredRequest.groupRequest())
-                groupRequest++;
-        }
-        {
-            ClientToServerRequest restoredRequest;
-            ecf::restore_from_string(saved_request, restoredRequest);
-            BOOST_REQUIRE_MESSAGE(restoredRequest == cmd_request,
-                                  "restoredRequest " << restoredRequest << " cmd_request " << cmd_request);
-        }
-
-        fs::remove("request.txt");
-    }
-
-    BOOST_CHECK_MESSAGE(getRequest == 3, " expected 3 get Request  but found " << getRequest);
-    BOOST_CHECK_MESSAGE(terminateRequest == 2, " expected 2 terminate Request but found " << terminateRequest);
-    BOOST_CHECK_MESSAGE(groupRequest == 1, " expected 1 group Request but found " << groupRequest);
-
-    for (const STC_Cmd_ptr& theCmd : stc_cmd_vec) {
-        //		std::cout << "TheCmd "; theCmd->print(std::cout); std::cout << "\n";
-
-        const ServerToClientResponse cmd_request(theCmd); // MUST be const to avoid AIX compiler warning
-        BOOST_REQUIRE_NO_THROW(ecf::save("request.txt", cmd_request));
-
-        ServerToClientResponse restoredRequest;
-        BOOST_REQUIRE_NO_THROW(ecf::restore("request.txt", restoredRequest));
-        BOOST_REQUIRE_MESSAGE(restoredRequest == cmd_request,
-                              "restoredRequest " << restoredRequest << " cmd_request " << cmd_request);
-        fs::remove("request.txt");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_all_request_persistence_text) {
-    cout << "Base:: ...test_all_request_persistence_text\n";
-    TestLog test_log("test_all_request_persistence_text.log"); // will create log file, and destroy log and remove file
-                                                               // at end of scope
-
-    test_persistence(fixtureDefsFile());
-}
-
-BOOST_AUTO_TEST_CASE(test_request_authenticate) {
-    cout << "Base:: ...test_request_authenticate\n";
-    TestLog test_log(
-        "test_request_authenticate.log"); // will create log file, and destroy log and remove file at end of scope
-
-    // the path "suiteName0/familyName0/taskName0" must exist in the defsfile_ fixture
-    Cmd_ptr cmd_ptr(new InitCmd("suiteName/familyName/taskName",
-                                Submittable::DUMMY_JOBS_PASSWORD(),
-                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                1));
-
-    // The invokeRequest will return check if the path and password exist in the Node tree
-    TestHelper::invokeRequest(&defsfile_, cmd_ptr);
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestRequeueNodeCmd.cpp 5.13.0-1/Base/test/TestRequeueNodeCmd.cpp
--- 5.12.4-1/Base/test/TestRequeueNodeCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestRequeueNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,383 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/ForceCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Pid.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_RequeueNodeCmd)
-
-BOOST_AUTO_TEST_CASE(test_requeue_with_suspend) {
-    cout << "Base:: ...test_requeue_with_suspend\n";
-    TestLog test_log(
-        "test_requeue_with_suspend.log"); // will create log file, and destroy log and remove file at end of scope
-
-    defs_ptr the_defs = Defs::create();
-    suite_ptr s1      = the_defs->add_suite("s1");
-    family_ptr f1     = s1->add_family("f1");
-    task_ptr t1       = f1->add_task("t1");
-    task_ptr t2       = f1->add_task("t2");
-    task_ptr t3       = f1->add_task("t3");
-    t3->addDefStatus(DState::SUSPENDED);
-
-    the_defs->beginAll();
-
-    // After begin/requeue we must honour defs status
-    BOOST_CHECK_MESSAGE(t3->isSuspended(), "Expected node to be suspended");
-
-    // Suspend all nodes
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, s1->absNodePath())));
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, f1->absNodePath())));
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t1->absNodePath())));
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t2->absNodePath())));
-    BOOST_CHECK_MESSAGE(s1->isSuspended(), "Expected node to be suspended");
-    BOOST_CHECK_MESSAGE(f1->isSuspended(), "Expected node to be suspended");
-    BOOST_CHECK_MESSAGE(t1->isSuspended(), "Expected node to be suspended");
-    BOOST_CHECK_MESSAGE(t2->isSuspended(), "Expected node to be suspended");
-
-    // Re-queue of the nodes, that are suspended, they should *stay* suspended
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
-    BOOST_CHECK_MESSAGE(t1->isSuspended(), "Expected node to stay suspended");
-
-    // Now re-queue the top level suite, this is suspended.
-    // This should stay suspended *BUT* child nodes which are suspend should be cleared
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(s1->absNodePath())));
-    BOOST_CHECK_MESSAGE(s1->isSuspended(), "Suite should stay suspend");
-    BOOST_CHECK_MESSAGE(!f1->isSuspended(), "Expected child nodes to be un-suspended");
-    BOOST_CHECK_MESSAGE(!t1->isSuspended(), "Expected child nodes to be un-suspended");
-    BOOST_CHECK_MESSAGE(!t2->isSuspended(), "Expected child nodes to be un-suspended");
-    BOOST_CHECK_MESSAGE(t3->isSuspended(), "Requeue must honour def status");
-}
-
-BOOST_AUTO_TEST_CASE(test_requeue_family_clears_children_SUP_909) {
-    cout << "Base:: ...test_requeue_family_clears_children_SUP_909\n";
-    TestLog test_log("test_requeue_family_clears_children_SUP_909.log"); // will create log file, and destroy log and
-                                                                         // remove file at end of scope
-
-    //   suite s1
-    //    family f1
-    //       task t1
-    //          time 23:30
-    //     endFamily
-    //   endsuite
-    // make sure time is set *before* 23:30, so that time dependency holds the task
-
-    defs_ptr the_defs = Defs::create();
-    suite_ptr suite   = the_defs->add_suite("s1");
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
-    suite->addClock(clockAttr);
-
-    family_ptr f1 = suite->add_family("f1");
-    task_ptr t1   = f1->add_task("t1");
-    t1->addTime(TimeAttr(23, 30));
-
-    const TimeSeries& theTime = t1->timeVec().back().time_series();
-
-    the_defs->beginAll();
-
-    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    BOOST_CHECK_MESSAGE(!theTime.is_valid(), "Expected time to have expired");
-    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
-
-    // Now reque the family, this should clear the time, so that it now holding again
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(f1->absNodePath())));
-    TestHelper::test_state(f1, NState::QUEUED);
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be reset");
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_based_requeue_clears_children) {
-    cout << "Base:: ...test_repeat_based_requeue_clears_children\n";
-    TestLog test_log("test_repeat_based_requeue_clears_children.log"); // will create log file, and destroy log and
-                                                                       // remove file at end of scope
-
-    //   suite s1
-    //    repeat day 1
-    //    family f1
-    //       task t1
-    //          time 23:30
-    //     endfamily
-    //   endsuite
-    // make sure time is set *before* 23:30, so that time dependency holds the task
-
-    defs_ptr the_defs = Defs::create();
-    suite_ptr suite   = the_defs->add_suite("s1");
-    ClockAttr clockAttr(15, 12, 2010, false);
-    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
-    suite->addClock(clockAttr);
-
-    suite->addRepeat(RepeatDay(1));
-
-    family_ptr f1 = suite->add_family("f1");
-    task_ptr t1   = f1->add_task("t1");
-    t1->addTime(TimeAttr(23, 30));
-
-    const TimeSeries& theTime = t1->timeVec().back().time_series();
-
-    the_defs->beginAll();
-
-    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
-
-    // Forcing task t1 to complete, should cause the top, level repeat to REQEUE
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
-
-    TestHelper::test_state(t1, NState::QUEUED);
-    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
-    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
-                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
-}
-
-BOOST_AUTO_TEST_CASE(test_ecflow_359) {
-    cout << "Base:: ...test_ECFLOW-359\n";
-    TestLog test_log("test_ecflow_359.log"); // will create log file, and destroy log and remove file at end of scope
-
-    //   suite s1
-    //     family f1
-    //       repeat date YMD 20090916 20090928
-    //       family parent
-    //          task dummy
-    //             time 16:00
-    //       endfamily
-    //       task complete
-    //          defstatus complete
-
-    //   set defstatus complete /s1/f1/parent/dummy
-    //   requeue s1/f1/parent
-    //   f1 gets set complete through status inheritance
-    //   YMD is not increment at the moment...
-
-    defs_ptr the_defs = Defs::create();
-    suite_ptr suite   = the_defs->add_suite("s1");
-    family_ptr f1     = suite->add_family("f1");
-    f1->addRepeat(RepeatDate("YMD", 20090916, 20090928, 1));
-
-    family_ptr parent = f1->add_family("parent");
-    task_ptr dummy    = parent->add_task("dummy");
-    dummy->addTime(TimeAttr(16, 0));
-
-    task_ptr complete = f1->add_task("complete");
-    complete->addDefStatus(DState::COMPLETE);
-
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs;
-
-    the_defs->beginAll();
-
-    //   cout << "----->set defstatus complete /s1/f1/parent/dummy\n";
-    BOOST_CHECK_MESSAGE(dummy->defStatus() == DState::QUEUED,
-                        "Expected dstate to be queued but found " << DState::toString(dummy->dstate()));
-    TestHelper::invokeRequest(the_defs.get(),
-                              Cmd_ptr(new AlterCmd(dummy->absNodePath(), AlterCmd::DEFSTATUS, "complete")));
-    BOOST_CHECK_MESSAGE(dummy->defStatus() == DState::COMPLETE,
-                        "Expected dstate to be complete but found " << DState::toString(dummy->dstate()));
-    //   cout << the_defs;
-
-    //   cout << "----->requeue parent since all children are now complete, we expect the repeat on the f1 to
-    //   increment\n";
-    BOOST_CHECK_MESSAGE(f1->repeat().value() == 20090916,
-                        "Expected repeat value of 20090916 but found " << f1->repeat().value());
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(parent->absNodePath())));
-    BOOST_CHECK_MESSAGE(f1->repeat().value() == 20090917,
-                        "Expected repeat value of 20090917 but found " << f1->repeat().value());
-    //   cout << the_defs;
-
-    //   cout << "----->requeue again\n";
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(parent->absNodePath())));
-    BOOST_CHECK_MESSAGE(f1->repeat().value() == 20090918,
-                        "Expected repeat value of 20090918 but found " << f1->repeat().value());
-    //   cout << the_defs;
-}
-
-BOOST_AUTO_TEST_CASE(test_ecflow_428) {
-    cout << "Base:: ...test_ECFLOW-428\n";
-    TestLog test_log("test_ecflow_428.log"); // will create log file, and destroy log and remove file at end of scope
-
-    //   suite s1
-    //     family f1
-    //       family f2
-    //          task t1
-    //          task t2
-
-    // Set t1 to aborted, then call reque aborted on suite s1
-    // This should result ALL nodes to be in a queued state
-
-    defs_ptr the_defs = Defs::create();
-    suite_ptr suite   = the_defs->add_suite("s1");
-    suite->addDefStatus(DState::SUSPENDED);
-    family_ptr f1 = suite->add_family("f1");
-    family_ptr f2 = f1->add_family("f1");
-    task_ptr t1   = f2->add_task("t1");
-    task_ptr t2   = f2->add_task("t2");
-
-    //   PrintStyle style(PrintStyle::STATE); cout << the_defs;
-
-    the_defs->beginAll();
-
-    // set t1 to aborted state
-    TestHelper::invokeRequest(
-        the_defs.get(),
-        Cmd_ptr(
-            new ForceCmd(t1->absNodePath(), "aborted", false /*recursive */, false /* set Repeat to last value */)));
-    TestHelper::test_state(t1, NState::ABORTED);
-    TestHelper::test_state(t2, NState::QUEUED);
-    TestHelper::test_state(f1, NState::ABORTED);
-    TestHelper::test_state(f2, NState::ABORTED);
-    TestHelper::test_state(suite, NState::ABORTED);
-
-    // Now reque aborted tasks for suite
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(suite->absNodePath(), RequeueNodeCmd::ABORT)));
-
-    // *Suite* should now be queued
-    TestHelper::test_state(suite, NState::QUEUED);
-    TestHelper::test_state(f1, NState::QUEUED);
-    TestHelper::test_state(f2, NState::QUEUED);
-    TestHelper::test_state(t1, NState::QUEUED);
-    TestHelper::test_state(t2, NState::QUEUED);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_based_requeue_resets_relative_duration) {
-    cout << "Base:: ...test_repeat_based_requeue_resets_relative_duration\n";
-    TestLog test_log("test_repeat_based_requeue_resets_relative_duration.log"); // will create log file, and destroy log
-                                                                                // and remove file at end of scope
-
-    //   suite ecflow_1182
-    //    family f
-    //      repeat integer HYEAR 1993 2017 1
-    //      time +00:01
-    //      task uk2fdb
-
-    defs_ptr the_defs = Defs::create();
-    suite_ptr suite   = the_defs->add_suite("ecflow_1182");
-    family_ptr f      = suite->add_family("f");
-    f->addRepeat(RepeatInteger("rep", 1993, 2017));
-    f->addTime(TimeAttr("+00:01"));
-
-    task_ptr t1 = f->add_task("uk2fsb");
-
-    auto& theTime = const_cast<TimeSeries&>(f->timeVec().back().time_series());
-
-    the_defs->beginAll();
-    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
-
-    // forward time, so that time expires
-    // The calendar is *only* updated if the suite have been begun. Hence make sure this test scaffold
-    // starts the test, with all the suites in a begun state
-    boost::posix_time::ptime time_now = Calendar::second_clock_time();
-    {
-        CalendarUpdateParams cal(time_now, minutes(1), true /* server running */, false /* for Test*/);
-        the_defs->updateCalendar(cal); // cout << suite->calendar().toString() << "\n";
-        time_now += minutes(1);
-    }
-    {
-        CalendarUpdateParams cal(time_now, minutes(1), true /* server running */, false /* for Test*/);
-        the_defs->updateCalendar(cal); // cout << suite->calendar().toString() << "\n";
-    }
-    theTime.requeue(suite->calendar(), true); // will expire time
-    BOOST_CHECK_MESSAGE(!theTime.is_valid(), "Expected time to be expired");
-
-    // Now re-queue the suite/family
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(suite->absNodePath())));
-    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be valid");
-
-    // PrintStyle style(PrintStyle::MIGRATE);
-    // cout << the_defs;
-}
-
-BOOST_AUTO_TEST_CASE(test_reque_with_repeat_and_defstatus_complete) {
-    cout << "Base:: ...test_reque_with_repeat_and_defstatus_complete\n";
-
-    // This will test that when we have a family with a repeat AND defstatus complete
-    // We ONLY log the state change complete in the log file when re-queuing
-
-    //   suite test_reque_with_repeat_and_defstatus_complete
-    //     family f1
-    //       repeat date YMD 20000101 20100101 1
-    //       task t1
-    //       task t2
-    ///      defstatus complete
-
-    defs_ptr the_defs = Defs::create();
-    suite_ptr suite   = the_defs->add_suite("test_reque_with_repeat_and_defstatus_complete");
-    family_ptr f1     = suite->add_family("f1");
-    f1->addRepeat(RepeatDate("YMD", 20090531, 20101231, 1));
-    f1->addDefStatus(DState::COMPLETE);
-    task_ptr t1 = f1->add_task("t1");
-    task_ptr t2 = f1->add_task("t2");
-
-    // PrintStyle style(PrintStyle::STATE); cout << the_defs;
-
-    the_defs->beginAll();
-
-    // Create a log file with a unique name, to avoid problems when running in paralle
-    // This test relies on log file contents to be flushed.
-    std::string log_file = "Base/test/test_reque_with_repeat_and_defstatus_complete_";
-    log_file += Pid::getpid(); // can throw
-    log_file += ".log";
-    log_file = File::test_data(log_file, "Base");
-
-    Log::create(log_file);
-
-    // Re-queue the family. In past we queued all nodes, then set to complete
-    // We still do this, but we now longer LOG the setting the the queued state
-    // Hence in the log file we only expected to see nodes in the complete state
-    // See: ECFLOW-1239. When dealing with thousands of nodes, this was causing performance problems
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(f1->absNodePath())));
-    TestHelper::test_state(t1, NState::COMPLETE);
-    TestHelper::test_state(t2, NState::COMPLETE);
-    TestHelper::test_state(f1, NState::COMPLETE);
-    TestHelper::test_state(suite, NState::COMPLETE);
-
-    // This should also flush the log file.
-    Log::destroy();
-
-    // Open the log file and look for 'queued:' if we find it then this is a regression.
-    std::string error_msg;
-    std::string log_contents = File::get_first_n_lines(log_file, 1000, error_msg);
-    BOOST_REQUIRE_MESSAGE(error_msg.empty(), "could not open log file " << log_file);
-    BOOST_CHECK_MESSAGE(log_contents.find("complete:") != std::string::npos,
-                        "defstatus complete failed.\n'" << log_contents << "'");
-    BOOST_CHECK_MESSAGE(log_contents.find("queued:") == std::string::npos,
-                        "RequeNode with repeat and defstatus complete should only log the complete state change");
-
-    fs::remove(log_file);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestResolveDependencies.cpp 5.13.0-1/Base/test/TestResolveDependencies.cpp
--- 5.12.4-1/Base/test/TestResolveDependencies.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestResolveDependencies.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,296 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_ResolveDependencies)
-
-BOOST_AUTO_TEST_CASE(test_resolve_dependencies) {
-    cout << "Base:: ...test_resolve_dependencies\n";
-    TestLog test_log(
-        "test_resolve_dependencies.log"); // will create log file, and destroy log and remove file at end of scope
-
-    ////////////////////////////////////////////////////////////////////////////////////////////////////
-    // Create the defs file
-    //   suite suite
-    //     family f
-    //       task t
-    //         meter step 0 240 120
-    //         task tt
-    //           complete t:step ge 120
-    //           trigger t == complete
-    //     endfamily
-    //   endsuite
-    Defs defs;
-    std::string metername  = "step";
-    std::string suitename  = "suite";
-    std::string familyname = "f";
-    {
-        suite_ptr suite = defs.add_suite(suitename);
-        family_ptr fam  = suite->add_family(familyname);
-
-        task_ptr task = fam->add_task("t");
-        task->addMeter(Meter(metername, 0, 240, 120));
-
-        task_ptr task_tt = fam->add_task("tt");
-        task_tt->add_complete("t:step ge 120");
-        task_tt->add_trigger("t == complete");
-
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-
-    // Ensure initial state is unknown
-    string suite_f_t  = "/suite/f/t";
-    string suite_f_tt = "/suite/f/tt";
-    node_ptr node_t   = defs.findAbsNode(suite_f_t);
-    node_ptr node_tt  = defs.findAbsNode(suite_f_tt);
-    suite_ptr suite   = defs.findSuite(suitename);
-    family_ptr fam    = suite->findFamily(familyname);
-    BOOST_CHECK_MESSAGE(suite->state() == NState::UNKNOWN,
-                        "expected state NState::UNKNOWN, but found to be " << NState::toString(suite->state()));
-    BOOST_CHECK_MESSAGE(node_t->state() == NState::UNKNOWN,
-                        "expected state NState::UNKNOWN, but found to be " << NState::toString(node_t->state()));
-    BOOST_CHECK_MESSAGE(node_tt->state() == NState::UNKNOWN,
-                        "expected state NState::UNKNOWN, but found to be " << NState::toString(node_tt->state()));
-    BOOST_CHECK_MESSAGE(fam->state() == NState::UNKNOWN,
-                        "expected state NState::UNKNOWN, but found to be " << NState::toString(fam->state()));
-
-    // ***********************************************************************
-    // Create a request to begin suite
-    // make sure chosen suite can begin to resolve dependencies.
-    // beginning the suite will :
-    //     1/ set all children to the QUEUED state
-    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
-    {
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
-        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(suite->state()));
-        BOOST_CHECK_MESSAGE(fam->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(fam->state()));
-        BOOST_CHECK_MESSAGE(node_t->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(node_t->state()));
-        BOOST_CHECK_MESSAGE(node_tt->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(node_tt->state()));
-    }
-
-    //*******************************************************************************
-    // Resolve dependencies.
-    //   task t
-    //     meter step 0 240 120       EXPECTED to be sumbitted
-    //
-    //   task tt
-    //     complete t:step ge 120     Expected to HOLD, since we ain't done nothing yet
-    //     trigger t == complete
-    {
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
-        BOOST_CHECK_MESSAGE(node_t->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(node_t->state()));
-        BOOST_CHECK_MESSAGE(node_tt->state() == NState::QUEUED,
-                            "expected state NState::QUEUED, but found to be " << NState::toString(node_tt->state()));
-    }
-
-    //**********************************************************************
-    // Create a request to set the Meter node t. This should force node tt
-    // to complete immediately
-    {
-        int meterValue = 120;
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new MeterCmd(suite_f_t,
-                                                       Submittable::DUMMY_JOBS_PASSWORD(),
-                                                       Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                       1,
-                                                       metername,
-                                                       meterValue)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
-        const Meter& theMeter = node_t->findMeter(metername);
-        BOOST_CHECK_MESSAGE(!theMeter.empty(), "Could not find the meter ");
-        BOOST_CHECK_MESSAGE(theMeter.value() == meterValue, "Meter value not set");
-
-        BOOST_CHECK_MESSAGE(node_t->state() == NState::ACTIVE,
-                            "expected state NState::ACTIVE, but found to be " << NState::toString(node_t->state()));
-        BOOST_CHECK_MESSAGE(node_tt->state() == NState::COMPLETE,
-                            "expected state NState::COMPLETE, but found to be " << NState::toString(node_tt->state()));
-    }
-
-    {
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_trigger_after_delete) {
-    cout << "Base:: ...test_trigger_after_delete\n";
-    ////////////////////////////////////////////////////////////////////////////////////////////////////
-    // Create the defs file
-    //   suite suite1    # the limit we want delete
-    //     family f
-    //       task t0
-    //         defstatus complete
-    //       task t1
-    //         event event
-    //       task t2
-    //         meter meter 0 100 100
-    //       task t3
-    //         edit user_var 1
-    //       task t4
-    //         repeat integer repeat_var 0 10 2
-    //     endfamily
-    //   endsuite
-    //   suite suite2
-    //     family f
-    //       task t0
-    //         trigger /suite1/f/t0 == complete
-    //       task t1
-    //         trigger /suite1/f/t1:event == set
-    //       task t2
-    //         trigger /suite1/f/t2:meter == 10
-    //       task t3
-    //         trigger /suite1/f/t2:user_var == 1
-    //       task t4
-    //         trigger /suite1/f/t2:repeat_var == 2
-    //     endfamily
-    //   endsuite
-    //
-    // In this test case all triggers in suite2 will evaluate true, we then delete suite1 and
-    // all the triggers should evaluate false; This is used to test the shared ptr in
-    // the expression, which hold the reference nodes. When the reference nodes are deleted
-    // then the expression should not evaluate
-    Defs defs;
-    {
-        suite_ptr suite = Suite::create("suite1");
-        family_ptr f    = Family::create("f");
-        task_ptr t0     = Task::create("t0");
-        task_ptr t1     = Task::create("t1");
-        task_ptr t2     = Task::create("t2");
-        task_ptr t3     = Task::create("t3");
-        task_ptr t4     = Task::create("t4");
-        t0->addDefStatus(DState::COMPLETE);
-        t1->addEvent(Event(0, "event", true));
-        t2->addMeter(Meter("meter", 0, 100, 100));
-        t3->addVariable(Variable("user_var", "1"));
-        t4->addRepeat(RepeatInteger("repeat_var", 0, 10, 2));
-
-        f->addTask(t0);
-        f->addTask(t1);
-        f->addTask(t2);
-        f->addTask(t3);
-        f->addTask(t4);
-        suite->addFamily(f);
-        defs.addSuite(suite);
-    }
-    {
-        suite_ptr suite = Suite::create("suite2");
-        family_ptr f    = Family::create("f");
-        task_ptr t0     = Task::create("t0");
-        task_ptr t1     = Task::create("t1");
-        task_ptr t2     = Task::create("t2");
-        task_ptr t3     = Task::create("t3");
-        task_ptr t4     = Task::create("t4");
-        t0->add_trigger("/suite1/f/t0 == complete");
-        t1->add_trigger("/suite1/f/t1:event == set");
-        t2->add_trigger("/suite1/f/t2:meter == 10");
-        t3->add_trigger("/suite1/f/t3:user_var == 1");
-        t4->add_trigger("/suite1/f/t4:repeat_var == 2");
-
-        f->addTask(t0);
-        f->addTask(t1);
-        f->addTask(t2);
-        f->addTask(t3);
-        f->addTask(t4);
-        suite->addFamily(f);
-        defs.addSuite(suite);
-    }
-
-    // begin. This will reset all attributes
-    defs.beginAll();
-
-    // setup attrbutes in suite1 so that evalaution will succeed in suite 2
-    // *** this must be in its own scope otherwise the shared_ptr will keep the node alive
-    {
-        node_ptr t1 = defs.findAbsNode("/suite1/f/t1");
-        t1->changeEvent("event", "set");
-        node_ptr t2 = defs.findAbsNode("/suite1/f/t2");
-        t2->changeMeter("meter", 10);
-        node_ptr t4 = defs.findAbsNode("/suite1/f/t4");
-        t4->changeRepeat("2");
-        // cout << defs;
-    }
-
-    // evalate the triggers in suite2
-    {
-        node_ptr suite2 = defs.findAbsNode("/suite2");
-        std::vector<task_ptr> suite2_tasks;
-        suite2->get_all_tasks(suite2_tasks);
-        BOOST_REQUIRE_MESSAGE(suite2_tasks.size() == 5, "Expected 5 tasks on suite2 but found " << suite2_tasks.size());
-
-        for (auto& suite2_task : suite2_tasks) {
-            BOOST_REQUIRE_MESSAGE(suite2_task->triggerAst()->evaluate(),
-                                  "Expected task " << suite2_task->absNodePath() << " to evaluate");
-        }
-    }
-
-    // Ok Now delete suite1,
-    // *** It is extremely important that shared_ptr for '/suite1' is in its own
-    // *** scope, otherwise it will keep the 'suite' live, and NOT delete the limits
-    {
-        node_ptr suite1 = defs.findAbsNode("/suite1");
-        BOOST_REQUIRE_MESSAGE(suite1.get(), "Could not find the suite we want to delete?");
-        BOOST_REQUIRE_MESSAGE(defs.deleteChild(suite1.get()), "Deletion failed?");
-        BOOST_REQUIRE_MESSAGE(!defs.findAbsNode("/suite1").get(), "Deletion failed?");
-    }
-
-    // revaluate the triggers in suite2. This should fail, since we have delete suite1
-    {
-        node_ptr suite2 = defs.findAbsNode("/suite2");
-        std::vector<task_ptr> suite2_tasks;
-        suite2->get_all_tasks(suite2_tasks);
-        BOOST_REQUIRE_MESSAGE(suite2_tasks.size() == 5, "Expected 5 tasks on suite2 but found " << suite2_tasks.size());
-
-        for (auto& suite2_task : suite2_tasks) {
-            BOOST_REQUIRE_MESSAGE(!suite2_task->triggerAst()->evaluate(),
-                                  "Expected task " << suite2_task->absNodePath() << " to fail evaluation");
-        }
-    }
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestSSyncCmd.cpp 5.13.0-1/Base/test/TestSSyncCmd.cpp
--- 5.12.4-1/Base/test/TestSSyncCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestSSyncCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,484 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MockServer.hpp"
-#include "MyDefsFixture.hpp"
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/DeleteCmd.hpp"
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
-#include "ecflow/base/cts/user/PlugCmd.hpp"
-#include "ecflow/base/stc/SNewsCmd.hpp"
-#include "ecflow/base/stc/SSyncCmd.hpp"
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_SSyncCmd)
-
-/// define a function which returns nothing, and takes a defs_ptr parameter
-typedef boost::function<void(defs_ptr)> defs_change_cmd;
-
-/// Re-use the same test scaffold to modify and then resync, by passing
-/// in a function that will modify the defs
-static void test_sync_scaffold(defs_change_cmd the_defs_change_command,
-                               const std::string& test_name,
-                               bool full_sync        = false,
-                               bool start_with_begin = false) {
-    MyDefsFixture clientFixture;
-    MyDefsFixture serverFixture;
-    defs_ptr server_defs = serverFixture.create_defs();
-    if (start_with_begin)
-        server_defs->beginAll();
-    server_defs->set_server().set_state(
-        SState::HALTED); // if defs default state is RUNNING, whereas for server it is HALTED
-
-    ServerReply server_reply;
-    defs_ptr client_defs = clientFixture.create_defs();
-    if (start_with_begin)
-        client_defs->beginAll();
-    client_defs->set_server().set_state(
-        SState::HALTED); // if defs default state is RUNNING, whereas for server it is HALTED
-    server_reply.set_client_defs(client_defs);
-
-    Ecf::set_debug_equality(true); // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
-                        "Test:" << test_name << ": Starting point client and server defs should be the same");
-    Ecf::set_debug_equality(false); // only has affect in DEBUG build
-
-    // Get change number before any changes
-    unsigned int client_state_change_no  = Ecf::state_change_no();
-    unsigned int client_modify_change_no = Ecf::modify_change_no();
-
-    // make some change to the server
-    {
-        Ecf::set_server(true);
-
-        the_defs_change_command(server_defs);
-
-        std::string error_msg;
-        BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(error_msg),
-                              "Test:" << test_name << ": Invariants failed: " << error_msg);
-        BOOST_REQUIRE_MESSAGE(!(*server_reply.client_defs() == *server_defs),
-                              "Test:" << test_name << ": Expected client and server defs to differ\n"
-                                      << *server_reply.client_defs() << "\n"
-                                      << "server defs   = " << *server_defs);
-        Ecf::set_server(false);
-    }
-
-    MockServer mock_server(server_defs);
-    unsigned int client_handle = 0;
-    SNewsCmd news_cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
-    SSyncCmd cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
-
-    std::string error_msg;
-    BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(error_msg),
-                          "Test:" << test_name << ": Invariants failed: " << error_msg);
-    BOOST_CHECK_MESSAGE(news_cmd.get_news(), "Test:" << test_name << ": Expected server to change");
-    BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), "Test:" << test_name << ": Expected server to change");
-    BOOST_CHECK_MESSAGE(server_reply.in_sync(), "Test:" << test_name << ": Expected server to change");
-    BOOST_CHECK_MESSAGE(server_reply.full_sync() == full_sync,
-                        "Test:" << test_name << ": Expected sync not as expected");
-
-    error_msg.clear();
-    BOOST_REQUIRE_MESSAGE(server_reply.client_defs()->checkInvariants(error_msg),
-                          "Test:" << test_name << ": Invariants failed: " << error_msg);
-
-    DebugEquality debug_equality; // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
-                        "Test:" << test_name << ": Server and client should be same after sync");
-    //	if (! (*server_defs == *server_reply.client_defs()) ) {
-    //	   cout << "Server====================================================================\n";
-    //	   cout << server_defs;
-    //    cout << "Client====================================================================\n";
-    //    cout << server_reply.client_defs();
-    //	}
-}
-
-// The modifiers
-void delete_some_attributes(defs_ptr defs) {
-    std::vector<Task*> tasks;
-    defs->getAllTasks(tasks);
-    for (Task* task : tasks) {
-
-        SuiteChanged1 changed(task->suite());
-
-        /// Take a copy, of the objects we want to delete. since there are returned by reference
-        std::vector<Event> events = task->events();
-        std::vector<Meter> meters = task->meters();
-        std::vector<Label> labels = task->labels();
-
-        for (const Event& e : events) {
-            task->deleteEvent(e.name_or_number());
-        }
-        for (const Meter& m : meters) {
-            task->deleteMeter(m.name());
-        }
-        for (const Label& l : labels) {
-            task->deleteLabel(l.name());
-        }
-
-        BOOST_REQUIRE_MESSAGE(task->events().empty(), "Expected all events to be deleted");
-        BOOST_REQUIRE_MESSAGE(task->meters().empty(), "Expected all meters to be deleted");
-        BOOST_REQUIRE_MESSAGE(task->labels().empty(), "Expected all labels to be deleted");
-    }
-}
-
-void delete_time_attributes(defs_ptr defs) {
-    std::vector<Node*> nodes;
-    defs->getAllNodes(nodes);
-    for (Node* node : nodes) {
-
-        SuiteChanged1 changed(node->suite());
-
-        /// Take a copy, of the objects we want to delete. since there are returned by reference
-        std::vector<TimeAttr> times   = node->timeVec();
-        std::vector<TodayAttr> todays = node->todayVec();
-        std::vector<DayAttr> days     = node->days();
-        std::vector<DateAttr> dates   = node->dates();
-        std::vector<CronAttr> crons   = node->crons();
-
-        for (const TimeAttr& t : times) {
-            node->delete_time(t);
-        }
-        for (const TodayAttr& t : todays) {
-            node->delete_today(t);
-        }
-        for (const DayAttr& t : days) {
-            node->delete_day(t);
-        }
-        for (const DateAttr& t : dates) {
-            node->delete_date(t);
-        }
-        for (const CronAttr& t : crons) {
-            node->delete_cron(t);
-        }
-
-        BOOST_REQUIRE_MESSAGE(node->timeVec().empty(), "Expected all times to be deleted");
-        BOOST_REQUIRE_MESSAGE(node->todayVec().empty(), "Expected all todays to be deleted");
-        BOOST_REQUIRE_MESSAGE(node->days().empty(), "Expected all days to be deleted");
-        BOOST_REQUIRE_MESSAGE(node->dates().empty(), "Expected all dates to be deleted");
-        BOOST_REQUIRE_MESSAGE(node->crons().empty(), "Expected all crons to be deleted");
-    }
-}
-
-void delete_misc_attributes(defs_ptr defs) {
-    std::vector<Node*> nodes;
-    defs->getAllNodes(nodes);
-    for (Node* node : nodes) {
-
-        SuiteChanged1 changed(node->suite());
-
-        /// Take a copy, of the objects we want to delete. since there are returned by reference
-        std::vector<ZombieAttr> zombies = node->zombies();
-        // std::vector<VerifyAttr> verifys = node->verifys()();
-
-        for (const ZombieAttr& t : zombies) {
-            node->delete_zombie(t.zombie_type());
-        }
-        // for(const VerifyAttr & t: verifys ) { node->delete_verify( t );}
-
-        BOOST_REQUIRE_MESSAGE(node->zombies().empty(), "Expected all zombies to be deleted");
-        // BOOST_REQUIRE_MESSAGE( node->verifys().empty(),"Expected all verifys to be deleted");
-    }
-}
-
-void add_some_attributes(defs_ptr defs) {
-    std::vector<task_ptr> tasks;
-    defs->get_all_tasks(tasks);
-    for (task_ptr task : tasks) {
-        SuiteChanged1 changed(task->suite());
-        task->addDay(DayAttr(DayAttr::TUESDAY));
-    }
-}
-
-void begin(defs_ptr defs) {
-    defs->beginAll();
-} // reset all attributes
-
-void add_alias(defs_ptr defs) {
-
-    std::vector<task_ptr> tasks;
-    defs->get_all_tasks(tasks);
-    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
-
-    SuiteChanged1 changed(tasks[0]->suite());
-    tasks[0]->add_alias_only();
-}
-
-void remove_all_aliases(defs_ptr defs) {
-
-    std::vector<alias_ptr> aliases;
-    defs->get_all_aliases(aliases);
-    BOOST_REQUIRE_MESSAGE(!aliases.empty(), "Expected at least one alias");
-
-    for (alias_ptr alias : aliases) {
-        TestHelper::invokeRequest(defs.get(), Cmd_ptr(new DeleteCmd(alias->absNodePath())));
-    }
-
-    aliases.clear();
-    defs->get_all_aliases(aliases);
-    BOOST_REQUIRE_MESSAGE(aliases.empty(), "Expected at no  alias");
-}
-
-void remove_all_tasks(defs_ptr defs) {
-
-    // Remove tasks should force a incremental sync
-    std::vector<task_ptr> tasks;
-    defs->get_all_tasks(tasks);
-    for (task_ptr task : tasks) {
-        SuiteChanged1 changed(task->suite());
-        task->remove();
-    }
-
-    tasks.clear();
-    defs->get_all_tasks(tasks);
-    BOOST_REQUIRE_MESSAGE(tasks.empty(), "Failed to delete tasks");
-}
-
-void remove_a_family(defs_ptr defs) {
-
-    // Remove tasks should force a incremental sync
-    std::vector<Family*> vec;
-    defs->getAllFamilies(vec);
-    size_t family_size = vec.size();
-    BOOST_REQUIRE_MESSAGE(!vec.empty(), "Expected at least one family");
-    if (!vec.empty()) {
-        SuiteChanged1 changed(vec[0]->suite());
-        vec[0]->remove();
-    }
-
-    vec.clear();
-    defs->getAllFamilies(vec);
-    BOOST_REQUIRE_MESSAGE(vec.size() < family_size, "Failed to delete family");
-}
-
-void change_clock_gain(defs_ptr defs) {
-    for (suite_ptr suite : defs->suiteVec()) {
-        if (suite->clockAttr().get()) {
-            SuiteChanged changed(suite);
-            suite->changeClockGain("100001");
-        }
-    }
-}
-void change_clock_type_to_real(defs_ptr defs) {
-
-    for (suite_ptr suite : defs->suiteVec()) {
-        if (suite->clockAttr().get()) {
-            SuiteChanged changed(suite);
-            suite->changeClockType("real");
-        }
-    }
-}
-void change_clock_type_to_hybrid(defs_ptr defs) {
-
-    for (suite_ptr suite : defs->suiteVec()) {
-        if (suite->clockAttr().get()) {
-            SuiteChanged changed(suite);
-            suite->changeClockType("hybrid");
-        }
-    }
-}
-void change_clock_date(defs_ptr defs) {
-
-    for (suite_ptr suite : defs->suiteVec()) {
-        if (suite->clockAttr().get()) {
-            SuiteChanged changed(suite);
-            suite->changeClockDate("1.1.2001");
-        }
-    }
-}
-void change_clock_sync(defs_ptr defs) {
-
-    for (suite_ptr suite : defs->suiteVec()) {
-        if (suite->clockAttr().get()) {
-            SuiteChanged changed(suite);
-            suite->changeClockSync();
-        }
-    }
-}
-
-/// This has been split into two functions, as changing both together could mask an error
-/// i.e found bug where we forgot to update state_change number when changing the limit
-/// max value, however because we had, changed value as well it got masked.
-void change_limit_max(defs_ptr defs) {
-
-    for (suite_ptr s : defs->suiteVec()) {
-        std::vector<limit_ptr> theLimits = s->limits();
-        for (limit_ptr l : theLimits) {
-            // std::cout << "found " << l->toString() << "\n";
-            TestHelper::invokeRequest(defs.get(),
-                                      Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_MAX, l->name(), "90")));
-            limit_ptr v = s->find_limit(l->name());
-            BOOST_CHECK_MESSAGE(v.get() && v->theLimit() == 90, "expected to find limit with max value of 90");
-        }
-    }
-}
-void change_limit_value(defs_ptr defs) {
-
-    for (suite_ptr s : defs->suiteVec()) {
-        std::vector<limit_ptr> theLimits = s->limits();
-        for (limit_ptr l : theLimits) {
-            TestHelper::invokeRequest(defs.get(),
-                                      Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_VAL, l->name(), "33")));
-            limit_ptr v = s->find_limit(l->name());
-            BOOST_CHECK_MESSAGE(v.get() && v->value() == 33, "expected to find limit with value of 33");
-        }
-    }
-}
-
-void update_repeat(defs_ptr defs) {
-
-    std::vector<Node*> nodes;
-    defs->getAllNodes(nodes);
-
-    for (Node* n : nodes) {
-        if (!n->repeat().empty()) {
-            SuiteChanged1 changed(n->suite());
-            n->increment_repeat();
-        }
-    }
-}
-
-void update_calendar(defs_ptr defs) {
-
-    // The calendar is *only* updated if the suite have been begun. Hence make sure this test scaffold
-    // starts the test, with all the suites in a begun state
-    CalendarUpdateParams p(Calendar::second_clock_time(), minutes(1), true /* server running */, false /* for Test*/);
-    defs->updateCalendar(p);
-
-    // Currently updating the calendar, does not cause change, Hence force a change
-    for (suite_ptr suite : defs->suiteVec()) {
-        SuiteChanged changed(suite);
-        suite->add_variable("name", "value");
-    }
-
-    // Note: In the real server, persisting that calendar, the clock type is not persisted.
-    //       i.e when we have hybrid calendar, when restored on the client side it will be 'real' clock since
-    //       that is the default now. This is not correct and will fail invariant checking.
-    //       however the memento should reset clock type on the calenadar form the clok attribute.
-}
-
-void delete_suite(defs_ptr defs) {
-    std::vector<suite_ptr> vec = defs->suiteVec();
-    BOOST_REQUIRE_MESSAGE(!vec.empty(), "Expected suites");
-    vec[0]->remove();
-}
-
-void set_server_state_shutdown(defs_ptr defs) {
-    defs->set_server().set_state(SState::SHUTDOWN);
-}
-void set_server_state_running(defs_ptr defs) {
-    defs->set_server().set_state(SState::RUNNING);
-}
-
-void add_server_variable(defs_ptr defs) {
-    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "_fred_", "value")));
-}
-void change_server_variable(defs_ptr defs) {
-    // Because the scaffold create client/server defs each time.
-    // To test change/delete variables we modify the default set
-    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::VARIABLE, "ECF_TRIES", "4")));
-}
-void delete_server_variable(defs_ptr defs) {
-    // Because the scaffold create client/server defs each time.
-    // To test change/delete variables we modify the default set
-    // ***NOTE*** we cannot delete server variables like ECF_TRIES, can only change them
-    // However we can delete user variables added to the server
-    TestHelper::invokeRequest(defs.get(),
-                              Cmd_ptr(new AlterCmd("/", AlterCmd::DEL_VARIABLE, "MyDefsFixture_user_variable")));
-}
-
-void reorder_suites(defs_ptr defs) {
-    std::vector<suite_ptr> suiteVec = defs->suiteVec();
-    BOOST_REQUIRE_MESSAGE(!suiteVec.empty(), "Expected suites");
-    std::string path = "/" + suiteVec[0]->name();
-    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new OrderNodeCmd(path, NOrder::ALPHA)));
-}
-
-void move_peers(defs_ptr defs) {
-    std::vector<suite_ptr> suiteVec = defs->suiteVec();
-    BOOST_REQUIRE_MESSAGE(suiteVec.size() >= 2, "Expected suites");
-    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new PlugCmd(suiteVec[0]->absNodePath(), suiteVec[1]->absNodePath())));
-}
-void move_peers1(defs_ptr defs) {
-    std::vector<suite_ptr> suiteVec = defs->suiteVec();
-    BOOST_REQUIRE_MESSAGE(suiteVec.size() >= 2, "Expected suites");
-    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new PlugCmd(suiteVec[1]->absNodePath(), suiteVec[0]->absNodePath())));
-}
-
-void set_defs_flag(defs_ptr defs) {
-    defs->flag().set(ecf::Flag::MESSAGE);
-}
-
-void set_defs_state(defs_ptr defs) {
-    defs->set_state(NState::ABORTED);
-}
-
-BOOST_AUTO_TEST_CASE(test_ssync_cmd) {
-    // To DEBUG: enable the defines in Memento.hpp
-    cout << "Base:: ...test_ssync_cmd\n";
-    TestLog test_log("test_ssync_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    test_sync_scaffold(update_repeat, "update_repeat");
-    test_sync_scaffold(delete_some_attributes, "delete_some_attributes");
-    test_sync_scaffold(delete_time_attributes, "delete_time_attributes");
-    test_sync_scaffold(delete_misc_attributes, "delete_misc_attributes");
-    test_sync_scaffold(add_some_attributes, "add_some_attributes");
-    test_sync_scaffold(begin, "begin", true /* expect full_sync */);
-    test_sync_scaffold(add_alias, "add_alias");
-    test_sync_scaffold(remove_all_aliases, "remove_all_aliases");
-    test_sync_scaffold(remove_all_tasks, "remove_all_tasks");
-    test_sync_scaffold(remove_a_family, "remove_a_family");
-    test_sync_scaffold(change_clock_gain, "change_clock_gain", true /* expect full_sync */);
-    test_sync_scaffold(change_clock_type_to_real, "change_clock_type_to_real", true /* expect full_sync */);
-    test_sync_scaffold(change_clock_type_to_hybrid, "change_clock_type_to_hybrid", true /* expect full_sync */);
-    test_sync_scaffold(change_clock_date, "change_clock_date", true /* expect full_sync */);
-    test_sync_scaffold(change_clock_sync, "change_clock_sync", true /* expect full_sync */);
-    test_sync_scaffold(
-        update_calendar, "update_calendar", false /* expect full_sync */, true /* start test with begin */);
-    test_sync_scaffold(change_limit_max, "change_limit_max");
-    test_sync_scaffold(change_limit_value, "change_limit_value");
-    test_sync_scaffold(delete_suite, "delete_suite", true /* expect full_sync */);
-
-    // Test Changes in Defs
-    // The default server state is HALTED, hence setting to halted will not show a change
-    test_sync_scaffold(set_server_state_shutdown, "set_server_state_shutdown");
-    test_sync_scaffold(set_server_state_running, "set_server_state_running");
-
-    test_sync_scaffold(add_server_variable, "add_server_variable");
-    test_sync_scaffold(change_server_variable, "change_server_variable");
-    test_sync_scaffold(delete_server_variable, "delete_server_variable");
-
-    test_sync_scaffold(reorder_suites, "reorder_suites");
-    test_sync_scaffold(move_peers, "move_peers");
-    test_sync_scaffold(move_peers1, "move_peers1");
-
-    test_sync_scaffold(set_defs_flag, "set_defs_flag");
-    test_sync_scaffold(set_defs_state, "set_defs_state");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestSSyncCmdOrder.cpp 5.13.0-1/Base/test/TestSSyncCmdOrder.cpp
--- 5.12.4-1/Base/test/TestSSyncCmdOrder.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestSSyncCmdOrder.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,254 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MockServer.hpp"
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
-#include "ecflow/base/stc/SSyncCmd.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// The client handle commands do not change state & modify change number, hence need to bypass these checks
-static bool bypass_state_modify_change_check = false;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_SSyncCmdOrder)
-
-/// define a function which returns nothing, and takes a defs_ptr parameter
-typedef boost::function<void(defs_ptr)> defs_change_cmd;
-
-static std::vector<std::string> vector_abcd() {
-    std::vector<std::string> names;
-    names.reserve(4);
-    names.emplace_back("a");
-    names.emplace_back("b");
-    names.emplace_back("c");
-    names.emplace_back("d");
-    return names;
-}
-static std::vector<std::string> vector_dcba() {
-    std::vector<std::string> names;
-    names.reserve(4);
-    names.emplace_back("d");
-    names.emplace_back("c");
-    names.emplace_back("b");
-    names.emplace_back("a");
-    return names;
-}
-
-static defs_ptr create_defs() {
-    std::vector<std::string> names = vector_dcba();
-    defs_ptr defs                  = Defs::create();
-    for (size_t j = 0; j < names.size(); j++) {
-        suite_ptr s = defs->add_suite(names[j]);
-        if (0 == j) { // only add family to first suite
-            for (size_t k = 0; k < names.size(); k++) {
-                family_ptr f = s->add_family(names[k]);
-                for (const auto& name : names) {
-                    task_ptr t = f->add_task(name);
-                    //               t->add_alias_only(); // alias0
-                    //               t->add_alias_only(); // alias1
-                    //               t->add_alias_only(); // alias2
-                }
-            }
-        }
-    }
-    return defs;
-}
-
-/// Re-use the same test scaffold to modify and then resync, by passing in a function that will modify the defs
-static void test_sync_scaffold(defs_change_cmd the_defs_change_command,
-                               unsigned int test_equality, /*0 means test equality, any other number test size*/
-                               bool full_sync,
-                               unsigned int client_handle) {
-    defs_ptr server_defs = create_defs();
-    ServerReply server_reply;
-    server_reply.set_client_defs(create_defs());
-
-    Ecf::set_debug_equality(true); // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
-                        "Starting point client and server defs should be the same");
-    Ecf::set_debug_equality(false); // only has affect in DEBUG build
-
-    // Get change number before any changes
-    Ecf::set_state_change_no(0);
-    Ecf::set_modify_change_no(0);
-    unsigned int client_state_change_no  = Ecf::state_change_no();
-    unsigned int client_modify_change_no = Ecf::modify_change_no();
-
-    // make some change to the server
-    {
-        Ecf::set_server(true);
-
-        the_defs_change_command(server_defs);
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(errorMsg), "Invariants failed " << errorMsg);
-        BOOST_REQUIRE_MESSAGE(!(*server_reply.client_defs() == *server_defs),
-                              "Expected client and server defs to differ " << *server_reply.client_defs() << "\n"
-                                                                           << "server defs   = " << *server_defs);
-        Ecf::set_server(false);
-    }
-
-    //   cout << "test_sync_scaffold AFTER Command before SYNC: Server:\n" << *server_defs << "\n";
-    //   cout << "test_sync_scaffold AFTER Command before SYNC: Client:\n" << *server_reply.client_defs() << "\n";
-
-    MockServer mock_server(server_defs);
-    SSyncCmd cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
-    string error_msg;
-    BOOST_REQUIRE_MESSAGE(mock_server.defs()->checkInvariants(error_msg), error_msg);
-    BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), "Expected server to change");
-    BOOST_CHECK_MESSAGE(server_reply.in_sync(), "Expected to be in sync");
-    BOOST_CHECK_MESSAGE(server_reply.full_sync() == full_sync, "Expected full sync");
-
-    DebugEquality debug_equality; // only has affect in DEBUG build
-    if (0 == test_equality) {
-        BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(), "Server and client should be same after sync");
-    }
-    else {
-        BOOST_CHECK_MESSAGE(server_reply.client_defs()->suiteVec().size() == test_equality,
-                            "Expected suite of size " << test_equality << " but found "
-                                                      << server_reply.client_defs()->suiteVec().size());
-    }
-}
-
-static void reorder_suites(defs_ptr theDefs) {
-
-    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/a", NOrder::ALPHA)));
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec()) == vector_abcd(),
-                          "NOrder::ALPHA expected "
-                              << ecf::algorithm::join(vector_abcd()) << " but found: "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec())));
-}
-
-static void reorder_family(defs_ptr theDefs) {
-    //   std::cout << "reorder_family\n" << *theDefs << "\n";
-
-    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/d/d", NOrder::ALPHA)));
-
-    std::vector<Family*> families;
-    theDefs->findSuite("d")->getAllFamilies(families);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(families) == vector_abcd(),
-                          "NOrder::ALPHA  expected "
-                              << ecf::algorithm::join(vector_abcd()) << " but found: "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(families)));
-}
-
-static void reorder_task(defs_ptr theDefs) {
-    // std::cout << "reorder_task\n" << *theDefs << "\n";
-
-    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/d/d/d", NOrder::ALPHA)));
-
-    std::vector<Task*> tasks;
-    theDefs->findAbsNode("/d/d")->getAllTasks(tasks);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(tasks) == vector_abcd(),
-                          "NOrder::ALPHA  expected "
-                              << ecf::algorithm::join(vector_abcd()) << " but found: "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(tasks)));
-}
-
-// static void reorder_alias(defs_ptr theDefs) {
-//    //std::cout << "reorder_task\n" << *theDefs << "\n";
-//
-//    TestHelper::invokeRequest(theDefs.get(),Cmd_ptr( new OrderNodeCmd("/d/d/d/alias0",NOrder::ALPHA)));
-//
-//    std::vector<alias_ptr> aliases;
-//    theDefs->findAbsNode("/d/d/d")->get_all_aliases(aliases);
-//    BOOST_REQUIRE_MESSAGE( ecf::algorithm::transform_to_name_vector(aliases) == vector_abcd(),"NOrder::ALPHA  expected
-//    " << ecf::algorithm::join(vector_abcd())<< " but found: " <<
-//    ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(tasks)));
-// }
-
-static void reorder_suites_using_handles(defs_ptr theDefs) {
-
-    // *** NOTE ****: Whenever we register a handle, we get a *FULL* sync
-
-    // create client handle which references all the suites
-    // It should be noted that invokeRequest, uses a MockServer, which set/unsets
-    // Hence after this call Ecf::server_ is false. Hence we need to ensure that following
-    // commands/ DM function set Ecf::server_ to true.
-    std::vector<std::string> suite_names = vector_abcd();
-    TestHelper::invokeRequest(
-        theDefs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
-    BOOST_CHECK_MESSAGE(theDefs->client_suite_mgr().clientSuites().size() == 1,
-                        "Expected 1 Client suites but found " << theDefs->client_suite_mgr().clientSuites().size());
-
-    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/a", NOrder::ALPHA)));
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec()) == vector_abcd(),
-                          "NOrder::ALPHA  expected "
-                              << ecf::algorithm::join(vector_abcd()) << " but found: "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec())));
-}
-
-static void reorder_family_using_handles(defs_ptr theDefs) {
-
-    // *** NOTE ****: Whenever we register a handle, we get a *FULL* sync
-
-    // create client handle which references all the suites
-    // It should be noted that invokeRequest, uses a MockServer, which set/unsets
-    // Hence after this call Ecf::server_ is false. Hence we need to ensure that following
-    // commands/ DM function set Ecf::server_ to true.
-    std::vector<std::string> suite_names;
-    suite_names.emplace_back("d"); // clinet handle for suite 'd' ONLY
-    TestHelper::invokeRequest(
-        theDefs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
-    BOOST_CHECK_MESSAGE(theDefs->client_suite_mgr().clientSuites().size() == 1,
-                        "Expected 1 Client suites but found " << theDefs->client_suite_mgr().clientSuites().size());
-
-    /// Don't call, data model function directly, since Ecf::server_ is false. *here*
-    /// The suite should stay the same, only suite d's family should change
-    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/d/d", NOrder::ALPHA)));
-    BOOST_REQUIRE_MESSAGE(
-        ecf::algorithm::transform_to_name_vector(theDefs->suiteVec()) == vector_dcba(),
-        "expected " << ecf::algorithm::join(vector_dcba()) << " but found: "
-                    << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec())));
-
-    suite_ptr suite_a = theDefs->findSuite("d");
-    std::vector<Family*> families;
-    suite_a->getAllFamilies(families);
-    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(families) == vector_abcd(),
-                          "NOrder::ALPHA  expected "
-                              << ecf::algorithm::join(vector_abcd()) << " but found: "
-                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(families)));
-}
-
-BOOST_AUTO_TEST_CASE(test_ssync_cmd_test_order) {
-    cout << "Base:: ...test_ssync_cmd_test_order\n";
-    TestLog test_log(
-        "test_ssync_cmd_test_order.log"); // will create log file, and destroy log and remove file at end of scope
-
-    test_sync_scaffold(reorder_suites, 0 /* test equality */, false /* expect full_sync */, 0);
-    test_sync_scaffold(reorder_family, 0 /* test equality */, false /* expect full_sync */, 0);
-    test_sync_scaffold(reorder_task, 0 /* test equality */, false /* expect full_sync */, 0);
-    //   test_sync_scaffold(reorder_alias,  0 /* test equality */, false /* expect full_sync */, 0);
-
-    test_sync_scaffold(
-        reorder_suites_using_handles, 0 /* test equality */, true /* expect full_sync */, 1 /* client handle */);
-    test_sync_scaffold(
-        reorder_family_using_handles, 1 /* test size     */, true /* expect full_sync */, 1 /* client handle */);
-
-    /// Keep valgrind happy
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestSSyncCmd_CH1.cpp 5.13.0-1/Base/test/TestSSyncCmd_CH1.cpp
--- 5.12.4-1/Base/test/TestSSyncCmd_CH1.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestSSyncCmd_CH1.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,714 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MockServer.hpp"
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-#include "ecflow/base/stc/SNewsCmd.hpp"
-#include "ecflow/base/stc/SSyncCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/SuiteChanged.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-/// This test, is used to check sync with the client handles.
-/// The client handles will register interest in a set of suites
-/// When calling sync, check will only receive notification on our
-/// our suites
-// In particular when a set of suites are registered to a handle
-// and we add/delete/check point/order the server passes back to the client
-// the a *new* defs with all the suites corresponding to the handle
-// There is a complication however, the suite are not copied/cloned
-// This causes a problem, since if we create a new defs, and add
-// the suites, the suite defs pointer is *NOW* corrupted, as it will point
-// to the new defs. This is not an issue in real apps, since searisation
-// fixes up these ptrs.
-
-// The client handle commands do not change state & modify change number, hence need to bypass these checks
-static bool bypass_state_modify_change_check = false;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_SSyncCmd_CH1)
-
-static defs_ptr create_client_defs(defs_ptr defs) {
-    for (size_t j = 0; j < 5; j++) {
-        suite_ptr suite = defs->add_suite("s" + ecf::convert_to<std::string>(j));
-        family_ptr f    = suite->add_family("f");
-        f->add_task("t");
-        if (j == 0) {
-            suite->addLimit(Limit("suiteLimit", 10));
-            suite->addRepeat(RepeatDate("YMD", 20090916, 20090916, 1));
-        }
-    }
-    return defs;
-}
-
-static defs_ptr create_server_defs() {
-    defs_ptr defs = Defs::create();
-
-    // Create server defs, with a port other than default.
-    // This allows additional testing. i.e server variables
-    std::vector<Variable> server_variables;
-    ServerState::setup_default_server_variables(server_variables, "3141");
-    defs->set_server().set_server_variables(server_variables);
-
-    // ensure client/server start out the same
-    return create_client_defs(defs);
-}
-
-/// define a function which returns nothing, and takes a defs_ptr parameter
-typedef boost::function<bool(defs_ptr)> defs_change_cmd;
-
-/// Re-use the same test scaffold to modify and then resync, by passing
-/// in a function that will modify the defs
-void test_sync_scaffold(defs_change_cmd the_defs_change_command, const std::string& test_name, bool full_sync = false) {
-    // Create the defs
-    defs_ptr server_defs = create_server_defs();
-    ServerReply server_reply;
-    server_reply.set_client_defs(create_client_defs(Defs::create()));
-
-    Ecf::set_debug_equality(true); // only has affect in DEBUG build
-    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
-                        test_name << ": Starting point client and server defs should be the same : "
-                                  << "SERVER\n"
-                                  << server_defs << "CLIENT\n"
-                                  << server_reply.client_defs());
-    Ecf::set_debug_equality(false); // only has affect in DEBUG build
-
-    // set handle and change numbers, before any changes
-    Ecf::set_state_change_no(0);
-    Ecf::set_modify_change_no(0);
-    unsigned int client_state_change_no  = Ecf::state_change_no();
-    unsigned int client_modify_change_no = Ecf::modify_change_no();
-    unsigned int client_handle           = 0;
-
-    bool expected_change;
-
-    // make some change to the server
-    {
-        /// create client handle which references suites s0 and s4, in the server defs
-        /// Registering suites should change handle_changed boolean
-        std::vector<std::string> suite_names;
-        suite_names.emplace_back("s0");
-        suite_names.emplace_back("s4");
-        TestHelper::invokeRequest(
-            server_defs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
-
-        BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().clientSuites().size() == 1,
-                            test_name << ": Expected 1 Client suites but found "
-                                      << server_defs->client_suite_mgr().clientSuites().size());
-        client_handle = server_defs->client_suite_mgr().clientSuites().front().handle();
-        BOOST_CHECK_MESSAGE(client_handle == 1, "");
-
-        /// Check that handle_changed set, required for syncing, i.e needed for full sync , without change state/modify
-        /// numbers
-        BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().handle_changed(client_handle) == true,
-                            "Expected handle_changed to be set when suites are registered ");
-
-        /// called create Defs should clear the flag. make sure server state, is synced
-        defs_ptr the_client_defs = server_defs->client_suite_mgr().create_defs(client_handle, server_defs);
-        BOOST_CHECK_MESSAGE(the_client_defs->suiteVec().size() == 2, test_name << ": Expected 2 suites");
-        BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().handle_changed(client_handle) == false,
-                            test_name << ": Expected handle_changed to be cleared after create_defs()");
-        BOOST_CHECK_MESSAGE(server_defs->server().compare(the_client_defs->server()),
-                            test_name << ": Server state does not match");
-
-        Ecf::set_server(true);
-        expected_change = the_defs_change_command(server_defs);
-        std::string error_msg;
-        BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(error_msg),
-                              test_name << ": Invariants failed: " << error_msg);
-        Ecf::set_server(false);
-
-        /// Call create defs again, after change in server defs, check server state is synced
-        the_client_defs = server_defs->client_suite_mgr().create_defs(client_handle, server_defs);
-        BOOST_CHECK_MESSAGE(server_defs->server().compare(the_client_defs->server()),
-                            test_name << ": Server state does not match");
-        BOOST_CHECK_MESSAGE(server_defs->get_flag() == the_client_defs->get_flag(),
-                            test_name << ": Server flags do not match");
-    }
-
-    MockServer mock_server(server_defs);
-    SNewsCmd news_cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
-    SSyncCmd cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
-
-    if (expected_change) {
-        BOOST_CHECK_MESSAGE(news_cmd.get_news(), test_name << " : get_news : Expected server to change");
-        BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), test_name << " : do_sync : Expected server to change");
-        BOOST_CHECK_MESSAGE(server_reply.in_sync(), test_name << " : in_sync : Expected client server to be in sync");
-        BOOST_CHECK_MESSAGE(server_reply.full_sync() == full_sync,
-                            test_name << ": Expected sync not as expected. client: " << server_reply.full_sync()
-                                      << " full_sync: " << full_sync);
-        BOOST_CHECK_MESSAGE(server_defs->state() == server_reply.client_defs()->state(),
-                            test_name << ": Expected server State(" << NState::toString(server_defs->state())
-                                      << ") to be same as client state("
-                                      << NState::toString(server_reply.client_defs()->state()) << ")");
-        if (full_sync) {
-            Ecf::set_debug_equality(true); // only has affect in DEBUG build
-            BOOST_CHECK_MESSAGE(server_defs->server().compare(server_reply.client_defs()->server()),
-                                test_name << ": Server state does not match");
-        }
-
-        // * Note we expect client defs to fail invariant checking when doing a full sync with handles
-        // * Under real server this should be ok since, we fix up the defs ptr, during serialisation
-
-        // * note. We can't really compare server and client defs, since when we sync with
-        // * with handles, we only return a sub set of the suites, in our handle
-
-        // DO a sync again. hence we should expect no changes
-        server_reply.clear_for_invoke(false);
-        Ecf::set_server(true);
-        /* server side */ SNewsCmd news_cmd1(client_handle,
-                                             server_reply.client_defs()->state_change_no(),
-                                             server_reply.client_defs()->modify_change_no(),
-                                             &mock_server);
-        /* server side */ SSyncCmd cmd1(client_handle,
-                                        server_reply.client_defs()->state_change_no(),
-                                        server_reply.client_defs()->modify_change_no(),
-                                        &mock_server);
-        Ecf::set_server(false);
-        /* client side */ BOOST_CHECK_MESSAGE(!news_cmd1.get_news(),
-                                              test_name << ": Expected no changes to client, we should be in sync");
-        /* client side */ BOOST_CHECK_MESSAGE(!cmd1.do_sync(server_reply),
-                                              test_name << ": Expected no changes to client, we should be in sync");
-    }
-    else {
-
-        BOOST_CHECK_MESSAGE(!news_cmd.get_news(), test_name << ": Expected no change");
-        BOOST_CHECK_MESSAGE(!cmd.do_sync(server_reply), test_name << ": Expected no change");
-        BOOST_CHECK_MESSAGE(!server_reply.in_sync(), test_name << ": Expected no change");
-        BOOST_CHECK_MESSAGE(!(*server_defs == *server_reply.client_defs()),
-                            test_name << ": Server and client defs expected to differ");
-    }
-}
-
-static bool set_server_state_shutdown(defs_ptr defs) {
-    defs->set_server().set_state(SState::SHUTDOWN);
-    return true; // expect changes
-}
-static bool set_server_state_running(defs_ptr defs) {
-    defs->set_server().set_state(SState::RUNNING);
-    return true; // expect changes
-}
-
-static bool set_defs_flag(defs_ptr defs) {
-    defs->flag().set(ecf::Flag::BYRULE);
-    defs->flag().set(ecf::Flag::EDIT_FAILED);
-    return true; // expect changes
-}
-
-static bool change_suites_s3_outside_of_handle(defs_ptr defs) {
-    /// Make a state change to suites s3, in the server. This is *not* in the client handle
-    /// Note: we do *NOT* make a state change as this will be propagated to the defs, and hence will be synced
-    /// We *NEED* MockSuiteChangedServer, so that change is propagated to the suite.
-    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
-    defs->findSuite("s3")->suspend();                         // small scale state change
-    return false;                                             // expect no changes
-}
-
-static bool change_suites_s3_outside_of_handle_add_variable(defs_ptr defs) {
-    /// make a state change to suites s3, in the server. This is *not* in the client handle
-    /// We *NEED* MockSuiteChangedServer, so that change is propagated to the suite.
-    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
-    defs->findSuite("s3")->add_variable("Var", "value");      // small scale state change
-    return false;                                             // expect no changes in sync
-}
-
-static bool add_task_to_suite_s3(defs_ptr defs) {
-    /// make a modify change to suites s3, in the server. This is *not* in the client handle
-    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
-    defs->findSuite("s3")->addTask(Task::create("s3_task"));  // small scale change
-    return false;                                             //  expect no changes, since suite s3 not in handle
-}
-
-static bool delete_task_on_suite_s3(defs_ptr defs) {
-    /// make a modify change to suites s3, in the server. This is *not* in the client handle
-    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
-    defs->findAbsNode("/s3/f/t")->remove();                   // small scale change
-    return false;                                             // expect no changes, since suite s3 not in handle
-}
-static bool delete_family_on_suite_s3(defs_ptr defs) {
-    /// make a modify change to suites s3, in the server. This is *not* in the client handle
-    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
-    defs->findAbsNode("/s3/f")->remove();                     // small scale change
-    return false;                                             // expect no changes, since suite s3 not in handle
-}
-
-static bool change_state_of_s4(defs_ptr defs) {
-    /// Ok now make state change to s4, which **is** in the handle
-    /// We need MockSuiteChangedServer, so that change is propagated to the suite.
-    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
-    defs->findSuite("s4")->set_state(NState::SUBMITTED);      // small scale change
-    return true;                                              // expect changes
-}
-
-static bool add_variable_to_suite_s4(defs_ptr defs) {
-    /// Ok now make state change to s4, which **is** in the handle
-    /// We need MockSuiteChangedServer, so that change is propagated to the suite.
-    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
-    defs->findSuite("s4")->add_variable("Var", "value");      // small scale state change
-    return true;                                              // expect changes
-}
-
-static bool add_server_user_variables(defs_ptr defs) {
-    // Change server. This is outside of any suites
-    std::vector<Variable> user_variables;
-    user_variables.emplace_back("a", "b");
-    user_variables.emplace_back("c", "d");
-    defs->set_server().set_user_variables(user_variables);
-    return true; // expect change
-}
-
-static bool add_task_to_suite_s4(defs_ptr defs) {
-    /// Ok now make modify change to s4, which **is** in the handle
-    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
-    defs->findSuite("s4")->addTask(Task::create("s4_task"));  // small scale change
-    return true;                                              // expect changes
-}
-
-static bool delete_task_on_suite_s4(defs_ptr defs) {
-    /// Ok now make modify change to s4, which **is** in the handle
-    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
-    defs->findAbsNode("/s4/f/t")->remove();                   // small scale change
-    return true;                                              // expect changes, since suite s4 is in handle
-}
-
-static bool delete_family_on_suite_s4(defs_ptr defs) {
-    /// Ok now make modify change to s4, which **is** in the handle
-    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
-    defs->findAbsNode("/s4/f")->remove();                     // small scale change
-    return true;                                              // expect changes, since suite s4 is in handle
-}
-
-static bool change_order_of_s4_top(defs_ptr defs) {
-    /// Ok make modify change to s4, which **is** in the handle
-    suite_ptr s4 = defs->findSuite("s4");
-    MockSuiteChangedServer mockServer(s4); // Increment suite state/modify change number
-    defs->order(s4.get(), NOrder::TOP);    // small scale scale change
-    return true;
-}
-
-static bool change_order_of_s4_bottom(defs_ptr defs) {
-    /// Ok make modify change to s4, which **is** in the handle
-    suite_ptr s4 = defs->findSuite("s4");
-    MockSuiteChangedServer mockServer(s4); // Increment suite state/modify change number
-    defs->order(s4.get(), NOrder::BOTTOM); // small scale change
-    return true;
-}
-
-static bool delete_suite_s4(defs_ptr defs) {
-    /// Ok now make delete s4 which, which **is** in the handle
-    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
-    defs->findSuite("s4")->remove();                          // large scale change
-    return true;                                              // expect changes
-}
-
-static bool set_defs_state(defs_ptr defs) {
-    defs->set_state(NState::ABORTED); // changes the defs state
-    return true;                      // expect changes
-}
-
-static bool set_defs_state_2(defs_ptr defs) {
-    defs->set_state(NState::ABORTED); // changes the defs state
-    return delete_suite_s4(defs);     // large scale change
-}
-
-static bool add_server_variable(defs_ptr defs) {
-    // Change defs server state. small scale change
-    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "_fred_", "value")));
-    return true;
-}
-
-static bool change_server_variable(defs_ptr defs) {
-    // Because the scaffold create client/server defs each time.
-    // To test change/delete variables we modify the default set
-    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::VARIABLE, "ECF_TRIES", "4")));
-    return true;
-}
-
-// ===============================================================================
-// The modifiers, do this for suite s0 which is in a handle
-// ===============================================================================
-
-static bool s0_delete_some_attributes(defs_ptr defs) {
-    /// Ok now make state change to s4, which **is** in the handle
-    /// We need MockSuiteChangedServer, so that change is propagated to the suite.
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    std::vector<Task*> tasks;
-    suite->getAllTasks(tasks);
-    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
-
-    for (Task* task : tasks) {
-        SuiteChanged1 changed(task->suite());
-        task->addMeter(Meter("meter", 0, 100));
-    }
-    return true;
-}
-
-static bool s0_add_some_attributes(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    std::vector<task_ptr> tasks;
-    suite->get_all_tasks(tasks);
-    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
-
-    for (task_ptr task : tasks) {
-        SuiteChanged1 changed(suite.get());
-        task->addDay(DayAttr(DayAttr::TUESDAY));
-    }
-    return true;
-}
-
-static bool s0_begin(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    suite->begin();
-    return true;
-}
-
-static bool s0_add_alias(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    std::vector<task_ptr> tasks;
-    suite->get_all_tasks(tasks);
-    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
-
-    SuiteChanged1 changed(tasks[0]->suite());
-    tasks[0]->add_alias_only();
-    return true;
-}
-
-static bool s0_remove_all_tasks(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    // Remove tasks should force a incremental sync
-    std::vector<task_ptr> tasks;
-    suite->get_all_tasks(tasks);
-    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
-    for (task_ptr task : tasks) {
-        SuiteChanged1 changed(task->suite());
-        task->remove();
-    }
-
-    tasks.clear();
-    suite->get_all_tasks(tasks);
-    BOOST_REQUIRE_MESSAGE(tasks.empty(), "Failed to delete tasks");
-    return true;
-}
-
-static bool s0_remove_a_family(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    std::vector<Family*> vec;
-    suite->getAllFamilies(vec);
-    size_t family_size = vec.size();
-    BOOST_REQUIRE_MESSAGE(!vec.empty(), "Expected at least one family");
-    if (!vec.empty()) {
-        SuiteChanged1 changed(vec[0]->suite());
-        vec[0]->remove();
-    }
-
-    vec.clear();
-    suite->getAllFamilies(vec);
-    BOOST_REQUIRE_MESSAGE(vec.size() < family_size, "Failed to delete family");
-    return true;
-}
-
-static bool s0_change_clock_gain(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    suite->changeClockGain("100001");
-    return true;
-}
-
-static bool s0_change_clock_type_to_real(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    suite->changeClockType("hybrid");
-    return true;
-}
-
-static bool s0_change_clock_date(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-
-    suite->changeClockDate("1.1.2001");
-    return true;
-}
-
-static bool s0_change_clock_sync(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    suite->changeClockSync();
-    return true;
-}
-
-/// This has been split into two functions, as changing both together could mask an error
-/// i.e found bug where we forgot to update state_change number when changing the limit
-/// max value, however because we had, changed value as well it got masked.
-static bool s0_change_limit_max(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    // Note: we ONLY* need MockSuiteChangedServer, when we make changes via functions and not commands
-
-    std::vector<limit_ptr> theLimits = suite->limits();
-    BOOST_REQUIRE_MESSAGE(!theLimits.empty(), "The limit are empty on suite s0 " << defs);
-    for (limit_ptr l : theLimits) {
-        // std::cout << "found " << l->toString() << "\n";
-        TestHelper::invokeRequest(defs.get(),
-                                  Cmd_ptr(new AlterCmd(suite->absNodePath(), AlterCmd::LIMIT_MAX, l->name(), "90")));
-        limit_ptr v = suite->find_limit(l->name());
-        BOOST_CHECK_MESSAGE(v.get() && v->theLimit() == 90, "expected to find limit with max value of 90");
-    }
-    return true;
-}
-
-static bool s0_change_limit_value(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    // Note: we ONLY* need MockSuiteChangedServer, when we make changes via functions and not commands
-
-    std::vector<limit_ptr> theLimits = suite->limits();
-    for (limit_ptr l : theLimits) {
-        TestHelper::invokeRequest(defs.get(),
-                                  Cmd_ptr(new AlterCmd(suite->absNodePath(), AlterCmd::LIMIT_VAL, l->name(), "33")));
-        limit_ptr v = suite->find_limit(l->name());
-        BOOST_CHECK_MESSAGE(v.get() && v->value() == 33, "expected to find limit with value of 33");
-    }
-    return true;
-}
-
-static bool s0_update_repeat(defs_ptr defs) {
-    suite_ptr suite = defs->findSuite("s0");
-    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
-    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
-
-    SuiteChanged1 changed(suite.get());
-    suite->increment_repeat();
-    return true;
-}
-
-BOOST_AUTO_TEST_CASE(test_ssync_using_handle) {
-    cout << "Base:: ...test_ssync_using_handle\n";
-    TestLog test_log(
-        "test_ssync_using_handle.log"); // will create log file, and destroy log and remove file at end of scope
-
-    // =======================================================================================
-    // Note: where we update Suite::modify_change_no()  we should *EXPECT* a full sync
-    // =======================================================================================
-
-    // test_sync_scaffold will created 5 suites  s0,s1,s2,s3,s4,s5 and add suites s0 & s4 to a handle
-    // The following test will perform changes in/out of handles
-
-    { // Change defs state in the presence of handles. These should sync regardless of handles
-        // The default server state is HALTED, hence setting to halted will not show a change
-        test_sync_scaffold(set_server_state_shutdown, "set_server_state_shutdown");
-        test_sync_scaffold(set_server_state_running, "set_server_state_running");
-        test_sync_scaffold(set_defs_flag, "set_defs_flag");
-
-        test_sync_scaffold(add_server_variable, "add_server_variable");
-        test_sync_scaffold(change_server_variable, "change_server_variable");
-
-        test_sync_scaffold(set_defs_state, "set_defs_state");
-        test_sync_scaffold(set_defs_state_2, "set_defs_state_2", true /* expect a full sync */);
-    }
-
-    test_sync_scaffold(change_suites_s3_outside_of_handle, "change_suites_s3_outside_of_handle");
-    test_sync_scaffold(change_suites_s3_outside_of_handle_add_variable,
-                       "change_suites_s3_outside_of_handle_add_variable");
-    test_sync_scaffold(add_task_to_suite_s3, "add_task_to_suite_s3");
-    test_sync_scaffold(delete_task_on_suite_s3, "delete_task_on_suite_s3");
-    test_sync_scaffold(delete_family_on_suite_s3, "delete_family_on_suite_s3");
-
-    test_sync_scaffold(change_order_of_s4_top, "change_order_of_s4_top");       // change order is an incremental sync
-    test_sync_scaffold(change_order_of_s4_bottom, "change_order_of_s4_bottom"); // change order is an incremental sync
-
-    test_sync_scaffold(change_state_of_s4, "change_state_of_s4");
-    test_sync_scaffold(add_variable_to_suite_s4, "add_variable_to_suite_s4");
-    test_sync_scaffold(add_server_user_variables, "add_server_user_variables");
-    test_sync_scaffold(add_task_to_suite_s4, "add_task_to_suite_s4");
-    test_sync_scaffold(delete_task_on_suite_s4, "delete_task_on_suite_s4");
-    test_sync_scaffold(delete_family_on_suite_s4, "delete_family_on_suite_s4");
-    test_sync_scaffold(delete_suite_s4, "delete_suite_s4", true /* expect a full sync */);
-
-    test_sync_scaffold(s0_delete_some_attributes, "s0_delete_some_attributes");
-    test_sync_scaffold(s0_add_some_attributes, "s0_add_some_attributes");
-    test_sync_scaffold(s0_add_alias, "s0_add_alias");
-    test_sync_scaffold(s0_update_repeat, "s0_update_repeat");
-    test_sync_scaffold(s0_change_limit_max, "s0_change_limit_max");
-    test_sync_scaffold(s0_change_limit_value, "s0_change_limit_value");
-    test_sync_scaffold(s0_begin, "s0_begin", true /* expect a full sync */);
-
-    test_sync_scaffold(s0_remove_all_tasks, "s0_remove_all_tasks");
-    test_sync_scaffold(s0_remove_a_family, "s0_remove_a_family");
-
-    test_sync_scaffold(s0_change_clock_gain, "s0_change_clock_gain", true /* expect a full sync */);
-    test_sync_scaffold(s0_change_clock_type_to_real, "s0_change_clock_type_to_real", true /* expect a full sync */);
-    test_sync_scaffold(s0_change_clock_date, "s0_change_clock_date", true /* expect a full sync */);
-    test_sync_scaffold(s0_change_clock_sync, "s0_change_clock_sync", true /* expect a full sync */);
-}
-
-// =============================================================================================
-
-static defs_ptr create_the_server_defs() {
-    defs_ptr defs                    = create_server_defs();
-    std::vector<suite_ptr> suite_vec = defs->suiteVec();
-    for (size_t j = 0; j < suite_vec.size(); j++) {
-        suite_vec[j]->set_state_change_no(j);
-        suite_vec[j]->set_modify_change_no(j);
-    }
-    return defs;
-}
-
-BOOST_AUTO_TEST_CASE(test_ssync_full_sync_using_handle) {
-    /// This test checks that when user has registered with all the suites.
-    /// Syncing should use the global change numbers
-    /// **ADDITIONALLY* the newsCmd  must reflect this.
-    /// This is handled in ClientSuites::create_defs, in that we *MUST* update the
-    /// local change numbers to be the same as the global change numbers
-    /// This is important since the NewsCmd must be in *SYNC* with SYNCCmd
-
-    cout << "Base:: ...test_ssync_full_sync_using_handle\n";
-    TestLog test_log("test_ssync_full_sync_using_handle.log"); // will create log file, and destroy log and remove file
-                                                               // at end of scope
-
-    // Create the server defs with some changes, in state & modify numbers
-    defs_ptr server_defs = create_the_server_defs();
-
-    // Create Client defs, without any changes
-    ServerReply server_reply;
-    server_reply.set_client_defs(create_client_defs(Defs::create()));
-
-    // Server & client should be the same, since we ignore change numbers in the comparison
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
-                        "Starting point client and server defs should be the same"
-                            << "SERVER\n"
-                            << server_defs << "CLIENT\n"
-                            << server_reply.client_defs());
-
-    /// register interest in **ALL** the suites
-    std::vector<std::string> suite_names;
-    suite_names.emplace_back("s0");
-    suite_names.emplace_back("s1");
-    suite_names.emplace_back("s2");
-    suite_names.emplace_back("s3");
-    suite_names.emplace_back("s4");
-    TestHelper::invokeRequest(
-        server_defs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
-
-    /// make sure handle created.
-    BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().clientSuites().size() == 1,
-                        "Expected 1 Client suites but found " << server_defs->client_suite_mgr().clientSuites().size());
-    unsigned int client_handle = server_defs->client_suite_mgr().clientSuites().front().handle();
-    BOOST_CHECK_MESSAGE(client_handle == 1, "");
-
-    // make sure server suites have different state/modify numbers from the client
-    {
-        unsigned int server_state_change_no  = 0;
-        unsigned int server_modify_change_no = 0;
-        server_defs->client_suite_mgr().max_change_no(client_handle, server_state_change_no, server_modify_change_no);
-        BOOST_CHECK_MESSAGE(server_state_change_no == 4, "");
-        BOOST_CHECK_MESSAGE(server_modify_change_no == 4, "");
-
-        // *MAKE* sure global change numbers are different to handle suite change numbers
-        // This is the key part of this test.
-        // Since syncing should transfer these change numbers to the client
-        Ecf::set_state_change_no(server_state_change_no + 10);
-        Ecf::set_modify_change_no(server_modify_change_no + 20);
-    }
-
-    // Now sync from server
-    Ecf::set_server(true);
-    MockServer mock_server(server_defs);
-    /* server side */ SNewsCmd news_cmd(client_handle,
-                                        server_reply.client_defs()->state_change_no(),
-                                        server_reply.client_defs()->modify_change_no(),
-                                        &mock_server);
-    /* server side */ SSyncCmd cmd(client_handle,
-                                   server_reply.client_defs()->state_change_no(),
-                                   server_reply.client_defs()->modify_change_no(),
-                                   &mock_server);
-    Ecf::set_server(false);
-
-    // make sure SSyncCmd updated the server change numbers, to use global change numbers
-    unsigned int server_state_change_no  = 0;
-    unsigned int server_modify_change_no = 0;
-    {
-        server_defs->client_suite_mgr().max_change_no(client_handle, server_state_change_no, server_modify_change_no);
-        BOOST_CHECK_MESSAGE(server_state_change_no == 14, "");
-        BOOST_CHECK_MESSAGE(server_modify_change_no == 24, "");
-    }
-
-    // SYNC the client, via do_sync( this should transfer change numbers to the client )
-    BOOST_CHECK_MESSAGE(news_cmd.get_news(), "Expected server to change");
-    BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), "Expected server to change");
-    BOOST_CHECK_MESSAGE(server_reply.in_sync(), "Expected server to change");
-    BOOST_CHECK_MESSAGE(server_defs->state() == server_reply.client_defs()->state(),
-                        "Expected server State(" << NState::toString(server_defs->state())
-                                                 << ") to be same as client state("
-                                                 << NState::toString(server_reply.client_defs()->state()) << ")");
-
-    // After do_sync client and server change number should be in sync
-    BOOST_CHECK_MESSAGE(server_reply.client_defs()->state_change_no() == server_state_change_no,
-                        "Expected " << server_reply.client_defs()->state_change_no()
-                                    << " state change number but found " << server_state_change_no);
-    BOOST_CHECK_MESSAGE(server_reply.client_defs()->modify_change_no() == server_modify_change_no,
-                        "Expected " << server_reply.client_defs()->modify_change_no()
-                                    << " modify change number but found " << server_modify_change_no);
-
-    // Do final sync, there should not be ANY changes
-    Ecf::set_server(true);
-    /* server side */ SNewsCmd news_cmd1(client_handle,
-                                         server_reply.client_defs()->state_change_no(),
-                                         server_reply.client_defs()->modify_change_no(),
-                                         &mock_server);
-    /* server side */ SSyncCmd cmd1(client_handle,
-                                    server_reply.client_defs()->state_change_no(),
-                                    server_reply.client_defs()->modify_change_no(),
-                                    &mock_server);
-    Ecf::set_server(false);
-    /* client side */ BOOST_CHECK_MESSAGE(!news_cmd1.get_news(), "Expected no changes to client, we should be in sync");
-    /* client side */ BOOST_CHECK_MESSAGE(!cmd1.do_sync(server_reply),
-                                          "Expected no changes to client, we should be in sync");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestSpecificIssues.cpp 5.13.0-1/Base/test/TestSpecificIssues.cpp
--- 5.12.4-1/Base/test/TestSpecificIssues.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestSpecificIssues.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,81 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_SpecificIssues)
-
-static defs_ptr create_defs() {
-    // suite s1
-    //   family f1
-    //     trigger f2 == complete
-    //     task t1
-    //     task t2
-    //   endfamily
-    //   family f2
-    //     task t1
-    //     task t2
-    //   endfamily
-    // endsuite
-    defs_ptr theDefs = Defs::create();
-    suite_ptr suite  = theDefs->add_suite("s1");
-    family_ptr f1    = suite->add_family("f1");
-    family_ptr f2    = suite->add_family("f2");
-    f1->add_trigger("f2 == complete");
-    f1->add_task("t1");
-    f1->add_task("t2");
-    f2->add_task("t1");
-    f2->add_task("t2");
-
-    return theDefs;
-}
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_189) {
-    cout << "Base:: ...test_ECFLOW_189\n";
-    TestLog test_log("test_ECFLOW_189.log"); // will create log file, and destroy log and remove file at end of scope
-
-    defs_ptr the_defs = create_defs();
-    the_defs->beginAll();
-    node_ptr t1 = the_defs->findAbsNode("/s1/f1/t1");
-    node_ptr t2 = the_defs->findAbsNode("/s1/f1/t2");
-
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t1->absNodePath())));
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t2->absNodePath())));
-
-    TestHelper::test_state(t1, DState::SUSPENDED);
-    TestHelper::test_state(t2, DState::SUSPENDED);
-
-    // Now resume /s1/f1/t1 and /s1/f1/t2
-    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::RESUME, t1->absNodePath())));
-
-    // We expect state to be queued since the trigger on /s1/f1 should prevent jobs from running
-    // If we find submitted or aborted(i.e it was free to run, but could not generate the jobs), then its an error
-    TestHelper::test_state(t1, NState::QUEUED);
-    TestHelper::test_state(t2, NState::QUEUED);
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Base/test/TestStatsCmd.cpp 5.13.0-1/Base/test/TestStatsCmd.cpp
--- 5.12.4-1/Base/test/TestStatsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Base/test/TestStatsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,136 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "MockServer.hpp"
-#include "MyDefsFixture.hpp"
-#include "ecflow/base/ClientToServerRequest.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/base/stc/ServerToClientCmd.hpp"
-#include "ecflow/core/Log.hpp"
-
-///
-///   Tests for `Stats` command
-///    - check that the 'number of suits' is correctly reported
-///    - check that the 'requests per second' is correctly reported
-///
-
-namespace {
-
-std::string extract_report_value(const std::string& report, const std::string& label) {
-    boost::char_separator<char> sep("\n"); // splitting report by lines
-    using tokenizer_t = boost::tokenizer<boost::char_separator<char>>;
-    tokenizer_t tokens(report, sep);
-    for (const auto& token : tokens) {
-        if (token.find(label) != std::string::npos) {
-            // Important!
-            //   By convention, the labels in report by `Stats` have width 35
-            //   If this convention changes, the test will fail
-            return token.substr(35);
-        }
-    }
-    throw std::runtime_error("Unable to find requested label");
-}
-
-int extract_number_of_suites(const std::string& report) {
-    auto entry = extract_report_value(report, "Number of Suites");
-    return ecf::convert_to<int>(entry);
-}
-
-std::string extract_request_per_second(const std::string& report) {
-    auto entry = extract_report_value(report, "Request/s per 1,5,15,30,60 min");
-    return entry;
-}
-
-} // namespace
-
-BOOST_AUTO_TEST_SUITE(U_Base)
-
-BOOST_AUTO_TEST_SUITE(T_StatsCmd)
-
-BOOST_AUTO_TEST_CASE(test_stats_cmd__reports_number_of_suites) {
-
-    ecf::TestLog test_log("test_stats_cmd__reports_number_of_suites.log");
-
-    Defs defs;
-    // Considering 3 suites, to be reported by `Stats`
-    defs.addSuite(Suite::create("some_suite"));
-    defs.addSuite(Suite::create("another_suite"));
-    defs.addSuite(Suite::create("yet_another_suite"));
-
-    MockServer server(&defs);
-
-    // Execute `Stats` command
-    {
-        auto command = std::make_shared<CtsCmd>(CtsCmd::STATS);
-
-        ClientToServerRequest request;
-        request.set_cmd(command);
-
-        try {
-            auto reply = request.handleRequest(&server);
-            if (reply) {
-                BOOST_REQUIRE(reply->ok());
-
-                auto no_of_suites = extract_number_of_suites(reply->get_string());
-                BOOST_REQUIRE(no_of_suites == 3);
-            }
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Unexpected exception : " << e.what() << " : " << request);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_stats_cmd__reports_requests_per_second) {
-
-    ecf::TestLog test_log("test_stats_cmd__reports_requests_per_second.log");
-
-    Defs defs;
-
-    MockServer server(&defs);
-
-    // Simulate some fictitious server load to report statistics
-    int polling = 60; // every 60 seconds
-    int samples = 60; // to cover 1 hour 'uptime'
-    for (int i = 0; i < samples; ++i) {
-        int sample = 30 + (samples - i - 1);
-        // Note: the request counter sample varies to allow checking that the
-        // measurements are processed in the correct order
-        server.stats().request_count_ = sample;
-        server.stats().update_stats(polling);
-    }
-
-    // Execute `Stats` command
-    {
-        auto command = std::make_shared<CtsCmd>(CtsCmd::STATS);
-
-        ClientToServerRequest request;
-        request.set_cmd(command);
-
-        try {
-            auto reply = request.handleRequest(&server);
-            if (reply) {
-                BOOST_REQUIRE(reply->ok());
-
-                auto requests_per_second = extract_request_per_second(reply->get_string());
-                BOOST_REQUIRE(requests_per_second == "0.50 0.53 0.62 0.74 0.99");
-            }
-        }
-        catch (std::exception& e) {
-            BOOST_CHECK_MESSAGE(false, "Unexpected exception : " << e.what() << " : " << request);
-        }
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CMakeLists.txt 5.13.0-1/CMakeLists.txt
--- 5.12.4-1/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -22,10 +22,10 @@ if (NOT DEFINED CMAKE_BUILD_TYPE)
   set(CMAKE_BUILD_TYPE Release CACHE STRING "Build Configuration type" FORCE)
 endif()
 
-find_package( ecbuild 3.4 REQUIRED HINTS ${CMAKE_CURRENT_SOURCE_DIR} ${CMAKE_CURRENT_SOURCE_DIR}/../ecbuild ) # Before project()  
+find_package( ecbuild 3.4 REQUIRED HINTS ${CMAKE_CURRENT_SOURCE_DIR} ${CMAKE_CURRENT_SOURCE_DIR}/../ecbuild /workspace/ecbuild) # Before project()
 
 # this will generate variables, see ACore/ecflow_version.h.in
-project( ecflow LANGUAGES CXX VERSION 5.12.4 )
+project( ecflow LANGUAGES CXX VERSION 5.13.0 )
 
 set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${CMAKE_SOURCE_DIR}/cmake)
 
@@ -348,24 +348,10 @@ find_package(ClangFormat)
 # =========================================================================================
 # build source code
 # =========================================================================================
-add_subdirectory( ACore )
-add_subdirectory( ANattr )
-add_subdirectory( ANode )
-add_subdirectory( Base )
-add_subdirectory( CSim )
-add_subdirectory( Client )
+add_subdirectory( libs )
 
 if (ENABLE_SERVER)
-  add_subdirectory( Server )
   add_subdirectory( tools )
-  add_subdirectory( Test )
-endif()
-
-if (ENABLE_PYTHON)
-  if ( ENABLE_PYTHON_PTR_REGISTER )
-    add_definitions( -DECF_ENABLE_PYTHON_PTR_REGISTER )
-  endif()
-  add_subdirectory( Pyext )
 endif()
 
 if (ENABLE_UI)
@@ -373,14 +359,6 @@ if (ENABLE_UI)
   add_subdirectory( share )
 endif()
 
-if (ENABLE_HTTP)
-  add_subdirectory( Http )
-endif()
-
-if (ENABLE_UDP)
-  add_subdirectory( Udp )
-endif()
-
 # =========================================================================================
 # DOXYGEN to use: make doxygen  -> ${CMAKE_CURRENT_BINARY_DIR}/Doc/doxygen/html/index.html
 # =========================================================================================
@@ -417,15 +395,17 @@ endif()
 # =========================================================================================
 ecbuild_dont_pack(
   DIRS
+    .scratch
+    .git
     .settings
     bamboo
-    ACore/doc
-    ANattr/doc
-    ANode/doc
-    Client/doc
-    CSim/doc
-    Pyext/doc
-    Server/doc
+    libs/core/doc
+    libs/attributes/doc
+    libs/node/doc
+    libs/client/doc
+    libs/simulator/doc
+    libs/pyext/doc
+    libs/server/doc
     ecbuild
     SCRATCH
     CUSTOMER
diff -pruN 5.12.4-1/CSim/CMakeLists.txt 5.13.0-1/CSim/CMakeLists.txt
--- 5.12.4-1/CSim/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,94 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-set(srcs
-  # Headers
-  src/ecflow/simulator/Analyser.hpp
-  src/ecflow/simulator/AstAnalyserVisitor.hpp
-  src/ecflow/simulator/DefsAnalyserVisitor.hpp
-  src/ecflow/simulator/FlatAnalyserVisitor.hpp
-  src/ecflow/simulator/Simulator.hpp
-  src/ecflow/simulator/SimulatorVisitor.hpp
-  # Sources
-  src/ecflow/simulator/Analyser.cpp
-  src/ecflow/simulator/AstAnalyserVisitor.cpp
-  src/ecflow/simulator/DefsAnalyserVisitor.cpp
-  src/ecflow/simulator/FlatAnalyserVisitor.cpp
-  src/ecflow/simulator/Simulator.cpp
-  src/ecflow/simulator/SimulatorVisitor.cpp
-)
-ecbuild_add_library(
-  TARGET
-    libsimulator
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-  PUBLIC_LIBS
-    node
-    attributes
-    core
-)
-target_clangformat(libsimulator)
-
-set(test_srcs
-  # Headers
-  test/TestUtil.hpp
-  # Sources
-  test/TestAnalysis.cpp
-  test/TestAutoArchive.cpp
-  test/TestAutoCancel.cpp
-  test/TestAutoCancel.cpp
-  test/TestAutoRestore.cpp
-  test/TestMeter.cpp
-  test/TestRepeat.cpp
-  test/TestSimulator.cpp
-  test/TestSimulator_main.cpp # test entry point
-  test/TestTime.cpp
-  test/TestToday.cpp
-  test/TestUtil.cpp
-)
-ecbuild_add_test(
-  TARGET
-    s_simulator
-  LABELS
-    integration nightly
-  SOURCES
-    ${test_srcs}
-  LIBS
-    libsimulator
-    Threads::Threads
-  TEST_DEPENDS
-    u_base
-)
-target_clangformat(s_simulator CONDITION ENABLE_TESTS)
-
-if (ENABLE_ALL_TESTS)
-
-  ecbuild_add_test(
-    TARGET
-      s_simulator_single
-    LABELS
-      integration nightly
-    SOURCES
-      test/TestSingleSimulator.cpp
-      test/TestSingleSimulator_main.cpp # test entry point
-      test/TestUtil.cpp
-    LIBS
-      libsimulator
-      Threads::Threads
-    TEST_DEPENDS
-      u_base
-  )
-  target_clangformat(s_simulator_single CONDITION ENABLE_TESTS)
-
-endif()
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/Analyser.cpp 5.13.0-1/CSim/src/ecflow/simulator/Analyser.cpp
--- 5.12.4-1/CSim/src/ecflow/simulator/Analyser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/Analyser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/simulator/Analyser.hpp"
-
-#include <fstream>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/simulator/DefsAnalyserVisitor.hpp"
-#include "ecflow/simulator/FlatAnalyserVisitor.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-Analyser::Analyser() = default;
-
-void Analyser::run(Defs& theDefs) {
-    // Run flat analysis
-    {
-        FlatAnalyserVisitor visitor;
-        theDefs.acceptVisitTraversor(visitor);
-
-        std::string fileName = "defs.flat";
-
-        std::ofstream file(fileName.c_str());
-        if (!file.is_open())
-            throw std::runtime_error("Analyser::run: Failed to open file \"" + fileName + "\"");
-
-        file << visitor.report();
-    }
-
-    // run depth first analysis
-    {
-        DefsAnalyserVisitor visitor;
-        theDefs.acceptVisitTraversor(visitor);
-
-        std::string fileName = "defs.depth";
-
-        std::ofstream file(fileName.c_str(), ios::out);
-        if (!file.is_open())
-            throw std::runtime_error("Analyser::run: Failed to open file \"" + fileName + "\"");
-
-        file << visitor.report();
-        file.close();
-    }
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/Analyser.hpp 5.13.0-1/CSim/src/ecflow/simulator/Analyser.hpp
--- 5.12.4-1/CSim/src/ecflow/simulator/Analyser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/Analyser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_simulator_Analyser_HPP
-#define ecflow_simulator_Analyser_HPP
-
-class Defs;
-
-namespace ecf {
-
-class Analyser {
-public:
-    Analyser();
-
-    static void run(Defs& theDefs);
-};
-
-} // namespace ecf
-
-#endif /* ecflow_simulator_Analyser_HPP */
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.cpp 5.13.0-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.cpp
--- 5.12.4-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/simulator/AstAnalyserVisitor.hpp"
-
-#include "ecflow/node/ExprAst.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-AstAnalyserVisitor::AstAnalyserVisitor()  = default;
-AstAnalyserVisitor::~AstAnalyserVisitor() = default;
-
-void AstAnalyserVisitor::visitTop(AstTop*) {
-}
-void AstAnalyserVisitor::visitRoot(AstRoot*) {
-}
-void AstAnalyserVisitor::visitAnd(AstAnd*) {
-}
-void AstAnalyserVisitor::visitNot(AstNot*) {
-}
-void AstAnalyserVisitor::visitPlus(AstPlus*) {
-}
-void AstAnalyserVisitor::visitMinus(AstMinus*) {
-}
-void AstAnalyserVisitor::visitDivide(AstDivide*) {
-}
-void AstAnalyserVisitor::visitMultiply(AstMultiply*) {
-}
-void AstAnalyserVisitor::visitModulo(AstModulo*) {
-}
-void AstAnalyserVisitor::visitOr(AstOr*) {
-}
-void AstAnalyserVisitor::visitEqual(AstEqual*) {
-}
-void AstAnalyserVisitor::visitNotEqual(AstNotEqual*) {
-}
-void AstAnalyserVisitor::visitLessEqual(AstLessEqual*) {
-}
-void AstAnalyserVisitor::visitGreaterEqual(AstGreaterEqual*) {
-}
-void AstAnalyserVisitor::visitGreaterThan(AstGreaterThan*) {
-}
-void AstAnalyserVisitor::visitLessThan(AstLessThan*) {
-}
-void AstAnalyserVisitor::visitLeaf(AstLeaf*) {
-}
-void AstAnalyserVisitor::visitInteger(AstInteger*) {
-}
-void AstAnalyserVisitor::visitInstant(AstInstant*) {
-}
-void AstAnalyserVisitor::visitFunction(AstFunction*) {
-}
-void AstAnalyserVisitor::visitNodeState(AstNodeState*) {
-}
-void AstAnalyserVisitor::visitEventState(AstEventState*) {
-}
-
-void AstAnalyserVisitor::visitNode(AstNode* astNode) {
-    Node* refNode = astNode->referencedNode();
-    if (refNode)
-        dependentNodes_.insert(refNode);
-    else
-        dependentNodePaths_.insert(astNode->nodePath());
-}
-
-void AstAnalyserVisitor::visitVariable(AstVariable* astVar) {
-}
-void AstAnalyserVisitor::visitParentVariable(AstParentVariable* astVar) {
-}
-
-void AstAnalyserVisitor::visitFlag(AstFlag* astVar) {
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.hpp 5.13.0-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.hpp
--- 5.12.4-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/AstAnalyserVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_simulator_AstAnalyserVisitor_HPP
-#define ecflow_simulator_AstAnalyserVisitor_HPP
-
-#include <set>
-
-#include "ecflow/node/ExprAstVisitor.hpp"
-
-class Node;
-
-namespace ecf {
-
-class AstAnalyserVisitor : public ExprAstVisitor {
-public:
-    AstAnalyserVisitor();
-    ~AstAnalyserVisitor() override;
-
-    const std::set<Node*>& dependentNodes() const { return dependentNodes_; }
-    const std::set<std::string>& dependentNodePaths() const { return dependentNodePaths_; }
-
-    void visitTop(AstTop*) override;
-    void visitRoot(AstRoot*) override;
-    void visitAnd(AstAnd*) override;
-    void visitNot(AstNot*) override;
-    void visitPlus(AstPlus*) override;
-    void visitMinus(AstMinus*) override;
-    void visitDivide(AstDivide*) override;
-    void visitMultiply(AstMultiply*) override;
-    void visitModulo(AstModulo*) override;
-    void visitOr(AstOr*) override;
-    void visitEqual(AstEqual*) override;
-    void visitNotEqual(AstNotEqual*) override;
-    void visitLessEqual(AstLessEqual*) override;
-    void visitGreaterEqual(AstGreaterEqual*) override;
-    void visitGreaterThan(AstGreaterThan*) override;
-    void visitLessThan(AstLessThan*) override;
-    void visitLeaf(AstLeaf*) override;
-    void visitInteger(AstInteger*) override;
-    void visitInstant(AstInstant*) override;
-    void visitFunction(AstFunction*) override;
-    void visitNodeState(AstNodeState*) override;
-    void visitEventState(AstEventState*) override;
-    void visitNode(AstNode*) override;
-    void visitVariable(AstVariable*) override;
-    void visitParentVariable(AstParentVariable*) override;
-    void visitFlag(AstFlag*) override;
-
-private:
-    std::set<Node*> dependentNodes_;
-    std::set<std::string> dependentNodePaths_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_simulator_AstAnalyserVisitor_HPP */
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.cpp 5.13.0-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.cpp
--- 5.12.4-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,181 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/simulator/DefsAnalyserVisitor.hpp"
-
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/AstAnalyserVisitor.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-///////////////////////////////////////////////////////////////////////////////
-DefsAnalyserVisitor::DefsAnalyserVisitor() = default;
-
-void DefsAnalyserVisitor::visitDefs(Defs* d) {
-    for (suite_ptr s : d->suiteVec()) {
-        s->acceptVisitTraversor(*this);
-    }
-}
-
-void DefsAnalyserVisitor::visitSuite(Suite* s) {
-    visitNodeContainer(s);
-}
-void DefsAnalyserVisitor::visitFamily(Family* f) {
-    visitNodeContainer(f);
-}
-
-void DefsAnalyserVisitor::visitNodeContainer(NodeContainer* nc) {
-    std::set<Node*> dependentNodes;
-    analyse(nc, dependentNodes);
-
-    for (node_ptr t : nc->nodeVec()) {
-        t->acceptVisitTraversor(*this);
-    }
-}
-
-void DefsAnalyserVisitor::visitTask(Task* t) {
-    std::set<Node*> dependentNodes;
-    analyse(t, dependentNodes);
-}
-
-void DefsAnalyserVisitor::analyse(Node* node, std::set<Node*>& dependentNodes, bool dependent) {
-    // ***************************************************************
-    // Do a depth first search to find the root cause of the blockage
-    // ***************************************************************
-    // #ifdef DEBUG
-    //	if (dependent)  {
-    //		ss_ << "DefsAnalyserVisitor::analyse " << node->debugType() << Str::COLON() << node->absNodePath();
-    //		ss_ << " state(" << NState::toString(node->state()) << ")\n";
-    //	}
-    // #endif
-    if (analysedNodes_.find(node) != analysedNodes_.end())
-        return;
-    analysedNodes_.insert(node);
-    if (node->state() == NState::COMPLETE)
-        return;
-
-    if (node->state() == NState::QUEUED) {
-        std::vector<std::string> theReasonWhy;
-        node->why(theReasonWhy);
-        for (const auto& i : theReasonWhy) {
-            Indentor::indent(ss_) << "Reason: " << i << "\n";
-        }
-    }
-
-    /// Note a complete expression that does not evaluate, does *NOT* hold the node
-    /// It merly sets node to complete.
-    if (node->completeAst() && !node->evaluateComplete()) {
-        // Follow nodes referenced in the complete expressions
-        analyseExpressions(node, dependentNodes, false, dependent);
-
-        // follow child nodes
-        auto* nc = dynamic_cast<NodeContainer*>(node);
-        if (nc) {
-            for (node_ptr t : nc->nodeVec()) {
-                t->acceptVisitTraversor(*this);
-            }
-        }
-    }
-
-    if (node->triggerAst() && !node->evaluateTrigger()) {
-        // Follow nodes referenced in the trigger expressions
-        analyseExpressions(node, dependentNodes, true, dependent);
-
-        // follow child nodes
-        auto* nc = dynamic_cast<NodeContainer*>(node);
-        if (nc) {
-            for (node_ptr t : nc->nodeVec()) {
-                t->acceptVisitTraversor(*this);
-            }
-        }
-    }
-}
-
-void DefsAnalyserVisitor::analyseExpressions(Node* node,
-                                             std::set<Node*>& dependentNodes,
-                                             bool trigger,
-                                             bool dependent) {
-    Indentor in;
-    Indentor::indent(ss_);
-    if (dependent)
-        ss_ << "DEPENDENT ";
-    if (trigger) {
-        ss_ << node->debugNodePath() << " holding on trigger expression '" << node->triggerExpression() << "'\n";
-    }
-    else {
-        ss_ << node->debugNodePath() << " holding on complete expression '" << node->completeExpression() << "'\n";
-    }
-
-    AstAnalyserVisitor astVisitor;
-    if (trigger) {
-        node->triggerAst()->accept(astVisitor);
-        ss_ << *node->triggerAst();
-    }
-    else {
-        node->completeAst()->accept(astVisitor);
-        ss_ << *node->completeAst();
-    }
-
-    // Warn about NULL node references in the trigger expressions
-    for (const string& nodePath : astVisitor.dependentNodePaths()) {
-        Indentor in2;
-        Indentor::indent(ss_) << "'" << nodePath << "' is not defined in the expression\n";
-    }
-
-    // **** NOTE: Currently for COMPLETE expression will only follow trigger expressions
-    for (Node* triggerNode : astVisitor.dependentNodes()) {
-
-        Indentor in2;
-        Indentor::indent(ss_) << "EXPRESSION NODE " << triggerNode->debugNodePath();
-        ss_ << " state(" << NState::toString(triggerNode->state()) << ")";
-        if (triggerNode->triggerAst())
-            ss_ << " trigger(evaluation = " << triggerNode->evaluateTrigger() << "))";
-        if (analysedNodes_.find(triggerNode) != analysedNodes_.end())
-            ss_ << " analysed ";
-        if (dependentNodes.find(triggerNode) != dependentNodes.end())
-            ss_ << " ** ";
-        ss_ << "\n";
-
-        if (dependentNodes.find(triggerNode) != dependentNodes.end()) {
-            // possible deadlock make sure
-            if (triggerNode->triggerAst()) {
-                AstAnalyserVisitor visitor;
-                triggerNode->triggerAst()->accept(visitor);
-
-                //				cerr << "Node = " << node->absNodePath() << "\n";
-                //				cerr << "triggerNode = " << triggerNode->absNodePath() << "\n";
-                //				for(Node* n:visitor.dependentNodes() ) {
-                //					cerr << "triggerNode Node dependents = " << n->absNodePath() <<
-                //"\n";
-                //				}
-
-                if (visitor.dependentNodes().find(node) != visitor.dependentNodes().end()) {
-                    Indentor in3;
-                    Indentor::indent(ss_) << "Deadlock detected between:\n";
-                    Indentor in4;
-                    Indentor::indent(ss_) << node->debugNodePath() << "\n";
-                    Indentor::indent(ss_) << triggerNode->debugNodePath() << "\n";
-                }
-            }
-            continue;
-        }
-        dependentNodes.insert(triggerNode);
-        analyse(triggerNode, dependentNodes, true);
-    }
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.hpp 5.13.0-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.hpp
--- 5.12.4-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/DefsAnalyserVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_simulator_DefsAnalyserVisitor_HPP
-#define ecflow_simulator_DefsAnalyserVisitor_HPP
-
-#include <set>
-#include <sstream>
-
-#include "ecflow/node/NodeTreeVisitor.hpp"
-
-class Node;
-
-namespace ecf {
-
-class DefsAnalyserVisitor final : public NodeTreeVisitor {
-public:
-    DefsAnalyserVisitor();
-    std::string report() const { return ss_.str(); }
-
-    bool traverseObjectStructureViaVisitors() const override { return true; }
-    void visitDefs(Defs*) override;
-    void visitSuite(Suite*) override;
-    void visitFamily(Family*) override;
-    void visitNodeContainer(NodeContainer*) override;
-    void visitTask(Task*) override;
-
-private:
-    void analyse(Node* n, std::set<Node*>& dependentNodes, bool dependent = false);
-    void analyseExpressions(Node* node, std::set<Node*>& dependentNodes, bool trigger, bool dependent);
-
-    std::stringstream ss_;
-    std::set<Node*> analysedNodes_; // The node we  analysed
-};
-
-} // namespace ecf
-
-#endif /* ecflow_simulator_DefsAnalyserVisitor_HPP */
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.cpp 5.13.0-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.cpp
--- 5.12.4-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,116 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/simulator/FlatAnalyserVisitor.hpp"
-
-#include "ecflow/core/Indentor.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprAst.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/AstAnalyserVisitor.hpp"
-
-using namespace std;
-
-namespace ecf {
-
-///////////////////////////////////////////////////////////////////////////////
-FlatAnalyserVisitor::FlatAnalyserVisitor() = default;
-
-void FlatAnalyserVisitor::visitDefs(Defs* d) {
-    for (suite_ptr s : d->suiteVec()) {
-        s->acceptVisitTraversor(*this);
-    }
-}
-
-void FlatAnalyserVisitor::visitSuite(Suite* s) {
-    visitNodeContainer(s);
-}
-void FlatAnalyserVisitor::visitFamily(Family* f) {
-    visitNodeContainer(f);
-}
-
-void FlatAnalyserVisitor::visitNodeContainer(NodeContainer* nc) {
-    if (nc->state() == NState::COMPLETE)
-        return;
-
-    Indentor in;
-    bool traverseChildren = analyse(nc);
-
-    // Dont bother traversing children if parent is holding on trigger/complete expression
-    if (traverseChildren) {
-        for (node_ptr t : nc->nodeVec()) {
-            t->acceptVisitTraversor(*this);
-        }
-    }
-}
-
-void FlatAnalyserVisitor::visitTask(Task* t) {
-    Indentor in;
-    analyse(t);
-}
-
-bool FlatAnalyserVisitor::analyse(Node* node) {
-    bool traverseChildren = true;
-
-    Indentor::indent(ss_) << node->debugType() << Str::COLON() << node->name() << " state("
-                          << NState::toString(node->state()) << ")";
-    if (node->state() != NState::COMPLETE) {
-
-        if (node->repeat().isInfinite()) {
-            ss_ << " may **NEVER** complete due to " << node->repeat().toString();
-        }
-        ss_ << "\n";
-
-        if (node->state() == NState::QUEUED) {
-            std::vector<std::string> theReasonWhy;
-            node->why(theReasonWhy);
-            for (const auto& i : theReasonWhy) {
-                Indentor::indent(ss_) << "Reason: " << i << "\n";
-            }
-        }
-
-        /// Note a complete expression that does not evaluate, does *NOT* hold the node
-        /// It merly sets node to complete.
-        if (node->completeAst() && !node->evaluateComplete()) {
-            Indentor::indent(ss_) << "holding on complete expression '" << node->completeExpression() << "'\n";
-
-            AstAnalyserVisitor astVisitor;
-            node->completeAst()->accept(astVisitor);
-            for (const string& nodePath : astVisitor.dependentNodePaths()) {
-                Indentor in;
-                Indentor::indent(ss_) << "'" << nodePath << "' is not defined in the expression\n";
-            }
-            ss_ << *node->completeAst();
-
-            traverseChildren = false;
-        }
-
-        if (node->triggerAst() && !node->evaluateTrigger()) {
-            Indentor::indent(ss_) << "holding on trigger expression '" << node->triggerExpression() << "'\n";
-
-            AstAnalyserVisitor astVisitor;
-            node->triggerAst()->accept(astVisitor);
-            for (const string& nodePath : astVisitor.dependentNodePaths()) {
-                Indentor in;
-                Indentor::indent(ss_) << "'" << nodePath << "' is not defined in the expression\n";
-            }
-            ss_ << *node->triggerAst();
-
-            traverseChildren = false;
-        }
-    }
-    ss_ << "\n";
-    return traverseChildren;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.hpp 5.13.0-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.hpp
--- 5.12.4-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/FlatAnalyserVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_simulator_FlatAnalyserVisitor_HPP
-#define ecflow_simulator_FlatAnalyserVisitor_HPP
-
-#include <sstream>
-
-#include "ecflow/node/NodeTreeVisitor.hpp"
-
-class Node;
-
-namespace ecf {
-
-class FlatAnalyserVisitor final : public NodeTreeVisitor {
-public:
-    FlatAnalyserVisitor();
-    std::string report() const { return ss_.str(); }
-
-    bool traverseObjectStructureViaVisitors() const override { return true; }
-    void visitDefs(Defs*) override;
-    void visitSuite(Suite*) override;
-    void visitFamily(Family*) override;
-    void visitNodeContainer(NodeContainer*) override;
-    void visitTask(Task*) override;
-
-private:
-    bool analyse(Node* n);
-    std::stringstream ss_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_simulator_FlatAnalyserVisitor_HPP */
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/Simulator.cpp 5.13.0-1/CSim/src/ecflow/simulator/Simulator.cpp
--- 5.12.4-1/CSim/src/ecflow/simulator/Simulator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/Simulator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,383 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/simulator/Simulator.hpp"
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
-
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/simulator/Analyser.hpp"
-#include "ecflow/simulator/SimulatorVisitor.hpp"
-
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-using namespace std;
-using namespace ecf;
-
-// #define DEBUG_LONG_RUNNING_SUITES 1
-
-namespace ecf {
-
-/// Class that allows multiple log files.
-class LogDestroyer {
-public:
-    LogDestroyer() = default;
-    ~LogDestroyer() { Log::destroy(); }
-};
-
-Simulator::Simulator() : print_style_(PrintStyle::STATE) {
-}
-
-bool Simulator::run(const std::string& theDefsFile, std::string& errorMsg) const {
-#ifdef DEBUG_LONG_RUNNING_SUITES
-    cout << "Simulator::run parsing file " << theDefsFile << endl;
-#endif
-
-    Defs theDefs;
-    std::string warningMsg;
-    if (!theDefs.restore(theDefsFile, errorMsg, warningMsg))
-        return false;
-    // cout << theDefs << "\n";
-    return run(theDefs, theDefsFile, errorMsg, false /* don't do check, allready done */);
-}
-
-bool Simulator::run(Defs& theDefs, const std::string& defs_filename, std::string& errorMsg, bool do_checks) const {
-#ifdef DEBUG_LONG_RUNNING_SUITES
-    std::cout << "Simulator::run " << defs_filename << " no of suites " << theDefs.suiteVec().size() << endl;
-#endif
-    // ****:NOTE:******
-    // ** This simulator relies on the defs checking to set event and meter usedInTrigger()
-    // ** to speed up simulator. However this is done in AstResolveVisitor.
-    // ** Which is called during checking:
-    // ** By default checking in done when reading a defs file from disk:
-    // ** However many test create Defs on the fly. These may not do_checks.
-    // ** Hence we do it here, since it is simulator specific.
-
-    //   Please note that when we use a clock attribute, for a specific date
-    //   then when we are using repeat, they can cause the suite to re-queue
-    //   and RESET the suite time, back to clock attribute time
-
-    if (do_checks) {
-        std::string warningMsg;
-        if (!theDefs.check(errorMsg, warningMsg)) {
-            return false;
-        }
-    }
-
-    // Allow new log to be created each time, by destroying the old log.
-    LogDestroyer destroyLog;
-
-    // Initialise the Log file, and destroy when done. This
-    // allows new log file to be created named after the definition file
-    std::string logFileName = defs_filename + ".log";
-    fs::remove(logFileName);
-    Log::create(logFileName);
-    // cout << "defs_filename " << defs_filename << "\n";
-    // cout << "***** after Log::create(logFileName)\n";
-
-    // Do the following:
-    // o call begin() for each suite
-    // o determine calendar increment. If no time dependencies use an hour increment
-    // o determine max simulation period. ie looks at size of repeats
-    // o If multiple suites and some suites have no tasks, mark them as complete, these may have server limits
-    // o If no tasks at all, no point in simulating
-    // o ********************************************************************************
-    //   Please note that when we use a clock attribute, for a specific date
-    //   then when we are using repeat, they can cause the suite to re-queue
-    //   and RESET the suite time, back to clock attribute time
-    //   *********************************************************************************
-    SimulatorVisitor simiVisitor(defs_filename);
-    theDefs.acceptVisitTraversor(simiVisitor);
-    if (!simiVisitor.errors_found().empty()) {
-        errorMsg += simiVisitor.errors_found();
-        return false;
-    }
-
-    // Let visitor determine calendar increment. i.e if no time dependencies we will use 1 hour increment
-    time_duration calendarIncrement                        = simiVisitor.calendarIncrement();
-    boost::posix_time::time_duration max_simulation_period = simiVisitor.maxSimulationPeriod();
-
-    std::stringstream ss;
-    ss << " time dependency(" << simiVisitor.hasTimeDependencies() << ") max_simulation_period("
-       << to_simple_string(max_simulation_period) << ") calendarIncrement(" << to_simple_string(calendarIncrement)
-       << ")";
-    std::string msg = ss.str();
-    log(Log::MSG, msg);
-#ifdef DEBUG_LONG_RUNNING_SUITES
-    cout << defs_filename << msg
-         << "   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n";
-#endif
-
-    // Do we have autocancel, must be done before.
-    int hasAutoCancel = 0;
-    for (suite_ptr s : theDefs.suiteVec()) {
-        if (s->hasAutoCancel())
-            hasAutoCancel++;
-    }
-
-    // ==================================================================================
-    // Start simulation ...
-    // Assume: User has taken into account autocancel end time.
-    // ==================================================================================
-    CalendarUpdateParams calUpdateParams(calendarIncrement);
-    boost::posix_time::time_duration duration(0, 0, 0, 0);
-    while (duration <= max_simulation_period) {
-
-#ifdef DEBUG_LONG_RUNNING_SUITES
-        for (suite_ptr my_suite : theDefs.suiteVec()) {
-            cout << "duration: " << to_simple_string(duration) << " " << my_suite->calendar().toString()
-                 << " +++++++++++++++++++++++++++++++++++ " << endl;
-
-            // use following to snapshot definition state at a given point in time
-            //         {
-            //        	 boost::gregorian::date debug_date(2019,8,5);
-            //        	 ptime debug_time(debug_date, hours(10) );
-            //        	 if (my_suite->calendar().suiteTime() == debug_time) {
-            //        		 cout << theDefs.print(PrintStyle::MIGRATE) << endl;
-            //        	 }
-            //         }
-        }
-#endif
-
-        // Resolve dependencies and submit jobs
-        if (!doJobSubmission(theDefs, errorMsg))
-            return false;
-
-        // Increment calendar per suite. *MUST* use *COPY* as update_calendar() can remove suites (auto-cancel)
-        std::vector<suite_ptr> suiteVec = theDefs.suiteVec();
-        for (suite_ptr suite : suiteVec) {
-            boost::posix_time::time_duration max_duration_for_suite = simiVisitor.max_simulation_period(suite.get());
-            if (duration < max_duration_for_suite) {
-                theDefs.update_calendar(suite.get(), calUpdateParams);
-            }
-        }
-        duration += calendarIncrement;
-    }
-
-    // ==================================================================================
-    // END of simulation
-    // ==================================================================================
-    if (!theDefs.checkInvariants(errorMsg)) {
-        return false;
-    }
-
-    // Cater for suite, with no verify attributes, but which are not complete. testAnalysis.cpp
-    // Ignore suites with crons as they will never complete
-    // Ignore suites with autocancel, as suite may get deleted
-    if (!simiVisitor.foundCrons() && (hasAutoCancel == 0)) {
-        size_t completeSuiteCnt = 0;
-        for (suite_ptr s : theDefs.suiteVec()) {
-            if (s->state() == NState::COMPLETE)
-                completeSuiteCnt++;
-        }
-
-        if ((theDefs.suiteVec().size() != completeSuiteCnt)) {
-            std::stringstream mss;
-            mss << "\nDefs file " << defs_filename << "\n";
-            for (suite_ptr s : theDefs.suiteVec()) {
-                if (s->state() != NState::COMPLETE)
-                    mss << "  suite '/" << s->name() << "' has not completed\n";
-            }
-            errorMsg += mss.str();
-
-            run_analyser(theDefs, errorMsg);
-            return false;
-        }
-    }
-
-    if (theDefs.verification(errorMsg)) {
-        return true;
-    }
-
-    run_analyser(theDefs, errorMsg);
-    return false;
-}
-
-void Simulator::run_analyser(Defs& theDefs, std::string& errorMsg) const {
-    Analyser analyser;
-    analyser.run(theDefs);
-    errorMsg += "Please see files .flat and .depth for analysis\n";
-    errorMsg += theDefs.print(PrintStyle::MIGRATE);
-}
-
-bool Simulator::doJobSubmission(Defs& theDefs, std::string& errorMsg) const {
-    //   const std::vector<suite_ptr>& suiteVec = theDefs.suiteVec();
-    //   for(suite_ptr s: suiteVec) cout << s->debugNodePath() << " " << s->calendar().toString() <<  endl;
-
-    // For the simulation we ensure job submission takes less than 10 seconds
-    // Resolve dependencies and submit jobs
-    JobsParam jobsParam(10 /*submitJobsInterval */, false /*create jobs*/); // spawn jobs *will* be set to false
-    Jobs jobs(&theDefs);
-    if (!jobs.generate(jobsParam)) {
-        ecf::log(Log::ERR, jobsParam.getErrorMsg());
-        assert(false);
-        return false;
-    }
-
-    // #ifdef DEBUG_LONG_RUNNING_SUITES
-    //	cout << "Simulator::doJobSubmission jobsParam.submitted().size() " << jobsParam.submitted().size() << " level =
-    //" << level_ << endl; #endif
-
-    level_++;
-
-    // For those jobs that were submitted, Simulate client by going
-    // through the task events and meters and updating them and then
-    // re-checking for job submission. Finally mark task as complete
-    // This is important as there may be other task dependent on this.
-    for (Submittable* t : jobsParam.submitted()) {
-
-#ifdef DEBUG_LONG_RUNNING_SUITES
-        // If task repeating themselves, determine what is causing this:
-        std::map<Submittable*, int>::iterator i = taskIntMap_.find(t);
-        if (i == taskIntMap_.end())
-            taskIntMap_.insert(std::make_pair(t, 1));
-        else {
-            (*i).second++;
-            // Find top most node that has a repeat, check if its incrementing:
-            Node* nodeWithRepeat = NULL;
-            Node* theParent      = t->parent();
-            while (theParent) {
-                if (!theParent->repeat().empty())
-                    nodeWithRepeat = theParent;
-                theParent = theParent->parent();
-            }
-            // cout << t->suite()->calendar().toString();
-            if (nodeWithRepeat) {
-                cout << " level " << level_ << " submitted task " << t->debugNodePath() << " count = " << (*i).second
-                     << " HAS parent Repeating node " << nodeWithRepeat->debugNodePath() << " "
-                     << nodeWithRepeat->repeat().dump() << endl;
-            }
-            else { // cound be a cron
-                cout << " level " << level_ << " submitted task " << t->debugNodePath() << " count = " << (*i).second
-                     << endl;
-            }
-        }
-#endif
-
-#ifdef DEBUG_LONG_RUNNING_SUITES
-        cout << t->debugNodePath() << " completes at " << t->suite()->calendar().toString() << " level " << level_
-             << " parent state:" << endl;
-#endif
-
-        // If the task has any event used in the trigger expressions, then update event.
-        std::string msg;
-        for (Event& event : t->ref_events()) {
-            if (event.usedInTrigger()) { // event used in trigger/complete expression
-                // initial value, if the value taken by the event on begin/re-queue. Child command is expected to invert
-                // the event
-                if (event.initial_value())
-                    event.set_value(false); // initial value is set,   hence clear event
-                else
-                    event.set_value(true); // initial value is clear, hence set the event , (default)
-
-                msg.clear();
-                msg += Str::CHILD_CMD();
-                msg += "event ";
-                msg += event.name_or_number();
-                msg += " ";
-                msg += t->absNodePath();
-                log(Log::MSG, msg);
-
-                if (!doJobSubmission(theDefs, errorMsg)) {
-                    level_--;
-                    return false;
-                }
-            }
-            else {
-                // warn about events not used in any trigger or complete expressions
-                // 				cout << "submitted task " << t->debugNodePath() << " UN-USED event " <<
-                // event.toString() << "\n";
-            }
-        }
-
-        // if the task has any meters used in trigger expressions, then increment meters
-        for (Meter& meter : t->ref_meters()) {
-            if (meter.usedInTrigger()) { // meter used in trigger/complete expression
-                while (meter.value() < meter.max()) {
-                    meter.set_value(meter.value() + 1);
-
-                    msg.clear();
-                    msg += Str::CHILD_CMD();
-                    msg += "meter ";
-                    msg += meter.name();
-                    msg += " ";
-                    msg += t->absNodePath();
-                    log(Log::MSG, msg);
-
-                    if (!doJobSubmission(theDefs, errorMsg)) {
-                        level_--;
-                        return false;
-                    }
-                }
-            }
-            else {
-                // Meters that are not used in trigger are usually used to indicate progress.
-                meter.set_value(meter.max());
-            }
-        }
-
-        if (!update_for_queues(t, msg, t->ref_queues(), theDefs, errorMsg))
-            return false;
-        Node* parent = t->parent();
-        while (parent) {
-            if (!update_for_queues(t, msg, parent->ref_queues(), theDefs, errorMsg))
-                return false;
-            parent = parent->parent();
-        }
-
-        // any state change should be followed with a job submission
-        t->complete(); // mark task as complete
-    }
-
-    level_--;
-    return true;
-}
-
-bool Simulator::update_for_queues(Submittable* t,
-                                  std::string& msg,
-                                  std::vector<QueueAttr>& queues,
-                                  Defs& theDefs,
-                                  std::string& errorMsg) const {
-    for (QueueAttr& queue : queues) {
-        const std::vector<std::string>& queue_list = queue.list();
-        for (size_t i = 0; i < queue_list.size(); i++) {
-            std::string step = queue.active();
-            if (step != "<NULL>")
-                queue.complete(step);
-            if (queue.used_in_trigger()) {
-                msg.clear();
-                msg += Str::CHILD_CMD();
-                msg += "queue ";
-                msg += queue.name();
-                msg += " complete";
-                msg += " ";
-                msg += step;
-                msg += t->absNodePath();
-                log(Log::MSG, msg);
-
-                if (!doJobSubmission(theDefs, errorMsg)) {
-                    level_--;
-                    return false;
-                }
-            }
-        }
-    }
-    return true;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/Simulator.hpp 5.13.0-1/CSim/src/ecflow/simulator/Simulator.hpp
--- 5.12.4-1/CSim/src/ecflow/simulator/Simulator.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/Simulator.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,67 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_simulator_Simulator_HPP
-#define ecflow_simulator_Simulator_HPP
-
-#include <map>
-#include <string>
-#include <vector>
-
-#include "ecflow/core/PrintStyle.hpp"
-
-class QueueAttr;
-class Defs;
-class Submittable;
-
-namespace ecf {
-
-// This class is used to simulate a definition file. This is usefull because:
-//   a/ Saves time over involving server and asking client to play definition file
-//   b/ Informs about any parser errors in the definition file
-//   c/ Informs about any deadlocks, i.e. if a suite does not complete
-//   d/ Simulates both real and hybrid clocks
-//   e/ Simulation will by default run for a year. Should really use start/end clock for accurate simulations
-class Simulator {
-public:
-    // For deterministic results simulate using clock(start) and endclock(finish)
-    // Otherwise default to run simulation for:
-    // No time dependencies: simulate for 24 hours
-    //    time || today // 24 hours
-    //    day           // 1 week
-    //    date          // 1 month
-    //    cron          // 1 year
-    //    repeat        // 1 year
-    Simulator();
-    Simulator(const Simulator&)            = delete;
-    Simulator& operator=(const Simulator&) = delete;
-
-    /// return true if all ok else returns false;
-    bool run(Defs&, const std::string& defs_filename, std::string& errorMsg, bool do_checks = true) const;
-    bool run(const std::string& theDefsFile, std::string& errorMsg) const;
-
-private:
-    bool doJobSubmission(Defs&, std::string& errorMsg) const;
-    void run_analyser(Defs& theDefs, std::string& errorMsg) const;
-
-    bool update_for_queues(Submittable* t,
-                           std::string& msg,
-                           std::vector<QueueAttr>& queues,
-                           Defs& theDefs,
-                           std::string& errormsg) const;
-
-    mutable std::map<Submittable*, int> taskIntMap_;
-    mutable int level_{0};
-    PrintStyle print_style_; // by default show state when writing defs to standard out. RAII
-};
-
-} // namespace ecf
-
-#endif /* ecflow_simulator_Simulator_HPP */
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/SimulatorVisitor.cpp 5.13.0-1/CSim/src/ecflow/simulator/SimulatorVisitor.cpp
--- 5.12.4-1/CSim/src/ecflow/simulator/SimulatorVisitor.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/SimulatorVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,158 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/simulator/SimulatorVisitor.hpp"
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-namespace ecf {
-
-// Please note: we can speed up simulation, by using a calendar increment of 1 hour
-// However this will *ONLY* work *IF*
-//   o All the time based attributes time,today,cron have no minutes, i.e only i hour resolution
-//   o The calendar start time, must also have hour resolution, otherwise time/cron based attributes
-//     will be missed. i.e we increment calendar start time , with calendar increment
-//     If calendar start time is minutes based, and increment in hour based, time attributes will be missed
-//     Note: today is different, to time/cron, as it does not require a exact match
-
-///////////////////////////////////////////////////////////////////////////////
-SimulatorVisitor::SimulatorVisitor(const std::string& defs_filename)
-    : defs_filename_(defs_filename),
-      foundTasks_(false),
-      foundCrons_(false),
-      foundTime_(false),
-      hasTimeDependencies_(false),
-      has_end_clock_(false),
-      max_sim_duration_(hours(24)),
-      max_suite_duration_(hours(24)),
-      ci_(hours(1)) {
-}
-
-void SimulatorVisitor::visitDefs(Defs* d) {
-    for (suite_ptr s : d->suiteVec()) {
-        s->acceptVisitTraversor(*this);
-    }
-}
-
-void SimulatorVisitor::visitSuite(Suite* s) {
-    /// begin , will cause creation of generated variables. The generated variables
-    /// are use in client scripts and used to locate the ecf files.
-    s->begin();
-
-    // Found time dependencies use calendar increment of one minute
-    if (s->hasTimeDependencies()) {
-        hasTimeDependencies_ = true;
-    }
-
-    if (s->clockAttr() && s->clock_end_attr()) {
-        max_suite_duration_ = s->clock_end_attr()->ptime() - s->clockAttr()->ptime();
-        has_end_clock_      = true; // no need to determine max_length, user specified
-    }
-
-    visitNodeContainer(s);
-
-    // IF the suite has no task  (i.e could consist of just limits, set suite to complete
-    // Since we rely on it for termination of tests
-    // make setting NState::COMPLETE is after begin(), which will set Node into the queued state
-    if (!foundTasks_) {
-        s->set_state(NState::COMPLETE);
-        std::stringstream ss;
-        ss << "The defs file " << defs_filename_ << " has a suite '/" << s->suite()->name()
-           << "' which has no tasks. Ignoring \n";
-        log(Log::WAR, ss.str());
-    }
-
-    // If we have cron/time with calendar increment of 1 hour, where calendar start time is in minutes
-    // we will miss the time/cron based attributes, hence use 1 minute resolution
-    if ((foundCrons_ || foundTime_) && ci_ == hours(1)) {
-        // simulation has not started so, suiteTime same as start time.
-        boost::posix_time::time_duration start_time = s->calendar().suiteTime().time_of_day();
-        if (start_time.minutes() != 0) {
-            // cout << " start_time " << start_time << "   " << defs_filename_ << "\n";
-            log(Log::WAR,
-                "Found cron or time based attributes, with 1 hour resolution, however suite calendar start time has "
-                "minute resolution, reverting to minute resolution for simulation.");
-            log(Log::WAR,
-                "To speed up resolution use suite calendar with hour setting only, i.e where minutes is zero");
-            ci_ = minutes(1);
-        }
-    }
-
-    // record the max simulation period for THIS suite. i.e different suites can have different simulation period
-    suite_duration_vec_.emplace_back(s, max_suite_duration_);
-
-    // make sure total simulation period cover all the suites.
-    if (max_suite_duration_ > max_sim_duration_) {
-        max_sim_duration_ = max_suite_duration_;
-    }
-}
-
-boost::posix_time::time_duration SimulatorVisitor::max_simulation_period(Suite* s) const {
-    size_t suite_duration_vec_size = suite_duration_vec_.size();
-    for (size_t i = 0; i < suite_duration_vec_size; i++) {
-        if (suite_duration_vec_[i].first == s)
-            return suite_duration_vec_[i].second;
-    }
-    return max_sim_duration_;
-}
-
-void SimulatorVisitor::visitFamily(Family* f) {
-    visitNodeContainer(f);
-}
-
-void SimulatorVisitor::visitNodeContainer(NodeContainer* nc) {
-    if (ci_ == hours(1))
-        nc->get_time_resolution_for_simulation(ci_);
-    if (!has_end_clock_)
-        nc->get_max_simulation_duration(max_suite_duration_);
-
-    if (!nc->crons().empty()) {
-        foundCrons_ = true;
-        std::stringstream ss;
-        ss << defs_filename_ << ": Found crons on NodeContainer\n";
-        log(Log::MSG, ss.str());
-    }
-
-    if (!nc->timeVec().empty()) {
-        foundTime_ = true;
-    }
-
-    for (node_ptr t : nc->nodeVec()) {
-        t->acceptVisitTraversor(*this);
-    }
-}
-
-void SimulatorVisitor::visitTask(Task* t) {
-    if (ci_ == hours(1))
-        t->get_time_resolution_for_simulation(ci_);
-    if (!has_end_clock_)
-        t->get_max_simulation_duration(max_suite_duration_);
-
-    foundTasks_ = true;
-
-    if (!t->crons().empty()) {
-        foundCrons_ = true;
-    }
-    if (!t->timeVec().empty()) {
-        foundTime_ = true;
-    }
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/CSim/src/ecflow/simulator/SimulatorVisitor.hpp 5.13.0-1/CSim/src/ecflow/simulator/SimulatorVisitor.hpp
--- 5.12.4-1/CSim/src/ecflow/simulator/SimulatorVisitor.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/src/ecflow/simulator/SimulatorVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,82 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_simulator_SimulatorVisitor_HPP
-#define ecflow_simulator_SimulatorVisitor_HPP
-
-#include <vector>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/node/NodeTreeVisitor.hpp"
-
-class Defs;
-class Family;
-class NodeContainer;
-class Suite;
-class Task;
-
-namespace ecf {
-
-class SimulatorVisitor final : public NodeTreeVisitor {
-public:
-    explicit SimulatorVisitor(const std::string& defs_filename);
-
-    /// If we have crons and no endclock then show error message
-    const std::string& errors_found() const { return error_msg_; }
-
-    /// Crons run for ever. Detect them so that we can abort early
-    bool foundCrons() const { return foundCrons_; }
-
-    /// returns true if defs has time,date,today, date time based attributes
-    bool hasTimeDependencies() const { return hasTimeDependencies_; }
-
-    /// Determine the max simulation period in hours over all the suites.
-    /// We will default to a year( 8784 =  366 X 24)
-    /// However by going through and looking at the repeats, we can get a better idea
-    boost::posix_time::time_duration maxSimulationPeriod() const { return max_sim_duration_; }
-
-    /// return the max simulation period for the given suite.
-    /// Allow definition with multiple suite with different simulation periods
-    boost::posix_time::time_duration max_simulation_period(Suite* s) const;
-
-    // default calendar increment is one minute, however if we have no time dependencies,
-    // then simulation can be speeded up, i.e by using hour increment
-    const boost::posix_time::time_duration& calendarIncrement() const { return ci_; }
-
-    bool traverseObjectStructureViaVisitors() const override { return true; }
-    void visitDefs(Defs*) override;
-    void visitSuite(Suite*) override;
-    void visitFamily(Family*) override;
-    void visitNodeContainer(NodeContainer*) override;
-    void visitTask(Task*) override;
-
-private:
-    /// Commented out since, we need to find a way of truncating lon repeats
-    /// without changing repeat structure.
-    //	void analyse(Node* node);
-    //	int truncateRepeats_;  // allow for simulation to complete earlier. ***NOT USED, kept for reference *****
-
-    std::string defs_filename_;
-    std::string error_msg_;
-    bool foundTasks_;
-    bool foundCrons_;
-    bool foundTime_;
-    bool hasTimeDependencies_;
-    bool has_end_clock_;
-    boost::posix_time::time_duration max_sim_duration_;
-    boost::posix_time::time_duration max_suite_duration_;
-    boost::posix_time::time_duration ci_;
-    std::vector<std::pair<Suite*, boost::posix_time::time_duration>> suite_duration_vec_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_simulator_SimulatorVisitor_HPP */
diff -pruN 5.12.4-1/CSim/test/TestAnalysis.cpp 5.13.0-1/CSim/test/TestAnalysis.cpp
--- 5.12.4-1/CSim/test/TestAnalysis.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestAnalysis.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,76 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_Analysis)
-
-/// Use this class to test single simulation of definition file that we want to add
-/// to Test Simulator. This is a separate exe
-
-BOOST_AUTO_TEST_CASE(test_analysys) {
-    cout << "Simulator:: ...test_analysys\n";
-    // suite suite
-    //   family family
-    //     task t1
-    //       trigger t2 == complete
-    //     task t2
-    //       trigger t1 == complete
-    //   endfamily
-    // endsuite
-
-    // This simulation is expected to fail, since we have a deadlock/ race condition
-    // It will prodice a defs.depth and defs.flat files. Make sure to remove them
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_analysys");
-        family_ptr fam  = suite->add_family("family");
-
-        task_ptr task1 = fam->add_task("t1");
-        task1->add_trigger("t2 == complete");
-
-        task_ptr task2 = fam->add_task("t2");
-        task2->add_trigger("t1 == complete");
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(!simulator.run(theDefs, findTestDataLocation("test_analysys.def"), errorMsg), errorMsg);
-
-    fs::remove("defs.depth");
-    fs::remove("defs.flat");
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_analysys.def") + ".log";
-    fs::remove(logFileName);
-
-    /// Destroy singleton's to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestAutoArchive.cpp 5.13.0-1/CSim/test/TestAutoArchive.cpp
--- 5.12.4-1/CSim/test/TestAutoArchive.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestAutoArchive.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,314 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-/// Simulate definition files that are created on then fly. This allows us to validate
-/// Defs file, to check for correctness
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_AutoArchive)
-
-BOOST_AUTO_TEST_CASE(test_autoarchive_suite) {
-    cout << "Simulator:: ...test_autoarchive_suite\n";
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autoarchive at hour resolution
-    Defs theDefs;
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
-                                                      File::test_data("CSim/test", "CSim")); // required for archive
-    suite_ptr s1, s2, s3;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        s1 = theDefs.add_suite("test_autoarchive_10_hours_relative");
-        s1->addClock(clockAttr);
-        s1->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(10, 0), true));
-        s1->add_family("family")->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        s2 = theDefs.add_suite("test_autoarchive_1_hours_real");
-        s2->addClock(clockAttr);
-        s2->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), false));
-        s2->add_family("family")->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        s3 = theDefs.add_suite("test_autoarchive_1_day_relative");
-        s3->addClock(clockAttr);
-        s3->add_autoarchive(ecf::AutoArchiveAttr(1));
-        s3->add_family("family")->add_task("t");
-        //       cout << theDefs << "\n";
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autoarchive_suite.def"), errorMsg), errorMsg);
-
-    // make sure autoarchive archives the suite.
-    BOOST_CHECK_MESSAGE(s1->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << s1->absNodePath() << " to be archived");
-    BOOST_CHECK_MESSAGE(s2->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << s2->absNodePath() << " to be archived");
-    BOOST_CHECK_MESSAGE(s3->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << s3->absNodePath() << " to be archived");
-
-    BOOST_CHECK_MESSAGE(fs::exists(s1->archive_path()), "Expected suite " << s1->absNodePath() << " to be archived");
-    BOOST_CHECK_MESSAGE(fs::exists(s2->archive_path()), "Expected suite " << s2->absNodePath() << " to be archived");
-    BOOST_CHECK_MESSAGE(fs::exists(s3->archive_path()), "Expected suite " << s3->absNodePath() << " to be archived");
-
-    BOOST_CHECK_MESSAGE(s1->nodeVec().empty(), "Expected suite " << s1->absNodePath() << " to be empty");
-    BOOST_CHECK_MESSAGE(s1->nodeVec().empty(), "Expected suite " << s2->absNodePath() << " to be empty");
-    BOOST_CHECK_MESSAGE(s1->nodeVec().empty(), "Expected suite " << s3->absNodePath() << " to be empty");
-
-    s1->restore();
-    s2->restore();
-    s3->restore();
-
-    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << s1->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(!s2->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << s2->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(!s3->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << s3->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(s1->get_flag().is_set(ecf::Flag::RESTORED),
-                        "Expected suite " << s1->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(s2->get_flag().is_set(ecf::Flag::RESTORED),
-                        "Expected suite " << s2->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(s3->get_flag().is_set(ecf::Flag::RESTORED),
-                        "Expected suite " << s3->absNodePath() << " to be restored");
-
-    BOOST_CHECK_MESSAGE(!fs::exists(s1->archive_path()), "Expected file " << s1->archive_path() << " to be removed");
-    BOOST_CHECK_MESSAGE(!fs::exists(s2->archive_path()), "Expected file " << s2->archive_path() << " to be removed");
-    BOOST_CHECK_MESSAGE(!fs::exists(s3->archive_path()), "Expected file " << s3->archive_path() << " to be removed");
-
-    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s1->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s2->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s3->absNodePath() << " to be restored");
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autoarchive_suite.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_autoarchive_ast_node_reset) {
-    cout << "Simulator:: ...test_autoarchive_ast_node_reset\n";
-
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autoarchive at hour resolution
-    Defs theDefs;
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
-                                                      File::test_data("CSim/test", "CSim")); // required for archive
-
-    suite_ptr suite_s2;
-    suite_ptr suite_s3;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("s1");
-        suite->addClock(clockAttr);
-        suite->addDefStatus(DState::COMPLETE);
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t")->add_trigger("/s2/family/t == complete");
-
-        task_ptr task2 = fam->add_task("t2");
-        task2->add_trigger("/s3/family/t == complete");
-        //    cout << theDefs << "\n";
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_s2 = theDefs.add_suite("s2");
-        suite_s2->addClock(clockAttr);
-        suite_s2->add_autoarchive(ecf::AutoArchiveAttr(0)); // archive on next calendar update
-        suite_s2->add_family("family")->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_s3 = theDefs.add_suite("s3");
-        suite_s3->addClock(clockAttr);
-        suite_s3->add_autoarchive(ecf::AutoArchiveAttr(0)); // archive on next calendar update
-        suite_s3->add_family("family")->add_task("t");
-    }
-
-    // Check number of AST nodes. The AST should be created on the fly
-    std::set<Node*> theSet;
-    theDefs.getAllAstNodes(theSet);
-    BOOST_CHECK_MESSAGE(theSet.size() == 2,
-                        "Expected to have 2 AST nodes in trigger/complete expressions but found " << theSet.size());
-
-    // Run the simulator
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autoarchive_ast_node_reset.def"), errorMsg),
-                        errorMsg);
-
-    // Auto archive should archive suite s2 and s3, leaving one suite i.e s1
-    const std::vector<suite_ptr>& suites = theDefs.suiteVec();
-    for (const auto& suite : suites) {
-        if (suite->name() == "s2" || suite->name() == "s3") {
-            BOOST_CHECK_MESSAGE(suite->get_flag().is_set(ecf::Flag::ARCHIVED),
-                                "Expected suite " << suite->absNodePath() << " to be archived");
-        }
-    }
-
-    // The references to nodes in suites s2, s3 should have been cleared in suite s1
-    {
-        std::set<Node*> theSet;
-        theDefs.getAllAstNodes(theSet);
-        BOOST_CHECK_MESSAGE(theSet.empty(),
-                            "Expected to have 0 AST nodes in trigger/complete expressions but found " << theSet.size());
-    }
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autocancel_ast_node_reset.def") + ".log";
-    fs::remove(logFileName);
-    fs::remove(suite_s2->archive_path()); // remove generated archive files
-    fs::remove(suite_s3->archive_path()); // remove generated archive files
-}
-
-BOOST_AUTO_TEST_CASE(test_autoarchive_family) {
-    cout << "Simulator:: ...test_autoarchive_family\n";
-    Defs theDefs;
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
-                                                      File::test_data("CSim/test", "CSim")); // required for archive
-
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autoarchive_family");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(10, 0), true));
-        task_ptr task = fam->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autoarchive_1_2_hours_real");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(2, 0), false));
-        task_ptr task = fam->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        ClockAttr end_clock(true);
-        end_clock.date(14, 10, 2009); // 14 October 2009 was a Wednesday
-
-        suite_ptr suite = theDefs.add_suite("test_autoarchive_1_2_day_relative");
-        suite->addClock(clockAttr);
-        suite->add_end_clock(end_clock);
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_autoarchive(ecf::AutoArchiveAttr(2)); // 2 days
-        fam->add_task("t");
-    }
-    // cout << theDefs << "\n";
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autoarchive_family.def"), errorMsg),
-                        errorMsg);
-
-    // make sure all familes has been archived
-    std::vector<Family*> famVec;
-    theDefs.getAllFamilies(famVec);
-    for (auto f : famVec) {
-        BOOST_CHECK_MESSAGE(f->get_flag().is_set(ecf::Flag::ARCHIVED),
-                            "Expected family " << f->absNodePath() << " to be archived");
-        BOOST_CHECK_MESSAGE(fs::exists(f->archive_path()), "Expected family " << f->absNodePath() << " to be archived");
-        BOOST_CHECK_MESSAGE(f->nodeVec().empty(), "Expected family " << f->absNodePath() << " to be empty");
-
-        f->restore();
-        BOOST_CHECK_MESSAGE(f->get_flag().is_set(ecf::Flag::RESTORED),
-                            "Expected family " << f->absNodePath() << " to be restored");
-        BOOST_CHECK_MESSAGE(!f->get_flag().is_set(ecf::Flag::ARCHIVED),
-                            "Expected family " << f->absNodePath() << " to be restored");
-        BOOST_CHECK_MESSAGE(!fs::exists(f->archive_path()), "Expected file " << f->absNodePath() << " to be removed");
-        BOOST_CHECK_MESSAGE(!f->nodeVec().empty(), "Expected family " << f->absNodePath() << " to be restored");
-    }
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autoarchive_family_and_task.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_two_autoarchive_in_hierarchy) {
-    cout << "Simulator:: ...test_two_autoarchive_in_hierarchy\n";
-    Defs theDefs;
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
-                                                      File::test_data("CSim/test", "CSim")); // required for archive
-
-    suite_ptr suite;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite = theDefs.add_suite("test_two_autoarchive_in_hierarchy");
-        suite->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
-        task_ptr task = fam->add_task("t");
-    }
-    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
-    //   cout << theDefs;
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_two_autoarchive_in_hierarchy.def"), errorMsg),
-                        errorMsg);
-
-    // Check ONLY the suite got archived an not family
-    BOOST_CHECK_MESSAGE(suite->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << suite->absNodePath() << " to be archived");
-    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()),
-                        "Expected family " << suite->absNodePath() << " to be archived");
-    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Expected family " << suite->absNodePath() << " to be empty");
-
-    // The family should have been deleted
-    node_ptr fam = theDefs.findAbsNode("/test_two_autoarchive_in_hierarchy/family");
-    BOOST_CHECK_MESSAGE(!fam, "Expected family to be deleted");
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_two_autoarchive_in_hierarchy.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestAutoCancel.cpp 5.13.0-1/CSim/test/TestAutoCancel.cpp
--- 5.12.4-1/CSim/test/TestAutoCancel.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestAutoCancel.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,318 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-/// Simulate definition files that are created on then fly. This us to validate
-/// Defs file, to check for correctness
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_AutoCancel)
-
-BOOST_AUTO_TEST_CASE(test_autocancel_ast_node_reset) {
-    cout << "Simulator:: ...test_autocancel_ast_node_reset\n";
-
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autocancel at hour resolution
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("s1");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->add_trigger("/s2/family/t == complete");
-
-        task_ptr task2 = fam->add_task("t2");
-        task2->add_trigger("/s3/family/t == complete");
-        task2->add_complete("/s2/family == complete");
-
-        task_ptr task3 = fam->add_task("t3");
-        task3->add_trigger("/s3 == complete");
-        task3->add_complete("/s2 == complete");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-
-        suite_ptr suite = theDefs.add_suite("s2");
-        suite->addClock(clockAttr);
-        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("s3");
-        suite->addClock(clockAttr);
-        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t");
-    }
-
-    // Check number of AST nodes. The AST should be created on the fly
-    std::set<Node*> theSet;
-    theDefs.getAllAstNodes(theSet);
-    BOOST_CHECK_MESSAGE(theSet.size() == 5,
-                        "Expected to have 5 AST nodes in trigger/complete expressions but found " << theSet.size());
-
-    // Run the simulator
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_ast_node_reset.def"), errorMsg),
-                        errorMsg);
-
-    // Auto cancel should delete suite s2 and s3, leaving one suite i.e s1
-    BOOST_CHECK_MESSAGE(theDefs.suiteVec().size() == 1,
-                        "Expected to have 1 suites but found " << theDefs.suiteVec().size());
-
-    // The references to nodes in suites s2, s3 should have been cleared in suite s1
-    {
-        std::set<Node*> theSet;
-        theDefs.getAllAstNodes(theSet);
-        BOOST_CHECK_MESSAGE(theSet.empty(),
-                            "Expected to have 0 AST nodes in trigger/complete expressions but found " << theSet.size());
-    }
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autocancel_ast_node_reset.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_autocancel_suite) {
-    cout << "Simulator:: ...test_autocancel_suite\n";
-
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autocancel at hour resolution
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_10_hours_relative");
-        suite->addClock(clockAttr);
-        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(10, 0), true));
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_1_hours_real");
-        suite->addClock(clockAttr);
-        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t");
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_1_day_relative");
-        suite->addClock(clockAttr);
-        suite->addAutoCancel(ecf::AutoCancelAttr(1));
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t");
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_suite.def"), errorMsg), errorMsg);
-
-    // make sure autocancel deletes the suite.
-    BOOST_CHECK_MESSAGE(theDefs.suiteVec().size() == 0,
-                        "Expected to have 0 suites but found " << theDefs.suiteVec().size());
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autocancel_suite.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_autocancel_family_and_task) {
-    cout << "Simulator:: ...test_autocancel_family_and_task\n";
-
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autocancel at hour resolution
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_9_10_hours_relative");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(10, 0), true));
-
-        task_ptr task = fam->add_task("t");
-        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(9, 0), true));
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_1_2_hours_real");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(2, 0), false));
-
-        task_ptr task = fam->add_task("t");
-        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        ClockAttr end_clock(true);
-        end_clock.date(14, 10, 2009); // 14 October 2009 was a Wednesday
-
-        suite_ptr suite = theDefs.add_suite("test_autocancel_1_2_day_relative");
-        suite->addClock(clockAttr);
-        suite->add_end_clock(end_clock);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addAutoCancel(ecf::AutoCancelAttr(2)); // 2 days
-
-        task_ptr task = fam->add_task("t");
-        task->addAutoCancel(ecf::AutoCancelAttr(1)); // 1 days
-    }
-    // cout << theDefs << "\n";
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_family_and_task.def"), errorMsg),
-                        errorMsg);
-
-    // make sure autocancel deletes the families.
-    std::vector<Family*> famVec;
-    theDefs.getAllFamilies(famVec);
-    BOOST_CHECK_MESSAGE(famVec.size() == 0,
-                        "Expected to have 0 families but found " << famVec.size() << "\n"
-                                                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autocancel_family_and_task.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_autocancel_task) {
-    cout << "Simulator:: ...test_autocancel_task\n";
-
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autocancel at hour resolution
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_10_hours_relative");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(10, 0), true));
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_1_hours_real");
-        suite->addClock(clockAttr);
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
-    }
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autocancel_1_day_relative");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addAutoCancel(ecf::AutoCancelAttr(1));
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_task.def"), errorMsg), errorMsg);
-
-    // make sure autocancel deletes the tasks and leaves families intact.
-    std::vector<task_ptr> task_vec;
-    theDefs.get_all_tasks(task_vec);
-
-    std::vector<Family*> famVec;
-    theDefs.getAllFamilies(famVec);
-
-    BOOST_CHECK_MESSAGE(famVec.size() == 3, "Expected to have 3 families but found " << famVec.size());
-    BOOST_CHECK_MESSAGE(task_vec.size() == 0, "Expected to have 0 tasks but found " << task_vec.size());
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autocancel_task.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_two_autocancel_in_hierarchy) {
-    cout << "Simulator:: ...test_two_autocancel_in_hierarchy\n"; // ECFLOW-556
-
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autocancel at hour resolution
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_two_autocancel_in_hierarchy");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), true));
-        task_ptr task = fam->add_task("t");
-        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), true));
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_two_autocancel_in_hierarchy.def"), errorMsg),
-                        errorMsg);
-
-    std::vector<task_ptr> task_vec;
-    theDefs.get_all_tasks(task_vec);
-
-    std::vector<Family*> famVec;
-    theDefs.getAllFamilies(famVec);
-
-    BOOST_CHECK_MESSAGE(famVec.size() == 0, "Expected to have 0 families but found " << famVec.size());
-    BOOST_CHECK_MESSAGE(task_vec.size() == 0, "Expected to have 0 tasks but found " << task_vec.size());
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_two_autocancel_in_hierarchy.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestAutoRestore.cpp 5.13.0-1/CSim/test/TestAutoRestore.cpp
--- 5.12.4-1/CSim/test/TestAutoRestore.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestAutoRestore.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,172 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-/// Simulate definition files that are created on then fly. This allows us to validate
-/// Defs file, to check for correctness
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_AutoRestore)
-
-BOOST_AUTO_TEST_CASE(test_autorestore_suite) {
-    cout << "Simulator:: ...test_autorestore_suite\n";
-    // ****: Since we have no time dependencies the simulator calendar increment
-    // ****: is in hours. Hence autoarchive at hour resolution
-    Defs theDefs;
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
-                                                      File::test_data("CSim/test", "CSim")); // required for archive
-    string s1_path;
-    {
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr s1 = theDefs.add_suite("test_autorestore_suite");
-        s1->addClock(clockAttr);
-        s1->add_autoarchive(ecf::AutoArchiveAttr(0));
-        s1->add_family("family")->add_task("t");
-        s1_path = s1->absNodePath();
-    }
-    {
-        std::vector<std::string> nodes_to_restore;
-        nodes_to_restore.push_back(s1_path);
-        ClockAttr clockAttr(true);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr s3 = theDefs.add_suite("test_autorestore_suite_2");
-        s3->addClock(clockAttr);
-        task_ptr t1 = s3->add_family("family")->add_task("t");
-        t1->add_autorestore(ecf::AutoRestoreAttr(nodes_to_restore));
-        t1->add_trigger("/test_autorestore_suite == complete");
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autorestore_suite.def"), errorMsg), errorMsg);
-
-    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
-    //   cout << theDefs;
-
-    // suite test_autorestore_suite, should have been archived then restored
-    suite_ptr s1 = theDefs.findSuite("test_autorestore_suite");
-    BOOST_REQUIRE_MESSAGE(s1, "Expected to find suite s1");
-    BOOST_CHECK_MESSAGE(s1->get_flag().is_set(ecf::Flag::RESTORED),
-                        "Expected suite " << s1->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::ARCHIVED),
-                        "Expected suite " << s1->absNodePath() << " to be restored");
-    BOOST_CHECK_MESSAGE(!fs::exists(s1->archive_path()), "Expected file " << s1->archive_path() << " to be removed");
-    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s1->absNodePath() << " to be restored");
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autorestore_suite.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_autorestore_family) {
-    cout << "Simulator:: ...test_autorestore_family\n";
-
-    // *** Autoarchiving takes place in Defs::updatecalendar(..) which happens every 60/seconds
-    // *** Autorestore   takes place immediately after state change, hence if could occur before updateCalendar has run
-    // ***               hence in this test we use time attributes, to ensure the updateCalendar/autoarchive is run
-    // before
-    // ***               autorestore
-    Defs theDefs;
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
-                                                      File::test_data("CSim/test", "CSim")); // required for archive
-
-    std::vector<std::string> vec;
-    {
-        ClockAttr clockAttr(false);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autoarchive_family");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_autoarchive(AutoArchiveAttr(0));
-        task_ptr task = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(1, 0, true));
-        vec.push_back(fam->absNodePath());
-    }
-    {
-        ClockAttr clockAttr(false);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_autoarchive_family_1");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(2, 0), false));
-        task_ptr task = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(1, 0, true));
-        vec.push_back(fam->absNodePath());
-    }
-    {
-        ClockAttr clockAttr(false);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        ClockAttr end_clock(false);
-        end_clock.date(14, 10, 2009); // 14 October 2009 was a Wednesday
-
-        suite_ptr suite = theDefs.add_suite("test_autoarchive_family_2");
-        suite->addClock(clockAttr);
-        suite->add_end_clock(end_clock);
-
-        family_ptr fam = suite->add_family("do_autorestore");
-        task_ptr t     = fam->add_task("t");
-        t->add_autorestore(ecf::AutoRestoreAttr(vec));
-        t->add_trigger(vec[0] + " == complete and " + vec[1] + " == complete");
-        t->addTime(ecf::TimeAttr(2, 0, true)); // make sure we finish 1 hour after, since restore is immediate
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autorestore_family.def"), errorMsg),
-                        errorMsg);
-    // PrintStyle::setStyle(PrintStyle::MIGRATE);
-    // cout << theDefs;
-
-    // make sure all familes has been archived
-    std::vector<Family*> famVec;
-    theDefs.getAllFamilies(famVec);
-    for (auto f : famVec) {
-        if (f->name() == "do_autorestore")
-            continue;
-        BOOST_CHECK_MESSAGE(f->get_flag().is_set(ecf::Flag::RESTORED),
-                            "Expected family " << f->absNodePath() << " to be restored");
-        BOOST_CHECK_MESSAGE(!f->get_flag().is_set(ecf::Flag::ARCHIVED),
-                            "Expected family " << f->absNodePath() << " to be restored");
-        BOOST_CHECK_MESSAGE(!fs::exists(f->archive_path()), "Expected file " << f->absNodePath() << " to be removed");
-        BOOST_CHECK_MESSAGE(!f->nodeVec().empty(), "Expected family " << f->absNodePath() << " to be restored");
-    }
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_autorestore_family.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestMeter.cpp 5.13.0-1/CSim/test/TestMeter.cpp
--- 5.12.4-1/CSim/test/TestMeter.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestMeter.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,100 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-/// Simulate definition files that are created on then fly. This us to validate
-/// Defs file, to check for correctness
-
-BOOST_AUTO_TEST_SUITE(SimulatorTestSuite)
-
-BOOST_AUTO_TEST_CASE(test_meter) {
-    cout << "Simulator:: ...test_meter\n";
-
-    // suite suite
-    //   clock real <todays date>
-    //   family family
-    //     task fc
-    //       meter hour 0 240
-    //       task half
-    //         trigger fc:hour >= 120
-    //   endfamily
-    // endsuite
-
-    // Initialise clock with todays date  then create a time attribute + minutes
-    // such that the task should only run once, in the next minute
-    boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
-
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(theLocalTime);
-        suite_ptr suite = theDefs.add_suite("test_meter");
-        suite->addClock(clockAttr);
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        family_ptr fam = suite->add_family("family");
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        task_ptr fc = fam->add_task("fc");
-        fc->addMeter(Meter("hour", 0, 240, 240));
-        fc->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        task_ptr half = fam->add_task("half");
-        half->add_trigger("fc:hour >= 120");
-        half->addVerify(VerifyAttr(NState::COMPLETE, 1));
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_meter.def"), errorMsg), errorMsg);
-
-    // The simulator will set all the meter values, so final value must be the max value.
-    bool found_task = false;
-    std::vector<Task*> theServerTasks;
-    theDefs.getAllTasks(theServerTasks);
-    for (Task* t : theServerTasks) {
-        if (t->name() == "fc") {
-            found_task                       = true;
-            const std::vector<Meter>& meters = t->meters();
-            BOOST_REQUIRE_MESSAGE(meters.size() == 1, "Expected one meter but found " << meters.size());
-            BOOST_CHECK_MESSAGE(meters[0].value() == meters[0].max(),
-                                "Expected meter to have value of " << meters[0].max() << " but found "
-                                                                   << meters[0].value());
-        }
-    }
-    BOOST_REQUIRE_MESSAGE(found_task, "Failed to find task fc ");
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_meter.def") + ".log";
-    fs::remove(logFileName);
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestRepeat.cpp 5.13.0-1/CSim/test/TestRepeat.cpp
--- 5.12.4-1/CSim/test/TestRepeat.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestRepeat.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,508 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-/// Simulate definition files that are created on then fly. This us to validate
-/// Defs file, to check for correctness
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_Repeat)
-
-BOOST_AUTO_TEST_CASE(test_repeat_integer) {
-    cout << "Simulator:: ...test_repeat_integer\n";
-
-    // suite suite
-    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     repeat integer VAR 0 1 1     # run at 0, 1     2 times
-    //     task t<n>
-    //     ....
-    //   endfamily
-    // endsuite
-
-    // Each task/job should be run *4* times, according to the repeats
-    // Mimics nested loops
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("suite");
-        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat contents 2 times
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1));   // repeat contents 2 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 4)); // verify family repeats 2 times
-        int taskSize = 2;
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr t = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            t->addVerify(VerifyAttr(NState::COMPLETE, 4)); // Each task should run 4 times
-        }
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_integer.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_integer.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_integer_relative) {
-    cout << "Simulator:: ...test_repeat_integer_relative\n";
-
-    // suite suite
-    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     repeat integer VAR 0 1 1     # run at 0, 1     2 times
-    //     task t1
-    //       time +0;02
-    //   endfamily
-    // endsuite
-
-    // Each task/job should be run *4* times relative to Node times, according to the repeats
-    // Mimics nested loops
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true /*false means use hybrid clock*/);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_repeat_integer_relative");
-        suite->addClock(clockAttr);
-        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat contents 2 times
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat contents 2 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 4));
-
-        task_ptr t = fam->add_task("t1");
-        t->addTime(ecf::TimeAttr(TimeSlot(0, 2), true /*relative*/));
-        t->addVerify(VerifyAttr(NState::COMPLETE, 4)); // Each task should run 4 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_integer_relative.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_integer_relative.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date) {
-    cout << "Simulator:: ...test_repeat_date\n";
-    // suite suite
-    //   clock real <fixed date + time>
-    //   family family
-    //     repeat date YMD 20091001  20091015 1  # yyyymmdd
-    //     task t
-    //       time 10:00
-    //   endfamily
-    // endsuite
-
-    // Each task should be run 15 times, ie every day at 10.00 am from  1st Oct->15 October 15 times
-    Defs theDefs;
-    {
-        ClockAttr clockAttr;
-        clockAttr.date(1, 10, 2009);
-        suite_ptr suite = theDefs.add_suite("test_repeat_date");
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatDate("YMD", 20091001, 20091015, 1)); // repeat contents 15 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 15));
-
-        task_ptr task = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 15)); // task should complete 15 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_date.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_2) {
-    cout << "Simulator:: ...test_repeat_date_2\n";
-    // suite suite
-    //   clock real <fixed date + time>
-    //   family family
-    //     repeat date YMD 20091015 20091001 -1
-    //     task t
-    //        time 10:00
-    //     endfamily
-    // endsuite
-
-    // Each task should be run 15 times, ie every day at 10.00 am
-    Defs theDefs;
-    {
-        ClockAttr clockAttr;
-        clockAttr.date(1, 10, 2015);
-        suite_ptr suite = theDefs.add_suite("test_repeat_date");
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatDate("YMD", 20091015, 20091001, -1)); // repeat contents 15 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 15));
-
-        task_ptr task = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 15)); // task should complete 15 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_date.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_for_loop) {
-    cout << "Simulator:: ...test_repeat_date_for_loop\n";
-
-    // suite suite
-    //   clock real <todays date>
-    //   repeat date YMD 20091001  20091005 1  # yyyymmdd
-    //   family family
-    //     repeat date YMD 20091001  20091005 1  # yyyymmdd
-    //     task t
-    //       time 10:00
-    //   endfamily
-    // endsuite
-
-    // Each task should be run 5 * 5= 25 times, ie every day from from 1st Oct -> 5 Oct 5*5 times
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_repeat_date_for_loop");
-        suite->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 5));
-
-        // start at specific time other wise time dependent checks will not verify
-        ClockAttr clockAttr;
-        clockAttr.date(1, 10, 2009);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 25));
-
-        task_ptr task = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 25)); // task should complete 25 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date_for_loop.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_date_for_loop.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_for_loop2) {
-    cout << "Simulator:: ...test_repeat_date_for_loop2\n";
-
-    // suite suite
-    //   clock real <todays date>
-    //   repeat date YMD 20091001  20091005 1  # yyyymmdd
-    //   family family
-    //     repeat date YMD 20091001  20091005 1  # yyyymmdd
-    //     task t
-    //       time 10:00
-    //       time 11:00
-    //   endfamily
-    // endsuite
-
-    // Each task should be run 5 * 5 * 2 = 50 times, ie every day from from 1st Oct -> 5 Oct 5*5 times * 2 time slots
-    Defs theDefs;
-    {
-        // start at specific time other wise time dependent checks will not verify
-        suite_ptr suite = theDefs.add_suite("test_repeat_date_for_loop2");
-        suite->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 5));
-
-        ClockAttr clockAttr;
-        clockAttr.date(1, 10, 2009);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 25));
-
-        task_ptr task = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
-        task->addTime(ecf::TimeAttr(TimeSlot(11, 0)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 50)); // task should complete 50 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date_for_loop2.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_date_for_loop2.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_list) {
-    cout << "Simulator:: ...test_repeat_date_list\n";
-    // suite suite
-    //   clock real <fixed date + time>
-    //   family family
-    //     repeat datelist YMD 20091001 20181001 20101001 # yyyymmdd
-    //     task t
-    //       time 10:00
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        ClockAttr clockAttr;
-        clockAttr.date(1, 10, 2009);
-        suite_ptr suite = theDefs.add_suite("test_repeat_date_list");
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatDateList("YMD", {20091001, 20181001, 20101001}));
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 3));
-
-        task_ptr task = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 15 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_date.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_with_cron) {
-    cout << "Simulator:: ...test_repeat_with_cron\n";
-    // suite s
-    //   clock real <today date>
-    //   endclock <today date> + 1 week
-    //   family f
-    //     repeat date YMD 20091001 20091004 1  # yyyymmdd
-    //     family plot
-    //       complete plot/finish == complete
-    //
-    //       task finish
-    //         trigger 1 == 0    # stops task from running
-    //         complete checkdata::done or checkdata == complete
-    //
-    //       task checkdata
-    //         event done
-    //         cron <today date> + 2 minutes     # cron that run forever
-    //      endfamily
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        boost::posix_time::ptime theLocalTime       = Calendar::second_clock_time();
-        boost::posix_time::ptime time_plus_2_minute = theLocalTime + minutes(2);
-        ClockAttr clockAttr(theLocalTime, false /* real clock*/);
-        ClockAttr end_clock(theLocalTime + hours(24 * 7), false /* real clock*/);
-
-        suite_ptr suite = theDefs.add_suite("test_repeat_with_cron");
-        suite->addClock(clockAttr);
-        suite->add_end_clock(end_clock);
-
-        family_ptr f = suite->add_family("f");
-        f->addRepeat(RepeatDate("YMD", 20091001, 20091004, 1)); // repeat contents 4 times
-        f->addVerify(VerifyAttr(NState::COMPLETE, 4));
-
-        family_ptr family_plot = f->add_family("plot");
-        family_plot->add_complete("plot/finish ==  complete");
-        family_plot->addVerify(VerifyAttr(NState::COMPLETE, 4));
-
-        task_ptr task_finish = family_plot->add_task("finish");
-        task_finish->add_trigger("1 == 0");
-        task_finish->add_complete("checkdata:done or checkdata == complete");
-        task_finish->addVerify(VerifyAttr(NState::COMPLETE, 4));
-
-        task_ptr task_checkdata = family_plot->add_task("checkdata");
-        task_checkdata->addEvent(Event(1, "done"));
-
-        CronAttr cronAttr;
-        cronAttr.addTimeSeries(ecf::TimeSeries(ecf::TimeSlot(time_plus_2_minute.time_of_day())));
-        task_checkdata->addCron(cronAttr);
-        task_checkdata->addVerify(VerifyAttr(NState::COMPLETE, 8));
-
-        //		cout << theDefs << "\n";
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_with_cron.def"), errorMsg),
-                          errorMsg << "\n"
-                                   << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_with_cron.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_enumerated) {
-    cout << "Simulator:: ...test_repeat_enumerated\n";
-    // suite suite
-    //   family family
-    //     repeat enumerated ENUM "hello" "there" "bill" # run 3 times
-    //     task t1
-    //   endfamily
-    // endsuite
-
-    // Each task/job should be run 3 according to the repeats
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_repeat_enumerated");
-
-        std::vector<std::string> theEnums;
-        theEnums.emplace_back("hello"); // index 0
-        theEnums.emplace_back("there"); // index 1
-        theEnums.emplace_back("bill");  // index 2
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatEnumerated("ENUM", theEnums)); // repeat contents 3 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 3));
-
-        task_ptr task = fam->add_task("t1");
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3));
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_enumerated.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    std::vector<Task*> theServerTasks;
-    theDefs.getAllTasks(theServerTasks);
-    for (Task* t : theServerTasks) {
-        // verify repeat has the last value
-        auto* family         = dynamic_cast<Family*>(t->parent());
-        const Repeat& repeat = family->findRepeat("ENUM");
-        BOOST_REQUIRE_MESSAGE(!repeat.empty(), "Expected to find repeat on family " << family->absNodePath());
-        BOOST_REQUIRE_MESSAGE(!repeat.valid(), "Expected invalid repeat");
-        BOOST_REQUIRE_MESSAGE(repeat.value() == 3, "Expected to find repeat with value 3 but found " << repeat.value());
-        BOOST_REQUIRE_MESSAGE(repeat.last_valid_value() == 2,
-                              "Expected to find repeat with last valid value 2 but found "
-                                  << repeat.last_valid_value());
-    }
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_enumerated.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_string) {
-    cout << "Simulator:: ...test_repeat_string\n";
-    // suite suite
-    //   family family
-    //     repeat string STRING "hello" "there" # run 2 times
-    //     task t1
-    //   endfamily
-    // endsuite
-
-    // Each task/job should be run 3 according to the repeats
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_repeat_string");
-
-        std::vector<std::string> theStrings;
-        theStrings.emplace_back("hello"); // index 0
-        theStrings.emplace_back("there"); // index 1
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatString("STRING", theStrings)); // repeat contents 2 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 2));
-
-        task_ptr task = fam->add_task("t1");
-        task->addVerify(VerifyAttr(NState::COMPLETE, 2));
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_string.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    std::vector<Task*> theServerTasks;
-    theDefs.getAllTasks(theServerTasks);
-    for (Task* t : theServerTasks) {
-        // verify repeat has the last value
-        auto* family         = dynamic_cast<Family*>(t->parent());
-        const Repeat& repeat = family->findRepeat("STRING");
-        BOOST_REQUIRE_MESSAGE(!repeat.empty(), "Expected to find repeat on family " << family->absNodePath());
-        BOOST_REQUIRE_MESSAGE(!repeat.valid(), "Expected invalid repeat");
-        BOOST_REQUIRE_MESSAGE(repeat.value() == 2, "Expected to find repeat with value 2 but found " << repeat.value());
-        BOOST_REQUIRE_MESSAGE(repeat.last_valid_value() == 1,
-                              "Expected to find repeat with last valid value 1 but found "
-                                  << repeat.last_valid_value());
-    }
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_repeat_string.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestSimulator.cpp 5.13.0-1/CSim/test/TestSimulator.cpp
--- 5.12.4-1/CSim/test/TestSimulator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestSimulator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,98 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_Simulator)
-
-void simulate(const std::string& directory, bool pass) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (is_directory(dir_itr->status())) {
-                simulate(relPath.string(), pass);
-                continue;
-            }
-
-            // Only simulate file with .def file extension, i.e. ignore log files.
-            // cout << "path = " << relPath << "\n";
-            if (File::getExt(relPath.filename().string()) != "def" &&
-                File::getExt(relPath.filename().string()) != "got")
-                continue;
-
-            // std::cout << "...............Simulating file " << relPath.string() << "\n";
-            Simulator simulator;
-            std::string errorMsg;
-            bool simPass = simulator.run(relPath.string(), errorMsg);
-            if (pass) {
-                // Test expected to pass
-                BOOST_CHECK_MESSAGE(simPass, "Simulator expected to pass for " << relPath << "\n" << errorMsg);
-            }
-            else {
-                // test expected to fail
-                BOOST_CHECK_MESSAGE(!simPass, "Simulator expected to fail for " << relPath << "\n" << errorMsg);
-            }
-
-            // remove generated log file. Comment out to debug
-            std::string logFileName = relPath.string() + ".log";
-            fs::remove(logFileName);
-        }
-        catch (const std::exception& ex) {
-            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_simulate_good_defs) {
-    cout << "Simulator:: ...test_simulate_good_defs\n";
-
-    std::string path = File::test_data("CSim/test/data/good_defs", "CSim");
-
-    // All the defs in this directory are expected to pass
-    simulate(path, true);
-}
-
-BOOST_AUTO_TEST_CASE(test_simulate_bad_defs) {
-    cout << "Simulator:: ...test_simulate_bad_defs\n";
-
-    std::string path = File::test_data("CSim/test/data/bad_defs", "CSim");
-
-    // All the defs in this directory are expected to fail
-    simulate(path, false);
-
-    /// Destroy System singleton to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestSimulator_main.cpp 5.13.0-1/CSim/test/TestSimulator_main.cpp
--- 5.12.4-1/CSim/test/TestSimulator_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestSimulator_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Simulator
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/CSim/test/TestSingleSimulator.cpp 5.13.0-1/CSim/test/TestSingleSimulator.cpp
--- 5.12.4-1/CSim/test/TestSingleSimulator.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestSingleSimulator.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,92 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_SingleSimulator)
-
-BOOST_AUTO_TEST_CASE(test_analysys, *boost::unit_test::disabled()) {
-    cout << "Simulator:: ...test_analysys\n";
-    // suite suite
-    //   family family
-    //     task t1
-    //       trigger t2 == complete
-    //     task t2
-    //       trigger t1 == complete
-    //   endfamily
-    // endsuite
-
-    // This simulation is expected to fail, since we have a deadlock/ race condition
-    // It will prodice a defs.depth and defs.flat files. Make sure to remove them
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_analysys");
-        family_ptr fam  = suite->add_family("family");
-
-        task_ptr task1 = fam->add_task("t1");
-        task1->add_trigger("t2 == complete");
-
-        task_ptr task2 = fam->add_task("t2");
-        task2->add_trigger("t1 == complete");
-
-        //    cout << theDefs << "\n";
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(!simulator.run(theDefs, findTestDataLocation("test_analysys.def"), errorMsg), errorMsg);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_analysys.def") + ".log";
-    fs::remove(logFileName);
-
-    // cout << theDefs << "\n";
-    fs::remove("defs.depth");
-    fs::remove("defs.flat");
-
-    /// Destroy singleton's to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_single_from_file) {
-    cout << "Simulator:: ...test_single_from_file\n";
-
-    std::string path = File::test_data("CSim/test/data/good_defs/day/family.def", "CSim");
-
-    Simulator simulator;
-    std::string errorMsg;
-    bool passed = simulator.run(path, errorMsg);
-
-    BOOST_REQUIRE_MESSAGE(passed, path << " failed simulation \n" << errorMsg);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestSingleSimulator_main.cpp 5.13.0-1/CSim/test/TestSingleSimulator_main.cpp
--- 5.12.4-1/CSim/test/TestSingleSimulator_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestSingleSimulator_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_SingleSimulator
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/CSim/test/TestTime.cpp 5.13.0-1/CSim/test/TestTime.cpp
--- 5.12.4-1/CSim/test/TestTime.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestTime.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,395 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-/// Simulate definition files that are created on then fly. This allows us to create
-/// tests with todays date/time this speeds up the testr, we can also validate
-/// Defs file, to check for correctness
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_Time)
-
-BOOST_AUTO_TEST_CASE(test_time) {
-    cout << "Simulator:: ...test_time\n";
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       time <start>
-    //   endfamily
-    // endsuite
-
-    // Initialise clock with todays date  then create a time attribute + minutes
-    // such that the task should only run once, in the next minute
-    boost::posix_time::ptime theLocalTime     = Calendar::second_clock_time();
-    boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
-
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_time");
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_minute.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // expect task to complete 1 time
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_time.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_time_series) {
-    cout << "Simulator:: ...test_time_series\n";
-
-    // suite suite
-    //   clock real <sunday>
-    //   family family
-    //     task t1
-    //     time 00:30 23:59 04:00  # should run 6 times 00:30 4:30 8:30 12:30 16:30 20:30
-    //   endfamily
-    // endsuite
-
-    // Initialise real clock on a Moday, such that task should _only_ run
-    // on Monday since we are using a hybrid clock
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true /*false means use hybrid clock*/);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_time_series");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        TimeSeries timeSeries(TimeSlot(00, 30), TimeSlot(23, 59), TimeSlot(4, 0), false /* relative */);
-
-        task->addTime(TimeAttr(timeSeries));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 6)); // expect task to complete 6 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time_series.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_time_series.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_time_and_date) {
-    cout << "Simulator:: ...test_time_and_date\n";
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       date  <today date>
-    //       time <start>
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        // Initialise clock with todays date  then create a time attribute + minutes
-        // such that the task should only run once, in the next minute
-        boost::posix_time::ptime theLocalTime     = Calendar::second_clock_time();
-        boost::gregorian::date todaysDate         = theLocalTime.date();
-        boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
-
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite_ptr suite = theDefs.add_suite("test_time_and_date");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addDate(DateAttr(todaysDate));
-        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_minute.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // expect task to complete 1 time
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time_and_date.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_time_and_date.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_time_and_tomorrows_date) {
-    cout << "Simulator:: ...test_time_and_tomorrows_date\n";
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       date  <tomorrows date>
-    //       time <start>
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        // Initialise clock with todays date  then create a time attribute + minutes
-        // such that the task should only run once, in the next minute
-        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
-        boost::gregorian::date tomorrows_date = theLocalTime.date();
-        tomorrows_date += days(1);
-        boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
-
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite_ptr suite = theDefs.add_suite("test_time_and_tomorrows_date");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addDate(DateAttr(tomorrows_date));
-        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_minute.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // expect task to complete 1 time
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time_and_tomorrows_date.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_time_and_tomorrows_date.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_multiple_times_and_dates) {
-    cout << "Simulator:: ...test_multiple_times_and_dates\n";
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       date <today date>
-    //       date <tomorrows date>
-    //       time <start>
-    //       time <start>
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with todays date  then create a time attribute + minutes
-        // Note: we don't use:
-        //    boost::posix_time::ptime   theLocalTime =  Calendar::second_clock_time();
-        // because if run at late we can end up with illegal for the hour, ie. > 24
-
-        boost::gregorian::date todaysDate(2009, 2, 10);
-        ptime theLocalTime(todaysDate, hours(3));
-        boost::gregorian::date tomarrows_date           = todaysDate + date_duration(1);
-        boost::posix_time::time_duration td_plus_minute = theLocalTime.time_of_day() + minutes(1);
-        boost::posix_time::time_duration td_plus_hour   = theLocalTime.time_of_day() + hours(1);
-
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_dates");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addDate(DateAttr(todaysDate));
-        task->addDate(DateAttr(tomarrows_date));
-        task->addTime(TimeAttr(TimeSlot(td_plus_minute)));
-        task->addTime(TimeAttr(TimeSlot(td_plus_hour)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // expect task to complete 4 time
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_dates.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_multiple_times_and_dates.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_multiple_times_and_dates_hybrid) {
-    cout << "Simulator:: ...test_multiple_times_and_dates_hybrid\n";
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   clock hybrid <todays date>
-    //   family family
-    //     task t1
-    //       date  <today date>
-    //       date  <tomrrows date>
-    //       time <start>
-    //       time <start>
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with todays date  then create a time attribute + minutes
-        // such that the task should only run once, in the next minute
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2012, 2, 22), time_duration(10, 20, 0));
-        boost::gregorian::date todaysDate     = theLocalTime.date();
-        boost::gregorian::date tomorrows_date = todaysDate + date_duration(1);
-        boost::posix_time::time_duration td_plus_minute    = theLocalTime.time_of_day() + minutes(1);
-        boost::posix_time::time_duration td_plus_10_minute = theLocalTime.time_of_day() + minutes(10);
-
-        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_dates_hybrid");
-        suite->addClock(ClockAttr(theLocalTime, true)); // true means use hybrid clock
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addDate(DateAttr(todaysDate));
-        task->addDate(DateAttr(tomorrows_date));
-        task->addTime(TimeAttr(TimeSlot(td_plus_minute)));
-        task->addTime(TimeAttr(TimeSlot(td_plus_10_minute)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 2)); // expect task to complete 2 time
-                                                          // cout << theDefs << "\n";
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(
-        simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_dates_hybrid.def"), errorMsg),
-        errorMsg << "\n"
-                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_multiple_times_and_dates_hybrid.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_multiple_times_and_days) {
-    cout << "Simulator:: ...test_multiple_times_and_days\n";
-
-    // suite suite
-    //   clock real <sunday>
-    //   family family
-    //     rep integer 0 1 1 # repeat twice
-    //     task t1
-    //       day  monday
-    //       day  tuesday
-    //       time <start>
-    //       time <start>
-    //   endfamily
-    // endsuite
-
-    // Initialise real clock on a sunday, such that task should run on Monday & tuesday twice
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(false /*false means use real clock*/);
-        clockAttr.date(11, 10, 2009); // 11 October 2009 was a sunday
-        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_days");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        // fam->addRepeat( RepeatInteger("rep",0,1,1) );
-        task_ptr task = fam->add_task("t");
-        task->addDay(DayAttr(DayAttr::MONDAY));
-        task->addDay(DayAttr(DayAttr::TUESDAY));
-        task->addTime(TimeAttr(TimeSlot(10, 0)));
-        task->addTime(TimeAttr(TimeSlot(20, 0)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // expect task to complete 4 time
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_days.def"), errorMsg),
-                        errorMsg << "\n"
-                                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_multiple_times_and_days.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_multiple_times_and_days_hybrid) {
-    cout << "Simulator:: ...test_multiple_times_and_days_hybrid\n";
-
-    // suite suite
-    //   clock hybrid <monday>
-    //   family family
-    //     task t1
-    //       day  monday
-    //       day  tuesday
-    //       time <start>
-    //       time <start>
-    //   endfamily
-    // endsuite
-
-    // Initialise real clock on a Monday, such that task should _only_ run
-    // on Monday since we are using a hybrid clock
-    Defs theDefs;
-    {
-        ClockAttr clockAttr(true /*false means use hybrid clock*/);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_days_hybrid");
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addDay(DayAttr(DayAttr::MONDAY));
-        task->addDay(DayAttr(DayAttr::TUESDAY));
-        task->addTime(TimeAttr(TimeSlot(10, 0)));
-        task->addTime(TimeAttr(TimeSlot(11, 0)));
-        task->addTime(TimeAttr(TimeSlot(20, 0)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // expect task to complete 3 times
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(
-        simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_days_hybrid.def"), errorMsg),
-        errorMsg << "\n"
-                 << theDefs);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_multiple_times_and_days_hybrid.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestToday.cpp 5.13.0-1/CSim/test/TestToday.cpp
--- 5.12.4-1/CSim/test/TestToday.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestToday.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,160 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "TestUtil.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-/// Simulate definition files that are created on then fly. This allows us to create
-/// tests with todays date/time this speeds up the testr, we can also validate
-/// Defs file, to check for correctness
-
-BOOST_AUTO_TEST_SUITE(S_Simulator)
-
-BOOST_AUTO_TEST_SUITE(T_Today)
-
-BOOST_AUTO_TEST_CASE(test_today) {
-    cout << "Simulator:: ...test_today\n";
-
-    // suite suite
-    //   clock real <fixed date>
-    //   family family
-    //     task t1
-    //       today <start>  # +1 minute
-    //       today <start>  # +2 minute
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock   then create a today attribute + minutes
-        // such that the task should only run once, in the next minute
-        ptime theLocalTime                        = boost::posix_time::ptime(date(2010, 6, 21), time_duration(1, 2, 0));
-        boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
-        boost::posix_time::ptime time_plus_10_minute = theLocalTime + minutes(10);
-
-        suite_ptr suite = theDefs.add_suite("test_today");
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_minute.time_of_day())));
-        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_10_minute.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 2)); // expect task to complete 2 time
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    bool result = simulator.run(theDefs, findTestDataLocation("test_today.def"), errorMsg);
-
-    BOOST_CHECK_MESSAGE(result, errorMsg);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_today.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_today_time_series) {
-    cout << "Simulator:: ...test_today_time_series\n";
-
-    // suite suite
-    //   clock real <monday>
-    //   family family
-    //     task t1
-    //       today 00:30 18:59 04:00  # should run 5 times 00:30 4:30 8:30 12:30 16:30
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_today_time_series");
-        ClockAttr clockAttr(true /*false means use hybrid clock*/);
-        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        TimeSeries timeSeries(TimeSlot(00, 30), TimeSlot(18, 59), TimeSlot(4, 0), false /* relative */);
-
-        task->addToday(TodayAttr(timeSeries));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 5));
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_today_time_series.def"), errorMsg), errorMsg);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_today_time_series.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_CASE(test_today_time_and_date) {
-    cout << "Simulator:: ...test_today_time_and_date\n";
-
-    // suite suite
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       date  <today date>
-    //       time  <start>
-    //       today <start>
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // To speed up simulation: start calendar with hour increment AND time attributes with hours only
-        //
-        // Task will only run if all time dependencies are satisfied
-        boost::posix_time::ptime theLocalTime   = ptime(date(2010, 2, 10), hours(15));
-        boost::gregorian::date todaysDate       = theLocalTime.date();
-        boost::posix_time::ptime time_plus_hour = theLocalTime + hours(1);
-
-        suite_ptr suite = theDefs.add_suite("test_today_time_and_date");
-        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addDate(DateAttr(todaysDate));
-        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_hour.time_of_day())));
-        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_hour.time_of_day())));
-
-        task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-    }
-
-    Simulator simulator;
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_today_time_and_date.def"), errorMsg),
-                        errorMsg);
-
-    // remove generated log file. Comment out to debug
-    std::string logFileName = findTestDataLocation("test_today_time_and_date.def") + ".log";
-    fs::remove(logFileName);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/CSim/test/TestUtil.cpp 5.13.0-1/CSim/test/TestUtil.cpp
--- 5.12.4-1/CSim/test/TestUtil.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestUtil.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "TestUtil.hpp"
-
-#include "ecflow/core/File.hpp"
-
-using namespace std;
-using namespace ecf;
-
-std::string findTestDataLocation(const std::string& defsFile) {
-    std::string testData = File::test_data("CSim/test/data", "CSim");
-    testData += "/";
-    testData += defsFile;
-    return testData;
-}
diff -pruN 5.12.4-1/CSim/test/TestUtil.hpp 5.13.0-1/CSim/test/TestUtil.hpp
--- 5.12.4-1/CSim/test/TestUtil.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/TestUtil.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_simulator_test_TestUtil_HPP
-#define ecflow_simulator_test_TestUtil_HPP
-
-#include <string>
-
-/// Returns the location of the defs file, such thats it in the test data area
-std::string findTestDataLocation(const std::string& defsFile);
-
-#endif /* ecflow_simulator_test_TestUtil_HPP */
diff -pruN 5.12.4-1/CSim/test/data/bad_defs/impossible_day.def 5.13.0-1/CSim/test/data/bad_defs/impossible_day.def
--- 5.12.4-1/CSim/test/data/bad_defs/impossible_day.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/bad_defs/impossible_day.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite csim_repeat_day3
-  clock real 04.08.2019            # Sunday
-  endclock   04.09.2019            # added endclock to avoid simulation for a year due to repeat
-  family f
-    repeat integer rep 0 1
-    family f1
-       day monday
-       task t1
-            day tuesday            # cant be free on Monday and Tuesday, 
-            time 10:00   
-            verify complete:0     
-    endfamily
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/bad_defs/today.def 5.13.0-1/CSim/test/data/bad_defs/today.def
--- 5.12.4-1/CSim/test/data/bad_defs/today.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/bad_defs/today.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-suite suiteName
-   family familyName0
-   		today 15:00
-   		today 23:59 00:00 00:30  # start should be less than finish
-    endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/JIRA/1628.def 5.13.0-1/CSim/test/data/good_defs/JIRA/1628.def
--- 5.12.4-1/CSim/test/data/good_defs/JIRA/1628.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/JIRA/1628.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-suite ecflow__1628
-  clock    real 20.04.2020     # Monday
-  endclock      27.04.2020     # Monday, add endclock otherwise we simulate for year due to repeat.
-
-  task t1 ;  day monday ;    verify complete:1      
-  task t2 ;  day tuesday ;   verify complete:1        
-  task t3 ;  day wednesday ; verify complete:1        
-  task t4 ;  day thursday ;  verify complete:1       
-  task t5 ;  day friday ;    verify complete:1       
-  task t6 ;  day saturday ;  verify complete:1        
-  task t7 ;  day sunday ;    verify complete:1  
-  
-  task t11 ;  day monday ;    day tuesday ;   verify complete:2        
-  task t21 ;  day tuesday ;   day monday ;    verify complete:2        
-  task t31 ;  day wednesday ; day tuesday ;   verify complete:2        
-  task t41 ;  day thursday ;  day wednesday ; verify complete:2        
-  task t51 ;  day friday ;    day thursday ;  verify complete:2        
-  task t61 ;  day saturday ;  day friday ;    verify complete:2        
-  task t71 ;  day sunday ;    day saturday ;  verify complete:2  
-
-  task t72 ;  day sunday ; day monday ; day tuesday ; day wednesday ; day thursday ; day friday ; day saturday ;  verify complete:7  
-
-  family fam
-    verify complete:2      
-    day sunday 
-    day tuesday  
-    time 08:00
-    task t1
-        verify complete:2 
-   endfamily
-        
-  family fam2
-    verify complete:14 
-    day sunday ; day monday ; day tuesday ; day wednesday ; day thursday ; day friday ; day saturday ; 
-    time 08:00
-    time 09:00
-    task t1
-        verify complete:14        
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/JIRA/1638.def 5.13.0-1/CSim/test/data/good_defs/JIRA/1638.def
--- 5.12.4-1/CSim/test/data/good_defs/JIRA/1638.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/JIRA/1638.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,18 +0,0 @@
-#5.4.0
-suite ECFLOW_1638
-  clock real 1.5.2020
-  endclock 3.5.2020
-  task t2
-    date 1.5.2010
-    date 1.5.2011
-    verify complete:0
-  task t3
-    time 23:00
-    verify complete:1
-  task t4
-    cron 23:00
-    verify complete:2
-  task t5
-    cron 10:00 20:00 01:00
-    verify complete:22
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/JIRA/ECFLOW-130.def 5.13.0-1/CSim/test/data/good_defs/JIRA/ECFLOW-130.def
--- 5.12.4-1/CSim/test/data/good_defs/JIRA/ECFLOW-130.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/JIRA/ECFLOW-130.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-# 4.0.3
-suite radarlvl2
-  clock real 1.1.2014  # need to define a date otherwise log file/verify content varies according to the time 
-  # repeat day 1
-  family prod
-    task jradar_level2_cleanup
-      time 00:10 21:10 03:00
-      verify complete:8
-    task jradar_reflectivity_mosaic
-      event release_mosaic
-      time 00:20 23:20 01:00
-      verify complete:24
-    task jradar_reflectivity_ref2grb
-      trigger /radarlvl2/prod/jradar_reflectivity_mosaic:release_mosaic
-      verify complete:24
-      time 00:20 23:20 01:00
-    task jradar_canrad
-      time 00:05 23:55 00:10
-      verify complete:144
-    task jradar_level2
-      time 00:10 23:55 00:15
-      verify complete:96
-  endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/JIRA/ECFLOW-1628.def 5.13.0-1/CSim/test/data/good_defs/JIRA/ECFLOW-1628.def
--- 5.12.4-1/CSim/test/data/good_defs/JIRA/ECFLOW-1628.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/JIRA/ECFLOW-1628.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,108 +0,0 @@
-suite ecflow_1628
-  clock real 20.04.2020     # Monday
-  family barrier
-    repeat enumerated YMD 1 2 3 4 5 6 7
-    verify complete:7
-    family start
-      complete start/0 == complete and start/1 == complete and start/2 == complete and start/3 == complete and start/4 == complete and start/5 == complete and start/6 == complete
-      family 0
-        verify complete:7
-        time 23:00
-        day monday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 1
-        verify complete:7
-        time 23:00
-        day tuesday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 2
-        verify complete:7
-        time 23:00
-        day wednesday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 3
-        verify complete:7
-        time 23:00
-        day thursday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 4
-        verify complete:7
-        time 23:00
-        day friday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 5
-        verify complete:7
-        time 23:00
-        day saturday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-      family 6
-        verify complete:7
-        time 23:00
-        day sunday
-        task t1
-        task t2
-           trigger ./t1 == complete
-        task t3
-           trigger ./t2 == complete
-        task t4
-           trigger ./t3 == complete
-        task t5
-           trigger ./t4 == complete
-      endfamily
-    endfamily
-  endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/JIRA/ECFLOW-833.def 5.13.0-1/CSim/test/data/good_defs/JIRA/ECFLOW-833.def
--- 5.12.4-1/CSim/test/data/good_defs/JIRA/ECFLOW-833.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/JIRA/ECFLOW-833.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-suite Icemap2_to_DB_ecflow_833
-  clock    real 04.12.2016     # Sunday
-  endclock      09.12.2016     # Saturday, and endclock otherwise we simulate for year due to repeat.
-  repeat enumerated VARIABLE first        
-
-  family icemap
-
-    verify complete:2  # after Monday@8am we re-queue due to future time dependency     
-    day monday
-    day thursday
-    time 08:00
-     
-    task from_Icemap2
-        verify complete:2        # task should complete twice
-
-    task load_to_DB
-        trigger from_Icemap2 == complete
-        verify complete:2        # task should complete twice
-
-    task sleep
-        trigger load_to_DB == complete
-        verify complete:2        # task should complete twice
-
-    task clean
-        trigger sleep == complete
-        verify complete:2        # task should complete twice
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/SingleDefsTest/test.def 5.13.0-1/CSim/test/data/good_defs/SingleDefsTest/test.def
--- 5.12.4-1/CSim/test/data/good_defs/SingleDefsTest/test.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/SingleDefsTest/test.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-   suite suite
-      clock hybrid 6.11.2009 +54190
-      family family
-         task t
-            verify complete:3
-            time +00:01 00:03 00:01
-      endfamily
-   endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/cron.def 5.13.0-1/CSim/test/data/good_defs/cron/cron.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/cron.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/cron.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite cron              # use real clock otherwise the date will change
-   clock real 1.1.2006  # need to define a date otherwise log file content varies according to the time 
-   endclock   2.1.2006  # When to finish.
-   family cronFamily
-		task t
-  			 cron 10:00 20:00 01:00  
-  			 verify complete:11      # verify tasks complete 11 times. 		
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/cron2.def 5.13.0-1/CSim/test/data/good_defs/cron/cron2.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/cron2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/cron2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite cron2              # use real clock otherwise the date wont change
-   clock real 1.1.2017   # need to define a date otherwise log file content varies according to the time 
-   endclock   3.1.2017   # When to finish. 
-   family cronFamily
-		task t
-  			 cron -w 0,1 10:00 11:00 01:00          # run every Sunday & Monday at 10 and 11 am	
-  			 verify complete:4                      # task should complete 16 times	
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/cron3.def 5.13.0-1/CSim/test/data/good_defs/cron/cron3.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/cron3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/cron3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite cron3              # use real clock otherwise the date wont change
-   clock real  1.1.2006  # need to define a date otherwise log file content varies according to the time 
-   endclock   13.1.2006  # When to finish. 
-   family cronFamily
-		task t
-  			 cron -d 10,11,12   10:00 11:00 01:00   # run  10,11,12 of the month at 10am and 11 am		
-             verify complete:6                      # task should complete 6 times 
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/cron4.def 5.13.0-1/CSim/test/data/good_defs/cron/cron4.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/cron4.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/cron4.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite cron4             # use real clock otherwise the date wont change
-   clock real 1.1.2017  # need to define a date otherwise log file content varies according to the time 
-   endclock   1.2.2017  # When to finish. 
-   family cronFamily
-		task t
-  			 cron -m 1   10:00 11:00 01:00   # run every day at 10 and 11 for Jan	
-  			 verify complete:62              # Jan has 31 days hence expect task completeion 62 times
-   endfamily
-endsuite
-
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/cron5.def 5.13.0-1/CSim/test/data/good_defs/cron/cron5.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/cron5.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/cron5.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite cron5              # use real clock otherwise the date wont change
-   clock real 1.10.2009  # need to define a date otherwise log file content varies according to the time 
-   endclock   1.11.2009  # When to finish. 
-   family cronFamily
-		task t
-  			 cron -w 0  -m 10   10:00 11:00 01:00   # run every sunday in October at 10 and 11am
-  			 verify complete:8		                # 4 sundays in october hence expect 8 task completions
-   endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/cron6.def 5.13.0-1/CSim/test/data/good_defs/cron/cron6.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/cron6.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/cron6.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite cron6              
-  clock real  1.1.2006 # Define a start date for deterministic simulation 
-  endclock   17.1.2006 # When to finish. Otherwise we simulate for 1 year due to cron. Ok but wasteful.
-  family cronFamily
-    task t
-  	  cron -d 15,16  -m 1 10:00 11:00 01:00  # run 15,16 January at 10 and 11am	
-      verify complete:4	
-   endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/cron7.def 5.13.0-1/CSim/test/data/good_defs/cron/cron7.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/cron7.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/cron7.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-suite cron7           # use real clock otherwise the date wont change
- clock real 1.1.2017  # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2018  # When to finish. 
- family cronFamily
-  task t
-   cron -d 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:00 # run every day for a year
-   verify complete:365
- endfamily
-endsuite
-
-suite leap_year       # use real clock otherwise the date wont change
- clock real 1.1.2016  # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2017  # When to finish. 
- family cronFamily
-  task t
-   cron -d 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:00  # run every day for a year
-   verify complete:366 # leap year has 366 days
- endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/last.def 5.13.0-1/CSim/test/data/good_defs/cron/last.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/last.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/last.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,98 +0,0 @@
-suite cron            # use real clock otherwise the date wont change
- clock real 1.1.2019  # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020  # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   cron -d L 10:00    # run on the last of the month
-   verify complete:12
- endfamily
-endsuite
-
-suite cron1            # use real clock otherwise the date wont change
- clock real 1.1.2019  # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020  # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   cron -w 0L 10:00    # run on the last sunday of each month
-   verify complete:12
- endfamily
-endsuite
-
-suite cron2             # use real clock otherwise the date wont change
- clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   cron -d 1,L 10:00    # run on the first and last of the month
-   verify complete:24
- endfamily
-endsuite
-
-suite cron3             # use real clock otherwise the date wont change
- clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   cron -w 0L,1L,2L,3L,4L,5L,6L 10:00  # run on the last Monday,Tuesdat..Saturday,Sunday of the month
-   verify complete:84
- endfamily
-endsuite
-
-suite cron4             # use real clock otherwise the date wont change
- clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   # run on the last thursday and Last of the month, this only occurs 3 times in a year
-   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
-   cron -w 4L -d L 10:00    
-    
-   # In 2019, thursday was last of month 3 times
-   verify complete:3   
- endfamily
-endsuite
-
-suite cron5             # use real clock otherwise the date wont change
- clock real 1.1.2019     # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020     # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   cron -w 0,1L -m 1  10:00 # run every sunday and last Monday of the month, in January
-   verify complete:5
- endfamily
-endsuite
-
-suite cron6             # use real clock otherwise the date wont change
- clock real 1.1.2019     # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020     # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
-   # There is *ONLY* one day in January, i.e Thursday 31 of january
-   cron -w 0,1,2,3,4,5,6L -d L -m 1 10:00 
-   verify complete:1
- endfamily
-endsuite
-
-suite cron7              # use real clock otherwise the date wont change
- clock real 1.1.2019     # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020     # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   # expect 0 days, since last of the month in January is a thursday, and thursday is missing from day of the week
-   cron -w 0,1,2,3,5,6L -d L -m 1  10:00  
-   verify complete:0
- endfamily
-endsuite
-
-suite cron8             # use real clock otherwise the date wont change
- clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   # run on the last saturday and Last of the month, this only occurs 2 times in a year
-   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
-   cron -w 6L -d L 10:00    
-   verify complete:2
- endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/cron/last3.def 5.13.0-1/CSim/test/data/good_defs/cron/last3.def
--- 5.12.4-1/CSim/test/data/good_defs/cron/last3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/cron/last3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite cron4             # use real clock otherwise the date wont change
- clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
- endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
- family cronFamily
-  task t
-   # run on the last saturday and Last of the month, this only occurs 2 times in a year
-   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
-   cron -w 6L -d L 10:00    
-   verify complete:2
- endfamily
-endsuite
-
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/Repeat.def 5.13.0-1/CSim/test/data/good_defs/day/Repeat.def
--- 5.12.4-1/CSim/test/data/good_defs/day/Repeat.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/Repeat.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-suite csim_repeat_day
-  clock real 04.08.2019            # Sunday
-  endclock   13.08.2019            # added endclock to avoid simulation for a year due to repeat
-  family f
-    repeat integer rep 0 1
-    family f1
-       day monday                   # This acts like a guard over time attributes. They are not freed until day is free
-       task t1
-            time 10:00   
-            time 12:00   
-            verify complete:4      
-    endfamily
-  endfamily
-endsuite
-
-suite csim_repeat_day3
-  clock real 04.08.2019   # Sunday
-  endclock   31.08.2019   # added endclock to avoid simulation for a year due to repeat
-  family f
-    repeat integer rep 0 1
-    family f1
-       repeat integer rep 0 1
-       task t1
-            time 11:00   
-            day monday          
-            verify complete:4     
-    endfamily
-  endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/day.def 5.13.0-1/CSim/test/data/good_defs/day/day.def
--- 5.12.4-1/CSim/test/data/good_defs/day/day.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/day.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite day_suite
- clock real 11.10.2009   # 11 October 2009 was a Sunday, task x should hold for a day
- family family
-   verify complete:1     # family should complete once
-   task y
-     verify complete:1        # task should complete once
-   task x
-     trigger ./y == complete
-	  time 01:00
- 	  day monday               # simulate for 1 week, due to day
- 	  verify complete:1        # task should complete once
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/family.def 5.13.0-1/CSim/test/data/good_defs/day/family.def
--- 5.12.4-1/CSim/test/data/good_defs/day/family.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/family.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite family
-  clock real 04.08.2019   # Sunday
-  endclock   13.08.2019   # added endclock to avoid simulation for a year due to repeat
-  family f1
-       time 10:00   
-       time 11:00   
-       task t1
-            day monday         # run at midnight 1 time  
-            verify complete:1    
-    endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/hybrid_day.def 5.13.0-1/CSim/test/data/good_defs/day/hybrid_day.def
--- 5.12.4-1/CSim/test/data/good_defs/day/hybrid_day.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/hybrid_day.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite suite
-  clock hybrid 11.10.2009  # 11 october 2009 was a sunday, task x should complete on begin
-  endclock     13.10.2009  # end time
-  family family
- 	verify complete:1
- 	task y
- 	  verify complete:1
- 	task x
-	  trigger ./y == complete
- 	  day monday
- 	  verify complete:1
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/multiple_days.def 5.13.0-1/CSim/test/data/good_defs/day/multiple_days.def
--- 5.12.4-1/CSim/test/data/good_defs/day/multiple_days.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/multiple_days.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite multiple
-  clock real 04.12.2016            # Sunday
-  endclock   09.12.2016            # Friday added endclock to avoid simulation for a year due to repeat
-  repeat enumerated VARIABLE first # with repeat max duration is 8760 hours, i.e 1 year
-  family f    
-    day monday                     
-    day thursday                    
-    task t                         # run monday and thursday morning
-       verify complete:2  
-    task t2
-       trigger ./t == complete
-       verify complete:2  
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/repeat2.def 5.13.0-1/CSim/test/data/good_defs/day/repeat2.def
--- 5.12.4-1/CSim/test/data/good_defs/day/repeat2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/repeat2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite csim_repeat_day2
-  clock real 04.08.2019   # Sunday
-  endclock   13.08.2019   # added endclock to avoid simulation for a year due to repeat
-  family f
-    repeat integer rep 0 1
-    family f1
-       time 10:00   
-       time 11:00              # no guard so has no effect
-       task t1
-            day monday         # run at midnight, 2 times  
-            verify complete:2     
-    endfamily
-  endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/repeat3.def 5.13.0-1/CSim/test/data/good_defs/day/repeat3.def
--- 5.12.4-1/CSim/test/data/good_defs/day/repeat3.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/repeat3.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-suite csim_repeat_day2
-  clock real 04.08.2019        # Sunday
-  endclock   13.08.2019        # added endclock to avoid simulation for a year due to repeat
-  family f
-    repeat integer rep 0 1
-    family f1
-       time 08:00 20:00 01:00  # no guard so has no effect
-       task t1
-            day monday         # run at midnight, 2 times  
-            verify complete:2     
-    endfamily
-  endfamily
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/simple.def 5.13.0-1/CSim/test/data/good_defs/day/simple.def
--- 5.12.4-1/CSim/test/data/good_defs/day/simple.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/simple.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite simple
- clock real 19.04.2020   #  was a Sunday,  
- family family
-   verify complete:1     # family should complete once
-   task t
-     day monday               # simulate for 1 week, due to day
-     verify complete:1        # task should complete once
- endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/day/simple2.def 5.13.0-1/CSim/test/data/good_defs/day/simple2.def
--- 5.12.4-1/CSim/test/data/good_defs/day/simple2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/day/simple2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite simple
-  clock    real 19.04.2020     # Sunday
-  endclock      27.04.2020     # Monday, add endclock otherwise we simulate for year due to repeat.
-      
-      family 0
-        verify complete:1
-        time 23:00
-        day monday
-        task t1
-        task t2
-           trigger ./t1 == complete
-      endfamily   
-endsuite
-
- 
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/event/event.def 5.13.0-1/CSim/test/data/good_defs/event/event.def
--- 5.12.4-1/CSim/test/data/good_defs/event/event.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/event/event.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-suite suite
-  clock real 5.1.2017        
-  family family
-     task t1
-        event event
-        event event_set set
-        verify complete:1
-     task t2
-        trigger t1:event
-        verify complete:1
-     task t3
-        trigger t2 == complete and t1:event_set == clear
-        verify complete:1
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/misc/defstatus.def 5.13.0-1/CSim/test/data/good_defs/misc/defstatus.def
--- 5.12.4-1/CSim/test/data/good_defs/misc/defstatus.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/misc/defstatus.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite test_repeat_defstatus
-  clock real 04.12.2016             
-  defstatus complete       # this should cause node state complete down the hierarchy  
-  repeat integer VAR 0 1 1           
-  edit SLEEPTIME 1
-  edit ECF_INCLUDE $ECF_HOME/includes
-  verify complete:1
-  family family
-     verify complete:1
-     repeat integer VAR 0 2 1        
-     task t1
-       verify complete:1
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/misc/lifecycle.def 5.13.0-1/CSim/test/data/good_defs/misc/lifecycle.def
--- 5.12.4-1/CSim/test/data/good_defs/misc/lifecycle.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/misc/lifecycle.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite suite1
-  family family1
-   	task a
-        event 1 myEvent
-        meter myMeter 0 100
-   	task b
-   		trigger a == complete
-   endfamily
-   family family2
-   		task aa
-   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent 
-   		task bb
-   			trigger ../family1/a:myMeter >= 50  or  ../family1/a:myEvent
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/CSim/test/data/good_defs/operations/loop.def 5.13.0-1/CSim/test/data/good_defs/operations/loop.def
--- 5.12.4-1/CSim/test/data/good_defs/operations/loop.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/operations/loop.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-# This file was taken from one of operational suites
-  
-suite limits
-  defstatus complete
-  clock hybrid 0 # 01.07.2009 14:47
-  limit metis 6
-endsuite
-
-suite admin
-  #defstatus suspended
-  clock hybrid  22.12.2005   # run at midnight to ensure test is deterministice
-  inlimit /limits:metis
-  
-  family daily
-    repeat date YMD 20070115 20070118 1 #  run 4 times
- 	verify complete:4
-    family check
- 	  verify complete:4          # make sure it actually ran 4 times
-      task rcp
-        time 00:00 23:59 00:10   # Note: finish minute (59) is not a multiple of the increment 10, last time is 23:50
- 	    verify complete:576       # 576 = 24(hours) * 6( completions per hour) * 4 times
- 	endfamily
-  endfamily
-endsuite 
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/operations/mars.def 5.13.0-1/CSim/test/data/good_defs/operations/mars.def
--- 5.12.4-1/CSim/test/data/good_defs/operations/mars.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/operations/mars.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-suite mars
-  clock hybrid 01.07.2009  
-  family archive
-  	repeat integer fred 1 1 
-    task grib
-      verify complete:6        # 00:30 4:30 8:30 12:30 16:30 20:30
-      time 00:30 23:59 04:00   #
-   endfamily
-endsuite
- 
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/operations/naw.def 5.13.0-1/CSim/test/data/good_defs/operations/naw.def
--- 5.12.4-1/CSim/test/data/good_defs/operations/naw.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/operations/naw.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,208 +0,0 @@
-#============================================================
-suite weather
-  clock hybrid -3542400 # 29.08.2009 16:54
-  # repeat day 1 # status 0   ************** DISABLED SO THAT SUITE CAN COMPLETE *****************
-  edit SMSTRIES '2'
-  edit SMSCMD 'smssubmit.x %SMSJOB% hades rdx'
-  edit SMSHOME '/vol/rdx_dir/mars_stats/sms'
-  edit SMSINCLUDE '/vol/rdx_dir/mars_stats/sms/include'
-  edit SMSFILES '/vol/rdx_dir/mars_stats/sms/weather'
-  edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-  edit ACCOUNT 'ecrmna'
-  edit OWNER 'naw'
-  edit EXPVER 'weather'
-  edit LOGDIR '/scratch/rd/rdx'
-  edit USER 'rdx'
-  edit QUEUE 'normal'
-  edit ECFS 'no'
-  family naw
-    family general
-      # time 06:00
-      task metgrams
-        defstatus complete
-      task equipot
-        defstatus complete
-    endfamily
-    family tephi
-      edit WSHOST 'linux_cluster'
-      edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %WSHOST% %USER%'
-      edit HOUR '00'
-      # time 05:35
-      task rd_tephi
-        defstatus complete
-        edit TDATE '2000110500'
-        edit EXPVER 'e4mb'
-      task tephi
-    endfamily
-    family main
-      edit WSHOST 'linux_cluster'
-      edit SCHOST 'c1a'
-      edit CPUTIME '30000'
-      edit MEM '800'
-      edit SMSLOGPORT '9314'
-      edit SMSLOGHOST 'c1a-batch'
-      edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSCMD '/home/rd/rdx/bin/smssubmit.x.nils %SMSJOB% %WSHOST% %USER%'
-      edit LOGDIR '/vol/explog/outputs'
-      family scm_quick
-        edit LONG 'no'
-        edit START12 'no'
-        task getmars_scm
-          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit LOGDIR '/c1a/rdx_dir/log'
-          # time 05:20
-        task getdata_scm
-          trigger getmars_scm eq complete
-          edit CLASS 'np'
-          edit NPES '8'
-          edit MEM '800'
-          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit LOGDIR '/c1a/rdx_dir/log'
-        task benson
-          trigger getdata_scm eq complete
-          edit QUEUE 'normal'
-        task chilbolton
-          trigger getdata_scm eq complete
-        task husbos
-          trigger getdata_scm eq complete
-        task belvoir_castle
-          trigger getdata_scm eq complete
-        task york
-          trigger getdata_scm eq complete
-        task welshpool
-          trigger getdata_scm eq complete
-          edit QUEUE 'normal'
-        task newmarket
-          trigger getdata_scm eq complete
-      endfamily
-      family scm
-        edit LONG 'yes'
-        edit START12 'no'
-        task getmars_scm
-          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit LOGDIR '/c1a/rdx_dir/log'
-          # time 06:45
-        task getdata_scm
-          trigger getmars_scm eq complete
-          edit CLASS 'np'
-          edit NPES '8'
-          edit MEM '800'
-          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit LOGDIR '/c1a/rdx_dir/log'
-          edit SMSPASS 'FREE'
-        task benson
-          trigger getdata_scm eq complete
-          edit SMSPASS 'FREE'
-        task chilbolton
-          trigger getdata_scm eq complete
-        task husbos
-          trigger getdata_scm eq complete
-          edit SMSPASS 'FREE'
-        task belvoir_castle
-          trigger getdata_scm eq complete
-        task york
-          trigger getdata_scm eq complete
-        task welshpool
-          trigger getdata_scm eq complete
-          edit SMSPASS 'FREE'
-        task newmarket
-          trigger getdata_scm eq complete
-        task cabauw
-          trigger getdata_scm eq complete
-        task arm_sgp
-          trigger getdata_scm eq complete
-        task vocals0850W
-          defstatus complete
-          trigger getdata_scm eq complete
-        task vocals0750W
-          defstatus complete
-          trigger getdata_scm eq complete
-        task web
-          trigger benson eq complete and chilbolton eq complete and husbos eq complete and belvoir_castle eq complete and york eq complete and welshpool eq complete and newmarket eq complete and cabauw eq complete and arm_sgp eq complete and vocals0850W eq complete and vocals0750W eq complete
-      endfamily
-    endfamily
-  endfamily
-endsuite
-suite weather12
-  clock hybrid -9244800 # 14.06.2009 16:54
-  # repeat day 1 # status 0  ************** DISABLED SO THAT SUITE CAN COMPLETE *****************
-  edit SMSTRIES '2'
-  edit SMSCMD 'smssubmit.x %SMSJOB% hades rdx'
-  edit SMSHOME '/vol/rdx_dir/mars_stats/sms'
-  edit SMSINCLUDE '/vol/rdx_dir/mars_stats/sms/include'
-  edit SMSFILES '/vol/rdx_dir/mars_stats/sms/weather'
-  edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-  edit ACCOUNT 'ecrmna'
-  edit OWNER 'naw'
-  edit EXPVER 'weather'
-  edit LOGDIR '/scratch/rd/rdx'
-  edit USER 'rdx'
-  edit QUEUE 'normal'
-  edit ECFS 'no'
-  family naw
-    family main
-      edit WSHOST 'linux_cluster'
-      edit SCHOST 'c1a'
-      edit CPUTIME '30000'
-      edit MEM '800'
-      edit SMSLOGPORT '9314'
-      edit SMSLOGHOST 'c1a-batch'
-      edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSCMD '/home/rd/rdx/bin/smssubmit.x.nils %SMSJOB% %WSHOST% %USER%'
-      edit LOGDIR '/vol/explog/outputs'
-      family scm
-        edit LONG 'yes'
-        edit START12 'yes'
-        task getmars_scm
-          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit LOGDIR '/c1a/rdx_dir/log'
-          edit SMSPASS 'FREE'
-          # time 17:45
-        task getdata_scm
-          trigger getmars_scm eq complete
-          edit CLASS 'np'
-          edit NPES '8'
-          edit MEM '800'
-          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit LOGDIR '/c1a/rdx_dir/log'
-        task benson
-          trigger getdata_scm eq complete
-        task chilbolton
-          trigger getdata_scm eq complete
-        task husbos
-          trigger getdata_scm eq complete
-        task belvoir_castle
-          trigger getdata_scm eq complete
-        task york
-          trigger getdata_scm eq complete
-        task welshpool
-          trigger getdata_scm eq complete
-        task newmarket
-          trigger getdata_scm eq complete
-        task cabauw
-          defstatus complete
-          trigger getdata_scm eq complete
-          edit SMSPASS 'FREE'
-        task arm_sgp
-          defstatus complete
-          trigger getdata_scm eq complete
-        task vocals0850W
-          defstatus complete
-          trigger getdata_scm eq complete
-        task vocals0750W
-          defstatus complete
-          trigger getdata_scm eq complete
-        task web
-          trigger benson eq complete and chilbolton eq complete and husbos eq complete and belvoir_castle eq complete and york eq complete and welshpool eq complete and newmarket eq complete and cabauw eq complete and arm_sgp eq complete and vocals0750W eq complete and vocals0850W eq complete
-      endfamily
-    endfamily
-  endfamily
-endsuite
-#============================================================
diff -pruN 5.12.4-1/CSim/test/data/good_defs/operations/xbe.def 5.13.0-1/CSim/test/data/good_defs/operations/xbe.def
--- 5.12.4-1/CSim/test/data/good_defs/operations/xbe.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/operations/xbe.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9134 +0,0 @@
-#============================================================
-extern an
-extern an
-extern fc
-extern fc
-extern eps_sv
-extern eps_sv
-extern eps_fc
-extern eps_fc
-extern oceatm
-extern oceatm
-extern oce
-extern oce
-extern fpos
-extern fpos
-extern sens
-extern sens
-extern wam
-extern wam
-extern oc
-extern oc
-extern climplot
-extern climplot
-extern coup
-extern coup
-extern an
-extern an
-extern fc
-extern fc
-extern eps_sv
-extern eps_sv
-extern eps_fc
-extern eps_fc
-extern oceatm
-extern oceatm
-extern oce
-extern oce
-extern fpos
-extern fpos
-extern sens
-extern sens
-extern wam
-extern wam
-extern oc
-extern oc
-extern climplot
-extern climplot
-extern coup
-extern coup
-suite cu9
-  clock hybrid 0 # 27.11.2008 16:54
-  family a01d
-    edit SMSTRIES '1'
-    edit SMSFILES '/vol/msverify/sms/cu9/a01d'
-    edit SMSINCLUDE '/vol/msverify/sms/cu9/a01d/include'
-    edit SMSHOME '/vol/msverify/sms'
-    edit SMSOUT '/vol/msverify/sms'
-    edit SMSLOGPORT '9314'
-    edit SMSLOGHOST 'hpce-batch'
-    edit FSFAMILY ''
-    edit DELTA_DAY '0'
-    edit HOUR ''
-    edit MEMBER '0'
-    edit NPROCA '1'
-    edit NPROCB '1'
-    edit THREADS '1'
-    edit BRANCH ''
-    edit PROJECTS 'none'
-    edit PARALLEL '4'
-    edit DEBUG '0'
-    edit PROFILE '0'
-    edit DISPLAY 'define_your_own:0.0'
-    edit QUEUE 'normal'
-    edit SCHOST 'hpce'
-    edit WSHOST 'ecgate'
-    edit LOGHOST 'linux_cluster'
-    edit EXPVER 'a01d'
-    edit OWNER 'cu9'
-    edit USER 'xbe'
-    edit ACCOUNT 'betro3'
-    edit YMD '2008021112'
-    edit SECS '43200'
-    edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-    edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-    edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-    edit LOGDIR '/hpce/rdx_dir/msx'
-    family make
-      edit YMD '2008021112'
-      edit HOUR ''
-      edit FSFAMILY 'make'
-      task setup
-        edit QUEUE 'normal'
-      family libs
-        defstatus complete
-        trigger setup eq complete
-        edit CCSUBDIR '.'
-        task p4setup_ifs
-          edit SMSTRIES '2'
-        task p4diff_ifs
-          trigger p4setup_ifs eq complete
-        family compile
-          trigger p4setup_ifs eq complete
-          family ifsaux
-            defstatus complete
-            task libifsaux
-          endfamily
-          family surf
-            defstatus complete
-            trigger ifsaux eq complete
-            task libsurf
-          endfamily
-          family trans
-            defstatus complete
-            trigger ifsaux eq complete
-            task libtrans
-          endfamily
-          family ifs
-            defstatus complete
-            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( surf eq complete or surf eq unknown)
-            task libifs
-          endfamily
-          family wam
-            defstatus complete
-            trigger ifsaux eq complete
-            task libwam
-          endfamily
-          family odb
-            defstatus complete
-            family compiler
-              task libodbsqlcompiler
-            endfamily
-            family databases
-              trigger compiler eq complete
-              family CCMA
-                task libCCMA
-              endfamily
-              family ECMA
-                task libECMA
-              endfamily
-            endfamily
-            family corelibs
-              trigger ../ifsaux eq complete
-              family odb
-                task libodb
-              endfamily
-              family odbdummy
-                trigger odb/libodb eq complete
-                task libodbdummy
-              endfamily
-              family odbmain
-                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and ../../ifs eq complete
-                task libodbmain
-              endfamily
-              family odbport
-                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and odbmain/libodbmain eq complete and ../../ifs eq complete
-                task libodbport
-              endfamily
-            endfamily
-          endfamily
-          family ssa
-            defstatus complete
-            trigger ifsaux eq complete and ifs eq complete and odb/corelibs/odb/libodb eq complete
-            task libssa
-          endfamily
-          family obstat
-            defstatus complete
-            trigger ifsaux eq complete and odb/corelibs/odb/libodb eq complete
-            task libobstat
-          endfamily
-          family bl
-            defstatus complete
-            trigger ifsaux eq complete
-            task libbl95
-          endfamily
-          family scat
-            defstatus complete
-            trigger ifsaux eq complete
-            task libscat
-          endfamily
-          family satrad
-            defstatus complete
-            trigger ifsaux eq complete
-            task libsatrad
-          endfamily
-          family aeolus
-            defstatus complete
-            trigger ifsaux eq complete
-            task libaeolus
-          endfamily
-          family prepdata
-            defstatus complete
-            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( ifs eq complete or ifs eq unknown)
-            task libprepdata
-          endfamily
-        endfamily
-      endfamily
-      task links
-        trigger  ( setup eq complete or setup eq unknown) and  ( libs eq complete or libs eq unknown)
-        edit QUEUE 'normal'
-      task logfiles
-        trigger  ( links eq complete or links eq unknown)
-        edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-        edit LOGDIR '/hpce/rdx_dir/msx'
-    endfamily
-    family eps_varfc
-      limit SC 6
-      limit PIC 6
-      edit STREAM 'ENFO'
-      edit FSFAMILY 'mc'
-      edit HOUR ''
-      edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-      edit LOGDIR '/hpce/rdx_dir/msx'
-      family make
-        trigger ../make eq complete
-        edit YMD '2008021112'
-        edit HOUR '12'
-        task setup
-          edit QUEUE 'normal'
-        family bins
-          trigger ../../make/links eq complete and ./setup eq complete
-          task ifs
-          task wamabs
-            edit QUEUE 'normal'
-          task mc_tools
-          task prepdata
-          task ma_tools
-            defstatus complete
-        endfamily
-        family const
-          task datalinks
-            trigger ../setup eq complete
-          task wconstA
-            trigger ../bins/wamabs eq complete
-            edit WAMRESOL 'global100'
-            edit WAMNFRE '30'
-            edit WAMNANG '24'
-          task wconstB
-            trigger ./wconstA eq complete
-            edit WAMRESOL 'global100'
-            edit WAMNFRE '25'
-            edit WAMNANG '12'
-          task wconstC
-            trigger ./wconstB eq complete
-            edit WAMRESOL 'global300'
-            edit WAMNFRE '25'
-            edit WAMNANG '12'
-          task getsst
-            defstatus complete
-            trigger ../setup eq complete and ../../main/fc/inigroup/getini eq complete
-        endfamily
-        task logfiles
-          trigger bins eq complete and const eq complete
-          edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-          edit LOGDIR '/hpce/rdx_dir/msx'
-      endfamily
-      family main
-        family sv
-          defstatus complete
-          repeat string YMD  "2008021112" # status 0
-          edit EPSTYPE 'sv'
-          edit EPSSVTCSUB '1'
-          edit EPSSVOP '1'
-          task getini
-            trigger ../../make/const/datalinks eq complete
-            edit QUEUE 'normal'
-            edit INISTREAM 'DCDA'
-            edit INISTEP '6'
-            edit INITYPE 'fc'
-            edit PRIORITY '40'
-          task inidata_sv
-            trigger ../../make/bins/ifs eq complete and getini eq complete
-            edit QUEUE 'parallel'
-            edit NPES '16'
-            edit THREADS '4'
-            edit MEM '960'
-            edit CPUTIME '1000'
-          task svnh
-            trigger inidata_sv eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '0'
-            edit EPSTROP '0'
-            edit EPSHEM '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task svsh
-            trigger inidata_sv eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '0'
-            edit EPSTROP '0'
-            edit EPSHEM '2'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task targets
-            trigger ../../make/bins/mc_tools eq complete
-          task subspace
-            trigger svnh eq complete and svsh eq complete and targets eq complete
-          task sv1
-            trigger targets eq complete and subspace eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '1'
-            edit EPSTROP '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task sv2
-            trigger targets eq complete and subspace eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '2'
-            edit EPSTROP '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task sv3
-            trigger targets eq complete and subspace eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '3'
-            edit EPSTROP '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task sv4
-            trigger targets eq complete and subspace eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '4'
-            edit EPSTROP '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task sv5
-            trigger targets eq complete and subspace eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '5'
-            edit EPSTROP '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task sv6
-            trigger targets eq complete and subspace eq complete
-            edit FCLENGTH '48'
-            edit MEMBER '6'
-            edit EPSTROP '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task svnhevo
-            trigger svnh eq complete
-            edit FCLENGTH '48'
-            edit EPSHEM '1'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task svshevo
-            trigger svsh eq complete
-            edit FCLENGTH '48'
-            edit EPSHEM '2'
-            edit MEM '960'
-            edit NPES '16'
-            edit THREADS '2'
-            edit CPUTIME '6000'
-            edit QUEUE 'normal'
-          task svsave
-            trigger svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and svnhevo eq complete and svshevo eq complete
-          task logfiles
-            trigger svsave eq complete
-            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-            edit LOGDIR '/hpce/rdx_dir/msx'
-        endfamily
-        family fc
-          family inigroup
-            repeat string YMD  "2008021112" # status 1
-            trigger  ( ../sv:YMD gt inigroup:YMD or ../sv eq complete) and  ( inigroup:YMD lt  ( ensemble:YMD + 2))
-            complete  ( inigroup:YMD eq  ~ 1)
-            task getini
-              trigger ../../../make/setup eq complete
-              edit QUEUE 'normal'
-              edit INISTREAM 'DA'
-              edit INISTEP '0'
-              edit INITYPE '4v'
-              edit PRIORITY '40'
-            task inidata
-              trigger ../../../make/bins/ifs eq complete and getini eq complete and ../../../make/const/getsst eq complete
-              edit EPSFCRES '399'
-              edit EPSFCLEV '62'
-              edit QUEUE 'parallel'
-              edit NPES '16'
-              edit THREADS '4'
-              edit MEM '960'
-              edit CPUTIME '1000'
-            task wavini
-              trigger ../../../make/const/wconstA eq complete
-              edit QUEUE 'normal'
-              edit PRIORITY '40'
-              edit MEM '900'
-              edit NPES '1'
-              edit THREADS '1'
-              edit CPUTIME '8000'
-            task wcold
-              defstatus complete
-              trigger inidata eq complete and wavini eq complete
-              edit QUEUE 'normal'
-              edit MEM '900'
-              edit NPES '8'
-              edit THREADS '1'
-              edit CPUTIME '3000'
-            task wavfcdata
-              trigger ./wcold eq complete and ../../../make eq complete and wavini eq complete
-            task getsvs
-              trigger ../../../make/bins/mc_tools eq complete
-              edit EPSTROP '1'
-            task getae
-              trigger ./getini eq complete and ./getsvs eq complete
-              event 1
-            task rot
-              trigger ./inidata eq complete and ./getae eq complete and ../../../make/bins/mc_tools eq complete
-              edit EPSTROP '1'
-            task geticp
-              defstatus complete
-              trigger getini eq complete
-            family pert_ic
-              inlimit PIC
-              trigger geticp eq complete and rot eq complete and ./inidata eq complete and ../../../make/bins/mc_tools eq complete
-              edit EPSTROP '1'
-              edit EPSFCLEV '62'
-              edit EPSFCRES '399'
-              family 000
-                edit MEMBER '0'
-                task pertinic
-              endfamily
-              family 001
-                edit MEMBER '1'
-                task pertinic
-              endfamily
-              family 002
-                edit MEMBER '2'
-                task pertinic
-              endfamily
-              family 003
-                edit MEMBER '3'
-                task pertinic
-              endfamily
-              family 004
-                edit MEMBER '4'
-                task pertinic
-              endfamily
-              family 005
-                edit MEMBER '5'
-                task pertinic
-              endfamily
-              family 006
-                edit MEMBER '6'
-                task pertinic
-              endfamily
-              family 007
-                edit MEMBER '7'
-                task pertinic
-              endfamily
-              family 008
-                edit MEMBER '8'
-                task pertinic
-              endfamily
-              family 009
-                edit MEMBER '9'
-                task pertinic
-              endfamily
-              family 010
-                edit MEMBER '10'
-                task pertinic
-              endfamily
-              family 011
-                edit MEMBER '11'
-                task pertinic
-              endfamily
-              family 012
-                edit MEMBER '12'
-                task pertinic
-              endfamily
-              family 013
-                edit MEMBER '13'
-                task pertinic
-              endfamily
-              family 014
-                edit MEMBER '14'
-                task pertinic
-              endfamily
-              family 015
-                edit MEMBER '15'
-                task pertinic
-              endfamily
-              family 016
-                edit MEMBER '16'
-                task pertinic
-              endfamily
-              family 017
-                edit MEMBER '17'
-                task pertinic
-              endfamily
-              family 018
-                edit MEMBER '18'
-                task pertinic
-              endfamily
-              family 019
-                edit MEMBER '19'
-                task pertinic
-              endfamily
-              family 020
-                edit MEMBER '20'
-                task pertinic
-              endfamily
-              family 021
-                edit MEMBER '21'
-                task pertinic
-              endfamily
-              family 022
-                edit MEMBER '22'
-                task pertinic
-              endfamily
-              family 023
-                edit MEMBER '23'
-                task pertinic
-              endfamily
-              family 024
-                edit MEMBER '24'
-                task pertinic
-              endfamily
-              family 025
-                edit MEMBER '25'
-                task pertinic
-              endfamily
-              family 026
-                edit MEMBER '26'
-                task pertinic
-              endfamily
-              family 027
-                edit MEMBER '27'
-                task pertinic
-              endfamily
-              family 028
-                edit MEMBER '28'
-                task pertinic
-              endfamily
-              family 029
-                edit MEMBER '29'
-                task pertinic
-              endfamily
-              family 030
-                edit MEMBER '30'
-                task pertinic
-              endfamily
-              family 031
-                edit MEMBER '31'
-                task pertinic
-              endfamily
-              family 032
-                edit MEMBER '32'
-                task pertinic
-              endfamily
-              family 033
-                edit MEMBER '33'
-                task pertinic
-              endfamily
-              family 034
-                edit MEMBER '34'
-                task pertinic
-              endfamily
-              family 035
-                edit MEMBER '35'
-                task pertinic
-              endfamily
-              family 036
-                edit MEMBER '36'
-                task pertinic
-              endfamily
-              family 037
-                edit MEMBER '37'
-                task pertinic
-              endfamily
-              family 038
-                edit MEMBER '38'
-                task pertinic
-              endfamily
-              family 039
-                edit MEMBER '39'
-                task pertinic
-              endfamily
-              family 040
-                edit MEMBER '40'
-                task pertinic
-              endfamily
-              family 041
-                edit MEMBER '41'
-                task pertinic
-              endfamily
-              family 042
-                edit MEMBER '42'
-                task pertinic
-              endfamily
-              family 043
-                edit MEMBER '43'
-                task pertinic
-              endfamily
-              family 044
-                edit MEMBER '44'
-                task pertinic
-              endfamily
-              family 045
-                edit MEMBER '45'
-                task pertinic
-              endfamily
-              family 046
-                edit MEMBER '46'
-                task pertinic
-              endfamily
-              family 047
-                edit MEMBER '47'
-                task pertinic
-              endfamily
-              family 048
-                edit MEMBER '48'
-                task pertinic
-              endfamily
-              family 049
-                edit MEMBER '49'
-                task pertinic
-              endfamily
-              family 050
-                edit MEMBER '50'
-                task pertinic
-              endfamily
-            endfamily
-            task cp_pert
-              trigger pert_ic eq complete
-            task logfiles
-              trigger wavfcdata eq complete and wavini eq complete and inidata eq complete and pert_ic eq complete and cp_pert eq complete and rot eq complete
-              edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-              edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-              edit LOGDIR '/hpce/rdx_dir/msx'
-          endfamily
-          family ensemble
-            inlimit SC
-            repeat string YMD  "2008021112" # status 1
-            trigger  (  ( inigroup:YMD gt ensemble:YMD) or  ( inigroup eq complete)) and  ( ensemble:YMD eq lag:YMD)
-            complete  ( ensemble:YMD eq  ~ 1)
-            edit RUNVARFC '1'
-            edit HC_REFDATE '0'
-            family cv
-              defstatus complete
-              trigger  ( ../inigroup:YMD gt ../ensemble:YMD) or  ( ../inigroup/pert_ic/000 eq complete)
-              edit EPSTYPE 'cv'
-              family control_1
-                edit SUBFSFAMILY '/cv001'
-                edit EPSMEMBER '1'
-                edit EPSWAMRESOL 'global100'
-                edit EPSWAMNFRE '30'
-                edit EPSWAMNANG '24'
-                edit EPSWAMNSTPW '1'
-                task getiniLeg
-                  edit EPSFCRES '399'
-                  edit EPSFCLEV '62'
-                  edit EPSFCGTYPE 'l_2'
-                  edit PRIORITY '40'
-                task modeleps
-                  trigger ./getiniLeg eq complete
-                  edit MEM '960'
-                  edit NPES '24'
-                  edit THREADS '4'
-                  edit STACK '550'
-                  edit QUEUE 'normal'
-                  edit CPUTIME '2700'
-                  edit EPSFCRES '399'
-                  edit EPSFCLEV '62'
-                  edit EPSFCGTYPE 'l_2'
-                  edit EPSNLEGS '1'
-                  edit EPSLEG '1'
-                  edit EPSINISTEP '240'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '216'
-                  edit TSTEP '1800'
-                  meter step 0 216 216
-              endfamily
-              family control_2
-                edit SUBFSFAMILY '/cv002'
-                edit EPSMEMBER '2'
-                edit EPSWAMRESOL 'global100'
-                edit EPSWAMNFRE '25'
-                edit EPSWAMNANG '12'
-                edit EPSWAMNSTPW '1'
-                task getiniLeg
-                  edit PRIORITY '40'
-                  edit EPSFCRES '399'
-                  edit EPSFCLEV '62'
-                task intHtoLB
-                  trigger ./getiniLeg eq complete
-                  edit QUEUE 'parallel'
-                  edit NPES '8'
-                  edit THREADS '2'
-                  edit MEM '1599'
-                  edit CPUTIME '200'
-                  edit EPSINISTEP '216'
-                  edit EPSFCRES '255'
-                  edit EPSFCLEV '62'
-                  edit EPSFCGTYPE 'l_2'
-                task modeleps
-                  trigger ./intHtoLB eq complete
-                  edit MEM '960'
-                  edit NPES '16'
-                  edit THREADS '2'
-                  edit STACK '550'
-                  edit QUEUE 'normal'
-                  edit CPUTIME 'INF'
-                  edit EPSNLEGS '1'
-                  edit EPSLEG '1'
-                  edit EPSFCRES '255'
-                  edit EPSFCLEV '62'
-                  edit EPSFCGTYPE 'l_2'
-                  edit EPSINISTEP '0'
-                  edit EPSINISTEP_PREVIOUS '0'
-                  edit FCLENGTH '216'
-                  edit TSTEP '2700'
-                  meter step 0 216 216
-              endfamily
-            endfamily
-            family cf
-              edit EPSTYPE 'cf'
-              family control
-                trigger  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/000 eq complete)
-                edit SUBFSFAMILY '/cf000'
-                edit EPSMEMBER '0'
-                family legA
-                  edit EPSCOUPLE '0'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                    edit EPSLEG '2'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                    edit EPSLEG '3'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit EPSFCLENGTH_B '0'
-                    edit EPSINISTEP_B '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-            endfamily
-            family pf
-              edit EPSTYPE 'pf'
-              family 001
-                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/001 eq complete))
-                edit SUBFSFAMILY '/001'
-                edit EPSMEMBER '1'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc0'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '1'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '1'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '1'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '1'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '1'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '1'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '1'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 002
-                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/002 eq complete))
-                edit SUBFSFAMILY '/002'
-                edit EPSMEMBER '2'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc0'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '2'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '2'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '2'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '2'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '2'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '2'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '2'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 003
-                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/003 eq complete))
-                edit SUBFSFAMILY '/003'
-                edit EPSMEMBER '3'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc0'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '3'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '3'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '3'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '3'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '3'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '3'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '3'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 004
-                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/004 eq complete))
-                edit SUBFSFAMILY '/004'
-                edit EPSMEMBER '4'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc0'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '4'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '4'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '4'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '4'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '4'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc0'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '4'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '4'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 005
-                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/005 eq complete))
-                edit SUBFSFAMILY '/005'
-                edit EPSMEMBER '5'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc1'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '5'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '5'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '5'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '5'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '5'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '5'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '5'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 006
-                trigger  ( ./001/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/006 eq complete))
-                edit SUBFSFAMILY '/006'
-                edit EPSMEMBER '6'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc1'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '6'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '6'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '6'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '6'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '6'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '6'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '6'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 007
-                trigger  ( ./002/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/007 eq complete))
-                edit SUBFSFAMILY '/007'
-                edit EPSMEMBER '7'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc1'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '7'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '7'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '7'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '7'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '7'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '7'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '7'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 008
-                trigger  ( ./003/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/008 eq complete))
-                edit SUBFSFAMILY '/008'
-                edit EPSMEMBER '8'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc1'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '8'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '8'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '8'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '8'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '8'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '8'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '8'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 009
-                trigger  ( ./004/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/009 eq complete))
-                edit SUBFSFAMILY '/009'
-                edit EPSMEMBER '9'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc1'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '9'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '9'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '9'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '9'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '9'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc1'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '9'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '9'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 010
-                trigger  ( ./005/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/010 eq complete))
-                edit SUBFSFAMILY '/010'
-                edit EPSMEMBER '10'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc2'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '10'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '10'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '10'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '10'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '10'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '10'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '10'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 011
-                trigger  ( ./006/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/011 eq complete))
-                edit SUBFSFAMILY '/011'
-                edit EPSMEMBER '11'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc2'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '11'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '11'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '11'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '11'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '11'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '11'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '11'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 012
-                trigger  ( ./007/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/012 eq complete))
-                edit SUBFSFAMILY '/012'
-                edit EPSMEMBER '12'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc2'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '12'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '12'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '12'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '12'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '12'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '12'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '12'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 013
-                trigger  ( ./008/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/013 eq complete))
-                edit SUBFSFAMILY '/013'
-                edit EPSMEMBER '13'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc2'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '13'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '13'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '13'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '13'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '13'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '13'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '13'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 014
-                trigger  ( ./009/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/014 eq complete))
-                edit SUBFSFAMILY '/014'
-                edit EPSMEMBER '14'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc2'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '14'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '14'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '14'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '14'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '14'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc2'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '14'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '14'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 015
-                trigger  ( ./010/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/015 eq complete))
-                edit SUBFSFAMILY '/015'
-                edit EPSMEMBER '15'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc3'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '15'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '15'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '15'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '15'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '15'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '15'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '15'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 016
-                trigger  ( ./011/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/016 eq complete))
-                edit SUBFSFAMILY '/016'
-                edit EPSMEMBER '16'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc3'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '16'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '16'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '16'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '16'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '16'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '16'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '16'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 017
-                trigger  ( ./012/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/017 eq complete))
-                edit SUBFSFAMILY '/017'
-                edit EPSMEMBER '17'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc3'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '17'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '17'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '17'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '17'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '17'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '17'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '17'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 018
-                trigger  ( ./013/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/018 eq complete))
-                edit SUBFSFAMILY '/018'
-                edit EPSMEMBER '18'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc3'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '18'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '18'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '18'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '18'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '18'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '18'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '18'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 019
-                trigger  ( ./014/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/019 eq complete))
-                edit SUBFSFAMILY '/019'
-                edit EPSMEMBER '19'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc3'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '19'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '19'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '19'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '19'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '19'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc3'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '19'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '19'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 020
-                trigger  ( ./015/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/020 eq complete))
-                edit SUBFSFAMILY '/020'
-                edit EPSMEMBER '20'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc4'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '20'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '20'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '20'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '20'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '20'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '20'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '20'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 021
-                trigger  ( ./016/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/021 eq complete))
-                edit SUBFSFAMILY '/021'
-                edit EPSMEMBER '21'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc4'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '21'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '21'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '21'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '21'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '21'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '21'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '21'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 022
-                trigger  ( ./017/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/022 eq complete))
-                edit SUBFSFAMILY '/022'
-                edit EPSMEMBER '22'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc4'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '22'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '22'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '22'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '22'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '22'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '22'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '22'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 023
-                trigger  ( ./018/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/023 eq complete))
-                edit SUBFSFAMILY '/023'
-                edit EPSMEMBER '23'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc4'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '23'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '23'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '23'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '23'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '23'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '23'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '23'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 024
-                trigger  ( ./019/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/024 eq complete))
-                edit SUBFSFAMILY '/024'
-                edit EPSMEMBER '24'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc4'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '24'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '24'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '24'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '24'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '24'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc4'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '24'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '24'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 025
-                trigger  ( ./020/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/025 eq complete))
-                edit SUBFSFAMILY '/025'
-                edit EPSMEMBER '25'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc5'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '25'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '25'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '25'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '25'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '25'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '25'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '25'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 026
-                trigger  ( ./021/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/026 eq complete))
-                edit SUBFSFAMILY '/026'
-                edit EPSMEMBER '26'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc5'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '26'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '26'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '26'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '26'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '26'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '26'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '26'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 027
-                trigger  ( ./022/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/027 eq complete))
-                edit SUBFSFAMILY '/027'
-                edit EPSMEMBER '27'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc5'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '27'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '27'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '27'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '27'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '27'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '27'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '27'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 028
-                trigger  ( ./023/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/028 eq complete))
-                edit SUBFSFAMILY '/028'
-                edit EPSMEMBER '28'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc5'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '28'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '28'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '28'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '28'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '28'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '28'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '28'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 029
-                trigger  ( ./024/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/029 eq complete))
-                edit SUBFSFAMILY '/029'
-                edit EPSMEMBER '29'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc5'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '29'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '29'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '29'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '29'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '29'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc5'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '29'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '29'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 030
-                trigger  ( ./025/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/030 eq complete))
-                edit SUBFSFAMILY '/030'
-                edit EPSMEMBER '30'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc6'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '30'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '30'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '30'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '30'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '30'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '30'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '30'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 031
-                trigger  ( ./026/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/031 eq complete))
-                edit SUBFSFAMILY '/031'
-                edit EPSMEMBER '31'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc6'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '31'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '31'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '31'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '31'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '31'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '31'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '31'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 032
-                trigger  ( ./027/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/032 eq complete))
-                edit SUBFSFAMILY '/032'
-                edit EPSMEMBER '32'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc6'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '32'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '32'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '32'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '32'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '32'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '32'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '32'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 033
-                trigger  ( ./028/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/033 eq complete))
-                edit SUBFSFAMILY '/033'
-                edit EPSMEMBER '33'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc6'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '33'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '33'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '33'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '33'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '33'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '33'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '33'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 034
-                trigger  ( ./029/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/034 eq complete))
-                edit SUBFSFAMILY '/034'
-                edit EPSMEMBER '34'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc6'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '34'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '34'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '34'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '34'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '34'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc6'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '34'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '34'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 035
-                trigger  ( ./030/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/035 eq complete))
-                edit SUBFSFAMILY '/035'
-                edit EPSMEMBER '35'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc7'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '35'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '35'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '35'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '35'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '35'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '35'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '35'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 036
-                trigger  ( ./031/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/036 eq complete))
-                edit SUBFSFAMILY '/036'
-                edit EPSMEMBER '36'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc7'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '36'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '36'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '36'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '36'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '36'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '36'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '36'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 037
-                trigger  ( ./032/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/037 eq complete))
-                edit SUBFSFAMILY '/037'
-                edit EPSMEMBER '37'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc7'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '37'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '37'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '37'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '37'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '37'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '37'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '37'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 038
-                trigger  ( ./033/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/038 eq complete))
-                edit SUBFSFAMILY '/038'
-                edit EPSMEMBER '38'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc7'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '38'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '38'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '38'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '38'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '38'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '38'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '38'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 039
-                trigger  ( ./034/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/039 eq complete))
-                edit SUBFSFAMILY '/039'
-                edit EPSMEMBER '39'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc7'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '39'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '39'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '39'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '39'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '39'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc7'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '39'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '39'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 040
-                trigger  ( ./035/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/040 eq complete))
-                edit SUBFSFAMILY '/040'
-                edit EPSMEMBER '40'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc8'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '40'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '40'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '40'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '40'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '40'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '40'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '40'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 041
-                trigger  ( ./036/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/041 eq complete))
-                edit SUBFSFAMILY '/041'
-                edit EPSMEMBER '41'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc8'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '41'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '41'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '41'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '41'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '41'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '41'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '41'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 042
-                trigger  ( ./037/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/042 eq complete))
-                edit SUBFSFAMILY '/042'
-                edit EPSMEMBER '42'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc8'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '42'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '42'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '42'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '42'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '42'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '42'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '42'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 043
-                trigger  ( ./038/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/043 eq complete))
-                edit SUBFSFAMILY '/043'
-                edit EPSMEMBER '43'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc8'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '43'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '43'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '43'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '43'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '43'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '43'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '43'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 044
-                trigger  ( ./039/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/044 eq complete))
-                edit SUBFSFAMILY '/044'
-                edit EPSMEMBER '44'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc8'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '44'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '44'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '44'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '44'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '44'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc8'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '44'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '44'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 045
-                trigger  ( ./040/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/045 eq complete))
-                edit SUBFSFAMILY '/045'
-                edit EPSMEMBER '45'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc9'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '45'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '45'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '45'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '45'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '45'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '45'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '45'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 046
-                trigger  ( ./041/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/046 eq complete))
-                edit SUBFSFAMILY '/046'
-                edit EPSMEMBER '46'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc9'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '46'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '46'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '46'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '46'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '46'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an1'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '46'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '46'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 047
-                trigger  ( ./042/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/047 eq complete))
-                edit SUBFSFAMILY '/047'
-                edit EPSMEMBER '47'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc9'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '47'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '47'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '47'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '47'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '47'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an2'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '47'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '47'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 048
-                trigger  ( ./043/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/048 eq complete))
-                edit SUBFSFAMILY '/048'
-                edit EPSMEMBER '48'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc9'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '48'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '48'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '48'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '48'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '48'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an3'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '48'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '48'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 049
-                trigger  ( ./044/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/049 eq complete))
-                edit SUBFSFAMILY '/049'
-                edit EPSMEMBER '49'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc9'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '49'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '49'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '49'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '49'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '49'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an4'
-                  edit FCGROUP 'fc9'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '49'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '49'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-              family 050
-                trigger  ( ./045/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/050 eq complete))
-                edit SUBFSFAMILY '/050'
-                edit EPSMEMBER '50'
-                family legA
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc10'
-                  task getiniLeg
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '50'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                  task modeleps
-                    trigger ./getiniLeg eq complete
-                    edit MEM '960'
-                    edit NPES '24'
-                    edit CPUTIME '25000'
-                    edit THREADS '4'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '1'
-                    edit EPSMEMBER '50'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '240'
-                    edit EPSINISTEP_PREVIOUS '0'
-                    edit FCLENGTH '240'
-                    edit TSTEP '1800'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '30'
-                    edit EPSWAMNANG '24'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 240 240
-                endfamily
-                family legB
-                  trigger legA eq complete
-                  complete  ( 2 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc10'
-                  task getvarepsdata
-                    edit EPSLEG '2'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '50'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '399'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    complete  ( 2 gt 1)
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSMEMBER '50'
-                    edit EPSINISTEP '216'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    complete  ( 2 gt 1)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '2'
-                    edit EPSMEMBER '50'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '216'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global100'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    edit EPSFCLENGTH_A '240'
-                    meter step 0 0 0
-                endfamily
-                family legC
-                  trigger legB eq complete
-                  complete  ( 3 gt 1)
-                  edit EPSCOUPLE '0'
-                  edit OCGROUP 'an0'
-                  edit FCGROUP 'fc10'
-                  task getvarepsdata
-                    edit EPSLEG '3'
-                    edit PRIORITY '40'
-                    edit EPSMEMBER '50'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '255'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                  task intHtoL
-                    trigger ./getvarepsdata eq complete
-                    edit QUEUE 'parallel'
-                    edit NPES '8'
-                    edit THREADS '2'
-                    edit MEM '1599'
-                    edit CPUTIME '200'
-                    edit EPSINISTEP '168'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit FCLENGTH '0'
-                  task modeleps
-                    trigger  ( intHtoL eq complete)
-                    edit MEM '960'
-                    edit NPES '16'
-                    edit CPUTIME '4000'
-                    edit THREADS '2'
-                    edit STACK '550'
-                    edit QUEUE 'normal'
-                    edit EPSNLEGS '1'
-                    edit EPSLEG '3'
-                    edit EPSMEMBER '50'
-                    edit EPSFCRES '95'
-                    edit EPSFCLEV '62'
-                    edit EPSFCGTYPE 'l_2'
-                    edit EPSINISTEP '0'
-                    edit EPSINISTEP_PREVIOUS '168'
-                    edit FCLENGTH '0'
-                    edit TSTEP '2700'
-                    edit EPSWAMRESOL 'global300'
-                    edit EPSWAMNFRE '25'
-                    edit EPSWAMNANG '12'
-                    edit EPSWAMNSTPW '1'
-                    meter step 0 0 0
-                endfamily
-              endfamily
-            endfamily
-            task logfiles
-              trigger cv eq complete and cf eq complete and pf eq complete
-              edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-              edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-              edit LOGDIR '/hpce/rdx_dir/msx'
-          endfamily
-          family lag
-            repeat string YMD  "2008021112" # status 3
-            trigger  (  ( ensemble:YMD ge lag:YMD) or  ( ensemble eq complete or ensemble eq unknown)) and  (  ( inigroup:YMD gt lag:YMD) or  ( inigroup eq complete or inigroup eq unknown))
-            complete  ( lag:YMD eq  ~ 1)
-            family archive
-              edit SMSTRIES '1'
-              edit MEM_ARCH '400'
-              edit CPUTIME_ARCH '10000'
-              edit PRIORITY '45'
-              edit FCLENGTH '240'
-              family cv
-                defstatus complete
-                trigger cf eq complete
-                edit ARCHTYPE 'cv'
-                family arch000
-                  trigger  (  ( ../../../ensemble:YMD eq ../../../lag:YMD) and  ( ../../../ensemble/cv eq complete)) or  ( ../../../ensemble:YMD gt ../../../lag:YMD)
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '0'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-              endfamily
-              family cf
-                edit ARCHTYPE 'cf'
-                family arch000
-                  trigger  (  ( ../../../ensemble:YMD eq ../../../lag:YMD) and  ( ../../../ensemble/cf eq complete)) or  ( ../../../ensemble:YMD gt ../../../lag:YMD)
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '0'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-              endfamily
-              family pf
-                trigger cf eq complete and cv eq complete
-                edit ARCHTYPE 'pf'
-                family arch001
-                  trigger  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/001 eq complete and ../../../ensemble/pf/002 eq complete and ../../../ensemble/pf/003 eq complete and ../../../ensemble/pf/004 eq complete and ../../../ensemble/pf/005 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '1'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch002
-                  trigger arch001 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/006 eq complete and ../../../ensemble/pf/007 eq complete and ../../../ensemble/pf/008 eq complete and ../../../ensemble/pf/009 eq complete and ../../../ensemble/pf/010 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '2'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch003
-                  trigger arch002 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/011 eq complete and ../../../ensemble/pf/012 eq complete and ../../../ensemble/pf/013 eq complete and ../../../ensemble/pf/014 eq complete and ../../../ensemble/pf/015 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '3'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch004
-                  trigger arch003 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/016 eq complete and ../../../ensemble/pf/017 eq complete and ../../../ensemble/pf/018 eq complete and ../../../ensemble/pf/019 eq complete and ../../../ensemble/pf/020 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '4'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch005
-                  trigger arch004 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/021 eq complete and ../../../ensemble/pf/022 eq complete and ../../../ensemble/pf/023 eq complete and ../../../ensemble/pf/024 eq complete and ../../../ensemble/pf/025 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '5'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch006
-                  trigger arch005 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/026 eq complete and ../../../ensemble/pf/027 eq complete and ../../../ensemble/pf/028 eq complete and ../../../ensemble/pf/029 eq complete and ../../../ensemble/pf/030 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '6'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch007
-                  trigger arch006 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/031 eq complete and ../../../ensemble/pf/032 eq complete and ../../../ensemble/pf/033 eq complete and ../../../ensemble/pf/034 eq complete and ../../../ensemble/pf/035 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '7'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch008
-                  trigger arch007 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/036 eq complete and ../../../ensemble/pf/037 eq complete and ../../../ensemble/pf/038 eq complete and ../../../ensemble/pf/039 eq complete and ../../../ensemble/pf/040 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '8'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch009
-                  trigger arch008 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/041 eq complete and ../../../ensemble/pf/042 eq complete and ../../../ensemble/pf/043 eq complete and ../../../ensemble/pf/044 eq complete and ../../../ensemble/pf/045 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '9'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-                family arch010
-                  trigger arch009 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/046 eq complete and ../../../ensemble/pf/047 eq complete and ../../../ensemble/pf/048 eq complete and ../../../ensemble/pf/049 eq complete and ../../../ensemble/pf/050 eq complete))
-                  edit EPSCHUNKS '5'
-                  edit EPSARCHGRP '10'
-                  family arch
-                    task ml
-                      event fdb
-                    task pl
-                      trigger  ( ml eq complete or ml eq unknown)
-                      event fdb
-                    task sfc
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
-                      event fdb
-                    task pt
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
-                      event fdb
-                    task pv
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
-                      event fdb
-                    task hl
-                      defstatus complete
-                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
-                      event fdb
-                    task wm_sfc_arc
-                      trigger sfc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                    task wm_ua_arc
-                      trigger wm_sfc_arc eq complete
-                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
-                      edit RUNVARFC '1'
-                  endfamily
-                  task cleanmc
-                    trigger arch eq complete
-                endfamily
-              endfamily
-              family icp
-                trigger ./pf eq complete
-                edit ARCHTYPE 'icp'
-                task ml
-                  event fdb
-                task cleanmc
-                  trigger ml eq complete
-              endfamily
-            endfamily
-            task flush
-              trigger archive/pf eq complete and archive/cf eq complete and archive/cv eq complete and archive/icp eq complete
-              edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-              edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-              edit LOGDIR '/vol/msexplog/outputs'
-              edit QUEUE 'expsms'
-            family ecfs
-              task save
-            endfamily
-            family plot
-              family prob
-                edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                edit LOGDIR '/vol/msexplog/outputs'
-                edit QUEUE 'expsms'
-                task plumea
-                  defstatus complete
-                task pb
-                  defstatus complete
-                  trigger ../../prob eq complete
-              endfamily
-            endfamily
-            family prob
-              defstatus complete
-              task rain
-              task temp
-              task wind
-            endfamily
-            task cleanvarfc
-              trigger archive eq complete and flush eq complete and ecfs eq complete and plot eq complete and prob eq complete
-            task logfiles
-              trigger cleanvarfc eq complete
-              edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-              edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-              edit LOGDIR '/hpce/rdx_dir/msx'
-          endfamily
-        endfamily
-      endfamily
-    endfamily
-    task wipefdb
-      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown)
-      edit YMD '2008021112'
-      edit HOUR ''
-      edit FSFAMILY 'cancel'
-    task cancel
-      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown) and  ( wipefdb eq complete or wipefdb eq unknown)
-      edit YMD '2008021112'
-      edit HOUR ''
-      edit FSFAMILY 'cancel'
-      edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-      edit LOGDIR '/vol/msexplog/outputs'
-      edit QUEUE 'expsms'
-  endfamily
-endsuite
-#============================================================
diff -pruN 5.12.4-1/CSim/test/data/good_defs/operations/xde.def.glog 5.13.0-1/CSim/test/data/good_defs/operations/xde.def.glog
--- 5.12.4-1/CSim/test/data/good_defs/operations/xde.def.glog	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/operations/xde.def.glog	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-DBG:[14:20:32 3.11.2009]    state change /dfo unknown --> queued duration_(00:00:00) initTime_(2009-Nov-03 14:20:32) suiteTime_(2009-Nov-03 14:20:32)
-DBG:[14:20:32 3.11.2009]    state change /dfo queued --> complete duration_(00:00:00) initTime_(2009-Nov-03 14:20:32) suiteTime_(2009-Nov-03 14:20:32)
-DBG:[14:20:32 3.11.2009]    state change /dfi unknown --> queued duration_(00:00:00) initTime_(2009-Nov-03 14:20:32) suiteTime_(2009-Nov-03 14:20:32)
-DBG:[14:20:32 3.11.2009]    state change /dfi queued --> complete duration_(00:00:00) initTime_(2009-Nov-03 14:20:32) suiteTime_(2009-Nov-03 14:20:32)
diff -pruN 5.12.4-1/CSim/test/data/good_defs/operations/xfi.def 5.13.0-1/CSim/test/data/good_defs/operations/xfi.def
--- 5.12.4-1/CSim/test/data/good_defs/operations/xfi.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/operations/xfi.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,265 +0,0 @@
-#============================================================
-suite trunk_test
-  clock hybrid 0 # 18.03.2008 16:54
-  edit USER 'fim'
-  edit SMSINCLUDE '/scratch/ms/fi/fim/hm_home/trunk_test/lib/sms'
-  edit SMSFILES '/scratch/ms/fi/fim/hm_home/trunk_test/lib/sms'
-  edit EXP 'trunk_test'
-  edit ARGS ''
-  edit ENVT ''
-  edit YMD ''
-  edit HH '0'
-  edit Env_system '/home/ms/fi/fim/hm_home/trunk_test/Env_system'
-  edit TARGETNODE '%SMSHOST%'
-  edit HM_REV '/home/ms/dk/nhz/harmonie_release/trunk'
-  edit R_HOST ''
-  edit SRC_DIR ''
-  edit ENSMBR '-1'
-  edit SMSTRIES '1'
-  edit SMSJOBOUT '/hpce/ms_dir/ms/fi/fim/HARMONIE%SMSNAME%.%SMSTRYNO%'
-  edit SMSCMD 'perl -S Submit.pl -o %SMSJOBOUT% %SMSJOB% >> mSMS.log 2>&1'
-  edit SKIPifDONE '0'
-  task InitRun
-  family Build
-    trigger  ( InitRun eq complete)
-    task Build_pack
-    family Utilities
-      task Make_gl
-      task Make_monitor
-      task Make_oulan
-      task Make_gl_ecgate
-    endfamily
-    task Archive_log
-  endfamily
-endsuite
-suite test_def
-  clock hybrid 0 # 09.10.2009 16:54
-  edit USER 'sniemela'
-  edit SMSINCLUDE '/usr/people/sms/usr_def/hirlam/test_def/scripts'
-  edit SMSFILES '/usr/people/sms/usr_def/hirlam/test_def/scripts'
-  edit EXP 'test_def'
-  edit ARGS ''
-  edit ENVT ''
-  edit YMD ''
-  edit HH '0'
-  edit Env_system '/home/users/sniemela/Harmonie/hm_home/test_def/Env_system'
-  edit TARGETNODE '%SMSHOST%'
-  edit HM_REV '/operative/hirlam/home/Harmonie/33h1'
-  edit R_HOST ''
-  edit SRC_DIR ''
-  edit PP ''
-  edit ENSMBR '-1'
-  edit SMSTRIES '1'
-  edit HM_WD '/home/users/sniemela/Harmonie/hm_home/test_def'
-  edit DTGBEG '2008090100'
-  edit DTGEND '2008090100'
-  edit _mSMS_DocURL ''
-  edit SMSJOBOUT '/home/sms/tmp/%SMSNAME%.%SMSTRYNO%'
-  edit SMSCMD 'ssh %SMSHOST% -l %USER% ". /etc/profile;bsub "< %SMSJOB% 1>%SMSJOBOUT% 2>&1 &'
-  edit SKIPifDONE '0'
-  edit KONE_VALINTA 'jumbo'
-  task Ping_HPC
-    edit SMSHOST 'sms.fmi.fi'
-    edit SMSCMD 'sh< %SMSJOB% 1>%SMSJOBOUT% 2>&1 &'
-    label HOST ""
-  task Prepare_SMS
-    trigger  ( Ping_HPC eq complete)
-    edit SMSHOST 'sms.fmi.fi'
-    edit SMSCMD 'sh< %SMSJOB% 1>%SMSJOBOUT% 2>&1 &'
-  task InitRun
-    trigger  ( Ping_HPC eq complete) and  ( Prepare_SMS eq complete)
-  family Build
-    trigger  ( InitRun eq complete)
-    task Build_pack
-    family Utilities
-      task Make_gl
-      task Make_monitor
-      task Make_oulan
-    endfamily
-    task Archive_log
-      trigger  ( Build_pack eq complete and Utilities eq complete)
-  endfamily
-  family MARS
-    trigger  ( InitRun eq complete)
-    task Empty
-  endfamily
-  family MakeCycleInput
-    repeat date YMD 20080901 20080901 1 # status 0
-    trigger  ( Build eq complete and  ( MakeCycleInput:YMD lt  ( Postprocessing:YMD + 3)))
-    family Hour
-      repeat integer HH 0 23 24 # status 0
-      trigger  ( ../InitRun eq complete)
-      complete  (  (  ( ../MakeCycleInput:YMD le 20080901) and  ( Hour:HH lt 00)) or  (  ( ../MakeCycleInput:YMD ge 20080901) and  ( Hour:HH)))
-      task Prepare_cycle
-      family Climate
-        trigger  ( Prepare_cycle eq complete)
-        task Empty
-      endfamily
-      family Boundaries
-        trigger  ( Climate eq complete)
-        task Boundary_strategy
-        family LBC0
-          task hir2aro
-            trigger  ( ../Boundary_strategy eq complete)
-        endfamily
-        family LBC1
-          task hir2aro
-            trigger  ( ../Boundary_strategy eq complete)
-        endfamily
-        family LBC2
-          task hir2aro
-            trigger  ( ../Boundary_strategy eq complete)
-        endfamily
-        family LBC3
-          task hir2aro
-            trigger  ( ../Boundary_strategy eq complete)
-        endfamily
-        family LBC4
-          task hir2aro
-            trigger  ( ../Boundary_strategy eq complete)
-        endfamily
-        family LBC5
-          task hir2aro
-            trigger  ( ../Boundary_strategy eq complete)
-        endfamily
-        family LBC6
-          task hir2aro
-            trigger  ( ../Boundary_strategy eq complete)
-        endfamily
-      endfamily
-      family Observations
-        trigger  ( Climate eq complete and ../../MARS eq complete)
-        task Empty
-      endfamily
-      task Archive_log
-        trigger  ( Boundaries eq complete and Observations eq complete)
-    endfamily
-  endfamily
-  family Date
-    repeat date YMD 20080901 20080901 1 # status 0
-    trigger  ( Build eq complete)
-    family Hour
-      repeat integer HH 0 23 24 # status 0
-      complete  (  (  ( ../Date:YMD le 20080901) and  ( Hour:HH lt 00)) or  (  ( ../Date:YMD ge 20080901) and  ( Hour:HH gt 00)))
-      family Cycle
-        trigger  (  ( ../../MakeCycleInput eq complete) or  ( ../../MakeCycleInput:YMD gt ../../Date:YMD) or  (  ( ../../MakeCycleInput:YMD eq ../../Date:YMD) and  ( ../../MakeCycleInput/Hour:HH gt ../Hour:HH)) or  (  ( ../../MakeCycleInput:YMD eq ../../Date:YMD) and  ( ../../MakeCycleInput/Hour:HH eq ../Hour:HH)))
-        family StartData
-          trigger  (  ( ../../../MakeCycleInput eq complete) or  ( ../../../MakeCycleInput:YMD gt ../../../Date:YMD) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH gt ../../Hour:HH)) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH eq ../../Hour:HH) and  ( ../../../MakeCycleInput/Hour/Boundaries/LBC0 eq complete)))
-          task Prep_ini_surfex
-          task FirstGuess
-        endfamily
-        family Analysis
-          trigger  ( StartData eq complete and  (  ( ../../../MakeCycleInput eq complete) or  ( ../../../MakeCycleInput:YMD gt ../../../Date:YMD) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH gt ../../Hour:HH)) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH eq ../../Hour:HH) and  ( ../../../MakeCycleInput/Hour/Observations eq complete))))
-          family AnSFC
-            task Empty
-          endfamily
-          family AnUA
-            task Empty
-          endfamily
-        endfamily
-        family Forecasting
-          trigger  (  ( StartData eq complete and Analysis eq complete) and  (  ( ../../../MakeCycleInput eq complete) or  ( ../../../MakeCycleInput:YMD gt ../../../Date:YMD) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH gt ../../Hour:HH)) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH eq ../../Hour:HH) and  ( ../../../MakeCycleInput/Hour/Boundaries eq complete))))
-          task Forecast
-          task Archive_fc
-            trigger  ( Forecast eq complete)
-        endfamily
-      endfamily
-      task Archive_log
-        trigger  ( Cycle eq complete)
-      task LogProgress
-        trigger  ( Cycle eq complete)
-    endfamily
-  endfamily
-  family Postprocessing
-    repeat date YMD 20080901 20080901 1 # status 0
-    trigger  ( Build eq complete)
-    family Hour
-      repeat integer HH 0 23 24 # status 0
-      trigger  (  ( ../Date eq complete) or  ( ../Date:YMD gt ../Postprocessing:YMD) or  (  ( ../Date:YMD eq ../Postprocessing:YMD) and  ( ../Date/Hour:HH gt Hour:HH)))
-      complete  (  (  ( ../Postprocessing:YMD le 20080901) and  ( Hour:HH lt 00)) or  (  ( ../Postprocessing:YMD ge 20080901) and  ( Hour:HH gt 00)))
-      family Extract4ver
-        family fldextr0
-          task Run_fldver
-        endfamily
-        family fldextr1
-          task Run_fldver
-        endfamily
-        family fldextr2
-          task Run_fldver
-        endfamily
-        family fldextr3
-          task Run_fldver
-        endfamily
-        family fldextr4
-          task Run_fldver
-        endfamily
-        family fldextr5
-          task Run_fldver
-        endfamily
-        family fldextr6
-          task Run_fldver
-        endfamily
-      endfamily
-      task Gather_extract
-        trigger  ( Extract4ver eq complete)
-      family Postp_family
-        family Postp0
-          task Postpp
-        endfamily
-        family Postp1
-          task Postpp
-        endfamily
-        family Postp2
-          task Postpp
-        endfamily
-        family Postp3
-          task Postpp
-        endfamily
-        family Postp4
-          task Postpp
-        endfamily
-        family Postp5
-          task Postpp
-        endfamily
-        family Postp6
-          task Postpp
-        endfamily
-      endfamily
-      family Grib_family
-        trigger  ( Postp_family eq complete)
-        family Grib0
-          task Makegrib
-        endfamily
-        family Grib1
-          task Makegrib
-        endfamily
-        family Grib2
-          task Makegrib
-        endfamily
-        family Grib3
-          task Makegrib
-        endfamily
-        family Grib4
-          task Makegrib
-        endfamily
-        family Grib5
-          task Makegrib
-        endfamily
-        family Grib6
-          task Makegrib
-        endfamily
-      endfamily
-      task Cleancycle
-        trigger  ( Postp_family eq complete and Gather_extract eq complete and Grib_family eq complete)
-      family ECMWF
-        task Empty
-      endfamily
-      task Archive_log
-        trigger  ( ECMWF eq complete and Cleancycle eq complete)
-      task LogProgress
-        trigger  ( ECMWF eq complete and Cleancycle eq complete)
-        edit PP 'PP'
-    endfamily
-  endfamily
-endsuite
-#============================================================
diff -pruN 5.12.4-1/CSim/test/data/good_defs/operations/xpt.def 5.13.0-1/CSim/test/data/good_defs/operations/xpt.def
--- 5.12.4-1/CSim/test/data/good_defs/operations/xpt.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/operations/xpt.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,2562 +0,0 @@
-#============================================================
-extern an
-extern an
-extern fc
-extern fc
-extern eps_sv
-extern eps_sv
-extern eps_fc
-extern eps_fc
-extern eps_varfc
-extern eps_varfc
-extern oceatm
-extern oceatm
-extern oce
-extern oce
-extern fpos
-extern fpos
-extern sens
-extern sens
-extern wam
-extern wam
-extern oc
-extern oc
-extern climplot
-extern climplot
-extern an
-extern an
-extern fc
-extern fc
-extern eps_sv
-extern eps_sv
-extern eps_fc
-extern eps_fc
-extern eps_varfc
-extern eps_varfc
-extern oceatm
-extern oceatm
-extern oce
-extern oce
-extern fpos
-extern fpos
-extern sens
-extern sens
-extern wam
-extern wam
-extern oc
-extern oc
-extern climplot
-extern climplot
-suite ptb
-  clock hybrid 0 # 03.11.2008 16:55
-  family a020
-    edit SMSTRIES '1'
-    edit SMSFILES '/vol/msverify/sms/ptb/a020'
-    edit SMSINCLUDE '/vol/msverify/sms/ptb/a020/include'
-    edit SMSHOME '/vol/msverify/sms'
-    edit SMSOUT '/vol/msverify/sms'
-    edit SMSLOGPORT '9314'
-    edit SMSLOGHOST 'hpce-batch'
-    edit FSFAMILY ''
-    edit DELTA_DAY '0'
-    edit HOUR ''
-    edit MEMBER '0'
-    edit NPROCA '1'
-    edit NPROCB '1'
-    edit THREADS '1'
-    edit BRANCH ''
-    edit PARALLEL '4'
-    edit DEBUG '0'
-    edit PROFILE '0'
-    edit DISPLAY 'define_your_own:0.0'
-    edit QUEUE 'normal'
-    edit SCHOST 'hpce'
-    edit WSHOST 'ecgate'
-    edit LOGHOST 'ecgate'
-    edit EXPVER 'a020'
-    edit OWNER 'ptb'
-    edit USER 'xpt'
-    edit ACCOUNT 'ptearth'
-    edit YMD '19900101'
-    edit SECS '0'
-    edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-    edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-    edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-    edit LOGDIR '/hpce/rdx_dir/msx'
-    family make
-      edit YMD '19900101'
-      edit HOUR '00'
-      edit FSFAMILY 'make'
-      task setup
-        edit QUEUE 'normal'
-      family libs
-        defstatus complete
-        trigger setup eq complete
-        edit CCSUBDIR '.'
-        task p4setup_ifs
-          edit SMSTRIES '2'
-        task p4diff_ifs
-          trigger p4setup_ifs eq complete
-        family compile
-          trigger p4setup_ifs eq complete
-          family ifsaux
-            defstatus complete
-            task libifsaux
-          endfamily
-          family surf
-            defstatus complete
-            trigger ifsaux eq complete
-            task libsurf
-          endfamily
-          family trans
-            defstatus complete
-            trigger ifsaux eq complete
-            task libtrans
-          endfamily
-          family ifs
-            defstatus complete
-            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( surf eq complete or surf eq unknown)
-            task libifs
-          endfamily
-          family wam
-            defstatus complete
-            trigger ifsaux eq complete
-            task libwam
-          endfamily
-          family odb
-            defstatus complete
-            family compiler
-              task libodbsqlcompiler
-            endfamily
-            family databases
-              trigger compiler eq complete
-              family CCMA
-                task libCCMA
-              endfamily
-              family ECMA
-                task libECMA
-              endfamily
-            endfamily
-            family corelibs
-              trigger ../ifsaux eq complete
-              family odb
-                task libodb
-              endfamily
-              family odbdummy
-                trigger odb/libodb eq complete
-                task libodbdummy
-              endfamily
-              family odbmain
-                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and ../../ifs eq complete
-                task libodbmain
-              endfamily
-              family odbport
-                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and odbmain/libodbmain eq complete and ../../ifs eq complete
-                task libodbport
-              endfamily
-            endfamily
-          endfamily
-          family ssa
-            defstatus complete
-            trigger ifsaux eq complete and ifs eq complete and odb/corelibs/odb/libodb eq complete
-            task libssa
-          endfamily
-          family obstat
-            defstatus complete
-            trigger ifsaux eq complete and odb/corelibs/odb/libodb eq complete
-            task libobstat
-          endfamily
-          family bl
-            defstatus complete
-            trigger ifsaux eq complete
-            task libbl95
-          endfamily
-          family scat
-            defstatus complete
-            trigger ifsaux eq complete
-            task libscat
-          endfamily
-          family satrad
-            defstatus complete
-            trigger ifsaux eq complete
-            task libsatrad
-          endfamily
-          family aeolus
-            defstatus complete
-            trigger ifsaux eq complete
-            task libaeolus
-          endfamily
-          family prepdata
-            defstatus complete
-            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( ifs eq complete or ifs eq unknown)
-            task libprepdata
-          endfamily
-        endfamily
-      endfamily
-      task links
-        trigger  ( setup eq complete or setup eq unknown) and  ( libs eq complete or libs eq unknown)
-        edit QUEUE 'normal'
-      task logfiles
-        trigger  ( links eq complete or links eq unknown)
-        edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-        edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-        edit LOGDIR '/hpce/rdx_dir/msx'
-    endfamily
-    family coup
-      edit VERSION 'a020'
-      edit STREAM 'MMSF'
-      edit EPSTYPE 'fc'
-      edit EMOS_BASE '00'
-      edit DATEMASK '*.*.*'
-      edit FIRST_DAY '0'
-      edit YMD '19690101'
-      edit USE_YMD 'true'
-      edit FCCHUNK '1'
-      edit OCESUITE '0'
-      edit ORIGIN 'ECMF'
-      edit SMSTRIES '1'
-      edit DELTA_DAY '0'
-      edit USER_PRIORITY '50'
-      edit PRIORITY '50'
-      edit EMOS_TYPE 'fc'
-      edit EMOS_TIME_STEP_H '0000'
-      edit EMOS_STREAM 'DA'
-      edit FSFAMILY 'coup'
-      edit FCNPES '1'
-      edit MEMBER '0'
-      edit COUP 'true'
-      edit RUNBACK '0'
-      edit OCASSIMTOTAL '3'
-      edit OCCONTROLTOTAL '1'
-      edit OCNEWPERTORDER 'yes'
-      edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-      edit LOGDIR '/hpce/rdx_dir/msx'
-      edit HOUR '00'
-      edit CHUNK '0'
-      edit RUNCOUPLE '0'
-      edit FCLENGTH '0'
-      edit FCGROUP 'fc0'
-      edit OCGROUP 'an0'
-      edit OCTOTAL '3'
-      edit FCTOTAL '1'
-      edit OCSUITENO '1'
-      edit CFCTOTDONE '0'
-      edit FCTOTDONE '0'
-      edit CFCEXTOTDONE '0'
-      edit FCEXTOTDONE '0'
-      family limits
-        defstatus complete
-        limit mars 1
-        limit cpmodel 1
-        limit fdbclean 1
-        limit ws 1
-        limit PIC 6
-      endfamily
-      family make
-        trigger /ptb/a020/make eq complete
-        task setup
-        task links
-          trigger setup eq complete
-        task datalinks
-          trigger links eq complete
-        task ocsetup
-          trigger datalinks eq complete
-        task libsoc
-          trigger ./ocsetup eq complete
-        task oclinks
-          trigger ./libsoc eq complete
-        task prepdata
-          trigger oclinks eq complete
-        task mc_tools
-          trigger prepdata eq complete
-        task sc_tools
-          trigger mc_tools eq complete
-        task tools
-          defstatus complete
-          trigger oclinks eq complete
-          edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-          edit LOGDIR '/vol/msexplog/outputs'
-          edit QUEUE 'expsms'
-        task octools
-          defstatus complete
-          trigger tools eq complete
-          edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-          edit LOGDIR '/vol/msexplog/outputs'
-          edit QUEUE 'expsms'
-        task build_seasplot
-          defstatus complete
-          trigger octools eq complete
-          edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-          edit LOGDIR '/vol/msexplog/outputs'
-          edit QUEUE 'expsms'
-        family couple
-          trigger mc_tools eq complete
-          task ifs
-            trigger ../oclinks eq complete
-          task oasis
-          task wamabs
-        endfamily
-        family const
-          task wconst
-            trigger ../couple eq complete
-        endfamily
-        family control
-          defstatus complete
-          trigger const eq complete
-          edit FSFAMILY 'control'
-          task ocean
-            trigger ../libsoc eq complete
-          task forcing
-            trigger ocean eq complete
-          task getcouple
-            defstatus complete
-            trigger forcing eq complete
-            edit RUNCOUPLE '1'
-            edit FCGROUP 'fc0'
-        endfamily
-        family assim
-          trigger control eq complete and const eq complete
-          edit FSFAMILY 'assim'
-          task ocean
-            trigger ../libsoc eq complete
-          task forcing
-            trigger ocean eq complete
-          task getcouple
-            trigger forcing eq complete
-            edit RUNCOUPLE '1'
-            edit FCGROUP 'fc0'
-        endfamily
-        task logfiles
-          trigger setup eq complete and links eq complete and datalinks eq complete and ocsetup eq complete and libsoc eq complete and oclinks eq complete and tools eq complete and sc_tools eq complete and octools eq complete and build_seasplot eq complete and couple eq complete and const eq complete and control eq complete and assim eq complete
-          edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-          edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-          edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-          edit LOGDIR '/hpce/rdx_dir/msx'
-          edit LOGTASK 'make'
-      endfamily
-      family fcdate
-        trigger make eq complete
-        family main
-          repeat enumerated YMD  "19690101" "19690102" # status 19690102
-          edit LOGTASK 'fcdate/main'
-          family control0
-            defstatus complete
-            edit FSFAMILY 'control'
-            edit OCTOTAL '1'
-            edit OCGROUP 'an0'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit SUBFSFAMILY '_an0_fc0'
-            edit FCGROUP 'fc0'
-            task getini
-            task inidata
-              trigger getini eq complete
-              edit NPES '12'
-              edit ININPES '12'
-              edit MEM '900'
-              edit THREADS '2'
-              edit CPUTIME '1000'
-            task oceini
-            family eps_sv
-              defstatus complete
-              edit MOFCSV 'true'
-              family svevo
-                edit DELTA_DAY '-2'
-                task getini
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-              endfamily
-              family svini
-                edit DELTA_DAY '0'
-                task getini
-                  trigger ../svevo eq complete
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task targets
-                  trigger svsh eq complete
-                  edit FCLENGTH '48'
-                task subspace
-                  trigger svnh eq complete and svsh eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                task sv1
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '1'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv2
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '2'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv3
-                  trigger sv1 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '3'
-                task sv4
-                  trigger sv2 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '4'
-                task sv5
-                  trigger sv3 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '5'
-                task sv6
-                  trigger sv4 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '6'
-              endfamily
-            endfamily
-            family eps_pert
-              task getae
-                defstatus complete
-                trigger ../eps_sv eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task getsvs
-                defstatus complete
-                trigger getae eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task ocrot
-                defstatus complete
-                trigger getsvs eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task geticp
-                trigger ../getini eq complete
-              family pert_ic
-                inlimit /ptb/a020/coup/limits:PIC
-                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
-                edit EPSTROP '0'
-                family 000
-                  edit MEMBER '0'
-                  task pertinic
-                endfamily
-                family 001
-                  edit MEMBER '1'
-                  task pertinic
-                endfamily
-                family 002
-                  edit MEMBER '2'
-                  task pertinic
-                endfamily
-                family 003
-                  edit MEMBER '3'
-                  task pertinic
-                endfamily
-                family 004
-                  edit MEMBER '4'
-                  task pertinic
-                endfamily
-                family 005
-                  edit MEMBER '5'
-                  task pertinic
-                endfamily
-                family 006
-                  edit MEMBER '6'
-                  task pertinic
-                endfamily
-                family 007
-                  edit MEMBER '7'
-                  task pertinic
-                endfamily
-                family 008
-                  edit MEMBER '8'
-                  task pertinic
-                endfamily
-                family 009
-                  edit MEMBER '9'
-                  task pertinic
-                endfamily
-                family 010
-                  edit MEMBER '10'
-                  task pertinic
-                endfamily
-                family 011
-                  edit MEMBER '11'
-                  task pertinic
-                endfamily
-                family 012
-                  edit MEMBER '12'
-                  task pertinic
-                endfamily
-                family 013
-                  edit MEMBER '13'
-                  task pertinic
-                endfamily
-                family 014
-                  edit MEMBER '14'
-                  task pertinic
-                endfamily
-                family 015
-                  edit MEMBER '15'
-                  task pertinic
-                endfamily
-                family 016
-                  edit MEMBER '16'
-                  task pertinic
-                endfamily
-                family 017
-                  edit MEMBER '17'
-                  task pertinic
-                endfamily
-                family 018
-                  edit MEMBER '18'
-                  task pertinic
-                endfamily
-                family 019
-                  edit MEMBER '19'
-                  task pertinic
-                endfamily
-                family 020
-                  edit MEMBER '20'
-                  task pertinic
-                endfamily
-                family 021
-                  edit MEMBER '21'
-                  task pertinic
-                endfamily
-                family 022
-                  edit MEMBER '22'
-                  task pertinic
-                endfamily
-                family 023
-                  edit MEMBER '23'
-                  task pertinic
-                endfamily
-                family 024
-                  edit MEMBER '24'
-                  task pertinic
-                endfamily
-                family 025
-                  edit MEMBER '25'
-                  task pertinic
-                endfamily
-                family 026
-                  edit MEMBER '26'
-                  task pertinic
-                endfamily
-                family 027
-                  edit MEMBER '27'
-                  task pertinic
-                endfamily
-                family 028
-                  edit MEMBER '28'
-                  task pertinic
-                endfamily
-                family 029
-                  edit MEMBER '29'
-                  task pertinic
-                endfamily
-                family 030
-                  edit MEMBER '30'
-                  task pertinic
-                endfamily
-                family 031
-                  edit MEMBER '31'
-                  task pertinic
-                endfamily
-                family 032
-                  edit MEMBER '32'
-                  task pertinic
-                endfamily
-                family 033
-                  edit MEMBER '33'
-                  task pertinic
-                endfamily
-                family 034
-                  edit MEMBER '34'
-                  task pertinic
-                endfamily
-                family 035
-                  edit MEMBER '35'
-                  task pertinic
-                endfamily
-                family 036
-                  edit MEMBER '36'
-                  task pertinic
-                endfamily
-                family 037
-                  edit MEMBER '37'
-                  task pertinic
-                endfamily
-                family 038
-                  edit MEMBER '38'
-                  task pertinic
-                endfamily
-                family 039
-                  edit MEMBER '39'
-                  task pertinic
-                endfamily
-                family 040
-                  edit MEMBER '40'
-                  task pertinic
-                endfamily
-                family 041
-                  edit MEMBER '41'
-                  task pertinic
-                endfamily
-                family 042
-                  edit MEMBER '42'
-                  task pertinic
-                endfamily
-                family 043
-                  edit MEMBER '43'
-                  task pertinic
-                endfamily
-                family 044
-                  edit MEMBER '44'
-                  task pertinic
-                endfamily
-                family 045
-                  edit MEMBER '45'
-                  task pertinic
-                endfamily
-                family 046
-                  edit MEMBER '46'
-                  task pertinic
-                endfamily
-                family 047
-                  edit MEMBER '47'
-                  task pertinic
-                endfamily
-                family 048
-                  edit MEMBER '48'
-                  task pertinic
-                endfamily
-                family 049
-                  edit MEMBER '49'
-                  task pertinic
-                endfamily
-                family 050
-                  edit MEMBER '50'
-                  task pertinic
-                endfamily
-              endfamily
-            endfamily
-            task ocwavini
-              edit SMSTRIES '2'
-              edit MEM '300'
-              edit NPES '1'
-              edit CPUTIME '400'
-            task ocwcold
-              defstatus complete
-              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
-              edit MEM '800'
-              edit NPES '1'
-              edit THREADS '8'
-              edit CPUTIME '2000'
-            task ocwavfcdata
-              trigger ./ocwcold eq complete and ocwavini eq complete
-            family fc0
-              edit OCFCPERT '0'
-              edit FCGROUP 'fc0'
-              edit SUBFSFAMILY '_an0_fc0'
-              task iniocean
-                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
-              task iniatmos
-                trigger  ( /ptb/a020/coup/fcdate/main/control0/inidata eq complete and /ptb/a020/coup/fcdate/main/control0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/control0/eps_pert eq complete)
-                edit FCCHUNK '1'
-              task cpmodel1
-                inlimit /ptb/a020/coup/limits:cpmodel
-                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/control0/inidata eq complete and /ptb/a020/coup/fcdate/main/control0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/control0/eps_pert eq complete)
-                edit FCCHUNKSUB '1'
-                edit MEM '1300'
-                edit NPES '1'
-                edit THREADS '8'
-                edit EC_SMT 'yes'
-                edit CPUTIME '360000'
-                meter step -1 24 24
-              task extrafields
-                trigger cpmodel1 eq complete
-              task mm_sfc
-                trigger extrafields eq complete
-              task mm_ua
-                trigger mm_sfc eq complete
-            endfamily
-          endfamily
-          family assim0
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an0'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit SUBFSFAMILY '_an0_fc0'
-            edit FCGROUP 'fc0'
-            task getini
-            task inidata
-              trigger getini eq complete
-              edit NPES '12'
-              edit ININPES '12'
-              edit MEM '900'
-              edit THREADS '2'
-              edit CPUTIME '1000'
-            task oceini
-            family eps_sv
-              defstatus complete
-              edit MOFCSV 'true'
-              family svevo
-                edit DELTA_DAY '-2'
-                task getini
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-              endfamily
-              family svini
-                edit DELTA_DAY '0'
-                task getini
-                  trigger ../svevo eq complete
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task targets
-                  trigger svsh eq complete
-                  edit FCLENGTH '48'
-                task subspace
-                  trigger svnh eq complete and svsh eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                task sv1
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '1'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv2
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '2'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv3
-                  trigger sv1 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '3'
-                task sv4
-                  trigger sv2 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '4'
-                task sv5
-                  trigger sv3 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '5'
-                task sv6
-                  trigger sv4 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '6'
-              endfamily
-            endfamily
-            family eps_pert
-              task getae
-                defstatus complete
-                trigger ../eps_sv eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task getsvs
-                defstatus complete
-                trigger getae eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task ocrot
-                defstatus complete
-                trigger getsvs eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task geticp
-                trigger ../getini eq complete
-              family pert_ic
-                inlimit /ptb/a020/coup/limits:PIC
-                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
-                edit EPSTROP '0'
-                family 000
-                  edit MEMBER '0'
-                  task pertinic
-                endfamily
-                family 001
-                  edit MEMBER '1'
-                  task pertinic
-                endfamily
-                family 002
-                  edit MEMBER '2'
-                  task pertinic
-                endfamily
-                family 003
-                  edit MEMBER '3'
-                  task pertinic
-                endfamily
-                family 004
-                  edit MEMBER '4'
-                  task pertinic
-                endfamily
-                family 005
-                  edit MEMBER '5'
-                  task pertinic
-                endfamily
-                family 006
-                  edit MEMBER '6'
-                  task pertinic
-                endfamily
-                family 007
-                  edit MEMBER '7'
-                  task pertinic
-                endfamily
-                family 008
-                  edit MEMBER '8'
-                  task pertinic
-                endfamily
-                family 009
-                  edit MEMBER '9'
-                  task pertinic
-                endfamily
-                family 010
-                  edit MEMBER '10'
-                  task pertinic
-                endfamily
-                family 011
-                  edit MEMBER '11'
-                  task pertinic
-                endfamily
-                family 012
-                  edit MEMBER '12'
-                  task pertinic
-                endfamily
-                family 013
-                  edit MEMBER '13'
-                  task pertinic
-                endfamily
-                family 014
-                  edit MEMBER '14'
-                  task pertinic
-                endfamily
-                family 015
-                  edit MEMBER '15'
-                  task pertinic
-                endfamily
-                family 016
-                  edit MEMBER '16'
-                  task pertinic
-                endfamily
-                family 017
-                  edit MEMBER '17'
-                  task pertinic
-                endfamily
-                family 018
-                  edit MEMBER '18'
-                  task pertinic
-                endfamily
-                family 019
-                  edit MEMBER '19'
-                  task pertinic
-                endfamily
-                family 020
-                  edit MEMBER '20'
-                  task pertinic
-                endfamily
-                family 021
-                  edit MEMBER '21'
-                  task pertinic
-                endfamily
-                family 022
-                  edit MEMBER '22'
-                  task pertinic
-                endfamily
-                family 023
-                  edit MEMBER '23'
-                  task pertinic
-                endfamily
-                family 024
-                  edit MEMBER '24'
-                  task pertinic
-                endfamily
-                family 025
-                  edit MEMBER '25'
-                  task pertinic
-                endfamily
-                family 026
-                  edit MEMBER '26'
-                  task pertinic
-                endfamily
-                family 027
-                  edit MEMBER '27'
-                  task pertinic
-                endfamily
-                family 028
-                  edit MEMBER '28'
-                  task pertinic
-                endfamily
-                family 029
-                  edit MEMBER '29'
-                  task pertinic
-                endfamily
-                family 030
-                  edit MEMBER '30'
-                  task pertinic
-                endfamily
-                family 031
-                  edit MEMBER '31'
-                  task pertinic
-                endfamily
-                family 032
-                  edit MEMBER '32'
-                  task pertinic
-                endfamily
-                family 033
-                  edit MEMBER '33'
-                  task pertinic
-                endfamily
-                family 034
-                  edit MEMBER '34'
-                  task pertinic
-                endfamily
-                family 035
-                  edit MEMBER '35'
-                  task pertinic
-                endfamily
-                family 036
-                  edit MEMBER '36'
-                  task pertinic
-                endfamily
-                family 037
-                  edit MEMBER '37'
-                  task pertinic
-                endfamily
-                family 038
-                  edit MEMBER '38'
-                  task pertinic
-                endfamily
-                family 039
-                  edit MEMBER '39'
-                  task pertinic
-                endfamily
-                family 040
-                  edit MEMBER '40'
-                  task pertinic
-                endfamily
-                family 041
-                  edit MEMBER '41'
-                  task pertinic
-                endfamily
-                family 042
-                  edit MEMBER '42'
-                  task pertinic
-                endfamily
-                family 043
-                  edit MEMBER '43'
-                  task pertinic
-                endfamily
-                family 044
-                  edit MEMBER '44'
-                  task pertinic
-                endfamily
-                family 045
-                  edit MEMBER '45'
-                  task pertinic
-                endfamily
-                family 046
-                  edit MEMBER '46'
-                  task pertinic
-                endfamily
-                family 047
-                  edit MEMBER '47'
-                  task pertinic
-                endfamily
-                family 048
-                  edit MEMBER '48'
-                  task pertinic
-                endfamily
-                family 049
-                  edit MEMBER '49'
-                  task pertinic
-                endfamily
-                family 050
-                  edit MEMBER '50'
-                  task pertinic
-                endfamily
-              endfamily
-            endfamily
-            task ocwavini
-              edit SMSTRIES '2'
-              edit MEM '300'
-              edit NPES '1'
-              edit CPUTIME '400'
-            task ocwcold
-              defstatus complete
-              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
-              edit MEM '800'
-              edit NPES '1'
-              edit THREADS '8'
-              edit CPUTIME '2000'
-            task ocwavfcdata
-              trigger ./ocwcold eq complete and ocwavini eq complete
-            family fc0
-              edit OCFCPERT '0'
-              edit FCGROUP 'fc0'
-              edit SUBFSFAMILY '_an0_fc0'
-              task iniocean
-                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
-              task iniatmos
-                trigger  ( /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
-                edit FCCHUNK '1'
-              task cpmodel1
-                inlimit /ptb/a020/coup/limits:cpmodel
-                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
-                edit FCCHUNKSUB '1'
-                edit MEM '1300'
-                edit NPES '1'
-                edit THREADS '8'
-                edit EC_SMT 'yes'
-                edit CPUTIME '360000'
-                meter step -1 24 24
-              task extrafields
-                trigger cpmodel1 eq complete
-              task mm_sfc
-                trigger extrafields eq complete
-              task mm_ua
-                trigger mm_sfc eq complete
-            endfamily
-          endfamily
-          family assim1
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an1'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit SUBFSFAMILY '_an1_fc1'
-            edit FCGROUP 'fc1'
-            task getini
-              defstatus complete
-            task inidata
-              defstatus complete
-              trigger getini eq complete
-              edit NPES '12'
-              edit ININPES '12'
-              edit MEM '900'
-              edit THREADS '2'
-              edit CPUTIME '1000'
-            task oceini
-            family eps_sv
-              defstatus complete
-              edit MOFCSV 'true'
-              family svevo
-                edit DELTA_DAY '-2'
-                task getini
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-              endfamily
-              family svini
-                edit DELTA_DAY '0'
-                task getini
-                  trigger ../svevo eq complete
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task targets
-                  trigger svsh eq complete
-                  edit FCLENGTH '48'
-                task subspace
-                  trigger svnh eq complete and svsh eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                task sv1
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '1'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv2
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '2'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv3
-                  trigger sv1 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '3'
-                task sv4
-                  trigger sv2 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '4'
-                task sv5
-                  trigger sv3 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '5'
-                task sv6
-                  trigger sv4 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '6'
-              endfamily
-            endfamily
-            family eps_pert
-              defstatus complete
-              task getae
-                defstatus complete
-                trigger ../eps_sv eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task getsvs
-                defstatus complete
-                trigger getae eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task ocrot
-                defstatus complete
-                trigger getsvs eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task geticp
-                trigger ../getini eq complete
-              family pert_ic
-                inlimit /ptb/a020/coup/limits:PIC
-                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
-                edit EPSTROP '0'
-                family 000
-                  edit MEMBER '0'
-                  task pertinic
-                endfamily
-                family 001
-                  edit MEMBER '1'
-                  task pertinic
-                endfamily
-                family 002
-                  edit MEMBER '2'
-                  task pertinic
-                endfamily
-                family 003
-                  edit MEMBER '3'
-                  task pertinic
-                endfamily
-                family 004
-                  edit MEMBER '4'
-                  task pertinic
-                endfamily
-                family 005
-                  edit MEMBER '5'
-                  task pertinic
-                endfamily
-                family 006
-                  edit MEMBER '6'
-                  task pertinic
-                endfamily
-                family 007
-                  edit MEMBER '7'
-                  task pertinic
-                endfamily
-                family 008
-                  edit MEMBER '8'
-                  task pertinic
-                endfamily
-                family 009
-                  edit MEMBER '9'
-                  task pertinic
-                endfamily
-                family 010
-                  edit MEMBER '10'
-                  task pertinic
-                endfamily
-                family 011
-                  edit MEMBER '11'
-                  task pertinic
-                endfamily
-                family 012
-                  edit MEMBER '12'
-                  task pertinic
-                endfamily
-                family 013
-                  edit MEMBER '13'
-                  task pertinic
-                endfamily
-                family 014
-                  edit MEMBER '14'
-                  task pertinic
-                endfamily
-                family 015
-                  edit MEMBER '15'
-                  task pertinic
-                endfamily
-                family 016
-                  edit MEMBER '16'
-                  task pertinic
-                endfamily
-                family 017
-                  edit MEMBER '17'
-                  task pertinic
-                endfamily
-                family 018
-                  edit MEMBER '18'
-                  task pertinic
-                endfamily
-                family 019
-                  edit MEMBER '19'
-                  task pertinic
-                endfamily
-                family 020
-                  edit MEMBER '20'
-                  task pertinic
-                endfamily
-                family 021
-                  edit MEMBER '21'
-                  task pertinic
-                endfamily
-                family 022
-                  edit MEMBER '22'
-                  task pertinic
-                endfamily
-                family 023
-                  edit MEMBER '23'
-                  task pertinic
-                endfamily
-                family 024
-                  edit MEMBER '24'
-                  task pertinic
-                endfamily
-                family 025
-                  edit MEMBER '25'
-                  task pertinic
-                endfamily
-                family 026
-                  edit MEMBER '26'
-                  task pertinic
-                endfamily
-                family 027
-                  edit MEMBER '27'
-                  task pertinic
-                endfamily
-                family 028
-                  edit MEMBER '28'
-                  task pertinic
-                endfamily
-                family 029
-                  edit MEMBER '29'
-                  task pertinic
-                endfamily
-                family 030
-                  edit MEMBER '30'
-                  task pertinic
-                endfamily
-                family 031
-                  edit MEMBER '31'
-                  task pertinic
-                endfamily
-                family 032
-                  edit MEMBER '32'
-                  task pertinic
-                endfamily
-                family 033
-                  edit MEMBER '33'
-                  task pertinic
-                endfamily
-                family 034
-                  edit MEMBER '34'
-                  task pertinic
-                endfamily
-                family 035
-                  edit MEMBER '35'
-                  task pertinic
-                endfamily
-                family 036
-                  edit MEMBER '36'
-                  task pertinic
-                endfamily
-                family 037
-                  edit MEMBER '37'
-                  task pertinic
-                endfamily
-                family 038
-                  edit MEMBER '38'
-                  task pertinic
-                endfamily
-                family 039
-                  edit MEMBER '39'
-                  task pertinic
-                endfamily
-                family 040
-                  edit MEMBER '40'
-                  task pertinic
-                endfamily
-                family 041
-                  edit MEMBER '41'
-                  task pertinic
-                endfamily
-                family 042
-                  edit MEMBER '42'
-                  task pertinic
-                endfamily
-                family 043
-                  edit MEMBER '43'
-                  task pertinic
-                endfamily
-                family 044
-                  edit MEMBER '44'
-                  task pertinic
-                endfamily
-                family 045
-                  edit MEMBER '45'
-                  task pertinic
-                endfamily
-                family 046
-                  edit MEMBER '46'
-                  task pertinic
-                endfamily
-                family 047
-                  edit MEMBER '47'
-                  task pertinic
-                endfamily
-                family 048
-                  edit MEMBER '48'
-                  task pertinic
-                endfamily
-                family 049
-                  edit MEMBER '49'
-                  task pertinic
-                endfamily
-                family 050
-                  edit MEMBER '50'
-                  task pertinic
-                endfamily
-              endfamily
-            endfamily
-            task ocwavini
-              defstatus complete
-              edit SMSTRIES '2'
-              edit MEM '300'
-              edit NPES '1'
-              edit CPUTIME '400'
-            task ocwcold
-              defstatus complete
-              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
-              edit MEM '800'
-              edit NPES '1'
-              edit THREADS '8'
-              edit CPUTIME '2000'
-            task ocwavfcdata
-              defstatus complete
-              trigger ./ocwcold eq complete and ocwavini eq complete
-            family fc1
-              edit OCFCPERT '1'
-              edit FCGROUP 'fc1'
-              edit SUBFSFAMILY '_an1_fc1'
-              task iniocean
-                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
-              task iniatmos
-                trigger  ( /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
-                edit FCCHUNK '1'
-              task cpmodel1
-                inlimit /ptb/a020/coup/limits:cpmodel
-                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
-                edit FCCHUNKSUB '1'
-                edit MEM '1300'
-                edit NPES '1'
-                edit THREADS '8'
-                edit EC_SMT 'yes'
-                edit CPUTIME '360000'
-                meter step -1 24 24
-              task extrafields
-                trigger cpmodel1 eq complete
-              task mm_sfc
-                trigger extrafields eq complete
-              task mm_ua
-                trigger mm_sfc eq complete
-            endfamily
-          endfamily
-          family assim2
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an2'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit SUBFSFAMILY '_an2_fc2'
-            edit FCGROUP 'fc2'
-            task getini
-              defstatus complete
-            task inidata
-              defstatus complete
-              trigger getini eq complete
-              edit NPES '12'
-              edit ININPES '12'
-              edit MEM '900'
-              edit THREADS '2'
-              edit CPUTIME '1000'
-            task oceini
-            family eps_sv
-              defstatus complete
-              edit MOFCSV 'true'
-              family svevo
-                edit DELTA_DAY '-2'
-                task getini
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-              endfamily
-              family svini
-                edit DELTA_DAY '0'
-                task getini
-                  trigger ../svevo eq complete
-                  edit PRIORITY '40'
-                task inidata
-                  trigger getini eq complete
-                  edit NPES '12'
-                  edit ININPES '12'
-                  edit MEM '900'
-                  edit THREADS '2'
-                  edit CPUTIME '1000'
-                task svnh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task svsh
-                  trigger inidata eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB '0'
-                  edit EPSTROP '0'
-                  edit MEMBER '0'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task targets
-                  trigger svsh eq complete
-                  edit FCLENGTH '48'
-                task subspace
-                  trigger svnh eq complete and svsh eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                task sv1
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '1'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv2
-                  trigger targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '2'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                task sv3
-                  trigger sv1 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '3'
-                task sv4
-                  trigger sv2 eq complete and targets eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '4'
-                task sv5
-                  trigger sv3 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '5'
-                task sv6
-                  trigger sv4 eq complete and targets eq complete and subspace eq complete
-                  edit FCLENGTH '48'
-                  edit MEM '1600'
-                  edit NPES '8'
-                  edit THREADS '4'
-                  edit CPUTIME '16000'
-                  edit EC_SMT 'no'
-                  edit EPSSVDIAB 'true'
-                  edit EPSTROP '1'
-                  edit MEMBER '6'
-              endfamily
-            endfamily
-            family eps_pert
-              defstatus complete
-              task getae
-                defstatus complete
-                trigger ../eps_sv eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task getsvs
-                defstatus complete
-                trigger getae eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task ocrot
-                defstatus complete
-                trigger getsvs eq complete
-                edit EPSSVDIAB 'true'
-                edit EPSTROP '1'
-              task geticp
-                trigger ../getini eq complete
-              family pert_ic
-                inlimit /ptb/a020/coup/limits:PIC
-                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
-                edit EPSTROP '0'
-                family 000
-                  edit MEMBER '0'
-                  task pertinic
-                endfamily
-                family 001
-                  edit MEMBER '1'
-                  task pertinic
-                endfamily
-                family 002
-                  edit MEMBER '2'
-                  task pertinic
-                endfamily
-                family 003
-                  edit MEMBER '3'
-                  task pertinic
-                endfamily
-                family 004
-                  edit MEMBER '4'
-                  task pertinic
-                endfamily
-                family 005
-                  edit MEMBER '5'
-                  task pertinic
-                endfamily
-                family 006
-                  edit MEMBER '6'
-                  task pertinic
-                endfamily
-                family 007
-                  edit MEMBER '7'
-                  task pertinic
-                endfamily
-                family 008
-                  edit MEMBER '8'
-                  task pertinic
-                endfamily
-                family 009
-                  edit MEMBER '9'
-                  task pertinic
-                endfamily
-                family 010
-                  edit MEMBER '10'
-                  task pertinic
-                endfamily
-                family 011
-                  edit MEMBER '11'
-                  task pertinic
-                endfamily
-                family 012
-                  edit MEMBER '12'
-                  task pertinic
-                endfamily
-                family 013
-                  edit MEMBER '13'
-                  task pertinic
-                endfamily
-                family 014
-                  edit MEMBER '14'
-                  task pertinic
-                endfamily
-                family 015
-                  edit MEMBER '15'
-                  task pertinic
-                endfamily
-                family 016
-                  edit MEMBER '16'
-                  task pertinic
-                endfamily
-                family 017
-                  edit MEMBER '17'
-                  task pertinic
-                endfamily
-                family 018
-                  edit MEMBER '18'
-                  task pertinic
-                endfamily
-                family 019
-                  edit MEMBER '19'
-                  task pertinic
-                endfamily
-                family 020
-                  edit MEMBER '20'
-                  task pertinic
-                endfamily
-                family 021
-                  edit MEMBER '21'
-                  task pertinic
-                endfamily
-                family 022
-                  edit MEMBER '22'
-                  task pertinic
-                endfamily
-                family 023
-                  edit MEMBER '23'
-                  task pertinic
-                endfamily
-                family 024
-                  edit MEMBER '24'
-                  task pertinic
-                endfamily
-                family 025
-                  edit MEMBER '25'
-                  task pertinic
-                endfamily
-                family 026
-                  edit MEMBER '26'
-                  task pertinic
-                endfamily
-                family 027
-                  edit MEMBER '27'
-                  task pertinic
-                endfamily
-                family 028
-                  edit MEMBER '28'
-                  task pertinic
-                endfamily
-                family 029
-                  edit MEMBER '29'
-                  task pertinic
-                endfamily
-                family 030
-                  edit MEMBER '30'
-                  task pertinic
-                endfamily
-                family 031
-                  edit MEMBER '31'
-                  task pertinic
-                endfamily
-                family 032
-                  edit MEMBER '32'
-                  task pertinic
-                endfamily
-                family 033
-                  edit MEMBER '33'
-                  task pertinic
-                endfamily
-                family 034
-                  edit MEMBER '34'
-                  task pertinic
-                endfamily
-                family 035
-                  edit MEMBER '35'
-                  task pertinic
-                endfamily
-                family 036
-                  edit MEMBER '36'
-                  task pertinic
-                endfamily
-                family 037
-                  edit MEMBER '37'
-                  task pertinic
-                endfamily
-                family 038
-                  edit MEMBER '38'
-                  task pertinic
-                endfamily
-                family 039
-                  edit MEMBER '39'
-                  task pertinic
-                endfamily
-                family 040
-                  edit MEMBER '40'
-                  task pertinic
-                endfamily
-                family 041
-                  edit MEMBER '41'
-                  task pertinic
-                endfamily
-                family 042
-                  edit MEMBER '42'
-                  task pertinic
-                endfamily
-                family 043
-                  edit MEMBER '43'
-                  task pertinic
-                endfamily
-                family 044
-                  edit MEMBER '44'
-                  task pertinic
-                endfamily
-                family 045
-                  edit MEMBER '45'
-                  task pertinic
-                endfamily
-                family 046
-                  edit MEMBER '46'
-                  task pertinic
-                endfamily
-                family 047
-                  edit MEMBER '47'
-                  task pertinic
-                endfamily
-                family 048
-                  edit MEMBER '48'
-                  task pertinic
-                endfamily
-                family 049
-                  edit MEMBER '49'
-                  task pertinic
-                endfamily
-                family 050
-                  edit MEMBER '50'
-                  task pertinic
-                endfamily
-              endfamily
-            endfamily
-            task ocwavini
-              defstatus complete
-              edit SMSTRIES '2'
-              edit MEM '300'
-              edit NPES '1'
-              edit CPUTIME '400'
-            task ocwcold
-              defstatus complete
-              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
-              edit MEM '800'
-              edit NPES '1'
-              edit THREADS '8'
-              edit CPUTIME '2000'
-            task ocwavfcdata
-              defstatus complete
-              trigger ./ocwcold eq complete and ocwavini eq complete
-            family fc2
-              edit OCFCPERT '2'
-              edit FCGROUP 'fc2'
-              edit SUBFSFAMILY '_an2_fc2'
-              task iniocean
-                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
-              task iniatmos
-                trigger  ( /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
-                edit FCCHUNK '1'
-              task cpmodel1
-                inlimit /ptb/a020/coup/limits:cpmodel
-                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
-                edit FCCHUNKSUB '1'
-                edit MEM '1300'
-                edit NPES '1'
-                edit THREADS '8'
-                edit EC_SMT 'yes'
-                edit CPUTIME '360000'
-                meter step -1 24 24
-              task extrafields
-                trigger cpmodel1 eq complete
-              task mm_sfc
-                trigger extrafields eq complete
-              task mm_ua
-                trigger mm_sfc eq complete
-            endfamily
-          endfamily
-          task logfiles
-            trigger control0 eq complete and assim0 eq complete and assim1 eq complete and assim2 eq complete
-            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-            edit LOGDIR '/hpce/rdx_dir/msx'
-            edit MOVE_TO_ECFS 'no'
-        endfamily
-        family lag
-          repeat enumerated YMD  "19690101" "19690102" # status 19690102
-          edit LOGTASK 'fcdate/lag'
-          family control0
-            defstatus complete
-            edit FSFAMILY 'control'
-            edit OCTOTAL '1'
-            edit OCGROUP 'an0'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit FCGROUP 'fc0'
-            edit RUNFC '0'
-            family archive
-              inlimit /ptb/a020/coup/limits:mars
-              edit OCNEWPERTORDER 'yes'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              task preparcoup
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/control0/fc0 eq complete)))
-              task arcfc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-            endfamily
-            family restarts
-              trigger archive eq complete
-              edit FCCHUNKSUB '1'
-              family fc0
-                edit OCFCPERT '0'
-                edit FCGROUP 'fc0'
-                task saverestarts
-              endfamily
-            endfamily
-            task ocflush
-              trigger archive eq complete and restarts eq complete
-            family process
-              family fc0
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/control0/fc0 eq complete)
-                edit OCFCPERT '0'
-                edit FCGROUP 'fc0'
-                task nino_oc
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_daily
-                  trigger nino_oc eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_atmos
-                  trigger nino_daily eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task tcyc
-                  trigger ../../archive eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-              endfamily
-            endfamily
-          endfamily
-          family assim0
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an0'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit FCGROUP 'fc0'
-            edit RUNFC '0'
-            family archive
-              inlimit /ptb/a020/coup/limits:mars
-              edit OCNEWPERTORDER 'yes'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              task preparcoup
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/assim0/fc0 eq complete)))
-              task arcfc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-            endfamily
-            family restarts
-              trigger archive eq complete
-              edit FCCHUNKSUB '1'
-              family fc0
-                edit OCFCPERT '0'
-                edit FCGROUP 'fc0'
-                task saverestarts
-              endfamily
-            endfamily
-            task ocflush
-              trigger archive eq complete and restarts eq complete
-            family process
-              family fc0
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/assim0/fc0 eq complete)
-                edit OCFCPERT '0'
-                edit FCGROUP 'fc0'
-                task nino_oc
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_daily
-                  trigger nino_oc eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_atmos
-                  trigger nino_daily eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task tcyc
-                  trigger ../../archive eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-              endfamily
-            endfamily
-          endfamily
-          family assim1
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an1'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit FCGROUP 'fc1'
-            edit RUNFC '0'
-            family archive
-              inlimit /ptb/a020/coup/limits:mars
-              edit OCNEWPERTORDER 'yes'
-              edit FCGROUP 'fc1'
-              edit FCCHUNK '1'
-              task preparcoup
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/assim1/fc1 eq complete)))
-              task arcfc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-            endfamily
-            family restarts
-              trigger archive eq complete
-              edit FCCHUNKSUB '1'
-              family fc1
-                edit OCFCPERT '1'
-                edit FCGROUP 'fc1'
-                task saverestarts
-              endfamily
-            endfamily
-            task ocflush
-              trigger archive eq complete and restarts eq complete
-            family process
-              family fc1
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/assim1/fc1 eq complete)
-                edit OCFCPERT '1'
-                edit FCGROUP 'fc1'
-                task nino_oc
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_daily
-                  trigger nino_oc eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_atmos
-                  trigger nino_daily eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task tcyc
-                  trigger ../../archive eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-              endfamily
-            endfamily
-          endfamily
-          family assim2
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an2'
-            edit FCTOTAL '1'
-            edit RUNCOUPLE '1'
-            edit FCLENGTH '24'
-            edit FCGROUP 'fc2'
-            edit RUNFC '0'
-            family archive
-              inlimit /ptb/a020/coup/limits:mars
-              edit OCNEWPERTORDER 'yes'
-              edit FCGROUP 'fc2'
-              edit FCCHUNK '1'
-              task preparcoup
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/assim2/fc2 eq complete)))
-              task arcfc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_sfc_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-              task mm_ua_arc
-                trigger preparcoup eq complete
-                event fdb
-                label files ""
-            endfamily
-            family restarts
-              trigger archive eq complete
-              edit FCCHUNKSUB '1'
-              family fc2
-                edit OCFCPERT '2'
-                edit FCGROUP 'fc2'
-                task saverestarts
-              endfamily
-            endfamily
-            task ocflush
-              trigger archive eq complete and restarts eq complete
-            family process
-              family fc2
-                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/assim2/fc2 eq complete)
-                edit OCFCPERT '2'
-                edit FCGROUP 'fc2'
-                task nino_oc
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_daily
-                  trigger nino_oc eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task nino_atmos
-                  trigger nino_daily eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-                task tcyc
-                  trigger ../../archive eq complete
-                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-                  edit LOGDIR '/vol/msexplog/outputs'
-                  edit QUEUE 'expsms'
-              endfamily
-            endfamily
-          endfamily
-          task logfiles
-            trigger control0 eq complete and assim0 eq complete and assim1 eq complete and assim2 eq complete
-            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-            edit LOGDIR '/hpce/rdx_dir/msx'
-            edit MOVE_TO_ECFS 'no'
-        endfamily
-        family clean
-          repeat enumerated YMD  "19690101" "19690102" # status 19690102
-          edit LOGTASK 'fcdate/clean'
-          family control0
-            defstatus complete
-            edit FSFAMILY 'control'
-            edit OCTOTAL '1'
-            edit OCGROUP 'an0'
-            edit RUNCOUPLE '1'
-            edit FCTOTAL '1'
-            edit FCTOT '1'
-            family fc0
-              edit OCFCPERT '0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              task saveoce
-                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/control0 eq complete) and  ( /ptb/a020/coup/fcdate/main/control0 eq complete))))
-              task occleanfdb
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger saveoce eq complete
-                edit ICPDATA '1'
-              task occleanfdbicp
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger occleanfdb eq complete
-              task occleandirs
-                trigger occleanfdb eq complete and occleanfdbicp eq complete
-            endfamily
-          endfamily
-          family assim0
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an0'
-            edit RUNCOUPLE '1'
-            edit FCTOTAL '1'
-            edit FCTOT '3'
-            family fc0
-              edit OCFCPERT '0'
-              edit FCGROUP 'fc0'
-              edit FCCHUNK '1'
-              task saveoce
-                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/assim0 eq complete) and  ( /ptb/a020/coup/fcdate/main/assim0 eq complete))))
-              task occleanfdb
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger saveoce eq complete
-                edit ICPDATA '1'
-              task occleanfdbicp
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger occleanfdb eq complete and ../../assim1 eq complete and ../../assim2 eq complete
-              task occleandirs
-                trigger occleanfdb eq complete and ../../assim1 eq complete and ../../assim2 eq complete and occleanfdbicp eq complete
-            endfamily
-          endfamily
-          family assim1
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an1'
-            edit RUNCOUPLE '1'
-            edit FCTOTAL '1'
-            edit FCTOT '3'
-            family fc1
-              edit OCFCPERT '1'
-              edit FCGROUP 'fc1'
-              edit FCCHUNK '1'
-              task saveoce
-                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/assim1 eq complete) and  ( /ptb/a020/coup/fcdate/main/assim1 eq complete))))
-              task occleanfdb
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger saveoce eq complete
-                edit ICPDATA '1'
-              task occleanfdbicp
-                defstatus complete
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger occleanfdb eq complete
-              task occleandirs
-                trigger occleanfdb eq complete and occleanfdbicp eq complete
-            endfamily
-          endfamily
-          family assim2
-            edit FSFAMILY 'assim'
-            edit OCGROUP 'an2'
-            edit RUNCOUPLE '1'
-            edit FCTOTAL '1'
-            edit FCTOT '3'
-            family fc2
-              edit OCFCPERT '2'
-              edit FCGROUP 'fc2'
-              edit FCCHUNK '1'
-              task saveoce
-                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/assim2 eq complete) and  ( /ptb/a020/coup/fcdate/main/assim2 eq complete))))
-              task occleanfdb
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger saveoce eq complete
-                edit ICPDATA '1'
-              task occleanfdbicp
-                defstatus complete
-                inlimit /ptb/a020/coup/limits:fdbclean
-                trigger occleanfdb eq complete
-              task occleandirs
-                trigger occleanfdb eq complete and occleanfdbicp eq complete
-            endfamily
-          endfamily
-          task logfiles
-            trigger control0 eq complete and assim0 eq complete and assim1 eq complete and assim2 eq complete
-            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
-            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
-            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
-            edit LOGDIR '/hpce/rdx_dir/msx'
-            edit MOVE_TO_ECFS 'no'
-        endfamily
-      endfamily
-    endfamily
-    task wipefdb
-      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown)
-      edit YMD '19900101'
-      edit HOUR '00'
-      edit FSFAMILY 'cancel'
-    task cancel
-      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown) and  ( wipefdb eq complete or wipefdb eq unknown)
-      edit YMD '19900101'
-      edit HOUR '00'
-      edit FSFAMILY 'cancel'
-      edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
-      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
-      edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
-      edit LOGDIR '/vol/msexplog/outputs'
-      edit QUEUE 'expsms'
-  endfamily
-endsuite
-#============================================================
diff -pruN 5.12.4-1/CSim/test/data/good_defs/queue/queue.def 5.13.0-1/CSim/test/data/good_defs/queue/queue.def
--- 5.12.4-1/CSim/test/data/good_defs/queue/queue.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/queue/queue.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite test_queue
-   queue q1 1 2 3 4
-   task t1
-      verify complete:1  
-   task t2
-      trigger /test_queue:q1 == 4
-      verify complete:1  
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/queue/queue2.def 5.13.0-1/CSim/test/data/good_defs/queue/queue2.def
--- 5.12.4-1/CSim/test/data/good_defs/queue/queue2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/queue/queue2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,18 +0,0 @@
-suite test_queue
-   task t1
-      queue q1 1 2 3 4
-      verify complete:1  
-   task t2
-      trigger /test_queue/t1:q1 == 4
-        verify complete:1  
-   family f1
-      queue q2 1 2 3 4
-      task t1
-        verify complete:1  
-   endfamily
-   family f2
-      task t1
-        verify complete:1  
-        trigger /test_queue/f1:q2 > 3
-   endfamily  
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/hybrid_time.def 5.13.0-1/CSim/test/data/good_defs/time/hybrid_time.def
--- 5.12.4-1/CSim/test/data/good_defs/time/hybrid_time.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/hybrid_time.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suite
-  clock hybrid 6.11.2009 +54190
-  family family
-     task t
-        verify complete:3
-        time +00:01 00:03 00:01
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/multiple_time_and_dates_hybrid.def 5.13.0-1/CSim/test/data/good_defs/time/multiple_time_and_dates_hybrid.def
--- 5.12.4-1/CSim/test/data/good_defs/time/multiple_time_and_dates_hybrid.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/multiple_time_and_dates_hybrid.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite suite
-  clock hybrid 5.1.2017
-  family family
-    task t1
-      date  05.01.2017
-      date  06.01.2017
-      time 10:00
-      time 11:00
-      verify complete:2  # because hybrid will be for 24 hrs only
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/multiple_time_and_days.def 5.13.0-1/CSim/test/data/good_defs/time/multiple_time_and_days.def
--- 5.12.4-1/CSim/test/data/good_defs/time/multiple_time_and_days.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/multiple_time_and_days.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite suite
-  clock real 8.1.2017    # sunday
-  family family
-     task t1
-        day  monday      # day means simulator will run for a 1 week unless endclock used
-        day  tuesday
-        time 09:00
-        time 10:00
-        verify complete:4
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/multiple_time_and_days_hybrid.def 5.13.0-1/CSim/test/data/good_defs/time/multiple_time_and_days_hybrid.def
--- 5.12.4-1/CSim/test/data/good_defs/time/multiple_time_and_days_hybrid.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/multiple_time_and_days_hybrid.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-suite suite
-  clock hybrid 12.10.2010  # monday
-  family family
-    task t1
-      day  monday
-      day  tuesday
-      time 09:00
-      time 10:00
-      time 11:00
-      verify complete:3  # because hybrid will be for 24 hrs only, i.e monday
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/multiple_times_and_dates.def 5.13.0-1/CSim/test/data/good_defs/time/multiple_times_and_dates.def
--- 5.12.4-1/CSim/test/data/good_defs/time/multiple_times_and_dates.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/multiple_times_and_dates.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-suite suite
-  clock real 5.1.2017
-  family family
-    task t1
-      date  05.01.2017     # date means simulator will run for a month unless endclock used
-      date  06.01.2017
-      time  13:00
-      time  14:00
-      verify complete:4
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/time.def 5.13.0-1/CSim/test/data/good_defs/time/time.def
--- 5.12.4-1/CSim/test/data/good_defs/time/time.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/time.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suite
-  clock real 5.1.2017        
-  family family
-     task t1
-        time 13:00       # with time attribute simulator will run for 24 hours
-        verify complete:1
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/time_and_date.def 5.13.0-1/CSim/test/data/good_defs/time/time_and_date.def
--- 5.12.4-1/CSim/test/data/good_defs/time/time_and_date.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/time_and_date.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite suite     
-  clock real 5.1.2017
-  family family
-    task t1
-      date 05.01.2017      # simulator will run for a month, unless endclock used
-      time 14:00
-      verify complete:1
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/time_and_tomorrows_date.def 5.13.0-1/CSim/test/data/good_defs/time/time_and_tomorrows_date.def
--- 5.12.4-1/CSim/test/data/good_defs/time/time_and_tomorrows_date.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/time_and_tomorrows_date.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-suite suite
-  clock real 5.1.2017
-  family family
-    task t1
-      date  06.01.2017    # date means simulator will run for a month unless endclock used
-      time  15:00
-      verify complete:1
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/time/time_series.def 5.13.0-1/CSim/test/data/good_defs/time/time_series.def
--- 5.12.4-1/CSim/test/data/good_defs/time/time_series.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/time/time_series.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,8 +0,0 @@
-suite suite
-  clock real 12.10.2009 # 12 October 2009 was a Monday
-  family family
-     task t1                   # with time attribute simulator will run for 24 hours
-       time 00:30 23:59 04:00  # should run 6 times 00:30 4:30 8:30 12:30 16:30 20:30
-       verify complete:6
-  endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/CSim/test/data/good_defs/today/today.def 5.13.0-1/CSim/test/data/good_defs/today/today.def
--- 5.12.4-1/CSim/test/data/good_defs/today/today.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/today/today.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-suite suiteName
-   clock real 1.10.2009 # need to define a date , otherwise we start at current time, and hence test will vary
-   endclock  2.10.2009  # End time, otherwise will simulate for a year, when we have time dependencies
-   task t1
-      today 15:00                   
-      verify complete:1  
-endsuite
diff -pruN 5.12.4-1/CSim/test/data/good_defs/today/today2.def 5.13.0-1/CSim/test/data/good_defs/today/today2.def
--- 5.12.4-1/CSim/test/data/good_defs/today/today2.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/today/today2.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-suite s1
-   clock real 1.10.2009  # need to define a date , otherwise we start at current time, and hence test will vary
-   endclock  2.10.2009  # End time, otherwise will simulate for a year, when we have time dependencies
-   task t1                   
-      today 20:00                         
-      verify complete:1
-   task t2
-      today 15:00            
-      today 16:00                         
-      today 17:00                         
-      today 18:00                         
-      today 19:00                         
-      today 20:00                         
-      verify complete:6
-endsuite
-
diff -pruN 5.12.4-1/CSim/test/data/good_defs/today/today_range.def 5.13.0-1/CSim/test/data/good_defs/today/today_range.def
--- 5.12.4-1/CSim/test/data/good_defs/today/today_range.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/CSim/test/data/good_defs/today/today_range.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,14 +0,0 @@
-suite suiteName
-   clock real 1.10.2009  # need to define a date , otherwise we start at current time, and hence test will vary
-   endclock   2.10.2009  # End time, otherwise will simulate for a year, when we have time dependencies
-   task t1
-      today 10:00 11:00 01:00
-      verify complete:2     
-   task t2
-      today 10:00 11:00 00:30
-      verify complete:3    
-   task t3
-      today 09:00
-      today 10:00 11:00 00:30
-      verify complete:4   
-endsuite
diff -pruN 5.12.4-1/Client/.gitignore 5.13.0-1/Client/.gitignore
--- 5.12.4-1/Client/.gitignore	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/.gitignore	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-/gnuplot.script
diff -pruN 5.12.4-1/Client/CMakeLists.txt 5.13.0-1/Client/CMakeLists.txt
--- 5.12.4-1/Client/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,219 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-set(srcs
-  # Headers
-  src/ecflow/client/ClientCmdCache.hpp
-  src/ecflow/client/ClientEnvironment.hpp
-  src/ecflow/client/ClientInvoker.hpp
-  src/ecflow/client/ClientOptions.hpp
-  src/ecflow/client/Help.hpp
-  src/ecflow/client/Rtt.hpp
-  src/ecflow/client/UrlCmd.hpp
-  # Sources
-  src/ecflow/client/ClientCmdCache.cpp
-  src/ecflow/client/Rtt.cpp
-  src/ecflow/client/ClientEnvironment.cpp
-  src/ecflow/client/ClientInvoker.cpp
-  src/ecflow/client/Help.cpp
-  src/ecflow/client/Rtt.cpp
-  src/ecflow/client/ClientOptions.cpp
-  src/ecflow/client/UrlCmd.cpp
-)
-
-ecbuild_add_library(
-  TARGET
-    libclient
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-  PUBLIC_LIBS
-    base
-    Threads::Threads
-)
-target_clangformat(libclient)
-
-# ========================================================================
-# EXE ecflow_client, if OpenSSL not enabled ${OPENSSL_LIBRARIES}, is empty
-
-ecbuild_add_executable(
-  TARGET
-    ecflow_client
-  SOURCES
-    src/ecflow/client/ClientMain.cpp
-  LIBS
-    libclient
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-)
-target_clangformat(ecflow_client)
-
-# Override default behaviour that add RPATHS during install
-# The only thing that seem to work is set INSTALL_RPATH to ""
-# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
-# had no effect
-#          
-SET_TARGET_PROPERTIES(ecflow_client
-  PROPERTIES
-    INSTALL_RPATH ""
-)
-
-
-
-# use, i.e. don't skip the full RPATH for the build tree
-#SET(CMAKE_SKIP_BUILD_RPATH  FALSE)
-
-# when building, don't use the install RPATH already
-# (but later on when installing)
-#SET(CMAKE_BUILD_WITH_INSTALL_RPATH FALSE) 
-
-# the RPATH to be used when installing
-#SET(CMAKE_INSTALL_RPATH "")
-
-# don't add the automatically determined parts of the RPATH
-# which point to directories outside the build tree to the install RPATH
-#SET(CMAKE_INSTALL_RPATH_USE_LINK_PATH FALSE)
-
-
-# ================================================================================                         
-# TEST
-set(test_srcs
-  # Headers
-  test/InvokeServer.hpp
-  # Sources
-  test/TestClient_main.cpp # test entry point
-  test/TestClientEnvironment.cpp
-  test/TestClientOptions.cpp
-  test/TestClientInterface.cpp
-  test/TestJobGenOnly.cpp
-  test/TestLifeCycle.cpp
-  test/TestInitAddVariables.cpp
-  test/TestRtt.cpp
-  test/TestUrlCmd.cpp
-)
-
-if (ENABLE_SERVER)
-  list(APPEND test_srcs
-    # Headers
-    test/SCPort.hpp
-    # Sources
-    test/SCPort.cpp
-    test/TestClientTimeout.cpp
-    test/TestClientHandleCmd.cpp
-    test/TestCheckPtDefsCmd.cpp
-    test/TestCustomUser.cpp
-    test/TestGroupCmd.cpp
-    test/TestLoadDefsCmd.cpp
-    test/TestLogAndCheckptErrors.cpp
-    test/TestPasswdFile.cpp
-    test/TestPlugCmd.cpp
-    test/TestServer.cpp
-    test/TestServerAndLifeCycle.cpp
-    test/TestServerLoad.cpp
-    test/TestSignalSIGTERM.cpp
-    test/TestWhiteListFile.cpp
-  )
-endif()
-
-ecbuild_add_test(
-  TARGET
-    s_client
-  LABELS
-    integration nightly
-  SOURCES
-    ${test_srcs}
-  INCLUDES
-    ../Base/test
-    ../ANode/test
-  LIBS
-    libclient
-    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-    Boost::timer
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-  DEPENDS
-    ecflow_server # the server is launched to support tests
-  TEST_DEPENDS
-    u_base
-)
-target_clangformat(s_client
-  CONDITION ENABLE_TESTS
-)
-
-if (ENABLE_ALL_TESTS AND ENABLE_SERVER)
-  #
-  # Simple stand alone test
-  #
-  ecbuild_add_test(
-    TARGET
-      p_large_defs
-    LABELS
-      performance
-      manual # requires manual definition of env var ECF_TEST_DEFS_DIR
-    SOURCES
-      # Headers
-      test/SCPort.hpp
-      # Sources
-      test/SCPort.cpp
-      test/TestSinglePerf.cpp
-      test/TestSinglePerf_main.cpp # test entry point
-    INCLUDES
-      ../Base/test
-    LIBS
-      libclient
-      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    DEPENDS
-      ecflow_server # the server is launched to support tests
-    TEST_DEPENDS
-      u_base
-  )
-  target_clangformat(p_large_defs
-    CONDITION ENABLE_TESTS
-  )
-
-  #
-  # test migration
-  #
-  ecbuild_add_test(
-    TARGET
-      m_migration
-    LABELS
-      migration
-      manual # requires command line argument: m_test_migration <>
-    SOURCES
-      # Headers
-      test/SCPort.hpp
-      # Sources
-      test/SCPort.cpp
-      test/TestMigration.cpp
-      test/TestMigration_main.cpp # test entry point
-    INCLUDES
-      ../Base/test
-    LIBS
-      libclient
-      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    DEPENDS
-      ecflow_server # the server is launched to support tests
-    TEST_DEPENDS
-      u_base
-  )
-  target_clangformat(m_migration
-    CONDITION ENABLE_TESTS
-  )
-
-endif()
-
-# ===================================================================
-# install
-# ===================================================================
-install (TARGETS ecflow_client DESTINATION bin)
diff -pruN 5.12.4-1/Client/ecf_hostsfile 5.13.0-1/Client/ecf_hostsfile
--- 5.12.4-1/Client/ecf_hostsfile	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/ecf_hostsfile	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-
-host1:3142
-host2:3143
-
-host3
-
-host4:3147
-
-host5
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientCmdCache.cpp 5.13.0-1/Client/src/ecflow/client/ClientCmdCache.cpp
--- 5.12.4-1/Client/src/ecflow/client/ClientCmdCache.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientCmdCache.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/client/ClientCmdCache.hpp"
-
-std::shared_ptr<CSyncCmd> ClientCmdCache::csync_cmd(CSyncCmd::Api api,
-                                                    unsigned int client_handle,
-                                                    unsigned int client_state_change_no,
-                                                    unsigned int client_modify_change_no) const {
-    if (!csync_cmd_)
-        csync_cmd_ = std::make_shared<CSyncCmd>();
-    // csync_cmd_->init(api,client_handle,client_state_change_no,client_modify_change_no);
-    return csync_cmd_;
-}
-
-std::shared_ptr<CSyncCmd> ClientCmdCache::csync_cmd(unsigned int client_handle) const {
-    if (!csync_cmd_)
-        csync_cmd_ = std::make_shared<CSyncCmd>();
-    // csync_cmd_->init(client_handle);
-    return csync_cmd_;
-}
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientCmdCache.hpp 5.13.0-1/Client/src/ecflow/client/ClientCmdCache.hpp
--- 5.12.4-1/Client/src/ecflow/client/ClientCmdCache.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientCmdCache.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,35 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_ClientCmdCache_HPP
-#define ecflow_client_ClientCmdCache_HPP
-
-#include "ecflow/base/cts/user/CSyncCmd.hpp"
-
-class ClientCmdCache {
-public:
-    ClientCmdCache() = default;
-    // Disable copy (and move) semantics
-    ClientCmdCache(const ClientCmdCache&)                  = delete;
-    const ClientCmdCache& operator=(const ClientCmdCache&) = delete;
-
-    ~ClientCmdCache() = default;
-
-    std::shared_ptr<CSyncCmd> csync_cmd(CSyncCmd::Api,
-                                        unsigned int client_handle,
-                                        unsigned int client_state_change_no,
-                                        unsigned int client_modify_change_no) const;
-    std::shared_ptr<CSyncCmd> csync_cmd(unsigned int client_handle) const;
-
-private:
-    mutable std::shared_ptr<CSyncCmd> csync_cmd_;
-};
-
-#endif /* ecflow_client_ClientCmdCache_HPP */
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientEnvironment.cpp 5.13.0-1/Client/src/ecflow/client/ClientEnvironment.cpp
--- 5.12.4-1/Client/src/ecflow/client/ClientEnvironment.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,426 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/client/ClientEnvironment.hpp"
-
-#include <cstdlib> // for getenv()
-#include <iostream>
-#include <iterator>
-#include <stdexcept>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/PasswdFile.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeStamp.hpp"
-#include "ecflow/core/Version.hpp"
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/Openssl.hpp"
-#endif
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-
-// Provide upper and lower bounds for timeouts
-/// The timeout is used control for how long we continue to iterate over the hosts
-/// attempting to connect to the servers.
-#ifdef DEBUG
-    #define MAX_TIMEOUT 120            // Max time in seconds for client to deliver message
-    #define DEFAULT_ZOMBIE_TIMEOUT 120 // Max time in seconds for client to deliver message
-    #define MIN_TIMEOUT 5              // Some reasonable value
-#else
-    #define MAX_TIMEOUT 24 * 3600            // We don't try forever, only 24 hours
-    #define DEFAULT_ZOMBIE_TIMEOUT 12 * 3600 // We don't try forever, only 12 hours
-    #define MIN_TIMEOUT 10 * 60              // Some reasonable value
-#endif
-
-// #define DEBUG_ENVIRONMENT 1
-
-template <class T>
-ostream& operator<<(ostream& os, const vector<T>& v) {
-    copy(v.begin(), v.end(), ostream_iterator<T>(cout, "\n"));
-    return os;
-}
-
-ClientEnvironment::ClientEnvironment(bool gui)
-    : AbstractClientEnv(),
-      timeout_(MAX_TIMEOUT),
-      zombie_timeout_(DEFAULT_ZOMBIE_TIMEOUT),
-      gui_(gui) {
-    init();
-}
-
-ClientEnvironment::ClientEnvironment(bool gui, const std::string& host, const std::string& port)
-    : AbstractClientEnv(),
-      timeout_(MAX_TIMEOUT),
-      zombie_timeout_(DEFAULT_ZOMBIE_TIMEOUT),
-      gui_(gui) {
-    init();
-    set_host_port(host, port); // assumes we NOT going to read host file
-}
-
-// test constructor
-ClientEnvironment::ClientEnvironment(const std::string& hostFile, const std::string& host, const std::string& port)
-    : AbstractClientEnv(),
-      timeout_(MAX_TIMEOUT),
-      zombie_timeout_(DEFAULT_ZOMBIE_TIMEOUT) {
-    init();
-
-    /// The host file passed in takes *precedence* over ECF_HOSTFILE environment variable read in init()
-    host_file_ = hostFile;
-
-    /// Override config, and environment.
-    if (!host.empty()) {
-        host_vec_.clear();
-        host_vec_.emplace_back(host, port);
-    }
-}
-
-void ClientEnvironment::init() {
-    read_environment_variables();
-#ifdef DEBUG_ENVIRONMENT
-    std::cout << toString() << std::endl;
-#endif
-
-    // If no host specified default to local host and default port number
-    if (host_vec_.empty())
-        host_vec_.emplace_back(Str::LOCALHOST(), Str::DEFAULT_PORT_NUMBER());
-
-    // Program option are read in last, and will override any previous setting
-    // However program option are delayed until later. See notes in header
-    if (debug_)
-        std::cout << toString() << "\n";
-}
-
-void ClientEnvironment::set_debug(bool flag) {
-    // show client environment when debug is enabled
-    debug_ = flag;
-    if (debug_)
-        std::cout << toString() << "\n";
-}
-
-bool ClientEnvironment::get_next_host(std::string& errorMsg) {
-    if (debug_)
-        cout << "ClientEnvironment::get_next_host() host_file_read_ = " << host_file_read_
-             << " host_file_ = " << host_file_ << "\n";
-    if (!host_file_read_ && !host_file_.empty()) {
-
-        if (!parseHostsFile(errorMsg)) {
-            return false;
-        }
-        host_file_read_ = true;
-        // SKIP OVER THE FIRST HOST, hence both paths need to increment host_vec_index_
-    }
-
-    host_vec_index_++;
-    if (host_vec_index_ >= static_cast<int>(host_vec_.size())) {
-        host_vec_index_ = 0;
-    }
-
-    return true;
-}
-
-// AbstractClientEnv functions: ============================================================================
-const std::string& ClientEnvironment::host() const {
-#ifdef DEBUG_ENVIRONMENT
-// cout << "ClientEnvironment::host()  host_vec_index_ = " << host_vec_index_
-//      << " host_vec_[host_vec_index_] = " << host_vec_[host_vec_index_] << "\n";
-#endif
-    assert(!host_vec_.empty());
-    assert(host_vec_index_ >= 0 && host_vec_index_ < static_cast<int>(host_vec_.size()));
-    return host_vec_[host_vec_index_].first;
-}
-
-const std::string& ClientEnvironment::port() const {
-    assert(!host_vec_.empty());
-    assert(host_vec_index_ >= 0 && host_vec_index_ < static_cast<int>(host_vec_.size()));
-    return host_vec_[host_vec_index_].second;
-}
-
-void ClientEnvironment::set_host_port(const std::string& the_host, const std::string& the_port) {
-    if (the_host.empty())
-        throw std::runtime_error("ClientEnvironment::set_host_port: Empty host specified ?");
-    if (the_port.empty())
-        throw std::runtime_error("ClientEnvironment::set_host_port: Empty port specified ?");
-    try {
-        ecf::convert_to<int>(the_port);
-    }
-    catch (const ecf::bad_conversion&) {
-        throw std::runtime_error("ClientEnvironment::set_host_port: Invalid port number " + the_port);
-    }
-
-    // Override default
-    host_vec_.clear();
-
-    // make sure there only one host:port in host_vec_
-    host_vec_.emplace_back(the_host, the_port);
-
-    // Make sure we don't look in hosts file.
-    // When there is only one host:port in host_vec_, calling get_next_host() will always return host_vec_[0]
-    host_file_read_ = true;
-
-#ifdef ECF_OPENSSL
-    // Must be done *AFTER* host and port set
-    // Avoid enabling SSL for the GUI, via environment, this must be done explicitly by the GUI
-    if (!gui_)
-        enable_ssl_if_defined();
-#endif
-}
-
-bool ClientEnvironment::checkTaskPathAndPassword(std::string& errorMsg) const {
-    if (task_path_.empty()) {
-        errorMsg = "No task path specified for ECF_NAME \n";
-        return false;
-    }
-    if (jobs_password_.empty()) {
-        errorMsg = "No jobs password specified for ECF_PASS \n";
-        return false;
-    }
-    return true;
-}
-
-std::string ClientEnvironment::toString() const {
-    std::stringstream ss;
-    ss << "ClientEnvironment:\n";
-    ss << TimeStamp::now() << Version::description() << "\n";
-    ss << "   ECF_HOST/ECF_PORT : host_vec_index_ = " << host_vec_index_ << " host_vec_.size() = " << host_vec_.size()
-       << "\n";
-    if (!host_vec_.empty()) {
-        for (std::pair<std::string, std::string> i : host_vec_) {
-            ss << "   " << i.first << Str::COLON() << i.second << "\n";
-        }
-    }
-    ss << "   ECF_NAME = " << task_path_ << "\n";
-    ss << "   ECF_PASS = " << jobs_password_ << "\n";
-    ss << "   ECF_RID = " << remote_id_ << "\n";
-    ss << "   ECF_TRYNO = " << task_try_num_ << "\n";
-    ss << "   ECF_HOSTFILE = " << host_file_ << "\n";
-    ss << "   ECF_TIMEOUT = " << timeout_ << "\n";
-    ss << "   ECF_ZOMBIE_TIMEOUT = " << zombie_timeout_ << "\n";
-    ss << "   ECF_CONNECT_TIMEOUT = " << connect_timeout_ << "\n";
-    ss << "   ECF_DENIED = " << denied_ << "\n";
-    ss << "   NO_ECF = " << no_ecf_ << "\n";
-    for (const auto& i : env_) {
-        ss << "   " << i.first << " = " << i.second << "\n";
-    }
-
-    ss << "   ECF_DEBUG_CLIENT = " << debug_ << "\n";
-#ifdef ECF_OPENSSL
-    if (ssl())
-        ss << "   ECF_SSL = " << ssl_ << "\n";
-#endif
-    return ss.str();
-}
-
-std::string ClientEnvironment::hostSpecified() {
-    char* the_host = getenv(Str::ECF_HOST().c_str());
-    if (the_host)
-        return std::string(the_host);
-    return std::string();
-}
-
-std::string ClientEnvironment::portSpecified() {
-    char* theEnv = getenv(Str::ECF_PORT().c_str());
-    if (theEnv) {
-        return std::string(theEnv);
-    }
-    return Str::DEFAULT_PORT_NUMBER();
-}
-
-void ClientEnvironment::read_environment_variables() {
-#ifdef DEBUG_ENVIRONMENT
-    std::cout << "ClientEnvironment::read_environment_variables()\n";
-#endif
-
-    if (getenv(Str::ECF_NAME().c_str()))
-        task_path_ = getenv(Str::ECF_NAME().c_str());
-    if (getenv(Str::ECF_PASS().c_str()))
-        jobs_password_ = getenv(Str::ECF_PASS().c_str());
-    if (getenv(Str::ECF_TRYNO().c_str()))
-        task_try_num_ = atoi(getenv(Str::ECF_TRYNO().c_str()));
-    if (getenv("ECF_HOSTFILE"))
-        host_file_ = getenv("ECF_HOSTFILE");
-    if (getenv(Str::ECF_RID().c_str()))
-        remote_id_ = getenv(Str::ECF_RID().c_str());
-    if (getenv("ECF_USER"))
-        user_name_ = getenv("ECF_USER");
-
-    if (getenv("ECF_TIMEOUT"))
-        timeout_ = atoi(getenv("ECF_TIMEOUT")); // host file timeout
-    if (timeout_ > MAX_TIMEOUT)
-        timeout_ = MAX_TIMEOUT;
-    if (timeout_ < MIN_TIMEOUT)
-        timeout_ = MIN_TIMEOUT;
-
-    if (getenv("ECF_ZOMBIE_TIMEOUT"))
-        zombie_timeout_ = atoi(getenv("ECF_ZOMBIE_TIMEOUT")); // time out for zombies
-    if (zombie_timeout_ > MAX_TIMEOUT)
-        zombie_timeout_ = MAX_TIMEOUT;
-    if (zombie_timeout_ < MIN_TIMEOUT)
-        zombie_timeout_ = MIN_TIMEOUT;
-
-    if (getenv("ECF_CONNECT_TIMEOUT"))
-        connect_timeout_ = atoi(getenv("ECF_CONNECT_TIMEOUT")); // for test only
-
-    if (getenv("ECF_DENIED"))
-        denied_ = true;
-    if (getenv("NO_ECF"))
-        no_ecf_ = true;
-    if (getenv("ECF_DEBUG_CLIENT"))
-        debug_ = true;
-
-    char* debug_level = getenv("ECF_DEBUG_LEVEL");
-    if (debug_level) {
-        try {
-            Ecf::set_debug_level(ecf::convert_to<unsigned int>(debug_level));
-        }
-        catch (...) {
-            throw std::runtime_error("The environment variable ECF_DEBUG_LEVEL must be an unsigned integer.");
-        }
-    }
-
-    /// Override the config settings *IF* any
-    std::string port = Str::DEFAULT_PORT_NUMBER();
-    std::string host = Str::LOCALHOST();
-    if (!host_vec_.empty()) {
-        host = host_vec_[0].first;  //  first entry is the config host
-        port = host_vec_[0].second; //  first entry is the config port
-    }
-
-    if (getenv(Str::ECF_PORT().c_str())) {
-        port = getenv(Str::ECF_PORT().c_str());
-        host_vec_.clear(); // remove config settings, net effect is overriding
-        host_vec_.emplace_back(host, port);
-    }
-
-    // Add the ECF_HOST host into list of hosts. Make sure its first in host_vec_
-    // as we want environment setting to take priority.
-    string env_host = hostSpecified();
-    if (!env_host.empty()) {
-        host = env_host;
-        host_vec_.clear(); // remove previous setting if any
-        host_vec_.emplace_back(host, port);
-    }
-
-#ifdef ECF_OPENSSL
-    // Note: This must be placed here for child commands, where we we typically only use environment variables
-    // Must be done last *AFTER* host and port set
-    // Can't use enable_sll(), since that calls host()/port() which use host_vec_, which may be empty
-    // Avoid enabling SSL for the GUI, via environment, this must be done explicitly by the GUI
-    if (!gui_)
-        ssl_.enable_if_defined(host, port);
-#endif
-}
-
-bool ClientEnvironment::parseHostsFile(std::string& errorMsg) {
-    std::vector<std::string> lines;
-    if (!File::splitFileIntoLines(host_file_, lines, true /*IGNORE EMPTY LINES*/)) {
-        std::stringstream ss;
-        ss << "ClientEnvironment:: Could not open the hosts file " << host_file_;
-        errorMsg += ss.str();
-        return false;
-    }
-
-    // The Home server and port should be at index 0.
-    std::string job_supplied_port = Str::DEFAULT_PORT_NUMBER();
-    if (!host_vec_.empty())
-        job_supplied_port = host_vec_[0].second;
-
-    // Each line should have the format: We only read in the first token.
-    //       host        # comment
-    //       host:port   # another comment
-    // If no port is specified we default to port read in from the environment
-    // if that was not specified we default to Str::DEFAULT_PORT_NUMBER()
-    auto theEnd = lines.end();
-    for (auto i = lines.begin(); i != theEnd; ++i) {
-
-        std::vector<std::string> tokens;
-        Str::split((*i), tokens);
-        if (tokens.empty())
-            continue;
-        if (tokens[0][0] == '#') {
-            //			std::cout << "Ignoring line:'" << *i << "'\n";
-            continue;
-        }
-
-        std::string theBackupHost;
-        std::string thePort;
-
-        size_t colonPos = tokens[0].find_first_of(':');
-        if (colonPos == string::npos) {
-            // When the port is *NOT* specified, we must use the job supplied port.
-            // i.e. the one read in from the environment
-            theBackupHost = tokens[0];
-            thePort       = job_supplied_port;
-            //			std::cout << "Host = " << theBackupHost << " Port is  " << thePort << "\n";
-        }
-        else {
-            theBackupHost = tokens[0].substr(0, colonPos);
-            thePort       = tokens[0].substr(colonPos + 1);
-            //			std::cout << "Host = " << theBackupHost << " Port is specified " << thePort << "\n";
-        }
-
-        // std::cout << "Host = " << theBackupHost << "  " << thePort << "\n";
-        host_vec_.emplace_back(theBackupHost, thePort);
-    }
-
-    return true;
-}
-
-const std::string& ClientEnvironment::get_user_password(const std::string& user) const {
-    return get_password("ECF_PASSWD", user);
-}
-
-const std::string& ClientEnvironment::get_custom_user_password(const std::string& user) const {
-    return get_password("ECF_CUSTOM_PASSWD", user);
-}
-
-const std::string& ClientEnvironment::get_password(const char* env, const std::string& user) const {
-    // cout << "ClientEnvironment::get_password() env:" << env << " user:" << user << " passwd_(" << passwd_ << ")\n";
-    if (user.empty())
-        throw std::runtime_error("ClientEnvironment::get_user_password: No user specified");
-    if (!passwd_.empty()) {
-        // cout << "  ClientEnvironment::get_password() CACHED returning " << passwd_ << "\n";
-        return passwd_;
-    }
-
-    char* file = getenv(env);
-    if (file) {
-        std::string user_passwd_file = file;
-        // cout << "  ClientEnvironment::get_password() ECF_CUSTOM_PASSWD " << user_passwd_file  << "\n";
-        if (!user_passwd_file.empty() && fs::exists(user_passwd_file)) {
-            // cout << "  ClientEnvironment::get_password() LOADING password file\n";
-            PasswdFile passwd_file;
-            std::string errorMsg;
-            if (!passwd_file.load(user_passwd_file, debug(), errorMsg)) {
-                std::stringstream ss;
-                ss << "Could not parse ECF_CUSTOM_PASSWD file. " << errorMsg;
-                throw std::runtime_error(ss.str());
-            }
-            // std::cout << "ClientEnvironment::get_password() PasswdFile.dump()\n" << passwd_file.dump() << "\n";
-            // std::cout << "ClientEnvironment::get_password() user(" << user << ")" << " host(" << host() << ") port("
-            // << port() << ")\n";
-
-            passwd_ = passwd_file.get_passwd(user, host(), port()); // host() may return localhost.
-            if (passwd_.empty()) {
-                Host host;
-                passwd_ = passwd_file.get_passwd(user, host.name(), port());
-            }
-            // cout << "  ClientEnvironment::get_password() returning(" << passwd_ << ")\n";
-            return passwd_;
-        }
-    }
-
-    // cout << "  ClientEnvironment::get_user_password() returning EMPTY \n";
-    return Str::EMPTY();
-}
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientEnvironment.hpp 5.13.0-1/Client/src/ecflow/client/ClientEnvironment.hpp
--- 5.12.4-1/Client/src/ecflow/client/ClientEnvironment.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientEnvironment.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,200 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_ClientEnvironment_HPP
-#define ecflow_client_ClientEnvironment_HPP
-
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/base/AbstractClientEnv.hpp"
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/Openssl.hpp"
-#endif
-
-class ClientEnvironment final : public AbstractClientEnv {
-public:
-    /// The constructor will load the environment
-    explicit ClientEnvironment(bool gui);
-    explicit ClientEnvironment(bool gui, const std::string& host, const std::string& port);
-
-    /// This constructor is only used in Test environment, as it allow the host file to be set
-    explicit ClientEnvironment(const std::string& hostFile, const std::string& host = "", const std::string& port = "");
-
-    /// This controls for how long child commands continue trying to connect to Server before failing.
-    /// Maximum time in seconds for client to deliver message to server/servers. This is
-    /// typically 24 hours in a real environment. It is this long to allow operators to
-    /// recover from any crashes.
-    /// for the CHILD/task commands *ONLY*
-    /// Can be overridden by  changing environment variable ECF_TIMEOUT
-    long max_child_cmd_timeout() const { return timeout_; }
-
-    /// This controls for how long child zombie commands continue trying to connect to Server before failing.
-    /// Maximum time in seconds for client to deliver message to server/servers. This is
-    /// typically 12 hours in a real environment.
-    /// for the CHILD/task commands *ONLY*
-    /// Can be overridden by  changing environment variable ECF_ZOMBIE_TIMEOUT
-    long max_zombie_child_cmd_timeout() const { return zombie_timeout_; }
-
-    /// Allow pure python jobs to override the ECF_TIMEOUT & ECF_ZOMBIE_TIMEOUT
-    void set_child_cmd_timeout(unsigned int t) { timeout_ = t; }
-    void set_zombie_child_cmd_timeout(unsigned int t) { zombie_timeout_ = t; }
-
-    /// The timeout feature allow the client to fail gracefully in the case
-    /// where the server has died/crashed. The timeout will ensure the socket is closed.
-    /// allowing the server to be restarted without getting the address is use error.
-    /// Set the timeout for each client->server communication:
-    //    connect        : timeout_ second
-    //    send request   : timeout_ second
-    //    receive reply  : timeout_ second
-    // default is 0 second, which means take the timeout from the command/request
-    // The default can be overridden with ECF_CONNECT_TIMEOUT.
-    // This is useful when running valgrind --tool=callgrind which leads to
-    // massive slow down and disconnection from the client, when the server is still
-    // running.
-    // used for **test only**
-    int connect_timeout() const { return connect_timeout_; }
-
-    /// When called will demand load the ecf host file, and read the hosts.
-    /// Will then iterate over the host, when the end is reached will start over
-    /// If host cannot be opened or errors occur returns false;
-    bool get_next_host(std::string& errorMsg);
-
-    /// If server denies client communication and this flag is set, exit with an error
-    /// Avoids 24hr hour connection attempt to server. Aids zombie control.
-    bool denied() const { return denied_; }
-
-    /// if NO_ECF is set then abort client immediately.  Client should return success
-    /// useful when we want to test jobs stand-alone
-    bool no_ecf() const { return no_ecf_; }
-
-    /// for debug
-    std::string toString() const;
-
-    /// Return contents of ECF_HOST environment variable, Otherwise an EMPTY string
-    static std::string hostSpecified();
-
-    /// Returns of ECF_PORT,environment variable, otherwise returns Str::DEFAULT_PORT_NUMBER
-    static std::string portSpecified();
-
-    // Set the rid. Only needed to override in regression test, to avoid interference
-    // Should use a better name, as this is really the Process identifier of the running job.
-    // Needs to be the same value as supplied to child command init
-    void set_remote_id(const std::string& rid) { remote_id_ = rid; }
-
-    // Used by python to enable debug of client api
-    void set_debug(bool flag);
-
-#ifdef ECF_OPENSSL
-    /// return true if this is a ssl enabled server
-    ecf::Openssl& openssl() { return ssl_; }
-    bool ssl() const { return ssl_.enabled(); }
-    void enable_ssl_if_defined() {
-        ssl_.enable_if_defined(host(), port());
-    }                                                  // IF ECF_SSL=1,search server.crt, ELSE search <host>.<port>.crt
-    void enable_ssl() { ssl_.enable(host(), port()); } // search server.crt first, then <host>.<port>.crt
-    bool enable_ssl_no_throw() {
-        return ssl_.enable_no_throw(host(), port());
-    }                                      // search server.crt first, then <host>.<port>.crt
-    void disable_ssl() { ssl_.disable(); } // override environment setting for ECF_SSL
-#endif
-
-    // AbstractClientEnv functions:
-    void set_cli(bool f) override { cli_ = f; }
-    bool get_cli() const override { return cli_; }
-    bool checkTaskPathAndPassword(std::string& errorMsg) const override;
-    const std::string& task_path() const override { return task_path_; }
-    int task_try_no() const override { return task_try_num_; }
-    const std::string& jobs_password() const override { return jobs_password_; }
-    const std::string& process_or_remote_id() const override { return remote_id_; }
-    void set_host_port(const std::string& host, const std::string& port) override;
-    const std::string& host() const override;
-    const std::string& port() const override;
-    const std::vector<std::pair<std::string, std::string>>& env() const override { return env_; }
-    const std::string& get_user_password(const std::string& user) const override;
-    const std::string& get_custom_user_password(const std::string& user) const override;
-    void clear_user_password() override { passwd_.clear(); }
-    const std::string& get_user_name() const override { return user_name_; }
-    void set_user_name(const std::string& name) override { user_name_ = name; }
-    void set_password(const std::string& password) override { passwd_ = password; }
-    bool debug() const override { return debug_; } // enabled if ECF_DEBUG_CLIENT set
-    void set_test() override { under_test_ = true; }
-    bool under_test() const override { return under_test_; }
-
-    // Support for python child commands, and python jobs
-    void set_child_path(const std::string& path) { task_path_ = path; }
-    void set_child_password(const std::string& pass) { jobs_password_ = pass; }
-    void set_child_pid(const std::string& pid) { remote_id_ = pid; }
-    void set_child_try_no(unsigned int try_no) { task_try_num_ = try_no; }
-    void set_child_init_add_vars(const std::vector<Variable>& vars) { init_add_vars_ = vars; }
-    void set_child_complete_del_vars(std::vector<std::string>& vars) { complete_del_vars_ = vars; }
-    void set_child_host_file(const std::string& host_file) { host_file_ = host_file; }
-    void set_child_denied(bool denied) { denied_ = denied; }
-    void set_child_no_ecf(bool no_ecf) { no_ecf_ = no_ecf; }
-
-    const std::vector<Variable>& init_add_vars() const { return init_add_vars_; }
-    const std::vector<std::string>& complete_del_vars() const { return complete_del_vars_; }
-
-private:
-    std::string task_path_;     // ECF_NAME = /aSuit/aFam/aTask
-    std::string jobs_password_; // ECF_PASS jobs password
-    std::string remote_id_;     // ECF_RID process id of running job
-    std::string host_file_;     // ECF_HOSTFILE. File that lists the backup hosts, port numbers must match
-    std::string user_name_;
-    mutable std::string passwd_;
-
-    long timeout_;        // ECF_TIMEOUT. Host file iteration time out
-    long zombie_timeout_; // ECF_ZOMBIE_TIMEOUT. Host file iteration time out for zombies, default same as ECF_TIMEOUT
-    std::vector<Variable> init_add_vars_;
-    std::vector<std::string> complete_del_vars_;
-
-    std::vector<std::pair<std::string, std::string>> env_;      // For test allow env variable to be set on defs
-    std::vector<std::pair<std::string, std::string>> host_vec_; // The list of host:port pairs
-
-#ifdef ECF_OPENSSL
-    ecf::Openssl ssl_;
-#endif
-
-    unsigned int task_try_num_{1}; // ECF_TRYNO. The task try number. The number of times the job has been run
-    int connect_timeout_{0};       // default 0, ECF_CONNECT_TIMEOUT, connection timeout
-    int host_vec_index_{0};        // index into host_vec;
-
-    bool cli_{false};    // Command Line Interface
-    bool denied_{false}; // ECF_DENIED.If the server denies the communication, then the child command can be set to fail
-                         // immediately
-    bool no_ecf_{false}; // NO_ECF. if defined then abort cmd immediately. useful when test jobs stand-alone
-    bool debug_{false};  // For live debug, enabled by env variable ECF_CLIENT_DEBUG or set by option -d|--debug
-    bool under_test_{false};     // Used in testing client interface
-    bool host_file_read_{false}; // to ensure we read host file only once
-    bool gui_{false};
-
-    /// The option read from the command line.
-    friend class ClientOptions;
-
-    // Allow testing to override the task path set in the environment. In this constructor
-    friend class ClientInvoker;
-
-private:
-    void init();
-
-    void read_environment_variables(); /// Get the standard environment variables
-
-    void taskPath(const std::string& s) { task_path_ = s; }
-    void set_jobs_password(const std::string& s) { jobs_password_ = s; }
-    void set_connect_timeout(int t) { connect_timeout_ = t; }
-
-    // Allow testing to add or update the environment in the Defs file
-    // Each pair is ( variable name, variable value )
-    void setEnv(const std::vector<std::pair<std::string, std::string>>& e) { env_ = e; }
-
-    bool parseHostsFile(std::string& errorMsg);
-
-    const std::string& get_password(const char*, const std::string& user) const;
-};
-
-#endif /* ecflow_client_ClientEnvironment_HPP */
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientInvoker.cpp 5.13.0-1/Client/src/ecflow/client/ClientInvoker.cpp
--- 5.12.4-1/Client/src/ecflow/client/ClientInvoker.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientInvoker.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1768 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/client/ClientInvoker.hpp"
-
-#include <iostream>
-#include <iterator>
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
-
-#include "ecflow/base/Client.hpp"
-#include "ecflow/base/cts/task/AbortCmd.hpp"
-#include "ecflow/base/cts/task/CompleteCmd.hpp"
-#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
-#include "ecflow/base/cts/task/EventCmd.hpp"
-#include "ecflow/base/cts/task/InitCmd.hpp"
-#include "ecflow/base/cts/task/LabelCmd.hpp"
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-#include "ecflow/base/cts/task/QueueCmd.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/CFileCmd.hpp"
-#include "ecflow/base/cts/user/CSyncCmd.hpp"
-#include "ecflow/base/cts/user/CheckPtCmd.hpp"
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
-#include "ecflow/base/cts/user/DeleteCmd.hpp"
-#include "ecflow/base/cts/user/EditScriptCmd.hpp"
-#include "ecflow/base/cts/user/ForceCmd.hpp"
-#include "ecflow/base/cts/user/FreeDepCmd.hpp"
-#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
-#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
-#include "ecflow/base/cts/user/LogCmd.hpp"
-#include "ecflow/base/cts/user/LogMessageCmd.hpp"
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/base/cts/user/PlugCmd.hpp"
-#include "ecflow/base/cts/user/QueryCmd.hpp"
-#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
-#include "ecflow/base/cts/user/RunNodeCmd.hpp"
-#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
-#include "ecflow/base/cts/user/ZombieCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/SslClient.hpp"
-#endif
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/Rtt.hpp"
-#include "ecflow/core/CommandLine.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/TimeStamp.hpp"
-#include "ecflow/node/Defs.hpp"
-#ifdef DEBUG_PERF
-    #include "ecflow/core/DebugPerf.hpp"
-#endif
-
-#ifdef DEBUG
-
-    #if defined(HPUX) || defined(_AIX)
-        #define RETRY_CONNECTION_PERIOD 2
-        #define NEXT_HOST_POLL_PERIOD 2
-    #else
-        #define RETRY_CONNECTION_PERIOD 1
-        #define NEXT_HOST_POLL_PERIOD 1
-    #endif
-
-#else
-    #define RETRY_CONNECTION_PERIOD 10
-    #define NEXT_HOST_POLL_PERIOD 30
-#endif
-
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-
-// ==================================================================================
-// class ClientInvoker
-ClientInvoker::ClientInvoker() : clientEnv_(false), retry_connection_period_(RETRY_CONNECTION_PERIOD) {
-    if (clientEnv_.debug())
-        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 1=================start=================\n";
-}
-
-ClientInvoker::ClientInvoker(const std::string& host_port)
-    : clientEnv_(false),
-      retry_connection_period_(RETRY_CONNECTION_PERIOD) {
-    if (clientEnv_.debug())
-        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 2=================start=================\n";
-    set_hostport(host_port);
-}
-
-ClientInvoker::ClientInvoker(bool gui, const std::string& host, const std::string& port)
-    : clientEnv_(gui, host, port),
-      retry_connection_period_(RETRY_CONNECTION_PERIOD),
-      gui_(gui) {
-    if (clientEnv_.debug())
-        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 3=================start=================\n";
-}
-
-ClientInvoker::ClientInvoker(const std::string& host, const std::string& port)
-    : clientEnv_(false, host, port),
-      retry_connection_period_(RETRY_CONNECTION_PERIOD) {
-    if (clientEnv_.debug())
-        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 3=================start=================\n";
-}
-
-ClientInvoker::ClientInvoker(const std::string& host, int port)
-    : clientEnv_(false, host, ecf::convert_to<std::string>(port)),
-      retry_connection_period_(RETRY_CONNECTION_PERIOD) {
-    if (clientEnv_.debug())
-        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 4=================start=================\n";
-}
-
-void ClientInvoker::set_host_port(const std::string& host, const std::string& port) {
-    // Allow host and port to be overridden.
-    // o Override environment setting
-    // o For child commands will override opening of ecf_hosts file
-    clientEnv_.set_host_port(host, port);
-}
-
-void ClientInvoker::set_hostport(const std::string& host_port) {
-    // assume format <host>:<port> || <host>@<port>
-    size_t colonPos = host_port.find_first_of(':');
-    if (colonPos == string::npos) {
-        colonPos = host_port.find_first_of('@');
-        if (colonPos == string::npos)
-            throw std::runtime_error("ClientInvoker::set_host_port: expected <host>:<port> || <host>@<port> in " +
-                                     host_port);
-    }
-    std::string host = host_port.substr(0, colonPos);
-    std::string port = host_port.substr(colonPos + 1);
-    set_host_port(host, port);
-}
-
-const std::string& ClientInvoker::host() const {
-    return clientEnv_.host();
-}
-const std::string& ClientInvoker::port() const {
-    return clientEnv_.port();
-}
-
-void ClientInvoker::set_user_name(const std::string& user) {
-    clientEnv_.set_user_name(user);
-    clientEnv_.clear_user_password(); // force re-check of password
-}
-
-void ClientInvoker::set_password(const std::string& password) {
-    clientEnv_.set_password(password);
-}
-
-void ClientInvoker::taskPath(const std::string& s) {
-    test_ = true;
-    clientEnv_.taskPath(s);
-}
-void ClientInvoker::set_jobs_password(const std::string& djp) {
-    test_ = true;
-    clientEnv_.set_jobs_password(djp);
-}
-
-void ClientInvoker::setEnv(const std::vector<std::pair<std::string, std::string>>& e) {
-    assert(!e.empty());
-    test_ = true;
-    clientEnv_.setEnv(e); // For test allow env variable to be set on defs
-}
-
-void ClientInvoker::testInterface() {
-    testInterface_ = true;
-    clientEnv_.set_test();
-}
-
-const std::string& ClientInvoker::process_or_remote_id() const {
-    return clientEnv_.process_or_remote_id();
-}
-
-void ClientInvoker::enable_logging(const std::string& log_file_name) {
-    Rtt::create(log_file_name);
-}
-
-void ClientInvoker::disable_logging() {
-    Rtt::destroy();
-}
-
-void ClientInvoker::set_connect_timeout(int t) {
-    clientEnv_.set_connect_timeout(t);
-}
-
-void ClientInvoker::set_connection_attempts(unsigned int attempts) {
-    connection_attempts_ = attempts;
-    if (connection_attempts_ < 1)
-        connection_attempts_ = 1;
-}
-
-int ClientInvoker::get_cmd_from_args(const CommandLine& cl, Cmd_ptr& cts_cmd) const {
-    try {
-        // read in program option, and construct the client to server commands from them.
-        // This will extract host/port from the environment/ args
-        // This will throw std::runtime_error for invalid arguments or options
-        cts_cmd = args_.parse(cl, &clientEnv_);
-
-        // For --help and --debug, --load defs check_only no command is created
-        // When testInterface avoid writing to standard out.
-        if (!cts_cmd.get()) {
-            if (!testInterface_ && clientEnv_.debug()) {
-                cout << "args: ";
-                for (const auto& token : cl.tokens()) {
-                    cout << token << " ";
-                }
-                cout << "\n";
-            }
-        }
-        return 0;
-    }
-    catch (std::exception& e) {
-        stringstream ss;
-        if (cl.size() == 1) {
-            ss << Ecf::CLIENT_NAME() << ": No options specified\n";
-            ss << "Usage: " << Ecf::CLIENT_NAME() << " [OPTION]...\n";
-            ss << "Try '" << Ecf::CLIENT_NAME() << " --help' for list of options\n";
-        }
-        else {
-            ss << Ecf::CLIENT_NAME() << ": Caught exception whilst parsing arguments:\n" << e.what() << "\n";
-            ss << cl << "\n";
-        }
-        server_reply_.set_error_msg(ss.str());
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-    }
-    catch (...) {
-        server_reply_.set_error_msg("ClientInvoker: caught exception: Parsing arguments: unknown type!\n");
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-    }
-    return 1;
-}
-
-int ClientInvoker::invoke(int argc, char* argv[]) const {
-    return invoke(CommandLine(argc, argv));
-}
-
-int ClientInvoker::invoke(const CommandLine& cl) const {
-    // Allow request to logged & allow logging of round trip time, Hence must be placed *before* RoundTripRecorder
-    RequestLogger request_logger(this);
-
-    // initialise start_time_ and rtt_,
-    RoundTripRecorder round_trip_recorder(this);
-
-    /// If NO_ECF set then abort immediately. returning success. Useful in testing  jobs stand-alone.
-    if (clientEnv_.no_ecf()) {
-        cout << "NO_ECF\n";
-        return 0;
-    } // success
-
-    // Clear error message. For test. Don't keep previous error.
-    // i.e If next test passes when it shouldn't the wrong message is output
-    server_reply_.get_error_msg().clear();
-
-    Cmd_ptr cts_cmd;
-    if (get_cmd_from_args(cl, cts_cmd) == 1)
-        return 1;
-    if (!cts_cmd)
-        return 0; // For --help and --debug, --load defs check_only,  no command is created
-
-    // Under debug we display round trip time for each request
-    request_logger.set_cts_cmd(cts_cmd);
-
-    int res = do_invoke_cmd(cts_cmd);
-    if (res == 1 && on_error_throw_exception_)
-        throw std::runtime_error(server_reply_.error_msg());
-    return res;
-}
-
-int ClientInvoker::invoke(const std::string& arg) const {
-    int argc     = 2;
-    char* argv[] = {const_cast<char*>("ClientInvoker"), const_cast<char*>(arg.c_str())};
-    return invoke(argc, argv);
-}
-
-int ClientInvoker::invoke(const std::vector<std::string>& args) const {
-    return invoke(CommandLine(args));
-}
-
-int ClientInvoker::invoke(Cmd_ptr cts_cmd) const {
-    // assumes clients of Cmd_ptr constructor has caught exceptions
-
-    // Allow request to be logged & allow logging of round trip time, Hence must be placed *before* RoundTripRecorder
-    RequestLogger request_logger(this);
-
-    // initialise start_time_ and rtt_,
-    RoundTripRecorder round_trip_recorder(this);
-
-    // allow display of round trip time for each request
-    request_logger.set_cts_cmd(cts_cmd);
-
-    int res = do_invoke_cmd(cts_cmd);
-    if (res == 1 && on_error_throw_exception_)
-        throw std::runtime_error(server_reply_.error_msg());
-    return res;
-}
-
-int ClientInvoker::do_invoke_cmd(Cmd_ptr cts_cmd) const {
-#ifdef DEBUG_PERF
-    ecf::ScopedDurationTimer timer("  ClientInvoker::do_invoke_cmd");
-#endif
-
-    if (clientEnv_.debug())
-        cout << "\n"
-             << TimeStamp::now() << "ClientInvoker::do_invoke_cmd : on_error_throw_exception_("
-             << on_error_throw_exception_ << ")" << std::endl;
-    if (clientEnv_.no_ecf()) {
-        cout << "NO_ECF\n";
-        return 0;
-    } // success If NO_ECF set then abort immediately. returning success. Useful in testing  jobs stand-alone.
-    if (testInterface_)
-        return 0; // The testInterface_ flag allows testing of client interface, parsing of args, without needing to
-                  // contact server
-    assert(!clientEnv_.host().empty()); // make sure host is NOT empty.
-
-    // Add support for AUTO sync(using the group command), used by GUI and python *ONLY*
-    // only add to group those commands that actually update the defs
-    if (auto_sync_ && !cli() && cts_cmd->cmd_updates_defs() && !cts_cmd->group_cmd()) {
-
-        std::shared_ptr<GroupCTSCmd> grp_cmd = std::make_shared<GroupCTSCmd>(cts_cmd);
-        defs_ptr defs                        = server_reply_.client_defs();
-
-        if (defs.get())
-            grp_cmd->addChild(std::make_shared<CSyncCmd>(
-                CSyncCmd::SYNC, server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
-        else
-            grp_cmd->addChild(std::make_shared<CSyncCmd>(server_reply_.client_handle()));
-
-        cts_cmd = grp_cmd;
-    }
-
-    /// retry_connection_period_ specifies the time to wait, before retrying to connect to server.
-    /// Added to get round glitches in the network.
-    /// However for ping() always default to 1 second. This avoids 10 second wait in release mode.
-    /// We do this both for the CLI(command level interface) and python api
-    unsigned int retry_connection_period = retry_connection_period_;
-    if (cts_cmd->ping_cmd())
-        retry_connection_period = 1;
-
-    try {
-        /// report this message at least once. So client has a clue what's going on
-        bool report_block_client_on_home_server  = false;
-        bool report_block_client_server_halted   = false;
-        bool report_block_client_zombie_detected = false;
-        // We do not want to loop over the sms host list indefinitely hence we use a timer.
-        // The time out period is supplied via ClientEnvironment
-        bool never_polled = true; // don't wait for the first host only subsequent ones
-
-        while (true) {
-
-            // for each host try connecting several times. To compensate for network glitches.
-            int no_of_tries = connection_attempts_;
-            while (no_of_tries > 0) {
-                try {
-                    /// *** Each call to io_service.run(); is a *REQUEST* to the server ***
-                    /// *** Hence we *MUST* clear the server_reply before each call *******
-                    /// *** Found during zombie test. i.e when blocking, we were responding to previous, reply, since
-                    /// server_reply was not being reset *Note* server_reply_.client_handle_ is kept until the next call
-                    /// to register a new client_handle The client invoker can be used multiple times, hence keep value
-                    /// of defs, and client handle in server reply However this is only done, if we are not using the
-                    /// Command Level Interface(cli)
-                    server_reply_.clear_for_invoke(cli());
-
-                    if (!cts_cmd->setup_user_authentification(clientEnv_)) {
-                        server_reply_.set_error_msg("Invalid custom user(ECF_USER || --user <user>) or authentication "
-                                                    "failed for ECF_CUSTOM_PASSWD | ECF_PASSWD");
-                        return 1;
-                    }
-
-                    if (clientEnv_.debug()) {
-                        cout << TimeStamp::now() << "ClientInvoker: >>> " << cts_cmd->print_short();
-                        cout << " on " << client_env_host_port() << " : retry_connection_period("
-                             << retry_connection_period << ") no_of_tries(" << no_of_tries << ") cmd_connect_timeout("
-                             << cts_cmd->timeout() << ") ECF_CONNECT_TIMEOUT(" << clientEnv_.connect_timeout()
-#ifdef ECF_OPENSSL
-                             << ") SSL(" << clientEnv_.ssl()
-#endif
-                             << ")<<<" << endl;
-                    }
-
-                    boost::asio::io_service io_service;
-#ifdef ECF_OPENSSL
-                    if (clientEnv_.ssl()) {
-
-                        clientEnv_.openssl().init_for_client();
-
-                        SslClient theClient(io_service,
-                                            clientEnv_.openssl().context(),
-                                            cts_cmd,
-                                            clientEnv_.host(),
-                                            clientEnv_.port(),
-                                            clientEnv_.connect_timeout());
-                        {
-    #ifdef DEBUG_PERF
-                            ecf::ScopedDurationTimer my_timer("   io_service.run()");
-    #endif
-                            io_service.run();
-                        }
-                        if (clientEnv_.debug())
-                            cout << TimeStamp::now() << "ClientInvoker: >>> After: io_service.run() <<<" << endl;
-
-                        /// Let see how the server responded if at all.
-                        try {
-                            /// will return false if further action required
-                            if (theClient.handle_server_response(server_reply_, clientEnv_.debug())) {
-                                // The normal response.  RoundTriprecorder will record in rtt_
-                                return 0; // the normal exit path
-                            }
-                        }
-                        catch (std::exception& e) {
-                            server_reply_.set_error_msg(e.what());
-                            return 1;
-                        }
-                    }
-                    else {
-#endif
-                        Client theClient(
-                            io_service, cts_cmd, clientEnv_.host(), clientEnv_.port(), clientEnv_.connect_timeout());
-                        {
-#ifdef DEBUG_PERF
-                            ecf::ScopedDurationTimer my_timer("   io_service.run()");
-#endif
-                            io_service.run();
-                        }
-                        if (clientEnv_.debug())
-                            cout << TimeStamp::now() << "ClientInvoker: >>> After: io_service.run() <<<" << endl;
-
-                        /// Let see how the server responded if at all.
-                        try {
-                            /// will return false if further action required
-                            if (theClient.handle_server_response(server_reply_, clientEnv_.debug())) {
-                                // The normal response.  RoundTriprecorder will record in rtt_
-                                return 0; // the normal exit path
-                            }
-                        }
-                        catch (std::exception& e) {
-                            server_reply_.set_error_msg(e.what());
-                            return 1;
-                        }
-#ifdef ECF_OPENSSL
-                    }
-#endif
-
-                    if (server_reply_.block_client_on_home_server()) {
-                        // Valid reply from server. Typically waiting on a expression
-                        // Ok _Block_ on _current_ server, and continue waiting, until server reply is ok
-                        if (!report_block_client_on_home_server || clientEnv_.debug()) {
-                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " : "
-                                 << client_env_host_port() << " : WAITING on home server, continue waiting\n";
-                            report_block_client_on_home_server = true;
-                        }
-                        no_of_tries++;
-                    }
-                    else if (server_reply_.block_client_server_halted()) {
-                        // Valid reply from server.
-                        // fall through try again, then try other hosts
-                        if (!report_block_client_server_halted || clientEnv_.debug()) {
-                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " : "
-                                 << client_env_host_port() << " : blocking : server is HALTED, continue waiting\n";
-                            report_block_client_server_halted = true;
-                        }
-                    }
-                    else if (server_reply_.block_client_zombie_detected()) {
-                        // Valid reply from server.
-                        // fall through try again, then try other hosts
-                        if (!report_block_client_zombie_detected || clientEnv_.debug()) {
-                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " : "
-                                 << client_env_host_port() << " : blocking : zombie detected, continue waiting\n";
-                            report_block_client_zombie_detected = true;
-                        }
-                    }
-                    else if (server_reply_.invalid_argument()) {
-                        // Server could not decode client message and/or client could not decode server reply
-                        if (clientEnv_.debug()) {
-                            cout << TimeStamp::now() << "ClientInvoker:";
-                            cout << " failed : " << client_env_host_port() << " : " << server_reply_.error_msg()
-                                 << "\n";
-                        }
-                        return 1;
-                    }
-                    else if (server_reply_.eof()) {
-                        // Server did not reply or mixing ssl and non ssl
-                        if (clientEnv_.debug()) {
-                            cout << TimeStamp::now() << "ClientInvoker:";
-                            cout << " failed : " << client_env_host_port() << " : " << server_reply_.error_msg()
-                                 << "\n";
-                        }
-                        return 1;
-                    }
-                    else if (server_reply_.client_request_failed()) {
-                        // Valid reply from server
-                        // This error is ONLY valid if we got a real reply from the server
-                        // as opposed to some kind of connection errors. For connections errors
-                        // we fall through and try again.
-                        if (clientEnv_.debug()) {
-                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short()
-                                 << " failed : " << client_env_host_port() << " : " << server_reply_.error_msg()
-                                 << "\n";
-                        }
-                        return 1;
-                    }
-                    else {
-                        std::cout << TimeStamp::now() << "ClientInvoker: missed response? for request "
-                                  << cts_cmd->print_short() << " oops" << endl;
-                    }
-                }
-                catch (std::exception& e) {
-                    // *Some kind of connection error*: fall through and try again. Avoid this message when pinging, i.e
-                    // to see if server is alive.
-                    if (clientEnv_.debug()) {
-                        cerr << TimeStamp::now() << "ClientInvoker: Connection error: (" << e.what() << ")" << endl;
-                    }
-                    if (!cts_cmd->ping_cmd()) {
-                        cerr << TimeStamp::now() << "ClientInvoker: Connection error: (" << e.what() << ")" << endl;
-                    }
-                }
-
-                // Wait a bit before trying to connect again, but only if no_of_tries > 0
-                no_of_tries--;
-                if (no_of_tries > 0)
-                    sleep(retry_connection_period);
-            }
-
-            // Don't bother with other hosts when:
-            //  1/ Testing
-            //  2/ ping-ing
-            //  3/ ECF_DENIED has been set
-            //  4/ Dealing with non tasks based request
-            if (!cts_cmd->connect_to_different_servers() || test_ || cts_cmd->ping_cmd() || clientEnv_.denied()) {
-                std::stringstream ss;
-                ss << TimeStamp::now() << "Request( " << cts_cmd->print_short() << " )";
-                if (clientEnv_.denied())
-                    ss << " ECF_DENIED ";
-                ss << ", Failed to connect to " << client_env_host_port() << ". After " << connection_attempts_
-                   << " attempts. Is the server running ?\n";
-                // Only print client environment if not pinging
-                if (!cts_cmd->ping_cmd())
-                    ss << clientEnv_.toString() << endl;
-                server_reply_.set_error_msg(ss.str());
-                return 1;
-            }
-
-            boost::posix_time::time_duration duration = microsec_clock::universal_time() - start_time_;
-            if (clientEnv_.debug()) {
-                cout << "ClientInvoker: Time duration = " << duration.total_seconds()
-                     << " clientEnv_.max_child_cmd_timeout() = " << clientEnv_.max_child_cmd_timeout() << endl;
-            }
-
-            if (duration.total_seconds() >= clientEnv_.max_child_cmd_timeout()) {
-                std::stringstream ss;
-                ss << TimeStamp::now() << "ClientInvoker: Timed out after ECF_TIMOUT("
-                   << clientEnv_.max_child_cmd_timeout() << ") seconds : for " << client_env_host_port() << "\n";
-                std::string msg = ss.str();
-                cout << msg;
-                server_reply_.set_error_msg(msg);
-                return 1;
-            }
-            if (server_reply_.block_client_zombie_detected() &&
-                duration.total_seconds() >= clientEnv_.max_zombie_child_cmd_timeout()) {
-                std::stringstream ss;
-                ss << TimeStamp::now() << "ClientInvoker: *ZOMBIE* Timed out after ECF_ZOMBIE_TIMEOUT("
-                   << clientEnv_.max_zombie_child_cmd_timeout() << ") seconds : for " << client_env_host_port() << "\n";
-                std::string msg = ss.str();
-                cout << msg;
-                server_reply_.set_error_msg(msg);
-                return 1;
-            }
-
-            // The host is not playing ball, try the next host, will *restart* with home server, if end reached
-            // *get_next_host* *only* returns false if host exists, and parsing it fails
-            std::string current_host_port = client_env_host_port();
-
-            std::string local_error_msg;
-            if (!clientEnv_.get_next_host(local_error_msg)) {
-                /// Instead of exiting, Just spit out a warning
-                cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short()
-                     << " get next host failed because: " << local_error_msg << endl;
-            }
-
-            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " current host("
-                 << current_host_port << ") trying next host(" << client_env_host_port() << ")" << endl;
-
-            if (never_polled)
-                never_polled = false; // To avoid the first wait
-            else
-                sleep(NEXT_HOST_POLL_PERIOD);
-        }
-    }
-    catch (std::exception& e) {
-        stringstream ss;
-        ss << TimeStamp::now() << "ClientInvoker: caught exception: " << e.what() << "\n";
-        server_reply_.set_error_msg(ss.str());
-    }
-    catch (...) {
-        stringstream ss;
-        ss << TimeStamp::now() << "ClientInvoker: Caught Exception of unknown type!\n";
-        server_reply_.set_error_msg(ss.str());
-    }
-    return 1;
-}
-
-void ClientInvoker::reset() const {
-    server_reply_.set_client_defs(defs_ptr());
-    server_reply_.set_client_node(node_ptr());
-    server_reply_.set_client_handle(0);
-}
-
-//=====================================================================================
-// By using the command directly, it is a lot faster than using argc/argv
-// preserve old method to test api/command level interface.
-
-int ClientInvoker::sync(defs_ptr& client_defs) const {
-    if (client_defs.get()) {
-        server_reply_.set_client_defs(client_defs);
-        if (testInterface_)
-            return invoke(CtsApi::sync(
-                server_reply_.client_handle(), client_defs->state_change_no(), client_defs->modify_change_no()));
-        return invoke(std::make_shared<CSyncCmd>(CSyncCmd::SYNC,
-                                                 server_reply_.client_handle(),
-                                                 client_defs->state_change_no(),
-                                                 client_defs->modify_change_no()));
-    }
-
-    if (testInterface_)
-        return invoke(CtsApi::get());
-    int res = invoke(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET));
-    if (res == 0) {
-        client_defs = server_reply_.client_defs(); // update change number
-    }
-    return res;
-}
-
-int ClientInvoker::sync_local(bool sync_suite_clock) const {
-    defs_ptr defs = server_reply_.client_defs();
-    if (defs.get()) {
-
-        // Prevent infinite loops in change observers.
-        if (defs->in_notification()) {
-            std::cout << "ClientInvoker::sync_local() called in the middle of notification. Ignoring..... \n";
-            return 0;
-        }
-
-        if (testInterface_) {
-            if (sync_suite_clock)
-                return invoke(CtsApi::sync_clock(
-                    server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
-            return invoke(
-                CtsApi::sync(server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
-        }
-        if (sync_suite_clock)
-            return invoke(std::make_shared<CSyncCmd>(CSyncCmd::SYNC_CLOCK,
-                                                     server_reply_.client_handle(),
-                                                     defs->state_change_no(),
-                                                     defs->modify_change_no()));
-        return invoke(std::make_shared<CSyncCmd>(
-            CSyncCmd::SYNC, server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
-    }
-    // If we have a handle return the defs, with the registered suites, else returns the full defs
-    if (testInterface_)
-        return invoke(CtsApi::sync_full(server_reply_.client_handle()));
-
-    return invoke(std::make_shared<CSyncCmd>(server_reply_.client_handle()));
-}
-
-int ClientInvoker::news(defs_ptr& client_defs) const {
-    if (client_defs.get()) {
-        if (testInterface_)
-            return invoke(CtsApi::news(
-                server_reply_.client_handle(), client_defs->state_change_no(), client_defs->modify_change_no()));
-        return invoke(std::make_shared<CSyncCmd>(CSyncCmd::NEWS,
-                                                 server_reply_.client_handle(),
-                                                 client_defs->state_change_no(),
-                                                 client_defs->modify_change_no()));
-    }
-    server_reply_.set_error_msg("The client definition is empty.");
-    if (on_error_throw_exception_)
-        throw std::runtime_error(server_reply_.error_msg());
-    return 1;
-}
-
-int ClientInvoker::news_local() const {
-    defs_ptr defs = server_reply_.client_defs();
-    if (defs.get()) {
-        if (testInterface_)
-            return invoke(
-                CtsApi::news(server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
-        return invoke(std::make_shared<CSyncCmd>(
-            CSyncCmd::NEWS, server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
-    }
-
-    // There is no local defs, i.e first time call, The default client handle should be 0.
-    // go with defaults for state and modify change numbers
-    // User is expected to call sync_local(), which will update local defs.
-    if (testInterface_)
-        return invoke(CtsApi::news(server_reply_.client_handle(), 0, 0));
-    return invoke(std::make_shared<CSyncCmd>(CSyncCmd::NEWS, server_reply_.client_handle(), 0, 0));
-}
-//=====================================================================================
-
-int ClientInvoker::getDefs() const {
-    if (testInterface_)
-        return invoke(CtsApi::get());
-    return invoke(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET));
-}
-
-int ClientInvoker::loadDefs(const std::string& filePath,
-                            bool force,      /* true means overwrite suite of same name */
-                            bool check_only, /* client side, true means don't send to server, just check only */
-                            bool print,      /* client side, print the defs */
-                            bool stats       /* client side, print the defs statitics */
-) const {
-    if (testInterface_)
-        return invoke(CtsApi::loadDefs(filePath, force, check_only, print));
-    Cmd_ptr cmd = LoadDefsCmd::create(filePath, force, check_only, print, stats, &clientEnv_);
-    // If check_only cmd will be empty
-    if (cmd)
-        return invoke(cmd);
-    return 0;
-}
-
-int ClientInvoker::restartServer() const {
-    if (testInterface_)
-        return invoke(CtsApi::restartServer());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::RESTART_SERVER));
-}
-int ClientInvoker::haltServer() const {
-    if (testInterface_)
-        return invoke(CtsApi::haltServer(true /*auto_confirm*/));
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::HALT_SERVER));
-}
-int ClientInvoker::pingServer() const {
-    if (testInterface_)
-        return invoke(CtsApi::pingServer());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::PING));
-}
-int ClientInvoker::shutdownServer() const {
-    if (testInterface_)
-        return invoke(CtsApi::shutdownServer(true /*auto_confirm*/));
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::SHUTDOWN_SERVER));
-}
-int ClientInvoker::terminateServer() const {
-    if (testInterface_)
-        return invoke(CtsApi::terminateServer(true /*auto_confirm*/));
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::TERMINATE_SERVER));
-}
-int ClientInvoker::stats() const {
-    if (testInterface_)
-        return invoke(CtsApi::stats());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::STATS));
-}
-int ClientInvoker::stats_server() const {
-    if (testInterface_)
-        return invoke(CtsApi::stats_server());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::STATS_SERVER));
-}
-int ClientInvoker::stats_reset() const {
-    if (testInterface_)
-        return invoke(CtsApi::stats_reset());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::STATS_RESET));
-}
-int ClientInvoker::suites() const {
-    if (testInterface_)
-        return invoke(CtsApi::suites());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::SUITES));
-}
-int ClientInvoker::server_version() const {
-    if (testInterface_)
-        return invoke(CtsApi::server_version());
-    return invoke(std::make_shared<ServerVersionCmd>());
-}
-int ClientInvoker::debug_server_on() const {
-    if (testInterface_)
-        return invoke(CtsApi::debug_server_on());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_ON));
-}
-int ClientInvoker::debug_server_off() const {
-    if (testInterface_)
-        return invoke(CtsApi::debug_server_off());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_OFF));
-}
-
-//=====================================================================================
-
-int ClientInvoker::ch_register(bool auto_add_new_suites, const std::vector<std::string>& suites) const {
-    reset();
-    if (testInterface_)
-        return invoke(CtsApi::ch_register(0, auto_add_new_suites, suites));
-    return invoke(std::make_shared<ClientHandleCmd>(0, suites, auto_add_new_suites));
-}
-int ClientInvoker::ch1_register(bool auto_add_new_suites, const std::vector<std::string>& suites) const {
-    int client_handle = server_reply_.client_handle();
-    reset();
-    if (testInterface_)
-        return invoke(CtsApi::ch_register(client_handle, auto_add_new_suites, suites));
-    return invoke(std::make_shared<ClientHandleCmd>(client_handle, suites, auto_add_new_suites));
-}
-
-int ClientInvoker::ch_suites() const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_suites());
-    return invoke(std::make_shared<ClientHandleCmd>(ClientHandleCmd::SUITES));
-}
-int ClientInvoker::ch_drop(int client_handle) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_drop(client_handle));
-    return invoke(std::make_shared<ClientHandleCmd>(client_handle));
-}
-int ClientInvoker::ch_drop_user(const std::string& user) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_drop_user(user));
-    return invoke(std::make_shared<ClientHandleCmd>(user));
-}
-int ClientInvoker::ch_add(int client_handle, const std::vector<std::string>& suites) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_add(client_handle, suites));
-    return invoke(std::make_shared<ClientHandleCmd>(client_handle, suites, ClientHandleCmd::ADD));
-}
-int ClientInvoker::ch_remove(int client_handle, const std::vector<std::string>& suites) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_remove(client_handle, suites));
-    return invoke(std::make_shared<ClientHandleCmd>(client_handle, suites, ClientHandleCmd::REMOVE));
-}
-int ClientInvoker::ch_auto_add(int client_handle, bool auto_add_new_suites) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_auto_add(client_handle, auto_add_new_suites));
-    return invoke(std::make_shared<ClientHandleCmd>(client_handle, auto_add_new_suites));
-}
-int ClientInvoker::ch1_drop() const {
-    if (0 == server_reply_.client_handle())
-        return 0;
-    if (testInterface_)
-        return invoke(CtsApi::ch_drop(server_reply_.client_handle()));
-    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle()));
-}
-int ClientInvoker::ch1_add(const std::vector<std::string>& suites) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_add(server_reply_.client_handle(), suites));
-    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle(), suites, ClientHandleCmd::ADD));
-}
-int ClientInvoker::ch1_remove(const std::vector<std::string>& suites) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_remove(server_reply_.client_handle(), suites));
-    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle(), suites, ClientHandleCmd::REMOVE));
-}
-int ClientInvoker::ch1_auto_add(bool auto_add_new_suites) const {
-    if (testInterface_)
-        return invoke(CtsApi::ch_auto_add(server_reply_.client_handle(), auto_add_new_suites));
-    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle(), auto_add_new_suites));
-}
-
-// ======================================================================================================
-
-int ClientInvoker::begin(const std::string& suiteName, bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::begin(suiteName, force));
-    return invoke(std::make_shared<BeginCmd>(suiteName, force));
-}
-int ClientInvoker::begin_all_suites(bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::begin("", force));
-    return invoke(std::make_shared<BeginCmd>("", force));
-}
-// ======================================================================================================
-
-int ClientInvoker::zombieGet() const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieGet());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::GET_ZOMBIES));
-}
-int ClientInvoker::zombieFob(const Zombie& z) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieFob(
-            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-    return invoke(std::make_shared<ZombieCmd>(
-        User::FOB, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-}
-int ClientInvoker::zombieFail(const Zombie& z) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieFail(
-            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-    return invoke(std::make_shared<ZombieCmd>(
-        User::FAIL, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-}
-int ClientInvoker::zombieAdopt(const Zombie& z) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieAdopt(
-            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-    return invoke(std::make_shared<ZombieCmd>(
-        User::ADOPT, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-}
-int ClientInvoker::zombieBlock(const Zombie& z) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieBlock(
-            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-    return invoke(std::make_shared<ZombieCmd>(
-        User::BLOCK, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-}
-int ClientInvoker::zombieRemove(const Zombie& z) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieRemove(
-            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-    return invoke(std::make_shared<ZombieCmd>(
-        User::REMOVE, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-}
-int ClientInvoker::zombieKill(const Zombie& z) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieKill(
-            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-    return invoke(std::make_shared<ZombieCmd>(
-        User::KILL, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
-}
-int ClientInvoker::zombieFobCli(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieFobCli(absNodePath));
-    return invoke(std::make_shared<ZombieCmd>(User::FOB, std::vector<std::string>(1, absNodePath), "", ""));
-}
-int ClientInvoker::zombieFailCli(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieFailCli(absNodePath));
-    return invoke(std::make_shared<ZombieCmd>(User::FAIL, std::vector<std::string>(1, absNodePath), "", ""));
-}
-int ClientInvoker::zombieAdoptCli(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieAdoptCli(absNodePath));
-    return invoke(std::make_shared<ZombieCmd>(User::ADOPT, std::vector<std::string>(1, absNodePath), "", ""));
-}
-int ClientInvoker::zombieBlockCli(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieBlockCli(absNodePath));
-    return invoke(std::make_shared<ZombieCmd>(User::BLOCK, std::vector<std::string>(1, absNodePath), "", ""));
-}
-int ClientInvoker::zombieRemoveCli(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieRemoveCli(absNodePath));
-    return invoke(std::make_shared<ZombieCmd>(User::REMOVE, std::vector<std::string>(1, absNodePath), "", ""));
-}
-int ClientInvoker::zombieKillCli(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieKillCli(absNodePath));
-    return invoke(std::make_shared<ZombieCmd>(User::KILL, std::vector<std::string>(1, absNodePath), "", ""));
-}
-
-int ClientInvoker::zombieFobCliPaths(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieFobCli(paths));
-    return invoke(std::make_shared<ZombieCmd>(User::FOB, paths, "", ""));
-}
-int ClientInvoker::zombieFailCliPaths(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieFailCli(paths));
-    return invoke(std::make_shared<ZombieCmd>(User::FAIL, paths, "", ""));
-}
-int ClientInvoker::zombieAdoptCliPaths(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieAdoptCli(paths));
-    return invoke(std::make_shared<ZombieCmd>(User::ADOPT, paths, "", ""));
-}
-int ClientInvoker::zombieBlockCliPaths(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieBlockCli(paths));
-    return invoke(std::make_shared<ZombieCmd>(User::BLOCK, paths, "", ""));
-}
-int ClientInvoker::zombieRemoveCliPaths(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieRemoveCli(paths));
-    return invoke(std::make_shared<ZombieCmd>(User::REMOVE, paths, "", ""));
-}
-int ClientInvoker::zombieKillCliPaths(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::zombieKillCli(paths));
-    return invoke(std::make_shared<ZombieCmd>(User::KILL, paths, "", ""));
-}
-
-// ======================================================================================================
-
-int ClientInvoker::job_gen(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::job_gen(absNodePath));
-    return invoke(std::make_shared<CtsNodeCmd>(CtsNodeCmd::JOB_GEN, absNodePath));
-}
-
-int ClientInvoker::edit_history(const std::string& path) const {
-    if (testInterface_)
-        return invoke(CtsApi::edit_history(path));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::EDIT_HISTORY, path));
-}
-int ClientInvoker::kill(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::kill(paths));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::KILL, paths));
-}
-int ClientInvoker::kill(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::kill(absNodePath));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::KILL, absNodePath));
-}
-int ClientInvoker::status(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::status(paths));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::STATUS, paths));
-}
-int ClientInvoker::status(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::status(absNodePath));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::STATUS, absNodePath));
-}
-int ClientInvoker::suspend(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::suspend(paths));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::SUSPEND, paths));
-}
-int ClientInvoker::suspend(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::suspend(absNodePath));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::SUSPEND, absNodePath));
-}
-int ClientInvoker::resume(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::resume(paths));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESUME, paths));
-}
-int ClientInvoker::resume(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::resume(absNodePath));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESUME, absNodePath));
-}
-int ClientInvoker::check(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::check(paths));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::CHECK, paths));
-}
-int ClientInvoker::check(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::check(absNodePath));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::CHECK, absNodePath));
-}
-int ClientInvoker::delete_nodes(const std::vector<std::string>& paths, bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::delete_node(paths, force, true /*auto_confirm*/));
-    return invoke(std::make_shared<DeleteCmd>(paths, force));
-}
-int ClientInvoker::delete_node(const std::string& absNodePath, bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::delete_node(absNodePath, force, true /*auto_confirm*/));
-    return invoke(std::make_shared<DeleteCmd>(absNodePath, force));
-}
-int ClientInvoker::delete_all(bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::delete_node(std::vector<std::string>(), force));
-    return invoke(std::make_shared<DeleteCmd>(std::vector<std::string>(), force));
-}
-
-int ClientInvoker::archive(const std::vector<std::string>& paths, bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::archive(paths, force));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::ARCHIVE, paths, force));
-}
-int ClientInvoker::archive(const std::string& absNodePath, bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::archive(absNodePath, force));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::ARCHIVE, absNodePath, force));
-}
-int ClientInvoker::restore(const std::vector<std::string>& paths) const {
-    if (testInterface_)
-        return invoke(CtsApi::restore(paths));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESTORE, paths));
-}
-int ClientInvoker::restore(const std::string& absNodePath) const {
-    if (testInterface_)
-        return invoke(CtsApi::restore(absNodePath));
-    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESTORE, absNodePath));
-}
-
-// ======================================================================================================
-
-int ClientInvoker::replace(const std::string& absNodePath,
-                           const std::string& path_to_client_defs,
-                           bool create_parents_as_required,
-                           bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::replace(absNodePath, path_to_client_defs, create_parents_as_required, force));
-
-    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
-    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-    server_reply_.clear_for_invoke(cli());
-
-    /// Handle command constructors that can throw
-    Cmd_ptr cts_cmd;
-    try {
-        // For test allow the defs environment to changed, i.e. allow us to inject  ECF_CLIENT ???
-        cts_cmd = std::make_shared<ReplaceNodeCmd>(absNodePath, create_parents_as_required, path_to_client_defs, force);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "ClientInvoker::replace(" << absNodePath << "," << path_to_client_defs << ", ...) failed: " << e.what();
-        server_reply_.set_error_msg(ss.str());
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-
-    return invoke(cts_cmd);
-}
-
-int ClientInvoker::replace_1(const std::string& absNodePath,
-                             defs_ptr client_defs,
-                             bool create_parents_as_required,
-                             bool force) const {
-    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
-    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-    server_reply_.clear_for_invoke(cli());
-
-    /// Handle command constructors that can throw
-    Cmd_ptr cts_cmd;
-    try {
-        cts_cmd = std::make_shared<ReplaceNodeCmd>(absNodePath, create_parents_as_required, client_defs, force);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "ClientInvoker::replace_1(" << absNodePath << " ...) failed: " << e.what();
-        server_reply_.set_error_msg(ss.str());
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-
-    return invoke(cts_cmd);
-}
-
-int ClientInvoker::requeue(const std::vector<std::string>& paths, const std::string& option) const {
-    if (testInterface_)
-        return invoke(CtsApi::requeue(paths, option));
-
-    RequeueNodeCmd::Option the_option = RequeueNodeCmd::NO_OPTION;
-    if (!option.empty()) {
-        if (option == "abort")
-            the_option = RequeueNodeCmd::ABORT;
-        else if (option == "force")
-            the_option = RequeueNodeCmd::FORCE;
-        else {
-            server_reply_.set_error_msg("ClientInvoker::requeue: Expected option = [ force | abort ]");
-            if (on_error_throw_exception_) {
-                throw std::runtime_error(server_reply_.error_msg());
-            }
-            return 1;
-        }
-    }
-    return invoke(std::make_shared<RequeueNodeCmd>(paths, the_option));
-}
-
-int ClientInvoker::requeue(const std::string& absNodePath, const std::string& option) const {
-    if (testInterface_)
-        return invoke(CtsApi::requeue(absNodePath, option));
-
-    RequeueNodeCmd::Option the_option = RequeueNodeCmd::NO_OPTION;
-    if (!option.empty()) {
-        if (option == "abort")
-            the_option = RequeueNodeCmd::ABORT;
-        else if (option == "force")
-            the_option = RequeueNodeCmd::FORCE;
-        else {
-            server_reply_.set_error_msg("ClientInvoker::requeue: Expected option = [ force | abort ]");
-            if (on_error_throw_exception_)
-                throw std::runtime_error(server_reply_.error_msg());
-            return 1;
-        }
-    }
-    return invoke(std::make_shared<RequeueNodeCmd>(absNodePath, the_option));
-}
-
-int ClientInvoker::run(const std::vector<std::string>& paths, bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::run(paths, force));
-    return invoke(std::make_shared<RunNodeCmd>(paths, force));
-}
-int ClientInvoker::run(const std::string& absNodePath, bool force) const {
-    if (testInterface_)
-        return invoke(CtsApi::run(absNodePath, force));
-    return invoke(std::make_shared<RunNodeCmd>(absNodePath, force));
-}
-int ClientInvoker::order(const std::string& absNodePath, const std::string& order) const {
-    if (testInterface_)
-        return invoke(CtsApi::order(absNodePath, order));
-
-    if (!NOrder::isValid(order)) {
-        server_reply_.set_error_msg(
-            "ClientInvoker::order: please specify one of [ top, bottom, alpha, order, up, down, runtime ]\n");
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-    return invoke(std::make_shared<OrderNodeCmd>(absNodePath, NOrder::toOrder(order)));
-}
-int ClientInvoker::order(const std::string& absNodePath, NOrder::Order order) const {
-    return invoke(std::make_shared<OrderNodeCmd>(absNodePath, order));
-}
-
-// ======================================================================================================
-
-int ClientInvoker::checkPtDefs(ecf::CheckPt::Mode m, int check_pt_interval, int check_pt_save_time_alarm) const {
-    if (testInterface_)
-        return invoke(CtsApi::checkPtDefs(m, check_pt_interval, check_pt_save_time_alarm));
-    return invoke(std::make_shared<CheckPtCmd>(m, check_pt_interval, check_pt_save_time_alarm));
-}
-int ClientInvoker::restoreDefsFromCheckPt() const {
-    if (testInterface_)
-        return invoke(CtsApi::restoreDefsFromCheckPt());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::RESTORE_DEFS_FROM_CHECKPT));
-}
-
-int ClientInvoker::force(const std::string& absNodePath,
-                         const std::string& state_or_event,
-                         bool recursive,
-                         bool set_repeats_to_last_value) const {
-    if (testInterface_)
-        return invoke(CtsApi::force(absNodePath, state_or_event, recursive, set_repeats_to_last_value));
-    return invoke(std::make_shared<ForceCmd>(absNodePath, state_or_event, recursive, set_repeats_to_last_value));
-}
-int ClientInvoker::force(const std::vector<std::string>& paths,
-                         const std::string& state_or_event,
-                         bool recursive,
-                         bool set_repeats_to_last_value) const {
-    if (testInterface_)
-        return invoke(CtsApi::force(paths, state_or_event, recursive, set_repeats_to_last_value));
-    return invoke(std::make_shared<ForceCmd>(paths, state_or_event, recursive, set_repeats_to_last_value));
-}
-
-int ClientInvoker::freeDep(const std::vector<std::string>& paths,
-                           bool trigger,
-                           bool all,
-                           bool date,
-                           bool the_time) const {
-    if (testInterface_)
-        return invoke(CtsApi::freeDep(paths, trigger, all, date, the_time));
-    return invoke(std::make_shared<FreeDepCmd>(paths, trigger, all, date, the_time));
-}
-int ClientInvoker::freeDep(const std::string& absNodePath, bool trigger, bool all, bool date, bool the_time) const {
-    if (testInterface_)
-        return invoke(CtsApi::freeDep(absNodePath, trigger, all, date, the_time));
-    return invoke(std::make_shared<FreeDepCmd>(absNodePath, trigger, all, date, the_time));
-}
-
-int ClientInvoker::file(const std::string& absNodePath,
-                        const std::string& fileType,
-                        const std::string& max_lines) const {
-    if (testInterface_)
-        return invoke(CtsApi::file(absNodePath, fileType, max_lines));
-
-    /// Handle command constructors that can throw
-    Cmd_ptr cts_cmd;
-    try {
-        cts_cmd = std::make_shared<CFileCmd>(absNodePath, fileType, max_lines);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "ClientInvoker::file(" << absNodePath << "," << fileType << "," << max_lines << ") failed:\n" << e.what();
-        server_reply_.set_error_msg(ss.str());
-        if (on_error_throw_exception_) {
-            throw std::runtime_error(server_reply_.error_msg());
-        }
-        return 1;
-    }
-
-    return invoke(cts_cmd);
-}
-
-int ClientInvoker::plug(const std::string& sourcePath, const std::string& destPath) const {
-    if (testInterface_)
-        return invoke(CtsApi::plug(sourcePath, destPath));
-    return invoke(std::make_shared<PlugCmd>(sourcePath, destPath));
-}
-
-int ClientInvoker::query(const std::string& query_type,
-                         const std::string& path_to_attribute,
-                         const std::string& attribute) {
-    if (testInterface_)
-        return invoke(CtsApi::query(query_type, path_to_attribute, attribute));
-    return invoke(std::make_shared<QueryCmd>(query_type, path_to_attribute, attribute, clientEnv_.task_path()));
-}
-
-// ======================================================================================================
-
-int ClientInvoker::alter(const std::vector<std::string>& paths,
-                         const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-                         const std::string& attrType,
-                         const std::string& name,
-                         const std::string& value) const {
-    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
-    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-    server_reply_.clear_for_invoke(cli());
-
-    /// Handle command constructors that can throw
-    Cmd_ptr cts_cmd;
-    try {
-        cts_cmd = std::make_shared<AlterCmd>(paths, alterType, attrType, name, value);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "ClientInvoker::alter failed: " << e.what();
-        server_reply_.set_error_msg(ss.str());
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-    return invoke(cts_cmd);
-}
-
-int ClientInvoker::alter(const std::string& path,
-                         const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-                         const std::string& attrType,
-                         const std::string& name,
-                         const std::string& value) const {
-    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
-    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-    server_reply_.clear_for_invoke(cli());
-
-    /// Handle command constructors that can throw
-    Cmd_ptr cts_cmd;
-    try {
-        cts_cmd = std::make_shared<AlterCmd>(std::vector<std::string>(1, path), alterType, attrType, name, value);
-    }
-    catch (std::exception& e) {
-        std::stringstream ss;
-        ss << "ClientInvoker::alter failed: " << e.what();
-        server_reply_.set_error_msg(ss.str());
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-    return invoke(cts_cmd);
-}
-
-int ClientInvoker::alter_sort(const std::vector<std::string>& paths,
-                              const std::string& sortable_attribute_name,
-                              bool recursive) const {
-    if (testInterface_)
-        return invoke(CtsApi::alter_sort(paths, sortable_attribute_name, recursive));
-    std::string value;
-    if (recursive)
-        value = "recursive";
-    return invoke(std::make_shared<AlterCmd>(paths, sortable_attribute_name, value));
-}
-int ClientInvoker::alter_sort(const std::string& path,
-                              const std::string& sortable_attribute_name,
-                              bool recursive) const {
-    if (testInterface_)
-        invoke(CtsApi::alter_sort(std::vector<std::string>(1, path), sortable_attribute_name, recursive));
-    std::string value;
-    if (recursive)
-        value = "recursive";
-    return invoke(std::make_shared<AlterCmd>(std::vector<std::string>(1, path), sortable_attribute_name, value));
-}
-
-// ======================================================================================================
-
-int ClientInvoker::reloadwsfile() const {
-    if (testInterface_)
-        return invoke(CtsApi::reloadwsfile());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::RELOAD_WHITE_LIST_FILE));
-}
-
-int ClientInvoker::reloadpasswdfile() const {
-    if (testInterface_)
-        return invoke(CtsApi::reloadpasswdfile());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::RELOAD_PASSWD_FILE));
-}
-
-int ClientInvoker::reloadcustompasswdfile() const {
-    if (testInterface_)
-        return invoke(CtsApi::reloadcustompasswdfile());
-    return invoke(std::make_shared<CtsCmd>(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE));
-}
-
-int ClientInvoker::group(const std::string& groupRequest) const {
-    if (testInterface_)
-        return invoke(CtsApi::group(groupRequest));
-    return invoke(std::make_shared<GroupCTSCmd>(groupRequest, &clientEnv_));
-}
-
-int ClientInvoker::logMsg(const std::string& msg) const {
-    if (testInterface_)
-        return invoke(CtsApi::logMsg(msg));
-    return invoke(std::make_shared<LogMessageCmd>(msg));
-}
-int ClientInvoker::new_log(const std::string& new_path) const {
-    if (testInterface_)
-        return invoke(CtsApi::new_log(new_path));
-
-    /// Handle command constructors that can throw
-    Cmd_ptr cts_cmd;
-    try {
-        cts_cmd = std::make_shared<LogCmd>(new_path);
-    }
-    catch (std::exception& e) {
-        server_reply_.set_error_msg(e.what());
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-    return invoke(cts_cmd);
-}
-int ClientInvoker::getLog(int lastLines) const {
-    if (lastLines == 0)
-        lastLines = Log::get_last_n_lines_default();
-    if (testInterface_)
-        return invoke(CtsApi::getLog(lastLines));
-    return invoke(std::make_shared<LogCmd>(LogCmd::GET, lastLines));
-}
-int ClientInvoker::clearLog() const {
-    if (testInterface_)
-        return invoke(CtsApi::clearLog());
-    return invoke(std::make_shared<LogCmd>(LogCmd::CLEAR));
-}
-int ClientInvoker::flushLog() const {
-    if (testInterface_)
-        return invoke(CtsApi::flushLog());
-    return invoke(std::make_shared<LogCmd>(LogCmd::FLUSH));
-}
-int ClientInvoker::get_log_path() const {
-    if (testInterface_)
-        return invoke(CtsApi::get_log_path());
-    return invoke(std::make_shared<LogCmd>(LogCmd::PATH));
-}
-
-int ClientInvoker::forceDependencyEval() const {
-    return invoke(CtsApi::forceDependencyEval());
-}
-
-// ======================================================================================================
-
-int ClientInvoker::edit_script_edit(const std::string& path_to_task) {
-    return invoke(std::make_shared<EditScriptCmd>(path_to_task, EditScriptCmd::EDIT));
-}
-
-int ClientInvoker::edit_script_preprocess(const std::string& path_to_task) {
-    return invoke(std::make_shared<EditScriptCmd>(path_to_task, EditScriptCmd::PREPROCESS));
-}
-
-int ClientInvoker::edit_script_preprocess(const std::string& path_to_task,
-                                          const std::vector<std::string>& file_contents) {
-    return invoke(std::make_shared<EditScriptCmd>(path_to_task, file_contents));
-}
-
-int ClientInvoker::edit_script_submit(const std::string& path_to_task, const NameValueVec& used_variables) {
-    return invoke(std::make_shared<EditScriptCmd>(path_to_task, used_variables));
-}
-
-int ClientInvoker::edit_script_submit(const std::string& path_to_task,
-                                      const NameValueVec& used_variables,
-                                      const std::vector<std::string>& file_contents,
-                                      bool create_alias,
-                                      bool run_alias) {
-    return invoke(
-        std::make_shared<EditScriptCmd>(path_to_task, used_variables, file_contents, create_alias, run_alias));
-}
-
-std::string ClientInvoker::client_env_host_port() const {
-    std::string host_port = clientEnv_.host();
-    host_port += Str::COLON();
-    host_port += clientEnv_.port();
-    return host_port;
-}
-
-std::string ClientInvoker::find_free_port(int seed_port_number, bool debug) {
-    // Ping failed, We need to distinguish between:
-    //    a/ Server does not exist : <FREE> port
-    //    b/ Address in use        : <BUSY> port on existing server
-    // Using server_version() but then get error messages
-    // ******** Until this is done we can't implement port hopping **********
-
-    if (debug)
-        cout << "  ClientInvoker::find_free_port: starting with port " << seed_port_number << "\n";
-    int the_port = seed_port_number;
-    std::string free_port;
-    ClientInvoker client;
-    client.set_retry_connection_period(1); // avoid long wait
-    client.set_connection_attempts(1);     // avoid long wait
-    while (true) {
-        free_port = ecf::convert_to<std::string>(the_port);
-        try {
-            if (debug)
-                cout << "   Trying to connect to server on '" << Str::LOCALHOST() << ":" << free_port << "'\n";
-            client.set_host_port(Str::LOCALHOST(), free_port);
-            client.pingServer();
-            if (debug)
-                cout << "   Connected to server on port " << free_port << " trying next port\n";
-            the_port++;
-        }
-        catch (std::runtime_error& e) {
-            std::string error_msg = e.what();
-            if (debug)
-                cout << "   " << error_msg;
-            if (error_msg.find("authentication failed") != std::string::npos) {
-                if (debug)
-                    cout << "   Could not connect, due to authentication failure, hence port " << the_port
-                         << " is used, trying next port\n";
-                the_port++;
-                continue;
-            }
-            if (error_msg.find("invalid_argument") != std::string::npos) {
-                if (debug)
-                    cout << "   Mixing 4 and 5 series ?, hence port " << the_port << " is used, trying next port\n";
-                the_port++;
-                continue;
-            }
-            else {
-                if (debug)
-                    cout << "   Found free port " << free_port << "\n";
-                break;
-            }
-        }
-    }
-    return free_port;
-}
-
-bool ClientInvoker::wait_for_server_reply(int time_out) const {
-    DurationTimer timer;
-    while (true) {
-        sleep(2);
-
-        if (on_error_throw_exception_) {
-            try {
-                pingServer(); // will throw exception
-                return true;  // no exception, server lives
-            }
-            catch (...) {
-            }
-        }
-        else {
-            if (pingServer() == 0) {
-                return true; // ping OK,
-            }
-        }
-        if (timer.duration() > time_out) {
-            return false;
-        }
-    }
-    return false;
-}
-
-bool ClientInvoker::wait_for_server_death(int time_out) const {
-    DurationTimer timer;
-    while (true) {
-
-        if (on_error_throw_exception_) {
-            try {
-                pingServer(); // will throw exception
-            }
-            catch (...) {
-                // server died
-                return true;
-            }
-        }
-        else {
-            if (pingServer() == 1) {
-                return true; // ping failed, server has died,
-            }
-        }
-        if (timer.duration() > time_out) {
-            return false; // server still lives
-        }
-
-        // Ping ok, server lives, continue pinging, until timeout
-        sleep(2);
-    }
-    return false;
-}
-
-int ClientInvoker::load_in_memory_defs(const defs_ptr& clientDefs, bool force) const {
-    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
-    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
-    server_reply_.clear_for_invoke(cli());
-
-    if (!clientDefs.get()) {
-        server_reply_.set_error_msg("The client definition is empty.");
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-
-    // Client defs  has been created in memory.
-    // warn about naff expression and unresolved in-limit references to Limit's
-    // Don't allow defs to be loaded into server, with trigger parser errors.
-    std::string warningMsg;
-    if (!clientDefs->check(server_reply_.get_error_msg(), warningMsg)) {
-        if (on_error_throw_exception_)
-            throw std::runtime_error(server_reply_.error_msg());
-        return 1;
-    }
-
-    return invoke(std::make_shared<LoadDefsCmd>(clientDefs, force /*force overwrite suite of same name*/));
-}
-
-void ClientInvoker::check_child_parameters() const {
-    if (clientEnv_.debug()) {
-        std::cout << "  child_task_path = '" << clientEnv_.task_path() << "'\n";
-        std::cout << "  child_task_password = '" << clientEnv_.jobs_password() << "'\n";
-        std::cout << "  child_task_pid = '" << clientEnv_.process_or_remote_id() << "'\n";
-        std::cout << "  child_task_try_no = " << clientEnv_.task_try_no() << "\n";
-    }
-    if (clientEnv_.task_path().empty())
-        throw std::runtime_error("Child Path not set");
-    if (clientEnv_.jobs_password().empty())
-        throw std::runtime_error("Child password not set");
-    if (clientEnv_.process_or_remote_id().empty())
-        throw std::runtime_error("Child pid not set");
-    if (clientEnv_.task_try_no() == 0)
-        throw std::runtime_error("Child try_no not set");
-}
-
-void ClientInvoker::child_init() {
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<InitCmd>(clientEnv_.task_path(),
-                                     clientEnv_.jobs_password(),
-                                     clientEnv_.process_or_remote_id(),
-                                     clientEnv_.task_try_no(),
-                                     clientEnv_.init_add_vars()));
-}
-
-void ClientInvoker::child_abort(const std::string& reason) {
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<AbortCmd>(clientEnv_.task_path(),
-                                      clientEnv_.jobs_password(),
-                                      clientEnv_.process_or_remote_id(),
-                                      clientEnv_.task_try_no(),
-                                      reason));
-}
-
-void ClientInvoker::child_event(const std::string& event_name_or_number, bool event_value) {
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<EventCmd>(clientEnv_.task_path(),
-                                      clientEnv_.jobs_password(),
-                                      clientEnv_.process_or_remote_id(),
-                                      clientEnv_.task_try_no(),
-                                      event_name_or_number,
-                                      event_value));
-}
-
-void ClientInvoker::child_meter(const std::string& meter_name, int meter_value) {
-    if (meter_name.empty())
-        throw std::runtime_error("Meter name not set");
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<MeterCmd>(clientEnv_.task_path(),
-                                      clientEnv_.jobs_password(),
-                                      clientEnv_.process_or_remote_id(),
-                                      clientEnv_.task_try_no(),
-                                      meter_name,
-                                      meter_value));
-}
-
-void ClientInvoker::child_label(const std::string& label_name, const std::string& label_value) {
-    if (label_name.empty())
-        throw std::runtime_error("Label name not set");
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<LabelCmd>(clientEnv_.task_path(),
-                                      clientEnv_.jobs_password(),
-                                      clientEnv_.process_or_remote_id(),
-                                      clientEnv_.task_try_no(),
-                                      label_name,
-                                      label_value));
-}
-
-void ClientInvoker::child_wait(const std::string& expression) {
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<CtsWaitCmd>(clientEnv_.task_path(),
-                                        clientEnv_.jobs_password(),
-                                        clientEnv_.process_or_remote_id(),
-                                        clientEnv_.task_try_no(),
-                                        expression));
-}
-
-std::string ClientInvoker::child_queue(const std::string& queue_name,
-                                       const std::string& action,
-                                       const std::string& step,
-                                       const std::string& path_to_node_with_queue) {
-    if (queue_name.empty())
-        throw std::runtime_error("ClientInvoker::child_queue: Queue name not set");
-    if (action.empty())
-        throw std::runtime_error("ClientInvoker::child_queue: action not set");
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<QueueCmd>(clientEnv_.task_path(),
-                                      clientEnv_.jobs_password(),
-                                      clientEnv_.process_or_remote_id(),
-                                      clientEnv_.task_try_no(),
-                                      queue_name,
-                                      action,
-                                      step,
-                                      path_to_node_with_queue));
-    return server_reply_.get_string();
-}
-
-void ClientInvoker::child_complete() {
-    check_child_parameters();
-    on_error_throw_exception_ = true; // for python always throw exception
-    invoke(std::make_shared<CompleteCmd>(clientEnv_.task_path(),
-                                         clientEnv_.jobs_password(),
-                                         clientEnv_.process_or_remote_id(),
-                                         clientEnv_.task_try_no(),
-                                         clientEnv_.complete_del_vars()));
-}
-
-// ==========================================================================
-// class RequestLogger:
-// ==========================================================================
-RequestLogger::RequestLogger(const ClientInvoker* ci) : ci_(ci) {
-}
-RequestLogger::~RequestLogger() {
-
-    // *assumes* destructor of RoundTripRecorder was invoked first, to allow recording of the time rtt_
-    if (cmd_.get()) {
-        if (ci_->clientEnv_.debug() && ci_->server_reply_.error_msg().empty()) {
-            cout << TimeStamp::now() << "ClientInvoker: " << cmd_->print_short() << " SUCCEEDED "
-                 << to_simple_string(ci_->rtt_) << "\n";
-        }
-
-        if (Rtt::instance()) {
-            std::string ss;
-            ss += ci_->client_env_host_port();
-            ss += " ";
-            cmd_->print(ss);
-            ss += " ";
-            ss += Rtt::tag();
-            ss += to_simple_string(ci_->rtt_); // Note: endl added rtt(..)
-            ss += " : ";
-            ss += ci_->server_reply_.error_msg();
-            rtt(ss);
-        }
-
-        if (ci_->cli() && cmd_->ping_cmd() && ci_->server_reply_.error_msg().empty()) {
-            cout << "ping server(" << ci_->client_env_host_port() << ") succeeded in " << to_simple_string(ci_->rtt_)
-                 << "  ~" << ci_->rtt_.total_milliseconds() << " milliseconds\n";
-        }
-    }
-}
-
-// ==========================================================================
-// class RoundTripRecorder:
-// ==========================================================================
-RoundTripRecorder::RoundTripRecorder(const ClientInvoker* ci) : ci_(ci) {
-    // get the current time from the clock -- one second resolution
-    ci_->start_time_ = microsec_clock::universal_time();
-    ci_->rtt_        = boost::posix_time::time_duration();
-}
-
-RoundTripRecorder::~RoundTripRecorder() {
-    ci_->rtt_ = microsec_clock::universal_time() - ci_->start_time_;
-}
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientInvoker.hpp 5.13.0-1/Client/src/ecflow/client/ClientInvoker.hpp
--- 5.12.4-1/Client/src/ecflow/client/ClientInvoker.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientInvoker.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,471 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_ClientInvoker_HPP
-#define ecflow_client_ClientInvoker_HPP
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-#include "ecflow/base/Cmd.hpp"
-#include "ecflow/base/ServerReply.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientOptions.hpp"
-#include "ecflow/core/NOrder.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-class CommandLine;
-
-/// Invokes the client depending on the arguments
-/// This has been separated from main, to allow us to invoke the client
-/// from a test suite.
-/// Important: We can make *many* calls with the same ClientInvoker.
-/// This is more efficient than creating a ClientInvoker for each request
-class ClientInvoker {
-public:
-    ClientInvoker(const ClientInvoker&)                  = delete;
-    const ClientInvoker& operator=(const ClientInvoker&) = delete;
-
-    /// Will create the *ClientEnvironment* once on construction
-    /// By default will throw exception std::runtime_error for errors
-    ClientInvoker();
-    explicit ClientInvoker(const std::string& host_port);
-    ClientInvoker(bool GUI, const std::string& host, const std::string& port);
-    ClientInvoker(const std::string& host, const std::string& port);
-    ClientInvoker(const std::string& host, int port);
-
-    /// for debug allow the current client environment to be printed
-    std::string to_string() const { return clientEnv_.toString(); }
-
-    /// if throw_exception_on_error = false, then
-    ///    invoke() will return 0 for success and 1 for error.
-    ///    The error message can be retrieved from errorMsg()
-    /// if throw_exception_on_error = true,
-    ///	  then invoke() for errors will throw std::runtime_error
-    ///   will still return 0 for success.
-    void set_throw_on_error(bool f) { on_error_throw_exception_ = f; }
-
-    /// Enable auto sync on each command that can modify the Defs state in the server
-    void set_auto_sync(bool f) { auto_sync_ = f; }
-    bool is_auto_sync_enabled() const { return auto_sync_; }
-
-    /// Return the time it takes to contact server and get a reply.
-    const boost::posix_time::time_duration& round_trip_time() const { return rtt_; }
-
-    /// Configure to using command line interface
-    /// This affect commands like ping, log & file, so that, output is written to standard out
-    /// Can also be used to check argument arguments
-    void set_cli(bool f) { clientEnv_.set_cli(f); }
-    bool cli() const { return clientEnv_.get_cli(); }
-
-#ifdef ECF_OPENSSL
-    /// Override any ssl read from environment(ECF_SSL) or command line args(-ssl)
-    void enable_ssl() { clientEnv_.enable_ssl(); }
-    bool enable_ssl_no_throw() { return clientEnv_.enable_ssl_no_throw(); }
-    void disable_ssl() { clientEnv_.disable_ssl(); } // override environment setting for ECF_SSL
-#endif
-
-    /// This will override the environment setting.
-    /// In particular setting host explicitly will avoid cycling through server list,
-    /// if connection fails. hence will bomb out earlier
-    /// If applied to child command's will continue attempting this host/port until timeout
-    void set_host_port(const std::string& h, const std::string& p);
-    void set_hostport(const std::string& host_port);
-    const std::string& host() const;
-    const std::string& port() const;
-
-    /// This will override the environment setting. ECF_USER or --user
-    /// Clear password, so that re-validate users password from password file
-    void set_user_name(const std::string& user);
-    void set_password(const std::string& password);
-
-    /// Whenever there is a connections failure we wait a number of seconds
-    /// before trying again. ( i.e. to get round glitches in the network.)
-    /// For the ping command this is set as 1 second
-    /// This wait between connection attempts can be configured here.
-    /// i.e for the GUI & python interface this can be reduced to increase responsiveness.
-    /// Default: In debug this period in set to 1 second and in release mode 10 seconds
-    void set_retry_connection_period(unsigned int period) { retry_connection_period_ = period; }
-
-    /// Set the number of times to connect to server, in case of failure
-    /// The period between connection attempts is handled by set_retry_connection_period
-    /// i.e for the GUI & python interface this can be reduced to increase responsiveness.
-    /// Default value is set as 2. Setting a value less than 1 is ignored, will default to 1 in this case
-    void set_connection_attempts(unsigned int attempts);
-
-    /// returns 1 on error and 0 on success. The errorMsg can be accessed via errorMsg()
-    /// Will attempt to connect to the server a number of times. If this fails it will
-    /// try the next server, and so on until a timeout period is reached.
-    int invoke(int argc, char* argv[]) const;
-    int invoke(const CommandLine& cl) const;
-
-    /// If testing, overwrite the task path set in the environment, required for
-    /// testing the task based commands.
-    /// By allowing environment to be changed, we allow smsinit,smscomplete, etc to be replaced
-    /// with ECF_CLIENT path executable
-    /// The following functions are only used for testing purposes.
-    /// Override task paths,env' & job creation at begin time
-    void taskPath(const std::string& s);
-    void set_jobs_password(const std::string&);
-    void setEnv(const std::vector<std::pair<std::string, std::string>>& e);
-    void testInterface(); // allow cmd construction to be aware thats it under test
-    const std::string& process_or_remote_id() const;
-
-    /// record each request its arguments and the round trip time to and from server
-    /// If the file cannot opened for create/append then an runtime error exception is thrown
-    void enable_logging(const std::string& log_file_name);
-    void disable_logging();
-
-    void debug(bool flag) { clientEnv_.set_debug(flag); }
-
-    /// The timeout feature allow the client to fail gracefully in the case
-    /// where the server has died/crashed. The timeout will ensure the socket is closed.
-    /// allowing the server to be restarted without getting the address is use error.
-    /// Set the timeout for each client->server communication:
-    //    connect        : timeout_ second
-    //    send request   : timeout_ second
-    //    receive reply  : timeout_ second
-    // default is 0 second, which means take the timeout from the command/request
-    // used for test only
-    void set_connect_timeout(int t);
-
-    /// ServerReply Holds the reply from the server
-    void reset() const; // will clear local client definition and handle
-    const ServerReply& server_reply() const { return server_reply_; }
-    defs_ptr defs() const { return server_reply_.client_defs(); }
-    const std::string& get_string() const { return server_reply_.get_string(); }
-    bool in_sync() const { return server_reply_.in_sync(); }
-    bool get_news() const { return (server_reply_.get_news() != ServerReply::NO_NEWS); }
-    int client_handle() const { return server_reply_.client_handle(); }
-
-    /// If invoke returns 1, the error message can be retrieved with this function
-    const std::string& errorMsg() const { return server_reply_.error_msg(); }
-
-    // ***************************************************************************
-    // Task/child based api. Only added here for test.
-    // Relies on environment for the other args
-    int initTask(const std::string& process_id) const { return invoke(TaskApi::init(process_id)); }
-    int abortTask(const std::string& reason_why = "") const { return invoke(TaskApi::abort(reason_why)); }
-    int eventTask(const std::string& eventName, const std::string& value = "set") const {
-        return invoke(TaskApi::event(eventName, value));
-    }
-    int meterTask(const std::string& meterName, const std::string& new_meter_value) const {
-        return invoke(TaskApi::meter(meterName, new_meter_value));
-    }
-    int labelTask(const std::string& labelName, const std::vector<std::string>& labels) const {
-        return invoke(TaskApi::label(labelName, labels));
-    }
-    int waitTask(const std::string& on_expression) const { return invoke(TaskApi::wait(on_expression)); }
-    int queueTask(const std::string& queue_name,
-                  const std::string& action,
-                  const std::string& step                    = "",
-                  const std::string& path_to_node_with_queue = "") const {
-        return invoke(TaskApi::queue(queue_name, action, step, path_to_node_with_queue));
-    }
-    int completeTask() const { return invoke(TaskApi::complete()); }
-
-    // Support for python child commands, and python jobs
-    void set_child_path(const std::string& path) { clientEnv_.set_child_path(path); }
-    void set_child_password(const std::string& pass) { clientEnv_.set_child_password(pass); }
-    void set_child_pid(const std::string& pid) { clientEnv_.set_child_pid(pid); }
-    void set_child_try_no(unsigned int try_no) { clientEnv_.set_child_try_no(try_no); }
-    void set_child_timeout(unsigned int seconds) {
-        clientEnv_.set_child_cmd_timeout(seconds);
-    } // ECF_TIMEOUT default is 24 hours allow python jobs to override
-    void set_child_host_file(const std::string& host_file) { clientEnv_.set_child_host_file(host_file); }
-    void set_child_denied(bool denied) { clientEnv_.set_child_denied(denied); }
-    void set_child_no_ecf(bool no_ecf) { clientEnv_.set_child_no_ecf(no_ecf); }
-
-    void set_child_init_add_vars(const std::vector<Variable>& vars) { clientEnv_.set_child_init_add_vars(vars); }
-    void set_child_complete_del_vars(std::vector<std::string>& vars) { clientEnv_.set_child_complete_del_vars(vars); }
-    void set_zombie_child_timeout(unsigned int seconds) {
-        clientEnv_.set_zombie_child_cmd_timeout(seconds);
-    } // ECF_ZOMBIE_TIMEOUT default is 24 hours allow python jobs to override
-
-    void child_init();
-    void child_abort(const std::string& reason = "");
-    void child_event(const std::string& event_name_or_number, bool value = true);
-    void child_meter(const std::string& meter_name, int meter_value);
-    void child_label(const std::string& label_name, const std::string& label_value);
-    void child_wait(const std::string& on_expression);
-    std::string child_queue(const std::string& queue_name,
-                            const std::string& ation,
-                            const std::string& step,
-                            const std::string& path_to_node_with_queue = "");
-    void child_complete();
-
-    // ********************************************************************************
-    // The client api. Mirrors CtsApi on the whole
-    int getDefs() const;
-    int loadDefs(const std::string& filePath,
-                 bool force      = false, /* true means overwrite suite of same name */
-                 bool check_only = false, /* client side only, true means don't send to server, just check only */
-                 bool print      = false, /* client side only, print the defs */
-                 bool stats      = false  /* client side only, print the defs statitics */
-    ) const;
-    int load(const defs_ptr& defs, bool force = false /*true means overwrite suite of same name*/) const {
-        return load_in_memory_defs(defs, force);
-    }
-    int sync(defs_ptr& client_defs) const;
-    int sync_local(bool sync_suite_clock = false) const;
-    int news(defs_ptr& client_defs) const;
-    int news_local() const;
-
-    // find free port on local host. Not 100% accurate, use in test
-    static std::string find_free_port(int seed_port_number, bool debug = false);
-
-    bool wait_for_server_reply(int time_out = 60) const; // wait for server reply, returning false means timed out.
-    bool wait_for_server_death(
-        int time_out = 60) const; // wait for server reply, returning true means server died,false means timed out.
-    int restartServer() const;
-    int haltServer() const;
-    int shutdownServer() const;
-    int terminateServer() const;
-    int pingServer() const;
-    int server_load(const std::string& path_to_log_file = "") const {
-        return invoke(CtsApi::server_load(path_to_log_file));
-    }
-    int debug_server_on() const;
-    int debug_server_off() const;
-    int stats() const; // returns stats as string, server does formatting, & hence is free to change ECFLOW-880
-    int stats_reset() const;
-    int stats_server() const; // for test only, as stats returned may change for each release ECFLOW-880
-    int server_version() const;
-
-    int suites() const;
-    int ch_register(bool auto_add_new_suites, const std::vector<std::string>& suites) const;
-    int ch_suites() const;
-    int ch_drop(int client_handle) const;
-    int ch_drop_user(const std::string& user = "") const;
-    int ch_add(int client_handle, const std::vector<std::string>& suites) const;
-    int ch_remove(int client_handle, const std::vector<std::string>& suites) const;
-    int ch_auto_add(int client_handle, bool auto_add_new_suites) const;
-    int ch1_register(bool auto_add_new_suites,
-                     const std::vector<std::string>& suites) const; // uses existing handle on client if any
-    int ch1_drop() const;                                           // uses existing handle on client
-    int ch1_add(const std::vector<std::string>& suites) const;      // uses existing handle on client
-    int ch1_remove(const std::vector<std::string>& suites) const;   // uses existing handle on client
-    int ch1_auto_add(bool auto_add_new_suites) const;               // uses existing handle on client
-
-    int begin(const std::string& suiteName, bool force = false) const;
-    int begin_all_suites(bool force = false) const;
-
-    int zombieGet() const;
-    int zombieFob(const Zombie& z) const;
-    int zombieFail(const Zombie& z) const;
-    int zombieAdopt(const Zombie& z) const;
-    int zombieBlock(const Zombie& z) const;
-    int zombieRemove(const Zombie& z) const;
-    int zombieKill(const Zombie& z) const;
-    int zombieFobCli(const std::string& absNodePath) const;
-    int zombieFailCli(const std::string& absNodePath) const;
-    int zombieAdoptCli(const std::string& absNodePath) const;
-    int zombieBlockCli(const std::string& absNodePath) const;
-    int zombieRemoveCli(const std::string& absNodePath) const;
-    int zombieKillCli(const std::string& absNodePath) const;
-    int zombieFobCliPaths(const std::vector<std::string>& paths) const;
-    int zombieFailCliPaths(const std::vector<std::string>& paths) const;
-    int zombieAdoptCliPaths(const std::vector<std::string>& paths) const;
-    int zombieBlockCliPaths(const std::vector<std::string>& paths) const;
-    int zombieRemoveCliPaths(const std::vector<std::string>& paths) const;
-    int zombieKillCliPaths(const std::vector<std::string>& paths) const;
-
-    int job_gen(const std::string& absNodePath) const;
-
-    int edit_history(const std::string& path) const;
-    int kill(const std::vector<std::string>& paths) const;
-    int kill(const std::string& absNodePath) const;
-    int status(const std::vector<std::string>& paths) const;
-    int status(const std::string& absNodePath) const;
-    int suspend(const std::vector<std::string>& paths) const;
-    int suspend(const std::string& absNodePath) const;
-    int resume(const std::vector<std::string>& paths) const;
-    int resume(const std::string& absNodePath) const;
-    int check(const std::vector<std::string>& paths) const;
-    int check(const std::string& absNodePath) const;
-    int delete_nodes(const std::vector<std::string>& paths, bool force = false) const;
-    int delete_node(const std::string& absNodePath, bool force = false) const;
-    int delete_all(bool force = false) const;
-    int archive(const std::vector<std::string>& paths, bool force = false) const;
-    int archive(const std::string& absNodePath, bool force = false) const;
-    int restore(const std::vector<std::string>& paths) const;
-    int restore(const std::string& absNodePath) const;
-
-    int replace(const std::string& absNodePath,
-                const std::string& path_to_client_defs,
-                bool create_parents_as_required = true,
-                bool force                      = false) const;
-    int replace_1(const std::string& absNodePath,
-                  defs_ptr client_defs,
-                  bool create_parents_as_required = true,
-                  bool force                      = false) const;
-
-    int requeue(const std::vector<std::string>& paths, const std::string& option = "") const;
-    int requeue(const std::string& absNodePath, const std::string& option = "") const;
-    int run(const std::vector<std::string>& paths, bool force = false) const;
-    int run(const std::string& absNodePath, bool force = false) const;
-    int order(const std::string& absNodePath, const std::string& order) const; // slow
-    int order(const std::string& absNodePath, NOrder::Order) const;            // fast
-
-    // Note: if *ALL* arguments are defaulted only then do we do a explicit save.
-    int checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
-                    int check_pt_interval        = 0,
-                    int check_pt_save_time_alarm = 0) const;
-    int restoreDefsFromCheckPt() const;
-
-    int force(const std::string& absNodePath,
-              const std::string& state_or_event,
-              bool recursive                 = false,
-              bool set_repeats_to_last_value = false) const;
-    int force(const std::vector<std::string>& paths,
-              const std::string& state_or_event,
-              bool recursive                 = false,
-              bool set_repeats_to_last_value = false) const;
-
-    int freeDep(const std::vector<std::string>& paths,
-                bool trigger = true,
-                bool all     = false,
-                bool date    = false,
-                bool time    = false) const;
-    int freeDep(const std::string& absNodePath,
-                bool trigger = true,
-                bool all     = false,
-                bool date    = false,
-                bool time    = false) const;
-
-    int file(const std::string& absNodePath, const std::string& fileType, const std::string& max_lines = "10000") const;
-
-    int plug(const std::string& sourcePath, const std::string& destPath) const;
-
-    int query(const std::string& query_type, const std::string& path_to_attribute, const std::string& attribute);
-
-    int alter(const std::vector<std::string>& paths,
-              const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-              const std::string& attrType,
-              const std::string& name  = "",
-              const std::string& value = "") const;
-    int alter(const std::string& path,
-              const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-              const std::string& attrType,
-              const std::string& name  = "",
-              const std::string& value = "") const;
-    int alter_sort(const std::vector<std::string>& paths,
-                   const std::string& sortable_attribute_name,
-                   bool recursive = true) const;
-    int alter_sort(const std::string& path, const std::string& sortable_attribute_name, bool recursive = true) const;
-
-    int reloadwsfile() const;
-    int reloadpasswdfile() const;
-    int reloadcustompasswdfile() const;
-
-    int group(const std::string& groupRequest) const;
-
-    int logMsg(const std::string& msg) const;
-    int new_log(const std::string& new_path = "") const;
-    int getLog(int lastLines = 0) const;
-    int clearLog() const;
-    int flushLog() const;
-    int get_log_path() const;
-
-    int forceDependencyEval() const;
-
-    /// The first is for use by CLI(Commend level interface), the other are for ecFlowview/Python
-    int edit_script(const std::string& path_to_task,
-                    const std::string& edit_type,
-                    const std::string& path_to_script = "",
-                    bool create_alias                 = false,
-                    bool run                          = true) {
-        return invoke(CtsApi::edit_script(path_to_task, edit_type, path_to_script, create_alias, run));
-    }
-    int edit_script_edit(const std::string& path_to_task);       // ecFlowview EDIT
-    int edit_script_preprocess(const std::string& path_to_task); // ecFlowview PRE_PROCESS
-    int edit_script_submit(const std::string& path_to_task, const NameValueVec& used_variables); // ecFlowview SUBMIT
-    int edit_script_preprocess(const std::string& path_to_task,
-                               const std::vector<std::string>& file_contents); // ecFlowview PRE_PROCESS USER File
-    int edit_script_submit(const std::string& path_to_task,
-                           const NameValueVec& used_variables,
-                           const std::vector<std::string>& file_contents,
-                           bool alias = false,
-                           bool run   = true); // ecFlowview SUBMIT_FILE
-
-private:
-    int get_cmd_from_args(const CommandLine& cl, Cmd_ptr& cts_cmd) const;
-
-    /// returns 1 on error and 0 on success. The errorMsg can be accessed via errorMsg()
-    int invoke(const std::string& arg) const;
-    int invoke(const std::vector<std::string>& args) const;
-    int invoke(Cmd_ptr) const; // assumes clients of Cmd_ptr constructor has caught exceptions
-
-    int do_invoke_cmd(Cmd_ptr) const;
-    int load_in_memory_defs(const defs_ptr& clientDefs,
-                            bool force) const; /// For clients that want to load a in memory definition into the server.
-    std::string client_env_host_port() const;
-    void check_child_parameters() const;
-
-private:
-    friend class RoundTripRecorder;
-    friend class RequestLogger;
-
-    /// For use by python interface,
-    std::vector<std::string>::const_iterator changed_node_paths_begin() const {
-        return server_reply_.changed_nodes().begin();
-    }
-    std::vector<std::string>::const_iterator changed_node_paths_end() const {
-        return server_reply_.changed_nodes().end();
-    }
-    friend void export_Client();
-
-private:
-    mutable ClientEnvironment
-        clientEnv_;              // Will read the environment *once* on construction. Must be before Client options
-    mutable ClientOptions args_; // Used for argument parsing & creating client request
-    mutable ServerReply server_reply_;     // stores the local defs, client_handle, & all server replies
-    unsigned int connection_attempts_{2};  // No of attempts to establish connection with the server
-    unsigned int retry_connection_period_; // No of seconds to wait before trying to connect in case of failure.
-
-    mutable boost::posix_time::time_duration rtt_; // record latency for each cmd.
-    mutable boost::posix_time::ptime start_time_;  // Used for time out and measuring latency
-
-    bool gui_{false};
-    bool on_error_throw_exception_{true};
-    bool auto_sync_{false};
-    bool test_{false};          // used in testing only
-    bool testInterface_{false}; // used in testing only
-};
-
-// Allow logging and debug output of request round trip times
-class RequestLogger {
-public:
-    RequestLogger(const RequestLogger&)                  = delete;
-    const RequestLogger& operator=(const RequestLogger&) = delete;
-
-    explicit RequestLogger(const ClientInvoker* ci);
-    ~RequestLogger();
-    void set_cts_cmd(Cmd_ptr cmd) { cmd_ = cmd; }
-
-private:
-    const ClientInvoker* ci_;
-    Cmd_ptr cmd_;
-};
-
-class RoundTripRecorder {
-public:
-    RoundTripRecorder(const RoundTripRecorder&)                  = delete;
-    const RoundTripRecorder& operator=(const RoundTripRecorder&) = delete;
-
-    explicit RoundTripRecorder(const ClientInvoker* ci);
-    ~RoundTripRecorder();
-
-private:
-    const ClientInvoker* ci_;
-};
-
-#endif /* ecflow_client_ClientInvoker_HPP */
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientMain.cpp 5.13.0-1/Client/src/ecflow/client/ClientMain.cpp
--- 5.12.4-1/Client/src/ecflow/client/ClientMain.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientMain.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/CommandLine.hpp"
-
-int main(int argc, char* argv[]) {
-
-    /// By default, error condition will throw exception.
-    try {
-        ClientInvoker client;
-        client.set_cli(true); // output log and file commands to standard out
-        (void)client.invoke(CommandLine(argc, argv));
-    }
-    catch (std::exception& e) {
-        std::cerr << e.what() << std::endl;
-        return 1;
-    }
-    return 0;
-}
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientOptions.cpp 5.13.0-1/Client/src/ecflow/client/ClientOptions.cpp
--- 5.12.4-1/Client/src/ecflow/client/ClientOptions.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientOptions.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,302 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-///
-/// \brief Delegates argument parsing to the registered commands
-///
-
-#include "ecflow/client/ClientOptions.hpp"
-
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/program_options.hpp>
-
-#include "ecflow/base/ClientOptionsParser.hpp"
-#include "ecflow/base/cts/task/TaskApi.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/Help.hpp"
-#include "ecflow/core/CommandLine.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/PasswordEncryption.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost;
-namespace po = boost::program_options;
-
-static std::string print_variable_map(const boost::program_options::variables_map& vm);
-
-ClientOptions::ClientOptions() {
-    // This could have been moved to parse(). However since the same ClienttInvoker can be
-    // be used for multiple commands. We have separated out the parts the need only be done once.
-    // hence improving the performance:
-    std::string title_help = "Client options, ";
-    title_help += Version::description();
-    title_help += "   ";
-    desc_ = new po::options_description(title_help, po::options_description::m_default_line_length + 80);
-
-    // This will iterate over all the registered client to server commands and
-    // Each command will add to the option description, its required arguments
-    cmdRegistry_.addAllOptions(*desc_);
-
-    // Allow the host,port and rid to be  overridden by the command line
-    // This allows the jobs, which make other calls to ecflow_client from interfering with each other
-    // clang-format off
-    desc_->add_options()(
-        "rid",
-        po::value<string>()->implicit_value(string("")),
-        "When specified overrides the environment variable ECF_RID. Can only be used for child commands.");
-    desc_->add_options()(
-        "port",
-        po::value<string>()->implicit_value(string("")),
-        "When specified overrides the environment variable ECF_PORT and default port: '3141'");
-    desc_->add_options()(
-        "host",
-        po::value<string>()->implicit_value(string("")),
-        "When specified overrides the environment variable ECF_HOST and default host: 'localhost'");
-    desc_->add_options()(
-        "user",
-        po::value<string>()->implicit_value(string("")),
-        "Specifies the user name used to contact the server. Must be used in combination with option --password.");
-    desc_->add_options()(
-        "password",
-        po::value<string>()->implicit_value(string("")),
-        "Specifies the password used to contact the server. Must be used in combination with option --user.");
-#ifdef ECF_OPENSSL
-    desc_->add_options()(
-        "ssl",
-        "Enables the use of SSL when contacting the server.\n"
-        "When specified overrides the environment variable ECF_SSL.");
-#endif
-    // clang-format on
-}
-
-ClientOptions::~ClientOptions() {
-    delete desc_;
-}
-
-Cmd_ptr ClientOptions::parse(const CommandLine& cl, ClientEnvironment* env) const {
-    // We expect two hyphen/minus, However sometimes we get a weird/rogue kind of hyphen
-    // This rogue hyphen can mess up the parsing.
-    // # ecflow_client ––group="halt=yes; check_pt; terminate=yes"  // *BAD* hyphens 2 of them
-    // # ecflow_client –-group="halt=yes; check_pt; terminate=yes"  // *BAD* hyphens 1 of them, i.e. first
-    // # ecflow_client --group="halt=yes; check_pt; terminate=yes"  // *GOOD*
-    //
-    //   dec:  -30 ffffffe2 37777777742 \342
-    //   hex: -128 ffffff80 37777777600 \200
-    //   oct: -109 ffffff93 37777777623 \223
-    //
-    // The correct hyphen has:
-    //   dec:45 hex:2D oct:55 -
-    if (env->debug()) {
-        cout << "  ClientOptions::parse " << cl << "\n";
-        std::cout << "  help column width = " << po::options_description::m_default_line_length + 80 << "\n";
-    }
-
-    // parse arguments into 'vm'.
-    //       --alter delete cron -w 0,1 10:00 /s1     # -w treated as option
-    //       --alter=/s1 change meter name -1         # -1 treated as option
-    // Note: negative numbers get treated as options: i.e trying to change meter value to a negative number
-    //       To avoid negative numbers from being treated as option use, we need to change command line style:
-    //       po::command_line_style::unix_style ^ po::command_line_style::allow_short
-    boost::program_options::variables_map vm;
-
-    // 1) Parse the CLI options
-    po::parsed_options parsed_options = po::command_line_parser(cl.tokens())
-                                            .options(*desc_)
-                                            .style(po::command_line_style::default_style)
-                                            .extra_style_parser(ClientOptionsParser{})
-                                            .run();
-
-    // 2) Store the CLI options into the variable map
-    po::store(parsed_options, vm);
-    po::notify(vm);
-
-    // If explicitly requested by user, set environment in DEBUG mode
-    if (vm.count("debug")) {
-        env->set_debug(true);
-    }
-
-    // Check to see if host or port, specified. This will override the environment variables
-    std::string host, port;
-    if (vm.count("port")) {
-        port = vm["port"].as<std::string>();
-        if (env->debug())
-            std::cout << "  port " << port << " overridden at the command line\n";
-        try {
-            ecf::convert_to<int>(port);
-        }
-        catch (ecf::bad_conversion& e) {
-            std::stringstream ss;
-            ss << "ClientOptions::parse: The specified port(" << port << ") must be convertible to an integer";
-            throw std::runtime_error(ss.str());
-        }
-    }
-    if (vm.count("host")) {
-        host = vm["host"].as<std::string>();
-        if (env->debug())
-            std::cout << "   host " << host << " overridden at the command line\n";
-    }
-    if (!host.empty() || !port.empty()) {
-        if (host.empty())
-            host = env->hostSpecified(); // get the environment variable ECF_HOST
-        if (port.empty())
-            port = env->portSpecified(); // get the environment variable ECF_PORT || Str::DEFAULT_PORT_NUMBER()
-        if (host.empty())
-            host = Str::LOCALHOST(); // if ECF_HOST not specified default to localhost
-        if (port.empty())
-            port = Str::DEFAULT_PORT_NUMBER(); // if ECF_PORT not specified use default
-        env->set_host_port(host, port);
-    }
-    if (vm.count("rid")) {
-        std::string rid = vm["rid"].as<std::string>();
-        if (env->debug())
-            std::cout << "  rid " << rid << " overridden at the command line\n";
-        env->set_remote_id(rid);
-    }
-    if (vm.count("user")) {
-        std::string user = vm["user"].as<std::string>();
-        if (env->debug())
-            std::cout << "  user " << user << " overridden at the command line\n";
-        env->set_user_name(user);
-    }
-    if (vm.count("password")) {
-        std::string password = vm["password"].as<std::string>();
-        if (env->debug())
-            std::cout << "  password overridden at the command line\n";
-        env->set_password(PasswordEncryption::encrypt(password, env->get_user_name()));
-    }
-
-#ifdef ECF_OPENSSL
-    if (vm.count("ssl")) {
-        if (env->debug())
-            std::cout << "  ssl set via command line\n";
-        env->enable_ssl();
-    }
-#endif
-
-    // Defer the parsing of the command , to the command. This allows
-    // all cmd functionality to be centralised with the command
-    // This can throw std::runtime_error if arg's don't parse
-    Cmd_ptr client_request;
-    if (!cmdRegistry_.parse(client_request, vm, env)) {
-
-        // The arguments did *NOT* match with any of the registered command.
-        // Hence, if arguments don't match help, debug or version it's an error
-        // Note: we did *NOT* check for a NULL client_request since *NOT* all
-        //       requests need to create it. Some commands are client specific.
-        //       For example:
-        //         --server_load         // this is sent to server
-        //         --server_load=<path>  // no command returned, command executed by client
-        if (vm.count("help")) {
-            string topic = vm["help"].as<std::string>();
-            std::cout << Help{*desc_, topic};
-            return client_request;
-        }
-
-        if (vm.count("version")) {
-            cout << Version::description() << "\n";
-            exit(0);
-        }
-
-        std::stringstream ss;
-        ss << print_variable_map(vm) << "\n";
-        ss << "ClientOptions::parse: Arguments did not match any commands.\n";
-        ss << "  argc=" << cl.size() << "\n";
-        for (size_t i = 0; i < cl.size(); i++) {
-            const std::string& arg = cl.tokens()[i];
-            ss << "  arg" << i << "=" << arg;
-
-            for (size_t s = 0; s < arg.size(); s++) {
-                if (static_cast<int>(arg[s]) < 0) {
-                    ss << "\nUnrecognised character not in ASCII range(0-127) " << std::dec << "dec("
-                       << static_cast<int>(arg[s]) << ") char:" << arg[s];
-                    ss << " found at index " << s << " for string '" << arg << "'\n";
-                    if (static_cast<int>(arg[s]) == -30)
-                        ss << "check for bad hyphen/minus";
-                    throw std::runtime_error(ss.str());
-                }
-            }
-        }
-        ss << "\nUse --help to see all the available commands\n";
-        throw std::runtime_error(ss.str());
-    }
-
-    return client_request;
-}
-
-static std::string print_variable_map(const boost::program_options::variables_map& vm) {
-    std::stringstream ss;
-    ss << "boost::program_options::variables_map:    vm.size() " << vm.size() << "\n";
-    for (po::variables_map::const_iterator it = vm.begin(); it != vm.end(); it++) {
-        std::cout << "> " << it->first;
-        if (((boost::any)it->second.value()).empty())
-            ss << "(empty)";
-        if (vm[it->first].defaulted() || it->second.defaulted())
-            ss << "(default)";
-
-        ss << "=";
-
-        bool is_char;
-        try {
-            boost::any_cast<const char*>(it->second.value());
-            is_char = true;
-        }
-        catch (const boost::bad_any_cast&) {
-            is_char = false;
-        }
-        bool is_str;
-        try {
-            boost::any_cast<std::string>(it->second.value());
-            is_str = true;
-        }
-        catch (const boost::bad_any_cast&) {
-            is_str = false;
-        }
-
-        if (((boost::any)it->second.value()).type() == typeid(int)) {
-            ss << vm[it->first].as<int>() << std::endl;
-        }
-        else if (((boost::any)it->second.value()).type() == typeid(bool)) {
-            ss << vm[it->first].as<bool>() << std::endl;
-        }
-        else if (((boost::any)it->second.value()).type() == typeid(double)) {
-            ss << vm[it->first].as<double>() << std::endl;
-        }
-        else if (is_char) {
-            ss << vm[it->first].as<const char*>() << std::endl;
-        }
-        else if (is_str) {
-            std::string temp = vm[it->first].as<std::string>();
-            if (temp.size()) {
-                ss << temp << std::endl;
-            }
-            else {
-                ss << "true" << std::endl;
-            }
-        }
-        else { // Assumes that the only remainder is vector<string>
-            try {
-                std::vector<std::string> vect = vm[it->first].as<std::vector<std::string>>();
-                size_t i                      = 0;
-                for (std::vector<std::string>::iterator oit = vect.begin(); oit != vect.end(); oit++, ++i) {
-                    ss << "\r> " << it->first << "[" << i << "]=" << (*oit) << std::endl;
-                }
-            }
-            catch (const boost::bad_any_cast&) {
-                ss << "UnknownType(" << ((boost::any)it->second.value()).type().name() << ")" << std::endl;
-            }
-        }
-    }
-    return ss.str();
-}
diff -pruN 5.12.4-1/Client/src/ecflow/client/ClientOptions.hpp 5.13.0-1/Client/src/ecflow/client/ClientOptions.hpp
--- 5.12.4-1/Client/src/ecflow/client/ClientOptions.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/ClientOptions.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_ClientOptions_HPP
-#define ecflow_client_ClientOptions_HPP
-
-#include "ecflow/base/cts/CtsCmdRegistry.hpp"
-class ClientEnvironment;
-class CommandLine;
-
-///
-/// \brief Will parse the client argument line, and construct a command that will be sent to the server.
-///
-/// The environment must be read in before the program options. The program options
-/// will construct the commands, some of which require the environment
-/// We could have just done this as last part of constructor. However we need a
-/// separation between reading the environment and reading the option for:
-/// a/ testing purposes. i.e as this allows us to inject/override the task path
-///    read in from the environment.
-/// b/ override host and port number.
-/// will throw std::runtime_error for invalid arguments
-///
-
-class ClientOptions {
-public:
-    ClientOptions(const ClientOptions&)                  = delete;
-    const ClientOptions& operator=(const ClientOptions&) = delete;
-
-    /// Will create command register, & ask each cmd to describe their arguments
-    ClientOptions();
-    ~ClientOptions();
-
-    /// parse the arguments and create the client request that is to be sent
-    /// to the server. Will throw std::runtime_error if invalid arguments specified
-    Cmd_ptr parse(const CommandLine& cl, ClientEnvironment*) const;
-
-private:
-    CtsCmdRegistry cmdRegistry_;
-    boost::program_options::options_description* desc_;
-};
-
-#endif /* ecflow_client_ClientOptions_HPP */
diff -pruN 5.12.4-1/Client/src/ecflow/client/Help.cpp 5.13.0-1/Client/src/ecflow/client/Help.cpp
--- 5.12.4-1/Client/src/ecflow/client/Help.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/Help.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,329 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/client/Help.hpp"
-
-#include <iomanip>
-
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-
-namespace /* __anonymous__ */ {
-
-using description_t = boost::program_options::option_description;
-using options_t     = std::vector<boost::shared_ptr<boost::program_options::option_description>>;
-
-struct CommandFilter
-{
-    template <typename PREDICATE>
-    static void select_by(options_t& options, PREDICATE select) {
-        // filter non-command options
-        options_t filtered;
-        std::copy_if(std::begin(options),
-                     std::end(options),
-                     std::back_inserter(filtered),
-                     [&select](const auto& description) { return select(description->long_name()); });
-
-        // consider only filtered options
-        std::swap(options, filtered);
-    }
-
-    static bool is_option(const std::string& value) {
-        return std::find(std::begin(known_options), std::end(known_options), value) != std::end(known_options);
-    }
-
-    static bool is_user_command(const std::string& value) { return !is_option(value) && !is_task_command(value); }
-
-    static bool is_task_command(const std::string& value) { return ecf::Child::valid_child_cmd(value); }
-
-    static bool is_command(const std::string& value) { return is_task_command(value) || is_user_command(value); }
-
-private:
-    constexpr static std::array known_options{"add", "debug", "host", "password", "port", "rid", "ssl", "user"};
-};
-
-const char* client_env_description =
-    "The client reads in the following environment variables. These are read by user and child command\n\n"
-    "|----------|----------|------------|-------------------------------------------------------------------|\n"
-    "| Name     |  Type    | Required   | Description                                                       |\n"
-    "|----------|----------|------------|-------------------------------------------------------------------|\n"
-    "| ECF_HOST | <string> | Mandatory* | The host name of the main server. defaults to 'localhost'         |\n"
-    "| ECF_PORT |  <int>   | Mandatory* | The TCP/IP port to call on the server. Must be unique to a server |\n"
-#ifdef ECF_OPENSSL
-    "| ECF_SSL  |  <any>   | Optional*  | Enable encrypted comms with SSL enabled server.                   |\n"
-#endif
-    "|----------|----------|------------|-------------------------------------------------------------------|"
-    "\n\n"
-    "* The host and port must be specified in order for the client to communicate with the server, this can \n"
-    "  be done by setting ECF_HOST, ECF_PORT or by specifying --host=<host> --port=<int> on the command line\n";
-
-const char* client_task_env_description =
-    "The following environment variables are specific to child commands.\n"
-    "The scripts should export the mandatory variables. Typically defined in the head/tail includes files\n\n"
-    "|--------------|----------|-----------|---------------------------------------------------------------|\n"
-    "| Name         |  Type    | Required  | Description                                                   |\n"
-    "|--------------|----------|-----------|---------------------------------------------------------------|\n"
-    "| ECF_NAME     | <string> | Mandatory | Full path name to the task                                    |\n"
-    "| ECF_PASS     | <string> | Mandatory | The jobs password, allocated by server, then used by server to|\n"
-    "|              |          |           | authenticate client request                                   |\n"
-    "| ECF_TRYNO    |  <int>   | Mandatory | The number of times the job has run. This is allocated by the |\n"
-    "|              |          |           | server, and used in job/output file name generation.          |\n"
-    "| ECF_RID      | <string> | Mandatory | The process identifier. Helps zombies identification and      |\n"
-    "|              |          |           | automated killing of running jobs                             |\n"
-    "| ECF_TIMEOUT  |  <int>   | optional  | Max time in *seconds* for client to deliver message to main   |\n"
-    "|              |          |           | server. The default is 24 hours                               |\n"
-    "| ECF_HOSTFILE | <string> | optional  | File that lists alternate hosts to try, if connection to main |\n"
-    "|              |          |           | host fails                                                    |\n"
-    "| ECF_DENIED   |  <any>   | optional  | Provides a way for child to exit with an error, if server     |\n"
-    "|              |          |           | denies connection. Avoids 24hr wait. Note: when you have      |\n"
-    "|              |          |           | hundreds of tasks, using this approach requires a lot of      |\n"
-    "|              |          |           | manual intervention to determine job status                   |\n"
-    "| NO_ECF       |  <any>   | optional  | If set exit's ecflow_client immediately with success. This    |\n"
-    "|              |          |           | allows the scripts to be tested independent of the server     |\n"
-    "|--------------|----------|-----------|---------------------------------------------------------------|\n";
-
-int get_options_max_width(const options_t& options) {
-    size_t vec_size  = options.size();
-    size_t max_width = 0;
-    for (size_t i = 0; i < vec_size; i++) {
-        max_width = std::max(max_width, options[i]->long_name().size());
-    }
-    max_width += 1;
-    return static_cast<int>(max_width);
-}
-
-void sort_options_by_long_name(options_t& options) {
-    std::sort(
-        options.begin(), options.end(), [](const auto& a, const auto& b) { return a->long_name() < b->long_name(); });
-}
-
-class Documentation {
-public:
-    using descriptions_t = boost::program_options::options_description;
-
-    explicit Documentation(const descriptions_t& descriptions) : descriptions_{descriptions} {}
-
-    void show(std::ostream& os, const std::string& topic) const;
-
-private:
-    void show_help(std::ostream& os) const;
-    void show_list_options(std::ostream& os) const;
-    void show_all_commands_summary(std::ostream& os, std::string_view title) const;
-    void show_task_commands_summary(std::ostream& os, std::string_view title) const;
-    void show_user_commands_summary(std::ostream& os, std::string_view title) const;
-    void show_options_summary(std::ostream& os, std::string_view title) const;
-    void show_command_help(std::ostream& os, const std::string& command) const;
-    void show_all_commands(std::ostream& os, std::string_view title) const;
-    void show_all_options(std::ostream& os) const;
-
-    template <typename PREDICATE>
-    void show_table(std::ostream& os, PREDICATE select, size_t columns) const;
-
-    template <typename PREDICATE>
-    void show_summary(std::ostream& os, PREDICATE select) const;
-
-    static std::string get_name_kind(const std::string& name) {
-        if (CommandFilter::is_option(name)) {
-            return "option  ";
-        }
-        else if (CommandFilter::is_task_command(name)) {
-            return "child   ";
-        }
-        else if (CommandFilter::is_user_command(name)) {
-            return "user    ";
-        }
-        else {
-            throw std::runtime_error("Unable to determine the kind of option/command");
-        }
-    }
-
-private:
-    const descriptions_t& descriptions_;
-};
-
-void Documentation::show(std::ostream& os, const std::string& topic) const {
-    // WARNING!!
-    //   This assumes that there are no user/child commands named: 'summary', 'all', 'child', 'user'
-    //
-
-    if (topic.empty()) {
-        show_help(os);
-    }
-    else if (topic == "all") {
-        show_list_options(os);
-    }
-    else if (topic == "summary") {
-        show_all_commands_summary(os, "\nEcflow client commands:\n");
-    }
-    else if (topic == "child") {
-        show_task_commands_summary(os, "\nEcflow child client commands:\n");
-    }
-    else if (topic == "user") {
-        show_user_commands_summary(os, "\nEcflow user client commands:\n");
-    }
-    else if (topic == "option") {
-        show_options_summary(os, "\nEcflow generic options:\n");
-    }
-    else {
-        show_command_help(os, topic);
-    }
-}
-
-void Documentation::show_help(std::ostream& os) const {
-    os << "\nClient/server based work flow package:\n\n";
-    os << ecf::Version::description() << "\n\n";
-    os << Ecf::CLIENT_NAME() << " provides the command line interface, for interacting with the server:\n";
-
-    os << "Try:\n\n";
-    os << "   " << Ecf::CLIENT_NAME() << " --help=all       # List all commands, verbosely\n";
-    os << "   " << Ecf::CLIENT_NAME() << " --help=summary   # One line summary of all commands\n";
-    os << "   " << Ecf::CLIENT_NAME() << " --help=child     # One line summary of child commands\n";
-    os << "   " << Ecf::CLIENT_NAME() << " --help=user      # One line summary of user command\n";
-    os << "   " << Ecf::CLIENT_NAME() << " --help=<cmd>     # Detailed help on each command\n\n";
-
-    show_all_commands(os, "Commands:");
-
-    show_all_options(os);
-}
-
-void Documentation::show_list_options(std::ostream& os) const {
-    os << descriptions_ << "\n";
-}
-
-template <typename PREDICATE>
-void Documentation::show_table(std::ostream& os, PREDICATE select, size_t columns) const {
-    // take a copy, since we need to sort
-    options_t options = descriptions_.options();
-
-    // filter for real commands
-    CommandFilter::select_by(options, select);
-
-    // sort using long_name
-    sort_options_by_long_name(options);
-
-    size_t max_width = get_options_max_width(options);
-    for (size_t i = 0; i < options.size(); i++) {
-        if (i == 0 || i % columns == 0) {
-            os << "\n   ";
-        }
-        os << std::left << std::setw(max_width) << options[i]->long_name();
-    }
-    os << "\n\n";
-}
-
-template <typename PREDICATE>
-void Documentation::show_summary(std::ostream& os, PREDICATE select) const {
-
-    // take a copy, since we need to sort
-    options_t options = descriptions_.options();
-
-    // filter for real commands
-    CommandFilter::select_by(options, select);
-
-    // sort using long_name
-    sort_options_by_long_name(options);
-
-    int max_width = get_options_max_width(options);
-    for (const auto& option : options) {
-        std::vector<std::string> lines;
-        ecf::Str::split(option->description(), lines, "\n");
-        if (!lines.empty()) {
-            std::string name = option->long_name();
-            os << "  " << std::left << std::setw(max_width) << name << " ";
-            os << Documentation::get_name_kind(name);
-            os << lines[0] << "\n";
-        }
-    }
-    os << "\n";
-}
-
-void Documentation::show_all_commands_summary(std::ostream& os, std::string_view title) const {
-    os << title << '\n';
-    show_summary(os, CommandFilter::is_command);
-}
-
-void Documentation::show_task_commands_summary(std::ostream& os, std::string_view title) const {
-    os << title << '\n';
-    show_summary(os, CommandFilter::is_task_command);
-}
-
-void Documentation::show_user_commands_summary(std::ostream& os, std::string_view title) const {
-    os << title << '\n';
-    show_summary(os, CommandFilter::is_user_command);
-}
-
-void Documentation::show_options_summary(std::ostream& os, std::string_view title) const {
-    os << title << '\n';
-    show_summary(os, CommandFilter::is_option);
-}
-
-void Documentation::show_command_help(std::ostream& os, const std::string& command) const {
-    // Help on individual command
-    const boost::program_options::option_description* od =
-        descriptions_.find_nothrow(command,
-                                   true,  /* approx, will find nearest match */
-                                   false, /* long_ignore_case = false*/
-                                   false  /* short_ignore_case = false*/
-        );
-    if (od) {
-        os << "\n";
-        os << od->long_name() << "\n";
-        for (size_t i = 0; i < od->long_name().size(); i++) {
-            os << "-";
-        }
-        os << "\n\n";
-        os << od->description() << "\n\n";
-        if (!CommandFilter::is_option(od->long_name())) {
-            os << client_env_description;
-            if (ecf::Child::valid_child_cmd(od->long_name())) {
-                os << "\n";
-                os << client_task_env_description;
-            }
-        }
-    }
-    else {
-        show_all_commands(os, "No matching command found, please choose from:");
-    }
-}
-
-void Documentation::show_all_commands(std::ostream& os, std::string_view title) const {
-    os << title << "\n";
-    show_table(os, CommandFilter::is_command, 5);
-}
-
-void Documentation::show_all_options(std::ostream& os) const {
-    os << "Generic Options:\n";
-    show_table(os, CommandFilter::is_option, 8);
-}
-
-} // namespace
-
-struct Help::Impl
-{
-    Documentation documentation_;
-    std::string topic_;
-
-    Impl(const descriptions_t& descriptions, std::string topic)
-        : documentation_(descriptions),
-          topic_(std::move(topic)) {}
-};
-
-Help::Help(const descriptions_t& descriptions, const std::string& topic)
-    : impl_(std::make_unique<Help::Impl>(descriptions, topic)) {
-}
-
-Help::~Help() = default;
-
-std::ostream& operator<<(std::ostream& os, const Help& help) {
-    help.impl_->documentation_.show(os, help.impl_->topic_);
-    return os;
-}
diff -pruN 5.12.4-1/Client/src/ecflow/client/Help.hpp 5.13.0-1/Client/src/ecflow/client/Help.hpp
--- 5.12.4-1/Client/src/ecflow/client/Help.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/Help.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_Help_HPP
-#define ecflow_client_Help_HPP
-
-#include <memory>
-
-#include <boost/program_options.hpp>
-
-class Help {
-public:
-    using descriptions_t = boost::program_options::options_description;
-
-    Help(const descriptions_t& descriptions, const std::string& topic);
-    ~Help();
-
-    friend std::ostream& operator<<(std::ostream& os, const Help& help);
-
-private:
-    struct Impl;
-    std::unique_ptr<Impl> impl_;
-};
-
-#endif /* ecflow_client_Help_HPP */
diff -pruN 5.12.4-1/Client/src/ecflow/client/Rtt.cpp 5.13.0-1/Client/src/ecflow/client/Rtt.cpp
--- 5.12.4-1/Client/src/ecflow/client/Rtt.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/Rtt.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,170 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/client/Rtt.hpp"
-
-#include <iostream>
-#include <stdexcept>
-#include <vector>
-
-#include <boost/date_time/posix_time/posix_time.hpp> //include all types plus i/o
-
-#include "ecflow/core/File.hpp"
-
-using namespace std;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-namespace ecf {
-
-Rtt* Rtt::instance_ = nullptr;
-
-void Rtt::create(const std::string& filename) {
-    if (instance_ == nullptr) {
-        instance_ = new Rtt(filename);
-    }
-}
-
-void Rtt::destroy() {
-    delete instance_;
-    instance_ = nullptr;
-}
-
-Rtt::Rtt(const std::string& filename) : file_(filename.c_str(), ios::out | ios::app) {
-    if (!file_.is_open()) {
-        std::cerr << "Rtt::Rtt Could not open file '" << filename << "'\n";
-        throw std::runtime_error("Rtt::Rtt: Could not open file " + filename);
-    }
-}
-
-Rtt::~Rtt() = default;
-
-void Rtt::log(const std::string& message) {
-    file_ << message << endl;
-}
-
-void rtt(const std::string& message) {
-    if (Rtt::instance()) {
-        Rtt::instance()->log(message);
-    }
-}
-
-std::string Rtt::analyis(const std::string& filename) {
-    std::vector<std::string> lines;
-    if (!File::splitFileIntoLines(filename, lines)) {
-        std::cout << "Rtt::analyis: could not open file " << filename << " (" << strerror(errno) << ")\n";
-        return string();
-    }
-
-    // Typical format
-    // localhost:3141 --ping :ma0 rtt:00:00:00.001082
-    // localhost:3141 --log=new Test/data/ECF_HOME/test_wait_cmd/test_wait_cmd.def_log  :ma0 rtt:00:00:00.000930
-    // localhost:3141 --zombie_get :ma0 rtt:00:00:00.003982
-
-    /// Extract the command name and time, and add to map, to compute averages, min,max & standard deviation
-    map<string, vector<time_duration>> cmd_time_map;
-    size_t max_cmd_size = 0;
-    for (auto& line : lines) {
-
-        if (line.empty())
-            continue;
-        //      cout << i << ":" << lines[i] << "   ";
-        string::size_type dash    = line.find("--");
-        string::size_type rtt_pos = line.find(Rtt::tag());
-        if (dash == std::string::npos)
-            continue;
-        if (rtt_pos == std::string::npos)
-            continue;
-
-        int cmd_length           = 0;
-        string::size_type equals = line.find("=", dash);
-        string::size_type space  = line.find(" ", dash);
-        if (equals != std::string::npos)
-            cmd_length = equals;
-        else if (space != std::string::npos)
-            cmd_length = space;
-        string cmd   = line.substr(0, cmd_length);
-        max_cmd_size = std::max(max_cmd_size, cmd.size());
-
-        string time = line.substr(rtt_pos + 4);
-        time_duration td(duration_from_string(time));
-        //      cout << "  cmd:(" << cmd << ") time(" << to_simple_string(td) << ")\n";
-
-        auto cmd_iterator = cmd_time_map.find(cmd);
-        if (cmd_iterator == cmd_time_map.end()) {
-            vector<time_duration> vec;
-            vec.push_back(td);
-            std::pair<string, vector<time_duration>> p = std::make_pair(cmd, vec);
-            cmd_time_map.insert(p);
-        }
-        else {
-            (*cmd_iterator).second.push_back(td);
-        }
-    }
-
-    time_duration total(0, 0, 0, 0);
-    int total_requests = 0;
-
-    // Create title
-    std::stringstream ss;
-    ss << left << setw(max_cmd_size + 1) << "Command" << right << setw(5) << "count" << setw(9) << "min" << setw(9)
-       << "average" << setw(9) << "max" << setw(9) << right << "std\n";
-    for (std::pair<string, vector<time_duration>> p : cmd_time_map) {
-
-        time_duration average_td(0, 0, 0, 0);
-        time_duration min(24, 59, 59, 0);
-        time_duration max(0, 0, 0, 0);
-        for (const auto& i : p.second) {
-            average_td += i;
-            total_requests++;
-            total += i;
-            min = std::min(min, i);
-            max = std::max(max, i);
-        }
-
-        ss << left << setw(max_cmd_size + 1) << p.first << setw(5) << right << p.second.size();
-        if (p.second.empty()) {
-            ss << setw(9) << right << p.second[0].total_microseconds() << " ? ";
-        }
-        else if (p.second.size() == 1) {
-            ss << setw(9) << right << p.second[0].total_microseconds();
-        }
-        else {
-            int average = average_td.total_microseconds() / p.second.size();
-
-            //          bool debug = false;
-            //          if (p.first == "begin")   debug = true;
-
-            // compute standard deviation
-            unsigned int total_diff_from_avg = 0;
-            for (auto& i : p.second) {
-                int diff         = i.total_microseconds() - average;
-                int diff_squared = diff * diff;
-                total_diff_from_avg += diff_squared;
-                //             if (debug) cout << "diff: " << diff << " diff_squared: " << diff_squared << "
-                //             total_diff_from_avg: " << total_diff_from_avg << "\n";
-            }
-
-            double avg = total_diff_from_avg / p.second.size();
-            auto stdd  = (int)sqrt(avg);
-            //          if (debug) cout << "avg: " << avg << " stdd: " << stdd << "\n";
-
-            ss << setw(9) << right << min.total_microseconds();
-            ss << setw(9) << right << average;
-            ss << setw(9) << right << max.total_microseconds();
-            ss << setw(9) << right << stdd;
-        }
-        ss << "\n";
-    }
-    ss << "\ntotal round trip time " << to_simple_string(total) << " for " << total_requests << " requests\n";
-    return ss.str();
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Client/src/ecflow/client/Rtt.hpp 5.13.0-1/Client/src/ecflow/client/Rtt.hpp
--- 5.12.4-1/Client/src/ecflow/client/Rtt.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/Rtt.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_Rtt_HPP
-#define ecflow_client_Rtt_HPP
-
-#include <fstream>
-#include <sstream>
-#include <string>
-
-///
-/// \brief Simple client based singleton for recording round trip times of all client based command
-///
-
-namespace ecf {
-
-class Rtt {
-public:
-    Rtt(const Rtt&)                  = delete;
-    const Rtt& operator=(const Rtt&) = delete;
-
-    static void create(const std::string& filename);
-    static void destroy();
-    static Rtt* instance() { return instance_; }
-
-    void log(const std::string& message);
-
-    /// Open the file, and create average times for all client invoker round trip times
-    static std::string analyis(const std::string& filename);
-
-    /// Used in output and parsing, when computing averages
-    static const char* tag() { return "rtt:"; }
-
-private:
-    ~Rtt();
-    explicit Rtt(const std::string& filename);
-    static Rtt* instance_;
-    mutable std::ofstream file_;
-};
-
-void rtt(const std::string& message);
-
-// allow user to do the following:
-// RTT("this is " << path << " ok ");
-//
-// helper, see STRINGIZE() macro
-template <typename Functor>
-std::string stringize_rtt(Functor const& f) {
-    std::ostringstream out;
-    f(out);
-    return out.str();
-}
-#define STRINGIZE_RTT(EXPRESSION) (ecf::stringize_rtt([](std::ostringstream& os) { os << EXPRESSION };))
-#define RTT(EXPRESSION) ecf::rtt(STRINGIZE_RTT(EXPRESSION))
-} // namespace ecf
-#endif
diff -pruN 5.12.4-1/Client/src/ecflow/client/UrlCmd.cpp 5.13.0-1/Client/src/ecflow/client/UrlCmd.cpp
--- 5.12.4-1/Client/src/ecflow/client/UrlCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/UrlCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/client/UrlCmd.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Node.hpp"
-
-UrlCmd::UrlCmd(defs_ptr defs, const std::string& absNodePath) : defs_(defs), node_(nullptr) {
-    if (!defs_.get()) {
-        throw std::runtime_error("UrlCmd: The definition parameter is empty");
-    }
-
-    if (absNodePath.empty()) {
-        throw std::runtime_error("UrlCmd: The node path parameter is empty");
-    }
-
-    node_ = defs_->findAbsNode(absNodePath).get();
-    if (!node_) {
-        std::string errorMsg = "UrlCmd: The node path parameter '";
-        errorMsg += absNodePath;
-        errorMsg += "' cannot be found.";
-        throw std::runtime_error(errorMsg);
-    }
-}
-
-std::string UrlCmd::getUrl() const {
-    std::string url;
-    node_->findParentUserVariableValue("ECF_URL_CMD", url);
-    if (url.empty()) {
-        std::string errorMsg = "UrlCmd: Could not find variable ECF_URL_CMD from node ";
-        errorMsg += node_->absNodePath();
-        throw std::runtime_error(errorMsg);
-    }
-
-    if (!node_->variableSubstitution(url)) {
-        std::string errorMsg = "UrlCmd:: Variable substitution failed for ";
-        errorMsg += url;
-        throw std::runtime_error(errorMsg);
-    }
-    return url;
-}
-
-void UrlCmd::execute() const {
-    // invoke as a system command, we don't use System::instance()
-    // since this is on the client side. hence no need manage the spawned process
-    system(getUrl().c_str());
-}
diff -pruN 5.12.4-1/Client/src/ecflow/client/UrlCmd.hpp 5.13.0-1/Client/src/ecflow/client/UrlCmd.hpp
--- 5.12.4-1/Client/src/ecflow/client/UrlCmd.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/src/ecflow/client/UrlCmd.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,46 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_UrlCmd_HPP
-#define ecflow_client_UrlCmd_HPP
-
-#include <string>
-
-#include "ecflow/node/NodeFwd.hpp"
-
-///
-/// \note Client side command only.
-/// \note Placed in this category, since the server does not need to link with it.
-///
-
-class UrlCmd {
-public:
-    UrlCmd()              = delete;
-    UrlCmd(const UrlCmd&) = delete;
-    UrlCmd(UrlCmd&&)      = delete;
-
-    /// Will throw std::runtime_error if defs or node path is not correct
-    UrlCmd(defs_ptr defs, const std::string& absNodePath);
-
-    UrlCmd& operator=(const UrlCmd&) = delete;
-    UrlCmd& operator=(UrlCmd&&)      = delete;
-
-    /// Will throw std::runtime_error if url cannot be formed
-    std::string getUrl() const;
-
-    /// Execute the url command
-    void execute() const;
-
-private:
-    defs_ptr defs_;
-    Node* node_;
-};
-
-#endif /* ecflow_client_UrlCmd_HPP */
diff -pruN 5.12.4-1/Client/test/InvokeServer.hpp 5.13.0-1/Client/test/InvokeServer.hpp
--- 5.12.4-1/Client/test/InvokeServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/InvokeServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,194 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_test_InvokeServer_HPP
-#define ecflow_client_test_InvokeServer_HPP
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/EcfPortLock.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Str.hpp"
-
-class InvokeServer {
-public:
-    InvokeServer()                    = delete;
-    InvokeServer(const InvokeServer&) = delete;
-    explicit InvokeServer(const std::string& msg,
-                          const std::string& port                      = ecf::Str::DEFAULT_PORT_NUMBER(),
-                          bool disable_job_generation                  = false,
-                          bool remove_checkpt_file_before_server_start = true,
-                          bool remove_checkpt_file_after_server_exit   = true)
-        : port_(port),
-          host_(ClientEnvironment::hostSpecified()),
-          remove_checkpt_file_after_server_exit_(remove_checkpt_file_after_server_exit) {
-        if (host_.empty()) {
-            if (!msg.empty()) {
-                std::cout << msg << "   port(" << port_ << ")";
-#ifdef ECF_OPENSSL
-                if (getenv("ECF_SSL"))
-                    std::cout << " (ssl)";
-#endif
-                std::cout << std::endl;
-            }
-
-            doStart(msg, port_, server_started_, disable_job_generation, remove_checkpt_file_before_server_start);
-        }
-        else {
-            // Start of test, clear any existing defs on remote/localhost server
-            // Assuming this has been started on input port
-            std::string test_name = msg;
-            test_name += " on ";
-            test_name += host_;
-            test_name += ecf::Str::COLON();
-            test_name += port_;
-
-            std::cout << test_name << std::endl;
-
-            ClientInvoker theClient(host_, port_);
-            theClient.logMsg(test_name);
-            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                                  CtsApi::to_string(CtsApi::delete_node())
-                                      << " failed should return 0. Should Delete ALL existing defs in the server\n"
-                                      << theClient.errorMsg());
-            server_started_ = true;
-        }
-    }
-
-    InvokeServer(const std::string& port,
-                 bool stop_ambiguaty,
-                 bool disable_job_generation                  = false,
-                 bool remove_checkpt_file_before_server_start = true,
-                 bool remove_checkpt_file_after_server_exit   = true)
-        : port_(port),
-          remove_checkpt_file_after_server_exit_(remove_checkpt_file_after_server_exit) {
-        // host_ is empty.
-        doStart("", port_, server_started_, disable_job_generation, remove_checkpt_file_before_server_start);
-    }
-
-    ~InvokeServer() {
-        // This will also remove the generated files.
-        // Will only terminate local server, host_ is *EMPTY* for local server, using two constructors above
-        if (host_.empty()) {
-            doEnd(ecf::Str::LOCALHOST(),
-                  port_,
-                  remove_checkpt_file_after_server_exit_,
-                  remove_log_file_after_server_exit_);
-        }
-    }
-
-    InvokeServer& operator=(const InvokeServer&) = delete;
-
-    const std::string& port() const { return port_; }
-    const std::string& host() const {
-        if (host_.empty())
-            return ecf::Str::LOCALHOST();
-        return host_;
-    }
-
-    std::string ecf_log_file() const { return host_name_.ecf_log_file(port_); }
-    std::string ecf_checkpt_file() const { return host_name_.ecf_checkpt_file(port_); }
-    std::string ecf_backup_checkpt_file() const { return host_name_.ecf_backup_checkpt_file(port_); }
-    bool server_started() const { return server_started_; }
-    void keep_log_file_after_server_exit() { remove_log_file_after_server_exit_ = false; }
-
-private:
-    static void doStart(const std::string& msg,
-                        const std::string& port,
-                        bool& server_started,
-                        bool disable_job_generation                  = false,
-                        bool remove_checkpt_file_before_server_start = true) {
-        /// Remove check pt and backup check pt file, else server will load it & remove log file
-        ecf::Host h;
-        if (remove_checkpt_file_before_server_start) {
-            fs::remove(h.ecf_checkpt_file(port));
-            fs::remove(h.ecf_backup_checkpt_file(port));
-        }
-        fs::remove(h.ecf_log_file(port));
-
-        // start the server in the background
-        std::string theServerInvokePath = ecf::File::find_ecf_server_path();
-        BOOST_REQUIRE_MESSAGE(!theServerInvokePath.empty(),
-                              "InvokeServer::doStart: `ecflow_server` executable must be available");
-        BOOST_REQUIRE_MESSAGE(fs::exists(theServerInvokePath),
-                              "InvokeServer::doStart: `ecflow_server` executable available at:" << theServerInvokePath);
-
-        // Create a port file. To avoid creating multiple servers on the same port number
-        ecf::EcfPortLock::create(port);
-
-        // Make sure server starts in the background to avoid hanging test
-        theServerInvokePath += " --port=" + port;
-        if (disable_job_generation) {
-            theServerInvokePath += " --dis_job_gen";
-        }
-        theServerInvokePath += " &";
-
-        // std::cout << "InvokeServer::doStart port = " << port << " server path = " <<  theServerInvokePath << "\n";
-        (void)system(theServerInvokePath.c_str());
-
-        // Allow time for server process to kick in.
-        ClientInvoker theClient(ecf::Str::LOCALHOST(), port);
-        if (theClient.wait_for_server_reply()) {
-            server_started = true;
-            if (!msg.empty())
-                theClient.logMsg(msg);
-        }
-        else {
-            server_started = false;
-        }
-    }
-
-    static void doEnd(const std::string& host,
-                      const std::string& port,
-                      bool remove_checkpt_file_after_server_exit,
-                      bool remove_log_file_after_server_exit) {
-        //    std::cout << "*****InvokeServer::doEnd    Closing server on  " << host << ecf::Str::COLON() << port <<
-        //    "\n";
-        {
-            ClientInvoker theClient(host, port);
-            BOOST_REQUIRE_NO_THROW(theClient.terminateServer());
-            BOOST_REQUIRE_MESSAGE(theClient.wait_for_server_death(), "Failed to terminate server after 60 seconds\n");
-        }
-
-        // remove port file. This prevented multiple different process from opening servers with same port number
-        ecf::EcfPortLock::remove(port);
-
-        // Remove generated file comment for debug
-        ecf::Host h;
-        if (remove_log_file_after_server_exit) {
-            fs::remove(h.ecf_log_file(port));
-            BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_log_file(port)),
-                                "log file " << h.ecf_log_file(port) << " not deleted\n");
-        }
-
-        if (remove_checkpt_file_after_server_exit) {
-            fs::remove(h.ecf_checkpt_file(port));
-            fs::remove(h.ecf_backup_checkpt_file(port));
-            BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_checkpt_file(port)),
-                                "file " << h.ecf_checkpt_file(port) << " not deleted\n");
-            BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_backup_checkpt_file(port)),
-                                "file " << h.ecf_backup_checkpt_file(port) << " not deleted\n");
-        }
-    }
-
-private:
-    std::string port_;
-    std::string host_;
-    ecf::Host host_name_;
-    bool remove_checkpt_file_after_server_exit_{true};
-    bool remove_log_file_after_server_exit_{true};
-    bool server_started_{false};
-};
-
-#endif /* ecflow_client_test_InvokeServer_HPP */
diff -pruN 5.12.4-1/Client/test/SCPort.cpp 5.13.0-1/Client/test/SCPort.cpp
--- 5.12.4-1/Client/test/SCPort.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/SCPort.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,95 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "SCPort.hpp"
-
-#include <iostream>
-
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/EcfPortLock.hpp"
-#include "ecflow/core/Str.hpp"
-
-namespace ecf {
-
-// init the globals. Note we dont use 3141, so that in the case where we already
-// have a remote/local server started external to the test, it does not clash
-// Also debug and release version use different port numbers to avoid clashes, if both tests run at same time
-
-#ifdef DEBUG
-int SCPort::thePort_ = 3161;
-#else
-int SCPort::thePort_ = 3144;
-#endif
-
-std::string SCPort::next() {
-    bool debug = false;
-    if (getenv("ECF_DEBUG_TEST"))
-        debug = true;
-
-    if (debug)
-        std::cout << "\nSCPort::next() : ";
-
-    // Allow parallel tests
-    char* ECF_FREE_PORT = getenv("ECF_FREE_PORT");
-    if (ECF_FREE_PORT) {
-        if (debug)
-            std::cout << " seed_port=ECF_FREE_PORT=(" << ECF_FREE_PORT << ")";
-        std::string port = ECF_FREE_PORT;
-        try {
-            thePort_ = ecf::convert_to<int>(port);
-        }
-        catch (...) {
-            std::cout << "SCPort::next()  ECF_FREE_PORT(" << ECF_FREE_PORT << ") not convertible to an integer\n";
-        }
-    }
-
-    // This is used to test remote servers(or legacy server with new client). Here ECF_HOST=localhost in the test
-    // scripts
-    std::string host = ClientEnvironment::hostSpecified();
-    if (debug)
-        std::cout << " ECF_HOST('" << host << "')";
-
-    if (host == Str::LOCALHOST()) {
-        char* ecf_port = getenv("ECF_PORT");
-        if (ecf_port) {
-            std::string port = ecf_port;
-            if (!port.empty()) {
-                if (debug)
-                    std::cout << " ECF_PORT('" << ecf_port << "')\n";
-                return port;
-            }
-        }
-        if (debug)
-            std::cout << " !!!!!! ERROR when ECF_HOST=localhost  EXPECTED ECF_PORT to be set !!!!!! ";
-    }
-
-    if (debug)
-        std::cout << "\n";
-    std::string the_port = next_only(debug);
-    if (debug)
-        std::cout << " SCPort::next() returning free port=" << the_port << "\n";
-    return the_port;
-}
-
-std::string SCPort::next_only(bool debug) {
-    if (debug)
-        std::cout << " SCPort::next_only : starting seed_port(" << thePort_ << ")\n";
-
-    // Use a combination of local lock file, and pinging the server
-    while (!EcfPortLock::is_free(thePort_, debug))
-        thePort_++;
-
-    if (debug)
-        std::cout << " SCPort::next_only() seed_port(" << thePort_ << ")\n";
-    return ClientInvoker::find_free_port(thePort_, debug);
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Client/test/SCPort.hpp 5.13.0-1/Client/test/SCPort.hpp
--- 5.12.4-1/Client/test/SCPort.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/SCPort.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_client_test_SCPort_HPP
-#define ecflow_client_test_SCPort_HPP
-
-#include <string>
-
-namespace ecf {
-
-// If two different process/servers both try to use the same port number, you
-// get an "Address in use" error, even if one the process is dead. This is
-// because the kernel does not immediately release the resource and there is
-// time out period. To get round this we will start the new server/client
-// and use a different port number.
-
-class SCPort {
-public:
-    /// Check ECF_HOST and ECF_PORT first, otherwise calls next_only
-    static std::string next();
-
-    /// make sure we have a unique port, each time next_only() is called;
-    static std::string next_only(bool debug = false);
-
-private:
-    SCPort()  = delete;
-    ~SCPort() = delete;
-
-    static int thePort_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_client_test_SCPort_HPP */
diff -pruN 5.12.4-1/Client/test/TestCheckPtDefsCmd.cpp 5.13.0-1/Client/test/TestCheckPtDefsCmd.cpp
--- 5.12.4-1/Client/test/TestCheckPtDefsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestCheckPtDefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,394 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "MyDefsFixture.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_CheckPtDefsCmd)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-// ************************************************************************************
-BOOST_AUTO_TEST_CASE(test_check_pt_defs_cmd) {
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-    InvokeServer invokeServer("Client:: ...test_check_pt_defs_cmd", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
-                                                  << theClient.errorMsg());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-
-    // First time. Should create a ecf_checkpt_file, but _no_ backup file
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                          CtsApi::checkPtDefs() << " failed should return 0\n"
-                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
-                          CtsApi::checkPtDefs() << " failed file(" << invokeServer.ecf_checkpt_file() << ") not saved");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
-                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
-                                                       << "), to have file size > 0");
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // This check only valid if server was invoked locally. Ignore for remote servers
-        BOOST_REQUIRE_MESSAGE(!fs::exists(invokeServer.ecf_backup_checkpt_file()),
-                              "Backup check point file(" << invokeServer.ecf_backup_checkpt_file()
-                                                         << ")should not exist,for very first time.");
-    }
-
-    // Save checkpoint file again. This should create a backup file, we should have ecf_checkpt_file and
-    // ecf_backup_checkpt_file
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                          CtsApi::checkPtDefs() << " failed should return 0\n"
-                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
-                          CtsApi::checkPtDefs()
-                              << " failed No check pt file(" << invokeServer.ecf_checkpt_file() << ") saved");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
-                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
-                                                       << ") to have file size > 0  ");
-    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_backup_checkpt_file()),
-                          "Backup check point file(" << invokeServer.ecf_backup_checkpt_file() << ") not created");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_backup_checkpt_file()) != 0,
-                          "Expected backup check point file(" << invokeServer.ecf_backup_checkpt_file()
-                                                              << "), to have file size > 0");
-
-    // Check the defaults for mode , interval and alarm time before making any changes
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
-                          " Expected default check pt mode to be ON_TIME");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == CheckPt::default_interval(),
-                          " Expected default check pt interval of "
-                              << CheckPt::default_interval() << " but found "
-                              << theClient.server_reply().stats().checkpt_interval_);
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // This check only valid if server was invoked locally. Ignore for remote servers
-        // From ecflow 4.7.0 checkpt_save_time_alarm went from 30 -> 20 seconds, hence will fail for old servers
-        BOOST_REQUIRE_MESSAGE(
-            theClient.server_reply().stats().checkpt_save_time_alarm_ == CheckPt::default_save_time_alarm(),
-            " Expected default check pt alarm time of " << CheckPt::default_save_time_alarm() << " but found "
-                                                        << theClient.server_reply().stats().checkpt_save_time_alarm_);
-    }
-
-    // Test change of check_pt interval and mode and alarm
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::NEVER) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::NEVER) << " failed should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::NEVER,
-                          " Expected check pt mode of NEVER");
-
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
-                                                                     << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
-                          " Expected check pt mode of ON_TIME");
-
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ALWAYS) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::ALWAYS) << " failed should return 0\n"
-                                                                    << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ALWAYS,
-                          " Expected check pt mode of ALWAYS");
-
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, 30) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME, 30) << " failed should return 0\n"
-                                                                         << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
-                          " Expected check pt mode of ON_TIME");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == 30,
-                          " Expected check pt interval of 30 but found "
-                              << theClient.server_reply().stats().checkpt_interval_);
-
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 56) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::UNDEFINED, 56) << " failed should return 0\n"
-                                                                           << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
-                          " Expected check pt mode of ON_TIME");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == 56,
-                          " Expected check pt interval of 56 but found "
-                              << theClient.server_reply().stats().checkpt_interval_);
-
-    // Mode and interval should remain unchanged only the alarm time should be changed
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 0, 10) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::UNDEFINED, 0, 10) << " failed should return 0\n"
-                                                                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
-                          " Expected check pt mode of ON_TIME");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == 56,
-                          " Expected check pt interval of 56 but found "
-                              << theClient.server_reply().stats().checkpt_interval_);
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_save_time_alarm_ == 10,
-                          " Expected check pt alarm time of 10 but found "
-                              << theClient.server_reply().stats().checkpt_save_time_alarm_);
-
-    // restore default check pointing for test that follow.
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, CheckPt::default_interval()) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
-                                                                     << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 0, CheckPt::default_save_time_alarm()) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
-                                                                     << theClient.errorMsg());
-
-    // check defaults were set
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
-                          " Expected default check pt mode to be ON_TIME");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == CheckPt::default_interval(),
-                          " Expected default check pt interval of "
-                              << CheckPt::default_interval() << " but found "
-                              << theClient.server_reply().stats().checkpt_interval_);
-    BOOST_REQUIRE_MESSAGE(
-        theClient.server_reply().stats().checkpt_save_time_alarm_ == CheckPt::default_save_time_alarm(),
-        " Expected default check pt alarm time of " << CheckPt::default_save_time_alarm() << " but found "
-                                                    << theClient.server_reply().stats().checkpt_save_time_alarm_);
-}
-
-BOOST_AUTO_TEST_CASE(test_restore_from_check_pt) {
-    InvokeServer invokeServer("Client:: ...test_restore_from_check_pt", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    defs_ptr the_defs = Defs::create();
-    the_defs->add_suite("s0");
-    the_defs->add_suite("s1");
-    the_defs->add_suite("s2");
-    the_defs->add_suite("s3");
-    the_defs->add_suite("s4");
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.load(the_defs) == 0, "load defs failed \n" << theClient.errorMsg());
-
-    size_t expected_no_of_suites = 5;
-    for (int i = 0; i < 5; i++) {
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                              CtsApi::checkPtDefs() << " failed should return 0\n"
-                                                    << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              "Expected delete all nodes to succeed\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0, "Expected halt server to succeed\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restoreDefsFromCheckPt() == 0, "Expected restoreDefsFromCheckPt succeed\n");
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0, "Expected getDefs() to succeed, i.e expected empty defs\n");
-        BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == expected_no_of_suites,
-                              "Expected " << expected_no_of_suites << " suites, after restoreDefsFromCheckPt but found "
-                                          << theClient.defs()->suiteVec().size() << "\n");
-
-        std::string suite = "/s" + ecf::convert_to<std::string>(i);
-        BOOST_REQUIRE_MESSAGE(theClient.delete_node(suite) == 0,
-                              "Expected delete single suite to succeed\n"
-                                  << theClient.errorMsg());
-        expected_no_of_suites--;
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_restore_from_check_pt_using_new_server) {
-    // This test relies on a NEW server invocation. Hence if ECF_HOST/remote server is used
-    // the test will will invalid. hence ignore.
-    if (!ClientEnvironment::hostSpecified().empty()) {
-        cout << "Client:: ...test_restore_from_check_pt_using_new_server: ignoring test when ECF_HOST specified\n";
-        return;
-    }
-
-    PrintStyle style(PrintStyle::STATE);
-    std::string port = SCPort::next();
-
-    MyDefsFixture theDefsFixture; // make sure generated server variable use this port.
-    defs_ptr defs_to_be_check_pointed = theDefsFixture.create_defs(port);
-
-    BOOST_REQUIRE_MESSAGE(defs_to_be_check_pointed->suiteVec().size() >= 2, "expected at least 2 suites");
-
-    {
-        // Start a new server. However make sure that on server exit, we not delete check pt files
-        InvokeServer invokeServer("Client:: ...test_restore_from_check_pt_using_new_server",
-                                  port,
-                                  false, /* bool disable_job_generation = false */
-                                  true,  /* bool remove_checkpt_file_before_server_start = true */
-                                  false  /* bool remove_checkpt_file_after_server_exit = true */
-        );
-        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-        BOOST_REQUIRE_MESSAGE(theClient.load(defs_to_be_check_pointed) == 0,
-                              "load defs failed \n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                              CtsApi::checkPtDefs() << " failed should\n"
-                                                    << theClient.errorMsg());
-    }
-
-    // start a new server, using same port. Make sure on start, we do not delete any checkpt files on start up
-    // server should *LOAD* check pt file on start up
-    InvokeServer invokeServer("", /* for debug use -new server- as msg */
-                              port,
-                              false, /* bool disable_job_generation = false */
-                              false, /* bool remove_checkpt_file_before_server_start = true */
-                              true   /* bool remove_checkpt_file_after_server_exit = true */
-    );
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Expected sync_local() to succeed \n");
-    BOOST_REQUIRE_MESSAGE(theClient.defs(), "Expected sync_local() to succeed defs is empty\n");
-
-    // To compare the defs, we need to massage theDefsFixture
-    // update server state to match server, and update flag, caused by restoreDefsFromCheckPt
-    defs_to_be_check_pointed->set_server().set_state(SState::HALTED);
-    defs_to_be_check_pointed->flag().set(ecf::Flag::MESSAGE);
-
-    // Specifically ignore server variables, as the port numbers are different( and therefore checkpt,log, etc will not
-    // match)
-    DebugEquality debug_equality; // only as affect in DEBUG build
-    DebugEquality::set_ignore_server_variables(true);
-
-    BOOST_CHECK_MESSAGE(*theClient.defs() == *defs_to_be_check_pointed,
-                        "expected defs to be the same.\nServer defs:\n"
-                            << *theClient.defs() << "\nExpected defs:\n"
-                            << *defs_to_be_check_pointed);
-}
-
-BOOST_AUTO_TEST_CASE(test_check_pt_edit_history) {
-    // This test relies on a NEW server invocation. Hence if ECF_HOST/remote server is used
-    // the test will will invalid. hence ignore.
-    if (!ClientEnvironment::hostSpecified().empty()) {
-        cout << "Client:: ...test_check_pt_edit_history: ignoring test when ECF_HOST specified\n";
-        return;
-    }
-
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-    InvokeServer invokeServer("Client:: ...test_check_pt_edit_history", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
-                          CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
-                                                                                    << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 0,
-                          "Expected edit history of size 0 after server start, but found "
-                              << theClient.server_reply().get_string_vec().size());
-
-    // make 5 edits
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
-                                                  << theClient.errorMsg());
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-
-    // make sure edit history updated
-    BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
-                          CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
-                                                                                    << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 5,
-                          "Expected edit history of size 5, but found "
-                              << theClient.server_reply().get_string_vec().size());
-
-    // make sure edit history was *NOT* serialized, It is only serialized when check pointing
-    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->get_edit_history(Str::ROOT_PATH()).size() == 0,
-                          "Expected edit history of size 0, but found "
-                              << theClient.defs()->get_edit_history(Str::ROOT_PATH()).size());
-
-    // This should write the edit history
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                          CtsApi::checkPtDefs() << " failed should return 0\n"
-                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
-                          CtsApi::checkPtDefs()
-                              << " failed No check pt file(" << invokeServer.ecf_checkpt_file() << ") saved");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
-                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
-                                                       << ") to have file size > 0  ");
-
-    // Create a defs file from the check pt file & check edit history
-    {
-        Defs defs;
-        defs.restore(invokeServer.ecf_checkpt_file()); // restore defs from checkpoint
-        BOOST_REQUIRE_MESSAGE(defs.get_edit_history(Str::ROOT_PATH()).size() == 5,
-                              "Expected edit history of size 5, but found "
-                                  << defs.get_edit_history(Str::ROOT_PATH()).size());
-    }
-
-    {
-        // clear edit history
-        BOOST_REQUIRE_MESSAGE(theClient.edit_history("clear") == 0,
-                              CtsApi::to_string(CtsApi::edit_history("clear")) << " should return 0\n"
-                                                                               << theClient.errorMsg());
-
-        // write checkpoint file, NOTE: theClient.checkPtDefs(ecf::CheckPt::ALWAYS) *ONLY* changes the mode.
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                              CtsApi::checkPtDefs() << " failed should return 0\n"
-                                                    << theClient.errorMsg());
-
-        // restore defs from checkpoint file
-        Defs defs;
-        defs.restore(invokeServer.ecf_checkpt_file()); // restore defs from checkpoint
-        BOOST_REQUIRE_MESSAGE(defs.get_edit_history().size() == 0,
-                              "Expected edit history of size 0, but found " << defs.get_edit_history().size());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestClientEnvironment.cpp 5.13.0-1/Client/test/TestClientEnvironment.cpp
--- 5.12.4-1/Client/test/TestClientEnvironment.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestClientEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,153 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-#include <vector>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_ClientEnvironment)
-
-// **************************************************************************************
-// test the client environment:
-// In particular test host file parsing
-// **************************************************************************************
-BOOST_AUTO_TEST_CASE(test_client_environment_host_file_parsing) {
-    std::cout << "Client:: ...test_client_environment_host_file_parsing" << endl;
-
-    std::string good_host_file = File::test_data("Client/test/data/good_hostfile", "Client");
-
-    // local host should be implicitly added to internal host list
-    std::string the_host = ClientEnvironment::hostSpecified();
-    if (the_host.empty())
-        the_host = Str::LOCALHOST();
-
-    std::vector<std::string> expectedHost;
-    expectedHost.push_back(the_host);
-    expectedHost.emplace_back("host1");
-    expectedHost.emplace_back("host2");
-    expectedHost.emplace_back("host3");
-    expectedHost.emplace_back("host4");
-    expectedHost.emplace_back("host5");
-    expectedHost.emplace_back("host6");
-
-    ClientEnvironment client_env(good_host_file);
-    //	cout << "client_env " << client_env.toString() << "\n";
-    std::string home_host = client_env.host();
-    std::string host;
-    //	cout << "client_env home host " << client_env.host() << " job supplied port " << client_env.port() << "\n";
-    size_t count = 0;
-    BOOST_CHECK_MESSAGE(home_host == expectedHost[count],
-                        "Expected home host " << expectedHost[count] << " but found " << home_host);
-
-    bool home_host_fnd = false;
-    while (home_host != host) {
-        // Cycle through the host until we reach the home host
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
-        //	   cout << "client_env host " << client_env.host() << "  port " << client_env.port() << "\n";
-        host = client_env.host();
-        count++;
-        if (host == home_host) {
-            home_host_fnd = true;
-            count         = 0;
-        }
-        BOOST_REQUIRE_MESSAGE(count < expectedHost.size(), "Test file out of date");
-        BOOST_CHECK_MESSAGE(host == expectedHost[count],
-                            "Expected host " << expectedHost[count] << " but found " << host);
-    }
-    BOOST_CHECK_MESSAGE(home_host_fnd, "Cycling through host file, should lead to home host");
-}
-
-BOOST_AUTO_TEST_CASE(test_client_environment_host_file_defaults) {
-    std::cout << "Client:: ...test_client_environment_host_file_defaults" << endl;
-
-    // When the HOST file does *NOT* indicate the port, it should be taken
-    // from the config/environment.
-    // In file good_hostfile, host3 and host5 do not specify a port, hence
-    // this port is assumed to be the job supplied port, that was read from
-    // config or environment. To test this correctly we need to specify a port
-    // other than the default
-
-    std::string good_host_file = File::test_data("Client/test/data/good_hostfile", "Client");
-
-    // local host should be implicitly added to internal host list
-    std::vector<std::pair<std::string, std::string>> expectedHost;
-    expectedHost.emplace_back(Str::LOCALHOST(), string("5111")); // here 5111 is job supplied port
-    expectedHost.emplace_back(string("host1"), string("3142"));
-    expectedHost.emplace_back(string("host2"), string("3141"));
-    expectedHost.emplace_back(string("host3"), string("5111")); // not specified in host file, hence expect 5111
-    expectedHost.emplace_back(string("host4"), string("4001"));
-    expectedHost.emplace_back(string("host5"), string("5111")); // not specified in host file, hence expect 5111
-    expectedHost.emplace_back(string("host6"), string("4081"));
-
-    // Create the ClientEnvironment overriding the config & environment. To specify host and port
-    ClientEnvironment client_env(good_host_file, Str::LOCALHOST(), "5111");
-    //   cout << "client_env " << client_env.toString() << "\n";
-    std::string home_host = client_env.host();
-    std::string home_port = client_env.port();
-    BOOST_CHECK_MESSAGE(Str::LOCALHOST() == home_host && "5111" == home_port, "host host & port not as expected");
-
-    std::string host;
-    //   cout << "client_env home host " << client_env.host() << "  job supplied port " << client_env.port() << "\n";
-    size_t count       = 0;
-    bool home_host_fnd = false;
-    while (home_host != host) {
-        // Cycle through the host until we reach the home host
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
-        //      cout << "client_env host " << client_env.host() << "  port " << client_env.port() << "\n";
-        host             = client_env.host();
-        std::string port = client_env.port();
-        count++;
-        if (host == home_host) {
-            BOOST_CHECK_MESSAGE(count - 1 == 6,
-                                "Expected 6 hosts in host file"); // ignore last increment of count, hence -1
-            home_host_fnd = true;
-            count         = 0;
-        }
-        BOOST_REQUIRE_MESSAGE(count < expectedHost.size(), "Test file out of date");
-        BOOST_CHECK_MESSAGE(host == expectedHost[count].first,
-                            "Expected host " << expectedHost[count].first << " but found " << host);
-        BOOST_CHECK_MESSAGE(port == expectedHost[count].second,
-                            "Expected port " << expectedHost[count].second << " but found " << port);
-    }
-    BOOST_CHECK_MESSAGE(home_host_fnd, "Cycling through host file, should lead to home host");
-}
-
-BOOST_AUTO_TEST_CASE(test_client_environment_empty_host_file) {
-    std::cout << "Client:: ...test_client_environment_empty_host_file" << endl;
-
-    std::string empty_host_file = File::test_data("Client/test/data/empty_hostfile", "Client");
-
-    std::string errormsg;
-    BOOST_CHECK_MESSAGE(File::create(empty_host_file, "", errormsg), "Failed to create empty host file " << errormsg);
-
-    ClientEnvironment client_env(empty_host_file);
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
-    BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
-
-    fs::remove(empty_host_file);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestClientHandleCmd.cpp 5.13.0-1/Client/test/TestClientHandleCmd.cpp
--- 5.12.4-1/Client/test/TestClientHandleCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,75 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/System.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_ClientHandleCmd)
-
-BOOST_AUTO_TEST_CASE(test_client_handle_cmd) {
-    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-    InvokeServer invokeServer("Client:: ...test_client_handle_cmd ", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    theClient.set_auto_sync(true);
-
-    std::vector<std::string> suites = {"s1", "s2"};
-    defs_ptr defs                   = Defs::create();
-    for (auto s : suites) {
-        defs->add_suite(s);
-    }
-
-    BOOST_REQUIRE_MESSAGE(theClient.load(defs) == 0, "load defs failed \n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "load failed");
-
-    BOOST_REQUIRE_MESSAGE(theClient.ch1_register(true, suites) == 0, "ch1_register failed\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "register group sync failed");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 1, " ch1_register failed expected handle 1");
-
-    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0, "delete_all failed\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == 0, "delete all failed");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 0,
-                          "delete all failed expected handle 0 but found " << theClient.server_reply().client_handle());
-
-    // repeat test without auto_sync
-    theClient.set_auto_sync(false);
-    BOOST_REQUIRE_MESSAGE(theClient.load(defs) == 0, "load defs failed \n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "load failed");
-
-    BOOST_REQUIRE_MESSAGE(theClient.ch1_register(true, suites) == 0, "ch1_register failed\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "register group sync failed");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 1, " ch1_register failed expected handle 1");
-
-    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0, "delete_all failed\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == 0, "delete all failed");
-    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 0,
-                          "delete all failed expected handle 0 but found " << theClient.server_reply().client_handle());
-
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestClientInterface.cpp 5.13.0-1/Client/test/TestClientInterface.cpp
--- 5.12.4-1/Client/test/TestClientInterface.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestClientInterface.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1577 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-#include <vector>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/base/cts/user/CFileCmd.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_ClientInterface)
-
-// **************************************************************************************
-// test the interface, this will create the cmd without actually submitting to the server
-// This will test argument parsing.
-// **************************************************************************************
-BOOST_AUTO_TEST_CASE(test_client_interface) {
-    std::cout << "Client:: ...test_client_interface" << endl;
-
-    ClientInvoker theClient;
-    theClient.testInterface(); // stops submission to server
-    std::vector<std::string> paths;
-    paths.emplace_back("/s1/t1");
-    paths.emplace_back("/s2/t2");
-
-    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.terminateServer() == 0,
-                          CtsApi::terminateServer() << " should return 0\n"
-                                                    << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.server_version() == 0,
-                          CtsApi::server_version() << " should return 0\n"
-                                                   << theClient.errorMsg());
-
-    {
-        defs_ptr dummy_defs = Defs::create();
-        BOOST_REQUIRE_MESSAGE(theClient.sync(dummy_defs) == 0,
-                              std::string(CtsApi::syncArg()) << " should return 0\n"
-                                                             << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.news(dummy_defs) == 0,
-                              std::string(CtsApi::newsArg()) << " should return 0\n"
-                                                             << theClient.errorMsg());
-    }
-
-    BOOST_REQUIRE_MESSAGE(theClient.server_load("/path/to_log/file") == 0,
-                          CtsApi::server_load("/path/to_log/file") << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.server_load() == 0,
-                          CtsApi::server_load("") << " should return 0\n"
-                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.pingServer() == 0,
-                          CtsApi::pingServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.debug_server_on() == 0,
-                          CtsApi::debug_server_on() << " should return 0\n"
-                                                    << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.debug_server_off() == 0,
-                          CtsApi::debug_server_off() << " should return 0\n"
-                                                     << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats() == 0, CtsApi::stats() << " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                          CtsApi::stats_server() << " should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.stats_reset() == 0,
-                          CtsApi::stats_reset() << " should return 0\n"
-                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.suites() == 0, CtsApi::suites() << " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0, CtsApi::get() << " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.begin("/suite") == 0,
-                          CtsApi::begin("/suite") << " should return 0\n"
-                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.begin("/suite", true) == 0,
-                          CtsApi::begin("/suite", true) << " should return 0\n"
-                                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.begin("/suite", false) == 0,
-                          CtsApi::begin("/suite", false) << " should return 0\n"
-                                                         << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.begin_all_suites() == 0,
-                          CtsApi::begin() << " should return 0\n"
-                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "next") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "prev") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("event", "/suite", "event") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("meter", "/suite", "meter") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("variable", "/suite", "var") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("trigger", "/suite", "1 == 1") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("state", "/suite", "") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("dstate", "/suite", "") == 0,
-                          CtsApi::queryArg() << " should return 0\n"
-                                             << theClient.errorMsg());
-
-    Zombie z(Child::USER,
-             ecf::Child::INIT,
-             ZombieAttr::get_default_attr(Child::USER),
-             "/path/to/task",
-             "DUMMY_JOBS_PASSWORD",
-             "DUMMY_PROCESS_OR_REMOTE_ID",
-             1,
-             "host");
-    BOOST_REQUIRE_MESSAGE(theClient.zombieGet() == 0,
-                          CtsApi::zombieGet() << " should return 0\n"
-                                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieFob(z) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieFail(z) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieAdopt(z) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieBlock(z) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieRemove(z) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieKill(z) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieFobCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieFailCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieAdoptCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieBlockCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieRemoveCli("/path/to/task") == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieKillCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieFobCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieFailCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieAdoptCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieBlockCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieRemoveCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.zombieKillCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.job_gen("") == 0,
-                          CtsApi::job_gen("") << " should return 0\n"
-                                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.job_gen("/s") == 0,
-                          CtsApi::job_gen("/s") << " should return 0\n"
-                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.check("") == 0,
-                          CtsApi::to_string(CtsApi::check("")) << " should return 0\n"
-                                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.check("/") == 0,
-                          CtsApi::to_string(CtsApi::check("/")) << " should return 0\n"
-                                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.check("_all_") == 0,
-                          CtsApi::to_string(CtsApi::check("_all_")) << " should return 0\n"
-                                                                    << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.check("/s") == 0,
-                          CtsApi::to_string(CtsApi::check("/s")) << " should return 0\n"
-                                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.check(paths) == 0,
-                          CtsApi::to_string(CtsApi::check(paths)) << " should return 0\n"
-                                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.kill("/s") == 0,
-                          CtsApi::to_string(CtsApi::kill("/s")) << " should return 0\n"
-                                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.kill(paths) == 0,
-                          CtsApi::to_string(CtsApi::kill(paths)) << " should return 0\n"
-                                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.status("/s") == 0,
-                          CtsApi::to_string(CtsApi::status("/s")) << " should return 0\n"
-                                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.status(paths) == 0,
-                          CtsApi::to_string(CtsApi::status(paths)) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.suspend("/s") == 0,
-                          CtsApi::to_string(CtsApi::suspend("/s")) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.suspend(paths) == 0,
-                          CtsApi::to_string(CtsApi::suspend(paths)) << " should return 0\n"
-                                                                    << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.resume("/s") == 0,
-                          CtsApi::to_string(CtsApi::resume("/s")) << " should return 0\n"
-                                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.resume(paths) == 0,
-                          CtsApi::to_string(CtsApi::resume(paths)) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.edit_history("/s") == 0,
-                          CtsApi::to_string(CtsApi::edit_history("/s")) << " should return 0\n"
-                                                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.edit_history("clear") == 0,
-                          CtsApi::to_string(CtsApi::edit_history("clear")) << " should return 0\n"
-                                                                           << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.archive("/s") == 0,
-                          CtsApi::to_string(CtsApi::archive("/s")) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.archive(paths) == 0,
-                          CtsApi::to_string(CtsApi::archive(paths)) << " should return 0\n"
-                                                                    << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.archive("/s", true) == 0,
-                          CtsApi::to_string(CtsApi::archive("/s", true)) << " should return 0\n"
-                                                                         << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.archive(paths, true) == 0,
-                          CtsApi::to_string(CtsApi::archive(paths, true)) << " should return 0\n"
-                                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restore("/s") == 0,
-                          CtsApi::to_string(CtsApi::restore("/s")) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restore(paths) == 0,
-                          CtsApi::to_string(CtsApi::restore(paths)) << " should return 0\n"
-                                                                    << theClient.errorMsg());
-
-    // empty string should be same as delete all
-    BOOST_REQUIRE_MESSAGE(theClient.delete_node("") == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_node("_all_") == 0,
-                          CtsApi::to_string(CtsApi::delete_node("_all")) << " should return 0\n"
-                                                                         << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_node("_all_", true) == 0,
-                          CtsApi::to_string(CtsApi::delete_node("_all", true)) << " should return 0\n"
-                                                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_node("_all_", false) == 0,
-                          CtsApi::to_string(CtsApi::delete_node("_all", false)) << " should return 0\n"
-                                                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_node("/s") == 0,
-                          CtsApi::to_string(CtsApi::delete_node("/s")) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_node("/s", true) == 0,
-                          CtsApi::to_string(CtsApi::delete_node("/s", true)) << " should return 0\n"
-                                                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_node("/s", false) == 0,
-                          CtsApi::to_string(CtsApi::delete_node("/s", false)) << " should return 0\n"
-                                                                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_nodes(paths, false) == 0,
-                          CtsApi::to_string(CtsApi::delete_node(paths, false)) << " should return 0\n"
-                                                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_nodes(paths, true) == 0,
-                          CtsApi::to_string(CtsApi::delete_node(paths, false)) << " should return 0\n"
-                                                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.requeue("/s", "") == 0,
-                          CtsApi::to_string(CtsApi::requeue("/s", "")) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.requeue("/s", "force") == 0,
-                          CtsApi::to_string(CtsApi::requeue("/s", "force")) << " should return 0\n"
-                                                                            << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.requeue("/s", "abort") == 0,
-                          CtsApi::to_string(CtsApi::requeue("/s", "abort")) << " should return 0\n"
-                                                                            << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.requeue(paths, "") == 0,
-                          CtsApi::to_string(CtsApi::requeue(paths, "")) << " should return 0\n"
-                                                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.requeue(paths, "force") == 0,
-                          CtsApi::to_string(CtsApi::requeue(paths, "force")) << " should return 0\n"
-                                                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.requeue(paths, "abort") == 0,
-                          CtsApi::to_string(CtsApi::requeue(paths, "abort")) << " should return 0\n"
-                                                                             << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.run("/s") == 0,
-                          CtsApi::to_string(CtsApi::run("/s")) << " should return 0\n"
-                                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.run("/s", true) == 0,
-                          CtsApi::to_string(CtsApi::run("/s", true)) << " should return 0\n"
-                                                                     << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.run(paths) == 0,
-                          CtsApi::to_string(CtsApi::run(paths)) << " should return 0\n"
-                                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.run(paths, true) == 0,
-                          CtsApi::to_string(CtsApi::run(paths, true)) << " should return 0\n"
-                                                                      << theClient.errorMsg());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, true /*force*/) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, true /*force*/, true /*check_only*/) == 0,
-                          "should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true, true) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, false, true) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "top") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "bottom") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "alpha") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "order") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "up") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "down") == 0, " should return 0\n" << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                          CtsApi::checkPtDefs() << " should return 0\n"
-                                                << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::NEVER) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, 180) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ALWAYS) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 0, 35) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restoreDefsFromCheckPt() == 0,
-                          CtsApi::restoreDefsFromCheckPt() << " should return 0\n"
-                                                           << theClient.errorMsg());
-
-    std::vector<std::string> event_paths;
-    event_paths.emplace_back("/s1:e");
-    event_paths.emplace_back("/s2/f1/t1:e");
-    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths[0], "set") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths[1], "clear") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths, "set") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths, "clear") == 0, " should return 0\n" << theClient.errorMsg());
-    std::vector<std::string> validStates = NState::allStates(); // HPUX barfs if use NState::allStates() directly
-    for (const string& state : validStates) {
-        BOOST_REQUIRE_MESSAGE(theClient.force("/s", state, true, true) == 0,
-                              "force " << state << " should return 0\n"
-                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force(paths, state, true, true) == 0,
-                              "force " << state << " should return 0\n"
-                                       << theClient.errorMsg());
-    }
-
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s") == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", true, true, true, true) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", true) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", false, true) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", false, false, true) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", false, false, false, true) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep(paths) == 0, " should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.freeDep(paths, true, true, true, true) == 0,
-                          " should return 0\n"
-                              << theClient.errorMsg());
-
-    std::vector<CFileCmd::File_t> fileTypesVec = CFileCmd::fileTypesVec();
-    for (auto& i : fileTypesVec) {
-        BOOST_REQUIRE_MESSAGE(theClient.file("/s", CFileCmd::toString(i), string("100")) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-    }
-
-    BOOST_REQUIRE_MESSAGE(theClient.plug("/source", "/dest") == 0, " should return 0\n" << theClient.errorMsg());
-
-    {
-        BOOST_REQUIRE_MESSAGE(theClient.getLog(10) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.clearLog() == 0,
-                              CtsApi::clearLog() << " should return 0\n"
-                                                 << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.flushLog() == 0,
-                              CtsApi::flushLog() << " should return 0\n"
-                                                 << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.get_log_path() == 0,
-                              CtsApi::get_log_path() << " should return 0\n"
-                                                     << theClient.errorMsg());
-
-        std::string new_log_path = File::test_data("Client/test/data/new_log.log", "Client");
-        BOOST_REQUIRE_MESSAGE(theClient.new_log(new_log_path) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.new_log("") == 0, " should return 0\n" << theClient.errorMsg());
-    }
-
-    BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
-                          CtsApi::reloadwsfile() << " should return 0\n"
-                                                 << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                          CtsApi::forceDependencyEval() << " should return 0\n"
-                                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.group("shutdown yes;halt yes;restart") == 0,
-                          "--group should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.group("shutdown=yes;halt=yes;restart") == 0,
-                          "--group should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show") == 0, "--group should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show state") == 0,
-                          "--group should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show defs") == 0, "--group should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show migrate") == 0,
-                          "--group should return 0\n"
-                              << theClient.errorMsg());
-
-    {
-        std::string path_to_script = "dummy_ecf_file" + File::ECF_EXTN();
-        std::string contents       = "%comment\n"
-                                     "VAR =  fred\n"
-                                     "%end\n"
-                                     "# rest of the ecf file\n";
-        std::string error_msg;
-        BOOST_CHECK_MESSAGE(File::create(path_to_script, contents, error_msg), error_msg);
-
-        std::vector<std::string> file_contents;
-        NameValueVec used_variables;
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script_edit("/s") == 0,
-                              "--edit_script_edit should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script_preprocess("/s") == 0,
-                              "--edit_script_preprocess should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script_preprocess("/s", file_contents) == 0,
-                              "--edit_script_preprocess should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script_submit("/s", used_variables) == 0,
-                              "--edit_script_submit should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script_submit("/s", used_variables, file_contents) == 0,
-                              "--edit_script_submit should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script_submit("/s", used_variables, file_contents, true /*alias*/) == 0,
-                              "--edit_script_submit should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(
-            theClient.edit_script_submit("/s", used_variables, file_contents, true /*alias*/, true /*run*/) == 0,
-            "--edit_script_submit should return 0\n"
-                << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "edit") == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "pre_process") == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit", path_to_script) == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script) == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, true) == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, false) == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, false, true) == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, false, false) == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "pre_process_file", path_to_script) == 0,
-                              "--edit_script should return 0\n"
-                                  << theClient.errorMsg());
-        fs::remove(path_to_script);
-    }
-
-    {
-        std::vector<std::string> suites;
-        suites.emplace_back("a");
-        suites.emplace_back("b");
-        BOOST_REQUIRE_MESSAGE(theClient.ch_register(true, suites) == 0, "--ch_register \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_register(false, suites) == 0, "--ch_register \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_suites() == 0, "--ch_suites should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_drop(1) == 0, "--ch_drop should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_drop_user("user") == 0,
-                              "--ch_drop_user should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_add(1, suites) == 0, "--ch_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_remove(1, suites) == 0, "--ch_remove \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, true) == 0, "--ch_auto_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, false) == 0, "--ch_auto_add \n" << theClient.errorMsg());
-
-        // need test interface that allows client handle to set on ClinetInvoker
-        // ch1_add needs a non zero handle
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_register(true, suites) == 0, "--ch1_drop \n" << theClient.errorMsg());
-        auto& svr = const_cast<ServerReply&>(theClient.server_reply());
-        svr.set_client_handle(1);
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_drop() == 0, "--ch1_drop \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_add(suites) == 0, "--ch1_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_remove(suites) == 0, "--ch1_remove \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(true) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(false) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
-    }
-
-    {
-        defs_ptr theDefs = Defs::create();
-        theDefs->addSuite(Suite::create("s1"));
-        BOOST_REQUIRE_MESSAGE(theClient.load(theDefs) == 0, "-- load should return 0\n" << theClient.errorMsg());
-    }
-
-    /// test alter
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:fob::10") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:fob::") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf_pid:fob::") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf_passwd:fob::") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf_pid_passwd:fob::") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "user:fob::10") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "path:fob::10") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "path:fob::") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter(
-                              "/s1", "add", "zombie", "ecf:fob:init,event,meter,label,wait,complete,abort:10") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:fob:init,event,meter,label,wait,complete:10") ==
-                              0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter(
-                              "/s1", "add", "zombie", "ecf:fail:init,event,meter,label,wait,complete:10000") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter(
-                              "/s1", "add", "zombie", "ecf:adopt:init,event,meter,label,wait,complete:23") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter(
-                              "/s1", "add", "zombie", "ecf:remove:init,event,meter,label,wait,complete:0") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:block:init,event,meter,label,wait,complete:") ==
-                              0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter(
-                              "/s1", "add", "zombie", "ecf:kill:init,event,meter,label,wait,complete:103333333") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+12:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:00 20:00 00:30") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "12:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "10:00 20:00 00:30") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.12.2009") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*.12.2009") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*.*.2009") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*.*.*") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "-") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "--") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "-- --") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "--fred") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "--fred --bill") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "value") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "/value/with/path") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "name", "value") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "name", "/value/with/path2") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s +00:15 -a 20:00 -c +02:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -a 20:00 -c +02:00 -s +00:15") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -c +02:00 -a 20:00  -s +00:15") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s 00:02 -c +00:05") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s 00:01 -a 14:30 -c +00:01") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s +00:15 -a 20:00 -c +02:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-a 20:00 -c +02:00 -s +00:15") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-c +02:00 -a 20:00  -s +00:15") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s 00:02 -c +00:05") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s 00:01 -a 14:30 -c +00:01") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "limit", "limit_name", "10") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "limit_name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "limit_name", "10") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "/path/to/limit:limit_name2") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "/path/to/limit:limit_name2", "10") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "label", "name", "value") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "label", "name", "/value/with/paths") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-
-    for (const string& day : DayAttr::allDays()) {
-        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", day) == 0,
-                              "--alter should return 0\n"
-                                  << theClient.errorMsg());
-    }
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "variable") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "variable", "varName") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "variable", "varName", "/var/with/path/for/delete") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "variable") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "variable", "varName") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "variable", "varName", "/s1/with/path/for/delete") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+12:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:00 20:00 00:30") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "12:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "10:00 20:00 00:30") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.12.2009") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*.12.2009") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*.*.2009") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*.*.*") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day", "sunday") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "23:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "10:00 20:00 01:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0,1 10:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 10,11,12 12:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 10:00 20:00 01:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "1") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "meter", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "meter") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "trigger") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "complete") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "repeat") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit_path", "limit_name", "path") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit_path", "limit_name", "/path/with/slash") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "inlimit", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "zombie", "user") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "zombie", "ecf") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "zombie", "path") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "late") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "label", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "variable", "name", "newValue") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "variable", "name", "/new/value/with/path") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "variable", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "hybrid") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "real") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "12.6.2013") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "20") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_sync") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "22", "set") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "33", "clear") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "4") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name", "set") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name", "clear") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "20") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "-1") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "name", "newValue") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "name", "/value/with/path/ECFLOW-480") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "name", "") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "(t:step + 20) ge (t:step1 - 20)") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "/suite/fred == complete") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "/suite/fred:event") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "not ( a == complete )") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "/trigger/with/leading/slash == aborted") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "/trigger/with/leading/slash:event") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "repeat", "1") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "repeat", "blue") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_max", "limit_name", "12") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_value", "limit_name", "12") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s +00:15 -a 20:00 -c +02:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s 00:02 -c +00:05") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s 00:01 -a 14:30 -c +00:01") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a 20:00 -c +02:00") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-a 20:00 -c +02:00 -s +00:15") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-c +02:00 -a 20:00  -s +00:15") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-
-    std::vector<std::string> dstates = DState::allStates();
-    for (const auto& dstate : dstates) {
-        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "defstatus", dstate) == 0,
-                              "--alter should return 0\n"
-                                  << theClient.errorMsg());
-    }
-
-    std::vector<std::string> flag_types;
-    Flag::valid_flag_type(flag_types);
-    for (const auto& flag_type : flag_types) {
-        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "set_flag", flag_type) == 0,
-                              "--alter should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "clear_flag", flag_type) == 0,
-                              "--alter should return 0\n"
-                                  << theClient.errorMsg());
-    }
-
-    // sort
-    std::vector<std::string> sortable_attributes = Attr::all_attrs();
-    BOOST_REQUIRE_MESSAGE(!sortable_attributes.empty(), "Expected to find attributes");
-    for (const auto& sortable_attribute : sortable_attributes) {
-        BOOST_REQUIRE_MESSAGE(theClient.alter_sort("/s1", sortable_attribute, true) == 0,
-                              "--alter should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.alter_sort("/s1", sortable_attribute, false) == 0,
-                              "--alter should return 0\n"
-                                  << theClient.errorMsg());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_client_interface_for_fail) {
-    std::cout << "Client:: ...test_client_interface_for_fail" << endl;
-
-    ClientInvoker theClient;
-    theClient.testInterface(); // stops submission to server
-    theClient.set_throw_on_error(false);
-
-    std::vector<std::string> paths;
-    paths.emplace_back("/s1");
-    paths.emplace_back("/s2");
-
-    BOOST_REQUIRE_MESSAGE(theClient.check("fred") == 1,
-                          CtsApi::to_string(CtsApi::check("fred")) << " should return 1\n"
-                                                                   << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "deleted", "label", "name") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "changed", "late", "-c +02:00 -a 20:00  -s +00:15") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "added", "label", "name", "/value/with/paths") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    /// test alter
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "012:00") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "1200") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "fred") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:0020:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:00 2000 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+1000 20:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:00 20:00 0030") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "any old rubbish") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+10:0020:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+10:00 2000 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+1000 20:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+10:00 20:00 0030") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "any old rubbish") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "0.12.2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.0.2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.12.g") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*..2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12..2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.12.") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "fred") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "any old rubbish") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", "frenday") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", "opps ") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "na me", "value") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "na me", "value") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "", "value") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -a") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -c") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s +00:15 -a") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s +00:15 -a 20:00 -c") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-a") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-c") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s +00:15 -a") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s +00:15 -a 20:00 -c") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-c +02:000 -a 20:00  -s +00:15") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "label", " 1 2") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "vari able", "varName") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "v ariable", "varName") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "l able", "name") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "label", "na me") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "012:00") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "1200") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "fred") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:0020:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:00 2000 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+1000 20:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:00 20:00 0030") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "any old rubbish") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+10:0020:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+10:00 2000 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+1000 20:00 00:30") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+10:00 20:00 0030") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "any old rubbish") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "0.12.2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.0.2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.12.g") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*..2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12..2009") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.12.") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "fred") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "any old rubbish") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day", "su nday") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day", "fryday") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "any old rubbish") == 1,
-                          "Expected fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "2300") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "1000 20:00 01:00") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0,1 1000'") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 1000") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 10,11,12 1200") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 10,11,12") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 1200") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 10:00 20:00 01:000") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 10:00 20:00 0100") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w -m 20:00 01:00") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 1000 20:00 01:00") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 20 -m 5,6,7,8 10:00 20:00 01:00") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8,24 10:00 20:00 01:00") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "name df") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "22  56  ") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "meter", "na me") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit", " name") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "inlimit", "na me") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "vari able", "name", "newValue") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "", "name", "/new/value/with/path") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "hyb rid") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "hybrid ") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "ybrid") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "re al") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "rreal") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "*.6.2013") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "12.0.2013") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "any old rubbish") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "string") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "fred") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name", "fr ed") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "na me") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "na me", "20") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "-") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "na me", "newValue") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "t:step + 20) ge (t:step1 - 20)") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "not  a == complete )") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_max", "limit_  name", "12") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_value", "limit_  name", "12") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "defstatus", "complete-34") == 1,
-                          "--alter expected to fail\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -a") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -c") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a 20:00 -c") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a 20:00 -c") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:152") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-c +00:152") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-a +00:152") == 1,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.query("event", "/suite", "") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("meter", "/suite", "") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("variable", "/suite", "") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("trigger", "/suite", "") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("event", "", "event") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("meter", "", "meter") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("variable", "", "var") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("trigger", "", "1 == 1") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("xxxx", "/suite", "1 == 1") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("", "/suite", "1 == 1") == 1,
-                          std::string(CtsApi::queryArg()) << " should return 0\n"
-                                                          << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "xx") == 1,
-                          CtsApi::queryArg() << " should return 1\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "nextyyy") == 1,
-                          CtsApi::queryArg() << " should return 1\n"
-                                             << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "prevyyy") == 1,
-                          CtsApi::queryArg() << " should return 1\n"
-                                             << theClient.errorMsg());
-}
-
-BOOST_AUTO_TEST_CASE(test_client_task_interface) {
-    std::cout << "Client:: ...test_client_task_interface" << endl;
-
-    ClientInvoker theClient;
-    theClient.testInterface(); // stops submission to server
-    theClient.taskPath("/a/made/up/path");
-    theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
-
-    BOOST_REQUIRE_MESSAGE(theClient.initTask(Submittable::DUMMY_PROCESS_OR_REMOTE_ID()) == 0,
-                          "--init should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.abortTask("reason for abort") == 0,
-                          "--abort should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.eventTask("event_name", "set") == 0,
-                          "--event should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.eventTask("event_name", "clear") == 0,
-                          "--event should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.meterTask("meter_name", "20") == 0,
-                          "--meter should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.waitTask("a == complete") == 0, "--wait should return 0\n" << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "active") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "complete", "4") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "aborted", "4") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "no_of_aborted") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "reset") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "active", "", "/path/to/node/with/queue") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "complete", "4", "/path/to/node/with/queue") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "aborted", "4", "/path/to/node/with/queue") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "no_of_aborted", "", "/path/to/node/with/queue") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "reset", "", "/path/to/node/with/queue") == 0,
-                          "--queue should return 0\n"
-                              << theClient.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0, "--complete should return 0\n" << theClient.errorMsg());
-    std::vector<std::string> labels;
-    labels.emplace_back("test_client_task_interface");
-    BOOST_REQUIRE_MESSAGE(theClient.labelTask("label_name", labels) == 0,
-                          "--label should return 0\n"
-                              << theClient.errorMsg());
-}
-
-BOOST_AUTO_TEST_CASE(test_client_task_interface_for_fail) {
-    std::cout << "Client:: ...test_client_task_interface_for_fail" << endl;
-
-    {
-        ClientInvoker theClient;
-        theClient.testInterface(); // stops submission to server
-        theClient.taskPath("/a/made/up/path");
-        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
-        BOOST_REQUIRE_THROW(theClient.waitTask("a == "),
-                            std::runtime_error); //  --wait with a bad expression 'a == ' should fail
-    }
-    { // No Jobs password expect exception.
-        ClientInvoker theClient;
-        theClient.testInterface(); // stops submission to server
-        theClient.taskPath("/a/made/up/path");
-        theClient.set_jobs_password(
-            ""); // The password(ECF_PASS) will be READ from the environment. Hence set to empty here
-
-        BOOST_REQUIRE_THROW(theClient.initTask(Submittable::DUMMY_PROCESS_OR_REMOTE_ID()), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.abortTask("reason for abort"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.eventTask("event_name"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.meterTask("meter_name", "20"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.waitTask("a == complete"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.completeTask(), std::runtime_error);
-        std::vector<std::string> labels;
-        labels.emplace_back("test_client_task_interface");
-        BOOST_REQUIRE_THROW(theClient.labelTask("label_name", labels), std::runtime_error);
-    }
-    {
-        ClientInvoker theClient;
-        theClient.testInterface(); // stops submission to server
-        theClient.taskPath("/a/made/up/path");
-        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
-
-        BOOST_REQUIRE_THROW(theClient.eventTask("", "set"), std::runtime_error);   // event name is empty
-        BOOST_REQUIRE_THROW(theClient.eventTask("event", ""), std::runtime_error); // value is empty must be set | clear
-        BOOST_REQUIRE_THROW(theClient.eventTask("event", "true"), std::runtime_error);  // value must be set | clear
-        BOOST_REQUIRE_THROW(theClient.eventTask("event", "false"), std::runtime_error); // value must be set | clear
-        BOOST_REQUIRE_THROW(theClient.meterTask("", "20"), std::runtime_error);         // meter name is empty
-        BOOST_REQUIRE_THROW(theClient.meterTask("meter", ""), std::runtime_error);      // meter value is empty
-        BOOST_REQUIRE_THROW(theClient.meterTask("meter", "fred"),
-                            std::runtime_error); // meter value not convertible to an integer
-    }
-    { // No task path set expect exception
-        ClientInvoker theClient;
-        theClient.testInterface(); // stops submission to server
-        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
-        theClient.taskPath(""); // The task path(ECF_NAME) could read from the environment, hence clear here.
-
-        BOOST_REQUIRE_THROW(theClient.initTask(Submittable::DUMMY_PROCESS_OR_REMOTE_ID()), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.abortTask("reason for abort"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.eventTask("event_name"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.meterTask("meter_name", "20"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.waitTask("a == complete"), std::runtime_error);
-        BOOST_REQUIRE_THROW(theClient.completeTask(), std::runtime_error);
-        std::vector<std::string> labels;
-        labels.emplace_back("test_client_task_interface");
-        BOOST_REQUIRE_THROW(theClient.labelTask("label_name", labels), std::runtime_error);
-    }
-    { // test bad queue
-        ClientInvoker theClient;
-        theClient.testInterface(); // stops submission to server
-        theClient.taskPath("/a/made/up/path");
-        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
-
-        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "fred"), std::runtime_error); // unknown action
-        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "active", "", "should be path"),
-                            std::runtime_error);                                           // bad path no '/'
-        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "complete"), std::runtime_error); // no step specified
-        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "complete", "3", "path"), std::runtime_error); // bad path
-        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "aborted"), std::runtime_error); // no step specified
-        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "aborted", "3", "path"), std::runtime_error); // bad path
-        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "reset", "", "no path"),
-                            std::runtime_error); //  bad path no '/'
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestClientOptions.cpp 5.13.0-1/Client/test/TestClientOptions.cpp
--- 5.12.4-1/Client/test/TestClientOptions.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestClientOptions.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1347 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/base/cts/task/AbortCmd.hpp"
-#include "ecflow/base/cts/task/CompleteCmd.hpp"
-#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
-#include "ecflow/base/cts/task/EventCmd.hpp"
-#include "ecflow/base/cts/task/InitCmd.hpp"
-#include "ecflow/base/cts/task/LabelCmd.hpp"
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-#include "ecflow/base/cts/task/QueueCmd.hpp"
-#include "ecflow/base/cts/user/AlterCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/PathsCmd.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/client/ClientOptions.hpp"
-#include "ecflow/core/CommandLine.hpp"
-#include "ecflow/core/PasswordEncryption.hpp"
-
-///
-/// \brief Tests the capabilities of ClientOptions
-///
-
-template <typename COMMAND, typename REQUIRE>
-void test_user_command(const CommandLine& cl, REQUIRE check) {
-    std::cout << "Testing command line: " << cl.original() << std::endl;
-
-    ClientOptions options;
-    ClientEnvironment environment(false);
-    try {
-        auto base_command    = options.parse(cl, &environment);
-        auto derived_command = dynamic_cast<COMMAND*>(base_command.get());
-
-        BOOST_REQUIRE(derived_command);
-        check(*derived_command, environment);
-    }
-    catch (boost::program_options::unknown_option& e) {
-        BOOST_CHECK_MESSAGE(false, std::string("Unexpected exception caught: ") + e.what());
-    }
-}
-
-template <typename COMMAND, typename REQUIRE>
-void test_task_command(const CommandLine& cl, REQUIRE check) {
-    std::cout << "Testing command line: " << cl.original() << std::endl;
-
-    ClientOptions options;
-    ClientEnvironment environment(false);
-    // Setup environment with some defaults
-    environment.set_child_path("/path/to/child");
-    environment.set_child_password("password");
-    try {
-        auto base_command    = options.parse(cl, &environment);
-        auto derived_command = dynamic_cast<COMMAND*>(base_command.get());
-
-        BOOST_REQUIRE(derived_command);
-        check(*derived_command, environment);
-    }
-    catch (boost::program_options::unknown_option& e) {
-        BOOST_CHECK_MESSAGE(false, std::string("Unexpected exception caught: ") + e.what());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_ClientOptions)
-
-BOOST_AUTO_TEST_SUITE(T_Generic) // test generic options
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_process_username_and_password) {
-    const char* expected_username = "username";
-    const char* plain_password    = "password";
-    std::string expected_password = PasswordEncryption::encrypt(plain_password, expected_username);
-
-    // Make command line
-    auto cl = CommandLine::make_command_line(
-        "ecflow_client", "--user", expected_username, "--password", plain_password, "--ping");
-
-    ClientOptions options;
-    ClientEnvironment environment(false);
-    options.parse(cl, &environment);
-
-    std::string actual_username = environment.get_user_name();
-    BOOST_REQUIRE(expected_username == actual_username);
-
-    std::string actual_password = environment.get_user_password(expected_username);
-    BOOST_REQUIRE(expected_password == actual_password);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Abort) // --abort (AbortCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_abort) {
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=somereason");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "somereason");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort", "some reason with spaces");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "some reason with spaces");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=some reason with spaces ");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "some reason with spaces ");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=some", "reason");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "some"); // Important: the reason is only "some"!
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=--dashed reason");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "--dashed reason");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort", "--dashed reason");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "--dashed reason");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--abort", "--dashed reason", "--debug");
-        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.reason(), "--dashed reason");
-            BOOST_CHECK(env.debug());
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Alter) // --alter (AlterCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_handle_alter_change) {
-
-    /*
-     * --alter change <type> <name> <value> <path> [<path>...]
-     * ************************************************************************************************************** */
-
-    std::vector<std::vector<std::string>> paths_set = {
-        {"/node1"}, {"/node1", "/node2"}, {"/node1", "/node2", "/node3"}};
-
-    for (const auto& paths : paths_set) {
-
-        using Expected = AlterCmd::Change_attr_type;
-
-        /*
-         * --alter change variable <name> <value> <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-
-        std::vector<std::string> variable_values = {"",
-                                                    "--dashes at beginning of value",
-                                                    "a value with --dashes inside",
-                                                    "    value starting with spaces",
-                                                    "value ending with spaces      ",
-                                                    "   some value surrounded by spaces      ",
-                                                    "/some/valid/path"};
-
-        for (const auto& value : variable_values) {
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "change", "variable", "name", value, paths);
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::VARIABLE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "change", "variable", "name", value, paths, "--debug");
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::VARIABLE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), true);
-                });
-            }
-        }
-
-        /*
-         * --alter change label <name> <value> <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        std::vector<std::string> label_values = {"",
-                                                 "--dashes at beginning of value",
-                                                 "a value with --dashes inside",
-                                                 "    value starting with spaces",
-                                                 "value ending with spaces      ",
-                                                 "   some value surrounded by spaces      ",
-                                                 "/some/valid/path"};
-
-        for (const auto& value : label_values) {
-            {
-                auto cl =
-                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "label", "name", value, paths);
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LABEL);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "change", "label", "name", value, paths, "--debug");
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LABEL);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), true);
-                });
-            }
-        }
-
-        /*
-         * --alter change event <name> <value> <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        // No value provided
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "change", "event", "name", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl =
-                CommandLine::make_command_line("ecflow_client", "--alter", "change", "event", "name", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-        // Explicitly provided value
-        std::vector<std::string> event_values = {"set", "clear"};
-        for (const auto& value : event_values) {
-            {
-                auto cl =
-                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "event", "name", value, paths);
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "change", "event", "name", value, paths, "--debug");
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), true);
-                });
-            }
-        }
-
-        /*
-         * --alter change meter <name> <value> <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        std::vector<std::string> meter_values = {"0", "100"};
-        for (const auto& value : meter_values) {
-            {
-                auto cl =
-                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "meter", "name", value, paths);
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::METER);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "change", "meter", "name", value, paths, "--debug");
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::METER);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), true);
-                });
-            }
-        }
-
-        /*
-         * --alter change clock_type ( hybrid | real ) <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        std::vector<std::string> clock_type_values = {"hybrid", "real"};
-        for (const auto& value : clock_type_values) {
-            {
-                auto cl =
-                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_type", value, paths);
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), value);
-                    BOOST_REQUIRE_EQUAL(command.value(), "");
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_TYPE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "change", "clock_type", value, paths, "--port", "1234");
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), value);
-                    BOOST_REQUIRE_EQUAL(command.value(), "");
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_TYPE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "1234");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-        }
-
-        /*
-         * --alter change clock_gain <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        {
-            auto cl =
-                CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_gain", "2023.01.01", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "2023.01.01");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_GAIN);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line(
-                "ecflow_client", "--alter", "change", "clock_gain", "2023.01.01", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "2023.01.01");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_GAIN);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-
-        /*
-         * --alter change clock_sync <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_sync", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_SYNC);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl =
-                CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_sync", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_SYNC);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-
-        /*
-         * --alter change late <value>  <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        std::vector<std::string> late_values = {"late -s +00:15  -a  20:00  -c +02:00"};
-        for (const auto& value : late_values) {
-            {
-                auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "change", "late", value, paths);
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), value);
-                    BOOST_REQUIRE_EQUAL(command.value(), "");
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LATE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "change", "late", value, paths, "--debug");
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), value);
-                    BOOST_REQUIRE_EQUAL(command.value(), "");
-                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LATE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), true);
-                });
-            }
-        }
-
-    } // paths
-}
-
-BOOST_AUTO_TEST_CASE(test_is_able_handle_alter_add) {
-
-    /*
-     * --alter add <type> <name> <value> <path> [<path>...]
-     * ************************************************************************************************************** */
-
-    std::vector<std::vector<std::string>> paths_set = {
-        {"/node1"}, {"/node1", "/node2"}, {"/node1", "/node2", "/node3"}};
-
-    for (const auto& paths : paths_set) {
-
-        using Expected = AlterCmd::Add_attr_type;
-
-        std::vector<std::string> variable_values = {"",
-                                                    "--dashes at beginning of value",
-                                                    "a value with --dashes inside",
-                                                    "    value starting with spaces",
-                                                    "value ending with spaces      ",
-                                                    "   some value surrounded by spaces      ",
-                                                    "/some/valid/path"};
-
-        /*
-         * --alter add variable <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        for (const auto& value : variable_values) {
-            {
-                auto cl =
-                    CommandLine::make_command_line("ecflow_client", "--alter", "add", "variable", "name", value, paths);
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.add_attr_type(), Expected::ADD_VARIABLE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), false);
-                });
-            }
-            {
-                auto cl = CommandLine::make_command_line(
-                    "ecflow_client", "--alter", "add", "variable", "name", value, paths, "--debug");
-                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                    BOOST_REQUIRE_EQUAL(command.name(), "name");
-                    BOOST_REQUIRE_EQUAL(command.value(), value);
-                    BOOST_REQUIRE_EQUAL(command.add_attr_type(), Expected::ADD_VARIABLE);
-                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                    for (size_t i = 0; i < paths.size(); ++i) {
-                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                    }
-                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                    BOOST_REQUIRE_EQUAL(env.debug(), true);
-                });
-            }
-        }
-    } // paths
-}
-
-BOOST_AUTO_TEST_CASE(test_is_able_handle_alter_delete) {
-    /*
-     * --alter delete <type> <name> <path> [<path>...]
-     * ************************************************************************************************************** */
-
-    std::vector<std::vector<std::string>> paths_set = {
-        {"/node1"}, {"/node1", "/node2"}, {"/node1", "/node2", "/node3"}};
-
-    for (const auto& paths : paths_set) {
-
-        using Expected = AlterCmd::Delete_attr_type;
-
-        /*
-         * --alter delete <type> <name> <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        // No explicit name, means delete all variables
-        {
-            auto cl =
-                CommandLine::make_command_line("ecflow_client", "--alter", "delete", "variable", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_VARIABLE);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "variable", "name", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_VARIABLE);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line(
-                "ecflow_client", "--alter", "delete", "variable", "name", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_VARIABLE);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-
-        /*
-         * --alter delete label <name> <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        // No explicit name, means delete all labels
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "label", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_LABEL);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "label", "name", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_LABEL);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl =
-                CommandLine::make_command_line("ecflow_client", "--alter", "delete", "label", "name", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_LABEL);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-
-        /*
-         * --alter delete event <name> <path> [<path>...]
-         * ---------------------------------------------------------------------------------------------------------- */
-        // No explicit name, means delete all events
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", "name", paths);
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), false);
-            });
-        }
-        {
-            auto cl =
-                CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", "name", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client",
-                                                     "--host=default",
-                                                     "--port",
-                                                     "8888",
-                                                     "--alter",
-                                                     "delete",
-                                                     "event",
-                                                     "name",
-                                                     paths,
-                                                     "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "default");
-                BOOST_REQUIRE_EQUAL(env.port(), "8888");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client",
-                                                     "--alter",
-                                                     "delete",
-                                                     "event",
-                                                     "name",
-                                                     paths,
-                                                     "--host",
-                                                     "default",
-                                                     "--debug",
-                                                     "--port",
-                                                     "8888");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "name");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "default");
-                BOOST_REQUIRE_EQUAL(env.port(), "8888");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-        {
-            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", paths, "--debug");
-            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
-                BOOST_REQUIRE_EQUAL(command.name(), "");
-                BOOST_REQUIRE_EQUAL(command.value(), "");
-                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
-                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
-                for (size_t i = 0; i < paths.size(); ++i) {
-                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
-                }
-                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
-                BOOST_REQUIRE_EQUAL(env.port(), "3141");
-                BOOST_REQUIRE_EQUAL(env.debug(), true);
-            });
-        }
-    } // paths
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Begin) // --begin (BeginCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_begin) {
-    using Command = BeginCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--begin");
-        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.suiteName(), "");
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--begin=somesuite");
-        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.suiteName(), "somesuite");
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--begin=suite --force");
-        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.suiteName(), "suite");
-            BOOST_CHECK_EQUAL(command.force(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", R"(--begin="suite --force")");
-        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.suiteName(), "suite");
-            BOOST_CHECK_EQUAL(command.force(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--begin", "suite --force");
-        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.suiteName(), "suite");
-            BOOST_CHECK_EQUAL(command.force(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", R"(--begin="--force")");
-        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.suiteName(), "");
-            BOOST_CHECK_EQUAL(command.force(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--begin", "--force");
-        // This is an invalid, as --begin only takes a single argument (potentialy with --force as second value)
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Check) // --check (PathsCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_check) {
-    using Command = PathsCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--check=_all_");
-        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
-            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--check", "_all_");
-        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
-            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--check=/");
-        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
-            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--check", "/");
-        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
-            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--check=/s1", "/s2/f2", "/s3/f3/t3");
-        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
-            BOOST_REQUIRE_EQUAL(command.paths().size(), static_cast<size_t>(3));
-            BOOST_CHECK_EQUAL(command.paths()[0], "/s1");
-            BOOST_CHECK_EQUAL(command.paths()[1], "/s2/f2");
-            BOOST_CHECK_EQUAL(command.paths()[2], "/s3/f3/t3");
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--check", "/s1", "/s2/f2", "/s3/f3/t3");
-        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
-            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(3));
-            BOOST_CHECK_EQUAL(command.paths()[0], "/s1");
-            BOOST_CHECK_EQUAL(command.paths()[1], "/s2/f2");
-            BOOST_CHECK_EQUAL(command.paths()[2], "/s3/f3/t3");
-            BOOST_CHECK_EQUAL(command.force(), false);
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Complete) // --complete (CompleteCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_complete) {
-    using Command = CompleteCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--complete");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK(command.variables_to_delete().empty());
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--complete", "--remove", "var1");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_REQUIRE_EQUAL(command.variables_to_delete().size(), static_cast<size_t>(1));
-            BOOST_REQUIRE_EQUAL(command.variables_to_delete()[0], "var1");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--complete", "--remove", "var1", "var2");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_REQUIRE_EQUAL(command.variables_to_delete().size(), static_cast<size_t>(2));
-            BOOST_REQUIRE_EQUAL(command.variables_to_delete()[0], "var1");
-            BOOST_REQUIRE_EQUAL(command.variables_to_delete()[1], "var2");
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Event) // --event (EventCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_event) {
-    using Command = EventCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--event=name");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--event", "name");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--event=name", "set");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--event", "name", "set");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), true);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--event=name", "clear");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), false);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--event", "name", "clear");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), false);
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Init) // --init (InitCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_init) {
-    using Command = InitCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--init=1234");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
-            BOOST_CHECK_EQUAL(command.variables_to_add().size(), static_cast<size_t>(0));
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--init", "1234");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
-            BOOST_CHECK_EQUAL(command.variables_to_add().size(), static_cast<size_t>(0));
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--init=1234", "--add", "name1=value1");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
-            BOOST_REQUIRE_EQUAL(command.variables_to_add().size(), static_cast<size_t>(1));
-            BOOST_CHECK_EQUAL(command.variables_to_add()[0].name(), "name1");
-            BOOST_CHECK_EQUAL(command.variables_to_add()[0].theValue(), "value1");
-        });
-    }
-    {
-        auto cl =
-            CommandLine::make_command_line("ecflow_client", "--init=1234", "--add", "name1=--value1", "name2=--value2");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
-            BOOST_REQUIRE_EQUAL(command.variables_to_add().size(), static_cast<size_t>(2));
-            BOOST_CHECK_EQUAL(command.variables_to_add()[0].name(), "name1");
-            BOOST_CHECK_EQUAL(command.variables_to_add()[0].theValue(), "--value1");
-            BOOST_CHECK_EQUAL(command.variables_to_add()[1].name(), "name2");
-            BOOST_CHECK_EQUAL(command.variables_to_add()[1].theValue(), "--value2");
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Label) // --label (LabelCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_label) {
-    using Command = LabelCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "some value with spaces");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), "some value with spaces");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label", "name", "some value with spaces");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), "some value with spaces");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", R"(some "quoted" value)");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), R"(some "quoted" value)");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label", "name", R"(some "quoted" value)");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), R"(some "quoted" value)");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "-j64");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), "-j64");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--long-option");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), "--long-option");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--option=value");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), "--option=value");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--debug", "--debug");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), "--debug");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--port", "--debug", "--port", "123");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.label(), "--port");
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Meter) // --meter (MeterCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_meter) {
-    using Command = MeterCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "0");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), 0);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter", "name", "0");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), 0);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "-1");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), -1);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter", "name", "-1");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), -1);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "10");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), 10);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "20", "--debug");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), 20);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter", "name", "-20", "--debug");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), -20);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "-100", "--debug", "--port", "1234");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), -100);
-        });
-    }
-    {
-        auto cl =
-            CommandLine::make_command_line("ecflow_client", "--meter", "name", "-100", "--debug", "--port", "1234");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.value(), -100);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line(
-            "ecflow_client", "--port", "3141", "--host", "ecflow", "--meter", "step", "-1", "--debug");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "step");
-            BOOST_CHECK_EQUAL(command.value(), -1);
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line(
-            "ecflow_client", "--port", "3141", "--host", "ecflow", "--meter", "step", "-1", "--debug");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "step");
-            BOOST_CHECK_EQUAL(command.value(), -1);
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Queue) // --queue (QueueCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_queue) {
-    using Command = QueueCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "active");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "active");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "active");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "active");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "active", "/s/f/t");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "active");
-            BOOST_CHECK_EQUAL(command.path_to_node_with_queue(), "/s/f/t");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "complete", "42");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "complete");
-            BOOST_CHECK_EQUAL(command.step(), "42");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "complete", "42");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "complete");
-            BOOST_CHECK_EQUAL(command.step(), "42");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "aborted", "42");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "aborted");
-            BOOST_CHECK_EQUAL(command.step(), "42");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "aborted", "42");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "aborted");
-            BOOST_CHECK_EQUAL(command.step(), "42");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "no_of_aborted");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "no_of_aborted");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "no_of_aborted");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "no_of_aborted");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "no_of_aborted", "/s/f/t");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "no_of_aborted");
-            BOOST_CHECK_EQUAL(command.path_to_node_with_queue(), "/s/f/t");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "reset");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "reset");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "reset", "/s/f/t");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.name(), "name");
-            BOOST_CHECK_EQUAL(command.action(), "reset");
-            BOOST_CHECK_EQUAL(command.path_to_node_with_queue(), "/s/f/t");
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE(T_Wait) // --wait (WaitCmd)
-
-BOOST_AUTO_TEST_CASE(test_is_able_to_handle_wait) {
-    using Command = CtsWaitCmd;
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--wait=/suite/taskx == complete");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.expression(), "/suite/taskx == complete");
-        });
-    }
-    {
-        auto cl = CommandLine::make_command_line("ecflow_client", "--wait", "/suite/taskx == complete");
-        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
-            BOOST_CHECK_EQUAL(command.expression(), "/suite/taskx == complete");
-        });
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestClientTimeout.cpp 5.13.0-1/Client/test/TestClientTimeout.cpp
--- 5.12.4-1/Client/test/TestClientTimeout.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestClientTimeout.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,83 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/Str.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_ClientTimeout)
-
-// ************************************************************************************
-// Note : If you make edits to node tree, they will have no effect until the server is rebuilt /
-// ************************************************************************************
-
-// This test will check the timeoout feature of the Client
-//
-// The timeout feature allows the client to fail gracefully in the case where the server has died/crashed.
-// After timeout, the socket is closed allowing the server to be restarted without getting the `address in use` error.
-//
-BOOST_AUTO_TEST_CASE(test_client_timeout, *boost::unit_test::disabled()) {
-
-    //
-    // Important: This test is disabled because ClientInvoker doesn't actually allow to set an overall timeout
-    //            Until this functionality is available, this test cannot be effectively implemented
-    //
-
-    // The following removes check pt and backup file before server start,
-    // to avoid the server from loading previous test data
-    InvokeServer invokeServer("Client:: ...test_client_timeout", SCPort::next());
-
-    // The timeout is configured to vary according the the client request
-    // however we can override for testing.
-    // Here we set a timeout for 1 second, then attempt to load a very large definition into the server.
-    // Note: the timeout of 1 second means we have 1 second for each communication, hence:
-    //    connect        : 1 second
-    //    send request   : 1 second
-    //    receive reply  : 1 second
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    theClient.set_connect_timeout(0);
-
-    std::string path = File::test_data("ANode/test/parser/data/single_defs/mega.def", "parser");
-    BOOST_REQUIRE_THROW(theClient.loadDefs(path),
-                        std::runtime_error); // Expect load defs to fail with a timeout of 1 second
-
-    /// Now see what timeout value we succeed with
-    bool loaded_defs = false;
-    for (int i = 2; i < 30; ++i) {
-        theClient.set_connect_timeout(i);
-        try {
-            cout << "Trying with timeout of " << i << " seconds\n";
-            theClient.loadDefs(path);
-            cout << "   loaded mega defs with a timeout of " << i << " seconds\n";
-            loaded_defs = true;
-            break;
-        }
-        catch (...) {
-        }
-    }
-    BOOST_REQUIRE_MESSAGE(loaded_defs, "Expected load of defs to succeed\n");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestClient_main.cpp 5.13.0-1/Client/test/TestClient_main.cpp
--- 5.12.4-1/Client/test/TestClient_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestClient_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Client
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/Client/test/TestCustomUser.cpp 5.13.0-1/Client/test/TestCustomUser.cpp
--- 5.12.4-1/Client/test/TestCustomUser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestCustomUser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,159 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/PasswdFile.hpp"
-#include "ecflow/core/User.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_CustomUser)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-//
-// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
-//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
-//       is specified then *don't* shutdown the server
-// ************************************************************************************
-
-class Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env {
-public:
-    explicit Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env(const std::string& passwd_file)
-        : ecf_passwd_("ECF_CUSTOM_PASSWD="),
-          ecf_user_("ECF_USER=") {
-        ecf_passwd_ += passwd_file;
-        auto* put = const_cast<char*>(ecf_passwd_.c_str());
-        BOOST_CHECK_MESSAGE(putenv(put) == 0, "putenv failed for " << put);
-
-        ecf_user_ += User::login_name();
-        auto* put2 = const_cast<char*>(ecf_user_.c_str());
-        BOOST_CHECK_MESSAGE(putenv(put2) == 0, "putenv failed for " << put2);
-    }
-    ~Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env() {
-        putenv(const_cast<char*>("ECF_CUSTOM_PASSWD")); // remove from env, otherwise valgrind complains
-        putenv(const_cast<char*>("ECF_USER"));          // remove from env, otherwise valgrind complains
-    }
-
-private:
-    std::string ecf_passwd_;
-    std::string ecf_user_;
-};
-
-BOOST_AUTO_TEST_CASE(test_custom_user) {
-    Host the_host;
-    std::string host        = ClientEnvironment::hostSpecified();
-    std::string port        = SCPort::next();
-    std::string passwd_file = the_host.ecf_custom_passwd_file(port);
-    std::string passwd      = "xxxx";
-    if (host.empty()) {
-        // make sure NO passed file is present before the server is started.
-        // Only do this locally, as passwd file on remote machine may not be accessible
-        fs::remove(passwd_file);
-    }
-    else {
-        // The test only works if server is started locally.
-        std::cout << "...Client:: ...test_custom_user ignoring when HOST specified\n";
-        return;
-    }
-
-    {
-        // Create a valid passwd file; Before server start; make sure server closes before password file is deleted:
-        // cout << "\nCreating CUSTOM passwd_file " << passwd_file << "\n\n";
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(PasswdFile::createWithAccess(passwd_file, the_host.name(), port, passwd, errorMsg),
-                              errorMsg);
-        BOOST_REQUIRE_MESSAGE(fs::exists(passwd_file), "passwd file NOT created");
-    }
-
-    { // *** Need a separate scope so that server shuts down whilst password file is *STILL* present
-        // *** Otherwise terminate of server will fail. i.e ECF_PASSWORD is still valid
-
-        // Set ECF_USER and ECF_PASSWD environment variable. Use same file for client and server
-        // add on construction, and remove at destruction.
-        Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env custom_user(passwd_file);
-
-        // This will remove check pt and backup file before server start,
-        // to avoid the server from loading previous test data
-        // make sure server closes before password file is deleted:
-        InvokeServer invokeServer("Client:: ...test_custom_user", port);
-        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-        theClient.set_throw_on_error(false);
-
-        // Invoking a client request that requires authorisation
-        BOOST_REQUIRE_MESSAGE(theClient.reloadcustompasswdfile() == 0,
-                              CtsApi::reloadcustompasswdfile() << " should return 0\n"
-                                                               << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                              CtsApi::shutdownServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                              CtsApi::haltServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-
-        // Change to a user not in password file
-        theClient.set_user_name(
-            "dodgy_geezer"); // this should clear password, so that its reloaded when *next* cmd runs
-
-        // all client command should now *FAIL*.
-        BOOST_CHECK_MESSAGE(theClient.reloadcustompasswdfile() == 1,
-                            CtsApi::reloadcustompasswdfile() << " should return 1\n");
-        BOOST_CHECK_MESSAGE(theClient.delete_all() == 1,
-                            CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                     << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 1,
-                            CtsApi::shutdownServer() << " should return 0\n"
-                                                     << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.haltServer() == 1,
-                            CtsApi::haltServer() << " should return 0\n"
-                                                 << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.restartServer() == 1,
-                            CtsApi::restartServer() << " should return 0\n"
-                                                    << theClient.errorMsg());
-
-        // reset to a valid user again:
-        theClient.set_user_name(
-            User::login_name()); // this should clear password, so that its reloaded when *next* cmd runs
-
-        // all client command should now pass. Invoking a client request that requires authorisation
-        BOOST_CHECK_MESSAGE(theClient.reloadcustompasswdfile() == 0,
-                            CtsApi::reloadcustompasswdfile() << " should return 0\n");
-        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
-
-        // terminate server with a valid valid user since ECF_PASSWORD/ECF_USER is still in effect.
-    }
-
-    // Remove the white list file. Comment out for debug
-    fs::remove(passwd_file);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestGroupCmd.cpp 5.13.0-1/Client/test/TestGroupCmd.cpp
--- 5.12.4-1/Client/test/TestGroupCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestGroupCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,263 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_GroupCmd)
-
-BOOST_AUTO_TEST_CASE(test_group_cmd) {
-    // The previous test's has created/destroyed a server process
-    // If two different process both try to use the same port number, you
-    // get an "Address in use" error, even if one the process is dead. This is
-    // because the kernel does not immediately release the resource and there is
-    // time out period. To get round this we will start the new server/client
-    // and use a different port number. the default is 3141
-
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-    InvokeServer invokeServer("Client:: ...test_group_cmd", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.group("shutdown yes;halt yes;restart") == 0,
-                          "--group should return 0\n"
-                              << theClient.errorMsg());
-}
-
-BOOST_AUTO_TEST_CASE(test_client_group_lifecyle) {
-    /// *** This test is the same as in file TestServerAndLifeCyle.cpp only this time
-    /// *** we use the group command where ever possible
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-
-    // ** NOTE: We disable job generation in the server **/
-    InvokeServer invokeServer(
-        "Client:: ...test_client_group_lifecyle", SCPort::next(), true /*disable job generation in server*/);
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-
-    size_t expected_var = 0;
-    {
-        // restart server, load lifecycle, and get the defs tree from the server
-        std::string groupRequest = "--restart; load=";
-        groupRequest += File::test_data("Client/test/data/lifecycle.txt", "Client");
-        groupRequest += "; get";
-
-        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
-                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
-                                               << theClient.errorMsg());
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "Server returned a NULL defs");
-        BOOST_REQUIRE_MESSAGE(serverDefs->suiteVec().size() >= 1, "  no suite ?");
-        const std::vector<suite_ptr>& suites   = serverDefs->suiteVec();
-        const std::vector<Variable>& variables = suites[0]->variables();
-        expected_var                           = variables.size();
-    }
-
-    {
-        // add some var's with spaces ECFLOW-1265
-        expected_var += 1;
-        std::string groupRequest = "alter add variable VAR 'space s' /suite1; get";
-
-        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
-                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
-                                               << theClient.errorMsg());
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "Server returned a NULL defs");
-        const std::vector<suite_ptr>& suites = serverDefs->suiteVec();
-        BOOST_REQUIRE_MESSAGE(suites.size() >= 1, "  no suite ?");
-        const std::vector<Variable>& variables = suites[0]->variables();
-        BOOST_REQUIRE_MESSAGE(variables.size() == expected_var,
-                              "Expected " << expected_var << " variables but found " << variables.size());
-        BOOST_REQUIRE_MESSAGE(variables[expected_var - 1].theValue() == "'space s'",
-                              "Expected 'space s' but found " << variables[expected_var - 1].theValue());
-    }
-
-    // Now go through and simulate client request to change Node tree state.
-    // This is **highly** dependent on lifecycle.txt
-    //	suite suite1
-    //	  family family1
-    //	   	task a
-    //	        event 1 myEvent
-    //	        meter myMeter 0 100
-    //	   	task b
-    //	   		trigger a == complete
-    //	   endfamily
-    //	   family family2
-    //	   		task aa
-    //	   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
-    //	   		task bb
-    //	   			trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
-    //	    endfamily
-    //	endsuite
-    string suite1_family1_a  = "suite1/family1/a";
-    string suite1_family1_b  = "suite1/family1/b";
-    string suite1_family2_aa = "suite1/family2/aa";
-    string suite1_family2_bb = "suite1/family2/bb";
-
-    // ***********************************************************************
-    // Create a request to initialise Node: suite1/family1/a
-    // Create a request to set the event on Node suite1/family1/a
-    // This should place suite1_family2_bb immediately into submitted state
-    // Since we at least one node in ACTIVE, suite should be in ACTIVE state
-    {
-        theClient.taskPath(suite1_family1_a);
-        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
-
-        // make sure to use same ECF_RID if its specified
-        std::string remote_id = "process_or_remote_id";
-        if (!theClient.process_or_remote_id().empty())
-            remote_id = theClient.process_or_remote_id();
-        std::string groupRequest = "begin=suite1;  init=";
-        groupRequest += remote_id;
-        groupRequest += "; event=myEvent; force-dep-eval; get";
-
-        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
-                              "Group request " << groupRequest << " failed should return 0\n"
-                                               << theClient.errorMsg());
-
-        defs_ptr serverDefs = theClient.defs();
-        // PrintStyle style(PrintStyle::STATE);
-        // cerr << *serverDefs.get() << "\n";
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        node_ptr node = serverDefs->findAbsNode(suite1_family1_a);
-        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(node->state()));
-        node_ptr nodeb = serverDefs->findAbsNode(suite1_family2_bb);
-        BOOST_REQUIRE_MESSAGE(nodeb->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeb->state()));
-    }
-
-    //**********************************************************************
-    // Create a request to set the Meter on Node suite1/family1/a
-    // This should force suite1_family2_aa immediately into submitted state
-    // This should force suite1_family2_bb immediately into submitted state
-    {
-        theClient.taskPath(suite1_family1_a);
-        std::string groupRequest = "meter=myMeter 100; force-dep-eval; get";
-        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
-                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
-                                               << theClient.errorMsg());
-
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        node_ptr nodeaa = serverDefs->findAbsNode(suite1_family2_aa);
-        BOOST_REQUIRE_MESSAGE(nodeaa->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeaa->state()));
-
-        node_ptr nodebb = serverDefs->findAbsNode(suite1_family2_bb);
-        BOOST_REQUIRE_MESSAGE(nodebb->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodebb->state()));
-    }
-
-    //**********************************************************************
-    // Create a request to complete task suite1/family1/a
-    // This should force suite1_family1_b to complete
-    // 	Resolve dependencies
-    // 	We could either wait 60 second or
-    // 	added a custom command that will force dependency evaluation
-    {
-        theClient.taskPath(suite1_family1_a);
-        std::string groupRequest = "complete;force-dep-eval;get";
-        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
-                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
-                                               << theClient.errorMsg());
-
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        node_ptr node = serverDefs->findAbsNode(suite1_family1_b);
-        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
-                              "Expected NState::ACTIVE, but found " << NState::toString(node->state()));
-    }
-
-    //********************************************************************************
-    // Complete the remaining tasks. Should really call init first, but what the eck.
-    //
-    // Get the node tree back from the server, and check its node state
-    // All node state should be complete. + check meter/event value was set properly
-
-    {
-        theClient.taskPath(suite1_family1_b);
-        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
-                              TaskApi::complete() << " failed should return 0\n"
-                                                  << theClient.errorMsg());
-
-        theClient.taskPath(suite1_family2_aa);
-        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
-                              TaskApi::complete() << " failed should return 0\n"
-                                                  << theClient.errorMsg());
-
-        theClient.taskPath(suite1_family2_bb);
-        std::string groupRequest = "complete;force-dep-eval;get";
-        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
-                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
-                                               << theClient.errorMsg());
-
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        std::string metername = "myMeter";
-        int meterValue        = 100;
-        node_ptr node         = serverDefs->findAbsNode(suite1_family1_a);
-        const Meter& theMeter = node->findMeter(metername);
-        BOOST_REQUIRE_MESSAGE(!theMeter.empty(), "Could not find the meter");
-        BOOST_REQUIRE_MESSAGE(theMeter.value() == meterValue,
-                              "Expected meter value " << meterValue << " but found " << theMeter.value());
-        {
-            std::string errorMsg;
-            BOOST_REQUIRE_MESSAGE(serverDefs->checkInvariants(errorMsg), errorMsg);
-        }
-
-        std::string eventname = "myEvent";
-        const Event& theEvent = node->findEventByNameOrNumber(eventname);
-        BOOST_REQUIRE_MESSAGE(!theEvent.empty(), "Could not find the event myEvent");
-        BOOST_REQUIRE_MESSAGE(theEvent.value(), "The event was not set");
-
-        const std::vector<suite_ptr>& suiteVec = serverDefs->suiteVec();
-        suite_ptr suite                        = suiteVec.back();
-        BOOST_REQUIRE_MESSAGE(suite->state() == NState::COMPLETE,
-                              "Suite expected NState::COMPLETE, but found to be " << NState::toString(suite->state()));
-    }
-
-    {
-        // Check that a log file was created, by asking the server for it.
-        BOOST_REQUIRE_MESSAGE(theClient.getLog() == 0, "get log  failed should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(!theClient.get_string().empty(), "The log file returned from the server is empty!!");
-
-        // Clear the log
-        BOOST_REQUIRE_MESSAGE(theClient.clearLog() == 0,
-                              CtsApi::clearLog() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestInitAddVariables.cpp 5.13.0-1/Client/test/TestInitAddVariables.cpp
--- 5.12.4-1/Client/test/TestInitAddVariables.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestInitAddVariables.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/task/CompleteCmd.hpp"
-#include "ecflow/base/cts/task/InitCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_InitAddVariables)
-
-BOOST_AUTO_TEST_CASE(test_init_add_variables) {
-    cout << "Client:: ...test_init_add_variables " << endl;
-    TestLog test_log(
-        "test_init_add_variables.log"); // will create log file, and destroy log and remove file at end of scope
-
-    Defs defs;
-    suite_ptr suite = defs.add_suite("test_init_add_variables");
-    family_ptr f    = suite->add_family("f");
-    task_ptr t1     = f->add_task("t1");
-    t1->add_trigger(":name == 1 and :name2 == 2");
-    {
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-    {
-        std::string errorMsg, warningMsg;
-        BOOST_CHECK_MESSAGE(!defs.check(errorMsg, warningMsg),
-                            "Expected error since variable name and name2 are not defined");
-    }
-
-    BOOST_CHECK_MESSAGE(suite->state() == NState::UNKNOWN, " Initial suite state should be NState::UNKNOWN");
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("test_init_add_variables")));
-
-    {
-        // Test that init command with --add, will add variables
-        std::vector<Variable> vec{Variable("name", "1"), Variable("name2", "2")};
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new InitCmd(t1->absNodePath(),
-                                                      Submittable::DUMMY_JOBS_PASSWORD(),
-                                                      Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                      1,
-                                                      vec)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)), false);
-        const Variable& v  = t1->findVariable("name");
-        const Variable& v2 = t1->findVariable("name2");
-        BOOST_CHECK_MESSAGE(!v.empty(), "Expected --init to add variable");
-        BOOST_CHECK_MESSAGE(!v2.empty(), "Expected --init to add variable");
-
-        std::string errorMsg, warningMsg;
-        BOOST_CHECK_MESSAGE(defs.check(errorMsg, warningMsg),
-                            "Expected check to pass since variable name and name2 are defined " << errorMsg);
-    }
-
-    {
-        // Test that comeplete command with --remove, will delete variables
-        std::vector<std::string> vec{"name", "name2"};
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new CompleteCmd(t1->absNodePath(),
-                                                          Submittable::DUMMY_JOBS_PASSWORD(),
-                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                          1,
-                                                          vec)));
-        const Variable& v  = t1->findVariable("name");
-        const Variable& v2 = t1->findVariable("name2");
-        BOOST_CHECK_MESSAGE(v.empty(), "Expected --complete to delete variable");
-        BOOST_CHECK_MESSAGE(v2.empty(), "Expected --complete to delete variable");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestJobGenOnly.cpp 5.13.0-1/Client/test/TestJobGenOnly.cpp
--- 5.12.4-1/Client/test/TestJobGenOnly.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestJobGenOnly.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,92 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp> // IWYU pragma: keep
-
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/JobCreationCtrl.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_JobGenOnly)
-
-//  Tests the Job generation against the OLD sms
-BOOST_AUTO_TEST_CASE(test_jobgenonly) {
-    cout << "Client:: ...test_jobgenonly" << endl;
-
-    // Define paths to ECF_HOME and location of the defs file
-
-    std::string defsFile = File::test_data("Client/test/data/jobgenonly.def", "Client");
-    std::string ecf_home = File::test_data("Client/test/data/ECF_HOME", "Client");
-
-    /// Remove existing job file if any.
-    /// 	Job file location may NOT be same as ecf file.
-    /// 	The default Job location is defined by generated variable ECF_JOB
-    /// 	ECF_JOB = ECF_HOME/<abs node path>.job<try_no>.
-    std::vector<std::string> generatedFiles;
-    generatedFiles.reserve(5);
-    std::string t1_job = ecf_home + "/suite/family/t1.job0";
-    generatedFiles.push_back(t1_job);
-    std::string t2_job = ecf_home + "/suite/family/t2.job0";
-    generatedFiles.push_back(t2_job);
-    std::string t3_job = ecf_home + "/suite/family/t3.job0";
-    generatedFiles.push_back(t3_job);
-
-    // See EcfFile.cpp: To enable generation of man files, for test. i.e DEBUG_MAN_FILE
-#ifdef DEBUG_MAN_FILE
-    std::string t1_man = ecf_home + "/suite/family/t1.man";
-    generatedFiles.push_back(t1_man);
-    std::string t3_man = ecf_home + "/suite/family/t3.man";
-    generatedFiles.push_back(t3_man);
-#endif
-    for (const std::string& s : generatedFiles) {
-        fs::remove(s);
-    }
-    for (const std::string& s : generatedFiles) {
-        BOOST_REQUIRE_MESSAGE(!fs::exists(s), "Could not delete file " << s);
-    }
-
-    // Load the defs file 'jobgenonly.def'
-    Defs theDefs;
-    std::string errorMsg, warningMsg;
-    BOOST_REQUIRE_MESSAGE(theDefs.restore(defsFile, errorMsg, warningMsg), errorMsg);
-
-    // Override ECF_HOME. ECF_HOME is needed to locate to the .ecf files
-    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
-
-    // provide definition of ECF_CLIENT. This should replace smsinit, smscomplete, smsevent,etc
-    // with path to the ecf client
-    std::string clientPath = File::find_ecf_client_path();
-    BOOST_REQUIRE_MESSAGE(!clientPath.empty(), "Could not find path to client executable");
-    theDefs.set_server().add_or_update_user_variables("ECF_CLIENT", clientPath);
-
-    // JobCreationCtrl is used control what node we generate the jobs for:
-    // Since we have not set the node on it, we force job generation for all tasks
-    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
-    theDefs.check_job_creation(jobCtrl);
-    BOOST_REQUIRE_MESSAGE(jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
-    BOOST_REQUIRE_MESSAGE(jobCtrl->fail_submittables().empty(), "Expected no failing tasks");
-
-    // Check if jobs file were generated.
-    for (const std::string& s : generatedFiles) {
-        BOOST_REQUIRE_MESSAGE(fs::exists(s), "File " << s << " should have been created");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestLifeCycle.cpp 5.13.0-1/Client/test/TestLifeCycle.cpp
--- 5.12.4-1/Client/test/TestLifeCycle.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestLifeCycle.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,245 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/task/CompleteCmd.hpp"
-#include "ecflow/base/cts/task/EventCmd.hpp"
-#include "ecflow/base/cts/task/InitCmd.hpp"
-#include "ecflow/base/cts/task/MeterCmd.hpp"
-#include "ecflow/base/cts/user/BeginCmd.hpp"
-#include "ecflow/base/cts/user/CtsCmd.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_LifeCycle)
-
-BOOST_AUTO_TEST_CASE(test_node_tree_lifecycle) {
-    cout << "Client:: ...test_node_tree_lifecycle" << endl;
-    TestLog test_log(
-        "test_node_tree_lifecycle.log"); // will create log file, and destroy log and remove file at end of scope
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    Defs defs;
-    std::string errorMsg, warningMsg;
-    bool parse = defs.restore(path, errorMsg, warningMsg);
-    if (!parse)
-        std::cerr << errorMsg;
-    BOOST_CHECK(parse);
-
-    // Now go through and simulate client request to change Node tree state.
-    // This is **highly** dependent on lifecycle.txt
-    //	suite suite1
-    //	  family family1
-    //	   	task a
-    //	        event 1 myEvent
-    //	        meter myMeter 0 100
-    //	   	task b
-    //	   		trigger a == complete
-    //	   endfamily
-    //	   family family2
-    //	   		task aa
-    //	   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
-    //	   		task bb
-    //	   			trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
-    //	    endfamily
-    //	endsuite
-
-    // get the suite, before we do anything initial state should be UNKNOWN
-    const std::vector<suite_ptr>& suiteVec = defs.suiteVec();
-    suite_ptr suite                        = suiteVec.back();
-    BOOST_CHECK_MESSAGE(suite->state() == NState::UNKNOWN, " Initial suite state should be NState::UNKNOWN");
-
-    string suite1_family1_a  = "suite1/family1/a";
-    string suite1_family1_b  = "suite1/family1/b";
-    string suite1_family2_aa = "suite1/family2/aa";
-    string suite1_family2_bb = "suite1/family2/bb";
-
-    // Pick the suite that is allowed to resolve dependencies
-    // The suite must be loaded and be in state UNKNOWN or COMPLETE
-    TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("suite1")));
-
-    // ***********************************************************************
-    // Create a request to initialise Node: suite1/family1/a
-    {
-        TestHelper::invokeRequest(
-            &defs,
-            Cmd_ptr(new InitCmd(
-                suite1_family1_a, Submittable::DUMMY_JOBS_PASSWORD(), Submittable::DUMMY_PROCESS_OR_REMOTE_ID(), 1)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)), false);
-
-        node_ptr node = defs.findAbsNode(suite1_family1_a);
-        BOOST_CHECK_MESSAGE(node, "Could not find node");
-        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE, "Init request should place node in NState::ACTIVE");
-        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE, "Suite should be in NState::ACTIVE after init cmd");
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-
-    //**********************************************************************
-    // Create a request to set the event on Node suite1/family1/a
-    // This should force suite1_family2_bb immediately into submitted/active state
-    {
-        std::string eventname = "myEvent";
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new EventCmd(suite1_family1_a,
-                                                       Submittable::DUMMY_JOBS_PASSWORD(),
-                                                       Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                       1,
-                                                       eventname)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
-        node_ptr node = defs.findAbsNode(suite1_family1_a);
-
-        const Event& theEvent = node->findEventByNameOrNumber(eventname);
-        BOOST_CHECK_MESSAGE(!theEvent.empty(), "Could not find the event myEvent");
-        BOOST_CHECK_MESSAGE(theEvent.value(), "The event was not set");
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-
-        // cerr << "Defs " << defs << "\n";
-        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE,
-                            "State should be NState::ACTIVE but found to be " << NState::toString(node->state()));
-        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
-                            "Suite should be in NState::ACTIVE but found to be " << NState::toString(suite->state()));
-
-        node_ptr nodebb = defs.findAbsNode(suite1_family2_bb);
-        BOOST_CHECK_MESSAGE(nodebb->state() == NState::ACTIVE,
-                            "State should be NState::ACTIVE but found to be " << NState::toString(nodebb->state()));
-    }
-
-    //*******************************************************************************
-    // Resolve dependencies. After previous event suite1_family2_bb should have
-    //                       been put into ACTIVE state.
-    //                       ** Tests trigger/AST OR functionality **
-    //                       Since we at least one node in active, suite should
-    //                       be in avtive state
-    {
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        for (Submittable* t : jobsParam.submitted()) {
-            BOOST_CHECK_MESSAGE(t->state() == NState::SUBMITTED, "jobSubmission should change Node state");
-        }
-
-        {
-            node_ptr node = defs.findAbsNode(suite1_family1_a);
-            BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE, "resolve dependencies should change Node state here");
-        }
-        node_ptr node = defs.findAbsNode(suite1_family2_bb);
-        BOOST_CHECK_MESSAGE(node, "Could Not find Node " << suite1_family2_bb);
-        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE, "resolve dependencies should change Node state");
-        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
-                            "Suite expected NState::ACTIVE, but found to be " << NState::toString(suite->state()));
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-
-    //**********************************************************************
-    // Create a request to set the Meter on Node suite1/family1/a
-    // This should immediately change suite1_family2_aa into submitted state
-    {
-        std::string metername = "myMeter";
-        int meterValue        = 100;
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new MeterCmd(suite1_family1_a,
-                                                       Submittable::DUMMY_JOBS_PASSWORD(),
-                                                       Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
-                                                       1,
-                                                       metername,
-                                                       meterValue)));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
-
-        node_ptr node = defs.findAbsNode(suite1_family1_a);
-        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE,
-                            "Expected Node '" << node->absNodePath() << "' to be NState::ACTIVE, but found "
-                                              << NState::toString(node->state()) << "\n");
-        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
-                            "Suite expected NState::ACTIVE, but found to be " << NState::toString(suite->state()));
-
-        const Meter& theMeter = node->findMeter(metername);
-        BOOST_CHECK_MESSAGE(!theMeter.empty(), "Could not find the meter");
-        BOOST_CHECK_MESSAGE(theMeter.value() == meterValue, "Meter value not set");
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-
-        node_ptr nodeaa = defs.findAbsNode(suite1_family2_aa);
-        BOOST_CHECK_MESSAGE(nodeaa, "Could Not find Node " << suite1_family2_aa);
-        BOOST_CHECK_MESSAGE(nodeaa->state() == NState::ACTIVE, "resolve dependencies should change Node state");
-    }
-
-    //**********************************************************************
-    // Create a request to complete task suite1/family1/a
-    // A is complete, which means evaluation dependencies should force:
-    //      suite1/family1/b   :->to be submitted.
-    // since the complete command does an immediate job submission afterwards
-    {
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new CompleteCmd(suite1_family1_a, Submittable::DUMMY_JOBS_PASSWORD())));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
-
-        node_ptr node = defs.findAbsNode(suite1_family1_a);
-        BOOST_CHECK_MESSAGE(node, "Could not find node");
-        BOOST_CHECK_MESSAGE(node->state() == NState::COMPLETE,
-                            "Complete request should place node in NState::COMPLETE");
-        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
-                            "Expected NState::ACTIVE, but found to be " << NState::toString(suite->state()));
-
-        node_ptr nodeb = defs.findAbsNode(suite1_family1_b);
-        BOOST_CHECK_MESSAGE(nodeb, "Could not find node");
-        BOOST_CHECK_MESSAGE(nodeb->state() == NState::ACTIVE,
-                            "Expected NState::ACTIVE, but found to be " << NState::toString(nodeb->state()));
-
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-
-    //*******************************************************************************
-    // Job submission, should not send any jobs for submission.
-    //         This will evaluate dependencies( ie day,date, trigger ast)
-    {
-        JobsParam jobsParam; // create jobs = false, spawn jobs = false
-        Jobs jobs(&defs);
-        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
-        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
-                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
-    }
-
-    //********************************************************************************
-    // Complete the remaining tasks
-    {
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new CompleteCmd("suite1/family1/b", Submittable::DUMMY_JOBS_PASSWORD())));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new CompleteCmd(suite1_family2_aa, Submittable::DUMMY_JOBS_PASSWORD())));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new CompleteCmd(suite1_family2_bb, Submittable::DUMMY_JOBS_PASSWORD())));
-
-        BOOST_CHECK_MESSAGE(suite->state() == NState::COMPLETE, "Suite should be in NState::COMPLETE state");
-        std::string errorMsg;
-        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestLoadDefsCmd.cpp 5.13.0-1/Client/test/TestLoadDefsCmd.cpp
--- 5.12.4-1/Client/test/TestLoadDefsCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestLoadDefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,166 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_LoadDefsCmd)
-
-//=============================================================================
-// This test the LoadDefsCmd. This command will merge/absorb a defs file
-// Since we are merging 2 files. It will give us an opportunity to resolve
-// the extern node paths in the trigger expressions.
-//
-// ********************************************************************
-// In the real server, we dont store, externs
-// *******************************************************************
-BOOST_AUTO_TEST_CASE(test_load_defs_cmd_handleRequest) {
-    cout << "Client:: ...test_load_defs_cmd_handleRequest" << endl;
-    TestLog test_log("test_load_defs_cmd_handleRequest.log"); // will create log file, and destroy log and remove file
-                                                              // at end of scope
-
-    std::string firstDef = File::test_data("Client/test/data/first.def", "Client");
-
-    // Load the FIRST file with a set of unresolved extrens
-    defs_ptr firstDefs = Defs::create();
-    {
-        std::string errorMsg, warningMsg;
-        bool parse = firstDefs->restore(firstDef, errorMsg, warningMsg);
-        BOOST_CHECK_MESSAGE(parse, "Parse failed. " << errorMsg);
-        firstDefs->clear_externs(); // server defs should not have externs.
-    }
-    size_t noOfSuites = firstDefs->suiteVec().size();
-
-    // load the SECOND file, which should resolve the externs
-    std::string secondDef = File::test_data("Client/test/data/second.def", "Client");
-    Defs secondDefs;
-    {
-        std::string errorMsg, warningMsg;
-        bool parse = secondDefs.restore(secondDef, errorMsg, warningMsg);
-        BOOST_CHECK_MESSAGE(parse, "Parse failed. " << errorMsg);
-    }
-    noOfSuites += secondDefs.suiteVec().size();
-
-    // Create a LoadDefsCmd. This capable of merging defs files
-    // Externs are NOT loaded into the server.
-    LoadDefsCmd cmd(firstDefs);
-    cmd.setup_user_authentification();
-
-    // Calling handelRequest will absorb the first defs into second & server user variables
-    // AND resolve any references to node paths in the trigger expressions
-    //
-    // Test that the merge was OK as well
-    // Note: The firstDefs is recreated in the SERVER (via LoadDefsCmd), hence out of sync with this firstDefs
-    MockServer mockServer(&secondDefs);
-    STC_Cmd_ptr requestStatus = cmd.handleRequest(&mockServer);
-    BOOST_CHECK_MESSAGE(requestStatus, "Handle Request " << cmd << " returned NULL\n");
-    BOOST_CHECK_MESSAGE(requestStatus->error().empty(), requestStatus->error());
-    BOOST_CHECK_MESSAGE(secondDefs.suiteVec().size() == noOfSuites, "Merge failed to add suites");
-
-    // Modify the Defs file to add a task/trigger that references the undefined
-    // extern path defined in file 'first.def' This should fail.
-    task_ptr task = Task::create("AMadeUpName");
-    task->add_trigger("/a/b/c/d/e/f/g/h/j == complete");
-    secondDefs.suiteVec().back()->familyVec().back()->addTask(task);
-
-    // we just added an expression, re-parse to create AST
-    // This should also attempt to resolve the extern node path /a/b/c/d/e/f/g/h/j
-    // The suite 'a' should exist. But the full path is non existent
-    // hence we expect the PARSE to fail.
-    std::string errormsg, warningMsg;
-    BOOST_CHECK_MESSAGE(!secondDefs.check(errormsg, warningMsg), errormsg);
-}
-
-BOOST_AUTO_TEST_CASE(test_load_defs_check_only) {
-    /// Test that when check only is called the definition is NOT loaded
-    InvokeServer invokeServer("Client:: ...test_load_defs_check_only", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    // Do not load the defs do a check only
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    {
-        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, false, true /* check only*/) == 0,
-                              "Expected load to succeed\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Expected sync to succeed\n" << theClient.errorMsg());
-
-        // Note: when running with ECF_HOST=localhost the defs may exist, but the number of suites should be empty
-        BOOST_REQUIRE_MESSAGE(!theClient.defs() || theClient.defs()->suiteVec().empty(),
-                              "Expected no defs, since nothing should have been loaded\n"
-                                  << theClient.errorMsg());
-    }
-    {
-        theClient.set_auto_sync(true);
-        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, false, true /* check only*/) == 0,
-                              "Expected load to succeed\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(!theClient.defs() || theClient.defs()->suiteVec().empty(),
-                              "Expected no defs, since nothing should have been loaded\n"
-                                  << theClient.errorMsg());
-    }
-    // provide path to definition that should fail to parse
-    std::string path_bad_def = File::test_data("Client/test/data/bad.def", "Client");
-    BOOST_REQUIRE_THROW(theClient.loadDefs(path_bad_def, false, true /* check only*/), std::runtime_error);
-}
-
-BOOST_AUTO_TEST_CASE(test_load_defs) {
-    /// Test that loading a defs a second time, with the same suite, throws a errors
-    /// unless the -force option is used.
-    InvokeServer invokeServer("Client:: ...test_load_defs", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    // create a defs with a single suite 's1'
-    defs_ptr theDefs = Defs::create();
-    {
-        suite_ptr suite = Suite::create("s1");
-        theDefs->addSuite(suite);
-    }
-
-    // Load the defs into the server
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    theClient.set_throw_on_error(false);
-    BOOST_REQUIRE_MESSAGE(theClient.load(theDefs) == 0, "Expected load to succeed\n" << theClient.errorMsg());
-
-    // load the defs again. This should fail. as it stops accidental overwrites
-    BOOST_REQUIRE_MESSAGE(theClient.load(theDefs) == 1, "Expected load to fail\n" << theClient.errorMsg());
-
-    // Try again but with force
-    BOOST_REQUIRE_MESSAGE(theClient.load(theDefs, true /*force*/) == 0,
-                          "Expected load to succeed\n"
-                              << theClient.errorMsg());
-
-    /// Destroy singleton's to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestLogAndCheckptErrors.cpp 5.13.0-1/Client/test/TestLogAndCheckptErrors.cpp
--- 5.12.4-1/Client/test/TestLogAndCheckptErrors.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestLogAndCheckptErrors.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,170 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-#include <sys/stat.h>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Pid.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/User.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_LogAndCheckptErrors)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-// ************************************************************************************
-BOOST_AUTO_TEST_CASE(test_log_and_checkpt_write_errors) {
-    // This test needs to change directory *BEFORE* before the server starts.
-    // Hence if the server is already running ignore this test.
-    if (!ClientEnvironment::hostSpecified().empty()) {
-        cout << "Client:: ...test_log_and_checkpt_write_errors. IGNORING when server is already running" << endl;
-        return;
-    }
-
-    // When this test is run in Bamboo/Docker, the users is root, hence the chmod below will not work and test will fail
-    if (User::login_name() == "root") {
-        cout << "Client:: ...test_log_and_checkpt_write_errors. IGNORING when user is root." << endl;
-        return;
-    }
-
-    bool debug_me = false;
-    if (debug_me)
-        cout << "->Create a directory from where we will start the server\n";
-    std::string ecf_home = "test_log_and_checkpt_write_errors" + Pid::getpid();
-    fs::create_directory(ecf_home);
-
-    if (debug_me)
-        cout << "->change directory, before server start\n";
-    BOOST_CHECK_MESSAGE(chdir(ecf_home.c_str()) == 0,
-                        "Can't change directory to " << ecf_home << "  error: " << strerror(errno));
-    if (debug_me)
-        cout << "->current path = " << fs::current_path() << "\n";
-
-    {
-        if (debug_me)
-            cout << "->start the server\n";
-        InvokeServer invokeServer("Client:: ...test_log_and_checkpt_write_errors", SCPort::next());
-        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-        if (debug_me)
-            invokeServer.keep_log_file_after_server_exit();
-
-        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-        theClient.set_throw_on_error(false);
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
-                                                      << theClient.errorMsg());
-
-        if (debug_me)
-            cout << "->load a defs file to the server\n";
-        std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-        BOOST_CHECK_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-        if (debug_me) {
-            BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
-            PrintStyle style(PrintStyle::STATE);
-            cout << theClient.defs() << "\n";
-        }
-
-        if (debug_me)
-            cout << "->flush the log file, this will close the log file in the server\n";
-        BOOST_CHECK_MESSAGE(theClient.flushLog() == 0, "flushLog failed \n" << theClient.errorMsg());
-
-        if (debug_me)
-            cout << "->remove write permission for " << ecf_home << "\n";
-        BOOST_CHECK_MESSAGE(chdir("..") == 0, "Can't change directory to parent  error: " << strerror(errno));
-        BOOST_CHECK_MESSAGE(chmod(ecf_home.c_str(), strtol("0444", 0, 8)) == 0, "Can't chmod : " << strerror(errno));
-
-        if (debug_me)
-            cout << "->write the checkpoint file, should fail, this should also try to re-open the log file and fail\n";
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 1,
-                              CtsApi::checkPtDefs() << " Checkpoint expected to fail\n"
-                                                    << theClient.errorMsg());
-
-        if (debug_me)
-            cout << "->get the defs from server, Check flags, check server variables\n";
-        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.defs()->get_flag().is_set(Flag::CHECKPT_ERROR),
-                            "Expected Flag::CHECKPT_ERROR to be set");
-        BOOST_CHECK_MESSAGE(theClient.defs()->get_flag().is_set(Flag::LOG_ERROR), "Expected Flag::LOG_ERROR to be set");
-        BOOST_CHECK_MESSAGE(theClient.defs()->server().variable_exists("ECF_CHECKPT_ERROR"),
-                            "Expected to find ECF_CHECKPT_ERROR as a server variable");
-        BOOST_CHECK_MESSAGE(theClient.defs()->server().variable_exists("ECF_LOG_ERROR"),
-                            "Expected to find ECF_LOG_ERROR as a server variable");
-
-        const Variable& var  = theClient.defs()->server().findVariable("ECF_LOG_ERROR");
-        const Variable& var1 = theClient.defs()->server().findVariable("ECF_CHECKPT_ERROR");
-        BOOST_CHECK_MESSAGE(!var1.theValue().empty(), "Expected ECF_CHECKPT_ERROR to have a value");
-        BOOST_CHECK_MESSAGE(!var.theValue().empty(), "Expected ECF_LOG_ERROR to have a value");
-        if (debug_me)
-            cout << "->ECF_CHECKPT_ERROR=" << var1.theValue() << "\n";
-        if (debug_me)
-            cout << "->ECF_LOG_ERROR =" << var.theValue() << "\n";
-
-        if (debug_me)
-            cout << "->add write permission to " << ecf_home << "\n";
-        BOOST_CHECK_MESSAGE(chmod(ecf_home.c_str(), strtol("0755", 0, 8)) == 0, "Can't chmod : " << strerror(errno));
-
-        if (debug_me)
-            cout << "->flush log file again\n";
-        BOOST_CHECK_MESSAGE(theClient.flushLog() == 0, "flushLog failed \n" << theClient.errorMsg());
-
-        if (debug_me)
-            cout << "->clear the flags -> this should *ALSO* delete the server user variables\n";
-        BOOST_CHECK_MESSAGE(theClient.alter("/", "clear_flag", "log_error") == 0,
-                            "alter / clear_flag log_error : failed \n"
-                                << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.alter("/", "clear_flag", "checkpt_error") == 0,
-                            "alter / clear_flag checkpt_error : failed \n"
-                                << theClient.errorMsg());
-
-        if (debug_me)
-            cout << "->checkpoint again\n";
-        BOOST_CHECK_MESSAGE(theClient.checkPtDefs() == 0,
-                            CtsApi::checkPtDefs() << " Checkpoint expected to pass\n"
-                                                  << theClient.errorMsg());
-
-        if (debug_me)
-            cout << "->Get the defs, Check flags are cleared and server variables are deleted\n";
-        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(!theClient.defs()->get_flag().is_set(Flag::CHECKPT_ERROR),
-                            "Expected Flag::CHECKPT_ERROR to be cleared");
-        BOOST_CHECK_MESSAGE(!theClient.defs()->get_flag().is_set(Flag::LOG_ERROR),
-                            "Expected Flag::LOG_ERROR to be cleared");
-        BOOST_CHECK_MESSAGE(!theClient.defs()->server().variable_exists("ECF_CHECKPT_ERROR"),
-                            "Expected to NOT find ECF_CHECKPT_ERROR as a server variable");
-        BOOST_CHECK_MESSAGE(!theClient.defs()->server().variable_exists("ECF_LOG_ERROR"),
-                            "Expected to NOT find ECF_LOG_ERROR as a server variable");
-    }
-
-    if (debug_me)
-        cout << "->remove created directory " << ecf_home << "\n";
-    if (debug_me)
-        cout << "->current path = " << fs::current_path() << "\n";
-    if (!debug_me) {
-        BOOST_CHECK_MESSAGE(File::removeDir(ecf_home),
-                            "Failed to remove dir " << ecf_home << "  error: " << strerror(errno));
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestMigration.cpp 5.13.0-1/Client/test/TestMigration.cpp
--- 5.12.4-1/Client/test/TestMigration.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,113 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "TestHelper.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/client/Rtt.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-/**
- * Make available program's arguments to all tests, recieving
- * this fixture.
- */
-struct ArgsFixture
-{
-    ArgsFixture()
-        : argc(boost::unit_test::framework::master_test_suite().argc),
-          argv(boost::unit_test::framework::master_test_suite().argv) {}
-    int argc;
-    char** argv;
-};
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_Migration)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-// ************************************************************************************
-
-void do_test_migration(ClientInvoker& theClient,
-                       const std::string& host,
-                       const std::string& port,
-                       const std::string& directory,
-                       int& error_cnt) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (is_directory(dir_itr->status())) {
-                do_test_migration(theClient, host, port, relPath.string(), error_cnt);
-                continue;
-            }
-
-            cout << relPath.string() << "  : file size " << fs::file_size(relPath) << "\n\n";
-            if (fs::file_size(relPath) > 0) {
-                try {
-                    theClient.loadDefs(relPath.string());
-                    theClient.delete_all(true);
-                }
-                catch (std::exception& e) {
-                    error_cnt++;
-                    BOOST_CHECK_MESSAGE(false, theClient.errorMsg() << " : " << e.what());
-                }
-            }
-        }
-        catch (const std::exception& ex) {
-            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_FIXTURE_TEST_CASE(test_migration, ArgsFixture) {
-    if (argc != 2) {
-        std::cout << "Ignoring test! Since test directory is not provided\n";
-    }
-    else if (!fs::exists(argv[1])) {
-        std::cout << "Ignoring test! Since provided test directory does not exist\n";
-    }
-    else {
-        /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-        InvokeServer invokeServer("Client:: ...test_migration:", SCPort::next());
-        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                              "Migration test failed server failed to start on: " << invokeServer.host() << ":"
-                                                                                  << invokeServer.port());
-
-        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-        int error_cnt = 0;
-        do_test_migration(theClient, invokeServer.host(), invokeServer.port(), argv[1], error_cnt);
-        BOOST_REQUIRE_MESSAGE(error_cnt == 0, "Migration test failed " << error_cnt << " times ");
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestMigration_main.cpp 5.13.0-1/Client/test/TestMigration_main.cpp
--- 5.12.4-1/Client/test/TestMigration_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestMigration_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Migration
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/Client/test/TestPasswdFile.cpp 5.13.0-1/Client/test/TestPasswdFile.cpp
--- 5.12.4-1/Client/test/TestPasswdFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestPasswdFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,187 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/PasswdFile.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_PasswdFile)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-//
-// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
-//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
-//       is specified then *don't* shutdown the server
-// ************************************************************************************
-
-class Add_ECF_PASSWD_env {
-public:
-    explicit Add_ECF_PASSWD_env(const std::string& passwd_file) : env_("ECF_PASSWD=") {
-        env_ += passwd_file;
-        auto* put = const_cast<char*>(env_.c_str());
-        BOOST_CHECK_MESSAGE(putenv(put) == 0, "putenv failed for " << put);
-    }
-    ~Add_ECF_PASSWD_env() {
-        putenv(const_cast<char*>("ECF_PASSWD")); // remove from env, otherwise valgrind complains
-    }
-
-private:
-    std::string env_;
-};
-
-BOOST_AUTO_TEST_CASE(test_loading_of_passwd) {
-    Host the_host;
-    std::string host        = ClientEnvironment::hostSpecified();
-    std::string port        = SCPort::next();
-    std::string passwd_file = the_host.ecf_passwd_file(port);
-    std::string passwd      = "xxxx";
-    if (host.empty()) {
-        // make sure NO passed file is present before the server is started.
-        // Only do this locally, as passwd file on remote machine may not be accessible
-        fs::remove(passwd_file);
-    }
-    else {
-        // The test only works if server is started locally.
-        std::cout << "...Client:: ...test_loading_of_passwd ignoring when HOST specified\n";
-        return;
-    }
-
-    // cout << "passwd_file " << passwd_file << "\n";
-
-    // Set ECF_PASSWD environment variable. Use same file for client and server
-    // add on construction, and remove at destruction.
-    Add_ECF_PASSWD_env ecf_passwd(passwd_file);
-
-    // Create a valid passwd file; Before server start
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(PasswdFile::createWithAccess(passwd_file, the_host.name(), port, passwd, errorMsg), errorMsg);
-
-    // This will remove check pt and backup file before server start,
-    // to avoid the server from loading previous test data
-    InvokeServer invokeServer("Client:: ...test_loading_of_passwd", port);
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    theClient.set_throw_on_error(false);
-
-    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-
-    // reloading the same passwd file succeed.
-    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 0, CtsApi::reloadpasswdfile() << " should return 1\n");
-
-    // Invoking a client request that requires authorisation
-    BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
-    BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
-    BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
-    BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
-
-    // clear the password file.
-    errorMsg.clear();
-    BOOST_REQUIRE_MESSAGE(PasswdFile::clear(passwd_file, errorMsg), errorMsg);
-
-    // reload the password file, which is now empty
-    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 0, CtsApi::reloadpasswdfile() << " should return 1\n");
-
-    // all client command should now *FAIL*.
-    BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 1, "should return 1\n");
-    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 1, CtsApi::reloadpasswdfile() << " should return 1\n");
-
-    // Remove the white list file. Comment out for debug
-    fs::remove(passwd_file);
-}
-
-BOOST_AUTO_TEST_CASE(test_loading_of_passwd_fail) {
-    // TEST user *MUST* be in ECF_PASSWD file, into order to *ALLOW* reloadpasswdfile
-    Host the_host;
-    std::string host        = ClientEnvironment::hostSpecified();
-    std::string port        = SCPort::next();
-    std::string passwd_file = the_host.ecf_passwd_file(port);
-    std::string passwd      = "xxxx";
-    if (host.empty()) {
-        // make sure NO passed file is present before the server is started.
-        // Only do this locally, as passwd file on remote machine may not be accessible
-        fs::remove(passwd_file);
-    }
-    else {
-        // The test only works if server is started locally.
-        std::cout << "...Client:: ...test_loading_of_passwd_fail ignoring when HOST specified\n";
-        return;
-    }
-
-    // Set ECF_PASSWD environment variable. Use same file for client and server
-    // add on construction, and remove at destruction.
-    Add_ECF_PASSWD_env ecf_passwd(passwd_file);
-
-    // This will remove check pt and backup file before server start,
-    // to avoid the server from loading previous test data
-    InvokeServer invokeServer("Client:: ...test_loading_of_passwd_fail", port);
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    /// Passwd file is specified but does not exist. Command to succeed
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    theClient.set_throw_on_error(false);
-
-    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-
-    // OK now test passwd file functionality
-    // The passwd file should not exist, hence reload SHOULD fail. i.e because we deleted it earlier
-    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 1, CtsApi::reloadpasswdfile() << " should return 1\n");
-
-    // Create a valid passwd file; For the FIRST time:
-    std::string errorMsg;
-    BOOST_REQUIRE_MESSAGE(PasswdFile::createWithAccess(passwd_file, the_host.name(), port, passwd, errorMsg), errorMsg);
-
-    //  Reload should STILL fail. Since reloadpasswdfile *ITSELF* requires authentication.
-    //  Hence user *MUST* be in ECF_PASSWD file, into order to *ALLOW* reloadpasswdfile
-    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 1,
-                          CtsApi::reloadpasswdfile() << " should return 1\n"
-                                                     << theClient.errorMsg());
-
-    // Remove the white list file. Comment out for debug
-    fs::remove(passwd_file);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestPlugCmd.cpp 5.13.0-1/Client/test/TestPlugCmd.cpp
--- 5.12.4-1/Client/test/TestPlugCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestPlugCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,390 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
-#include "ecflow/base/cts/user/PlugCmd.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-
-using namespace std;
-using namespace ecf;
-
-static void get_defs(Defs& defs) {
-    // suite suite1
-    //   family family1
-    //       task a
-    //         event 1 myEvent
-    //         meter myMeter 0 100
-    //       task b
-    //          trigger a == complete
-    //    endfamily
-    //    family family2
-    //          task aa
-    //             trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
-    //          task bb
-    //             trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
-    //     endfamily
-    // endsuite
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-    std::string errorMsg, warningMsg;
-    bool parse = defs.restore(path, errorMsg, warningMsg);
-    if (!parse)
-        std::cerr << errorMsg;
-    BOOST_CHECK(parse);
-}
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_PlugCmd)
-
-BOOST_AUTO_TEST_CASE(test_plug_cmd) {
-    cout << "Client:: ...test_plug_cmd" << endl;
-    TestLog test_log("test_plug_cmd.log"); // will create log file, and destroy log and remove file at end of scope
-
-    {
-        Defs defs;
-        get_defs(defs);
-
-        /// Test failure modes, MockServer defaults to localhost:3141
-        // test source node that does not exist, fails
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new PlugCmd("I/dont/exist/on/the server", "suite1/family2")));
-
-        // test dest node that does not exist, fails
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "i/dont/exist/on/server")));
-
-        // test source node same as dest node, fails
-        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family1/a")));
-
-        // test dest node that matches local server host and port, but where path does not exist, fails
-        TestHelper::invokeFailureRequest(
-            &defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "//localhost:3141/i/dont/exist/on/local_server")));
-    }
-    {
-        Defs defs;
-        get_defs(defs);
-
-        // Lock server as another user. Invoke a valid request that should fail, due to a lock
-        MockServer server(&defs);
-        BOOST_REQUIRE_MESSAGE(server.lock("A user"), "Lock expected to succeed");
-        TestHelper::invokeFailureRequest(server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
-    }
-    {
-        Defs defs;
-        get_defs(defs);
-        MockServer server(&defs);
-
-        // Move the TASKS: on family1 --> family2
-        // Note: if on the destination node we select a task 'suite1/family2/aa', then node is moved to its parent
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new PlugCmd("suite1/family1/b", "//localhost:3141/suite1/family2/aa")));
-
-        node_ptr node = defs.findAbsNode("suite1/family1");
-        BOOST_REQUIRE_MESSAGE(node.get() && node->isFamily(), "Could not find suite1/family1");
-        BOOST_REQUIRE_MESSAGE(node->isFamily()->taskVec().size() == 0, "Failed to move task to other family");
-
-        node_ptr node2 = defs.findAbsNode("suite1/family2");
-        BOOST_REQUIRE_MESSAGE(node2.get() && node->isFamily(), "Could not find suite1/family2");
-        BOOST_REQUIRE_MESSAGE(node2->isFamily()->taskVec().size() == 4, "family2 two should have 4 tasks");
-    }
-
-    {
-        Defs defs;
-        get_defs(defs);
-        MockServer server(&defs);
-
-        // Move FAMILIES: Add a new suite and move family1 and  family2 to it.
-        defs.addSuite(Suite::create("suite2"));
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1", "suite2")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family2", "suite2")));
-
-        node_ptr suite1 = defs.findAbsNode("suite1");
-        BOOST_REQUIRE_MESSAGE(suite1.get() && suite1->isSuite(), "Could not find suite1");
-        BOOST_REQUIRE_MESSAGE(suite1->isSuite()->familyVec().size() == 0,
-                              "Expected suite1 to have '0' families as they should have been moved to suite2");
-
-        node_ptr suite2 = defs.findAbsNode("suite2");
-        BOOST_REQUIRE_MESSAGE(suite2.get() && suite2->isSuite(), "Could not find suite2");
-        BOOST_REQUIRE_MESSAGE(suite2->isSuite()->familyVec().size() == 2, "Expected suite2 to have '2' families");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_plug_cmd_preserves_server_state) {
-    cout << "Client:: ...test_plug_cmd_preserves_server_state" << endl;
-    TestLog test_log("test_plug_cmd_preserves_server_state.log"); // will create log file, and destroy log and remove
-                                                                  // file at end of scope
-
-    {
-        Defs defs;
-        get_defs(defs);
-        MockServer server(&defs);
-        server.shutdown();
-
-        // Move the TASKS: on family1 --> family2
-        TestHelper::invokeRequest(&server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
-
-        BOOST_CHECK_MESSAGE(server.state() == SState::SHUTDOWN,
-                            "Expected server state SHUTDOWN to be preserved after plug, but found state "
-                                << SState::to_string(server.state()));
-    }
-    {
-        Defs defs;
-        get_defs(defs);
-        MockServer server(&defs);
-        server.halted();
-
-        // Move the TASKS: on family1 --> family2
-        TestHelper::invokeRequest(&server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
-
-        BOOST_CHECK_MESSAGE(server.state() == SState::HALTED,
-                            "Expected server state HALTED to be preserved after plug, but found state "
-                                << SState::to_string(server.state()));
-    }
-    {
-        Defs defs;
-        get_defs(defs);
-        MockServer server(&defs);
-        server.restart();
-
-        // Move the TASKS: on family1 --> family2
-        TestHelper::invokeRequest(&server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
-
-        BOOST_CHECK_MESSAGE(server.state() == SState::RUNNING,
-                            "Expected server state RUNNING to be preserved after plug, but found state "
-                                << SState::to_string(server.state()));
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_plug_cmd_with_handles) {
-    cout << "Client:: ...test_plug_cmd_with_handles" << endl;
-    TestLog test_log(
-        "test_plug_cmd_with_handles.log"); // will create log file, and destroy log and remove file at end of scope
-
-    Defs defs;
-    get_defs(defs);
-
-    /// create client handle which references suites suite in the server defs
-    std::vector<std::string> suite_names;
-    suite_names.emplace_back("suite");
-    suite_names.emplace_back("suite2");
-    TestHelper::invokeRequest(
-        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), false /* bypass_state_modify_change_check */);
-
-    { // Move the TASKS: on family1 --> family2
-        // Note: if on the destination node we select a task 'suite1/family2/aa', then node is moved to its parent
-        Suite* suite                  = defs.findAbsNode("suite1")->isSuite();
-        unsigned int state_change_no  = suite->state_change_no();
-        unsigned int modify_change_no = suite->modify_change_no();
-
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
-        TestHelper::invokeRequest(&defs,
-                                  Cmd_ptr(new PlugCmd("suite1/family1/b", "//localhost:3141/suite1/family2/aa")));
-
-        BOOST_CHECK_MESSAGE(state_change_no != suite->state_change_no() ||
-                                modify_change_no != suite->modify_change_no(),
-                            "state and modify change numbers unaltered by plug command when using handles");
-    }
-
-    { // Move FAMILIES: Add a new suite and move family1 and  family2 to it.
-        suite_ptr suite2              = defs.add_suite("suite2");
-        unsigned int state_change_no  = suite2->state_change_no();
-        unsigned int modify_change_no = suite2->modify_change_no();
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1", "suite2")));
-        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family2", "suite2")));
-        BOOST_CHECK_MESSAGE(state_change_no != suite2->state_change_no() ||
-                                modify_change_no != suite2->modify_change_no(),
-                            "state and modify change numbers unaltered by plug command when using handles");
-    }
-}
-
-static void test_plug_on_multiple_server(const std::string& host1,
-                                         const std::string& port1,
-                                         const std::string& host2,
-                                         const std::string& port2) {
-    std::cout << " on host1(" << host1 << ":" << port1 << ") host2(" << host2 << ":" << port2 << ")" << endl;
-    ClientInvoker server1Client(host1, port1);
-    server1Client.set_throw_on_error(false);
-    ClientInvoker server2Client(host2, port2);
-    server2Client.set_throw_on_error(false);
-
-    // std::cout << " restartServer the FIRST and SECOND servers" << endl;
-    BOOST_REQUIRE_MESSAGE(server1Client.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
-                                                  << server1Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server2Client.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
-                                                  << server2Client.errorMsg());
-
-    // std::cout << " LOAD the defs into FIRST server(" << host1 << ":" << port1 << ") There is NO DEFS in the second
-    // server." << endl;
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-    BOOST_REQUIRE_MESSAGE(server1Client.loadDefs(path) == 0, "load defs failed \n" << server1Client.errorMsg());
-
-    // cout << " Test the ERROR conditions in MoveCmd" << endl;
-    std::string sourcePath = "/suite1";
-    std::string secondServerHostPort =
-        "//localhost:" + port2; // The destination path must encode the host:port path to the second server
-
-    std::string destPath = secondServerHostPort + "/A/made/up/dest/path/that/does/not/exist/on/server2";
-    // cout << " Plug/Move from server1(" << host1 << ":" << port1 << ") to destination server " << destPath << endl;
-    int theResult = server1Client.plug(sourcePath, destPath);
-    BOOST_REQUIRE_MESSAGE(theResult == 1, CtsApi::plugArg() << "Expected to fail since no defs in server 2\n");
-    // 	std::cout << "Error message = " << server1Client.errorMsg() << "\n";
-
-    // cout << " *** Load Defs into SECOND server ***, ie both servers have the same definitions" << endl;
-    BOOST_REQUIRE_MESSAGE(server2Client.loadDefs(path) == 0, "load defs failed \n" << server2Client.errorMsg());
-
-    destPath  = secondServerHostPort + "/suite1";
-    theResult = server1Client.plug(sourcePath, destPath);
-    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
-    BOOST_REQUIRE_MESSAGE(theResult == 1,
-                          CtsApi::plugArg() << " Expected to fail, since 'suite1' already exists in the server  \n");
-
-    destPath  = secondServerHostPort + "/suite1/family1";
-    theResult = server1Client.plug(sourcePath, destPath);
-    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
-    BOOST_REQUIRE_MESSAGE(theResult == 1,
-                          CtsApi::plugArg() << " Expected to fail, since can't move a suite into a family\n");
-
-    destPath  = secondServerHostPort + "/suite1";
-    theResult = server1Client.plug("/suite1/family1", destPath);
-    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
-    BOOST_REQUIRE_MESSAGE(theResult == 1,
-                          CtsApi::plugArg() << " Expected to fail, Destination already has a family1 \n");
-
-    destPath  = secondServerHostPort + "/A/made/up/dest/path/that/does/not/exist/on/server2";
-    theResult = server1Client.plug(sourcePath, destPath);
-    //  	cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
-    BOOST_REQUIRE_MESSAGE(theResult == 1,
-                          CtsApi::plugArg() << " Expected to fail, since destination path does not exist\n");
-
-    destPath  = secondServerHostPort;
-    theResult = server1Client.plug("/suite1/family1", destPath);
-    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
-    BOOST_REQUIRE_MESSAGE(
-        theResult == 1,
-        CtsApi::plugArg()
-            << " Expected to fail,since source path must be a suite, if the destination path name is empty\n");
-
-    // ==========================================================================================
-    // Test Plug command works
-    // ==========================================================================================
-
-    // Completely remove the 'suite1' file in the second server
-    BOOST_REQUIRE_MESSAGE(server2Client.delete_node(sourcePath) == 0,
-                          CtsApi::to_string(CtsApi::delete_node(sourcePath)) << " failed \n"
-                                                                             << server2Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server2Client.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << server2Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server2Client.defs().get(), "Server returned a NULL defs");
-    BOOST_REQUIRE_MESSAGE(server2Client.defs()->suiteVec().size() == 0, " Expected server2 to have zero suite");
-
-    // Move the suite FROM the FIRST server TO the SECOND server and check that it worked
-    destPath  = secondServerHostPort;
-    theResult = server1Client.plug(sourcePath, destPath);
-    BOOST_REQUIRE_MESSAGE(theResult == 0, CtsApi::plugArg() << " failed \n" << server1Client.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(server1Client.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << server1Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server1Client.defs().get(), "Server returned a NULL defs");
-    BOOST_REQUIRE_MESSAGE(server1Client.defs()->suiteVec().size() == 0, " Expected server1 to have no suites");
-
-    BOOST_REQUIRE_MESSAGE(server2Client.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << server2Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server2Client.defs().get(), "Server returned a NULL defs");
-    BOOST_REQUIRE_MESSAGE(server2Client.defs()->suiteVec().size() == 1, " Expected server2 to have one suite");
-
-    // ==========================================================================
-    // Do it again, but with no defs file in second server. reload defs into server1
-    BOOST_REQUIRE_MESSAGE(server1Client.delete_all() == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " failed \n"
-                                                                   << server1Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server2Client.delete_all() == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " failed \n"
-                                                                   << server2Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server1Client.loadDefs(path) == 0, "load defs failed \n" << server1Client.errorMsg());
-
-    destPath  = secondServerHostPort;
-    theResult = server1Client.plug(sourcePath, destPath);
-    BOOST_REQUIRE_MESSAGE(theResult == 0, CtsApi::plugArg() << " failed \n" << server1Client.errorMsg());
-
-    BOOST_REQUIRE_MESSAGE(server1Client.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << server1Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server1Client.defs().get(), "Server returned a NULL defs");
-    BOOST_REQUIRE_MESSAGE(server1Client.defs()->suiteVec().size() == 0, " Expected server1 to have no suites");
-
-    BOOST_REQUIRE_MESSAGE(server2Client.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << server2Client.errorMsg());
-    BOOST_REQUIRE_MESSAGE(server2Client.defs().get(), "Server returned a NULL defs");
-    BOOST_REQUIRE_MESSAGE(server2Client.defs()->suiteVec().size() == 1, " Expected server2 to have one suite");
-}
-
-BOOST_AUTO_TEST_CASE(test_server_plug_cmd) {
-    if (ClientEnvironment::hostSpecified().empty()) {
-
-        cout << "Client:: ...test_server_plug_cmd";
-
-        // Invoke two servers. *which* will both terminate at the end of this scope
-        // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-        // data
-        InvokeServer invokeServer1("", SCPort::next());
-        InvokeServer invokeServer2("", SCPort::next());
-        BOOST_REQUIRE_MESSAGE(invokeServer1.server_started(),
-                              "Server failed to start on " << invokeServer1.host() << ":" << invokeServer1.port());
-        BOOST_REQUIRE_MESSAGE(invokeServer2.server_started(),
-                              "Server failed to start on " << invokeServer2.host() << ":" << invokeServer2.port());
-
-        test_plug_on_multiple_server(
-            invokeServer1.host(), invokeServer1.port(), invokeServer2.host(), invokeServer2.port());
-    }
-    else {
-
-        cout << "Client:: ...test_server_plug_cmd";
-
-        // Remote server all ready running, start one more additional server
-        {
-            // remove any suites on the remote server. Since this test requires it.
-            ClientInvoker theClient(ClientEnvironment::hostSpecified(), ClientEnvironment::portSpecified());
-            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                                  CtsApi::to_string(CtsApi::delete_node())
-                                      << " failed should return 0. Should Delete ALL existing defs in the server\n"
-                                      << theClient.errorMsg());
-        }
-
-        // Start additional local server, special constructor. need false flag, to avoid ambiguity, with the other
-        // constructor.
-        std::string port2 = SCPort::next_only();
-        InvokeServer invokeServer2(port2, false);
-        BOOST_REQUIRE_MESSAGE(invokeServer2.server_started(),
-                              "Server failed to start on " << invokeServer2.host() << ":" << invokeServer2.port());
-
-        test_plug_on_multiple_server(
-            ClientEnvironment::hostSpecified(), ClientEnvironment::portSpecified(), Str::LOCALHOST(), port2);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestRtt.cpp 5.13.0-1/Client/test/TestRtt.cpp
--- 5.12.4-1/Client/test/TestRtt.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestRtt.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,51 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/client/Rtt.hpp"
-#include "ecflow/core/File.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_Rtt)
-
-BOOST_AUTO_TEST_CASE(test_client_invoker_round_trip_times) {
-    cout << "Client:: ...test_client_invoker_round_trip_times" << endl;
-
-    std::string root_path = File::test_data("Client/test/data/", "Client");
-
-    /// Open file rtt.dat and compute average round trip times
-    std::string result = Rtt::analyis(root_path + "rtt.dat");
-    // cout << result << "\n";
-
-    /// generated a file with results
-    std::string errorMsg;
-    string generated_file = root_path + "rtt_analysis.dat";
-    BOOST_CHECK_MESSAGE(File::create(generated_file, result, errorMsg), errorMsg);
-
-    /// Compare with a reference file
-    std::vector<std::string> ignoreVec;
-    errorMsg.clear();
-    std::string diffs = File::diff(generated_file, root_path + "ref_analysis.dat", ignoreVec, errorMsg);
-    BOOST_CHECK_MESSAGE(diffs.empty(), diffs << "\n" << errorMsg);
-
-    if (diffs.empty())
-        fs::remove(generated_file);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestServer.cpp 5.13.0-1/Client/test/TestServer.cpp
--- 5.12.4-1/Client/test/TestServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,607 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
-#include <boost/test/unit_test.hpp>
-#include <boost/timer/timer.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/core/perf_timer.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_Server)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-//
-// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
-//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
-//       is specified then *don't* shutdown the server
-// ************************************************************************************
-
-BOOST_AUTO_TEST_CASE(test_server_version) {
-    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-    InvokeServer invokeServer("Client:: ...test_server_version:", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.server_version() == 0, "server version\n" << theClient.errorMsg());
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // This check only valid if server was invoked locally. Ignore for remote servers
-        BOOST_REQUIRE_MESSAGE(theClient.get_string() == Version::raw(),
-                              "Expected client version(" << Version::raw() << ") to match server version("
-                                                         << theClient.get_string() << ")");
-    }
-    else {
-        // remote server, version may be different
-        BOOST_WARN_MESSAGE(theClient.get_string() == Version::raw(),
-                           "Client version(" << Version::raw() << ") does not match server version("
-                                             << theClient.get_string() << ")");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_server_state_changes) {
-    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-    InvokeServer invokeServer("Client:: ...test_server_state_changes:", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << theClient.errorMsg());
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // server started locally
-        BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
-                              "Expected INITIAL server state HALTED but found "
-                                  << SState::to_string(theClient.defs()->server().get_state()));
-    }
-
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::SHUTDOWN,
-                          "Expected server state SHUTDOWN but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
-                          "Expected server state HALTED but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                          CtsApi::get() << " failed should return 0\n"
-                                        << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::RUNNING,
-                          "Expected server state RUNNING but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    /// Repeat test using sync_local() to test incremental changes of server
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, " failed should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::SHUTDOWN,
-                          "Expected server state SHUTDOWN but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, " failed should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
-                          "Expected server state HALTED but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, " failed should return 0\n" << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::RUNNING,
-                          "Expected server state RUNNING but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // This check only valid if server was invoked locally. Ignore for remote servers
-
-        // make sure edit history updated
-        BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
-                              CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
-                                                                                        << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 7,
-                              "Expected edit history of size 7, but found "
-                                  << theClient.server_reply().get_string_vec().size());
-
-        // make sure edit history was *NOT* serialized, It is only serialized when check pointing
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.defs()->get_edit_history(Str::ROOT_PATH()).size() == 0,
-                              "Expected edit history of size 0, but found "
-                                  << theClient.defs()->get_edit_history(Str::ROOT_PATH()).size());
-
-        // clear edit history
-        BOOST_REQUIRE_MESSAGE(theClient.edit_history("clear") == 0,
-                              CtsApi::to_string(CtsApi::edit_history("clear")) << " should return 0\n"
-                                                                               << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
-                              CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
-                                                                                        << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 0,
-                              "Expected no edit history " << theClient.server_reply().get_string_vec().size());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_server_state_changes_with_auto_sync) {
-    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-    InvokeServer invokeServer("Client:: ...test_server_state_changes_with_auto_sync:", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    theClient.set_auto_sync(true);
-
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // server started locally
-        BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
-                              "Expected INITIAL server state HALTED but found "
-                                  << SState::to_string(theClient.defs()->server().get_state()));
-    }
-
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::SHUTDOWN,
-                          "Expected server state SHUTDOWN but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
-                          "Expected server state HALTED but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::RUNNING,
-                          "Expected server state RUNNING but found "
-                              << SState::to_string(theClient.defs()->server().get_state()));
-
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // This check only valid if server was invoked locally. Ignore for remote servers
-
-        // make sure edit history updated
-        BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
-                              CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
-                                                                                        << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 8 &&
-                                  theClient.server_reply().get_string_vec().size() <=
-                                      Defs::max_edit_history_size_per_node(),
-                              "Expected edit history of size 8, but found "
-                                  << theClient.server_reply().get_string_vec().size() << "\n"
-                                  << Str::dump_string_vec(theClient.server_reply().get_string_vec()));
-
-        // make sure edit history was *NOT* serialized, It is only serialized when check pointing
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.defs()->get_edit_history(Str::ROOT_PATH()).size() == 0,
-                              "Expected edit history of size 0, but found "
-                                  << theClient.defs()->get_edit_history(Str::ROOT_PATH()).size());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_server_stress_test) {
-    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-    InvokeServer invokeServer("Client:: ...test_server_stress_test:", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    int load = 125;
-#ifdef ECF_OPENSSL
-    if (getenv("ECF_SSL"))
-        load = 30;
-#endif
-
-    {
-        boost::timer::cpu_timer boost_timer;
-        DurationTimer duration_timer;
-        Timer<std::chrono::milliseconds> chrono_timer;
-        for (int i = 0; i < load; i++) {
-
-            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                                  CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                           << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.suspend("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.resume("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                                  CtsApi::shutdownServer() << " should return 0\n"
-                                                           << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                                  CtsApi::haltServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                                  CtsApi::restartServer() << " should return 0\n"
-                                                          << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "unknown", true) == 0,
-                                  "check should return 0\n"
-                                      << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-
-            BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
-            BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
-        }
-        cout << " Server handled " << load * 16 << " requests in boost_timer("
-             << boost_timer.format(3, Str::cpu_timer_format()) << ")"
-             << " DurationTimer(" << to_simple_string(duration_timer.elapsed()) << ")"
-             << " Chrono_timer(" << std::chrono::duration<double, std::milli>(chrono_timer.elapsed()).count()
-             << " milli)" << endl;
-    }
-    {
-        theClient.set_auto_sync(true);
-        boost::timer::cpu_timer
-            boost_timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-        DurationTimer duration_timer;
-        Timer<std::chrono::milliseconds> chrono_timer;
-        for (int i = 0; i < load; i++) {
-
-            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                                  CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                           << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.suspend("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.resume("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                                  CtsApi::shutdownServer() << " should return 0\n"
-                                                           << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                                  CtsApi::haltServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                                  CtsApi::restartServer() << " should return 0\n"
-                                                          << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "unknown", true) == 0,
-                                  "check should return 0\n"
-                                      << theClient.errorMsg());
-
-            BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
-            BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
-        }
-        cout << " Server handled " << load * 8 << " requests in boost_timer("
-             << boost_timer.format(3, Str::cpu_timer_format()) << ")"
-             << " DurationTimer(" << to_simple_string(duration_timer.elapsed()) << ")"
-             << " Chrono_timer(" << std::chrono::duration<double, std::milli>(chrono_timer.elapsed()).count()
-             << " milli)"
-             << " *with* AUTO SYNC" << endl;
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_server_group_stress_test) {
-    /// This is exactly the same test as above, but uses the group command
-    /// This should be faster as the network traffic should be a lot less
-    InvokeServer invokeServer("Client:: ...test_server_group_stress_test:", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    boost::timer::cpu_timer
-        boost_timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-    DurationTimer duration_timer;
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-
-    std::string groupRequest = CtsApi::to_string(CtsApi::delete_node());
-    groupRequest += ";";
-    groupRequest += CtsApi::to_string(CtsApi::loadDefs(path, true /*force*/, false /*check_only*/, false /*print*/));
-    groupRequest += ";";
-    groupRequest += CtsApi::shutdownServer();
-    groupRequest += ";";
-    groupRequest += CtsApi::haltServer();
-    groupRequest += ";";
-    groupRequest += CtsApi::restartServer();
-    groupRequest += ";";
-    groupRequest += CtsApi::restartServer();
-    groupRequest += ";";
-    groupRequest += CtsApi::checkPtDefs();
-    groupRequest += ";";
-    groupRequest += CtsApi::get();
-
-    // cout << "groupRequest = " << groupRequest << "\n";
-
-    int load = 125;
-#ifdef ECF_OPENSSL
-    if (getenv("ECF_SSL"))
-        load = 30;
-#endif
-
-    for (int i = 0; i < load; i++) {
-        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
-                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
-                                               << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
-        BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
-    }
-    cout << " Server handled " << load * 8 << " commands using " << load << " group requests in boost_timer("
-         << boost_timer.format(3, Str::cpu_timer_format()) << ") DurationTimer("
-         << to_simple_string(duration_timer.elapsed()) << ")" << endl;
-}
-
-BOOST_AUTO_TEST_CASE(test_server_stress_test_2) {
-    /// More extensive stress test, using as many user based command as possible.
-    ///
-    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-    InvokeServer invokeServer("Client:: ...test_server_stress_test_2:", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    Zombie z(Child::USER,
-             ecf::Child::INIT,
-             ZombieAttr::get_default_attr(Child::USER),
-             "path_to_task",
-             "DUMMY_JOBS_PASSWORD",
-             "DUMMY_PROCESS_OR_REMOTE_ID",
-             1,
-             "host");
-    std::vector<std::string> suites;
-    suites.emplace_back("suite1");
-    suites.emplace_back("made_up_suite");
-
-    std::vector<std::string> nodes_to_delete;
-    nodes_to_delete.emplace_back("/suite1/family2/aa"); // these should exist in lifecycle.txt
-    nodes_to_delete.emplace_back("/suite1/family2/bb");
-
-#if defined(HPUX)
-    int load = 10; // On non linux systems use different load otherwise it takes to long
-#elif defined(_AIX)
-    int load = 65; // On non linux systems use different load otherwise it takes to long
-#else
-    int load = 130;
-#endif
-
-#ifdef ECF_OPENSSL
-    if (getenv("ECF_SSL"))
-        load = 10;
-#endif
-
-    boost::timer::cpu_timer
-        boost_timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
-    DurationTimer duration_timer;
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    theClient.set_throw_on_error(false);
-
-    for (int i = 0; i < load; i++) {
-
-        BOOST_REQUIRE_MESSAGE(theClient.pingServer() == 0, " ping should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                              CtsApi::shutdownServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                              CtsApi::haltServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.news_local() == 0,
-                              " new local failed should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.stats() == 0, CtsApi::stats() << " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
-                              CtsApi::stats_server() << " should return 0\n"
-                                                     << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.suites() == 0,
-                              CtsApi::suites() << " should return 0\n"
-                                               << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.server_version() == 0,
-                              CtsApi::server_version() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.debug_server_off() == 0,
-                              CtsApi::debug_server_off() << " should return 0\n"
-                                                         << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.check("/suite1") == 0, "check should return 0\n" << theClient.errorMsg()); // 13
-
-        BOOST_REQUIRE_MESSAGE(theClient.logMsg("start") == 0, "log msg should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.get_log_path() == 0, "get_log_path should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.getLog(1) == 0, "get_log last line should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.flushLog() == 0, "flushLog should return 0\n" << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "unknown", true) == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "complete", true) == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "submitted", true) == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "active", true) == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "aborted", true) == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "queued", true) == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1/family1/a:myEvent", "set") == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1/family1/a:myEvent", "clear") == 0,
-                              "check should return 0\n"
-                                  << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.zombieGet() == 0,
-                              CtsApi::zombieGet() << " should return 0\n"
-                                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.zombieFob(z) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.zombieFail(z) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.zombieAdopt(z) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.zombieBlock(z) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.zombieRemove(z) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.zombieKill(z) == 0, " should return 0\n" << theClient.errorMsg()); // 19
-
-        BOOST_REQUIRE_MESSAGE(theClient.suspend("/suite1") == 0,
-                              CtsApi::to_string(CtsApi::suspend("/suite1")) << " should return 0\n"
-                                                                            << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.resume("/suite1") == 0,
-                              CtsApi::to_string(CtsApi::resume("/suite1")) << " should return 0\n"
-                                                                           << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.edit_history("/suite1") == 0,
-                              CtsApi::to_string(CtsApi::edit_history("/suite1")) << " should return 0\n"
-                                                                                 << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true, true) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, false, true) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg()); // 26
-
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
-                              CtsApi::checkPtDefs() << " should return 0\n"
-                                                    << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::NEVER) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ALWAYS) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, 180) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg()); // 32
-        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, CheckPt::default_interval()) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1") == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", true, true, true, true) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", true) == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", false, true) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", false, false, true) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", false, false, false, true) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg()); // 38
-
-        BOOST_REQUIRE_MESSAGE(theClient.ch_register(true, suites) == 0, "--ch_register \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_suites() == 0, "--ch_suites should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_add(1, suites) == 0, "--ch_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_remove(1, suites) == 0, "--ch_remove \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, true) == 0, "--ch_auto_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, false) == 0, "--ch_auto_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch_drop(1) == 0, "--ch_drop should return 0\n" << theClient.errorMsg()); // 45
-
-        BOOST_REQUIRE_MESSAGE(theClient.ch_register(true, suites) == 0, "--ch_register \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_add(suites) == 0, "--ch1_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(true) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(false) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_remove(suites) == 0, "--ch1_remove \n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.ch1_drop() == 0, "--ch1_drop \n" << theClient.errorMsg()); // 51
-
-        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", "top") == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", "bottom") == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", "alpha") == 0, " should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", NOrder::ORDER) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", NOrder::UP) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", NOrder::DOWN) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg()); // 57
-
-        BOOST_REQUIRE_MESSAGE(theClient.delete_node("/suite1/family1/a") == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.delete_nodes(nodes_to_delete) == 0,
-                              " should return 0\n"
-                                  << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg()); // 60
-        BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
-        BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
-    }
-
-    int no_of_client_calls = 74;
-
-    cout << " Server handled " << load * no_of_client_calls << " requests in boost_timer("
-         << boost_timer.format(3, Str::cpu_timer_format()) << ") DurationTimer("
-         << to_simple_string(duration_timer.elapsed()) << ")" << endl;
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestServerAndLifeCycle.cpp 5.13.0-1/Client/test/TestServerAndLifeCycle.cpp
--- 5.12.4-1/Client/test/TestServerAndLifeCycle.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestServerAndLifeCycle.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,296 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Submittable.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/System.hpp" // kill singleton for valgrind
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_ServerAndLifeCycle)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-//
-// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
-//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
-//       is specified then *don't* shutdown the server
-// ************************************************************************************
-
-BOOST_AUTO_TEST_CASE(test_client_lifecyle) {
-    // *******************************************************************************************
-    // This test will *ONLY* work when testing with new server invocation, since it relies
-    // on disabling job generation. Hence ignore test if ECF_HOST has been defined
-    // *******************************************************************************************
-    std::string host = ClientEnvironment::hostSpecified();
-    if (!host.empty()) {
-        // Server allready started, since we cant disable job generation ignore this test
-        std::cout << "Client:: ...test_client_lifecycle, ignoring test when ECF_HOST specified..." << endl;
-        return;
-    }
-
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-    // ** NOTE: We disable job generation in the server **/
-    InvokeServer invokeServer(
-        "Client:: ...test_client_lifecycle", SCPort::next(), true /*disable job generation in server*/);
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
-                                                  << theClient.errorMsg());
-
-    // load the defs into the server
-    {
-        std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "Load defs failed \n" << theClient.errorMsg());
-    }
-    {
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "Server returned a NULL defs");
-        BOOST_REQUIRE_MESSAGE(serverDefs->suiteVec().size() >= 1, "  no suite ?");
-    }
-
-    // Now go through and simulate client request to change Node tree state.
-    // This is **highly** dependent on lifecycle.txt
-    //	suite suite1
-    //	  family family1
-    //	   	task a
-    //	        event 1 myEvent
-    //	        meter myMeter 0 100
-    //	   	task b
-    //	   		trigger a == complete
-    //	   endfamily
-    //	   family family2
-    //	   		task aa
-    //	   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
-    //	   		task bb
-    //	   			trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
-    //	    endfamily
-    //	endsuite
-
-    string suite1_family1_a  = "suite1/family1/a";
-    string suite1_family1_b  = "suite1/family1/b";
-    string suite1_family2_aa = "suite1/family2/aa";
-    string suite1_family2_bb = "suite1/family2/bb";
-
-    {
-        // Begin will set all states to queued and then start job submission placing
-        // any submitted jobs into the active state. Note server setup has disabled job generation
-        BOOST_REQUIRE_MESSAGE(theClient.begin("suite1") == 0,
-                              CtsApi::begin("suite1") << " failed should return 0\n"
-                                                      << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-        defs_ptr serverDefs = theClient.defs();
-        node_ptr node       = serverDefs->findAbsNode(suite1_family1_a);
-
-        // Occasionally we get a random failure here. I suspect this is because the job generation caused by the
-        // BeginCmd, is such that the
-        //     time_now >= next_poll_time_   //* next_poll_time_ should always be at the minute interval
-        // When this happens, we defer job generation for a second:  See
-        // NodeTreeTraverser::traverse_node_tree_and_job_generate: line 343 Added time to confirm. If this the case, run
-        // test when not at/near minute interval
-        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be "
-                                  << NState::toString(node->state()) << " time now:" << Calendar::second_clock_time());
-    }
-
-    //**********************************************************************
-    // Create a request to set the event on Node suite1/family1/a
-    // This should place suite1_family2_bb immediately into submitted state
-    // Since we at least one node in submitted, suite should be in SUBMITTED state
-    {
-        theClient.taskPath(suite1_family1_a);
-        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
-        BOOST_REQUIRE_MESSAGE(theClient.eventTask("myEvent") == 0, " failed should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                              CtsApi::forceDependencyEval() << " failed should return 0\n"
-                                                            << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-        defs_ptr serverDefs = theClient.defs();
-        // PrintStyle style(PrintStyle::STATE);
-        // 		cerr << *serverDefs.get() << "\n";
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        node_ptr node = serverDefs->findAbsNode(suite1_family1_a);
-        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(node->state()));
-        node_ptr nodeb = serverDefs->findAbsNode(suite1_family2_bb);
-        BOOST_REQUIRE_MESSAGE(nodeb->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeb->state()));
-    }
-
-    //**********************************************************************
-    // Create a request to set the Meter on Node suite1/family1/a
-    // This should force suite1_family2_aa immediately into submitted state
-    // This should force suite1_family2_bb immediately into submitted state
-    {
-        theClient.taskPath(suite1_family1_a);
-        {
-            char* argv[] = {
-                const_cast<char*>("ClientInvoker"), const_cast<char*>("--meter=myMeter"), const_cast<char*>("100")};
-            BOOST_REQUIRE_MESSAGE(theClient.invoke(3, argv) == 0, " should return 0\n" << theClient.errorMsg());
-            BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                                  CtsApi::forceDependencyEval() << " failed should return 0\n"
-                                                                << theClient.errorMsg());
-        }
-
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        node_ptr nodeaa = serverDefs->findAbsNode(suite1_family2_aa);
-        BOOST_REQUIRE_MESSAGE(nodeaa->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeaa->state()));
-
-        node_ptr nodebb = serverDefs->findAbsNode(suite1_family2_bb);
-        BOOST_REQUIRE_MESSAGE(nodebb->state() == NState::ACTIVE,
-                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodebb->state()));
-    }
-
-    //**********************************************************************
-    // Create a request to complete task suite1/family1/a
-    // This should force suite1_family1_b to complete
-    {
-        theClient.taskPath(suite1_family1_a);
-        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
-                              TaskApi::complete() << " failed should return 0\n"
-                                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                              CtsApi::forceDependencyEval() << " failed should return 0\n"
-                                                            << theClient.errorMsg());
-
-        // Resolve dependencies
-        // We could either wait 60 second or
-        // added a custom command that will force dependency evaluation
-        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                              "--force-dep-eval failed should return 0\n"
-                                  << theClient.errorMsg());
-
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        node_ptr node = serverDefs->findAbsNode(suite1_family1_b);
-        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
-                              "Expected NState::ACTIVE, but found " << NState::toString(node->state()));
-    }
-
-    //********************************************************************************
-    // Complete the remaining tasks. Should really call init first, but what the eck.
-    {
-        theClient.taskPath(suite1_family1_b);
-        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
-                              TaskApi::complete() << " failed should return 0\n"
-                                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                              CtsApi::forceDependencyEval() << " failed should return 0\n"
-                                                            << theClient.errorMsg());
-
-        theClient.taskPath(suite1_family2_aa);
-        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
-                              TaskApi::complete() << " failed should return 0\n"
-                                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                              CtsApi::forceDependencyEval() << " failed should return 0\n"
-                                                            << theClient.errorMsg());
-
-        theClient.taskPath(suite1_family2_bb);
-        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
-                              TaskApi::complete() << " failed should return 0\n"
-                                                  << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
-                              CtsApi::forceDependencyEval() << " failed should return 0\n"
-                                                            << theClient.errorMsg());
-    }
-
-    {
-        // Get the node tree back from the server, and check its node state
-        // All node state should be complete. + check meter/event value was set properly
-        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
-                              CtsApi::get() << " failed should return 0\n"
-                                            << theClient.errorMsg());
-
-        defs_ptr serverDefs = theClient.defs();
-        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
-
-        std::string metername = "myMeter";
-        int meterValue        = 100;
-        node_ptr node         = serverDefs->findAbsNode(suite1_family1_a);
-        const Meter& theMeter = node->findMeter(metername);
-        BOOST_REQUIRE_MESSAGE(!theMeter.empty(), "Could not find the meter");
-        BOOST_REQUIRE_MESSAGE(theMeter.value() == meterValue,
-                              "Expected meter value " << meterValue << " but found " << theMeter.value());
-        {
-            std::string errorMsg;
-            BOOST_REQUIRE_MESSAGE(serverDefs->checkInvariants(errorMsg), errorMsg);
-        }
-
-        std::string eventname = "myEvent";
-        const Event& theEvent = node->findEventByNameOrNumber(eventname);
-        BOOST_REQUIRE_MESSAGE(!theEvent.empty(), "Could not find the event myEvent");
-        BOOST_REQUIRE_MESSAGE(theEvent.value(), "The event was not set");
-
-        const std::vector<suite_ptr>& suiteVec = serverDefs->suiteVec();
-        suite_ptr suite                        = suiteVec.back();
-        BOOST_REQUIRE_MESSAGE(suite->state() == NState::COMPLETE,
-                              "Suite expected NState::COMPLETE, but found to be " << NState::toString(suite->state()));
-    }
-
-    {
-        // Check that a log file was created, by asking the server for it.
-        BOOST_REQUIRE_MESSAGE(theClient.getLog() == 0, "get log failed should return 0\n" << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(!theClient.get_string().empty(), "The log file returned from the server is empty!!");
-
-        // Clear the log
-        BOOST_REQUIRE_MESSAGE(theClient.flushLog() == 0,
-                              CtsApi::flushLog() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.clearLog() == 0,
-                              CtsApi::clearLog() << " failed should return 0\n"
-                                                 << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-    }
-
-    /// Destroy singleton's to avoid valgrind from complaining
-    System::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestServerLoad.cpp 5.13.0-1/Client/test/TestServerLoad.cpp
--- 5.12.4-1/Client/test/TestServerLoad.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestServerLoad.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,138 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/File.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_ServerLoad)
-
-BOOST_AUTO_TEST_CASE(test_server_load) {
-    // Check if gnuplot is found on the path, on the RPM machines gnuplot not always installed
-    std::string path_to_gnuplot = File::which("gnuplot");
-    if (path_to_gnuplot.empty()) {
-        cout << "Client:: ...test_server_load -----> gnuplot not found on $PATH *IGNORING* test\n";
-        return;
-    }
-
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-    InvokeServer invokeServer("Client:: ...test_server_load", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-
-    // add some text in log file, need at least 4 different time-stamps for plotting
-    int load = 2;
-    for (int i = 0; i < load; i++) {
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                              CtsApi::shutdownServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                              CtsApi::haltServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-    }
-    sleep(1); // need a time gap
-    for (int i = 0; i < load; i++) {
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                              CtsApi::shutdownServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                              CtsApi::haltServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-    }
-    sleep(1); // need a time gap
-    for (int i = 0; i < load; i++) {
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                              CtsApi::shutdownServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                              CtsApi::haltServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-    }
-    sleep(1); // need a time gap
-    for (int i = 0; i < load; i++) {
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                              CtsApi::shutdownServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                              CtsApi::haltServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-    }
-
-    // Now generate gnuplot files.
-    BOOST_REQUIRE_MESSAGE(theClient.server_load() == 0,
-                          CtsApi::server_load_arg() << " should return 0 server not started, or connection refused\n"
-                                                    << theClient.errorMsg());
-
-    // Check files were created
-    Host the_host(invokeServer.host());
-    std::string gnuplot_dat_file    = the_host.prefix_host_and_port(invokeServer.port(), "gnuplot.dat");
-    std::string gnuplot_script_file = the_host.prefix_host_and_port(invokeServer.port(), "gnuplot.script");
-    std::string gnuplot_png_file    = the_host.prefix_host_and_port(invokeServer.port(), "png");
-
-    BOOST_REQUIRE_MESSAGE(fs::exists(gnuplot_dat_file),
-                          CtsApi::server_load_arg() << " failed file(" << gnuplot_dat_file << ") not generated");
-    BOOST_REQUIRE_MESSAGE(fs::exists(gnuplot_script_file),
-                          CtsApi::server_load_arg() << " failed file(" << gnuplot_script_file << ") not generated");
-    BOOST_REQUIRE_MESSAGE(fs::exists(gnuplot_png_file),
-                          CtsApi::server_load_arg() << " failed file(" << gnuplot_png_file << ") not generated");
-
-    BOOST_REQUIRE_MESSAGE(fs::file_size(gnuplot_dat_file) != 0,
-                          "Expected file(" << gnuplot_dat_file << ") to have file size > 0  ");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(gnuplot_script_file) != 0,
-                          "Expected file(" << gnuplot_script_file << ") to have file size > 0  ");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(gnuplot_png_file) != 0,
-                          "Expected file(" << gnuplot_png_file << ") to have file size > 0  ");
-
-    // remove generated gnuplot files.
-    fs::remove(gnuplot_dat_file);
-    fs::remove(gnuplot_script_file);
-    fs::remove(gnuplot_png_file);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestSignalSIGTERM.cpp 5.13.0-1/Client/test/TestSignalSIGTERM.cpp
--- 5.12.4-1/Client/test/TestSignalSIGTERM.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestSignalSIGTERM.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,113 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_SignalSIGTERM)
-
-static void wait_for_sigterm_in_server(ClientInvoker& theClient) {
-    int count = 0;
-    while (1) {
-        count++;
-        sleep(1);
-        BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Sync local failed\n" << theClient.errorMsg());
-        if (theClient.defs()->get_flag().is_set(ecf::Flag::ECF_SIGTERM)) {
-            // cout << "break after " << count << "s\n";
-            break;
-        }
-        BOOST_REQUIRE_MESSAGE(count > 9, "Server never received SIGTERM after 9 seconds");
-    }
-}
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-//
-// This test will send a signal SIGTERM, i.e (via kill -15 pid) and check to ensure
-// that a check point file is saved.
-// ************************************************************************************
-BOOST_AUTO_TEST_CASE(test_signal_SIGTERM) {
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-    InvokeServer invokeServer("Client:: ...test_signal_SIGTERM", SCPort::next());
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
-                                                  << theClient.errorMsg());
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
-
-    // Get the definition
-    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Sync local failed\n" << theClient.errorMsg());
-
-    // Get the process id of the server
-    const std::string& ecf_pid = theClient.defs()->server().find_variable("ECF_PID");
-    BOOST_REQUIRE_MESSAGE(!ecf_pid.empty(), "ECF_PID not set in the server");
-
-    // Send a SIGTERM to the server and ensure that a check point file is created
-    std::string sigterm = "kill -15 " + ecf_pid;
-    system(sigterm.c_str());
-    wait_for_sigterm_in_server(theClient);
-
-    // Clear sigterm flag
-    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "clear_flag", "sigterm") == 0,
-                          "--alter should return 0\n"
-                              << theClient.errorMsg());
-
-    // We expect a check point file to be save to disk, but *no* backup
-    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
-                          CtsApi::checkPtDefs() << " failed file(" << invokeServer.ecf_checkpt_file() << ") not saved");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
-                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
-                                                       << "), to have file size > 0");
-    if (ClientEnvironment::hostSpecified().empty()) {
-        // This check only valid if server was invoked locally. Ignore for remote servers
-        BOOST_REQUIRE_MESSAGE(!fs::exists(invokeServer.ecf_backup_checkpt_file()),
-                              "Backup check point file(" << invokeServer.ecf_backup_checkpt_file()
-                                                         << ")should not exist,for very first time.");
-    }
-
-    // Send a SIGTERM again. This time we expect the backup check point file to be created.
-    system(sigterm.c_str());
-    wait_for_sigterm_in_server(theClient);
-
-    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
-                          CtsApi::checkPtDefs()
-                              << " failed No check pt file(" << invokeServer.ecf_checkpt_file() << ") saved");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
-                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
-                                                       << ") to have file size > 0  ");
-    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_backup_checkpt_file()),
-                          "Expected backup check point file(" << invokeServer.ecf_backup_checkpt_file()
-                                                              << ") to be created");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_backup_checkpt_file()) != 0,
-                          "Expected backup check point file(" << invokeServer.ecf_backup_checkpt_file()
-                                                              << "), to have file size > 0");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestSinglePerf.cpp 5.13.0-1/Client/test/TestSinglePerf.cpp
--- 5.12.4-1/Client/test/TestSinglePerf.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestSinglePerf.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,381 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib> // getenv
-#include <fstream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "TestHelper.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/client/Rtt.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_SinglePerf)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-// ************************************************************************************
-
-// These thresholds are based on the largest definition in the tests.
-static int load_threshold_ms          = 4500;
-static int begin_threshold_ms         = 550;
-static double sync_full_threshold_s   = 2.6;
-static double full_threshold_s        = 2.9;
-static double suspend_threshold_s     = 3.5;
-static double resume_threshold_s      = 3.5;
-static double force_threshold_s       = 8.5;
-static double check_pt_threshold_s    = 1.0;
-static double client_cmds_threshold_s = 8.5;
-
-static void sync_and_news_local(ClientInvoker& theClient) {
-    {
-        cout << "   news_local() : ";
-        DurationTimer duration_timer;
-        theClient.news_local();
-        cout << duration_timer.elapsed_seconds();
-    }
-    {
-        cout << "   sync_local() : ";
-        DurationTimer duration_timer;
-        theClient.sync_local();
-        cout << duration_timer.elapsed_seconds() << endl;
-    }
-}
-
-void time_load_and_downloads(ClientInvoker& theClient,
-                             const std::string& host,
-                             const std::string& port,
-                             const std::string& directory) {
-    auto full_path = fs::absolute(directory);
-
-    BOOST_CHECK(fs::exists(full_path));
-    BOOST_CHECK(fs::is_directory(full_path));
-
-    int count = 10;
-    std::vector<std::string> paths;
-
-    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
-    fs::directory_iterator end_iter;
-    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
-        try {
-            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
-
-            // recurse down directories
-            if (is_directory(dir_itr->status())) {
-                time_load_and_downloads(theClient, host, port, relPath.string());
-                continue;
-            }
-
-            cout << "\n" << relPath.string() << "  : file size " << fs::file_size(relPath) << endl;
-            {
-                DurationTimer duration_timer;
-                BOOST_REQUIRE_MESSAGE(theClient.loadDefs(relPath.string()) == 0,
-                                      "load defs failed \n"
-                                          << theClient.errorMsg());
-                cout << " Load:                " << duration_timer.elapsed().total_milliseconds() << "ms" << endl;
-                BOOST_CHECK_MESSAGE(duration_timer.elapsed().total_milliseconds() < load_threshold_ms,
-                                    "regression load(" << duration_timer.elapsed().total_milliseconds()
-                                                       << "), exceeded threshold of " << load_threshold_ms);
-            }
-            {
-                DurationTimer duration_timer;
-                BOOST_REQUIRE_MESSAGE(theClient.begin_all_suites() == 0, "begin failed \n" << theClient.errorMsg());
-                cout << " Begin:               " << duration_timer.elapsed().total_milliseconds() << "ms" << endl;
-                BOOST_CHECK_MESSAGE(duration_timer.elapsed().total_milliseconds() < begin_threshold_ms,
-                                    "regression begin(" << duration_timer.elapsed().total_milliseconds()
-                                                        << "), exceeded threshold of " << begin_threshold_ms);
-            }
-
-            {
-                cout << " Download(news_local):";
-                cout.flush();
-                ClientInvoker client_news(host, port);
-                DurationTimer duration_timer;
-                for (int i = 0; i < count; i++) {
-                    if (i == 0 || i != 1) {
-                        client_news.news_local();
-                        switch (client_news.server_reply().get_news()) {
-                            case ServerReply::DO_FULL_SYNC:
-                                cout << "FULL ";
-                                break;
-                            case ServerReply::NEWS:
-                                cout << "NEWS ";
-                                break;
-                            case ServerReply::NO_NEWS:
-                                cout << "NO_NEWS ";
-                                break;
-                        }
-                    }
-                    else if (i == 1)
-                        client_news.sync_local();
-                }
-                cout << ": 1:news_local(),2:sync_local(),n:news_local with the new Client: "
-                     << duration_timer.elapsed().total_milliseconds() << "(ms)" << endl;
-            }
-            {
-                cout << " Download(Sync):      ";
-                cout.flush();
-                for (int i = 0; i < count; i++) {
-                    DurationTimer duration_timer;
-                    theClient.sync_local();
-                    int seconds = duration_timer.elapsed().total_milliseconds();
-                    cout << seconds << " ";
-                }
-                cout << ":(milli-seconds) sync_local() with the same Client. First call updates cache." << endl;
-            }
-            {
-                // On construction of Defs, hence should be slightly faster
-                cout << " Download(Sync-FULL): ";
-                cout.flush();
-                double total = 0;
-                for (int i = 0; i < count; i++) {
-                    ClientInvoker client(host, port);
-                    DurationTimer duration_timer;
-                    client.sync_local();
-                    int mil_secs = duration_timer.elapsed().total_milliseconds();
-                    cout << mil_secs << " ";
-                    total += mil_secs;
-                }
-                double average = (double)(total) / ((double)count * 1000);
-                cout << ": Avg:" << average << "(sec)  : sync_local() with *different* clients.uses cache!" << endl;
-                BOOST_CHECK_MESSAGE(average < sync_full_threshold_s,
-                                    "regression Sync-FULL(" << average << "), exceeded threshold of "
-                                                            << sync_full_threshold_s);
-            }
-            {
-                cout << " Download(FULL):      ";
-                cout.flush();
-                double total = 0;
-                for (int i = 0; i < count; i++) {
-                    ClientInvoker client(host, port);
-                    DurationTimer duration_timer;
-                    theClient.getDefs();
-                    int seconds = duration_timer.elapsed().total_milliseconds();
-                    cout << seconds << " ";
-                    total += seconds;
-                }
-                double average = (double)(total) / ((double)count * 1000);
-                cout << ": Avg:" << average << "(sec)  : get_defs() from different client" << endl;
-                BOOST_CHECK_MESSAGE(average < full_threshold_s,
-                                    "regression FULL(sync)(" << average << ") exceeded threshold of "
-                                                             << full_threshold_s);
-            }
-            {
-                std::vector<task_ptr> all_tasks;
-                if (!theClient.defs())
-                    theClient.sync_local();
-                theClient.defs()->get_all_tasks(all_tasks);
-                paths.clear();
-                paths.reserve(all_tasks.size());
-                for (size_t i = 0; i < all_tasks.size(); i++)
-                    paths.push_back(all_tasks[i]->absNodePath());
-
-                {
-                    cout << " Suspend " << paths.size() << " tasks : ";
-                    cout.flush();
-                    DurationTimer duration_timer;
-                    theClient.suspend(paths);
-                    cout << duration_timer.elapsed_seconds();
-                    sync_and_news_local(theClient);
-                }
-                {
-                    cout << " Resume " << paths.size() << " tasks  : ";
-                    cout.flush();
-                    DurationTimer duration_timer;
-                    theClient.resume(paths);
-                    cout << duration_timer.elapsed_seconds();
-                    sync_and_news_local(theClient);
-                }
-                {
-                    cout << " Suspend " << paths.size() << " tasks : ";
-                    cout.flush();
-                    theClient.set_auto_sync(true);
-                    DurationTimer duration_timer;
-                    theClient.suspend(paths);
-                    cout << duration_timer.elapsed_seconds() << " : auto-sync" << endl;
-                    BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < suspend_threshold_s,
-                                        "regression suspend(" << duration_timer.elapsed_seconds()
-                                                              << ") exceeded threshold of " << suspend_threshold_s);
-                    theClient.set_auto_sync(false);
-                }
-                {
-                    cout << " Resume " << paths.size() << " tasks  : ";
-                    cout.flush();
-                    theClient.set_auto_sync(true);
-                    DurationTimer duration_timer;
-                    theClient.resume(paths);
-                    cout << duration_timer.elapsed_seconds() << " : auto-sync" << endl;
-                    BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < resume_threshold_s,
-                                        "regression resume(" << duration_timer.elapsed_seconds()
-                                                             << ") exceeded threshold of " << resume_threshold_s);
-                    theClient.set_auto_sync(false);
-                }
-                {
-                    cout << " check  " << paths.size() << " tasks  : ";
-                    cout.flush();
-                    DurationTimer duration_timer;
-                    theClient.check(paths);
-                    cout << duration_timer.elapsed_seconds();
-                    sync_and_news_local(theClient);
-                }
-                {
-                    cout << " kill   " << paths.size() << " tasks  : ";
-                    cout.flush();
-                    DurationTimer duration_timer;
-                    theClient.kill(paths);
-                    cout << duration_timer.elapsed_seconds();
-                    sync_and_news_local(theClient);
-                }
-                {
-                    // force complete on all tasks, on some suites(3199.def), can cause infinite recursion, i.e cause
-                    // repeats to loop Hence we will call force aborted instead. Also AVOID active/submitted otherwise
-                    // we spend a huge time adding zombies, for the subsequent force cmd below. Node: state change
-                    // memento, will also persist duration time of state change.
-                    cout << " force  " << paths.size() << " tasks  : ";
-                    cout.flush();
-                    DurationTimer duration_timer;
-                    theClient.force(paths, "aborted");
-                    cout << duration_timer.elapsed_seconds() << " force(aborted)";
-                    sync_and_news_local(theClient);
-                }
-                {
-                    cout << " force  " << paths.size() << " tasks  : ";
-                    cout.flush();
-                    theClient.set_auto_sync(true);
-                    DurationTimer duration_timer;
-                    theClient.force(
-                        paths, "queued"); // can't use aborted again, as it already aborted, and hence will be ignored
-                    cout << duration_timer.elapsed_seconds() << " : auto-sync :  force(queued)" << endl;
-                    BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < force_threshold_s,
-                                        "regression force(" << duration_timer.elapsed_seconds()
-                                                            << ") exceeded threshold of " << force_threshold_s);
-                    theClient.set_auto_sync(false);
-                }
-            }
-            {
-                cout << " Check pt:            ";
-                cout.flush();
-                double total = 0;
-                for (int i = 0; i < count; i++) {
-                    DurationTimer duration_timer;
-                    theClient.checkPtDefs();
-                    int seconds = duration_timer.elapsed().total_milliseconds();
-                    cout << seconds << " ";
-                    total += seconds;
-                }
-                double average = (double)(total) / ((double)count * 1000);
-                cout << ": Avg:" << average << "(s)" << endl;
-                BOOST_CHECK_MESSAGE(average < check_pt_threshold_s,
-                                    "regression in check_pt(" << average << ") exceeded threshold of "
-                                                              << check_pt_threshold_s);
-            }
-            {
-                cout << " client cmds:         ";
-                cout.flush();
-                DurationTimer duration_timer;
-                size_t i;
-                for (i = 0; i < paths.size() && i < 2000; i++) {
-                    theClient.suspend(paths[i]);
-                    theClient.sync_local();
-                    theClient.resume(paths[i]);
-                    theClient.sync_local();
-                    theClient.force(paths[i], "aborted");
-                    theClient.sync_local();
-                    theClient.alter(paths[i], "add", "variable", "XXXX", "XXXX");
-                    theClient.sync_local();
-                    theClient.requeue(paths[i]);
-                    theClient.sync_local();
-                }
-                cout << i << " times " << duration_timer.elapsed_seconds()
-                     << "(s) (sync_local) with same client (suspend,resume,force,alter,requeue)" << endl;
-                BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < client_cmds_threshold_s,
-                                    "regression, exceeded threshold of " << client_cmds_threshold_s);
-            }
-            {
-                cout << " client cmds:         ";
-                cout.flush();
-                theClient.set_auto_sync(true);
-                DurationTimer duration_timer;
-                size_t i;
-                for (i = 0; i < paths.size() && i < 2000; i++) {
-                    theClient.suspend(paths[i]);
-                    theClient.resume(paths[i]);
-                    theClient.force(paths[i], "aborted");
-                    theClient.alter(paths[i], "add", "variable", "ZZZZ", "XXXX");
-                    theClient.requeue(paths[i]);
-                }
-                cout << i << " times " << duration_timer.elapsed_seconds()
-                     << "(s) (auto_sync ) with same client (suspend,resume,force,alter,requeue)" << endl;
-                BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < client_cmds_threshold_s,
-                                    "regression, exceeded threshold of " << client_cmds_threshold_s);
-                theClient.set_auto_sync(false);
-            }
-
-            {
-                DurationTimer duration_timer;
-                BOOST_REQUIRE_MESSAGE(theClient.delete_all(true) == 0,
-                                      "delete all defs failed \n"
-                                          << theClient.errorMsg());
-                cout << " Delete:              " << duration_timer.elapsed().total_milliseconds() << "ms" << endl;
-            }
-        }
-        catch (const std::exception& ex) {
-            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
-        }
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_perf_for_large_defs) {
-    if (const char* ecf_ssl = getenv("ECF_SSL"); ecf_ssl) {
-        load_threshold_ms       = 8000; // 4500;
-        begin_threshold_ms      = 800;  // 400;
-        sync_full_threshold_s   = 4.5;  // 2.6;
-        full_threshold_s        = 4.5;  // 2.8;
-        suspend_threshold_s     = 5.8;  // 3.5;
-        resume_threshold_s      = 6.5;  // 3.5;
-        force_threshold_s       = 15;   // 8.5;
-        check_pt_threshold_s    = 1.5;  // 1.0;
-        client_cmds_threshold_s = 950;  // 8.5;
-    }
-
-    if (const char* ecf_test_defs_dir = getenv("ECF_TEST_DEFS_DIR"); !ecf_test_defs_dir) {
-        std::cout << "Ignoring test! Environment variable ECF_TEST_DEFS_DIR is not defined\n";
-    }
-    else if (!fs::exists(ecf_test_defs_dir)) {
-        std::cout << "Ignoring test! Test definitions directory " << ecf_test_defs_dir << " does not exist\n";
-    }
-    else {
-        /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
-        InvokeServer invokeServer("Client:: ...test_perf_for_large_defs:", SCPort::next());
-        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-        time_load_and_downloads(theClient, invokeServer.host(), invokeServer.port(), ecf_test_defs_dir);
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestSinglePerf_main.cpp 5.13.0-1/Client/test/TestSinglePerf_main.cpp
--- 5.12.4-1/Client/test/TestSinglePerf_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestSinglePerf_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_SinglePerf
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/Client/test/TestUrlCmd.cpp 5.13.0-1/Client/test/TestUrlCmd.cpp
--- 5.12.4-1/Client/test/TestUrlCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestUrlCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,57 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <stdexcept>
-#include <string>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/client/UrlCmd.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_UrlCmd)
-
-//=============================================================================
-// This will test the UrlCmd.
-BOOST_AUTO_TEST_CASE(test_url_cmd) {
-    cout << "Client:: ...test_url_cmd" << endl;
-
-    std::string path = File::test_data("Client/test/data/lifecycle.txt", "Client");
-
-    defs_ptr defs = Defs::create();
-
-    std::string errorMsg, warningMsg;
-    bool parse = defs->restore(path, errorMsg, warningMsg);
-    BOOST_CHECK_MESSAGE(parse, errorMsg);
-
-    // Check error conditions
-    BOOST_REQUIRE_THROW(UrlCmd(defs, "a made up name"), std::runtime_error);
-    BOOST_REQUIRE_THROW(UrlCmd(defs_ptr(), "/suite1/family1/a"), std::runtime_error);
-
-    // The Url command relies on variable substitution, hence we must ensure that
-    // generated variables are created.
-    defs->beginAll();
-
-    UrlCmd urlCmd(defs, "/suite1/family1/a");
-    std::string expected = "${BROWSER:=firefox} -new-tab https://confluence.ecmwf.int/display/ECFLOW/ecflow+home";
-    std::string actual   = urlCmd.getUrl();
-    BOOST_CHECK_MESSAGE(expected == actual, "Expected '" << expected << "' but found " << actual);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/TestWhiteListFile.cpp 5.13.0-1/Client/test/TestWhiteListFile.cpp
--- 5.12.4-1/Client/test/TestWhiteListFile.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/TestWhiteListFile.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,180 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "InvokeServer.hpp"
-#include "SCPort.hpp"
-#include "ecflow/client/ClientEnvironment.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/WhiteListFile.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Client)
-
-BOOST_AUTO_TEST_SUITE(T_WhiteListFile)
-
-// ************************************************************************************
-// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
-//
-// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
-//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
-//       is specified then *don't* shutdown the server
-// ************************************************************************************
-
-BOOST_AUTO_TEST_CASE(test_loading_of_white_list_file) {
-    Host the_host;
-    std::string port = SCPort::next();
-    std::string host = ClientEnvironment::hostSpecified();
-    if (host.empty()) {
-
-        // make sure NO whitelist file is present before the server is started.
-        // This allows any user to send requests to the server
-        // Only do this locally, as white list file on remote machine may not be accessible
-        fs::remove(the_host.ecf_lists_file(port));
-    }
-
-    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-    // data
-    InvokeServer invokeServer("Client:: ...test_loading_of_white_list_file", port);
-    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                          CtsApi::haltServer() << " should return 0\n"
-                                               << theClient.errorMsg());
-    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                          CtsApi::restartServer() << " should return 0\n"
-                                                  << theClient.errorMsg());
-
-    // OK now test white list file functionality, but only if server was invoked locally
-    if (host.empty()) {
-
-        // The white list file should not exist, hence reload white list SHOULD fail.
-        // i.e because we deleted it earlier
-        BOOST_REQUIRE_THROW(theClient.reloadwsfile(), std::runtime_error);
-
-        // Create a valid white list file; For the FIRST time:
-        // **** IMPORTANT: if we had reloaded a white list file where the user has read access
-        // **************: _FIRST_ it will not be possible reload white file with write access, afterwards
-        // **************: since subsequent RELOAD command itself will require write access
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(WhiteListFile::createWithWriteAccess(the_host.ecf_lists_file(port), errorMsg), errorMsg);
-
-        //  Reload should pass, as its the _first_ time
-        BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
-                              CtsApi::reloadwsfile() << " should return 0\n"
-                                                     << theClient.errorMsg());
-
-        // Invoking a client request that requires write access, should pass
-        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
-
-        // Invoking a client request that requires read access, should also pass
-        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
-
-        // Remove the white list file. Comment out for debug
-        fs::remove(the_host.ecf_lists_file(port));
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_server_has_write_access_in_non_empty_whitelist) {
-    Host the_host;
-    std::string host = ClientEnvironment::hostSpecified();
-    if (host.empty()) {
-        // OK now test white list file functionality, but only if server was invoked locally
-
-        // make sure NO whitelist file is present before the server is started.
-        // This allows any user to send requests to the server
-        // Only do this locally, as white list file on remote machine may not be accessible
-        std::string port = SCPort::next();
-        fs::remove(the_host.ecf_lists_file(port));
-
-        // This will remove check pt and backup file before server start, to avoid the server from loading previous test
-        // data
-        InvokeServer invokeServer("Client:: ...test_server_has_write_access_in_non_empty_whitelist", port);
-        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
-                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
-
-        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
-        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
-                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
-                                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
-                              CtsApi::shutdownServer() << " should return 0\n"
-                                                       << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
-                              CtsApi::haltServer() << " should return 0\n"
-                                                   << theClient.errorMsg());
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-
-        // The white list file should not exist, hence reload white list SHOULD fail.
-        // i.e because we deleted it earlier
-        BOOST_REQUIRE_THROW(theClient.reloadwsfile(), std::runtime_error);
-
-        // Create a valid white list file where the server HAS NO write access.
-        std::string errorMsg;
-        BOOST_REQUIRE_MESSAGE(WhiteListFile::createWithNoAccess(the_host.ecf_lists_file(port), errorMsg), errorMsg);
-
-        // Reload whitelist. The server will adapt white list so the server user always has write access
-        BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
-                              CtsApi::reloadwsfile() << " should return 0\n"
-                                                     << theClient.errorMsg());
-
-        // Invoking a client request that requires write access, should still pass
-        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
-
-        // Invoking a client request that requires read access, should also pass
-        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
-
-        // ###############################################################################################################
-        // Remove the white list file. Comment out for debug
-        fs::remove(the_host.ecf_lists_file(port));
-
-        // Reload with empty white list. All users should have read/write access
-        BOOST_REQUIRE_MESSAGE(WhiteListFile::createEmpty(the_host.ecf_lists_file(port), errorMsg), errorMsg);
-        BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
-                              CtsApi::reloadwsfile() << " should return 0\n"
-                                                     << theClient.errorMsg());
-
-        // Invoking a client request that requires write access, should still pass
-        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
-                              CtsApi::restartServer() << " should return 0\n"
-                                                      << theClient.errorMsg());
-
-        // Invoking a client request that requires read access, should also pass
-        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
-        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
-
-        // Remove the white list file. Comment out for debug
-        fs::remove(the_host.ecf_lists_file(port));
-    }
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Client/test/data/ECF_HOME/includes/head.h 5.13.0-1/Client/test/data/ECF_HOME/includes/head.h
--- 5.12.4-1/Client/test/data/ECF_HOME/includes/head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ECF_HOME/includes/head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,53 +0,0 @@
-#!/bin/ksh
-
-set -e # stop the shell on first error
-set -u # fail when using an undefined variable
-set -x # echo script lines as they are executed
-set -o pipefail # fail if last(rightmost) command exits with a non-zero status
-
-# Defines the three variables that are needed for any
-# communication with ECF_
-
-export ECF_PORT=%ECF_PORT%    # The port number on the ecflow server
-export ECF_HOST=%ECF_HOST%    # Thehostname where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%
-fi
-
-# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
-os_name=$(uname -s)
-if [[ $os_name = Linux ]] ; then
-   host %ECF_HOST%
-fi
-
-# Tell ECF_ we have stated
-# The ECF_ variable ECF_RID will be set to parameter of smsinit
-# Here we give the current PID.
-
-smsinit $$
-
-# Defined a error hanlder
-
-ERROR() {
-   # wait for background process to stop.
-   # If we did not have background jobs, closly called foreround jobs
-   # may arrive out of order at the server, causing unnecessary zombies
-   # The wait should prevent this.
-   echo "ERROR() called"
-	set +e        # Clear -e flag, so we don't fail
-	wait          # wait for background process to stop
-   smsabort      # Notify ECF_ that something went wrong
-	trap 0        # Remove the trap
-	exit 0        # End the script
-}
-
-# Trap any calls to exit and errors caught by the -e flag
-
-trap ERROR 0
-
-# Trap any signal that may cause the script to fail
-
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/Client/test/data/ECF_HOME/includes/tail.h 5.13.0-1/Client/test/data/ECF_HOME/includes/tail.h
--- 5.12.4-1/Client/test/data/ECF_HOME/includes/tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ECF_HOME/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-# wait for background process to stop.
-# If we did not have background jobs, closly called foreround jobs
-# may arrive out of order at the server, causing unnecessary zombies
-# The wait should prevent this.
-
-wait         # wait for background process to stop
-smscomplete  # Notify ECF of a normal end
-trap 0       # Remove all traps
-exit 0       # End the shell
diff -pruN 5.12.4-1/Client/test/data/ECF_HOME/suite/family/head.h 5.13.0-1/Client/test/data/ECF_HOME/suite/family/head.h
--- 5.12.4-1/Client/test/data/ECF_HOME/suite/family/head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ECF_HOME/suite/family/head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-#!/bin/ksh
-
-set -e # stop the shell on first error
-set -u # fail when using an undefined variable
-set -x # echo script lines as they are executed
-
-# Defines the three variables that are needed for any
-# communication with ECF_
-
-export ECF_PORT=%ECF_PORT%    # The port number on the server
-export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%
-fi
-
-# Tell ECF_ we have stated
-# The ECF_ variable ECF_RID will be set to parameter of smsinit
-# Here we give the current PID.
-
-smsinit $$
-
-# Defined a error hanlder
-
-ERROR() {
-	set +e        # Clear -e flag, so we don't fail
-	smsabort      # Notify ECF_ that something went wrong
-	trap 0        # Remove the trap
-	exit 0        # End the script
-}
-
-# Trap any calls to exit and errors caught by the -e flag
-
-trap ERROR 0
-
-# Trap any signal that may cause the script to fail
-
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/Client/test/data/ECF_HOME/suite/family/t1.ecf 5.13.0-1/Client/test/data/ECF_HOME/suite/family/t1.ecf
--- 5.12.4-1/Client/test/data/ECF_HOME/suite/family/t1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ECF_HOME/suite/family/t1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,72 +0,0 @@
-%manual
-	OPERATORS: This is an example of using a manual
-	
-	This is used to also test variable subsitution of 
-	generated variables
-	SUITE     = %SUITE%
-	DATE      = %DATE%
-	DAY       = %DAY%
-	DD        = %DD%
-	DOW       = %DOW%
-	DOY       = %DOY%
-	MM        = %MM%
-	MONTH     = %MONTH%
-	YYYY      = %YYYY%
-	ECF_DATE   = %ECF_DATE%
-	ECF_TIME   = %ECF_TIME%
-	ECF_CLOCK  = %ECF_CLOCK%
-
-	FAMILY    = %FAMILY%
-	FAMILY1   = %FAMILY1%
-
-	TASK      = %TASK%
-	ECF_RID    = %ECF_RID:<not defined yet, since empty string in task>%
-	ECF_TRYNO  = %ECF_TRYNO%
-	ECF_NAME   = %ECF_NAME%
-	ECF_PASS   = %ECF_PASS%
-	ECF_SCRIPT = %ECF_SCRIPT%
-	ECF_JOB    = %ECF_JOB%
-	ECF_JOBOUT = %ECF_JOBOUT%
-    
-    Other ECF_ variables
-	ECF_KILL_CMD  = %ECF_KILL_CMD:<not defined yet>%
-	ECF_JOB_CMD   = %ECF_JOB_CMD%
-	ECF_HOME      = %ECF_HOME%
-	ECF_TRIES     = %ECF_TRIES:<Error>%
-	SMFILES      = %SMFILES:<not defined yet>%
-	ECF_INCLUDE   = %ECF_INCLUDE:<not defined yet>%
-	ECF_FETCH     = %ECF_FETCH:<not defined yet>%
-	ECF_OUT       = %ECF_OUT:<not defined yet>%
-	ECF_MICRO     = %ECF_MICRO%
-%end
-
-#============================================================
-# Using angle brackets should use ECF_INCLUDE
-#=========================================================
-%include <head.h>
-
-
-echo do some work
-# SLEEPTIME is defined thedefs.def file. Test variable substituition
-sleep %SLEEPTIME%
-echo end of job
-
-# test smsevent. smsmeter replaced with path to client exe
-smsevent  eventname
-smsmeter  metername 10
-
-%include <tail.h>
-
-
-%manual
-	Rest of the manual page is placed here, closer to the code
-%end
-%comment
-  Comment start
-%end
-%comment
-  Comment end
-%end
-%nopp
-  ignore everything in here
-%end
diff -pruN 5.12.4-1/Client/test/data/ECF_HOME/suite/family/t2.ecf 5.13.0-1/Client/test/data/ECF_HOME/suite/family/t2.ecf
--- 5.12.4-1/Client/test/data/ECF_HOME/suite/family/t2.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ECF_HOME/suite/family/t2.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
- 
-# using %include "filename"
-# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
-#
-# since we are using quotes we expect to find 'head.h' and 'tail.h'
-# in the same directory as the sms files.
-#======================================================================
-%include "head.h"
-
-
-echo do some work
-# SLEEPTIME is defined thedefs.def file. Test variable substituition
-sleep 10
-echo end of job
-
-
-%include "tail.h"
-
- 
\ No newline at end of file
diff -pruN 5.12.4-1/Client/test/data/ECF_HOME/suite/family/t3.ecf 5.13.0-1/Client/test/data/ECF_HOME/suite/family/t3.ecf
--- 5.12.4-1/Client/test/data/ECF_HOME/suite/family/t3.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ECF_HOME/suite/family/t3.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,39 +0,0 @@
-# using %include "filename"
-# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
-#
-# since we are using quotes we expect to find 'head.h' and 'tail.h'
-# in the same directory as the sms files.
-#======================================================================
-%include "head.h"
-
-
-echo do some work
-sleep 10
-echo end of job
-
-#=====================================================
-# change the ecfmicro character
-%ecfmicro &
-
-&manual
-	START Rest of the manual page is placed here, closer to the code
-&end
-&comment
-  Comment start
-  &SUITE&
-&end
-&comment
-  Comment end
-&end
-&nopp
-  ignore everything in here
-&end
-&manual
-	END of the manual
-&end
-#=====================================================
-# change the ecfmicro character back
-&ecfmicro %
-
-
-%include "tail.h"
diff -pruN 5.12.4-1/Client/test/data/ECF_HOME/suite/family/tail.h 5.13.0-1/Client/test/data/ECF_HOME/suite/family/tail.h
--- 5.12.4-1/Client/test/data/ECF_HOME/suite/family/tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ECF_HOME/suite/family/tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-smscomplete  # Notify ECF of a normal end
-trap 0       # Remove all traps
-exit 0       # End the shell
diff -pruN 5.12.4-1/Client/test/data/bad.def 5.13.0-1/Client/test/data/bad.def
--- 5.12.4-1/Client/test/data/bad.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/bad.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,5 +0,0 @@
-suite suite1
-   task dodgy
-      trigger a non sensical trigger and that should fail to parse 
-endsuite
-
diff -pruN 5.12.4-1/Client/test/data/first.def 5.13.0-1/Client/test/data/first.def
--- 5.12.4-1/Client/test/data/first.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/first.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-#
-# This defines extern which are defined in second.def
-#
-extern /a/b/c/d         
-extern /a/b/c/d/e:event        
-extern /a/b/c/d/e:meter       
-
-extern /a/b/c/d/e/f/g/h/j     # this does not exist in second.def
-
-suite suiteName
-   family familyName
-   		task p
-   			trigger /a/b/c/d == complete  		                                   # extern path
-  		task q
-   			trigger /a/b/c/d/e:event == set  		                               # extern event path
- 		task r
-   			trigger /a/b/c/d/e:meter le 30		                                   # extern meter path	
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/Client/test/data/good_hostfile 5.13.0-1/Client/test/data/good_hostfile
--- 5.12.4-1/Client/test/data/good_hostfile	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/good_hostfile	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-
-host1:3142    # some description of the port
-host2:3141    # another description
-
-host3
-
-host4:4001
-
-host5
-host6:4081
-
-# a comment
-#a comment
\ No newline at end of file
diff -pruN 5.12.4-1/Client/test/data/jobgenonly.def 5.13.0-1/Client/test/data/jobgenonly.def
--- 5.12.4-1/Client/test/data/jobgenonly.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/jobgenonly.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-#
-# We can define a variable ECF_HOME as want to use relative paths
-# i.e since the test must be relocatble to other platforms
-#
-suite suite
-	edit SLEEPTIME 10
-	edit ECF_INCLUDE $ECF_HOME/includes
-	family family
-	   task t1
-	   	event eventname
-	   	meter metername 0 100 100
-	   task t2
-	   task t3
-	endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Client/test/data/lifecycle.txt 5.13.0-1/Client/test/data/lifecycle.txt
--- 5.12.4-1/Client/test/data/lifecycle.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/lifecycle.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-suite suite1
-  edit ECF_URL_CMD  "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%"
-  edit ECF_URL_BASE "https://confluence.ecmwf.int"
-  edit ECF_URL      "display/ECFLOW/ecflow+home"
-  family family1
-   	task a
-        event 1 myEvent
-        meter myMeter 0 100
-   	task b
-   		trigger a == complete
-   endfamily
-   family family2
-   		task aa
-   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent 
-   		task bb
-   			trigger ../family1/a:myMeter >= 50  or  ../family1/a:myEvent
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/Client/test/data/ref_analysis.dat 5.13.0-1/Client/test/data/ref_analysis.dat
--- 5.12.4-1/Client/test/data/ref_analysis.dat	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/ref_analysis.dat	1970-01-01 00:00:00.000000000 +0000
@@ -1,33 +0,0 @@
-Command                               count      min  average      max     std
-localhost:3141 --begin                   49      562     1530     6932     1146
-localhost:3141 --ch_add                   1      514
-localhost:3141 --ch_drop                  8      472      491      513       12
-localhost:3141 --ch_register              9      503      533      578       22
-localhost:3141 --ch_rem                   1      511
-localhost:3141 --ch_suites               11      486      538      601       37
-localhost:3141 --check_pt                 3      689      854     1161      216
-localhost:3141 --delete                  56      516      756     1000      133
-localhost:3141 --file                    25      575      875     1013       94
-localhost:3141 --force                    4      544      554      572       10
-localhost:3141 --get                     83      889     2256     3926      519
-localhost:3141 --halt                     1      691
-localhost:3141 --kill                     2     1051     1062     1073       11
-localhost:3141 --load                    50     1462     2566     7291     1103
-localhost:3141 --log                     98      510      733      950      106
-localhost:3141 --news                    60      481      982     1537      196
-localhost:3141 --order                   33      502      549      795       82
-localhost:3141 --ping                     1     1594
-localhost:3141 --requeue                  1     2281
-localhost:3141 --restart                 50      483      676     2204      246
-localhost:3141 --restore_from_checkpt     3      716      888     1208      226
-localhost:3141 --resume                   1     2183
-localhost:3141 --shutdown                 1      680
-localhost:3141 --stats                    1      989
-localhost:3141 --suites                   2      492      622      752      130
-localhost:3141 --suspend                  2      511      517      524        6
-localhost:3141 --sync                   103      520     1610     4363      671
-localhost:3141 --sync_full               25     1155     2085     6717     1152
-localhost:3141 --terminate                1     1247
-localhost:3141 --zombie_get              68      484      729      917      105
-
-total round trip time 00:00:00.942435 for 753 requests
diff -pruN 5.12.4-1/Client/test/data/rtt.dat 5.13.0-1/Client/test/data/rtt.dat
--- 5.12.4-1/Client/test/data/rtt.dat	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/rtt.dat	1970-01-01 00:00:00.000000000 +0000
@@ -1,753 +0,0 @@
-localhost:3141 --ping :ma0 rtt:00:00:00.001594
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000818
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_repeat_integer/test_repeat_integer.def_log  :ma0 rtt:00:00:00.000851
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000761
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000780
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_repeat_integer/test_repeat_integer.def  :ma0 rtt:00:00:00.002748
-localhost:3141 --restart :ma0 rtt:00:00:00.000755
-localhost:3141 --begin=test_repeat_integer :ma0 rtt:00:00:00.002220
-localhost:3141 --get :ma0 rtt:00:00:00.002406
-localhost:3141 --news=0 140 1  :ma0 rtt:00:00:00.001107
-localhost:3141 --sync=0 140 1  :ma0 rtt:00:00:00.002342
-localhost:3141 --get :ma0 rtt:00:00:00.002121
-localhost:3141 --news=0 271 2  :ma0 rtt:00:00:00.001044
-localhost:3141 --sync=0 140 1  :ma0 rtt:00:00:00.002141
-localhost:3141 --get :ma0 rtt:00:00:00.001929
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000723
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000725
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_repeat_date/test_repeat_date.def_log  :ma0 rtt:00:00:00.000769
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000772
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000823
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_repeat_date/test_repeat_date.def  :ma0 rtt:00:00:00.002388
-localhost:3141 --restart :ma0 rtt:00:00:00.000733
-localhost:3141 --begin=test_repeat_date :ma0 rtt:00:00:00.002114
-localhost:3141 --get :ma0 rtt:00:00:00.002349
-localhost:3141 --news=0 451 6  :ma0 rtt:00:00:00.000838
-localhost:3141 --sync=0 451 6  :ma0 rtt:00:00:00.001649
-localhost:3141 --get :ma0 rtt:00:00:00.001388
-localhost:3141 --news=0 591 6  :ma0 rtt:00:00:00.001537
-localhost:3141 --sync=0 591 6  :ma0 rtt:00:00:00.002285
-localhost:3141 --get :ma0 rtt:00:00:00.002288
-localhost:3141 --news=0 661 6  :ma0 rtt:00:00:00.001085
-localhost:3141 --sync=0 661 6  :ma0 rtt:00:00:00.002283
-localhost:3141 --get :ma0 rtt:00:00:00.002007
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000829
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000724
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_repeat_enumerator/test_repeat_enumerator.def_log  :ma0 rtt:00:00:00.000778
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000785
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000823
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_repeat_enumerator/test_repeat_enumerator.def  :ma0 rtt:00:00:00.002341
-localhost:3141 --restart :ma0 rtt:00:00:00.000717
-localhost:3141 --begin=test_repeat_enumerator :ma0 rtt:00:00:00.001677
-localhost:3141 --get :ma0 rtt:00:00:00.002288
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000807
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000725
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_repeat_defstatus/test_repeat_defstatus.def_log  :ma0 rtt:00:00:00.000795
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000744
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000811
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_repeat_defstatus/test_repeat_defstatus.def  :ma0 rtt:00:00:00.002400
-localhost:3141 --restart :ma0 rtt:00:00:00.000700
-localhost:3141 --begin=test_repeat_defstatus :ma0 rtt:00:00:00.000835
-localhost:3141 --get :ma0 rtt:00:00:00.002359
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000810
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000707
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_handle/test_handle.def_log  :ma0 rtt:00:00:00.000799
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000787
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000807
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_handle/test_handle.def  :ma0 rtt:00:00:00.004505
-localhost:3141 --restart :ma0 rtt:00:00:00.000501
-localhost:3141 --begin :ma0 rtt:00:00:00.000770
-localhost:3141 --ch_register=false s0 s1 s2  :ma0 rtt:00:00:00.000555
-localhost:3141 --sync_full=1 :ma0 rtt:00:00:00.001948
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000586
-localhost:3141 --ch_drop=1 :ma0 rtt:00:00:00.000495
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000486
-localhost:3141 --ch_register=false s0 s1 s2  :ma0 rtt:00:00:00.000532
-localhost:3141 --sync=1 1006 32  :ma0 rtt:00:00:00.001916
-localhost:3141 --ch_add=1 s3 s4  :ma0 rtt:00:00:00.000514
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000564
-localhost:3141 --sync=1 1006 32  :ma0 rtt:00:00:00.002695
-localhost:3141 --ch_rem=1 s3 s4  :ma0 rtt:00:00:00.000511
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000552
-localhost:3141 --sync=1 1006 34  :ma0 rtt:00:00:00.001899
-localhost:3141 --ch_drop=1 :ma0 rtt:00:00:00.000486
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000503
-localhost:3141 --ch_register=false s0 s1 s2  :ma0 rtt:00:00:00.000506
-localhost:3141 --ch_register=false s3 s4  :ma0 rtt:00:00:00.000537
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000549
-localhost:3141 --ch_drop=1 :ma0 rtt:00:00:00.000502
-localhost:3141 --ch_drop=2 :ma0 rtt:00:00:00.000472
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000498
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000561
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000552
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_handle_sync/test_handle_sync.def_log  :ma0 rtt:00:00:00.000546
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000528
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000582
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_handle_sync/test_handle_sync.def  :ma0 rtt:00:00:00.003888
-localhost:3141 --restart :ma0 rtt:00:00:00.000484
-localhost:3141 --begin :ma0 rtt:00:00:00.000720
-localhost:3141 --ch_register=false s0 s1 s2  :ma0 rtt:00:00:00.000540
-localhost:3141 --news=1 0 0  :ma0 rtt:00:00:00.000496
-localhost:3141 --sync_full=1 :ma0 rtt:00:00:00.001951
-localhost:3141 --suspend /s3  :ma0 rtt:00:00:00.000524
-localhost:3141 --news=1 1126 54  :ma0 rtt:00:00:00.000481
-localhost:3141 --force=complete /s3  :ma0 rtt:00:00:00.000553
-localhost:3141 --news=1 1126 54  :ma0 rtt:00:00:00.000481
-localhost:3141 --sync=1 1126 54  :ma0 rtt:00:00:00.000631
-localhost:3141 --force=complete /s0  :ma0 rtt:00:00:00.000549
-localhost:3141 --news=1 1136 54  :ma0 rtt:00:00:00.000493
-localhost:3141 --sync=1 1136 54  :ma0 rtt:00:00:00.000898
-localhost:3141 --ch_drop=1 :ma0 rtt:00:00:00.000498
-localhost:3141 --ch_register=false s0 s1 s2  :ma0 rtt:00:00:00.000515
-localhost:3141 --news=1 1146 54  :ma0 rtt:00:00:00.000499
-localhost:3141 --sync=1 1146 54  :ma0 rtt:00:00:00.001963
-localhost:3141 --force=complete /s1  :ma0 rtt:00:00:00.000544
-localhost:3141 --sync=1 1146 54  :ma0 rtt:00:00:00.000894
-localhost:3141 --order=/s0 alpha  :ma0 rtt:00:00:00.000539
-localhost:3141 --sync=1 1155 54  :ma0 rtt:00:00:00.000874
-localhost:3141 --ch_drop=1 :ma0 rtt:00:00:00.000481
-localhost:3141 --suites :ma0 rtt:00:00:00.000492
-localhost:3141 --ch_register=false s0 s1 s2  :ma0 rtt:00:00:00.000503
-localhost:3141 --news=1 1157 54  :ma0 rtt:00:00:00.000496
-localhost:3141 --sync=1 1157 54  :ma0 rtt:00:00:00.001895
-localhost:3141 --force=unknown /s1  :ma0 rtt:00:00:00.000572
-localhost:3141 --sync=1 1157 54  :ma0 rtt:00:00:00.000892
-localhost:3141 --delete force yes /s2  :ma0 rtt:00:00:00.000524
-localhost:3141 --news=1 1166 54  :ma0 rtt:00:00:00.000482
-localhost:3141 --sync=1 1166 54  :ma0 rtt:00:00:00.001520
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000601
-localhost:3141 --ch_drop=1 :ma0 rtt:00:00:00.000513
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000490
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000495
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000484
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_handle_sync/test_handle_sync.def_log  :ma0 rtt:00:00:00.000544
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000523
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000557
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_handle_sync/test_handle_sync.def  :ma0 rtt:00:00:00.002196
-localhost:3141 --restart :ma0 rtt:00:00:00.000498
-localhost:3141 --begin :ma0 rtt:00:00:00.000596
-localhost:3141 --ch_register=false s0 s1 s2  :ma0 rtt:00:00:00.000534
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000550
-localhost:3141 --sync_full=1 :ma0 rtt:00:00:00.001931
-localhost:3141 --delete yes /s0  :ma0 rtt:00:00:00.000535
-localhost:3141 --delete yes /s1  :ma0 rtt:00:00:00.000519
-localhost:3141 --delete yes /s2  :ma0 rtt:00:00:00.000516
-localhost:3141 --sync=1 1224 69  :ma0 rtt:00:00:00.000834
-localhost:3141 --ch_suites :ma0 rtt:00:00:00.000541
-localhost:3141 --load=<in-memory-defs>  :ma0 rtt:00:00:00.001792
-localhost:3141 --sync=1 1230 72  :ma0 rtt:00:00:00.001890
-localhost:3141 --ch_drop=1 :ma0 rtt:00:00:00.000481
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000486
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000485
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_reque/test_reque.def_log  :ma0 rtt:00:00:00.000535
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000516
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000546
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_reque/test_reque.def  :ma0 rtt:00:00:00.001593
-localhost:3141 --restart :ma0 rtt:00:00:00.000496
-localhost:3141 --begin=test_reque :ma0 rtt:00:00:00.001472
-localhost:3141 --get :ma0 rtt:00:00:00.002323
-localhost:3141 --news=0 1412 83  :ma0 rtt:00:00:00.000997
-localhost:3141 --sync=0 1412 83  :ma0 rtt:00:00:00.002161
-localhost:3141 --get :ma0 rtt:00:00:00.002035
-localhost:3141 --news=0 1520 83  :ma0 rtt:00:00:00.001032
-localhost:3141 --sync=0 1520 83  :ma0 rtt:00:00:00.002325
-localhost:3141 --get :ma0 rtt:00:00:00.002004
-localhost:3141 --requeue /test_reque  :ma0 rtt:00:00:00.002281
-localhost:3141 --get :ma0 rtt:00:00:00.002302
-localhost:3141 --news=0 1714 85  :ma0 rtt:00:00:00.000983
-localhost:3141 --sync=0 1714 85  :ma0 rtt:00:00:00.002194
-localhost:3141 --get :ma0 rtt:00:00:00.002009
-localhost:3141 --news=0 1822 85  :ma0 rtt:00:00:00.001008
-localhost:3141 --sync=0 1822 85  :ma0 rtt:00:00:00.002332
-localhost:3141 --get :ma0 rtt:00:00:00.002077
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000764
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000729
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_kill_cmd/test_kill_cmd.def_log  :ma0 rtt:00:00:00.000776
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000759
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000807
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_kill_cmd/test_kill_cmd.def  :ma0 rtt:00:00:00.001838
-localhost:3141 --restart :ma0 rtt:00:00:00.000500
-localhost:3141 --begin=test_kill_task :ma0 rtt:00:00:00.001078
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001403
-localhost:3141 --sync=0 1884 89  :ma0 rtt:00:00:00.002116
-localhost:3141 --kill /test_kill_task/family/t0  :ma0 rtt:00:00:00.001073
-localhost:3141 --sync=0 1897 89  :ma0 rtt:00:00:00.001359
-localhost:3141 --sync=0 1899 89  :ma0 rtt:00:00:00.002039
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000814
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000712
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_kill_cmd/test_kill_cmd.def_log  :ma0 rtt:00:00:00.000781
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000753
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000854
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_kill_cmd/test_kill_cmd.def  :ma0 rtt:00:00:00.002131
-localhost:3141 --restart :ma0 rtt:00:00:00.000726
-localhost:3141 --begin=test_kill_suite :ma0 rtt:00:00:00.001499
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001974
-localhost:3141 --sync=0 1944 93  :ma0 rtt:00:00:00.002119
-localhost:3141 --kill /test_kill_suite  :ma0 rtt:00:00:00.001051
-localhost:3141 --sync=0 1957 93  :ma0 rtt:00:00:00.001405
-localhost:3141 --sync=0 1959 93  :ma0 rtt:00:00:00.002062
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000766
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000713
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_change_order/test_change_order.def_log  :ma0 rtt:00:00:00.000826
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000836
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000820
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_change_order/test_change_order.def  :ma0 rtt:00:00:00.005046
-localhost:3141 --restart :ma0 rtt:00:00:00.000489
-localhost:3141 --begin :ma0 rtt:00:00:00.000771
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.004407
-localhost:3141 --order=/a order  :ma0 rtt:00:00:00.000540
-localhost:3141 --sync=0 2163 103  :ma0 rtt:00:00:00.000903
-localhost:3141 --order=/a alpha  :ma0 rtt:00:00:00.000509
-localhost:3141 --sync=0 2165 103  :ma0 rtt:00:00:00.000844
-localhost:3141 --order=/a bottom  :ma0 rtt:00:00:00.000504
-localhost:3141 --sync=0 2167 103  :ma0 rtt:00:00:00.000845
-localhost:3141 --order=/a alpha  :ma0 rtt:00:00:00.000531
-localhost:3141 --order=/a down  :ma0 rtt:00:00:00.000502
-localhost:3141 --sync=0 2169 103  :ma0 rtt:00:00:00.000857
-localhost:3141 --order=/a alpha  :ma0 rtt:00:00:00.000515
-localhost:3141 --order=/c up  :ma0 rtt:00:00:00.000506
-localhost:3141 --sync=0 2173 103  :ma0 rtt:00:00:00.001106
-localhost:3141 --order=/a/a order  :ma0 rtt:00:00:00.000532
-localhost:3141 --sync=0 2177 103  :ma0 rtt:00:00:00.000849
-localhost:3141 --order=/a/a alpha  :ma0 rtt:00:00:00.000506
-localhost:3141 --sync=0 2179 103  :ma0 rtt:00:00:00.000846
-localhost:3141 --order=/a/a bottom  :ma0 rtt:00:00:00.000532
-localhost:3141 --sync=0 2181 103  :ma0 rtt:00:00:00.000841
-localhost:3141 --order=/a/a alpha  :ma0 rtt:00:00:00.000505
-localhost:3141 --order=/a/a down  :ma0 rtt:00:00:00.000524
-localhost:3141 --sync=0 2183 103  :ma0 rtt:00:00:00.000927
-localhost:3141 --order=/a/a alpha  :ma0 rtt:00:00:00.000513
-localhost:3141 --order=/a/c up  :ma0 rtt:00:00:00.000508
-localhost:3141 --sync=0 2187 103  :ma0 rtt:00:00:00.000918
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000506
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000497
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_change_order/test_change_order.def_log  :ma0 rtt:00:00:00.000545
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000529
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000592
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_change_order/test_change_order.def  :ma0 rtt:00:00:00.007291
-localhost:3141 --restart :ma0 rtt:00:00:00.000501
-localhost:3141 --begin :ma0 rtt:00:00:00.000935
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.006717
-localhost:3141 --ch_register=false a b c  :ma0 rtt:00:00:00.000578
-localhost:3141 --sync=1 2514 119  :ma0 rtt:00:00:00.004363
-localhost:3141 --sync=1 2514 117  :ma0 rtt:00:00:00.000520
-localhost:3141 --order=/a order  :ma0 rtt:00:00:00.000537
-localhost:3141 --sync=1 2514 117  :ma0 rtt:00:00:00.000907
-localhost:3141 --order=/a alpha  :ma0 rtt:00:00:00.000514
-localhost:3141 --sync=1 2516 117  :ma0 rtt:00:00:00.000870
-localhost:3141 --order=/a bottom  :ma0 rtt:00:00:00.000521
-localhost:3141 --sync=1 2518 117  :ma0 rtt:00:00:00.000848
-localhost:3141 --order=/a alpha  :ma0 rtt:00:00:00.000525
-localhost:3141 --order=/a down  :ma0 rtt:00:00:00.000503
-localhost:3141 --sync=1 2520 117  :ma0 rtt:00:00:00.000867
-localhost:3141 --order=/a alpha  :ma0 rtt:00:00:00.000524
-localhost:3141 --order=/c up  :ma0 rtt:00:00:00.000522
-localhost:3141 --sync=1 2524 117  :ma0 rtt:00:00:00.001098
-localhost:3141 --order=/a/a order  :ma0 rtt:00:00:00.000514
-localhost:3141 --sync=1 2528 117  :ma0 rtt:00:00:00.000847
-localhost:3141 --order=/a/a alpha  :ma0 rtt:00:00:00.000520
-localhost:3141 --sync=1 2530 117  :ma0 rtt:00:00:00.000846
-localhost:3141 --order=/a/a bottom  :ma0 rtt:00:00:00.000519
-localhost:3141 --sync=1 2532 117  :ma0 rtt:00:00:00.000880
-localhost:3141 --order=/a/a alpha  :ma0 rtt:00:00:00.000519
-localhost:3141 --order=/a/a down  :ma0 rtt:00:00:00.000505
-localhost:3141 --sync=1 2534 117  :ma0 rtt:00:00:00.000862
-localhost:3141 --order=/a/a alpha  :ma0 rtt:00:00:00.000505
-localhost:3141 --order=/a/c up  :ma0 rtt:00:00:00.000552
-localhost:3141 --sync=1 2538 117  :ma0 rtt:00:00:00.000916
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000514
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000550
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_limit/test_limit.def_log  :ma0 rtt:00:00:00.000533
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000516
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000589
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_limit/test_limit.def  :ma0 rtt:00:00:00.002230
-localhost:3141 --restart :ma0 rtt:00:00:00.000503
-localhost:3141 --begin=test_limit :ma0 rtt:00:00:00.002060
-localhost:3141 --get :ma0 rtt:00:00:00.003202
-localhost:3141 --news=0 2768 123  :ma0 rtt:00:00:00.001038
-localhost:3141 --sync=0 2768 123  :ma0 rtt:00:00:00.001993
-localhost:3141 --get :ma0 rtt:00:00:00.002829
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000853
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000725
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_today_single_slot/test_today_single_slot.def_log  :ma0 rtt:00:00:00.000794
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000746
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000819
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_today_single_slot/test_today_single_slot.def  :ma0 rtt:00:00:00.002144
-localhost:3141 --restart :ma0 rtt:00:00:00.000716
-localhost:3141 --begin=test_today_single_slot :ma0 rtt:00:00:00.001863
-localhost:3141 --get :ma0 rtt:00:00:00.002164
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000783
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000722
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_today_relative_time_series/test_today_relative_time_series.def_log  :ma0 rtt:00:00:00.000785
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000753
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000806
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_today_relative_time_series/test_today_relative_time_series.def  :ma0 rtt:00:00:00.002235
-localhost:3141 --restart :ma0 rtt:00:00:00.000733
-localhost:3141 --begin=test_today_relative_time_series :ma0 rtt:00:00:00.000786
-localhost:3141 --get :ma0 rtt:00:00:00.002183
-localhost:3141 --news=0 2942 131  :ma0 rtt:00:00:00.001012
-localhost:3141 --sync=0 2942 131  :ma0 rtt:00:00:00.001338
-localhost:3141 --get :ma0 rtt:00:00:00.001887
-localhost:3141 --news=0 2943 131  :ma0 rtt:00:00:00.001040
-localhost:3141 --sync=0 2943 131  :ma0 rtt:00:00:00.001342
-localhost:3141 --get :ma0 rtt:00:00:00.001948
-localhost:3141 --news=0 2944 131  :ma0 rtt:00:00:00.000995
-localhost:3141 --sync=0 2944 131  :ma0 rtt:00:00:00.001923
-localhost:3141 --get :ma0 rtt:00:00:00.001860
-localhost:3141 --news=0 2990 131  :ma0 rtt:00:00:00.001043
-localhost:3141 --sync=0 2990 131  :ma0 rtt:00:00:00.001330
-localhost:3141 --get :ma0 rtt:00:00:00.001863
-localhost:3141 --news=0 2991 131  :ma0 rtt:00:00:00.001036
-localhost:3141 --sync=0 2991 131  :ma0 rtt:00:00:00.001339
-localhost:3141 --get :ma0 rtt:00:00:00.001856
-localhost:3141 --news=0 2992 131  :ma0 rtt:00:00:00.000989
-localhost:3141 --sync=0 2992 131  :ma0 rtt:00:00:00.001931
-localhost:3141 --get :ma0 rtt:00:00:00.001831
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000780
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000763
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_today_real_time_series/test_today_real_time_series.def_log  :ma0 rtt:00:00:00.000823
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000767
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000849
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_today_real_time_series/test_today_real_time_series.def  :ma0 rtt:00:00:00.002284
-localhost:3141 --restart :ma0 rtt:00:00:00.000712
-localhost:3141 --begin=test_today_real_time_series :ma0 rtt:00:00:00.000800
-localhost:3141 --get :ma0 rtt:00:00:00.002248
-localhost:3141 --news=0 3104 135  :ma0 rtt:00:00:00.001324
-localhost:3141 --news=0 3104 135  :ma0 rtt:00:00:00.001037
-localhost:3141 --news=0 3104 135  :ma0 rtt:00:00:00.001011
-localhost:3141 --sync=0 3104 135  :ma0 rtt:00:00:00.001937
-localhost:3141 --get :ma0 rtt:00:00:00.001925
-localhost:3141 --news=0 3149 135  :ma0 rtt:00:00:00.001022
-localhost:3141 --news=0 3149 135  :ma0 rtt:00:00:00.001019
-localhost:3141 --news=0 3149 135  :ma0 rtt:00:00:00.001017
-localhost:3141 --sync=0 3149 135  :ma0 rtt:00:00:00.002064
-localhost:3141 --get :ma0 rtt:00:00:00.001955
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000796
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000889
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_events/test_events.def_log  :ma0 rtt:00:00:00.000794
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000782
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000808
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_events/test_events.def  :ma0 rtt:00:00:00.003309
-localhost:3141 --restart :ma0 rtt:00:00:00.000500
-localhost:3141 --begin=test_events :ma0 rtt:00:00:00.002266
-localhost:3141 --get :ma0 rtt:00:00:00.002928
-localhost:3141 --news=0 3298 139  :ma0 rtt:00:00:00.001039
-localhost:3141 --sync=0 3298 139  :ma0 rtt:00:00:00.001313
-localhost:3141 --get :ma0 rtt:00:00:00.002571
-localhost:3141 --news=0 3301 139  :ma0 rtt:00:00:00.001035
-localhost:3141 --sync=0 3301 139  :ma0 rtt:00:00:00.001922
-localhost:3141 --get :ma0 rtt:00:00:00.002557
-localhost:3141 --news=0 3324 139  :ma0 rtt:00:00:00.001105
-localhost:3141 --sync=0 3324 139  :ma0 rtt:00:00:00.002705
-localhost:3141 --get :ma0 rtt:00:00:00.002523
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000732
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000742
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_complete/test_complete.def_log  :ma0 rtt:00:00:00.000784
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000786
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000815
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_complete/test_complete.def  :ma0 rtt:00:00:00.003330
-localhost:3141 --restart :ma0 rtt:00:00:00.000719
-localhost:3141 --begin=test_complete :ma0 rtt:00:00:00.002345
-localhost:3141 --get :ma0 rtt:00:00:00.002671
-localhost:3141 --news=0 3507 143  :ma0 rtt:00:00:00.001112
-localhost:3141 --sync=0 3507 143  :ma0 rtt:00:00:00.002612
-localhost:3141 --get :ma0 rtt:00:00:00.002276
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000744
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_complete_does_not_hold/test_complete_does_not_hold.def_log  :ma0 rtt:00:00:00.000826
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000745
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000821
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_complete_does_not_hold/test_complete_does_not_hold.def  :ma0 rtt:00:00:00.002355
-localhost:3141 --restart :ma0 rtt:00:00:00.000716
-localhost:3141 --begin=test_complete_does_not_hold :ma0 rtt:00:00:00.001561
-localhost:3141 --get :ma0 rtt:00:00:00.002340
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_complete_with_empty_family/test_complete_with_empty_family.def_log  :ma0 rtt:00:00:00.000878
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000783
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000886
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_complete_with_empty_family/test_complete_with_empty_family.def  :ma0 rtt:00:00:00.002763
-localhost:3141 --restart :ma0 rtt:00:00:00.000707
-localhost:3141 --begin=test_complete_with_empty_family :ma0 rtt:00:00:00.002443
-localhost:3141 --get :ma0 rtt:00:00:00.002457
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000884
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_abort_cmd/test_abort_cmd.def_log  :ma0 rtt:00:00:00.000796
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000749
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000965
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_abort_cmd/test_abort_cmd.def  :ma0 rtt:00:00:00.002040
-localhost:3141 --restart :ma0 rtt:00:00:00.000804
-localhost:3141 --begin=test_abort_cmd :ma0 rtt:00:00:00.001465
-localhost:3141 --get :ma0 rtt:00:00:00.002093
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000760
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000722
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_shutdown/test_shutdown.def_log  :ma0 rtt:00:00:00.000799
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000758
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000807
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_shutdown/test_shutdown.def  :ma0 rtt:00:00:00.002494
-localhost:3141 --restart :ma0 rtt:00:00:00.000726
-localhost:3141 --begin=test_shutdown :ma0 rtt:00:00:00.000824
-localhost:3141 --shutdown=yes :ma0 rtt:00:00:00.000680
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.002101
-localhost:3141 --sync=0 3969 159  :ma0 rtt:00:00:00.001582
-localhost:3141 --sync=0 3970 159  :ma0 rtt:00:00:00.001078
-localhost:3141 --sync=0 3970 159  :ma0 rtt:00:00:00.001101
-localhost:3141 --sync=0 3970 159  :ma0 rtt:00:00:00.001619
-localhost:3141 --restart :ma0 rtt:00:00:00.002204
-localhost:3141 --get :ma0 rtt:00:00:00.002526
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000805
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000721
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_suspend_node/test_suspend_node.def_log  :ma0 rtt:00:00:00.000795
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000748
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000812
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_suspend_node/test_suspend_node.def  :ma0 rtt:00:00:00.002633
-localhost:3141 --restart :ma0 rtt:00:00:00.000505
-localhost:3141 --begin=test_suspend_node :ma0 rtt:00:00:00.000566
-localhost:3141 --suspend /test_suspend_node/family  :ma0 rtt:00:00:00.000511
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001683
-localhost:3141 --sync=0 4077 163  :ma0 rtt:00:00:00.001114
-localhost:3141 --sync=0 4077 163  :ma0 rtt:00:00:00.001066
-localhost:3141 --sync=0 4077 163  :ma0 rtt:00:00:00.002114
-localhost:3141 --sync=0 4098 163  :ma0 rtt:00:00:00.001920
-localhost:3141 --sync=0 4107 163  :ma0 rtt:00:00:00.001134
-localhost:3141 --sync=0 4107 163  :ma0 rtt:00:00:00.002167
-localhost:3141 --resume /test_suspend_node/family  :ma0 rtt:00:00:00.002183
-localhost:3141 --get :ma0 rtt:00:00:00.002853
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000768
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000723
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_cron_time_series/test_cron_time_series.def_log  :ma0 rtt:00:00:00.000786
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000759
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000851
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_cron_time_series/test_cron_time_series.def  :ma0 rtt:00:00:00.002216
-localhost:3141 --restart :ma0 rtt:00:00:00.000736
-localhost:3141 --begin=test_cron_time_series :ma0 rtt:00:00:00.000794
-localhost:3141 --get :ma0 rtt:00:00:00.002235
-localhost:3141 --news=0 4258 167  :ma0 rtt:00:00:00.001067
-localhost:3141 --news=0 4258 167  :ma0 rtt:00:00:00.001010
-localhost:3141 --sync=0 4258 167  :ma0 rtt:00:00:00.001992
-localhost:3141 --get :ma0 rtt:00:00:00.001889
-localhost:3141 --news=0 4303 167  :ma0 rtt:00:00:00.001011
-localhost:3141 --news=0 4303 167  :ma0 rtt:00:00:00.001005
-localhost:3141 --sync=0 4303 167  :ma0 rtt:00:00:00.001989
-localhost:3141 --get :ma0 rtt:00:00:00.001898
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000748
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000703
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_file_cmd/test_file_cmd.def_log  :ma0 rtt:00:00:00.000767
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000755
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000857
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_file_cmd/test_file_cmd.def  :ma0 rtt:00:00:00.002238
-localhost:3141 --restart :ma0 rtt:00:00:00.000722
-localhost:3141 --begin=test_file_cmd :ma0 rtt:00:00:00.002131
-localhost:3141 --get :ma0 rtt:00:00:00.001859
-localhost:3141 --file=/test_file_cmd script 10000  :ma0 rtt:00:00:00.000734
-localhost:3141 --file=/test_file_cmd job 10000  :ma0 rtt:00:00:00.000575
-localhost:3141 --file=/test_file_cmd jobout 10000  :ma0 rtt:00:00:00.000808
-localhost:3141 --file=/test_file_cmd manual 10000  :ma0 rtt:00:00:00.000954
-localhost:3141 --file=/test_file_cmd kill 10000  :ma0 rtt:00:00:00.000872
-localhost:3141 --file=/test_file_cmd stat 10000  :ma0 rtt:00:00:00.000810
-localhost:3141 --file=/test_file_cmd/family script 10000  :ma0 rtt:00:00:00.000926
-localhost:3141 --file=/test_file_cmd/family job 10000  :ma0 rtt:00:00:00.000939
-localhost:3141 --file=/test_file_cmd/family jobout 10000  :ma0 rtt:00:00:00.000952
-localhost:3141 --file=/test_file_cmd/family manual 10000  :ma0 rtt:00:00:00.000865
-localhost:3141 --file=/test_file_cmd/family kill 10000  :ma0 rtt:00:00:00.000794
-localhost:3141 --file=/test_file_cmd/family stat 10000  :ma0 rtt:00:00:00.000895
-localhost:3141 --file=/test_file_cmd/family/t0 script 10000  :ma0 rtt:00:00:00.000787
-localhost:3141 --file=/test_file_cmd/family/t0 job 10000  :ma0 rtt:00:00:00.000948
-localhost:3141 --file=/test_file_cmd/family/t0 jobout 10000  :ma0 rtt:00:00:00.000908
-localhost:3141 --file=/test_file_cmd/family/t0 manual 10000  :ma0 rtt:00:00:00.000993
-localhost:3141 --file=/test_file_cmd/family/t0 kill 10000  :ma0 rtt:00:00:00.000818
-localhost:3141 --file=/test_file_cmd/family/t0 stat 10000  :ma0 rtt:00:00:00.000896
-localhost:3141 --file=/test_file_cmd/family/t1 script 10000  :ma0 rtt:00:00:00.000827
-localhost:3141 --file=/test_file_cmd/family/t1 job 10000  :ma0 rtt:00:00:00.000830
-localhost:3141 --file=/test_file_cmd/family/t1 jobout 10000  :ma0 rtt:00:00:00.000950
-localhost:3141 --file=/test_file_cmd/family/t1 manual 10000  :ma0 rtt:00:00:00.001013
-localhost:3141 --file=/test_file_cmd/family/t1 kill 10000  :ma0 rtt:00:00:00.000931
-localhost:3141 --file=/test_file_cmd/family/t1 stat 10000  :ma0 rtt:00:00:00.000987
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000917
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000856
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_triggers_and_meters/test_triggers_and_meters.def_log  :ma0 rtt:00:00:00.000870
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000825
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.001000
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_triggers_and_meters/test_triggers_and_meters.def  :ma0 rtt:00:00:00.006511
-localhost:3141 --restart :ma0 rtt:00:00:00.000536
-localhost:3141 --begin=test_triggers_and_meters :ma0 rtt:00:00:00.006932
-localhost:3141 --get :ma0 rtt:00:00:00.003926
-localhost:3141 --news=0 4594 175  :ma0 rtt:00:00:00.001023
-localhost:3141 --sync=0 4594 175  :ma0 rtt:00:00:00.002577
-localhost:3141 --get :ma0 rtt:00:00:00.003520
-localhost:3141 --news=0 4660 175  :ma0 rtt:00:00:00.001043
-localhost:3141 --sync=0 4660 175  :ma0 rtt:00:00:00.002591
-localhost:3141 --get :ma0 rtt:00:00:00.003536
-localhost:3141 --news=0 4726 175  :ma0 rtt:00:00:00.001038
-localhost:3141 --sync=0 4726 175  :ma0 rtt:00:00:00.002202
-localhost:3141 --get :ma0 rtt:00:00:00.003526
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000790
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000756
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_day/test_why_day.def_log  :ma0 rtt:00:00:00.000783
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000750
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000879
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_day/test_why_day.def  :ma0 rtt:00:00:00.002096
-localhost:3141 --restart :ma0 rtt:00:00:00.000718
-localhost:3141 --begin=test_why_day :ma0 rtt:00:00:00.000780
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001765
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000916
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_date/test_why_date.def_log  :ma0 rtt:00:00:00.000793
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000765
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000889
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_date/test_why_date.def  :ma0 rtt:00:00:00.002029
-localhost:3141 --restart :ma0 rtt:00:00:00.000697
-localhost:3141 --begin=test_why_date :ma0 rtt:00:00:00.000787
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001839
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_time/test_why_time.def_log  :ma0 rtt:00:00:00.000800
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000802
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000797
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_time/test_why_time.def  :ma0 rtt:00:00:00.002091
-localhost:3141 --restart :ma0 rtt:00:00:00.000718
-localhost:3141 --begin=test_why_time :ma0 rtt:00:00:00.000778
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001753
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_today/test_why_today.def_log  :ma0 rtt:00:00:00.000764
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000746
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000775
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_today/test_why_today.def  :ma0 rtt:00:00:00.002027
-localhost:3141 --restart :ma0 rtt:00:00:00.000718
-localhost:3141 --begin=test_why_today :ma0 rtt:00:00:00.000798
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001773
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_cron/test_why_cron.def_log  :ma0 rtt:00:00:00.000815
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000785
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000944
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_cron/test_why_cron.def  :ma0 rtt:00:00:00.002163
-localhost:3141 --restart :ma0 rtt:00:00:00.000714
-localhost:3141 --begin=test_why_cron :ma0 rtt:00:00:00.000853
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001839
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_limit/test_why_limit.def_log  :ma0 rtt:00:00:00.000950
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000764
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000550
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_limit/test_why_limit.def  :ma0 rtt:00:00:00.001851
-localhost:3141 --restart :ma0 rtt:00:00:00.000491
-localhost:3141 --begin=test_why_limit :ma0 rtt:00:00:00.001091
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001767
-localhost:3141 --get :ma0 rtt:00:00:00.001970
-localhost:3141 --get :ma0 rtt:00:00:00.002742
-localhost:3141 --get :ma0 rtt:00:00:00.002792
-localhost:3141 --get :ma0 rtt:00:00:00.002725
-localhost:3141 --get :ma0 rtt:00:00:00.002751
-localhost:3141 --get :ma0 rtt:00:00:00.002718
-localhost:3141 --get :ma0 rtt:00:00:00.002756
-localhost:3141 --get :ma0 rtt:00:00:00.002724
-localhost:3141 --get :ma0 rtt:00:00:00.002835
-localhost:3141 --get :ma0 rtt:00:00:00.002715
-localhost:3141 --get :ma0 rtt:00:00:00.002782
-localhost:3141 --get :ma0 rtt:00:00:00.002761
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_trigger/test_why_trigger.def_log  :ma0 rtt:00:00:00.000829
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000767
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000850
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_trigger/test_why_trigger.def  :ma0 rtt:00:00:00.002027
-localhost:3141 --restart :ma0 rtt:00:00:00.000734
-localhost:3141 --begin=test_why_trigger :ma0 rtt:00:00:00.000829
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001716
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_meter/test_why_meter.def_log  :ma0 rtt:00:00:00.000784
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000739
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000789
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_meter/test_why_meter.def  :ma0 rtt:00:00:00.002763
-localhost:3141 --restart :ma0 rtt:00:00:00.000854
-localhost:3141 --begin=test_why_meter :ma0 rtt:00:00:00.001467
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001438
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_event/test_why_event.def_log  :ma0 rtt:00:00:00.000560
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000515
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000541
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_event/test_why_event.def  :ma0 rtt:00:00:00.002027
-localhost:3141 --restart :ma0 rtt:00:00:00.000488
-localhost:3141 --begin=test_why_event :ma0 rtt:00:00:00.001042
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001318
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_user_var/test_why_user_var.def_log  :ma0 rtt:00:00:00.000566
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000522
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000556
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_user_var/test_why_user_var.def  :ma0 rtt:00:00:00.001786
-localhost:3141 --restart :ma0 rtt:00:00:00.000488
-localhost:3141 --begin=test_why_user_var :ma0 rtt:00:00:00.000972
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001155
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_gen_var/test_why_gen_var.def_log  :ma0 rtt:00:00:00.000547
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000512
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000536
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_gen_var/test_why_gen_var.def  :ma0 rtt:00:00:00.001831
-localhost:3141 --restart :ma0 rtt:00:00:00.000486
-localhost:3141 --begin=test_why_gen_var :ma0 rtt:00:00:00.001012
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001184
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_why_repeat/test_why_repeat.def_log  :ma0 rtt:00:00:00.000596
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000511
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000536
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_why_repeat/test_why_repeat.def  :ma0 rtt:00:00:00.002163
-localhost:3141 --restart :ma0 rtt:00:00:00.000504
-localhost:3141 --begin=test_why_repeat :ma0 rtt:00:00:00.001293
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001210
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000557
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_time_single_slot/test_time_single_slot.def_log  :ma0 rtt:00:00:00.000519
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000510
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000535
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_time_single_slot/test_time_single_slot.def  :ma0 rtt:00:00:00.001462
-localhost:3141 --restart :ma0 rtt:00:00:00.000483
-localhost:3141 --begin=test_time_single_slot :ma0 rtt:00:00:00.000562
-localhost:3141 --get :ma0 rtt:00:00:00.002240
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000812
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000747
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_time_multiple_single_slot/test_time_multiple_single_slot.def_log  :ma0 rtt:00:00:00.000792
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000779
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000847
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_time_multiple_single_slot/test_time_multiple_single_slot.def  :ma0 rtt:00:00:00.002199
-localhost:3141 --restart :ma0 rtt:00:00:00.000729
-localhost:3141 --begin=test_time_multiple_single_slot :ma0 rtt:00:00:00.000829
-localhost:3141 --get :ma0 rtt:00:00:00.002265
-localhost:3141 --news=0 5429 231  :ma0 rtt:00:00:00.001035
-localhost:3141 --news=0 5429 231  :ma0 rtt:00:00:00.001046
-localhost:3141 --news=0 5429 231  :ma0 rtt:00:00:00.001050
-localhost:3141 --sync=0 5429 231  :ma0 rtt:00:00:00.002064
-localhost:3141 --get :ma0 rtt:00:00:00.001902
-localhost:3141 --news=0 5476 231  :ma0 rtt:00:00:00.001045
-localhost:3141 --news=0 5476 231  :ma0 rtt:00:00:00.001037
-localhost:3141 --news=0 5476 231  :ma0 rtt:00:00:00.001031
-localhost:3141 --sync=0 5476 231  :ma0 rtt:00:00:00.001942
-localhost:3141 --get :ma0 rtt:00:00:00.001908
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000767
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000727
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_time_relative_time_series/test_time_relative_time_series.def_log  :ma0 rtt:00:00:00.000803
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000751
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000812
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_time_relative_time_series/test_time_relative_time_series.def  :ma0 rtt:00:00:00.002174
-localhost:3141 --restart :ma0 rtt:00:00:00.000747
-localhost:3141 --begin=test_time_relative_time_series :ma0 rtt:00:00:00.000923
-localhost:3141 --get :ma0 rtt:00:00:00.002217
-localhost:3141 --news=0 5586 235  :ma0 rtt:00:00:00.001040
-localhost:3141 --sync=0 5586 235  :ma0 rtt:00:00:00.001332
-localhost:3141 --get :ma0 rtt:00:00:00.001847
-localhost:3141 --news=0 5587 235  :ma0 rtt:00:00:00.001036
-localhost:3141 --sync=0 5587 235  :ma0 rtt:00:00:00.001330
-localhost:3141 --get :ma0 rtt:00:00:00.001862
-localhost:3141 --news=0 5588 235  :ma0 rtt:00:00:00.001030
-localhost:3141 --sync=0 5588 235  :ma0 rtt:00:00:00.001907
-localhost:3141 --get :ma0 rtt:00:00:00.001864
-localhost:3141 --news=0 5634 235  :ma0 rtt:00:00:00.001043
-localhost:3141 --sync=0 5634 235  :ma0 rtt:00:00:00.001330
-localhost:3141 --get :ma0 rtt:00:00:00.001869
-localhost:3141 --news=0 5635 235  :ma0 rtt:00:00:00.001084
-localhost:3141 --sync=0 5635 235  :ma0 rtt:00:00:00.001336
-localhost:3141 --get :ma0 rtt:00:00:00.001866
-localhost:3141 --news=0 5636 235  :ma0 rtt:00:00:00.001042
-localhost:3141 --sync=0 5636 235  :ma0 rtt:00:00:00.001944
-localhost:3141 --get :ma0 rtt:00:00:00.001866
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000753
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000728
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_time_real_series/test_time_real_series.def_log  :ma0 rtt:00:00:00.000776
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000767
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000843
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_time_real_series/test_time_real_series.def  :ma0 rtt:00:00:00.002184
-localhost:3141 --restart :ma0 rtt:00:00:00.000749
-localhost:3141 --begin=test_time_real_series :ma0 rtt:00:00:00.000790
-localhost:3141 --get :ma0 rtt:00:00:00.001729
-localhost:3141 --news=0 5746 239  :ma0 rtt:00:00:00.001022
-localhost:3141 --news=0 5746 239  :ma0 rtt:00:00:00.001054
-localhost:3141 --news=0 5746 239  :ma0 rtt:00:00:00.001027
-localhost:3141 --sync=0 5746 239  :ma0 rtt:00:00:00.001934
-localhost:3141 --get :ma0 rtt:00:00:00.001898
-localhost:3141 --news=0 5791 239  :ma0 rtt:00:00:00.001034
-localhost:3141 --news=0 5791 239  :ma0 rtt:00:00:00.001043
-localhost:3141 --news=0 5791 239  :ma0 rtt:00:00:00.001034
-localhost:3141 --sync=0 5791 239  :ma0 rtt:00:00:00.001973
-localhost:3141 --get :ma0 rtt:00:00:00.001872
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000810
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000747
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_late/test_late.def_log  :ma0 rtt:00:00:00.000780
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000768
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000834
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_late/test_late.def  :ma0 rtt:00:00:00.001888
-localhost:3141 --restart :ma0 rtt:00:00:00.000714
-localhost:3141 --begin=test_late :ma0 rtt:00:00:00.001453
-localhost:3141 --get :ma0 rtt:00:00:00.001910
-localhost:3141 --news=0 5868 243  :ma0 rtt:00:00:00.001042
-localhost:3141 --sync=0 5868 243  :ma0 rtt:00:00:00.001371
-localhost:3141 --get :ma0 rtt:00:00:00.001607
-localhost:3141 --news=0 5870 243  :ma0 rtt:00:00:00.001032
-localhost:3141 --sync=0 5870 243  :ma0 rtt:00:00:00.001619
-localhost:3141 --get :ma0 rtt:00:00:00.001537
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.001516
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000770
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000741
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_server_job_submission/test_server_job_submission.def_log  :ma0 rtt:00:00:00.000797
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000762
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000810
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_server_job_submission/test_server_job_submission.def  :ma0 rtt:00:00:00.002509
-localhost:3141 --restart :ma0 rtt:00:00:00.000717
-localhost:3141 --begin=test_server_job_submission :ma0 rtt:00:00:00.002936
-localhost:3141 --get :ma0 rtt:00:00:00.002446
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000778
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000705
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_restore_defs_from_check_pt/test_restore_defs_from_check_pt.def_log  :ma0 rtt:00:00:00.000782
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000763
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000826
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_restore_defs_from_check_pt/test_restore_defs_from_check_pt.def  :ma0 rtt:00:00:00.001965
-localhost:3141 --restart :ma0 rtt:00:00:00.000718
-localhost:3141 --begin=test_restore_defs_from_check_pt :ma0 rtt:00:00:00.001473
-localhost:3141 --get :ma0 rtt:00:00:00.001889
-localhost:3141 --check_pt=never :ma0 rtt:00:00:00.000714
-localhost:3141 --get :ma0 rtt:00:00:00.001421
-localhost:3141 --check_pt :ma0 rtt:00:00:00.001161
-localhost:3141 --restore_from_checkpt :ma0 rtt:00:00:00.000741
-localhost:3141 --halt=yes :ma0 rtt:00:00:00.000691
-localhost:3141 --restore_from_checkpt :ma0 rtt:00:00:00.000716
-localhost:3141 --delete _all_ yes  :ma0 rtt:00:00:00.000851
-localhost:3141 --get :ma0 rtt:00:00:00.000889
-localhost:3141 --restore_from_checkpt :ma0 rtt:00:00:00.001208
-localhost:3141 --get :ma0 rtt:00:00:00.001442
-localhost:3141 --check_pt=on_time:120 :ma0 rtt:00:00:00.000689
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000737
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000723
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_wait_cmd/test_wait_cmd.def_log  :ma0 rtt:00:00:00.000797
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000765
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000770
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_wait_cmd/test_wait_cmd.def  :ma0 rtt:00:00:00.002531
-localhost:3141 --restart :ma0 rtt:00:00:00.000509
-localhost:3141 --begin=test_wait_cmd :ma0 rtt:00:00:00.002830
-localhost:3141 --get :ma0 rtt:00:00:00.002840
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000860
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_wait_cmd_parse_fail/test_wait_cmd_parse_fail.def_log  :ma0 rtt:00:00:00.000800
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000767
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000847
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_wait_cmd_parse_fail/test_wait_cmd_parse_fail.def  :ma0 rtt:00:00:00.002834
-localhost:3141 --restart :ma0 rtt:00:00:00.000726
-localhost:3141 --begin=test_wait_cmd_parse_fail :ma0 rtt:00:00:00.004206
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.002854
-localhost:3141 --sync=0 6337 261  :ma0 rtt:00:00:00.002927
-localhost:3141 --sync=0 6408 261  :ma0 rtt:00:00:00.002610
-localhost:3141 --sync=0 6438 261  :ma0 rtt:00:00:00.000789
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_wait_cmd_non_existant_paths/test_wait_cmd_non_existant_paths.def_log  :ma0 rtt:00:00:00.000822
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000759
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000844
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_wait_cmd_non_existant_paths/test_wait_cmd_non_existant_paths.def  :ma0 rtt:00:00:00.002826
-localhost:3141 --restart :ma0 rtt:00:00:00.000727
-localhost:3141 --begin=test_wait_cmd_non_existant_paths :ma0 rtt:00:00:00.004255
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.002858
-localhost:3141 --sync=0 6541 265  :ma0 rtt:00:00:00.002904
-localhost:3141 --sync=0 6584 265  :ma0 rtt:00:00:00.002972
-localhost:3141 --sync=0 6648 265  :ma0 rtt:00:00:00.000773
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000767
-localhost:3141 --log=new Test/data/ECF_HOME_debug/test_alias/test_alias.def_log  :ma0 rtt:00:00:00.000773
-localhost:3141 --log=clear :ma0 rtt:00:00:00.000775
-localhost:3141 --delete _all_ force yes  :ma0 rtt:00:00:00.000824
-localhost:3141 --load=Test/data/ECF_HOME_debug/test_alias/test_alias.def  :ma0 rtt:00:00:00.001962
-localhost:3141 --restart :ma0 rtt:00:00:00.000772
-localhost:3141 --begin=test_alias :ma0 rtt:00:00:00.001498
-localhost:3141 --get :ma0 rtt:00:00:00.001978
-localhost:3141 --file=/test_alias/task_a script 10000  :ma0 rtt:00:00:00.000870
-localhost:3141 --sync_full=0 :ma0 rtt:00:00:00.002039
-localhost:3141 --sync=0 6723 269  :ma0 rtt:00:00:00.001990
-localhost:3141 --sync=0 6744 269  :ma0 rtt:00:00:00.002100
-localhost:3141 --order=/test_alias/task_a/alias0 down  :ma0 rtt:00:00:00.000795
-localhost:3141 --sync=0 6750 269  :ma0 rtt:00:00:00.001277
-localhost:3141 --order=/test_alias/task_a/alias0 up  :ma0 rtt:00:00:00.000739
-localhost:3141 --sync=0 6752 269  :ma0 rtt:00:00:00.001272
-localhost:3141 --order=/test_alias/task_a/alias0 order  :ma0 rtt:00:00:00.000768
-localhost:3141 --sync=0 6754 269  :ma0 rtt:00:00:00.001300
-localhost:3141 --order=/test_alias/task_a/alias0 alpha  :ma0 rtt:00:00:00.000769
-localhost:3141 --sync=0 6756 269  :ma0 rtt:00:00:00.001274
-localhost:3141 --delete yes /test_alias/task_a/alias0  :ma0 rtt:00:00:00.000748
-localhost:3141 --delete yes /test_alias/task_a/alias1  :ma0 rtt:00:00:00.000741
-localhost:3141 --sync=0 6758 269  :ma0 rtt:00:00:00.001274
-localhost:3141 --zombie_get :ma0 rtt:00:00:00.000768
-localhost:3141 --suites :ma0 rtt:00:00:00.000752
-localhost:3141 --stats :ma0 rtt:00:00:00.000989
-localhost:3141 --terminate=yes :ma0 rtt:00:00:00.001247
diff -pruN 5.12.4-1/Client/test/data/second.def 5.13.0-1/Client/test/data/second.def
--- 5.12.4-1/Client/test/data/second.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Client/test/data/second.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
- 
-#
-# The defs is used conjunction with first.def to test resolution of externs
-#
-
-suite a
-   family b
-   		family c
-   			family d
-   				task e
-   					event event
-           	    	meter meter  0 100 100  # meter <name> <min> <max> [optional color change]
-           	endfamily
-    	endfamily
-    endfamily
-endsuite
-
diff -pruN 5.12.4-1/Http/CMakeLists.txt 5.13.0-1/Http/CMakeLists.txt
--- 5.12.4-1/Http/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,158 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-# cpp-httplib requires at least OpenSSL 1.1.1 for https support
-# so if we have OpenSSL enabled and the version is less than this,
-# we should disable SSL capabilities from the HTTP server
-
-if (OPENSSL_FOUND)
-  if (OPENSSL_VERSION VERSION_LESS 1.1.1)
-    ecbuild_warn("HTTP_SERVER requires at least OpenSSL 1.1.1 for https support (have version ${OPENSSL_VERSION}) - disabling https in HTTP server")
-    remove_definitions(-DECF_OPENSSL)
-    set(DISABLED_SSL_IN_HTTP_SERVER 1)
-  endif ()
-endif ()
-
-set(srcs
-  # Headers
-  src/ecflow/http/Api.hpp
-  src/ecflow/http/ApiV1.hpp
-  src/ecflow/http/ApiV1Impl.hpp
-  src/ecflow/http/Base64.hpp
-  src/ecflow/http/BasicAuth.hpp
-  src/ecflow/http/Client.hpp
-  src/ecflow/http/DefsStorage.hpp
-  src/ecflow/http/HttpServer.hpp
-  src/ecflow/http/HttpServerException.hpp
-  src/ecflow/http/JSON.hpp
-  src/ecflow/http/Options.hpp
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/http/TokenStorage.hpp>
-  src/ecflow/http/TreeGeneration.hpp
-  src/ecflow/http/TypeToJson.hpp
-  # Sources
-  src/ecflow/http/Api.cpp
-  src/ecflow/http/ApiV1.cpp
-  src/ecflow/http/ApiV1Impl.cpp
-  src/ecflow/http/BasicAuth.cpp
-  src/ecflow/http/Client.cpp
-  src/ecflow/http/DefsStorage.cpp
-  src/ecflow/http/HttpServer.cpp
-  src/ecflow/http/JSON.cpp
-  src/ecflow/http/Options.cpp
-  src/ecflow/http/TypeToJson.cpp
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/http/TokenStorage.cpp>
-)
-
-ecbuild_add_library(
-  TARGET libhttp
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-  PUBLIC_LIBS
-    base
-    libclient
-    nlohmann::json
-    httplib::httplib
-    $<$<BOOL:${ZLIB_FOUND}>:ZLIB::ZLIB>
-  PUBLIC_DEFINITIONS
-    $<$<BOOL:${ZLIB_FOUND}>:ECF_HTTP_COMPRESSION>
-)
-target_clangformat(libhttp)
-
-# ========================================================================
-# EXE ecflow_http, if OpenSSL not enabled ${OPENSSL_LIBRARIES}, is empty
-
-ecbuild_add_executable(
-  TARGET ecflow_http
-  SOURCES
-    src/ecflow/http/HttpMain.cpp
-  LIBS
-    libhttp
-    libclient
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-)
-target_clangformat(ecflow_http)
-
-# Override default behaviour that add RPATHS during install
-# The only thing that seem to work is set INSTALL_RPATH to ""
-# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
-# had no effect
-#          
-SET_TARGET_PROPERTIES(ecflow_http
-  PROPERTIES
-  INSTALL_RPATH ""
-)
-
-# use, i.e. don't skip the full RPATH for the build tree
-#SET(CMAKE_SKIP_BUILD_RPATH  FALSE)
-
-# when building, don't use the install RPATH already
-# (but later on when installing)
-#SET(CMAKE_BUILD_WITH_INSTALL_RPATH FALSE) 
-
-# the RPATH to be used when installing
-#SET(CMAKE_INSTALL_RPATH "")
-
-# don't add the automatically determined parts of the RPATH
-# which point to directories outside the build tree to the install RPATH
-#SET(CMAKE_INSTALL_RPATH_USE_LINK_PATH FALSE)
-
-if (ENABLE_HTTP AND ENABLE_SERVER)
-
-  if (OPENSSL_FOUND AND NOT DISABLED_SSL_IN_HTTP_SERVER)
-
-    set(test_srcs
-      # Headers
-      test/Certificate.hpp
-      test/InvokeServer.hpp
-      test/TokenFile.hpp
-      # Sources
-      test/TestApiV1.cpp
-      test/TestHttp_main.cpp # test entry point
-    )
-
-    ecbuild_add_test(
-      TARGET
-        s_http
-      LABELS
-        integration nightly
-      SOURCES
-        ${test_srcs}
-      INCLUDES
-        ../Base/test
-      LIBS
-        libhttp
-        libclient
-        libserver
-        Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-        $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-      DEPENDS
-        ecflow_server # the server is launched to support tests
-        ecflow_http
-      TEST_DEPENDS
-        u_base
-        s_client
-    )
-    target_clangformat(s_http
-      CONDITION ENABLE_TESTS
-    )
-  else ()
-    message(WARNING "SSL not enabled - will not run HTTP server tests")
-  endif ()
-
-endif ()
-
-# ===================================================================
-# install
-# ===================================================================
-install(TARGETS ecflow_http DESTINATION bin)
diff -pruN 5.12.4-1/Http/doc/openapi.yaml 5.13.0-1/Http/doc/openapi.yaml
--- 5.12.4-1/Http/doc/openapi.yaml	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/doc/openapi.yaml	1970-01-01 00:00:00.000000000 +0000
@@ -1,1403 +0,0 @@
-openapi: "3.0.0"
-info:
-  version: 1.0.0
-  title: ecFlow REST API
-paths:
-  /suites:
-    get:
-      summary: List all suites
-      operationId: listSuites
-      tags:
-        - suites
-      parameters:
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: A list of suites
-          content:
-            application/json:
-              schema:
-                type: array
-                items:
-                  type: string
-                uniqueItems: true
-              example: ["foo", "bar"]
-
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-    post:
-      summary: Create a new suite
-      operationId: createSuite
-      tags:
-        - suites
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: New suite definition
-        content:
-          application/json:
-            schema:
-              type: object
-              properties:
-                definition:
-                  type: string
-                  example: "suite foo\ntask bar\nendsuite"
-                auto_add_externs:
-                  type: boolean
-                  default: false
-              required:
-              - definition
-      responses:
-        '201':
-          description: Expected response
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-  /suites/tree:
-    get:
-      summary: Show all nodes (suites, families and tasks) as a tree
-      operationId: treeSuites
-      tags:
-        - suites
-      parameters:
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-        - name: content
-          in: query
-          required: false
-          description: Specify tree content
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Full node tree
-          content:
-            application/json:
-              schema:
-                type: object
-              example:
-                foo:
-                   baz: {}
-                bar: {}
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-
-  /suites/{nodeName}/tree:
-    get:
-      summary: Show this node and its children as a tree
-      operationId: treeNodes
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to retrieve
-          schema:
-            type: string
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-        - name: content
-          in: query
-          required: false
-          description: Specify tree content
-          schema:
-            type: string
-      responses:
-        '200':
-          description: A tree of nodes
-          content:
-            application/json:
-              schema:
-                type: object
-              example:
-                baz: {}
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-  /suites/{nodeName}/status:
-    get:
-      summary: Show status of a node (suite, family or task)
-      operationId: showNodeStatus
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to retrieve
-          schema:
-            type: string
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Status of the node
-          content:
-            application/json:
-              schema:
-                type: object
-                properties:
-                  default_status:
-                    type: string
-                  status:
-                    type: string
-                  why:
-                    type: object
-                    properties:
-                      bottom_up_why:
-                        type: array
-                        items:
-                          type: string
-                      top_down_why:
-                        type: array
-                        items: 
-                          type: string
-              example:
-                default_status: queued
-                status: complete
-                why:
-                  bottom_up_why: [ "SUITE:/foo is suspended" ]
-                  top_down_why: [ "SUITE:/foo is suspended" ]
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    put:
-      summary: Update status of a node (suite, family or task)
-      operationId: updateNodeStatus
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to update
-          schema:
-            type: string
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuthh: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: action to take on node
-        content:
-          application/json:
-            schema:
-              $ref: '#/components/schemas/Action'
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-  /suites/{nodeName}/attributes:
-    get:
-      summary: Show attributes of a node (suite, family or task)
-      operationId: showNodeAttributes
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to show
-          schema:
-            type: string
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Description of node attributes
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Attributes"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-    put:
-      summary: Update an attribute of a node (suite, family or task)
-      operationId: updateNodeAttribute
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to update
-          schema:
-            type: string
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: attribute to update
-        content:
-          application/json:
-            schema:
-              $ref: '#/components/schemas/Attribute'
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    post:
-      summary: Create a new attribute for a node (suite, family or task)
-      operationId: createNodeAttribute
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of node where attribute is added
-          schema:
-            type: string
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: attribute to create
-        content:
-          application/json:
-            schema:
-              $ref: '#/components/schemas/Attribute'
-      responses:
-        '201':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    delete:
-      summary: Remove an attribute of a node (suite, family or task)
-      operationId: removeNodeAttribute
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to update
-          schema:
-            type: string
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: attribute to remove
-        content:
-          application/json:
-            schema:
-              $ref: '#/components/schemas/Attribute'
-      responses:
-        '204':
-          description: Expected response to a valid request
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-
-  /suites/{nodeName}/definition:
-    get:
-      summary: Show ecFlow definition of a node (suite, family or task)
-      operationId: showNodeDefinition
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to retrieve
-          schema:
-            type: string
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                type: object
-                properties:
-                  definition:
-                    type: string
-                    example: "suite foo\nendsuite"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    put:
-      summary: Update definition of a node (suite, family or task)
-      operationId: updateNodeDefinition
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node which definition is updated
-          schema:
-            type: string
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: New definition
-        content:
-          application/json:
-            schema:
-              type: object
-              properties:
-                definition:
-                  type: string
-                  example: "family bar\nendfamily"
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    delete:
-      summary: Remove a node (suite, family or task)
-      operationId: removeNode
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to remove
-          schema:
-            type: string
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-      responses:
-        '204':
-          description: Expected response to a valid request
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-  /suites/{nodeName}/script:
-    get:
-      summary: Show script for a task
-      operationId: showNodeScript
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to retrieve (must be a task)
-          schema:
-            type: string
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Script contents
-          content:
-            application/json:
-              schema:
-                type: object
-                properties:
-                  script:
-                    type: string
-                  job:
-                    type: string
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-  /suites/{nodeName}/output:
-    get:
-      summary: Show output of a task
-      operationId: showNodeOutput
-      tags:
-        - nodes
-      parameters:
-        - name: nodeName
-          in: path
-          required: true
-          description: The name of the node to retrieve (must be a task)
-          schema:
-            type: string
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                type: object
-                properties:
-                  job_output:
-                    type: string
-                  kill_output:
-                    type: string
-                  status_output:
-                    type: string
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-  /server/status:
-    get:
-      summary: Show ecFlow server status
-      operationId: showServerStatus
-      tags:
-        - server
-      parameters:
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                type: object
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    put:
-      summary: Update ecFlow server status
-      operationId: updateServerStatus
-      tags:
-        - server
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: action to take on ecFlow server
-        content:
-          application/json:
-            schema:
-              $ref: '#/components/schemas/ServerAction'
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-  /server/ping:
-    get:
-      summary: Ping ecFlow server
-      operationId: pingServer
-      tags:
-        - server
-      parameters:
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                type: object
-                properties:
-                  host:
-                    type: string
-                  round_trip_time:
-                    type: string
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-  /server/attributes:
-    get:
-      summary: Show ecFlow server attributes
-      operationId: showServerAttributes
-      tags:
-        - server
-      parameters:
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                type: array
-                items:
-                  $ref: '#/components/schemas/ServerAttribute'
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    put:
-      summary: Update ecFlow server attribute
-      operationId: changeServerAttribute
-      tags:
-        - server
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: attribute to change
-        content:
-          application/json:
-            schema:
-              $ref: '#/components/schemas/ServerAttribute'
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    delete:
-      summary: Remove ecFlow server attribute
-      operationId: removeServerAttribute
-      tags:
-        - server
-      responses:
-        '204':
-          description: Expected response to a valid request
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-    post:
-      summary: Create a new ecFlow server attribute
-      operationId: createServerAttribute
-      tags:
-        - server
-      security:
-        - BasicAuth: []
-        - TokenAuth: []
-        - ApiKeyAuth: []
-        - ApiKeyAuthLegacy: []
-      requestBody:
-        required: true
-        description: attribute to create
-        content:
-          application/json:
-            schema:
-              $ref: '#/components/schemas/ServerAttribute'
-      responses:
-        '201':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Success20x"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-  /statistics:
-    get:
-      summary: Show REST api statistics
-      operationId: showApiStatistics
-      tags:
-        - api
-      parameters:
-        - name: filter
-          in: query
-          required: false
-          description: Filter results
-          schema:
-            type: string
-      responses:
-        '200':
-          description: Expected response to a valid request
-          content:
-            application/json:
-              schema:
-                type: object
-                properties:
-                  num_requests:
-                    type: integer
-                    example: 1
-                  num_errors:
-                    type: integer
-                    example: 0
-                  num_cached_requests:
-                    type: integer
-                    example: 1
-                  since:
-                    type: string
-                    example: "2022-10-06T12:00:00Z"
-        default:
-          description: unexpected error
-          content:
-            application/json:
-              schema:
-                $ref: "#/components/schemas/Error"
-
-
-components:
-  schemas:
-    ServerAction:
-      type: object
-      required:
-      - action
-      properties:
-        action:
-          type: string
-          enum: [reload_whitelist_file, reload_passwd_file, reload_custom_passwd_file]
-          example: reload_whitelist_file
-    ServerAttribute:
-      type: object
-      required:
-      - type
-      - name
-      - value
-      properties:
-        type:
-          type: string
-          enum: [variable]
-          example: variable
-        name:
-          type: string
-          example: foo
-        value:
-          type: string
-          example: bar
-    Action:
-      type: object
-      required:
-      - action
-      properties:
-        action:
-          type: string
-          enum: [abort, begin, complete, defstatus, execute, init, requeue, rerun, resume, submit, suspend]
-          example: complete
-        recursive:
-          type: boolean
-          default: false
-        force:
-          type: boolean
-          default: false
-        abort_why:
-          type: string
-        defstatus_value:
-          type: string
-    Attribute:
-      type: object
-      required:
-      - type
-      properties:
-        type:
-          type: string
-          enum: [autoarchive, autocancel, autorestore, complete, cron, day, date, event, generic, inlimit, label, late, limit, meter, queue, repeat, time, today, trigger, variable]
-          example: variable
-        name:
-          type: string
-        value:
-          type: string
-        old_value:
-          type: string
-        min:
-          type: string
-        max:
-          type: string
-    Success20x:
-      type: object
-      required:
-        - message
-      properties:
-        message:
-          type: string
-        path:
-          type: string
-    Error:
-      type: object
-      required:
-        - code
-        - message
-      properties:
-        status:
-          type: integer
-        message:
-          type: string
-        path:
-          type: string
-        method:
-          type: string
-        body:
-          type: string
-    Meter:
-      type: object
-      required:
-        - name
-        - value
-        - min
-        - max
-      properties:
-        name:
-          type: string
-        value:
-          type: integer
-        max:
-          type: integer
-        min:
-          type: integer
-    Event:
-      type: object
-      required:
-        - name
-        - value
-      properties:
-        name:
-          type: string
-        value:
-          type: string
-        initial_value:
-          type: string
-    Label:
-      type: object
-      required:
-        - name
-        - value
-      properties:
-        name:
-          type: string
-        value:
-          type: string
-    Variable:
-      type: object
-      required:
-        - name
-        - value
-      properties:
-        name:
-          type: string
-        value:
-          type: string
-        const:
-          type: boolean
-          default: false
-    Limit:
-      type: object
-      required:
-        - name
-        - value
-        - limit
-      properties:
-        name:
-          type: string
-        value:
-          type: string
-        limit:
-          type: integer
-    InLimit:
-      type: object
-      required:
-        - value
-      properties:
-        value:
-          type: string
-    Date:
-      type: object
-      required:
-        - value
-        - free
-      properties:
-        value:
-          type: string
-        free:
-          type: boolean
-    Day:
-      type: object
-      required:
-        - value
-        - free
-        - expired
-      properties:
-        value:
-          type: string
-        free:
-          type: boolean
-        expired:
-          type: boolean
-    Time:
-      type: object
-      required:
-        - value
-        - free
-      properties:
-        value:
-          type: string
-        free:
-          type: boolean
-    Today:
-      type: object
-      required:
-        - value
-        - free
-        - expired
-      properties:
-        value:
-          type: string
-        free:
-          type: boolean
-        expired:
-          type: boolean
-    Cron:
-      type: object
-      required:
-        - value
-      properties:
-        value:
-          type: string
-    Expression:
-      type: object
-      required:
-        - free
-        - value
-        - expressions
-      properties:
-        free:
-          type: boolean
-        value:
-          type: string
-        expressions:
-          type: array
-          items:
-            type:
-              string
-    Flag:
-      type: object
-      required:
-        - value
-      properties:
-        value:
-          type: string
-    Late:
-      type: object
-      required:
-        - value
-      properties:
-        value:
-          type: string
-        submitted:
-          type: string
-        active:
-          type: string
-        complete:
-          type: string
-        complete_is_relative:
-          type: boolean
-        is_late:
-          type: boolean
-    Zombie:
-      type: object
-      properties:
-        type:
-          type: string
-        action:
-          type: string
-        child_commands:
-          type: string
-        lifetime:
-          type: string
-    Queue:
-      type: object
-      required:
-        - name
-        - queue
-        - value
-        - index
-      properties:
-        name:
-          type: string
-        queue:
-          type: array
-          items:
-            type: string
-        index:
-          type: integer
-        value:
-          type: string
-    Generic:
-      type: object
-      required:
-        - name
-        - value
-      properties:
-        name:
-          type: string
-        value:
-          type: array
-          items:
-            type:
-              string
-    TimeSlot:
-      type: object
-      required:
-        - value
-      properties:
-        value:
-          type: string
-    AutoCancel:
-      type: object
-      required:
-        - relative
-        - days
-        - time
-        - value
-      properties:
-        relative:
-          type: boolean
-        value:
-          type: string
-        days:
-          type: boolean
-        time:
-          type: object
-          allOf:
-            - $ref: "#/components/schemas/TimeSlot"
-    AutoRestore:
-      type: object
-      required:
-        - value
-      properties:
-        value:
-          type: array
-          items:
-            type: string
-    AutoArchive:
-      type: object
-      required:
-        - relative
-        - days
-        - time
-        - value
-      properties:
-        relative:
-          type: boolean
-        value:
-          type: string
-        days:
-          type: boolean
-        time:
-          type: object
-          allOf:
-            - $ref: "#/components/schemas/TimeSlot"
-    RepeatDate:
-      type: object
-      required:
-        - name
-        - start
-        - end
-        - step
-        - value
-      properties:
-        name:
-          type: string
-        start:
-          type: integer
-        step:
-          type: integer
-        end:
-          type: integer
-        value:
-          type: integer
-    RepeatDateList:
-      type: object
-      required:
-        - name
-        - index
-        - value
-        - values
-      properties:
-        name:
-          type: string
-        index:
-          type: integer
-        value:
-          type: string
-        values:
-          type: array
-          items:
-            type: string
-    RepeatInteger:
-      type: object
-      required:
-        - name
-        - start
-        - step
-        - end
-        - value
-      properties:
-        name:
-          type: string
-        start:
-          type: integer
-        step:
-          type: integer
-        end:
-          type: integer
-        value:
-          type: integer
-    RepeatDay:
-      type: object
-      required:
-        - name
-        - step
-        - valid
-      properties:
-        name:
-          type: string
-        step:
-          type: integer
-        valid:
-          type: boolean
-    RepeatEnumerated:
-      type: object
-      required:
-        - name
-        - index
-        - value
-        - values
-      properties:
-        name:
-          type: string
-        index:
-          type: integer
-        value:
-          type: string
-        values:
-          type: array
-          items:
-            type: string
-    RepeatString:
-      type: object
-      required:
-        - name
-        - index
-        - value
-        - values
-      properties:
-        name:
-          type: string
-        index:
-          type: integer
-        value:
-          type: string
-        values:
-          type: array
-          items:
-            type: string
-    Attributes:
-      type: object
-      required:
-        - meters
-        - events
-        - labels
-        - variables
-        - inherited_variables
-        - limits
-        - inlimits
-        - dates
-        - days
-        - times
-        - todays
-        - crons
-        - repeat
-        - triggers
-        - completes
-        - flag
-        - late
-        - zombie
-        - queue
-        - generic
-        - autocancel
-        - autoarchive
-        - autorestore
-      properties:
-        events:
-          type: array
-          items:
-            $ref: "#/components/schemas/Event"
-        meters:
-          type: array
-          items:
-            $ref: "#/components/schemas/Meter"
-        labels:
-          type: array
-          items:
-            $ref: "#/components/schemas/Label"
-        variables:
-          type: array
-          items:
-            $ref: "#/components/schemas/Variable"
-        inherited_variables:
-          type: object
-          properties:
-            server:
-              type: array
-              items:
-                $ref: "#/components/schemas/Variable"
-        limits:
-          type: array
-          items:
-            $ref: "#/components/schemas/Limit"
-        inlimits:
-          type: array
-          items:
-            $ref: "#/components/schemas/InLimit"
-        dates:
-          type: array
-          items:
-            $ref: "#/components/schemas/Date"
-        days:
-          type: array
-          items:
-            $ref: "#/components/schemas/Day"
-        times:
-          type: array
-          items:
-            $ref: "#/components/schemas/Time"
-        todays:
-          type: array
-          items:
-            $ref: "#/components/schemas/Today"
-        crons:
-          type: array
-          items:
-            $ref: "#/components/schemas/Cron"
-        repeat:
-          type: object
-          oneOf:
-            - $ref: "#/components/schemas/RepeatDate"
-            - $ref: "#/components/schemas/RepeatDateList"
-            - $ref: "#/components/schemas/RepeatInteger"
-            - $ref: "#/components/schemas/RepeatDay"
-            - $ref: "#/components/schemas/RepeatString"
-            - $ref: "#/components/schemas/RepeatEnumerated"
-        triggers:
-          type: array
-          items:
-            $ref: "#/components/schemas/Expression"
-        completes:
-          type: array
-          items:
-            $ref: "#/components/schemas/Expression"
-        flag:
-          type: object
-          allOf:
-            - $ref: "#/components/schemas/Flag"
-        late:
-          type: object
-          allOf:
-            - $ref: "#/components/schemas/Late"
-        zombies:
-          type: array
-          items:
-            $ref: "#/components/schemas/Zombie"
-        queues:
-          type: array
-          items:
-            $ref: "#/components/schemas/Queue"
-        generics:
-          type: array
-          items:
-            $ref: "#/components/schemas/Generic"
-        autocancel:
-          allOf:
-            - $ref: "#/components/schemas/AutoCancel"
-        autorestore:
-          type: object
-          allOf:
-            - $ref: "#/components/schemas/AutoRestore"
-        autoarchive:
-          type: object
-          allOf:
-            - $ref: "#/components/schemas/AutoArchive"
- 
-  securitySchemes:
-    BasicAuth:
-      type: http
-      scheme: basic
-    TokenAuth:
-      type: http
-      scheme: bearer
-    ApiKeyAuth:
-      type: apiKey
-      in: header
-      name: X-API-Key
-    ApiKeyAuthLegacy:
-      type: apiKey
-      in: query
-      name: key
diff -pruN 5.12.4-1/Http/src/ecflow/http/Api.cpp 5.13.0-1/Http/src/ecflow/http/Api.cpp
--- 5.12.4-1/Http/src/ecflow/http/Api.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/Api.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/Api.hpp"
-
-#include "ecflow/http/ApiV1.hpp"
-#include "ecflow/http/DefsStorage.hpp"
-#include "ecflow/http/Options.hpp"
-
-namespace ecf::http {
-
-void setup(httplib::Server& http_server) {
-    routing(http_server);
-    update_defs_loop(opts.polling_interval);
-
-    if (opts.verbose) {
-        printf("API v1 ready\n");
-    }
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/Api.hpp 5.13.0-1/Http/src/ecflow/http/Api.hpp
--- 5.12.4-1/Http/src/ecflow/http/Api.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/Api.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,22 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_Api_HPP
-#define ecflow_http_Api_HPP
-
-#include "ecflow/http/HttpLibrary.hpp"
-
-namespace ecf::http {
-
-void setup(httplib::Server& server);
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_Api_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/ApiV1.cpp 5.13.0-1/Http/src/ecflow/http/ApiV1.cpp
--- 5.12.4-1/Http/src/ecflow/http/ApiV1.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/ApiV1.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,740 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/ApiV1.hpp"
-
-#include <atomic>
-#include <mutex>
-#include <string>
-
-#include <sys/time.h>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/http/ApiV1Impl.hpp"
-#include "ecflow/http/Client.hpp"
-#include "ecflow/http/HttpServerException.hpp"
-#include "ecflow/http/Options.hpp"
-#include "ecflow/http/TypeToJson.hpp"
-#include "ecflow/node/Defs.hpp"
-
-namespace ecf::http {
-
-static std::chrono::system_clock::time_point api_startup;
-
-std::atomic<unsigned int> num_requests(0);
-std::atomic<unsigned int> num_errors(0);
-std::atomic<unsigned int> num_cached_requests(0);
-std::atomic<unsigned int> last_request_time(0);
-
-namespace /* __anonymous__ */ {
-
-void set_cors(httplib::Response& response) {
-    response.set_header("Access-Control-Allow-Origin", "*");
-    response.set_header("Access-Control-Allow-Credentials", "true");
-    response.set_header("Access-Control-Allow-Headers", "*");
-}
-
-void set_allowed_methods(httplib::Response& response, const std::string& methods) {
-    response.set_header("Allow", methods);
-    response.set_header("Access-Control-Allow-Methods", methods);
-}
-
-void handle_exception(const std::exception& e, const httplib::Request& request, httplib::Response& response) {
-    // Try to guess a bit more suitable return values
-    // based on client output
-    // TODO: should this actually be done? eg. do the status codes *only*
-    // reflect the API functionality or also the application (ecflow) server?
-    // if user requests an ecflow script and the script does not exists, should
-    // 404 be returned (even if the rest api path was correct)?
-
-    auto trimr = [](const std::string& str) {
-        std::string copy = str;
-        copy.erase(copy.find_last_not_of(" \n\r") + 1, std::string::npos);
-        return copy;
-    };
-
-    HttpStatusCode status_code = HttpStatusCode::client_error_bad_request;
-
-    const std::string err = trimr(std::string(e.what()));
-
-    if (err.find("authentication failed") != std::string::npos) {
-        status_code = HttpStatusCode::client_error_unauthorized;
-    }
-    else if (err.find("Could not find") != std::string::npos) {
-        status_code = HttpStatusCode::client_error_not_found;
-    }
-    else if (err.find("Cannot find") != std::string::npos) {
-        status_code = HttpStatusCode::client_error_not_found;
-    }
-    else if (err.find("cannot be found") != std::string::npos &&
-             err.find("Could not find referenced node") == std::string::npos) {
-        status_code = HttpStatusCode::client_error_not_found;
-    }
-    else if (err.find("No such file") != std::string::npos) {
-        status_code = HttpStatusCode::client_error_not_found;
-    }
-    else if (err.find("Add Suite failed: A Suite of name") != std::string::npos) {
-        status_code = HttpStatusCode::client_error_conflict;
-    }
-    else if (err.find("Ran out of end points") != std::string::npos) {
-        status_code = HttpStatusCode::server_error_bad_gateway;
-    }
-    else if (err.find("Failed to connect to ") != std::string::npos) {
-        status_code = HttpStatusCode::server_error_bad_gateway;
-    }
-    else if (err.find("Cannot replace node ") != std::string::npos) {
-        status_code = HttpStatusCode::server_error_bad_gateway;
-    }
-
-    ojson j;
-    j["code"]    = status_code;
-    j["message"] = err;
-    j["path"]    = request.path;
-    j["method"]  = request.method;
-    if (request.body.empty() == false) {
-        j["body"] = request.body;
-    }
-    response.set_content(j.dump(), "application/json");
-    response.status = status_code;
-    set_cors(response);
-}
-
-void handle_exception(const HttpServerException& e, const httplib::Request& request, httplib::Response& response) {
-    ojson j;
-    j["code"]    = e.code();
-    j["message"] = e.what();
-    j["path"]    = request.path;
-    j["method"]  = request.method;
-    if (request.body.empty() == false) {
-        j["body"] = request.body;
-    }
-
-    response.set_content(j.dump(), "application/json");
-    response.status = e.code();
-    set_cors(response);
-}
-
-void set_last_request_time() {
-    struct timeval curtime
-    {
-    };
-    gettimeofday(&curtime, nullptr);
-    last_request_time = static_cast<unsigned int>(curtime.tv_sec);
-}
-
-template <typename T>
-void trycatch(const httplib::Request& request, httplib::Response& response, T&& func) {
-    set_last_request_time();
-    try {
-        num_requests++;
-        func();
-    }
-    catch (const HttpServerException& e) {
-        num_errors++;
-        handle_exception(e, request, response);
-    }
-    catch (const std::exception& e) {
-        num_errors++;
-        handle_exception(e, request, response);
-    }
-}
-
-ojson filter_json(const ojson& j, const httplib::Request& r) {
-
-    const std::string path = r.get_param_value("filter");
-    if (path.empty()) {
-        return j;
-    }
-
-    // split filter path on dot, and reverse the elements
-    // the elements are consumed by the dive() function
-
-    std::vector<std::string> path_elems;
-    ecf::Str::split(path, path_elems, ".");
-    std::reverse(path_elems.begin(), path_elems.end());
-
-    if (path_elems.empty()) {
-        return j;
-    }
-
-    // separate array name and index from a string
-    auto get_array_info = [](std::string_view str) {
-        const auto start = str.find("[");
-        const auto stop  = str.find("]");
-        const auto key   = str.substr(0, start);
-        const int index  = std::stoi(std::string{str.substr(start + 1, stop - start)});
-        return std::make_pair(key, index);
-    };
-
-    // special case: filter is .[INDEX], means that we return the
-    // correct array element from root json element assuming it's an array
-    if (path_elems.size() == 1 && path_elems[0][0] == '[' && path_elems[0][path_elems[0].size() - 1] == ']') {
-        const auto [key, index] = get_array_info(path_elems[0]);
-        return j[index];
-    }
-
-    // recursively find the correct element inside json document
-    std::function<ojson(const ojson&, std::vector<std::string>&)> dive = [&](const ojson& js,
-                                                                             const std::vector<std::string>& elems) {
-        if (elems.empty()) {
-            return js;
-        }
-
-        const auto elem = path_elems.back();
-        path_elems.pop_back();
-
-        try {
-            if (elem.find("[") != std::string::npos && elem.find("]") != std::string::npos) {
-                const auto [key, index] = get_array_info(elem);
-                return dive(js.at(std::string{key})[index], path_elems);
-            }
-
-            return dive(js.at(elem), path_elems);
-        }
-        catch (const ojson::exception& e [[maybe_unused]]) {
-            // filter path is not found or some other problem with user given path
-            return ojson();
-        }
-    };
-
-    return dive(j, path_elems);
-}
-
-static std::string get_tree_content_kind(const httplib::Request& request) {
-    constexpr const char* content = "content";
-    return request.has_param(content) ? request.get_param_value(content) : "basic";
-}
-
-static bool get_tree_content_id_flag(const httplib::Request& request) {
-    constexpr const char* content = "with_id";
-    return request.has_param(content) ? (request.get_param_value(content) == "true" ? true : false) : false;
-}
-
-} // namespace
-
-namespace v1 {
-
-void not_implemented(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::server_error_not_implemented;
-        set_cors(response);
-    });
-}
-
-void suites_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, POST, HEAD");
-        set_cors(response);
-    });
-}
-
-void suites_create(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        add_suite(request, response);
-        set_cors(response);
-    });
-}
-
-void suites_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        num_cached_requests++;
-        ojson j = filter_json(ecf::http::get_suites(), request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_tree_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, HEAD");
-        set_cors(response);
-    });
-}
-
-void node_tree_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        num_cached_requests++;
-        const std::string path = request.matches[1];
-        std::string tree_kind  = get_tree_content_kind(request);
-        bool with_id           = get_tree_content_id_flag(request);
-        ojson tree_content     = (tree_kind == "full") ? get_full_node_tree(path, with_id) : get_basic_node_tree(path);
-        ojson j                = filter_json(tree_content, request);
-        response.status        = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_definition_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, PUT, DELETE, HEAD");
-        set_cors(response);
-    });
-}
-
-void node_definition_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        num_cached_requests++;
-        const std::string path = request.matches[1];
-        ojson j                = filter_json(get_node_definition(path), request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_definition_update(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j = update_node_definition(request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/ojson");
-        set_cors(response);
-    });
-}
-
-void node_definition_delete(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        const std::string path = request.matches[1];
-        auto client            = get_client(request);
-        client->delete_node(path);
-
-        ojson j;
-        j["message"]    = "Node deleted successfully";
-        response.status = HttpStatusCode::success_no_content;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_status_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, PUT, HEAD");
-        set_cors(response);
-    });
-}
-
-void node_status_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        num_cached_requests++;
-        ojson j = filter_json(get_node_status(request), request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_status_update(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j         = update_node_status(request);
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_attributes_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, PUT, POST, DELETE, HEAD");
-        set_cors(response);
-    });
-}
-
-void node_attributes_create(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j         = add_node_attribute(request);
-        response.status = HttpStatusCode::success_created;
-        response.set_content(j.dump(), "application/ojson");
-        response.set_header("Location", "/v1/suites" + static_cast<std::string>(request.matches[1]) + "/attributes");
-        set_cors(response);
-    });
-}
-
-void node_attributes_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        num_cached_requests++;
-        const std::string path = request.matches[1];
-        ojson j                = filter_json(get_node_attributes(path), request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_attributes_update(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j         = update_node_attribute(request);
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_attributes_delete(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j         = delete_node_attribute(request);
-        response.status = HttpStatusCode::success_no_content;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_script_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, HEAD");
-        set_cors(response);
-    });
-}
-
-void node_script_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        const std::string path = request.matches[1];
-        auto client            = get_client(request);
-
-        ojson j;
-
-        client->file(path, "script");
-        j["script"] = client->server_reply().get_string();
-
-        try {
-            client->file(path, "job");
-            j["job"] = client->server_reply().get_string();
-        }
-        catch (const std::exception& e [[maybe_unused]]) {
-            j["job"] = "";
-        }
-
-        j               = filter_json(j, request);
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_script_update(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j         = update_script_content(request);
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void node_output_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, HEAD");
-        set_cors(response);
-    });
-}
-
-void node_output_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j         = filter_json(get_node_output(request), request);
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void server_ping_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, HEAD");
-        set_cors(response);
-    });
-}
-
-void server_ping_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        auto client = get_client(request);
-        client->pingServer();
-
-        ojson j;
-        j["host"]            = client->host() + ":" + client->port();
-        j["round_trip_time"] = to_simple_string(client->round_trip_time());
-        j                    = filter_json(j, request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void server_status_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, PUT, HEAD");
-        set_cors(response);
-    });
-}
-
-void server_status_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        auto client = get_client(request);
-
-        client->stats_server();
-        ojson j = client->server_reply().stats();
-        j       = filter_json(j, request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void server_status_update(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        auto payload = ojson::parse(request.body);
-        if (const std::string name = payload.at("action"); name == "reload_whitelist_file") {
-            get_client(request)->reloadwsfile();
-        }
-        else if (name == "reload_passwd_file") {
-            get_client(request)->reloadpasswdfile();
-        }
-        else if (name == "reload_custom_passwd_file") {
-            get_client(request)->reloadcustompasswdfile();
-        }
-        else {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request, "Invalid action: " + name);
-        }
-
-        ojson j;
-        j["message"]    = "Server updated successfully";
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void server_attributes_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, PUT, POST, DELETE, HEAD");
-        set_cors(response);
-    });
-}
-
-void server_attributes_create(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j = add_server_attribute(request);
-
-        response.status = HttpStatusCode::success_created;
-        response.set_content(j.dump(), "application/json");
-        response.set_header("Location", "/v1/server/attributes");
-        set_cors(response);
-    });
-}
-
-void server_attributes_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        num_cached_requests++;
-        ojson j = filter_json(get_server_attributes(), request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void server_attributes_update(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j = update_server_attribute(request);
-
-        response.status = HttpStatusCode::success_ok;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void server_attributes_delete(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        ojson j = delete_server_attribute(request);
-
-        response.status = HttpStatusCode::success_no_content;
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-void server_statistics_options(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status = HttpStatusCode::success_no_content;
-        set_allowed_methods(response, "GET, HEAD");
-        set_cors(response);
-    });
-}
-
-void server_statistics_read(const httplib::Request& request, httplib::Response& response) {
-    trycatch(request, response, [&]() {
-        response.status     = HttpStatusCode::success_ok;
-        const std::time_t t = std::chrono::system_clock::to_time_t(api_startup);
-        std::array<char, 80> date{};
-        std::tm tm{};
-        gmtime_r(&t, &tm);
-        strftime(date.data(), 80, "%Y-%m-%dT%H:%M:%SZ", &tm);
-
-        ojson j = {{"num_requests", num_requests.load()},
-                   {"num_errors", num_errors.load()},
-                   {"num_cached_requests", num_cached_requests.load()},
-                   {"since", std::string{date.data()}}};
-
-        j = filter_json(j, request);
-        response.set_content(j.dump(), "application/json");
-        set_cors(response);
-    });
-}
-
-} // namespace v1
-
-void routing(httplib::Server& http_server) {
-    if (opts.verbose) {
-        printf("Registering API location /v1\n");
-    }
-
-    /* .../suites */
-    {
-        std::string resource_path = R"(/v1/suites)";
-
-        http_server.Options(resource_path, v1::suites_options); // Options
-        http_server.Post(resource_path, v1::suites_create);     // Create
-        http_server.Get(resource_path, v1::suites_read);        // Read
-        http_server.Put(resource_path, v1::not_implemented);    // Update
-        http_server.Delete(resource_path, v1::not_implemented); // Delete
-    }
-
-    /* .../suites/<path>/tree */
-    {
-        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/tree)";
-        std::string resource_root = R"(/v1/suites(/)tree)";
-
-        http_server.Options(resource_path, v1::node_tree_options); // Options
-        http_server.Post(resource_path, v1::not_implemented);      // Create
-        http_server.Get(resource_root, v1::node_tree_read);        // Read
-        http_server.Get(resource_path, v1::node_tree_read);        // Read
-        http_server.Put(resource_path, v1::not_implemented);       // Updat
-        http_server.Delete(resource_path, v1::not_implemented);    // Delete
-    }
-
-    /* .../suites/<path>/definition */
-    {
-        std::string resourse_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/definition$)";
-
-        http_server.Options(resourse_path, v1::node_definition_options); // Options
-        http_server.Post(resourse_path, v1::not_implemented);            // Create
-        http_server.Get(resourse_path, v1::node_definition_read);        // Read
-        http_server.Put(resourse_path, v1::node_definition_update);      // Update
-        http_server.Delete(resourse_path, v1::node_definition_delete);   // Delete
-    }
-
-    /* .../suites/<path>/status */
-    {
-        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/status$)";
-
-        http_server.Options(resource_path, v1::node_status_options); // Options
-        http_server.Post(resource_path, v1::not_implemented);        // Create
-        http_server.Get(resource_path, v1::node_status_read);        // Read
-        http_server.Put(resource_path, v1::node_status_update);      // Update
-        http_server.Delete(resource_path, v1::not_implemented);      // Delete
-    }
-
-    /* .../suites/<path>/attributes */
-    {
-        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/attributes$)";
-
-        http_server.Options(resource_path, v1::node_attributes_options); // Options
-        http_server.Post(resource_path, v1::node_attributes_create);     // Create
-        http_server.Get(resource_path, v1::node_attributes_read);        // Read
-        http_server.Put(resource_path, v1::node_attributes_update);      // Update
-        http_server.Delete(resource_path, v1::node_attributes_delete);   // Delete
-    }
-
-    /* .../suites/<path>/script */
-    {
-        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/script$)";
-
-        http_server.Options(resource_path, v1::node_script_options); // Options
-        http_server.Post(resource_path, v1::not_implemented);        // Create
-        http_server.Get(resource_path, v1::node_script_read);        // Read
-        http_server.Put(resource_path, v1::not_implemented);         // Update
-        http_server.Delete(resource_path, v1::not_implemented);      // Delete
-    }
-
-    /* .../suites/<path>/output */
-    {
-        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/output$)";
-
-        http_server.Options(resource_path, v1::node_output_options); // Options
-        http_server.Post(resource_path, v1::not_implemented);        // Create
-        http_server.Get(resource_path, v1::node_output_read);        // Read
-        http_server.Put(resource_path, v1::not_implemented);         // Update
-        http_server.Delete(resource_path, v1::not_implemented);      // Delete
-    }
-
-    /* .../server/ping */
-    {
-        std::string resource_path = R"(/v1/server/ping)";
-
-        http_server.Options(resource_path, v1::server_ping_options); // Options
-        http_server.Post(resource_path, v1::not_implemented);        // Create
-        http_server.Get(resource_path, v1::server_ping_read);        // Read
-        http_server.Put(resource_path, v1::not_implemented);         // Update
-        http_server.Delete(resource_path, v1::not_implemented);      // Delete
-    }
-
-    /* .../server/status */
-    {
-        std::string resource_path = R"(/v1/server/status)";
-
-        http_server.Options("/v1/server/status", v1::server_status_options); // Options
-        http_server.Post(resource_path, v1::not_implemented);                // Create
-        http_server.Get(resource_path, v1::server_status_read);              // Read
-        http_server.Put("/v1/server/status", v1::server_status_update);      // Update
-        http_server.Delete(resource_path, v1::not_implemented);              // Delete
-    }
-
-    /* .../server/attributes */
-    {
-        std::string resource_path = R"(/v1/server/attributes)";
-
-        http_server.Options(resource_path, v1::server_attributes_options); // Options
-        http_server.Post(resource_path, v1::server_attributes_create);     // Create
-        http_server.Get(resource_path, v1::server_attributes_read);        // Read
-        http_server.Put(resource_path, v1::server_attributes_update);      // Update
-        http_server.Delete(resource_path, v1::server_attributes_delete);   // Delete
-    }
-
-    /* .../statistics */
-    {
-        std::string resource_path = R"(/v1/statistics)";
-
-        http_server.Options(resource_path, v1::server_statistics_options); // Options
-        http_server.Post(resource_path, v1::not_implemented);              // Create
-        http_server.Get(resource_path, v1::server_statistics_read);        // Read
-        http_server.Put(resource_path, v1::not_implemented);               // Update
-        http_server.Delete(resource_path, v1::not_implemented);            // Delete
-    }
-
-    api_startup = std::chrono::system_clock::now();
-    set_last_request_time();
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/ApiV1.hpp 5.13.0-1/Http/src/ecflow/http/ApiV1.hpp
--- 5.12.4-1/Http/src/ecflow/http/ApiV1.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/ApiV1.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,74 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_ApiV1_HPP
-#define ecflow_http_ApiV1_HPP
-
-#include "ecflow/http/DefsStorage.hpp"
-#include "ecflow/http/HttpLibrary.hpp"
-
-namespace ecf::http {
-
-void routing(httplib::Server& http_server);
-
-namespace v1 {
-
-void not_implemented(const httplib::Request& request, httplib::Response& response);
-
-void suites_options(const httplib::Request& request, httplib::Response& response);
-void suites_create(const httplib::Request& request, httplib::Response& response);
-void suites_read(const httplib::Request& request, httplib::Response& response);
-
-void node_tree_options(const httplib::Request& request, httplib::Response& response);
-void node_tree_read(const httplib::Request& request, httplib::Response& response);
-
-void node_definition_options(const httplib::Request& request, httplib::Response& response);
-void node_definition_read(const httplib::Request& request, httplib::Response& response);
-void node_definition_update(const httplib::Request& request, httplib::Response& response);
-void node_definition_delete(const httplib::Request& request, httplib::Response& response);
-
-void node_status_options(const httplib::Request& request, httplib::Response& response);
-void node_status_read(const httplib::Request& request, httplib::Response& response);
-void node_status_update(const httplib::Request& request, httplib::Response& response);
-
-void node_attributes_options(const httplib::Request& request, httplib::Response& response);
-void node_attributes_create(const httplib::Request& request, httplib::Response& response);
-void node_attributes_read(const httplib::Request& request, httplib::Response& response);
-void node_attributes_update(const httplib::Request& request, httplib::Response& response);
-void node_attributes_delete(const httplib::Request& request, httplib::Response& response);
-
-void node_script_options(const httplib::Request& request, httplib::Response& response);
-void node_script_read(const httplib::Request& request, httplib::Response& response);
-void node_script_update(const httplib::Request& request, httplib::Response& response);
-
-void node_output_options(const httplib::Request& request, httplib::Response& response);
-void node_output_read(const httplib::Request& request, httplib::Response& response);
-
-void server_ping_options(const httplib::Request& request, httplib::Response& response);
-void server_ping_read(const httplib::Request& request, httplib::Response& response);
-
-void server_status_options(const httplib::Request& request, httplib::Response& response);
-void server_status_read(const httplib::Request& request, httplib::Response& response);
-void server_status_update(const httplib::Request& request, httplib::Response& response);
-
-void server_attributes_options(const httplib::Request& request, httplib::Response& response);
-void server_attributes_create(const httplib::Request& request, httplib::Response& response);
-void server_attributes_read(const httplib::Request& request, httplib::Response& response);
-void server_attributes_update(const httplib::Request& request, httplib::Response& response);
-void server_attributes_delete(const httplib::Request& request, httplib::Response& response);
-
-void server_statistics_options(const httplib::Request& request, httplib::Response& response);
-void server_statistics_read(const httplib::Request& request, httplib::Response& response);
-
-} // namespace v1
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_ApiV1_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/ApiV1Impl.cpp 5.13.0-1/Http/src/ecflow/http/ApiV1Impl.cpp
--- 5.12.4-1/Http/src/ecflow/http/ApiV1Impl.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/ApiV1Impl.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1022 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/ApiV1Impl.hpp"
-
-#include <optional>
-#include <string>
-
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DState.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/Overload.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/http/BasicAuth.hpp"
-#include "ecflow/http/Client.hpp"
-#include "ecflow/http/HttpServerException.hpp"
-#include "ecflow/http/Options.hpp"
-#if defined(ECF_OPENSSL)
-    #include "ecflow/http/TokenStorage.hpp"
-#endif
-#include "ecflow/http/DefsStorage.hpp"
-#include "ecflow/http/HttpLibrary.hpp"
-#include "ecflow/http/TreeGeneration.hpp"
-#include "ecflow/http/TypeToJson.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/DefsTreeVisitor.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/node/parser/DefsStructureParser.hpp"
-
-// For token based authentication, this user account
-// needs to have full access to server as it's acting
-// in lieu of the actual user
-
-namespace ecf::http {
-
-namespace {
-
-ojson make_json_response(std::string_view path, std::string_view message) {
-    return ojson::object({{"path", path}, {"message", message}});
-}
-
-} // namespace
-
-ojson make_node_json(node_ptr node) {
-    return ojson::object(
-        {{"type", ecf::algorithm::tolower(node->debugType())}, {"name", node->name()}, {"children", ojson::array()}});
-}
-
-void print_sparser_node(ojson& j, const std::vector<node_ptr>& nodes) {
-    for (const auto& node : nodes) {
-        const std::string type = ecf::algorithm::tolower(node->debugType());
-
-        j[node->name()] = ojson::object({});
-        if (type == "family") {
-            print_sparser_node(j[node->name()], std::dynamic_pointer_cast<Family>(node)->nodeVec());
-        }
-    }
-}
-
-void print_node(ojson& j, const std::vector<node_ptr>& nodes, bool add_id = false) {
-    j["children"].get_ptr<ojson::array_t*>()->reserve(nodes.size());
-    for (const auto& node : nodes) {
-        const std::string type = ecf::algorithm::tolower(node->debugType());
-        auto jnode             = make_node_json(node);
-
-        j["children"].push_back(jnode);
-        if (type == "family") {
-            print_node(j["children"].back(), std::dynamic_pointer_cast<Family>(node)->nodeVec(), add_id);
-        }
-    }
-}
-
-node_ptr get_node(const std::string& path) {
-    node_ptr node = get_defs()->findAbsNode(path);
-    if (node.get() == nullptr) {
-        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
-    }
-
-    return node;
-}
-
-ojson get_node_status(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-
-    auto client = get_client(request);
-    client->query("dstate", path, "");
-
-    ojson j;
-    j["status"] = client->server_reply().get_string();
-    j["path"]   = path;
-
-    if (node_ptr node = get_node(path); node) {
-        j["default_status"] = DState::to_string(node->defStatus());
-
-        std::vector<std::string> why;
-        node->bottom_up_why(why);
-        j["why"]                  = ojson::object({});
-        j["why"]["bottom_up_why"] = why;
-        why.clear();
-        node->top_down_why(why);
-        j["why"]["top_down_why"] = why;
-    }
-
-    return j;
-}
-
-template <typename T>
-void apply_to_parents(const Node* node, T&& func) {
-    for (const Node* up = node; up != nullptr; up = up->parent()) {
-        func(up);
-    }
-}
-
-ojson get_basic_node_tree(const std::string& path) {
-    BasicTree tree;
-    DefsTreeVisitor(get_defs(), tree).visit_at(path);
-    return tree.content();
-}
-
-ojson get_full_node_tree(const std::string& path, bool with_id) {
-    FullTree tree{with_id};
-    DefsTreeVisitor(get_defs(), tree).visit_at(path);
-    return tree.content();
-}
-
-ojson get_sparser_node_tree(const std::string& path) {
-    ojson j;
-
-    if (path == "/") {
-        const std::vector<suite_ptr> suites = get_defs()->suiteVec();
-        for (const auto& suite : suites) {
-            j[suite->name()] = ojson::object({});
-
-            print_sparser_node(j[suite->name()], suite->nodeVec());
-        }
-    }
-    else {
-        node_ptr node = get_node(path);
-
-        if (node == nullptr) {
-            throw HttpServerException(HttpStatusCode::client_error_not_found, "Node " + path + " not found");
-        }
-
-        const std::string type = ecf::algorithm::tolower(node->debugType());
-
-        if (type == "family") {
-            print_sparser_node(j, std::dynamic_pointer_cast<Family>(node)->nodeVec());
-        }
-        else if (type == "suite") {
-            print_sparser_node(j, std::dynamic_pointer_cast<Suite>(node)->nodeVec());
-        }
-    }
-
-    return j;
-}
-
-ojson get_node_tree(const std::string& path, bool add_id = false) {
-    ojson j;
-
-    if (path == "/") {
-        const std::vector<suite_ptr> suites = get_defs()->suiteVec();
-        j["suites"]                         = ojson::array();
-        j["suites"].get_ptr<ojson::array_t*>()->reserve(suites.size());
-
-        for (const auto& suite : suites) {
-            ojson js = make_node_json(suite);
-
-            print_node(js, suite->nodeVec(), add_id);
-
-            j["suites"].push_back(js);
-        }
-    }
-    else {
-        node_ptr node = get_node(path);
-
-        if (node == nullptr) {
-            throw HttpServerException(HttpStatusCode::client_error_not_found, "Node " + path + " not found");
-        }
-
-        j = make_node_json(node);
-
-        const std::string type = ecf::algorithm::tolower(node->debugType());
-
-        if (type == "family") {
-            print_node(j, std::dynamic_pointer_cast<Family>(node)->nodeVec(), add_id);
-        }
-        else if (type == "suite") {
-            print_node(j, std::dynamic_pointer_cast<Suite>(node)->nodeVec(), add_id);
-        }
-    }
-
-    return j;
-}
-
-ojson get_suites() {
-    auto suites = get_defs()->suiteVec();
-
-    ojson j = ojson::array();
-    for (const auto& s : suites) {
-        j.push_back(s->name());
-    }
-    return j;
-}
-
-ojson get_server_attributes() {
-
-    ojson j;
-
-    j["variables"] = get_defs()->server().user_variables();
-
-    for (auto v : get_defs()->server().server_variables()) {
-        ojson _j    = v;
-        _j["const"] = true;
-        j["variables"].push_back(_j);
-    }
-    return j;
-}
-
-ojson get_node_attributes(const std::string& path) {
-    ojson j;
-
-    node_ptr node = get_node(path);
-
-    j["meters"]      = node->meters();
-    j["limits"]      = node->limits();
-    j["inlimits"]    = node->inlimits();
-    j["events"]      = node->events();
-    j["variables"]   = node->variables();
-    j["labels"]      = node->labels();
-    j["dates"]       = node->dates();
-    j["days"]        = node->days();
-    j["crons"]       = node->crons();
-    j["times"]       = node->timeVec();
-    j["todays"]      = node->todayVec();
-    j["repeat"]      = node->repeat();
-    j["path"]        = path;
-    j["trigger"]     = node->get_trigger();
-    j["complete"]    = node->get_complete();
-    j["flag"]        = node->get_flag();
-    j["late"]        = node->get_late();
-    j["zombies"]     = node->zombies();
-    j["generics"]    = node->generics();
-    j["queues"]      = node->queues();
-    j["autocancel"]  = node->get_autocancel();
-    j["autoarchive"] = node->get_autoarchive();
-    j["autorestore"] = node->get_autorestore();
-
-    {
-        // Collect 'normal' variables
-        auto vars = node->variables();
-        // ... and generated variables
-        node->gen_variables(vars);
-
-        j["variables"] = vars;
-    }
-
-    apply_to_parents(node->parent(), [&j](const Node* n) {
-        // Collect 'normal' variables
-        auto vars = n->variables();
-        // ... and generated variables
-        n->gen_variables(vars);
-
-        j["inherited_variables"][n->name()] = vars;
-    });
-
-    auto server_variables = get_defs()->server().server_variables();
-    auto user_variables   = get_defs()->server().user_variables();
-
-    server_variables.insert(server_variables.end(), user_variables.begin(), user_variables.end());
-
-    j["inherited_variables"]["server"] = server_variables;
-
-    return j;
-}
-
-ojson get_node_definition(const std::string& path) {
-    ojson j;
-
-    node_ptr node = get_node(path);
-
-    j["definition"] = node->print();
-    j["path"]       = path;
-
-    return j;
-}
-
-ojson get_node_output(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-
-    auto client = get_client(request);
-
-    ojson j;
-
-    client->file(path, "jobout");
-    j["job_output"] = client->server_reply().get_string();
-
-    try {
-        client->file(path, "kill");
-        j["kill_output"] = client->server_reply().get_string();
-    }
-    catch (const std::exception& e [[maybe_unused]]) {
-        j["kill_output"] = "";
-    }
-
-    try {
-        client->file(path, "stat");
-        j["status_output"] = client->server_reply().get_string();
-    }
-    catch (const std::exception& e [[maybe_unused]]) {
-        j["status_output"] = "";
-    }
-
-    return j;
-}
-
-void add_suite(const httplib::Request& request, httplib::Response& response) {
-    const std::string path = request.matches[1];
-    const ojson payload    = ojson::parse(request.body);
-
-    const std::string defs = payload.at("definition");
-
-    DefsStructureParser parser(defs);
-
-    {
-        std::string errorMsg;
-        std::string warningMsg;
-
-        if (parser.doParse(errorMsg, warningMsg) == false) {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                      "Invalid definition: " + errorMsg + "/" + warningMsg);
-        }
-    }
-
-    node_ptr node = parser.the_node_ptr();
-
-    auto defsptr = Defs::create();
-    {
-        std::string errorMsg;
-        std::string warningMsg;
-        defsptr->restore_from_string(defs, errorMsg, warningMsg);
-    }
-
-    try {
-        if (json_type_to_string(payload.at("auto_add_externs")) == "true") {
-            defsptr->auto_add_externs(true);
-        }
-    }
-    catch (const ojson::exception& e [[maybe_unused]]) {
-        // Nothing to do...
-    }
-
-    auto client = get_client(request);
-    client->load(defsptr);
-
-    ojson j;
-    j["message"] = "Suite(s) created successfully";
-    response.set_content(j.dump(), "application/json");
-    response.status = HttpStatusCode::success_created;
-    response.set_header("Location", request.path + "/" + node->name() + "/definition");
-}
-
-ojson update_node_definition(const httplib::Request& request) {
-    const std::string path         = request.matches[1];
-    const ojson payload            = ojson::parse(request.body);
-    const std::string new_defs_str = payload.at("definition");
-    const bool force               = payload.value("force", false);
-
-    // Support "partial node adding/replacement", meaning that
-    // user can give us just the definition of a new task, and
-    // we will add that to the suite.
-
-    // this takes a long time, but we need a copy as we are changing
-    // the defs locally here
-
-    auto defs   = std::make_shared<Defs>(*get_defs());
-    auto parent = defs->findAbsNode(path);
-
-    if (parent == nullptr) {
-        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path not found");
-    }
-
-    DefsStructureParser parser(new_defs_str);
-
-    {
-        std::string errorMsg;
-        std::string warningMsg;
-
-        if (parser.doParse(errorMsg, warningMsg) == false) {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                      "Invalid definition: " + errorMsg + "/" + warningMsg);
-        }
-    }
-
-    // If a child with the same name exists already, it needs to be removed
-    // before adding it with this new definition
-    node_ptr node = parser.the_node_ptr();
-    size_t pos    = 0;
-    if (auto child = parent->findImmediateChild(node->name(), pos); child) {
-        parent->removeChild(child.get());
-    }
-
-    {
-        std::string errorMsg;
-        if (parent->isAddChildOk(node.get(), errorMsg) == false) {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request, errorMsg);
-        }
-    }
-
-    parent->addChild(node);
-
-    auto client = get_client(request);
-    client->replace(path, defs->print(), true, force);
-
-    return make_json_response(path, "Definition updated successfully");
-}
-
-namespace /* __anonymous__ */ {
-
-template <typename T>
-void add_attribute_to_node(node_ptr node, const T& attr);
-
-template <>
-void add_attribute_to_node(node_ptr node, const Meter& attr) {
-    node->addMeter(attr);
-}
-
-template <>
-void add_attribute_to_node(node_ptr node, const Event& attr) {
-    node->addEvent(attr);
-}
-
-template <>
-void add_attribute_to_node(node_ptr node, const ecf::CronAttr& attr) {
-    node->addCron(attr);
-}
-
-template <>
-void add_attribute_to_node(node_ptr node, const std::string& attr) {
-    node->add_complete(attr);
-}
-
-template <>
-void add_attribute_to_node(node_ptr node, const ecf::AutoCancelAttr& attr) {
-    node->addAutoCancel(attr);
-}
-
-template <>
-void add_attribute_to_node(node_ptr node, const ecf::AutoRestoreAttr& attr) {
-    node->add_autorestore(attr);
-}
-
-template <>
-void add_attribute_to_node(node_ptr node, const ecf::AutoArchiveAttr& attr) {
-    node->add_autoarchive(attr);
-}
-
-} // namespace
-
-template <typename T>
-void add_attribute_to_path(const T& attr, const httplib::Request& request) {
-    const std::string path = request.matches[1];
-
-    auto defs   = std::make_shared<Defs>(*get_defs());
-    auto parent = defs->findAbsNode(path);
-
-    if (parent.get() == nullptr) {
-        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
-    }
-    add_attribute_to_node(parent, attr);
-
-    auto client = get_client(request);
-    client->replace(path, defs->print(), false, false);
-}
-
-void remove_attribute_from_path(std::string_view type, const httplib::Request& request) {
-    const std::string path = request.matches[1];
-
-    auto defs   = std::make_shared<Defs>(*get_defs());
-    auto parent = defs->findAbsNode(path);
-
-    if (parent.get() == nullptr) {
-        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
-    }
-
-    if (type == "autocancel") {
-        parent->deleteAutoCancel();
-    }
-    else if (type == "autorestore") {
-        parent->deleteAutoRestore();
-    }
-    else if (type == "autoarchive") {
-        parent->deleteAutoArchive();
-    }
-
-    auto client = get_client(request);
-    client->replace(path, defs->print(), false, false);
-}
-
-template <typename T>
-void update_attribute_in_path(const T& attr, std::string_view type, const httplib::Request& request) {
-    const std::string path = request.matches[1];
-
-    auto defs   = std::make_shared<Defs>(*get_defs());
-    auto parent = defs->findAbsNode(path);
-
-    if (parent.get() == nullptr) {
-        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
-    }
-
-    if (type == "autocancel") {
-        parent->deleteAutoCancel();
-    }
-    else if (type == "autorestore") {
-        parent->deleteAutoRestore();
-    }
-    else if (type == "autoarchive") {
-        parent->deleteAutoArchive();
-    }
-
-    add_attribute_to_node(parent, attr);
-
-    auto client = get_client(request);
-    client->replace(path, defs->print(), false, false);
-}
-
-template <typename T>
-T create_from_text(const std::string& line);
-
-template <>
-ecf::AutoArchiveAttr create_from_text(const std::string& line) {
-    if (line.find_first_of(':') == std::string::npos) {
-        try {
-            return ecf::AutoArchiveAttr(std::stoi(line));
-        }
-        catch (const std::exception& e) {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                      "Invalid value for autoarchive: " + line + " (" + e.what() + ")");
-        }
-    }
-    else {
-        int hour      = 0;
-        int min       = 0;
-        bool relative = ecf::TimeSeries::getTime(line, hour, min);
-        return ecf::AutoArchiveAttr(ecf::TimeSlot(hour, min), relative);
-    }
-}
-template <>
-ecf::AutoCancelAttr create_from_text(const std::string& line) {
-    if (line.find_first_of(':') == std::string::npos) {
-        try {
-            return ecf::AutoCancelAttr(std::stoi(line));
-        }
-        catch (const std::exception& e) {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                      "Invalid value for autocancel: " + line + " (" + e.what() + ")");
-        }
-    }
-    else {
-        int hour      = 0;
-        int min       = 0;
-        bool relative = ecf::TimeSeries::getTime(line, hour, min);
-        return ecf::AutoCancelAttr(ecf::TimeSlot(hour, min), relative);
-    }
-}
-template <>
-ecf::AutoRestoreAttr create_from_text(const std::string& line) {
-    std::vector<std::string> tasks;
-    ecf::Str::split(line, tasks, " ");
-
-    return ecf::AutoRestoreAttr(tasks);
-}
-
-ojson add_node_attribute(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-    const ojson payload    = ojson::parse(request.body);
-
-    const std::string type  = payload.at("type");
-    const std::string value = json_type_to_string(payload.at("value"));
-
-    auto client = get_client(request);
-
-    if (type == "meter") {
-        const std::string name = payload.at("name");
-        int min                = stoi(json_type_to_string(payload.at("min")));
-        int max                = stoi(json_type_to_string(payload.at("max")));
-        const Meter m(name, min, max, std::numeric_limits<int>::max(), stoi(value));
-        add_attribute_to_path(m, request);
-        // Adding a meter always results to having its value == min, even if the value
-        // of argument 'value' is something different
-        client->alter(path, "change", "meter", name, value);
-    }
-    else if (type == "event") {
-        const std::string name = payload.at("name");
-        const Event e(std::numeric_limits<int>::max(), name, (value == "true") ? true : false);
-        add_attribute_to_path(e, request);
-        if (value != "set" && value != "true" && value != "clear" && value != "false") {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                      "'value' for event must be one of: set/true, clear/false");
-        }
-        std::string value_ = (value == "true" || value == "set") ? "set" : "clear";
-        client->alter(path, "change", "event", name, value_);
-    }
-    else if (type == "cron") {
-        add_attribute_to_path(ecf::CronAttr::create(value), request);
-    }
-    else if (type == "complete") {
-        add_attribute_to_path(value, request);
-    }
-    else if (type == "autocancel") {
-        add_attribute_to_path(create_from_text<ecf::AutoCancelAttr>(value), request);
-    }
-    else if (type == "autorestore") {
-        add_attribute_to_path(create_from_text<ecf::AutoRestoreAttr>(value), request);
-    }
-    else if (type == "autoarchive") {
-        add_attribute_to_path(create_from_text<ecf::AutoArchiveAttr>(value), request);
-    }
-    else if (type == "time" || type == "day" || type == "date" || type == "today" || type == "late") {
-        client->alter(path, "add", type, value);
-    }
-    else {
-        const std::string name = payload.at("name");
-        client->alter(path, "add", type, name, value);
-    }
-
-    return make_json_response(path, "Attribute added successfully");
-}
-
-namespace /* __anonymous__ */ {
-
-ojson update_node_attribute_by_task(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-
-    const ojson payload    = ojson::parse(request.body);
-    const std::string type = payload.at("type");
-    const std::string name = payload.at("name");
-
-    // this is a child command call
-    if (ecf::Child::valid_child_cmd(type) == false) {
-        throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                  "Invalid action for child command: " + name);
-    }
-
-    auto client = get_client_for_tasks(request, payload);
-
-    struct Ancillary
-    {
-        std::string type;
-        std::string action;
-        std::string value;
-    };
-    std::optional<Ancillary> ancillary;
-
-    if (type == "event") {
-        const std::string value = payload.at("value");
-        if (value != "set" && value != "true" && value != "clear" && value != "false") {
-            throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                      "'value' for event must be one of: set/true, clear/false");
-        }
-        client->child_event(name, (value == "true" || value == "set"));
-    }
-    else if (type == "meter") {
-        const std::string value = payload.at("value");
-        client->child_meter(name, std::stoi(value));
-    }
-    else if (type == "label") {
-        const std::string value = payload.at("value");
-        client->child_label(name, value);
-    }
-    else if (type == "queue") {
-        auto queue_action = payload.at("queue_action").get<std::string>();
-        auto queue_step   = payload.contains("queue_step") ? payload.at("queue_step").get<std::string>() : "";
-        auto queue_path   = payload.contains("queue_path") ? payload.at("queue_path").get<std::string>() : "";
-        std::string reply = client->child_queue(name, queue_action, queue_step, queue_path);
-
-        if (queue_action == "active" || queue_action == "no_of_aborted") {
-            ancillary = std::make_optional(Ancillary{type, queue_action, reply});
-        }
-    }
-    else {
-        throw HttpServerException(HttpStatusCode::server_error_not_implemented,
-                                  "Child action " + type + ", on attribute " + name + ", is not supported");
-    }
-
-    ojson j = make_json_response(path, "Attribute changed successfully");
-    if (ancillary) {
-        if (ancillary->action == "active") {
-            j["step"] = ancillary->value;
-        }
-        else if (ancillary->action == "no_of_aborted") {
-            j["no_of_aborted"] = ancillary->value;
-        }
-    }
-    return j;
-}
-
-ojson update_node_attribute_by_user(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-    const ojson payload    = ojson::parse(request.body);
-
-    std::string type = payload.at("type");
-
-    auto client = get_client(request);
-
-    if (type == "repeat" || type == "late" || type == "complete") {
-        const std::string value = json_type_to_string(payload.at("value"));
-        client->alter(path, "change", type, value);
-    }
-    else if (type == "today" || type == "time" || type == "late") {
-        const std::string value     = json_type_to_string(payload.at("value"));
-        const std::string old_value = json_type_to_string(payload.at("old_value"));
-        client->alter(path, "change", type, old_value, value);
-    }
-    else if (type == "day" || type == "date") {
-        const std::string value     = json_type_to_string(payload.at("value"));
-        const std::string old_value = json_type_to_string(payload.at("old_value"));
-        client->alter(path, "delete", type, old_value);
-        client->alter(path, "add", type, value);
-    }
-    else if (type == "autocancel") {
-        const std::string value = json_type_to_string(payload.at("value"));
-        update_attribute_in_path(create_from_text<ecf::AutoCancelAttr>(value), type, request);
-        trigger_defs_update();
-    }
-    else if (type == "autorestore") {
-        const std::string value = json_type_to_string(payload.at("value"));
-        update_attribute_in_path(create_from_text<ecf::AutoRestoreAttr>(value), type, request);
-        trigger_defs_update();
-    }
-    else if (type == "autoarchive") {
-        const std::string value = json_type_to_string(payload.at("value"));
-        update_attribute_in_path(create_from_text<ecf::AutoArchiveAttr>(value), type, request);
-        trigger_defs_update();
-    }
-    else if (type == "cron") {
-        const std::string value     = json_type_to_string(payload.at("value"));
-        const std::string old_value = json_type_to_string(payload.at("old_value"));
-        client->alter(path, "delete", type, old_value);
-        trigger_defs_update([&] { add_attribute_to_path(ecf::CronAttr::create(value), request); });
-    }
-    else if (type == "limit") {
-        const std::string name = payload.at("name");
-        const static std::vector<std::string> keys{"max", "value"};
-        std::string value;
-        try {
-            value = json_type_to_string(payload.at("value"));
-            type  = type + "_value";
-        }
-        catch (const ojson::out_of_range& e [[maybe_unused]]) {
-            try {
-                value = json_type_to_string(payload.at("max"));
-                type  = type + "_max";
-            }
-            catch (const ojson::out_of_range& e [[maybe_unused]]) {
-                throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                          "For limit either 'max' or 'value' must be defined");
-            }
-        }
-        client->alter(path, "change", type, name, value);
-    }
-    else {
-        const std::string name = payload.at("name");
-        std::string value      = json_type_to_string(payload.at("value"));
-        if (type == "event") {
-            if (value != "set" && value != "true" && value != "clear" && value != "false") {
-                throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                          "'value' for event must be one of: set/true, clear/false");
-            }
-            value = (value == "true" || value == "set") ? "set" : "clear";
-        }
-        client->alter(path, "change", type, name, value);
-    }
-
-    return make_json_response(path, "Attribute changed successfully");
-}
-
-} // namespace
-
-ojson update_node_attribute(const httplib::Request& request) {
-
-    const ojson payload = ojson::parse(request.body);
-
-    std::string type = payload.at("type");
-
-    //
-    // Important: updating node attributes is not a straightforward matter!
-    //
-    // Firstly, it can be done either as a child command or a user command.
-    //
-    // Secondly, for user commands, the current client framework does not cover all attribute operations:
-    //  * Some attributes can be added, changed and delete with ClientInvoker
-    //  * Some attributes can be either added, changed or deleted with ClientInvoker
-    //  * Some attributes cannot be modified in any way with ClientInvoker
-    //
-    // As we want the API to be consistent, we allow to modify all ecFlow attributes,
-    // whether the Client code supports it or not.
-    //
-
-    if (payload.contains("ECF_NAME")) {
-        return update_node_attribute_by_task(request);
-    }
-    else {
-        return update_node_attribute_by_user(request);
-    }
-}
-
-ojson delete_node_attribute(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-    const ojson payload    = ojson::parse(request.body);
-
-    const std::string type = payload.at("type");
-    auto client            = get_client(request);
-
-    if (type == "time" || type == "today" || type == "day" || type == "date" || type == "cron" || type == "late" ||
-        type == "complete") {
-        const std::string value = payload.at("value");
-        client->alter(path, "delete", type, value);
-    }
-    else if (type == "autocancel" || type == "autorestore" || type == "autoarchive") {
-        remove_attribute_from_path(type, request);
-    }
-    else {
-        const std::string name = payload.at("name");
-        client->alter(path, "delete", type, name);
-    }
-
-    return make_json_response(path, "Attribute deleted successfully");
-}
-
-ojson add_server_attribute(const httplib::Request& request) {
-    const ojson payload    = ojson::parse(request.body);
-    const std::string type = payload.at("type");
-
-    if (type != "variable") {
-        throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                  "Only variables can be added to server attributes");
-    }
-
-    const std::string name  = payload.at("name");
-    const std::string value = json_type_to_string(payload.at("value"));
-
-    auto client = get_client(request);
-    client->alter("/", "add", type, name, value);
-
-    return make_json_response("/", "Attribute added successfully");
-}
-
-ojson update_server_attribute(const httplib::Request& request) {
-    const ojson payload     = ojson::parse(request.body);
-    const std::string type  = payload.at("type");
-    const std::string name  = payload.at("name");
-    const std::string value = payload.at("value");
-
-    if (std::string x; !get_defs()->server().find_user_variable(name, x)) {
-        throw HttpServerException(HttpStatusCode::client_error_not_found, "User variable not found");
-    }
-    else if (type != "variable") {
-        throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                  "Only variables can be updated in server attributes");
-    }
-
-    auto client = get_client(request);
-    client->alter("/", "change", type, name, value);
-
-    return make_json_response("/", "Attribute changed successfully");
-}
-
-ojson delete_server_attribute(const httplib::Request& request) {
-
-    const ojson payload = ojson::parse(request.body);
-
-    const std::string type = payload.at("type");
-    const std::string name = payload.at("name");
-
-    if (std::string x; !get_defs()->server().find_user_variable(name, x)) {
-        throw HttpServerException(HttpStatusCode::client_error_not_found, "User variable not found");
-    }
-    else if (type != "variable") {
-        throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                  "Only variables can be removed from server attributes");
-    }
-
-    auto client = get_client(request);
-    client->alter("/", "delete", type, name);
-
-    return make_json_response("/", "Attribute deleted successfully");
-}
-
-namespace /* __anonymous__ */ {
-
-ojson update_node_status_by_task(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-    const ojson payload    = ojson::parse(request.body);
-    const std::string name = payload.at("action");
-
-    // this is a child command call
-    if (ecf::Child::valid_child_cmd(name) == false) {
-        throw HttpServerException(HttpStatusCode::client_error_bad_request,
-                                  "Invalid action for child command: " + name);
-    }
-
-    auto client = get_client_for_tasks(request, payload);
-
-    if (name == "init") {
-        client->child_init();
-    }
-    else if (name == "abort") {
-        client->child_abort(payload.value("abort_why", ""));
-    }
-    else if (name == "complete") {
-        client->child_complete();
-    }
-    else if (name == "wait") {
-        client->child_wait(payload.at("wait_expression"));
-    }
-    else {
-        throw HttpServerException(HttpStatusCode::server_error_not_implemented,
-                                  "Child action " + name + " not supported");
-    }
-
-    return make_json_response(path, "Status changed successfully");
-}
-
-ojson update_node_status_by_user(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-    const ojson payload    = ojson::parse(request.body);
-    const std::string name = payload.at("action");
-
-    auto client = get_client(request);
-
-    bool recursive = payload.value("recursive", false);
-    bool force     = payload.value("force", false);
-
-    if (name == "begin") {
-        client->begin(path);
-    }
-    else if (name == "resume") {
-        client->resume(path);
-    }
-    else if (name == "requeue") {
-        client->requeue(path);
-    }
-    else if (name == "suspend") {
-        client->suspend(path);
-    }
-    else if (name == "defstatus") {
-        client->alter(path, "change", name, payload.at("defstatus_value").get<std::string>());
-    }
-    else if (name == "execute") {
-        client->run(path, true);
-    }
-    else if (name == "archive") {
-        client->archive(path, force);
-    }
-    else if (name == "restore") {
-        client->restore(path);
-    }
-    else {
-        std::string name_ = name;
-        if (name_ == "abort") {
-            name_ = "aborted";
-        }
-        else if (name_ == "rerun") {
-            name_ = "queued";
-        }
-        else if (name_ == "execute") {
-            name_ = "run";
-        }
-        else if (name_ == "submit") {
-            name_ = "submitted";
-        }
-
-        client->force(path, name_, recursive);
-    }
-
-    return make_json_response(path, "Status changed successfully");
-}
-
-} // namespace
-
-ojson update_node_status(const httplib::Request& request) {
-    if (const ojson payload = ojson::parse(request.body); payload.contains("ECF_NAME")) {
-        return update_node_status_by_task(request);
-    }
-    else {
-        return update_node_status_by_user(request);
-    }
-}
-
-ojson update_script_content(const httplib::Request& request) {
-    const std::string path = request.matches[1];
-    const ojson payload    = ojson::parse(request.body);
-
-    const std::string script = payload.at("script");
-
-    std::vector<std::string> lines;
-    lines.reserve(20);
-    std::stringstream ss(script);
-
-    for (std::string line; std::getline(ss, line, '\n');) {
-        lines.push_back(line);
-    }
-
-    auto client = get_client(request);
-    client->edit_script_submit(path, {}, lines, false, false);
-
-    return make_json_response(path, "Script submitted successfully");
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/ApiV1Impl.hpp 5.13.0-1/Http/src/ecflow/http/ApiV1Impl.hpp
--- 5.12.4-1/Http/src/ecflow/http/ApiV1Impl.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/ApiV1Impl.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,50 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_ApiV1Impl_HPP
-#define ecflow_http_ApiV1Impl_HPP
-
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/http/HttpLibrary.hpp"
-#include "ecflow/http/JSON.hpp"
-
-namespace ecf::http {
-
-ojson get_basic_node_tree(const std::string& path);
-ojson get_full_node_tree(const std::string& path, bool with_id);
-ojson get_sparser_node_tree(const std::string& path);
-
-void add_suite(const httplib::Request& request, httplib::Response& response);
-
-ojson get_suites();
-
-ojson get_server_attributes();
-ojson add_server_attribute(const httplib::Request& request);
-ojson update_server_attribute(const httplib::Request& request);
-ojson delete_server_attribute(const httplib::Request& request);
-
-ojson get_node_definition(const std::string& path);
-ojson update_node_definition(const httplib::Request& request);
-
-ojson get_node_attributes(const std::string& path);
-ojson add_node_attribute(const httplib::Request& request);
-ojson update_node_attribute(const httplib::Request& request);
-ojson delete_node_attribute(const httplib::Request& request);
-
-ojson get_node_status(const httplib::Request& request);
-ojson update_node_status(const httplib::Request& request);
-
-ojson get_node_output(const httplib::Request& request);
-
-ojson update_script_content(const httplib::Request& request);
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_ApiV1Impl_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/Base64.hpp 5.13.0-1/Http/src/ecflow/http/Base64.hpp
--- 5.12.4-1/Http/src/ecflow/http/Base64.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/Base64.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,158 +0,0 @@
-/*
- * Base64 encoding/decoding (RFC1341)
- * Copyright (c) 2005-2011, Jouni Malinen <j@w1.fi>
- *
- * This software may be distributed under the terms of the BSD license.
- * Original license included below:
- *
- *
- *   License
- *   -------
- *   This software may be distributed, used, and modified under the terms of BSD license:
- *
- *   Redistribution and use in source and binary forms, with or without modification,
- *   are permitted provided that the following conditions are met:
- *
- *   1. Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *   2. Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in the
- *       documentation and/or other materials provided with the distribution.
- *
- *   3. Neither the name(s) of the above-listed copyright holder(s) nor the
- *       names of its contributors may be used to endorse or promote products
- *       derived from this software without specific prior written permission.
- *
- *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- *   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- *   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- *   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- *   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- *   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- *   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
-
-#ifndef ecflow_http_Base64_HPP
-#define ecflow_http_Base64_HPP
-
-#include <cstring>
-#include <regex>
-
-/**
- * base64_decode - Base64 decode
- * @src: Data to be decoded
- * @len: Length of the data to be decoded
- * @out_len: Pointer to output length variable
- * Returns: Allocated buffer of out_len bytes of decoded data,
- * or %NULL on failure
- *
- * Caller is responsible for freeing the returned buffer.
- */
-
-inline unsigned char* base64_decode(const unsigned char* src, size_t len, size_t* out_len) {
-
-    static const std::string base64_table = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
-
-    unsigned char dtable[256], *out, *pos, block[4], tmp;
-    size_t olen;
-    int pad = 0;
-
-    memset(dtable, 0x80, 256);
-    for (size_t i = 0; i < sizeof(base64_table) - 1; i++) {
-        dtable[base64_table[i]] = (unsigned char)i;
-    }
-    int assignment     = '=';
-    dtable[assignment] = 0;
-
-    size_t count = 0;
-    for (size_t i = 0; i < len; i++) {
-        if (dtable[src[i]] != 0x80) {
-            count++;
-        }
-    }
-
-    if (count == 0 || count % 4) {
-        return nullptr;
-    }
-
-    olen = count / 4 * 3;
-    pos = out = (unsigned char*)malloc(olen);
-    if (out == nullptr) {
-        return nullptr;
-    }
-
-    count = 0;
-    for (size_t i = 0; i < len; i++) {
-        tmp = dtable[src[i]];
-        if (tmp == 0x80) {
-            continue;
-        }
-
-        if (src[i] == '=') {
-            pad++;
-        }
-        block[count] = tmp;
-        count++;
-        if (count == 4) {
-            *pos++ = (block[0] << 2) | (block[1] >> 4);
-            *pos++ = (block[1] << 4) | (block[2] >> 2);
-            *pos++ = (block[2] << 6) | block[3];
-            count  = 0;
-            if (pad) {
-                if (pad == 1) {
-                    pos--;
-                }
-                else if (pad == 2) {
-                    pos -= 2;
-                }
-                else {
-                    /* Invalid padding */
-                    free(out);
-                    return nullptr;
-                }
-                break;
-            }
-        }
-    }
-
-    *out_len = pos - out;
-    return out;
-}
-
-/* Wrapper for std::string /partio */
-
-inline std::string base64_decode(const std::string& encoded) {
-    size_t len         = 0;
-    unsigned char* out = base64_decode(reinterpret_cast<const unsigned char*>(encoded.c_str()), encoded.size(), &len);
-    if (!out) {
-        throw std::runtime_error("Unable to decode base64");
-    }
-
-    std::string decoded(reinterpret_cast<char*>(out), len);
-    free(out);
-    return decoded;
-}
-
-/* Simple validation of base64 string.
- * - length has to be multiple of 4
- * - valid characters are  A-Za-z0-9+/
- * padding of 0-2 characters at the end of string can be =
- *
- * /partio
- */
-
-inline bool base64_validate(const std::string& encoded) {
-    if (encoded.size() % 4 != 0) {
-        return false;
-    }
-    static const std::regex pattern("^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{4}|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)$");
-
-    return std::regex_match(encoded, pattern);
-}
-
-#endif /* ecflow_http_Base64_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/BasicAuth.cpp 5.13.0-1/Http/src/ecflow/http/BasicAuth.cpp
--- 5.12.4-1/Http/src/ecflow/http/BasicAuth.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/BasicAuth.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/BasicAuth.hpp"
-
-#include "ecflow/core/PasswordEncryption.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/http/Base64.hpp"
-#include "ecflow/http/HttpServerException.hpp"
-
-namespace ecf::http {
-
-std::pair<std::string, std::string> BasicAuth::get_credentials(const std::string& token) {
-    const std::string decoded = base64_decode(token);
-    std::vector<std::string> elems;
-    ecf::Str::split(decoded, elems, ":");
-
-    return std::make_pair(elems[0], PasswordEncryption::encrypt(elems[1], elems[0]));
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/BasicAuth.hpp 5.13.0-1/Http/src/ecflow/http/BasicAuth.hpp
--- 5.12.4-1/Http/src/ecflow/http/BasicAuth.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/BasicAuth.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,25 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_BasicAuth_HPP
-#define ecflow_http_BasicAuth_HPP
-
-#include <string>
-
-namespace ecf::http {
-
-class BasicAuth {
-public:
-    static std::pair<std::string, std::string> get_credentials(const std::string& token);
-};
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_BasicAuth_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/Client.cpp 5.13.0-1/Http/src/ecflow/http/Client.cpp
--- 5.12.4-1/Http/src/ecflow/http/Client.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/Client.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,125 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/Client.hpp"
-
-#include <string>
-
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/http/BasicAuth.hpp"
-#include "ecflow/http/HttpServerException.hpp"
-#if defined(ECF_OPENSSL)
-    #include "ecflow/http/TokenStorage.hpp"
-#endif
-
-// For token based authentication, this user account
-// needs to have full access to server as it's acting
-// in lieu of the actual user
-
-namespace ecf::http {
-
-const char* const ECF_USER = getenv("ECF_USER");
-const char* const ECF_PASS = getenv("ECF_PASS");
-
-bool authenticate(const httplib::Request& request, ClientInvoker* ci) {
-
-    auto auth_with_token = [&](const std::string& token) {
-#ifdef ECF_OPENSSL
-        if (TokenStorage::instance().verify(token)) {
-            if (ECF_USER != nullptr && ECF_PASS != nullptr) {
-                ci->set_user_name(std::string(ECF_USER));
-                ci->set_password(std::string(ECF_PASS));
-            }
-            return true;
-        }
-#endif
-        return false;
-    };
-
-    const auto& header = request.headers;
-
-    // Authorization: Basic ..........
-    // Authorization: Bearer ..........
-
-    auto auth = header.find("Authorization");
-
-    if (auth != header.end()) {
-        std::vector<std::string> elems;
-        ecf::Str::split(auth->second, elems, " ");
-
-        if (elems[0] == "Basic") {
-            auto [username, password] = BasicAuth::get_credentials(elems[1]);
-            ci->set_user_name(username);
-            ci->set_password(password);
-            return true;
-        }
-        else if (elems[0] == "Bearer") {
-#ifndef ECF_OPENSSL
-            throw HttpServerException(HttpStatusCode::server_error_internal_server_error,
-                                      "Server compiled without SSL support");
-#else
-            return auth_with_token(elems[1]);
-#endif
-        }
-        return false;
-    }
-
-    // No standard authentication header set,
-    // try X-API-Key and/or queryparam
-
-    auth = header.find("X-API-Key");
-
-    if (auth != header.end()) {
-#ifndef ECF_OPENSSL
-        throw HttpServerException(HttpStatusCode::server_error_internal_server_error,
-                                  "Server compiled without SSL support");
-#else
-        return auth_with_token(auth->second);
-#endif
-    }
-
-    // allow token to be passed as a query parameter
-    if (const std::string token = request.get_param_value("key"); token.empty() == false) {
-#ifndef ECF_OPENSSL
-        throw HttpServerException(HttpStatusCode::server_error_internal_server_error,
-                                  "Server compiled without SSL support");
-#else
-        return auth_with_token(token);
-#endif
-    }
-
-    return false;
-}
-
-std::unique_ptr<ClientInvoker> get_client(const httplib::Request& request) {
-    auto ci = std::make_unique<ClientInvoker>();
-
-    if (request.method != "GET" && request.method != "OPTIONS" && request.method != "HEAD" &&
-        authenticate(request, ci.get()) == false) {
-        throw HttpServerException(HttpStatusCode::client_error_unauthorized, "Unauthorized");
-    }
-    return ci;
-}
-
-std::unique_ptr<ClientInvoker> get_client_for_tasks(const httplib::Request& request, const ojson& payload) {
-    auto ci = get_client(request);
-
-    ci->set_child_path(payload.at("ECF_NAME").get<std::string>());
-    ci->set_child_password(payload.at("ECF_PASS").get<std::string>());
-    ci->set_child_pid(json_type_to_string(payload.at("ECF_RID")));
-    ci->set_child_try_no(std::stoi(json_type_to_string(payload.at("ECF_TRYNO"))));
-    ci->set_child_timeout(payload.value("ECF_TIMEOUT", 86400));
-    ci->set_zombie_child_timeout(payload.value("ECF_ZOMBIE_TIMEOUT", 43200));
-
-    return ci;
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/Client.hpp 5.13.0-1/Http/src/ecflow/http/Client.hpp
--- 5.12.4-1/Http/src/ecflow/http/Client.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/Client.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_Client_HPP
-#define ecflow_http_Client_HPP
-
-#include <memory>
-
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/http/HttpLibrary.hpp"
-#include "ecflow/http/JSON.hpp"
-
-namespace ecf::http {
-
-std::unique_ptr<ClientInvoker> get_client(const httplib::Request& request);
-
-std::unique_ptr<ClientInvoker> get_client_for_tasks(const httplib::Request& request, const ojson& payload);
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_Client_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/DefsStorage.cpp 5.13.0-1/Http/src/ecflow/http/DefsStorage.cpp
--- 5.12.4-1/Http/src/ecflow/http/DefsStorage.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/DefsStorage.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,175 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <condition_variable>
-#include <mutex>
-#include <optional>
-#include <string>
-#include <thread>
-
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/http/Options.hpp"
-#include "ecflow/node/Defs.hpp"
-
-namespace ecf::http {
-
-extern std::atomic<unsigned int> last_request_time;
-
-std::shared_ptr<Defs> defs_ = nullptr;
-
-static std::mutex def_mutex;
-static std::mutex cv_mutex;
-static std::condition_variable defs_cv;
-std::atomic update_defs(true);
-
-namespace /* __anonymous__ */ {
-
-void print_polling_interval_notification(long long sleeptime,
-                                         long long base_sleeptime,
-                                         long long drift,
-                                         long long max_sleeptime) {
-    printf("Polling interval is now %lld (base: %lld drift: %lld max: %lld)\n",
-           sleeptime,
-           base_sleeptime,
-           drift,
-           max_sleeptime);
-}
-
-} // namespace
-
-std::shared_ptr<Defs> get_defs() {
-    std::lock_guard lock(def_mutex);
-    return defs_;
-}
-
-namespace /* __anonymous__ */ {
-
-[[noreturn]] void defs_update(int interval) {
-    ClientInvoker client;
-
-    auto get_current_time = [] {
-        struct timeval curtime;
-        gettimeofday(&curtime, nullptr);
-        return static_cast<unsigned int>(curtime.tv_sec);
-    };
-
-    auto update = [&] {
-        {
-            std::lock_guard lock(def_mutex);
-            if (defs_ != nullptr) {
-                client.sync(defs_);
-            }
-            defs_ = client.defs();
-        }
-        if (opts.verbose) {
-            printf(
-                "Defs modify_change_no: %d state_change_no: %d\n", defs_->modify_change_no(), defs_->state_change_no());
-        }
-    };
-
-    // These will throw is ecflow server is not present; we will not
-    // try to reconnect if there wasn't a connection to begin with
-    client.news_local();
-    client.sync_local();
-
-    // Implement a drift to update cycle. The basic idea is that if we
-    // don't get requests to the interface, we slowly start to increase
-    // the interval which we use to poll ecFlow server. This is done to
-    // reduce ecFlow server load when there is no activity on the REST
-    // API.
-    // For every minute that goes by without any activity on the REST API,
-    // we increase the drift by one second. The maximum drift value is
-    // 10 * polling interval, but minimum 30 seconds. Activity on the API
-    // will reset drift to zero.
-
-    const std::chrono::seconds base_sleeptime(interval);
-    std::chrono::seconds sleeptime(interval);
-    const std::chrono::seconds max_sleeptime(std::max(30, opts.max_polling_interval));
-    std::chrono::seconds previous_sleeptime(interval);
-
-    for (;;) {
-        try {
-            while (true) {
-                std::unique_lock lock(cv_mutex);
-                if (defs_cv.wait_for(lock, sleeptime, [] { return update_defs.load(); })) {
-                    // update requested by some other thread
-                    if (opts.verbose) {
-                        printf("defs update requested\n");
-                    }
-                    update();
-                    update_defs = false;
-                }
-                else {
-                    // update triggered by timeout
-                    client.news(defs_);
-                    if (client.get_news()) {
-                        update();
-                        update_defs = false;
-                    }
-                }
-
-                if (opts.max_polling_interval <= opts.polling_interval) {
-                    // drift disabled
-                    continue;
-                }
-                const auto last_request_age = static_cast<double>(get_current_time() - last_request_time.load());
-                const auto drift            = std::chrono::seconds(static_cast<int>(floor(last_request_age / 60.)));
-
-                sleeptime = min(max_sleeptime, base_sleeptime + drift);
-                if (opts.verbose && sleeptime != previous_sleeptime) {
-                    print_polling_interval_notification(
-                        sleeptime.count(), base_sleeptime.count(), drift.count(), max_sleeptime.count());
-                }
-
-                previous_sleeptime = sleeptime;
-            }
-        }
-        catch (const std::exception& e) {
-            printf("ERROR: Communication problem with ecflow server? Retrying in 5s\n");
-            std::this_thread::sleep_for(std::chrono::seconds(5));
-        }
-    }
-}
-
-} // namespace
-
-void update_defs_loop(int interval) {
-    std::thread t(defs_update, interval);
-    t.detach();
-
-    while (update_defs.load() == true) {
-        std::this_thread::sleep_for(std::chrono::milliseconds(50));
-    }
-}
-
-template <typename T>
-void trigger_defs_update_predicate(T&& func) {
-    {
-        std::lock_guard lock(cv_mutex);
-        update_defs = true;
-        defs_cv.notify_one();
-    }
-
-    while (update_defs.load() == true) {
-        std::this_thread::sleep_for(std::chrono::milliseconds(20));
-    }
-
-    func();
-}
-
-void trigger_defs_update() {
-    trigger_defs_update_predicate([] { /* No OP */ });
-}
-
-void trigger_defs_update(std::function<void()> function) {
-    trigger_defs_update_predicate(function);
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/DefsStorage.hpp 5.13.0-1/Http/src/ecflow/http/DefsStorage.hpp
--- 5.12.4-1/Http/src/ecflow/http/DefsStorage.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/DefsStorage.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_DefsStorage_HPP
-#define ecflow_http_DefsStorage_HPP
-
-#include <functional>
-
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/http/JSON.hpp"
-
-namespace ecf::http {
-
-std::shared_ptr<Defs> get_defs();
-
-void update_defs_loop(int interval);
-
-void trigger_defs_update();
-void trigger_defs_update(std::function<void()> function);
-
-} // namespace ecf::http
-
-#endif /* DefsStorage */
diff -pruN 5.12.4-1/Http/src/ecflow/http/HttpLibrary.hpp 5.13.0-1/Http/src/ecflow/http/HttpLibrary.hpp
--- 5.12.4-1/Http/src/ecflow/http/HttpLibrary.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/HttpLibrary.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,35 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_HttpLibrary_HPP
-#define ecflow_http_HttpLibrary_HPP
-
-#include <sys/socket.h>
-#if defined(MSG_NOSIGNAL)
-    // The MSG_NOSIGNAL flag should be defined by <sys/socket.h>
-    // (as per POSIX: https://pubs.opengroup.org/onlinepubs/9699919799.2018edition/functions/send.html),
-    // but that is not always the case for OSX.
-    //
-    // If MSG_NOSIGNAL is not defined, we leave it up to httplib to use default flags.
-    //
-    #define CPPHTTPLIB_SEND_FLAGS MSG_NOSIGNAL
-    #define CPPHTTPLIB_RECV_FLAGS MSG_NOSIGNAL
-#endif
-
-#ifdef ECF_OPENSSL
-    #define CPPHTTPLIB_OPENSSL_SUPPORT
-#endif
-#ifdef ECF_HTTP_COMPRESSION
-    #define CPPHTTPLIB_ZLIB_SUPPORT
-#endif
-
-#include <httplib.h>
-
-#endif /* ecflow_http_HttpLibrary_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/HttpMain.cpp 5.13.0-1/Http/src/ecflow/http/HttpMain.cpp
--- 5.12.4-1/Http/src/ecflow/http/HttpMain.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/HttpMain.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <csignal>
-#include <cstring>
-#include <iostream>
-
-#include "ecflow/http/HttpServer.hpp"
-
-using ecf::http::HttpServer;
-
-int main(int argc, char* argv[]) {
-    // Sometimes we get SIGPIPE through openssl, when server is trying
-    // to write to a socket which client has already closed.
-    // Ignore this signal.
-    sigset_t set;
-    sigemptyset(&set);
-    sigaddset(&set, SIGPIPE);
-
-    if (pthread_sigmask(SIG_BLOCK, &set, nullptr) != 0) {
-        throw std::runtime_error("Failed to set signal mask");
-    }
-
-    try {
-        HttpServer server(argc, argv);
-        server.run();
-    }
-    catch (std::exception& e) {
-        std::cerr << e.what() << std::endl;
-        return 1;
-    }
-    return 0;
-}
diff -pruN 5.12.4-1/Http/src/ecflow/http/HttpServer.cpp 5.13.0-1/Http/src/ecflow/http/HttpServer.cpp
--- 5.12.4-1/Http/src/ecflow/http/HttpServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/HttpServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,261 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/HttpServer.hpp"
-
-#include <boost/program_options.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/http/Api.hpp"
-#include "ecflow/http/JSON.hpp"
-#include "ecflow/http/Options.hpp"
-
-namespace ecf::http {
-
-HttpServer::HttpServer(int argc, char** argv) {
-    parse_args(argc, argv);
-}
-
-void read_environment() {
-    if (getenv("ECF_RESTAPI_VERBOSE") != nullptr) {
-        opts.verbose = true;
-    }
-    if (getenv("ECF_RESTAPI_NOSSL") != nullptr) {
-        opts.no_ssl = true;
-    }
-    if (getenv("ECF_RESTAPI_POLLING_INTERVAL") != nullptr) {
-        opts.polling_interval = atoi(getenv("ECF_RESTAPI_POLLING_INTERVAL"));
-    }
-    if (getenv("ECF_RESTAPI_PORT") != nullptr) {
-        opts.port = atoi(getenv("ECF_RESTAPI_PORT"));
-    }
-    if (getenv("ECF_HOST") != nullptr) {
-        opts.ecflow_host = std::string(getenv("ECF_HOST"));
-    }
-    if (getenv("ECF_PORT") != nullptr) {
-        opts.ecflow_port = atoi(getenv("ECF_PORT"));
-    }
-    if (getenv("ECF_RESTAPI_TOKENS_FILE") != nullptr) {
-        opts.tokens_file = std::string(getenv("ECF_RESTAPI_TOKENS_FILE"));
-    }
-    if (getenv("ECF_RESTAPI_CERT_DIRECTORY") != nullptr) {
-        opts.cert_directory = std::string(getenv("ECF_RESTAPI_CERT_DIRECTORY"));
-    }
-    if (getenv("ECF_RESTAPI_MAX_UPDATE_INTERVAL") != nullptr) {
-        opts.max_polling_interval = atoi(getenv("ECF_RESTAPI_MAX_UPDATE_INTERVAL"));
-    }
-}
-
-void HttpServer::parse_args(int argc, char** argv) const {
-
-    // TODO[MB]: This essentially creates an Options object, thus makes more sense that move ability to Options.hpp
-
-    namespace po = boost::program_options;
-
-    po::options_description desc("Allowed options", 100);
-
-    read_environment();
-
-    // clang-format off
-
-   bool verbose = false;
-   bool no_ssl = false;
-
-   desc.add_options()
-       ("cert_directory", po::value(&opts.cert_directory), "directory where certificates are found (default: $HOME/.ecflowrc/ssl)")
-       ("ecflow_host", po::value(&opts.ecflow_host), "hostname of ecflow server (default: localhost)")
-       ("ecflow_port", po::value(&opts.ecflow_port), "port of ecflow server (default: 3141)")
-       ("help,h", "print help message")
-       ("max_polling_interval", po::value(&opts.max_polling_interval), "maximum polling interval in seconds, set to 0 to disable drift (default: 300)")
-       ("no_ssl", po::bool_switch(&no_ssl), "disable ssl (default: false)")
-       ("port,p", po::value(&opts.port), "port to listen (default: 8080)")
-       ("polling_interval", po::value(&opts.polling_interval), "interval in seconds to poll ecflow server for updates (default: 10)")
-       ("tokens_file", po::value(&opts.tokens_file), "location of api tokens file (default: api-tokens.json)")
-       ("verbose,v", po::bool_switch(&verbose), "enable verbose mode");
-
-    // clang-format on
-
-    po::variables_map opt;
-    po::store(po::command_line_parser(argc, argv).options(desc).run(), opt);
-    po::notify(opt);
-
-    if (opt.count("help")) {
-        std::cout << desc << std::endl;
-        exit(1);
-    }
-    if (verbose) {
-        opts.verbose = true;
-    }
-    if (no_ssl) {
-        opts.no_ssl = true;
-    }
-
-    setenv("ECF_HOST", opts.ecflow_host.c_str(), 1);
-    setenv("ECF_PORT", ecf::convert_to<std::string>(opts.ecflow_port).c_str(), 1);
-    // Unset these, otherwise ClientInvoker will automatically
-    // try to use them
-    unsetenv("ECF_PASSWD");
-    unsetenv("ECF_CUSTOM_PASSWD");
-}
-
-void apply_listeners(httplib::Server& http_server) {
-
-    // TODO[MB]: Needs to be further refactored
-
-    const auto dump_headers = [](const httplib::Headers& headers, std::stringstream& ss) {
-        for (const auto& [key, value] : headers) {
-            ss << key << ": " << value << "\n";
-        }
-    };
-
-    const auto format = [&dump_headers](const httplib::Request& req, const httplib::Response& res) {
-        std::stringstream ss;
-
-        ss << '\n';
-
-        ss << "*** REQUEST ***\n";
-        ss << req.method << " " << req.version << " " << req.path;
-        char sep = '?';
-        for (const auto& [parameter, value] : req.params) {
-            ss << sep << parameter << "=" << value;
-            sep = '&';
-        }
-        ss << '\n';
-
-        ss << "-=- header(s):\n";
-        dump_headers(req.headers, ss);
-
-        if (!req.body.empty()) {
-            ss << "-=- body:\n";
-            ss << req.body << "\n";
-        }
-
-        ss << '\n';
-        ss << "*** RESPONSE ***\n";
-        ss << res.status << " " << res.version << "\n";
-
-        ss << "-=- header(s):\n";
-        dump_headers(res.headers, ss);
-
-        if (!res.body.empty()) {
-            ss << "-=- body:\n";
-            ss << res.body << "\n";
-        }
-
-        return ss.str();
-    };
-
-    http_server.set_exception_handler([](const httplib::Request& req, httplib::Response& res, std::exception_ptr ep) {
-        try {
-            std::rethrow_exception(ep);
-        }
-        catch (const std::exception& e) {
-            if (opts.verbose) {
-                printf("Exception: Error 500: %s\n", e.what());
-            }
-            ojson j;
-            j["status"]  = res.status;
-            j["message"] = e.what();
-            j["path"]    = req.path;
-            j["method"]  = req.method;
-            if (req.body.empty() == false) {
-                j["body"] = req.body;
-            }
-            res.set_content(j.dump(), "application/json");
-        }
-        catch (...) {
-            if (opts.verbose) {
-                printf("Unknown exception occurred\n");
-            }
-        }
-    });
-
-    http_server.set_error_handler([](const httplib::Request& req, httplib::Response& res) {
-        if (opts.verbose) {
-            printf("error_handler called: Error: %d\n", res.status);
-        }
-
-        // Usually no need to modify response fields -- they should be configured now, as
-        // error handler is called *after* httplib finds out that status is >= 400
-        //
-        // Exception is when errorhandler is called so that it doesn't go through the
-        // registered endpoints
-
-        if (res.body.empty()) {
-            ojson j;
-            j["path"]   = req.path;
-            j["status"] = res.status;
-            res.set_content(j.dump(), "application/json");
-        }
-    });
-
-    http_server.set_logger([&format](const httplib::Request& req, const httplib::Response& res) {
-        const std::string str = format(req, res);
-        // using std::cout crashes with many threads calling
-        if (opts.verbose) {
-            printf("%s\n", str.c_str());
-        }
-    });
-}
-
-void start_server(httplib::Server& http_server) {
-    if (opts.verbose) {
-        printf("ecFlow server location is %s:%d\n", opts.ecflow_host.c_str(), opts.ecflow_port);
-    }
-
-    setup(http_server);
-
-    const std::string proto = (opts.no_ssl ? "http" : "https");
-
-    if (opts.verbose) {
-        printf("%s server listening on port %d\n", proto.c_str(), opts.port);
-    }
-
-    try {
-        bool ret = http_server.listen("0.0.0.0", opts.port);
-        if (ret == false) {
-            throw std::runtime_error("Failed to bind to port " + ecf::convert_to<std::string>(opts.port));
-        }
-    }
-    catch (const std::exception& e) {
-        if (opts.verbose) {
-            printf("Server execution stopped: %s\n", e.what());
-        }
-    }
-}
-
-void HttpServer::run() const {
-#ifdef ECF_OPENSSL
-    if (opts.no_ssl == false) {
-        if (fs::exists(opts.cert_directory + "/server.crt") == false ||
-            fs::exists(opts.cert_directory + "/server.key") == false) {
-            throw std::runtime_error("Directory " + opts.cert_directory +
-                                     " does not contain server.crt and/or server.key");
-        }
-
-        const std::string cert = opts.cert_directory + "/server.crt";
-        const std::string key  = opts.cert_directory + "/server.key";
-
-        httplib::SSLServer http_server(cert.c_str(), key.c_str());
-        apply_listeners(dynamic_cast<httplib::Server&>(http_server));
-        start_server(http_server);
-    }
-    else
-#endif
-    {
-        httplib::Server http_server;
-
-        apply_listeners(http_server);
-        start_server(http_server);
-    }
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/HttpServer.hpp 5.13.0-1/Http/src/ecflow/http/HttpServer.hpp
--- 5.12.4-1/Http/src/ecflow/http/HttpServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/HttpServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_HttpServer_HPP
-#define ecflow_http_HttpServer_HPP
-
-namespace ecf::http {
-
-class HttpServer {
-public:
-    HttpServer(int argc, char** argv);
-    void run() const;
-    ~HttpServer() = default;
-
-private:
-    void parse_args(int argc, char** argv) const;
-};
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_HttpServer_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/HttpServerException.hpp 5.13.0-1/Http/src/ecflow/http/HttpServerException.hpp
--- 5.12.4-1/Http/src/ecflow/http/HttpServerException.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/HttpServerException.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_HttpServerException_HPP
-#define ecflow_http_HttpServerException_HPP
-
-#include <exception>
-#include <string>
-
-namespace ecf::http {
-
-enum HttpStatusCode {
-    unknown              = 0,
-    information_continue = 100,
-    information_switching_protocols,
-    information_processing,
-    success_ok = 200,
-    success_created,
-    success_accepted,
-    success_non_authoritative_information,
-    success_no_content,
-    success_reset_content,
-    success_partial_content,
-    success_multi_status,
-    success_already_reported,
-    success_im_used              = 226,
-    redirection_multiple_choices = 300,
-    redirection_moved_permanently,
-    redirection_found,
-    redirection_see_other,
-    redirection_not_modified,
-    redirection_use_proxy,
-    redirection_switch_proxy,
-    redirection_temporary_redirect,
-    redirection_permanent_redirect,
-    client_error_bad_request = 400,
-    client_error_unauthorized,
-    client_error_payment_required,
-    client_error_forbidden,
-    client_error_not_found,
-    client_error_method_not_allowed,
-    client_error_not_acceptable,
-    client_error_proxy_authentication_required,
-    client_error_request_timeout,
-    client_error_conflict,
-    client_error_gone,
-    client_error_length_required,
-    client_error_precondition_failed,
-    client_error_payload_too_large,
-    client_error_uri_too_long,
-    client_error_unsupported_media_type,
-    client_error_range_not_satisfiable,
-    client_error_expectation_failed,
-    client_error_im_a_teapot,
-    client_error_misdirection_required = 421,
-    client_error_unprocessable_entity,
-    client_error_locked,
-    client_error_failed_dependency,
-    client_error_upgrade_required      = 426,
-    client_error_precondition_required = 428,
-    client_error_too_many_requests,
-    client_error_request_header_fields_too_large = 431,
-    client_error_unavailable_for_legal_reasons   = 451,
-    server_error_internal_server_error           = 500,
-    server_error_not_implemented,
-    server_error_bad_gateway,
-    server_error_service_unavailable,
-    server_error_gateway_timeout,
-    server_error_http_version_not_supported,
-    server_error_variant_also_negotiates,
-    server_error_insufficient_storage,
-    server_error_loop_detected,
-    server_error_not_extended = 510,
-    server_error_network_authentication_required
-};
-
-class HttpServerException : public std::exception {
-public:
-    HttpServerException() = delete;
-    HttpServerException(HttpStatusCode code, const std::string& msg) : code_(code), msg_(msg) {}
-
-    const char* what() const noexcept override { return msg_.c_str(); }
-    HttpStatusCode code() const { return code_; }
-
-private:
-    HttpStatusCode code_;
-    std::string msg_;
-};
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_HttpServerException_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/JSON.cpp 5.13.0-1/Http/src/ecflow/http/JSON.cpp
--- 5.12.4-1/Http/src/ecflow/http/JSON.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/JSON.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,43 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/JSON.hpp"
-
-#include "ecflow/core/Converter.hpp"
-
-namespace ecf::http {
-
-std::string json_type_to_string(const ojson& j) {
-    switch (j.type()) {
-        case ojson::value_t::null:
-            return "null";
-        case ojson::value_t::boolean:
-            return (j.get<bool>()) ? "true" : "false";
-        case ojson::value_t::string:
-            return j.get<std::string>();
-        case ojson::value_t::binary:
-            return j.dump();
-        case ojson::value_t::array:
-        case ojson::value_t::object:
-            return j.dump();
-        case ojson::value_t::discarded:
-            return "discarded";
-        case ojson::value_t::number_integer:
-            return ecf::convert_to<std::string>(j.get<int>());
-        case ojson::value_t::number_unsigned:
-            return ecf::convert_to<std::string>(j.get<unsigned int>());
-        case ojson::value_t::number_float:
-            return ecf::convert_to<std::string>(j.get<double>());
-        default:
-            return std::string();
-    }
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/JSON.hpp 5.13.0-1/Http/src/ecflow/http/JSON.hpp
--- 5.12.4-1/Http/src/ecflow/http/JSON.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/JSON.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_JSON_HPP
-#define ecflow_http_JSON_HPP
-
-#include "nlohmann/json.hpp"
-
-namespace ecf::http {
-
-using ojson = nlohmann::ordered_json;
-
-std::string json_type_to_string(const ojson& j);
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_JSON_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/Options.cpp 5.13.0-1/Http/src/ecflow/http/Options.cpp
--- 5.12.4-1/Http/src/ecflow/http/Options.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/Options.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/Options.hpp"
-
-namespace ecf::http {
-
-Options opts = {};
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/Options.hpp 5.13.0-1/Http/src/ecflow/http/Options.hpp
--- 5.12.4-1/Http/src/ecflow/http/Options.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/Options.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,35 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_Options_HPP
-#define ecflow_http_Options_HPP
-
-#include <string>
-
-namespace ecf::http {
-
-struct Options
-{
-    bool verbose{false};                                                        // ECF_RESTAPI_VERBOSE
-    bool no_ssl{false};                                                         // ECF_RESTAPI_NOSSL
-    int polling_interval{10};                                                   // ECF_RESTAPI_POLLING_INTERVAL
-    int port{8080};                                                             // ECF_RESTAPI_PORT
-    std::string ecflow_host{"localhost"};                                       // ECF_HOST
-    int ecflow_port{3141};                                                      // ECF_PORT
-    std::string tokens_file{"api-tokens.json"};                                 // ECF_RESTAPI_TOKENS_FILE
-    std::string cert_directory{std::string(getenv("HOME")) + "/.ecflowrc/ssl"}; // ECF_RESTAPI_CERT_DIRECTORY
-    int max_polling_interval{300};                                              // ECF_RESTAPI_MAX_POLLING_INTERVAL
-};
-
-extern Options opts;
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_Options_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/TokenStorage.cpp 5.13.0-1/Http/src/ecflow/http/TokenStorage.cpp
--- 5.12.4-1/Http/src/ecflow/http/TokenStorage.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/TokenStorage.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,238 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/TokenStorage.hpp"
-
-#include <atomic> // shared mutex only with c++14
-#include <fstream>
-#include <iomanip>
-#include <shared_mutex>
-#include <sstream>
-#include <thread>
-
-#include <openssl/evp.h>
-#include <openssl/hmac.h>
-#include <openssl/sha.h>
-
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/http/HttpServerException.hpp"
-#include "ecflow/http/JSON.hpp"
-#include "ecflow/http/Options.hpp"
-
-namespace ecf::http {
-
-std::shared_mutex m;
-
-std::atomic initialized = false;
-
-namespace {
-
-std::string hmac_sha256(const std::string& salt, const std::string& token) {
-    unsigned char hash[EVP_MAX_MD_SIZE];
-    unsigned int hash_len;
-
-    HMAC(EVP_sha256(),
-         salt.c_str(),
-         static_cast<int>(salt.size()),
-         reinterpret_cast<const unsigned char*>(token.c_str()),
-         token.size(),
-         hash,
-         &hash_len);
-    std::stringstream ss;
-    for (unsigned int i = 0; i < hash_len; i++) {
-        ss << std::hex << std::setw(2) << std::setfill('0') << static_cast<int>(hash[i]);
-    }
-    return ss.str();
-}
-
-std::string hmac_pbkdf2_sha256(const std::string& salt, const std::string& token, int num_iterations) {
-    unsigned char hash[SHA256_DIGEST_LENGTH];
-
-    PKCS5_PBKDF2_HMAC(token.c_str(),
-                      static_cast<int>(token.size()),
-                      reinterpret_cast<const unsigned char*>(salt.c_str()),
-                      static_cast<int>(salt.size()),
-                      num_iterations,
-                      EVP_sha256(),
-                      SHA256_DIGEST_LENGTH,
-                      hash);
-    std::stringstream ss;
-    for (int i = 0; i < SHA256_DIGEST_LENGTH; i++) {
-        ss << std::hex << std::setw(2) << std::setfill('0') << static_cast<int>(hash[i]);
-    }
-    return ss.str();
-}
-
-std::string hash(const std::string& method, const std::string& salt, const std::string& token) {
-    /*
-     * Hash a token with correct HMAC.
-     * Current options are:
-     * - sha256
-     * - pbkdf2:sha256
-     */
-
-    if (method == "sha256") {
-        return hmac_sha256(salt, token);
-    }
-    else if (method.find("pbkdf2:sha256") != std::string::npos) {
-        int num_iterations = 260000;
-
-        try {
-            num_iterations = std::stoi(method.substr(method.find(":", 8) + 1, std::string::npos));
-        }
-        catch (const std::exception& e) {
-            printf("ERROR: method %s has invalid number of iterations: %s\n", method.c_str(), e.what());
-        }
-        return hmac_pbkdf2_sha256(salt, token, num_iterations);
-    }
-
-    throw HttpServerException(HttpStatusCode::server_error_internal_server_error, "Unsupported HMAC: " + method);
-}
-
-bool is_supported_hmac(std::string_view method) {
-    if (method == "sha256" || method.find("pbkdf2:sha256") != std::string::npos) {
-        return true;
-    }
-    return false;
-}
-
-std::chrono::system_clock::time_point time_point_from_isostring(const std::string& str) {
-    if (str.empty()) {
-        return std::chrono::system_clock::time_point{};
-    }
-
-    std::tm tm = {};
-    strptime(str.c_str(), "%Y-%m-%dT%H:%M:%SZ", &tm);
-    return std::chrono::system_clock::from_time_t(std::mktime(&tm));
-}
-
-} // namespace
-
-TokenStorage::TokenStorage() {
-    std::thread t(&TokenStorage::ReadStorage, this);
-    t.detach();
-
-    while (initialized.load() == false) {
-        std::this_thread::sleep_for(std::chrono::milliseconds(10));
-    }
-}
-
-bool TokenStorage::verify(const std::string& token) const {
-    const auto now = std::chrono::system_clock::now();
-
-    // Take a (weak) reader lock; the background thread updating
-    // tokens from file can block us but other readers cannot
-
-    std::shared_lock lock(m);
-    for (const auto& t : tokens_) {
-        const std::string hashed = hash(t.method, t.salt, token);
-        if (hashed == t.hash && (t.expires.time_since_epoch().count() == 0 || t.expires > now) &&
-            (t.revoked.time_since_epoch().count() == 0 || t.revoked > now)) {
-            if (opts.verbose) {
-                printf("Token for '%s' authenticated successfully\n", t.description.c_str());
-            }
-            return true;
-        }
-    }
-    return false;
-}
-
-std::vector<Token> ReadTokens(const std::string& filename) {
-    std::ifstream ifs(filename);
-    auto j = ojson::parse(ifs);
-    std::vector<Token> new_tokens;
-
-    /* Read a token from json file.
-     * Format is:
-     * [
-     * {
-     *    "hash" : "...",        # hashed and salted token, format is identical to python
-                                 # library 'werkzeug': METHOD$SALT$HASH
-          "description" : "...", # free-form description of token (application)
-          "expires_at" : NUM,    # unix epoch time when this token will expire
-                                 # OPTIONAL: if missing or zero, no expiration time is set
-          "revoked_at" : NUM     # unix epoch time when this token was revoked
-                                 # OPTIONAL: if missing or zero, no revoke time is set
-     * }
-     * ]
-     */
-
-    for (const auto& o : j) {
-        try {
-            std::chrono::system_clock::time_point expires_at; // optional
-            std::chrono::system_clock::time_point revoked_at; // optional
-
-            if (o.contains("expires_at")) {
-                expires_at = time_point_from_isostring(o.at("expires_at").get<std::string>());
-            }
-
-            if (o.contains("revoked_at")) {
-                revoked_at = time_point_from_isostring(o.at("revoked_at").get<std::string>());
-            }
-
-            const std::string& hash = o.at("hash").get<std::string>();
-
-            std::vector<std::string> elems;
-            ecf::Str::split(hash, elems, "$");
-
-            if (elems.size() != 3) {
-                throw std::invalid_argument("Invalid hash format: " + hash);
-            }
-            if (is_supported_hmac(elems[0]) == false) {
-                throw std::invalid_argument("Unsupported HMAC: " + elems[0]);
-            }
-
-            new_tokens.emplace_back(
-                elems[2], elems[1], elems[0], o.at("description").get<std::string>(), expires_at, revoked_at);
-        }
-        catch (const std::exception& e) {
-            printf("Invalid token: %s: %s\n", o.dump().c_str(), e.what());
-        }
-    }
-    if (opts.verbose) {
-        printf("Read %ld tokens\n", new_tokens.size());
-    }
-
-    return new_tokens;
-}
-
-void TokenStorage::ReadStorage() {
-    const std::chrono::seconds sleep_time(20);
-    std::chrono::system_clock::time_point last_modified;
-
-    // Scan periodically the api-token file and read the
-    // contents automatically if they are updated
-
-    while (true) {
-        try {
-            auto current_modified =
-                std::chrono::system_clock::from_time_t(fs::last_write_time(fs::path(opts.tokens_file)));
-            if (current_modified > last_modified) {
-                auto new_tokens = ReadTokens(opts.tokens_file);
-                {
-                    std::lock_guard lock(m);
-                    tokens_ = new_tokens;
-                }
-                last_modified = current_modified;
-            }
-        }
-        catch (const fs::filesystem_error& e) {
-            printf("ERROR: API token file (%s) read failed: %s\n", opts.tokens_file.c_str(), e.what());
-        }
-        catch (const ojson::exception& e) {
-            printf("ERROR: API token file (%s) parse failed: %s\n", opts.tokens_file.c_str(), e.what());
-        }
-        initialized = true;
-        std::this_thread::sleep_for(sleep_time);
-    }
-}
-
-} // namespace ecf::http
diff -pruN 5.12.4-1/Http/src/ecflow/http/TokenStorage.hpp 5.13.0-1/Http/src/ecflow/http/TokenStorage.hpp
--- 5.12.4-1/Http/src/ecflow/http/TokenStorage.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/TokenStorage.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_TokenStorage_HPP
-#define ecflow_http_TokenStorage_HPP
-
-#include <chrono>
-#include <string>
-#include <vector>
-
-namespace ecf::http {
-
-struct Token
-{
-    std::string hash;
-    std::string salt;
-    std::string method;
-    std::string description;
-    std::chrono::system_clock::time_point expires;
-    std::chrono::system_clock::time_point revoked;
-
-    Token(const std::string& hash_,
-          const std::string& salt_,
-          const std::string& method_,
-          const std::string& description_,
-          const std::chrono::system_clock::time_point& expires_,
-          const std::chrono::system_clock::time_point& revoked_)
-        : hash(hash_),
-          salt(salt_),
-          method(method_),
-          description(description_),
-          expires(expires_),
-          revoked(revoked_) {}
-};
-
-class TokenStorage {
-public:
-    static const TokenStorage& instance() {
-        static TokenStorage instance_;
-        return instance_;
-    }
-    TokenStorage(const TokenStorage&)            = delete;
-    TokenStorage(TokenStorage&&)                 = delete;
-    TokenStorage& operator=(const TokenStorage&) = delete;
-    TokenStorage& operator=(TokenStorage&&)      = delete;
-
-    bool verify(const std::string& token) const;
-
-private:
-    TokenStorage();
-    ~TokenStorage() = default;
-    void ReadStorage();
-
-    std::vector<Token> tokens_;
-};
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_TokenStorage_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/TreeGeneration.hpp 5.13.0-1/Http/src/ecflow/http/TreeGeneration.hpp
--- 5.12.4-1/Http/src/ecflow/http/TreeGeneration.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/TreeGeneration.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,252 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_TreeGeneration_HPP
-#define ecflow_http_TreeGeneration_HPP
-
-#include <vector>
-
-#include "ecflow/http/JSON.hpp"
-#include "ecflow/http/TypeToJson.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-namespace ecf::http {
-
-struct BasicTree
-{
-    BasicTree() : root_(ojson::object({})), stack_{&root_} {}
-
-    void begin_visit(const Suite& suite) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[suite.name()] = ojson::object({});
-        stack_.push_back(&current);
-    }
-    void end_visit(const Suite& suite [[maybe_unused]]) { stack_.pop_back(); }
-
-    void begin_visit(const Family& family) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[family.name()] = ojson::object({});
-        stack_.push_back(&current);
-    }
-    void end_visit(const Family& family [[maybe_unused]]) { stack_.pop_back(); }
-
-    void begin_visit(const Task& task) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[task.name()] = ojson::object({});
-        stack_.push_back(&current);
-    }
-    void end_visit(const Task& task [[maybe_unused]]) { stack_.pop_back(); }
-
-    void begin_visit(const Alias& alias) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[alias.name()] = ojson::object({});
-        stack_.push_back(&current);
-    }
-    void end_visit(const Alias& alias [[maybe_unused]]) { stack_.pop_back(); }
-
-    const ojson& content() const { return root_; }
-
-private:
-    ojson root_;
-    std::vector<ojson*> stack_;
-};
-
-struct FullTree
-{
-    FullTree(bool with_id) : root_(ojson::object({})), stack_{&root_}, with_id_{with_id} {}
-
-    void begin_visit(const Suite& suite) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[suite.name()] = ojson::object({});
-
-        current["type"] = "suite";
-        if (with_id_) {
-            current["id"] = suite.absNodePath();
-        }
-        publish_state(suite, current);
-        publish_attributes(suite, current);
-
-        ojson& children = current["children"] = ojson::object({});
-        stack_.push_back(&children);
-    }
-
-    void end_visit(const Suite& suite [[maybe_unused]]) { stack_.pop_back(); }
-
-    void begin_visit(const Family& family) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[family.name()] = ojson::object({});
-
-        current["type"] = "family";
-        if (with_id_) {
-            current["id"] = family.absNodePath();
-        }
-        publish_state(family, current);
-        publish_attributes(family, current);
-
-        ojson& children = current["children"] = ojson::object({});
-        stack_.push_back(&children);
-    }
-
-    void end_visit(const Family& family [[maybe_unused]]) { stack_.pop_back(); }
-
-    void begin_visit(const Task& task) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[task.name()] = ojson::object({});
-
-        current["type"] = "task";
-        if (with_id_) {
-            current["id"] = task.absNodePath();
-        }
-        publish_state(task, current);
-        publish_attributes(task, current);
-
-        ojson& children = current["aliases"] = ojson::object({});
-        stack_.push_back(&children);
-    }
-
-    void end_visit(const Task& task [[maybe_unused]]) { stack_.pop_back(); }
-
-    void begin_visit(const Alias& alias) {
-        ojson& parent_ = *stack_.back();
-        ojson& current = parent_[alias.name()] = ojson::object({});
-        stack_.push_back(&current);
-
-        current["type"] = "alias";
-        if (with_id_) {
-            current["id"] = alias.absNodePath();
-        }
-        publish_state(alias, current);
-        publish_attributes(alias, current);
-    }
-
-    void end_visit(const Alias& alias [[maybe_unused]]) { stack_.pop_back(); }
-
-    const ojson& content() const { return root_; }
-
-private:
-    static void publish_state(const Node& node, ojson& parent) {
-        ojson& state = parent["state"] = ojson::object({});
-
-        state["node"]    = NState::toString(node.state());
-        state["default"] = DState::toString(node.dstate());
-    }
-
-    template <typename T>
-    static ojson publish_atribute(const T& attr, std::string_view type) {
-        auto j = ojson::object({});
-        to_json(j, attr);
-        j["type"] = type;
-        return j;
-    }
-
-    static void publish_attributes(const Node& node, ojson& parent) {
-        ojson& array = parent["attributes"] = ojson::array();
-
-        for (const auto& attr : node.labels()) {
-            array.emplace_back(publish_atribute(attr, "label"));
-        }
-        for (const auto& attr : node.meters()) {
-            array.emplace_back(publish_atribute(attr, "meter"));
-        }
-        for (const auto& attr : node.events()) {
-            array.emplace_back(publish_atribute(attr, "event"));
-        }
-        for (const auto& attr : node.variables()) {
-            array.emplace_back(publish_atribute(attr, "variable"));
-        }
-        for (const auto& attr : node.limits()) {
-            array.emplace_back(publish_atribute(*attr, "limit"));
-        }
-        for (const auto& attr : node.inlimits()) {
-            array.emplace_back(publish_atribute(attr, "inlimit"));
-        }
-        for (const auto& attr : node.dates()) {
-            array.emplace_back(publish_atribute(attr, "date"));
-        }
-        for (const auto& attr : node.days()) {
-            array.emplace_back(publish_atribute(attr, "day"));
-        }
-        for (const auto& attr : node.crons()) {
-            array.emplace_back(publish_atribute(attr, "cron"));
-        }
-        for (const auto& attr : node.timeVec()) {
-            array.emplace_back(publish_atribute(attr, "time"));
-        }
-        for (const auto& attr : node.todayVec()) {
-            array.emplace_back(publish_atribute(attr, "today"));
-        }
-        {
-            if (const auto* attr = node.get_late(); attr) {
-                array.emplace_back(publish_atribute(*attr, "late"));
-            }
-        }
-        {
-            if (const auto* attr = node.get_autocancel(); attr) {
-                array.emplace_back(publish_atribute(*attr, "autocancel"));
-            }
-        }
-        {
-            if (const auto* attr = node.get_autoarchive(); attr) {
-                array.emplace_back(publish_atribute(*attr, "autoarchive"));
-            }
-        }
-        {
-            if (const auto* attr = node.get_autorestore(); attr) {
-                array.emplace_back(publish_atribute(*attr, "autorestore"));
-            }
-        }
-        {
-            if (const auto& attr = node.repeat(); !attr.empty()) {
-                array.emplace_back(publish_atribute(attr, "repeat"));
-            }
-        }
-        {
-            if (const auto& attr = node.completeExpression(); !attr.empty()) {
-                auto j          = ojson::object({});
-                j["expression"] = attr;
-                j["type"]       = "complete";
-                array.emplace_back(j);
-            }
-        }
-        {
-            if (const auto& attr = node.triggerExpression(); !attr.empty()) {
-                auto j          = ojson::object({});
-                j["expression"] = attr;
-                j["type"]       = "trigger";
-                array.emplace_back(j);
-            }
-        }
-        for (const auto& attr : node.queues()) {
-            array.emplace_back(publish_atribute(attr, "queue"));
-        }
-        for (const auto& attr : node.zombies()) {
-            array.emplace_back(publish_atribute(attr, "zombie"));
-        }
-        for (const auto& attr : node.generics()) {
-            array.emplace_back(publish_atribute(attr, "generic"));
-        }
-
-        if (auto flag = node.get_flag(); flag.flag()) {
-            array.emplace_back(publish_atribute(flag, "flag"));
-        }
-    }
-
-private:
-    ojson root_;
-    std::vector<ojson*> stack_;
-    bool with_id_;
-};
-
-} // namespace ecf::http
-
-#endif /* ecflow_http_TreeGeneration_HPP */
diff -pruN 5.12.4-1/Http/src/ecflow/http/TypeToJson.cpp 5.13.0-1/Http/src/ecflow/http/TypeToJson.cpp
--- 5.12.4-1/Http/src/ecflow/http/TypeToJson.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/TypeToJson.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,355 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/http/TypeToJson.hpp"
-
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/SState.hpp"
-#include "ecflow/core/User.hpp"
-
-using ecf::http::ojson;
-
-void to_json(ojson& j, const ::Meter& a) {
-    j = ojson({{"name", a.name()}, {"min", a.min()}, {"max", a.max()}, {"value", a.value()}});
-}
-
-void to_json(ojson& j, const ::Label& a) {
-    j = ojson({{"name", a.name()}, {"value", a.new_value().empty() ? a.value() : a.new_value()}});
-}
-
-void to_json(ojson& j, const ::Variable& a) {
-    j = ojson({{"name", a.name()}, {"value", a.theValue()}, {"const", false}});
-}
-
-void to_json(ojson& j, const ::Event& a) {
-    j = ojson({{"name", a.name()}, {"value", a.value()}, {"initial_value", a.initial_value()}});
-}
-
-void to_json(ojson& j, const limit_ptr& a) {
-    to_json(j, *a);
-}
-
-void to_json(ojson& j, const Limit& a) {
-    j = ojson({{"name", a.name()}, {"value", a.value()}, {"limit", a.theLimit()}});
-}
-
-void to_json(ojson& j, const ::InLimit& a) {
-    j = ojson({{"value", a.toString()}});
-}
-
-void to_json(ojson& j, const ::DateAttr& a) {
-    std::string value = a.toString();
-    value             = value.substr(5, std::string::npos); // remove prefix "date "
-    j                 = ojson({{"value", value}, {"free", a.isSetFree()}});
-}
-
-void to_json(ojson& j, const ::DayAttr& a) {
-    std::string value = a.toString();
-    value             = value.substr(4, std::string::npos); // remove prefix "day "
-    j                 = ojson({{"value", value}, {"free", a.isSetFree()}, {"expired", a.expired()}});
-}
-
-void to_json(ojson& j, const ::RepeatDateList& a) {
-    std::vector<std::string> lst;
-    for (int i = 0; i < a.indexNum(); i++) {
-        lst.push_back(a.value_as_string(i));
-    }
-    j = ojson({{"name", a.name()}, {"index", a.index_or_value()}, {"value", a.valueAsString()}, {"values", lst}});
-}
-
-void to_json(ojson& j, const ::RepeatDate& a) {
-    j = ojson({{"name", a.name()}, {"start", a.start()}, {"end", a.end()}, {"step", a.step()}, {"value", a.value()}});
-}
-
-void to_json(ojson& j, const RepeatDateTime& a) {
-    j = ojson({{"name", a.name()},
-               {"start", ecf::Instant::format(a.start_instant())},
-               {"end", ecf::Instant::format(a.end_instant())},
-               {"step", ecf::Duration::format(a.step_duration())},
-               {"value", ecf::Instant::format(a.value_instant())}});
-}
-
-void to_json(ojson& j, const ::RepeatDay& a) {
-    j = ojson({{"name", a.name()}, {"value", a.value()}, {"valid", a.valid()}});
-}
-
-void to_json(ojson& j, const ::RepeatInteger& a) {
-    j = ojson({{"name", a.name()}, {"start", a.start()}, {"end", a.end()}, {"step", a.step()}, {"value", a.value()}});
-}
-
-void to_json(ojson& j, const ::RepeatEnumerated& a) {
-    std::vector<std::string> lst;
-    for (int i = 0; i < a.indexNum(); i++) {
-        lst.push_back(a.value_as_string(i));
-    }
-    j = ojson({{"name", a.name()}, {"index", a.index_or_value()}, {"value", a.valueAsString()}, {"values", lst}});
-}
-
-void to_json(ojson& j, const ::RepeatString& a) {
-    std::vector<std::string> lst;
-    for (int i = 0; i < a.indexNum(); i++) {
-        lst.push_back(a.value_as_string(i));
-    }
-    j = ojson({{"name", a.name()}, {"index", a.index_or_value()}, {"value", a.valueAsString()}, {"values", lst}});
-}
-
-namespace {
-
-template <typename T, typename... Rest>
-void repeat_to_json(ojson& j, const RepeatBase* b) {
-    if (auto rr = dynamic_cast<const T*>(b)) {
-        to_json(j, *rr);
-        return;
-    }
-
-    if constexpr (sizeof...(Rest) >= 1) {
-        repeat_to_json<Rest...>(j, b);
-    }
-}
-
-} // namespace
-
-void to_json(ojson& j, const Repeat& a) {
-    const RepeatBase* b = a.repeatBase();
-    repeat_to_json<RepeatDate,
-                   RepeatDateTime,
-                   RepeatDateList,
-                   RepeatInteger,
-                   RepeatDay,
-                   RepeatString,
-                   RepeatEnumerated>(j, b);
-}
-
-void to_json(ojson& j, const ::Stats& s) {
-    j["version"]                   = s.version_;
-    j["status"]                    = SState::to_string(s.status_);
-    j["host"]                      = s.host_;
-    j["port"]                      = s.port_;
-    j["up_since"]                  = s.up_since_;
-    j["job_sub_interval"]          = s.job_sub_interval_;
-    j["ECF_HOME"]                  = s.ECF_HOME_;
-    j["ECF_LOG"]                   = s.ECF_LOG_;
-    j["ECF_CHECK"]                 = s.ECF_CHECK_;
-    j["ECF_SSL"]                   = s.ECF_SSL_;
-    j["checkpt_interval"]          = s.checkpt_interval_;
-    j["checkpt_mode"]              = s.checkpt_mode_;
-    j["checkpt_save_time_alarm"]   = s.checkpt_save_time_alarm_;
-    j["no_of_suites"]              = s.no_of_suites_;
-    j["request_stats"]             = s.request_stats_;
-    j["locked_by_user"]            = s.locked_by_user_;
-    j["checkpt"]                   = s.checkpt_;
-    j["restore_defs_from_checkpt"] = s.restore_defs_from_checkpt_;
-    j["restart_server"]            = s.restart_server_;
-    j["shutdown_server"]           = s.shutdown_server_;
-    j["halt_server"]               = s.halt_server_;
-    j["ping"]                      = s.ping_;
-    j["debug_server_on"]           = s.debug_server_on_;
-    j["debug_server_off"]          = s.debug_server_off_;
-    j["get_defs"]                  = s.get_defs_;
-    j["server_version"]            = s.server_version_;
-    j["sync"]                      = s.sync_;
-    j["sync_full"]                 = s.sync_full_;
-    j["sync_clock"]                = s.sync_clock_;
-    j["news"]                      = s.news_;
-    j["task_init"]                 = s.task_init_;
-    j["task_complete"]             = s.task_complete_;
-    j["task_wait"]                 = s.task_wait_;
-    j["task_abort"]                = s.task_abort_;
-    j["task_event"]                = s.task_event_;
-    j["task_meter"]                = s.task_meter_;
-    j["task_label"]                = s.task_label_;
-    j["task_queue"]                = s.task_queue_;
-    j["zombie_fob"]                = s.zombie_fob_;
-    j["zombie_fail"]               = s.zombie_fail_;
-    j["zombie_adopt"]              = s.zombie_adopt_;
-    j["zombie_remove"]             = s.zombie_remove_;
-    j["zombie_get"]                = s.zombie_get_;
-    j["zombie_block"]              = s.zombie_block_;
-    j["zombie_kill"]               = s.zombie_kill_;
-    j["load_defs"]                 = s.load_defs_;
-    j["begin_cmd"]                 = s.begin_cmd_;
-    j["requeue_node"]              = s.requeue_node_;
-    j["node_job_gen"]              = s.node_job_gen_;
-    j["node_check_job_gen_only"]   = s.node_check_job_gen_only_;
-    j["node_delete"]               = s.node_delete_;
-    j["node_suspend"]              = s.node_suspend_;
-    j["node_resume"]               = s.node_resume_;
-    j["node_kill"]                 = s.node_kill_;
-    j["node_status"]               = s.node_status_;
-    j["node_edit_history"]         = s.node_edit_history_;
-    j["node_archive"]              = s.node_archive_;
-    j["node_restore"]              = s.node_restore_;
-    j["log_cmd"]                   = s.log_cmd_;
-    j["log_msg_cmd"]               = s.log_msg_cmd_;
-    j["order_node"]                = s.order_node_;
-    j["run_node"]                  = s.run_node_;
-    j["replace"]                   = s.replace_;
-    j["force"]                     = s.force_;
-    j["free_dep"]                  = s.free_dep_;
-    j["suites"]                    = s.suites_;
-    j["edit_script"]               = s.edit_script_;
-    j["alter_cmd"]                 = s.alter_cmd_;
-    j["ch_cmd"]                    = s.ch_cmd_;
-    j["plug"]                      = s.plug_;
-    j["move"]                      = s.move_;
-    j["group_cmd"]                 = s.group_cmd_;
-    j["server_load_cmd"]           = s.server_load_cmd_;
-    j["stats"]                     = s.stats_;
-    j["check"]                     = s.check_;
-    j["query"]                     = s.query_;
-    j["reload_white_list_file"]    = s.reload_white_list_file_;
-    j["reload_passwd_file"]        = s.reload_passwd_file_;
-    j["file_ecf"]                  = s.file_ecf_;
-    j["file_job"]                  = s.file_job_;
-    j["file_jobout"]               = s.file_jobout_;
-    j["file_cmdout"]               = s.file_cmdout_;
-    j["file_manual"]               = s.file_manual_;
-}
-
-void to_json(ojson& j, const ::Expression* a) {
-    if (!a) {
-        return;
-    }
-
-    to_json(j, *a);
-}
-
-void to_json(ojson& j, const ::Expression& a) {
-    const std::vector<PartExpression>& exprs = a.expr();
-    std::vector<ojson> str;
-
-    for (const auto& expr : exprs) {
-        std::string typestr("FIRST");
-        if (expr.andExpr()) {
-            typestr = "AND";
-        }
-        else if (expr.orExpr()) {
-            typestr = "OR";
-        }
-
-        ojson jj = ojson::object({{"expression", expr.expression()}, {"type", typestr}});
-
-        str.push_back(jj);
-    }
-
-    std::string value;
-    a.print(value, "complete");
-    value = value.substr(11, value.size() - 12);
-    j     = ojson::object({{"free", a.isFree()}, {"expressions", str}, {"value", value}});
-}
-
-void to_json(ojson& j, const ::QueueAttr& a) {
-    j["name"]  = a.name();
-    j["index"] = a.index();
-    j["value"] = a.value();
-    j["queue"] = a.list();
-}
-
-void to_json(ojson& j, const ::ZombieAttr& a) {
-    j["type"]           = ecf::Child::to_string(a.zombie_type());
-    j["action"]         = ecf::User::to_string(a.action());
-    j["child_commands"] = ecf::Child::to_string(a.child_cmds());
-    j["lifetime"]       = a.zombie_lifetime();
-}
-
-void to_json(ojson& j, const ::GenericAttr& a) {
-    j["name"]   = a.name();
-    j["values"] = a.values();
-}
-
-namespace ecf {
-
-void to_json(ojson& j, const ecf::TimeAttr& a) {
-    std::string value = a.toString();
-    value             = value.substr(5, std::string::npos); // remove prefix "date "
-    j                 = ojson({{"value", value}});
-}
-
-void to_json(ojson& j, const ecf::TodayAttr& a) {
-    j = ojson(
-        {{"value", a.time_series().toString()}, {"free", a.isSetFree()}, {"expired", !a.time_series().is_valid()}});
-}
-
-void to_json(ojson& j, const ecf::CronAttr& a) {
-    std::string value = a.toString();
-    value             = value.substr(5, std::string::npos); // remove prefix "cron "
-    j                 = ojson({{"value", value}});
-}
-
-void to_json(ojson& j, const ecf::Flag& a) {
-    j["value"] = a.to_string();
-}
-
-void to_json(ojson& j, const ecf::LateAttr* a) {
-    if (!a) {
-        return;
-    }
-
-    to_json(j, *a);
-}
-
-void to_json(ojson& j, const ecf::LateAttr& a) {
-    j["submitted"]            = a.submitted();
-    j["active"]               = a.active();
-    j["complete"]             = a.complete();
-    j["complete_is_relative"] = a.complete_is_relative();
-    j["is_late"]              = a.isLate();
-    const std::string value   = a.toString().substr(5, std::string::npos); // remove prefix "late "
-    j["value"]                = value;
-}
-
-void to_json(ojson& j, const ecf::TimeSlot& a) {
-    j["value"] = a.toString();
-}
-
-void to_json(ojson& j, const ecf::AutoCancelAttr* a) {
-    if (!a) {
-        return;
-    }
-
-    to_json(j, *a);
-}
-
-void to_json(ojson& j, const ecf::AutoCancelAttr& a) {
-    j["relative"]     = a.relative();
-    j["days"]         = a.days();
-    j["time"]         = a.time();
-    std::string value = a.toString().substr(11, std::string::npos);
-    j["value"]        = value;
-}
-
-void to_json(ojson& j, const ecf::AutoRestoreAttr* a) {
-    if (!a) {
-        return;
-    }
-
-    to_json(j, *a);
-}
-void to_json(ojson& j, const ecf::AutoRestoreAttr& a) {
-    std::string value = a.toString().substr(12, std::string::npos);
-    j["value"]        = value;
-}
-
-void to_json(ojson& j, const ecf::AutoArchiveAttr* a) {
-    if (!a) {
-        return;
-    }
-
-    to_json(j, *a);
-}
-void to_json(ojson& j, const ecf::AutoArchiveAttr& a) {
-    j["relative"]     = a.relative();
-    j["days"]         = a.days();
-    j["time"]         = a.time();
-    std::string value = a.toString().substr(12, std::string::npos);
-    j["value"]        = value;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Http/src/ecflow/http/TypeToJson.hpp 5.13.0-1/Http/src/ecflow/http/TypeToJson.hpp
--- 5.12.4-1/Http/src/ecflow/http/TypeToJson.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/src/ecflow/http/TypeToJson.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_TypeToJson_HPP
-#define ecflow_http_TypeToJson_HPP
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/ClockAttr.hpp"
-#include "ecflow/attribute/CronAttr.hpp"
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/attribute/RepeatAttr.hpp"
-#include "ecflow/attribute/TimeAttr.hpp"
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/base/Stats.hpp"
-#include "ecflow/core/TimeSlot.hpp"
-#include "ecflow/http/JSON.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/InLimit.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/LimitFwd.hpp"
-
-/**
- * IMPORTANT
- *
- * The following `to_json` functions are used by nlohmann::json library to convert the given object to a JSON object.
- *
- * These functions are effectively customization points, found using ADL (Argument-Dependent Lookup), and so need to be
- * declared in the same namespace as the object.
- */
-
-void to_json(ecf::http::ojson&, const ::Meter&);
-void to_json(ecf::http::ojson&, const ::Label&);
-void to_json(ecf::http::ojson&, const ::Variable&);
-void to_json(ecf::http::ojson&, const ::Event&);
-void to_json(ecf::http::ojson&, const ::limit_ptr&);
-void to_json(ecf::http::ojson&, const ::Limit&);
-void to_json(ecf::http::ojson&, const ::InLimit&);
-void to_json(ecf::http::ojson&, const ::DateAttr&);
-void to_json(ecf::http::ojson&, const ::DayAttr&);
-void to_json(ecf::http::ojson&, const ::RepeatDate&);
-void to_json(ecf::http::ojson&, const ::RepeatDateTime&);
-void to_json(ecf::http::ojson&, const ::RepeatDay&);
-void to_json(ecf::http::ojson&, const ::RepeatDateList&);
-void to_json(ecf::http::ojson&, const ::RepeatInteger&);
-void to_json(ecf::http::ojson&, const ::RepeatEnumerated&);
-void to_json(ecf::http::ojson&, const ::RepeatString&);
-void to_json(ecf::http::ojson&, const ::Repeat&);
-void to_json(ecf::http::ojson&, const ::Stats&);
-void to_json(ecf::http::ojson&, const ::Expression*);
-void to_json(ecf::http::ojson&, const ::Expression&);
-void to_json(ecf::http::ojson&, const ::QueueAttr&);
-void to_json(ecf::http::ojson&, const ::ZombieAttr&);
-void to_json(ecf::http::ojson&, const ::GenericAttr&);
-namespace ecf {
-void to_json(ecf::http::ojson&, const ecf::TimeAttr&);
-void to_json(ecf::http::ojson&, const ecf::TodayAttr&);
-void to_json(ecf::http::ojson&, const ecf::CronAttr&);
-void to_json(ecf::http::ojson&, const ecf::Flag&);
-void to_json(ecf::http::ojson&, const ecf::LateAttr*);
-void to_json(ecf::http::ojson&, const ecf::LateAttr&);
-void to_json(ecf::http::ojson&, const ecf::TimeSlot&);
-void to_json(ecf::http::ojson&, const ecf::AutoCancelAttr*);
-void to_json(ecf::http::ojson&, const ecf::AutoCancelAttr&);
-void to_json(ecf::http::ojson&, const ecf::AutoArchiveAttr*);
-void to_json(ecf::http::ojson&, const ecf::AutoArchiveAttr&);
-void to_json(ecf::http::ojson&, const ecf::AutoRestoreAttr*);
-void to_json(ecf::http::ojson&, const ecf::AutoRestoreAttr&);
-} // namespace ecf
-
-#endif /* ecflow_http_TypeToJson_HPP */
diff -pruN 5.12.4-1/Http/test/Certificate.hpp 5.13.0-1/Http/test/Certificate.hpp
--- 5.12.4-1/Http/test/Certificate.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/test/Certificate.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,188 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-///
-/// Based on https://gist.github.com/nathan-osman/5041136
-///
-
-#ifndef ecflow_http_test_Certificate_HPP
-#define ecflow_http_test_Certificate_HPP
-
-#include <cstdio>
-#include <iostream>
-
-#include <openssl/evp.h>
-#include <openssl/pem.h>
-#include <openssl/rsa.h>
-#include <openssl/x509.h>
-
-class Certificate {
-public:
-    Certificate() = delete;
-    explicit Certificate(const std::string& path);
-    ~Certificate();
-
-private:
-    std::string path_;
-    EVP_PKEY* generate_key();
-    X509* generate_x509(EVP_PKEY* pkey);
-    void write_to_disk(EVP_PKEY* pkey, X509* x509);
-};
-
-inline Certificate::Certificate(const std::string& path) : path_(path) {
-    // std::cout << "Generating RSA key..." << std::endl;
-
-    EVP_PKEY* pkey = generate_key();
-
-    /* Generate the certificate. */
-    // std::cout << "Generating x509 certificate..." << std::endl;
-
-    X509* x509 = generate_x509(pkey);
-    if (!x509) {
-        EVP_PKEY_free(pkey);
-        throw std::runtime_error("Unable to create certificate");
-        ;
-    }
-
-    /* Write the private key and certificate out to disk. */
-    // std::cout << "Writing key and certificate to disk..." << std::endl;
-
-    write_to_disk(pkey, x509);
-}
-
-inline Certificate::~Certificate() {
-    if (remove((path_ + "/server.crt").c_str()) != 0) {
-        std::cerr << "Failed to remove file server.crt" << std::endl;
-    }
-    else {
-        std::cout << "Removed file " << (path_ + "/server.crt") << std::endl;
-    }
-
-    if (remove((path_ + "/server.key").c_str()) != 0) {
-        std::cerr << "Failed to remove file server.key" << std::endl;
-    }
-    else {
-        std::cout << "Removed file " << (path_ + "/server.key") << std::endl;
-    }
-}
-
-/* Generates a 2048-bit RSA key. */
-inline EVP_PKEY* Certificate::generate_key() {
-    const int KEY_LEN = 2048;
-#if OPENSSL_VERSION_MAJOR >= 3
-    EVP_PKEY* pkey = EVP_RSA_gen(KEY_LEN);
-    if (!pkey) {
-        throw std::runtime_error("Unable to create EVP_PKEY structure");
-    }
-#else
-    /* Allocate memory for the EVP_PKEY structure. */
-    EVP_PKEY* pkey = EVP_PKEY_new();
-
-    /* Generate the RSA key and assign it to pkey. */
-    RSA* rsa    = RSA_new();
-    BIGNUM* bne = BN_new();
-
-    if (!BN_set_word(bne, 65537)) {
-        throw std::runtime_error("Unable to set BIGNUM");
-    }
-
-    if (!RSA_generate_key_ex(rsa, KEY_LEN, bne, NULL)) {
-        throw std::runtime_error("Unable to generate 2048-bit RSA key");
-    }
-
-    // RSA * rsa = RSA_generate_key(2048, RSA_F4, NULL, NULL);
-    if (!EVP_PKEY_assign_RSA(pkey, rsa)) {
-        EVP_PKEY_free(pkey);
-        throw std::runtime_error("Unable to generate 2048-bit RSA key");
-    }
-#endif
-
-    /* The key has been generated, return it. */
-    return pkey;
-}
-
-/* Generates a self-signed x509 certificate. */
-inline X509* Certificate::generate_x509(EVP_PKEY* pkey) {
-    /* Allocate memory for the X509 structure. */
-    X509* x509 = X509_new();
-    if (!x509) {
-        EVP_PKEY_free(pkey);
-        throw std::runtime_error("Unable to create X509 structure");
-    }
-
-    /* Set the serial number. */
-    ASN1_INTEGER_set(X509_get_serialNumber(x509), 1);
-
-    /* This certificate is valid from now until exactly one year from now. */
-    X509_gmtime_adj(X509_get_notBefore(x509), 0);
-    X509_gmtime_adj(X509_get_notAfter(x509), 31536000L);
-
-    /* Set the public key for our certificate. */
-    X509_set_pubkey(x509, pkey);
-
-    /* We want to copy the subject name to the issuer name. */
-    X509_NAME* name = X509_get_subject_name(x509);
-
-    /* Set the country code and common name. */
-    X509_NAME_add_entry_by_txt(name, "C", MBSTRING_ASC, (unsigned char*)"CA", -1, -1, 0);
-    X509_NAME_add_entry_by_txt(name, "O", MBSTRING_ASC, (unsigned char*)"ecflow-test", -1, -1, 0);
-    X509_NAME_add_entry_by_txt(name, "CN", MBSTRING_ASC, (unsigned char*)"localhost", -1, -1, 0);
-
-    /* Now set the issuer name. */
-    X509_set_issuer_name(x509, name);
-
-    /* Actually sign the certificate with our key. */
-    if (!X509_sign(x509, pkey, EVP_sha1())) {
-        X509_free(x509);
-        EVP_PKEY_free(pkey);
-        throw std::runtime_error("Error signing certificate");
-    }
-
-    return x509;
-}
-
-inline void Certificate::write_to_disk(EVP_PKEY* pkey, X509* x509) {
-    /* Open the PEM file for writing the key to disk. */
-
-    FILE* pkey_file = fopen((path_ + "/server.key").c_str(), "wb");
-    if (!pkey_file) {
-        EVP_PKEY_free(pkey);
-        throw std::runtime_error("Unable to open " + path_ + "/server.key for writing");
-    }
-
-    /* Write the key to disk. */
-    bool ret = PEM_write_PrivateKey(pkey_file, pkey, NULL, NULL, 0, NULL, NULL);
-    fclose(pkey_file);
-
-    EVP_PKEY_free(pkey);
-
-    if (!ret) {
-        X509_free(x509);
-        throw std::runtime_error("Unable to write private key to disk");
-    }
-
-    /* Open the PEM file for writing the certificate to disk. */
-    FILE* x509_file = fopen((path_ + "/server.crt").c_str(), "wb");
-    if (!x509_file) {
-        X509_free(x509);
-        throw std::runtime_error("Unable to open " + path_ + "/server.crt for writing");
-    }
-
-    /* Write the certificate to disk. */
-    ret = PEM_write_X509(x509_file, x509);
-    fclose(x509_file);
-
-    X509_free(x509);
-    if (!ret) {
-        throw std::runtime_error("Unable to write private key to disk");
-    }
-}
-
-#endif /* #ifndef ecflow_http_test_Certificate_HPP */
diff -pruN 5.12.4-1/Http/test/InvokeServer.hpp 5.13.0-1/Http/test/InvokeServer.hpp
--- 5.12.4-1/Http/test/InvokeServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/test/InvokeServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,85 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_test_InvokeServer_HPP
-#define ecflow_http_test_InvokeServer_HPP
-
-#include <iostream>
-#include <thread>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestHelper.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/EcfPortLock.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/server/Server.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-class InvokeServer {
-public:
-    InvokeServer() {
-        std::string port(getenv("ECF_PORT"));
-        /// Remove check pt and backup check pt file, else server will load it & remove log file
-        ecf::Host h;
-        fs::remove(h.ecf_checkpt_file(port));
-        fs::remove(h.ecf_backup_checkpt_file(port));
-        fs::remove(h.ecf_log_file(port));
-
-        std::string theServerInvokePath = ecf::File::find_ecf_server_path();
-
-        BOOST_REQUIRE_MESSAGE(!theServerInvokePath.empty(), "The server program could not be found");
-        BOOST_REQUIRE_MESSAGE(fs::exists(theServerInvokePath), "Server exe does not exist at:" << theServerInvokePath);
-
-        BOOST_TEST_MESSAGE("Using eclow_server from " << theServerInvokePath);
-
-        std::thread t([&] { system(theServerInvokePath.c_str()); });
-
-        t.detach();
-
-        sleep(1);
-
-        ClientInvoker theClient("localhost", port);
-        if (theClient.wait_for_server_reply()) {
-            theClient.restartServer();
-            server_started = true;
-        }
-        else {
-            server_started = false;
-        }
-    }
-
-    ~InvokeServer() {
-        std::string port(getenv("ECF_PORT"));
-
-        BOOST_TEST_MESSAGE("*****InvokeServer:: Closing server on port " << port);
-        {
-            ClientInvoker theClient("localhost", port);
-            BOOST_REQUIRE_NO_THROW(theClient.terminateServer());
-            BOOST_REQUIRE_MESSAGE(theClient.wait_for_server_death(), "Failed to terminate server after 60 seconds\n");
-        }
-
-        ecf::Host h;
-        fs::remove(h.ecf_log_file(port));
-        BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_log_file(port)), "log file " << h.ecf_log_file(port) << " not deleted\n");
-
-        fs::remove(h.ecf_checkpt_file(port));
-        fs::remove(h.ecf_backup_checkpt_file(port));
-        BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_checkpt_file(port)),
-                            "file " << h.ecf_checkpt_file(port) << " not deleted\n");
-        BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_backup_checkpt_file(port)),
-                            "file " << h.ecf_backup_checkpt_file(port) << " not deleted\n");
-    }
-
-    bool server_started{false};
-};
-
-#endif /* ecflow_http_test_InvokeServer_HPP */
diff -pruN 5.12.4-1/Http/test/TestApiV1.cpp 5.13.0-1/Http/test/TestApiV1.cpp
--- 5.12.4-1/Http/test/TestApiV1.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/test/TestApiV1.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,987 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifdef ECF_OPENSSL
-    #define CPPHTTPLIB_OPENSSL_SUPPORT
-#endif
-
-#include <httplib.h>
-
-#include <boost/test/unit_test.hpp>
-
-#include "Certificate.hpp"
-#include "InvokeServer.hpp"
-#include "TokenFile.hpp"
-#include "ecflow/http/HttpServer.hpp"
-#include "ecflow/http/HttpServerException.hpp"
-#include "ecflow/http/JSON.hpp"
-
-BOOST_AUTO_TEST_SUITE(S_Http)
-
-BOOST_AUTO_TEST_SUITE(T_ApiV1)
-
-using ecf::http::HttpServer;
-using ecf::http::HttpStatusCode;
-using ecf::http::ojson;
-
-const std::string API_HOST("localhost");
-const std::string API_KEY("3a8c3f7ac204d9c6370b5916bd8b86166c208e10776285edcbc741d56b5b4c1e");
-
-std::unique_ptr<Certificate> create_certificate() {
-    const char* cert_dir = getenv("ECF_API_CERT_DIRECTORY");
-    const std::string path_to_cert =
-        (cert_dir == nullptr) ? std::string(getenv("HOME")) + "/.ecflowrc/ssl/" : std::string(cert_dir);
-
-    std::unique_ptr<Certificate> cert;
-
-    BOOST_TEST_MESSAGE("Certificates at " << path_to_cert);
-
-    if (fs::exists(path_to_cert + "/server.crt") == false || fs::exists(path_to_cert + "/server.key") == false) {
-        if (fs::exists(path_to_cert) == false) {
-            fs::create_directories(path_to_cert);
-        }
-
-        cert = std::make_unique<Certificate>(path_to_cert);
-
-        setenv("ECF_API_CERT_DIRECTORY", path_to_cert.c_str(), 1);
-        return cert;
-    }
-    return cert;
-}
-
-std::unique_ptr<TokenFile> create_token_file() {
-    fs::path cwd(fs::current_path());
-    std::string tokens_file = cwd.string() + "/api-tokens.json";
-
-    auto tokenfile = std::make_unique<TokenFile>(tokens_file);
-    BOOST_TEST_MESSAGE("Token file " << tokens_file);
-    return tokenfile;
-}
-
-void start_api_server() {
-
-    if (getenv("NO_API_SERVER") != nullptr)
-        return; // for debugging
-    std::thread t([] {
-        int argc     = 3;
-        char* argv[] = {(char*)"ecflow_http", (char*)"--polling_interval", (char*)"1", NULL};
-
-        HttpServer server(argc, argv);
-        server.run();
-    });
-
-    sleep(1);
-    t.detach();
-}
-
-std::unique_ptr<InvokeServer> start_ecflow_server() {
-    if (getenv("NO_ECFLOW_SERVER") != nullptr)
-        return nullptr;
-
-    auto srv = std::make_unique<InvokeServer>();
-
-    BOOST_REQUIRE_MESSAGE(srv->server_started, "Server failed to start on port " << getenv("ECF_PORT"));
-    BOOST_TEST_MESSAGE("ecflow server at localhost:" << getenv("ECF_PORT"));
-    return srv;
-}
-
-struct SetupTest
-{
-    SetupTest() : tokenfile(create_token_file()), cert(create_certificate()) {
-        sigset_t set;
-        sigemptyset(&set);
-        sigaddset(&set, SIGPIPE);
-
-        if (pthread_sigmask(SIG_BLOCK, &set, NULL) != 0) {
-            throw std::runtime_error("Failed to set signal mask");
-        }
-
-        setenv("ECF_PORT", "3199", 0);
-        setenv("ECF_HOST", "localhost", 1);
-    }
-    void setup() {
-        // This needs to be initialized in setup() instead
-        // of constructor... really don't know why
-        srv = start_ecflow_server();
-        start_api_server();
-        printf("======= TESTS STARTING ========\n");
-    }
-    ~SetupTest() { printf("======= TESTS FINISHED ========\n"); }
-
-    std::unique_ptr<TokenFile> tokenfile{nullptr};
-    std::unique_ptr<Certificate> cert{nullptr};
-    std::unique_ptr<InvokeServer> srv{nullptr};
-};
-
-BOOST_TEST_GLOBAL_FIXTURE(SetupTest);
-
-httplib::Response handle_response(const httplib::Result& r,
-                                  HttpStatusCode expected_code = HttpStatusCode::success_ok,
-                                  bool throw_on_error          = false) {
-    if (r) {
-        BOOST_TEST_MESSAGE("Return code: " << r->status);
-        BOOST_TEST_MESSAGE("Return value: " << r->body);
-    }
-    else {
-        BOOST_TEST_MESSAGE("Null reply from server");
-    }
-
-    if (throw_on_error) {
-        if (!r) {
-            throw std::runtime_error("NULL reply from server");
-        }
-        else if (r->status != expected_code) {
-            throw std::runtime_error(
-                "Expected status code: " + ecf::convert_to<std::string>(static_cast<int>(expected_code)) +
-                " got: " + ecf::convert_to<std::string>(r->status));
-        }
-    }
-    else {
-        BOOST_REQUIRE_MESSAGE(r, "ERROR: no response");
-        BOOST_REQUIRE_MESSAGE(r->status == expected_code,
-                              "ERROR: status code is not " +
-                                  ecf::convert_to<std::string>(static_cast<int>(expected_code)));
-    }
-
-    return httplib::Response(*r);
-}
-
-httplib::Result request(const std::string& method,
-                        const std::string& resource,
-                        const std::string& payload             = "",
-                        const std::string& token               = "",
-                        const httplib::Headers& custom_headers = {}) {
-    httplib::SSLClient c(API_HOST, 8080);
-
-    c.enable_server_certificate_verification(false);
-    c.set_connection_timeout(3);
-
-    BOOST_TEST_MESSAGE("Request URL: " << method << " " << API_HOST << resource);
-    BOOST_TEST_MESSAGE("Request body: " << payload);
-
-    httplib::Headers h = {{"Content-type", "application/json"}};
-
-    if ((method == "post" || method == "put" || method == "delete") && token.empty() == false) {
-        h.insert(std::make_pair("Authorization", "Bearer " + token));
-    }
-
-    for (const auto& kv : custom_headers) {
-        h.insert(kv);
-    }
-
-    c.set_default_headers(h);
-
-    if (method == "get" || method == "head")
-        return c.Get(resource);
-    else if (method == "post")
-        return c.Post(resource, payload, "application/json");
-    else if (method == "put")
-        return c.Put(resource, payload, "application/json");
-    else if (method == "delete")
-        return c.Delete(resource, payload, "application/json");
-
-    BOOST_FAIL("Unknown HTTP method");
-
-    return httplib::Result(nullptr, httplib::Error::Unknown); // to silence compiler warnings
-}
-
-template <typename T>
-bool wait_until(T&& func, int wait_time = 1, int wait_count = 10) {
-    int c = 0;
-
-    while (func() == false) {
-        c++;
-        if (c > wait_count) {
-            BOOST_FAIL("Test failed");
-        }
-        sleep(wait_time);
-    }
-    return true;
-}
-
-bool check_for_path(const std::string& path) {
-    try {
-        handle_response(request("head", path), HttpStatusCode::success_ok, true);
-        return true;
-    }
-    catch (...) {
-        return false;
-    }
-}
-
-bool check_for_element(const std::string& path,
-                       const std::string& key_name,
-                       const std::string& attr_name,
-                       const std::string& value) {
-
-    try {
-        auto r = handle_response(request("get", path), HttpStatusCode::success_ok, true);
-        auto j = ojson::parse(r.body);
-
-        if (j.is_null()) {
-            return false;
-        }
-        else if (j.is_array() == false) {
-            j = ojson::array({j});
-            std::cout << "json is " << j << std::endl;
-        }
-
-        for (const auto& x : j) {
-            // std::cout << x << std::endl;
-            if (attr_name.empty() == false) {
-                // { "name": "foo", "value": "bar"}
-                // std::cout << "expecting: " << attr_name << "=" << value << " got: " << x["name"].get<std::string>()
-                // << "=" << json_type_to_string(x[key_name]) << std::endl;
-                if (attr_name == x["name"] && value == ecf::http::json_type_to_string(x[key_name]))
-                    return true;
-            }
-            else if (key_name.empty() == false) {
-                // { "foo" : "bar" }
-                // std::cout << "expecting: " << key_name << "='" << value << " got: " << key_name << "='" <<
-                // json_type_to_string(x[key_name]) << "'" << std::endl;
-
-                if (ecf::http::json_type_to_string(x[key_name]) == value)
-                    return true;
-            }
-            else {
-                // "bar"
-                // std::cout << "expecting: '" << value << "' got: '" << json_type_to_string(x) << "'" << std::endl;
-
-                if (value == ecf::http::json_type_to_string(x))
-                    return true;
-            }
-        }
-    }
-    catch (const std::exception& e) {
-        BOOST_TEST_MESSAGE(e.what());
-    }
-    // BOOST_TEST_MESSAGE("Attribute " << attr_name << " --> " << key_name << "=" << value << " at path " << path << "
-    // not found");
-    return false;
-}
-
-BOOST_AUTO_TEST_CASE(test_server) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    wait_until([] { return check_for_element("/v1/server/status?filter=status", "", "", "RUNNING"); });
-
-    handle_response(request("get", "/v1/server/ping"));
-
-    handle_response(
-        request("post", "/v1/server/attributes", R"({"type":"variable","name":"foo","value":"bar"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "foo", "bar"); });
-
-    handle_response(
-        request("put", "/v1/server/attributes", R"({"type":"variable","name":"foo","value":"baz"})", API_KEY));
-    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "foo", "baz"); });
-
-    handle_response(request("delete", "/v1/server/attributes", R"({"type":"variable","name":"foo"})", API_KEY),
-                    HttpStatusCode::success_no_content);
-    wait_until(
-        [] { return false == check_for_element("/v1/server/attributes?filter=variables", "value", "foo", "bar"); });
-}
-
-BOOST_AUTO_TEST_CASE(test_suite) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    // remove test-suite if it exists; disregard any problems with the call
-    request("delete", "/v1/suites/test/definition", "", API_KEY);
-    wait_until([] { return false == check_for_path("/v1/suites/test/definition"); });
-
-    handle_response(request("post",
-                            "/v1/suites",
-                            R"({"definition" : "suite test\n  family a\n    task a\n  endfamily\nendsuite"})",
-                            API_KEY),
-                    HttpStatusCode::success_created);
-    wait_until([] { return check_for_path("/v1/suites/test/definition"); });
-
-    auto result = handle_response(request("get", "/v1/suites"));
-
-    auto content = ojson::parse(result.body);
-    bool found   = false;
-
-    for (const auto& suite : content) {
-        if (suite.get<std::string>() == "test") {
-            found = true;
-            break;
-        }
-    }
-    BOOST_REQUIRE(found);
-
-    result  = handle_response(request("get", "/v1/suites/tree"));
-    content = ojson::parse(result.body);
-    found   = false;
-
-    for (const auto& suite : content.items()) {
-        if (suite.key() == "test") {
-            found = true;
-            break;
-        }
-    }
-
-    BOOST_REQUIRE(found);
-
-    result  = handle_response(request("get", "/v1/suites/test/a/tree"));
-    content = ojson::parse(result.body);
-    found   = false;
-
-    for (const auto& node : content.items()) {
-        if (node.key() == "a") {
-            found = true;
-            break;
-        }
-    }
-
-    BOOST_REQUIRE(found);
-
-    handle_response(request("put", "/v1/suites/test/status", R"({"action":"begin"})", API_KEY));
-
-    auto response = ojson::parse(handle_response(request("get", "/v1/suites/test/definition")).body);
-
-    const std::string& correct = "suite test\n  family a\n    task a\n  endfamily\nendsuite\n";
-
-    BOOST_REQUIRE(response.at("definition").get<std::string>() == correct);
-
-    handle_response(request("put", "/v1/suites/test/status", R"({"action":"suspend"})", API_KEY));
-    wait_until([] { return check_for_element("/v1/suites/test/status?filter=status", "", "", "suspended"); });
-}
-
-BOOST_AUTO_TEST_CASE(test_node_basic_tree) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    // (0) Clean up -- in case there is any left-over from passed/failed tests
-    request("delete", "/v1/suites/basic_suite/definition", "", API_KEY);
-    wait_until([] { return false == check_for_path("/v1/suites/basic_suite/definition"); });
-
-    // (1) Publish 'basic_suite' suite
-
-    std::string suite_definition =
-        R"({"definition" : "suite basic_suite\n  family f\n    task t\n      label l \"value\"\n      meter m 0 100 50\n      event e\n  endfamily\nendsuite\n# comment"})";
-    handle_response(request("post", "/v1/suites", suite_definition, API_KEY), HttpStatusCode::success_created);
-    wait_until([] { return check_for_path("/v1/suites/basic_suite/definition"); });
-
-    // (2) Retrieve 'basic_suite' suite tree
-    {
-        auto result  = handle_response(request("get", "/v1/suites/tree"));
-        auto content = ojson::parse(result.body);
-
-        BOOST_REQUIRE(content.contains("basic_suite"));
-        BOOST_REQUIRE(content["basic_suite"].contains("f"));
-        BOOST_REQUIRE(content["basic_suite"]["f"].contains("t"));
-    }
-
-    // (3) Retrieve 'basic_suite' suite tree, explicitly specifying basic content
-    {
-        auto result  = handle_response(request("get", "/v1/suites/tree?content=basic"));
-        auto content = ojson::parse(result.body);
-
-        BOOST_REQUIRE(content.contains("basic_suite"));
-        BOOST_REQUIRE(content["basic_suite"].contains("f"));
-        BOOST_REQUIRE(content["basic_suite"]["f"].contains("t"));
-    }
-
-    // (4) Retrieve specific node tree
-    {
-        auto result  = handle_response(request("get", "/v1/suites/basic_suite/f/tree?content=basic"));
-        auto content = ojson::parse(result.body);
-
-        BOOST_REQUIRE(content.contains("f"));
-        BOOST_REQUIRE(content["f"].contains("t"));
-    }
-
-    // (5) Clean up
-    request("delete", "/v1/suites/basic_suite/definition", "", API_KEY);
-    wait_until([] { return false == check_for_path("/v1/suites/basic_suite/definition"); });
-}
-
-BOOST_AUTO_TEST_CASE(test_node_full_tree) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    // (0) Clean up -- in case there is any left-over from passed/failed tests
-    request("delete", "/v1/suites/full_suite/definition", "", API_KEY);
-    wait_until([] { return false == check_for_path("/v1/suites/full_suite/definition"); });
-
-    // (1) Publish 'full_tree' suite
-
-    std::string suite_definition =
-        R"({"definition" : "suite full_suite\n  family f\n    task t\n      label l \"value\"\n      meter m 0 100 50\n      event e\n  endfamily\nendsuite\n# comment"})";
-    handle_response(request("post", "/v1/suites", suite_definition, API_KEY), HttpStatusCode::success_created);
-    wait_until([] { return check_for_path("/v1/suites/full_suite/definition"); });
-
-    // (2) Retrieve 'full_suite' suite tree, explicitly specifying full content
-    {
-        auto result  = handle_response(request("get", "/v1/suites/tree?content=full"));
-        auto content = ojson::parse(result.body);
-
-        BOOST_REQUIRE(content.contains("full_suite"));
-        BOOST_REQUIRE(content["full_suite"].contains("type"));
-        BOOST_REQUIRE(content["full_suite"]["type"] == "suite");
-        BOOST_REQUIRE(content["full_suite"].contains("state"));
-        BOOST_REQUIRE(content["full_suite"]["state"].contains("node"));
-        BOOST_REQUIRE(content["full_suite"]["state"].contains("default"));
-        BOOST_REQUIRE(content["full_suite"].contains("children"));
-
-        BOOST_REQUIRE(content["full_suite"]["children"].contains("f"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"].contains("type"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["type"] == "family");
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"].contains("state"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["state"].contains("node"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["state"].contains("default"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"].contains("children"));
-
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"].contains("t"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("type"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["type"] == "task");
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("state"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["state"].contains("node"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["state"].contains("default"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("attributes"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["attributes"].size() == 3);
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("aliases"));
-        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["aliases"].size() == 0);
-    }
-
-    // (2) Retrieve 'full_suite' suite tree, explicitly specifying full content
-    {
-        auto result  = handle_response(request("get", "/v1/suites/full_suite/f/tree?content=full"));
-        auto content = ojson::parse(result.body);
-
-        BOOST_REQUIRE(content.contains("f"));
-        BOOST_REQUIRE(content["f"].contains("state"));
-        BOOST_REQUIRE(content["f"]["state"].contains("node"));
-        BOOST_REQUIRE(content["f"]["state"].contains("default"));
-        BOOST_REQUIRE(content["f"].contains("children"));
-
-        BOOST_REQUIRE(content["f"]["children"].contains("t"));
-        BOOST_REQUIRE(content["f"]["children"]["t"].contains("state"));
-        BOOST_REQUIRE(content["f"]["children"]["t"]["state"].contains("node"));
-        BOOST_REQUIRE(content["f"]["children"]["t"]["state"].contains("default"));
-        BOOST_REQUIRE(content["f"]["children"]["t"].contains("attributes"));
-        BOOST_REQUIRE(content["f"]["children"]["t"]["attributes"].size() == 3);
-        BOOST_REQUIRE(content["f"]["children"]["t"].contains("aliases"));
-        BOOST_REQUIRE(content["f"]["children"]["t"]["aliases"].size() == 0);
-    }
-
-    // (4) Clean up
-    request("delete", "/v1/suites/full_suite/definition", "", API_KEY);
-    wait_until([] { return false == check_for_path("/v1/suites/full_suite/definition"); });
-}
-
-BOOST_AUTO_TEST_CASE(test_token_authentication) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
-
-    handle_response(request("put",
-                            "/v1/server/attributes",
-                            R"({"type":"variable","name":"xfoo","value":"xbaz"})",
-                            "",
-                            {{"X-API-Key", API_KEY}}));
-    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
-
-    handle_response(
-        request("delete", "/v1/server/attributes?key=" + API_KEY, R"({"type":"variable","name":"xfoo"})", ""),
-        HttpStatusCode::success_no_content);
-    wait_until(
-        [] { return false == check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
-
-    const std::string pbkdf2_API_KEY("351db772d94310a6d57aa7144448f4c108e7ee2e2a00a74edbdf8edb11bee71b");
-    handle_response(
-        request("post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", pbkdf2_API_KEY),
-        HttpStatusCode::success_created);
-    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
-
-    const std::string expired_API_KEY("764073a74875ada28859454e58881229a5149ae400589fc617234d8d96c6d91a");
-    handle_response(
-        request(
-            "post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", expired_API_KEY),
-        HttpStatusCode::client_error_unauthorized);
-
-    const std::string revoked_API_KEY("5c6f6a003f3292c4d7671c9ad8ca10fb76e2273e584992f0d1f8fdf4abcdc81e");
-    handle_response(
-        request(
-            "post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", revoked_API_KEY),
-        HttpStatusCode::client_error_unauthorized);
-}
-
-BOOST_AUTO_TEST_CASE(test_family_add, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_suite")) {
-    handle_response(
-        request("put", "/v1/suites/test/definition", R"({"definition": "family dynamic\nendfamily"})", API_KEY));
-    wait_until([] { return check_for_path("/v1/suites/test/dynamic/definition"); });
-}
-
-// STATUS
-
-BOOST_AUTO_TEST_CASE(test_status, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    const std::map<std::string, std::string> statuses{
-        {"abort", "aborted"}, {"complete", "complete"}, {"requeue", "queued"}, {"suspend", "suspended"}};
-
-    for (const auto& status : statuses) {
-        ojson j = {{"action", status.first}};
-        handle_response(request("put", "/v1/suites/test/dynamic/status", j.dump(), API_KEY));
-
-        wait_until(
-            [&] { return check_for_element("/v1/suites/test/dynamic/status?filter=status", "", "", status.second); });
-    }
-
-    handle_response(request(
-        "put", "/v1/suites/test/dynamic/status", R"({"action":"defstatus","defstatus_value":"complete"})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/status?filter=default_status", "", "", "complete"); });
-
-    handle_response(request("put", "/v1/suites/test/a/status", R"({"action":"archive"})", API_KEY));
-    wait_until([] { return false == check_for_path("/v1/suites/test/a/a/definition"); });
-
-    handle_response(request("put", "/v1/suites/test/a/status", R"({"action":"restore"})", API_KEY));
-    wait_until([] { return check_for_path("/v1/suites/test/a/a/definition"); });
-}
-
-// VARIABLE
-
-BOOST_AUTO_TEST_CASE(test_variable, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request(
-            "post", "/v1/suites/test/dynamic/attributes", R"({"type":"variable","name":"foo","value":"bar"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=variables", "value", "foo", "bar"); });
-
-    handle_response(request(
-        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"variable","name":"foo","value":"baz"})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=variables", "value", "foo", "baz"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"variable","name":"foo"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=variables", "value", "foo", "baz");
-    });
-}
-
-// METER
-
-BOOST_AUTO_TEST_CASE(test_meter, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(request("post",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"meter","name":"foo","value":"10","min":"0","max":"20"})",
-                            API_KEY),
-                    HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=meters", "value", "foo", "10"); });
-
-    handle_response(
-        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"meter","name":"foo","value":"15"})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=meters", "value", "foo", "15"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"meter","name":"foo"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=meters", "value", "foo", "15");
-    });
-}
-
-// LIMIT
-
-BOOST_AUTO_TEST_CASE(test_limit, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"limit","name":"foo","value":"0"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=limits", "value", "foo", "0"); });
-
-    handle_response(
-        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"limit","name":"foo","value":"6"})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=limits", "value", "foo", "6"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"limit","name":"foo"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=limits", "value", "foo", "6");
-    });
-}
-
-// EVENT
-
-BOOST_AUTO_TEST_CASE(test_event, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request(
-            "post", "/v1/suites/test/dynamic/attributes", R"({"type":"event","name":"foo","value":"set"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=events", "value", "foo", "true"); });
-
-    handle_response(request(
-        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"event","name":"foo","value":false})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=events", "value", "foo", "false"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"event","name":"foo"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=events", "value", "foo", "false");
-    });
-}
-
-// LABEL
-
-BOOST_AUTO_TEST_CASE(test_label, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request(
-            "post", "/v1/suites/test/dynamic/attributes", R"({"type":"label","name":"foo","value":"bar"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=labels", "value", "foo", "bar"); });
-
-    handle_response(request(
-        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"label","name":"foo","value":"baz"})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=labels", "value", "foo", "baz"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"label","name":"foo"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=labels", "value", "foo", "baz");
-    });
-}
-
-// TIME
-
-BOOST_AUTO_TEST_CASE(test_time, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"time","value":"+00:20"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=times", "value", "", "+00:20"); });
-
-    handle_response(request("put",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"time","old_value":"+00:20","value":"+00:25"})",
-                            API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=times", "value", "", "+00:25"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"time","value":"+00:25"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=times", "value", "", "+00:25");
-    });
-}
-
-// DAY
-
-BOOST_AUTO_TEST_CASE(test_day, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"day","value":"monday"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=days", "value", "", "monday"); });
-
-    handle_response(request("put",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"day","old_value":"monday","value":"tuesday"})",
-                            API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=days", "value", "", "tuesday"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"day","value":"tuesday"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=days", "value", "", "tuesday");
-    });
-}
-
-// DATE
-
-BOOST_AUTO_TEST_CASE(test_date, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"date","value":"1.*.*"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=dates", "value", "", "1.*.*"); });
-
-    handle_response(request("put",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"date","old_value":"1.*.*","value":"2.*.*"})",
-                            API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=dates", "value", "", "2.*.*"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"date","value":"2.*.*"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=dates", "value", "", "2.*.*");
-    });
-}
-
-// TODAY
-
-BOOST_AUTO_TEST_CASE(test_today, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"today","value":"03:00"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=todays", "value", "", "03:00"); });
-
-    handle_response(request("put",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"today","old_value":"03:00","value":"03:00 05:00 01:00"})",
-                            API_KEY));
-    wait_until([] {
-        return check_for_element("/v1/suites/test/dynamic/attributes?filter=todays", "value", "", "03:00 05:00 01:00");
-    });
-
-    handle_response(
-        request(
-            "delete", "/v1/suites/test/dynamic/attributes", R"({"type":"today","value":"03:00 05:00 01:00"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false ==
-               check_for_element("/v1/suites/test/dynamic/attributes?filter=todays", "value", "", "03:00 05:00 01:00");
-    });
-}
-
-// CRON
-
-BOOST_AUTO_TEST_CASE(test_cron, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"cron","value":"-w 0,1 10:00"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until([] {
-        return check_for_element("/v1/suites/test/dynamic/attributes?filter=crons", "value", "", "-w 0,1 10:00");
-    });
-
-    handle_response(request("put",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"cron","old_value":"-w 0,1 10:00","value":"23:00"})",
-                            API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=crons", "value", "", "23:00"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"cron","value":"23:00"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=crons", "value", "", "23:00");
-    });
-}
-
-// LATE
-
-BOOST_AUTO_TEST_CASE(test_late, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(request("post",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"late","value":"-s +00:01 -a 14:30 -c +00:01"})",
-                            API_KEY),
-                    HttpStatusCode::success_created);
-    wait_until([] {
-        return check_for_element(
-            "/v1/suites/test/dynamic/attributes?filter=late", "value", "", "-s +00:01 -a 14:30 -c +00:01");
-    });
-
-    handle_response(request("put",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"late","old_value":"-s +00:01 -a 14:30 -c +00:01","value":"-c +00:01"})",
-                            API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=late", "value", "", "-c +00:01"); });
-
-    handle_response(
-        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"late","value":"-c +00:01"})", API_KEY),
-        HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=late", "value", "", "-c +00:01");
-    });
-}
-
-// COMPLETE
-
-BOOST_AUTO_TEST_CASE(test_complete, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(request("post",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"complete","value":"/test/a eq complete"})",
-                            API_KEY),
-                    HttpStatusCode::success_created);
-    wait_until([] {
-        return check_for_element(
-            "/v1/suites/test/dynamic/attributes?filter=complete", "value", "", "/test/a eq complete");
-    });
-
-    handle_response(request(
-        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"complete","value":"/test/a eq active"})", API_KEY));
-    wait_until([] {
-        return check_for_element(
-            "/v1/suites/test/dynamic/attributes?filter=complete", "value", "", "/test/a eq active");
-    });
-
-    handle_response(request("delete",
-                            "/v1/suites/test/dynamic/attributes",
-                            R"({"type":"complete","value":"/test/a eq active"})",
-                            API_KEY),
-                    HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=complete", "value", "", "");
-    });
-}
-
-// AUTOCANCEL
-
-BOOST_AUTO_TEST_CASE(test_autocancel, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"autocancel","value":"+01:00"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until([] {
-        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autocancel", "value", "", "+01:00");
-    });
-
-    handle_response(
-        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"autocancel","value":"0"})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=autocancel", "value", "", "0"); });
-
-    handle_response(request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"autocancel"})", API_KEY),
-                    HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=autocancel", "value", "", "0");
-    });
-}
-
-// AUTOARCHIVE
-
-BOOST_AUTO_TEST_CASE(test_autoarchive, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"autoarchive","value":"+01:00"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until([] {
-        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autoarchive", "value", "", "+01:00");
-    });
-
-    handle_response(
-        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"autoarchive","value":"0"})", API_KEY));
-    wait_until(
-        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=autoarchive", "value", "", "0"); });
-
-    handle_response(request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"autoarchive"})", API_KEY),
-                    HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=autoarchive", "value", "", "");
-    });
-}
-
-// AUTORESTORE
-
-BOOST_AUTO_TEST_CASE(test_autorestore, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(
-        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"autorestore","value":"/test/a"})", API_KEY),
-        HttpStatusCode::success_created);
-    wait_until([] {
-        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autorestore", "value", "", "/test/a");
-    });
-
-    handle_response(
-        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"autorestore","value":"/test"})", API_KEY));
-    wait_until([] {
-        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autorestore", "value", "", "/test");
-    });
-
-    handle_response(request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"autorestore"})", API_KEY),
-                    HttpStatusCode::success_no_content);
-    wait_until([] {
-        return false ==
-               check_for_element("/v1/suites/test/dynamic/attributes?filter=autorestore", "value", "", "/test");
-    });
-}
-
-// OUTPUT
-
-BOOST_AUTO_TEST_CASE(test_output, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-    handle_response(request("get", "/v1/suites/test/a/a/output"), HttpStatusCode::client_error_not_found);
-}
-
-// SCRIPT
-
-BOOST_AUTO_TEST_CASE(test_script, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-    handle_response(request("get", "/v1/suites/test/a/a/script"), HttpStatusCode::client_error_not_found);
-}
-
-// DELETE FAMILY
-
-BOOST_AUTO_TEST_CASE(test_suite_family_delete, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_autorestore")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    handle_response(request("delete", "/v1/suites/test/dynamic/definition", "", API_KEY),
-                    HttpStatusCode::success_no_content);
-    wait_until([] { return false == check_for_path("/v1/suites/test/dynamic/definition"); });
-    wait_until([] { return check_for_path("/v1/suites/test/definition"); });
-
-    handle_response(request("delete", "/v1/suites/test/definition", "", API_KEY), HttpStatusCode::success_no_content);
-    wait_until([] { return false == check_for_path("/v1/suites/test/definition"); });
-}
-
-BOOST_AUTO_TEST_CASE(test_statistics, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_server")) {
-    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
-
-    auto response = handle_response(request("get", "/v1/statistics"));
-    auto j        = ojson::parse(response.body);
-
-    BOOST_REQUIRE(j["num_requests"].get<int>() > 0);
-    BOOST_REQUIRE(j["num_errors"].get<int>() > 0);
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Http/test/TestHttp_main.cpp 5.13.0-1/Http/test/TestHttp_main.cpp
--- 5.12.4-1/Http/test/TestHttp_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/test/TestHttp_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Http
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/Http/test/TokenFile.hpp 5.13.0-1/Http/test/TokenFile.hpp
--- 5.12.4-1/Http/test/TokenFile.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/test/TokenFile.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,67 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_http_test_TokenFile_HPP
-#define ecflow_http_test_TokenFile_HPP
-
-#include <ostream>
-#include <string>
-
-#include "nlohmann/json.hpp"
-
-class TokenFile {
-public:
-    TokenFile() = delete;
-    explicit TokenFile(const std::string& tokenfile);
-    ~TokenFile();
-
-private:
-    std::string tokenfile_;
-};
-
-inline TokenFile::TokenFile(const std::string& tokenfile) : tokenfile_(tokenfile) {
-    // write api token file
-    // api-keys: 3a8c3f7ac204d9c6370b5916bd8b86166c208e10776285edcbc741d56b5b4c1e
-    //           351db772d94310a6d57aa7144448f4c108e7ee2e2a00a74edbdf8edb11bee71b
-    //           764073a74875ada28859454e58881229a5149ae400589fc617234d8d96c6d91a
-    //           5c6f6a003f3292c4d7671c9ad8ca10fb76e2273e584992f0d1f8fdf4abcdc81e
-
-    nlohmann::json j = {
-        {{"hash", "sha256$22660ab1789dc30e$7e24f61129294505b6ac310ebe891df9800f4854a67bac953bb86bf9fd726813"},
-         {"description", "test-app-1"},
-         {"expires_at", ""}},
-        {{"hash",
-          "pbkdf2:sha256:20000$Iqbh8Bz86hYHpkpn$ea95e8fb276c602fe4a4b56569fbcc321be5b31a3caa6bb3a9001e595349887f"},
-         {"description", "test-app-2"},
-         {"expires_at", "2100-01-01T00:00:00Z"}},
-        {{"hash",
-          "pbkdf2:sha256:20000$Iqbh8Bz86hYHpkpn$ea95e8fb276c602fe4a4b56569fbcc321be5b31a3caa6bb3a9001e595349887f"},
-         {"description", "test-app-3"},
-         {"expires_at", "2000-01-01T00:00:00Z"}},
-        {{"hash",
-          "pbkdf2:sha256:20000$Iqbh8Bz86hYHpkpn$ea95e8fb276c602fe4a4b56569fbcc321be5b31a3caa6bb3a9001e595349887f"},
-         {"description", "test-app-4"},
-         {"revoked_at", "2000-01-01T00:00:00Z"}}};
-
-    std::ofstream o(tokenfile_);
-    o << std::setw(4) << j << std::endl;
-    setenv("ECF_API_TOKEN_FILE", tokenfile_.c_str(), 1);
-}
-
-inline TokenFile::~TokenFile() {
-    if (remove(tokenfile_.c_str()) != 0) {
-        std::cerr << "Failed to remove token file " << tokenfile_ << std::endl;
-    }
-    else {
-        BOOST_TEST_MESSAGE("Removed token file " << tokenfile_);
-    }
-}
-
-#endif /* #ifndef ecflow_http_test_TokenFile_HPP */
diff -pruN 5.12.4-1/Http/test/requirements.txt 5.13.0-1/Http/test/requirements.txt
--- 5.12.4-1/Http/test/requirements.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Http/test/requirements.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-requests
-pytest
-pytest-dependency
diff -pruN 5.12.4-1/Pyext/.gitignore 5.13.0-1/Pyext/.gitignore
--- 5.12.4-1/Pyext/.gitignore	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/.gitignore	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-/build
-/setup.py
-/timestamp
diff -pruN 5.12.4-1/Pyext/CMakeLists.txt 5.13.0-1/Pyext/CMakeLists.txt
--- 5.12.4-1/Pyext/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,260 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-### ecflow python bindings
-# NOTES:
-# 1/ Building multiple python3 versions not supported, since find_python(..) caches variables, Hack: clear cached variable.
-#    https://gitlab.kitware.com/cmake/cmake/issues/19820
-#
-# 2/
-# To see the python link line: Do python-config  --ldflags, i.e
-#   > /usr/local/apps/python/2.7.8-01/bin/python-config  --ldflags
-#   > -lpthread -ldl -lutil -lm -lpython2.7 -Xlinker -export-dynamic
-#
-# However on cct we get:
-#   > /usr/local/apps/python/2.7.5-01/bin/python-config --ldflags
-#   > -L/usr/local/apps/python/2.7.5-01/lib/python2.7/config -lpthread -ldl -lutil -lm -lpython2.7 -Xlinker -export-dynamic
-#
-# cct is correct as it has the "-L" but on other machines we rely on /usr/lib/libpython2.7.so.1.0 being there!
-# lxop-test does not have /usr/lib/libpython2.7.so.1.0 so ecbuild fails
-#
-# For problems with the python build, please look in <build-dir>/ecbuild.log, typically non developmental python
-# installs may not include python libs or includes
-# For ubuntoo to install we need:
-#    sudo apt-get install libpython-dev
-#
-
-# =============================================================================
-# Configure __init__.py to add __version__
-# =============================================================================
-set(INIT_PY_IN  "${CMAKE_CURRENT_SOURCE_DIR}/ecflow/__init__.py.in")
-set(INIT_PY_OUT "${CMAKE_CURRENT_SOURCE_DIR}/ecflow/__init__.py")
-configure_file(${INIT_PY_IN} ${INIT_PY_OUT} )
-
-
-# =============================================================================
-# Configure setup.py. Note used locally. Uses existing libraries
-# =============================================================================
-set(SETUP_PY_IN  "${CMAKE_CURRENT_SOURCE_DIR}/setup.py.in")
-set(SETUP_PY_OUT "${CMAKE_CURRENT_SOURCE_DIR}/setup.py")
-configure_file(${SETUP_PY_IN} ${SETUP_PY_OUT} )
-
-# ==============================================================================
-# source files (paths relative to dirs python2/python3)
-# ==============================================================================
-set(srcs
-  # Headers
-  ../src/ecflow/python/BoostPythonUtil.hpp
-  ../src/ecflow/python/ClientDoc.hpp
-  ../src/ecflow/python/DefsDoc.hpp
-  ../src/ecflow/python/Edit.hpp
-  ../src/ecflow/python/GlossaryDoc.hpp
-  ../src/ecflow/python/NodeAttrDoc.hpp
-  ../src/ecflow/python/NodeUtil.hpp
-  ../src/ecflow/python/Trigger.hpp
-  # Sources
-  ../src/ecflow/python/BoostPythonUtil.cpp
-  ../src/ecflow/python/ClientDoc.cpp
-  ../src/ecflow/python/DefsDoc.cpp
-  ../src/ecflow/python/EcfExt.cpp
-  ../src/ecflow/python/Edit.cpp
-  ../src/ecflow/python/ExportClient.cpp
-  ../src/ecflow/python/ExportCore.cpp
-  ../src/ecflow/python/ExportDefs.cpp
-  ../src/ecflow/python/ExportNode.cpp
-  ../src/ecflow/python/ExportNodeAttr.cpp
-  ../src/ecflow/python/ExportSuiteAndFamily.cpp
-  ../src/ecflow/python/ExportTask.cpp
-  ../src/ecflow/python/GlossaryDoc.cpp
-  ../src/ecflow/python/NodeAttrDoc.cpp
-  ../src/ecflow/python/NodeUtil.cpp
-  ../src/ecflow/python/Trigger.cpp
-)
-
-# =====================================================================
-# tests
-# =====================================================================
-set(u_tests
-  py_u_test_add
-  py_u_test_collection
-  py_u_test_cron
-  py_u_test_defs_constructor
-  py_u_test_get_attr
-  py_u_test_manual
-  py_u_test_late
-  py_u_test_replace_node
-  py_u_test_tutorial
-  py_u_TestAddDelete
-  py_u_TestAddDeleteFunc
-  py_u_TestAddNodeFunc
-  py_u_TestAutoAddExtern
-  py_u_TestCopy
-  py_u_TestDefs
-  py_u_TestDefsCheck
-  py_u_TestDerivable
-  py_u_TestEcf
-  py_u_TestError
-  py_u_TestFind
-  py_u_TestFlag
-  py_u_TestGetAllTasks
-  py_u_TestJobGeneration
-  py_u_TestParent
-  py_u_TestRemove
-  py_u_TestRepeatArithmetic
-  py_u_TestSimulator
-  py_u_TestTraversal
-  py_u_TestUserManual
-  py_u_TestWith
-  py_u_sort
-)
-
-set(s_tests
-  s_TestClientApi
-  s_TestPythonChildApi
-)
-
-
-message( STATUS "====================================================================================================================" )
-message( STATUS "PYTHON2" )
-message( STATUS "====================================================================================================================" )
-if(${CMAKE_VERSION} VERSION_LESS "3.12.0") 
-  # We only support python2 extension for cmake less 3.12.0
-  # cmake 3.12.0 or greater allows multiple boost python libs & hence multiple extensions to be built
-  # Using -DPYTHON_EXECUTABLE=/usr/local/apps/python3/3.6.5-01/bin/python3 is not sufficient as the wrong(python2) libs are found
-  ecbuild_find_python( VERSION 2.6 REQUIRED )  
-  message( STATUS "  PYTHON_FOUND                      : ${PYTHON_FOUND}" )
-  message( STATUS "  PYTHONINTERP_FOUND                : ${PYTHONINTERP_FOUND}" )
-  message( STATUS "  PYTHONLIBS_FOUND                  : ${PYTHONLIBS_FOUND}" )
-  message( STATUS "  PYTHON_VERSION_STRING             : ${PYTHON_VERSION_STRING}" )
-  message( STATUS "  PYTHON_VERSION_MAJOR              : ${PYTHON_VERSION_MAJOR}" )
-  message( STATUS "  PYTHON_VERSION_MINOR              : ${PYTHON_VERSION_MINOR}" )
-  message( STATUS "  PYTHON_VERSION_PATCH              : ${PYTHON_VERSION_PATCH}" )
-  message( STATUS "  PYTHON_CONFIG_EXECUTABLE          : ${PYTHON_CONFIG_EXECUTABLE}" )
-  message( STATUS "  PYTHON_EXECUTABLE                 : ${PYTHON_EXECUTABLE}" )
-  message( STATUS "  PYTHON_INCLUDE_DIRS               : ${PYTHON_INCLUDE_DIRS}" )
-  message( STATUS "  PYTHON_LIBRARIES                  : ${PYTHON_LIBRARIES}" )
-  if (${PYTHON_VERSION_MAJOR} EQUAL 3)
-    ecbuild_error("Need cmake version >= 3.12.0 to build ecflow python3 extension, current cmake version is ${CMAKE_VERSION}")
-  endif()
-
-  find_package( Boost ${ECFLOW_BOOST_VERSION} REQUIRED COMPONENTS python )
-  add_subdirectory( python2 )
-else()
-  # ======================================================================================
-  # Attempt to build both python2 *AND/OR* python3 ecflow extension, depending on what is found
-  # this assumes cmake 3.12.0 min, which added support for boost python2 and python3
-  # * NOTICE* that we do *NOT* use REQUIRED when searching for boost python libs
-  # ======================================================================================
-  find_package(Python2 COMPONENTS Interpreter Development)
-  if (Python2_FOUND)
-    message( STATUS "  Python2_Interpreter_FOUND         : ${Python2_Interpreter_FOUND}" )
-    message( STATUS "  Python2_EXECUTABLE                : ${Python2_EXECUTABLE}" )
-    message( STATUS "  Python2_STDLIB                    : ${Python2_STDLIB}    Standard platform independent installation directory" )
-    message( STATUS "  Python2_STDARCH                   : ${Python2_STDARCH}   Standard platform dependent installation directory." )
-    message( STATUS "  Python2_Development_FOUND         : ${Python2_Development_FOUND}" )
-    message( STATUS "  Python2_INCLUDE_DIRS              : ${Python2_INCLUDE_DIRS}" )
-    message( STATUS "  Python2_LIBRARIES                 : ${Python2_LIBRARIES}" )
-    message( STATUS "  Python2_LIBRARY_DIRS              : ${Python2_LIBRARY_DIRS}" )
-    message( STATUS "  Python2_VERSION                   : ${Python2_VERSION}" )
-    message( STATUS "  Python2_VERSION_MAJOR             : ${Python2_VERSION_MAJOR}" )
-    message( STATUS "  Python2_VERSION_MINOR             : ${Python2_VERSION_MINOR}" )
-    message( STATUS "  Python2_VERSION_PATCH             : ${Python2_VERSION_PATCH}" )
-    # *****************************************************************************************
-    # Although we have found python2 it could be that *ONLY* python3 was module loaded
-    # Otherwise will build for python2 and test with python3 interpreter
-    # *****************************************************************************************
-    if ( Python2_LIBRARIES )
-      ecbuild_find_python( VERSION 2.6 REQUIRED ) # if not included iterpreter not found ?
-      if ( ${PYTHON_VERSION_MAJOR} EQUAL 2)
-        message( STATUS "  PYTHON_FOUND                      : ${PYTHON_FOUND}" )
-        message( STATUS "  PYTHONINTERP_FOUND                : ${PYTHONINTERP_FOUND}" )
-        message( STATUS "  PYTHONLIBS_FOUND                  : ${PYTHONLIBS_FOUND}" )
-        message( STATUS "  PYTHON_VERSION_STRING             : ${PYTHON_VERSION_STRING}" )
-        message( STATUS "  PYTHON_VERSION_MAJOR              : ${PYTHON_VERSION_MAJOR}" )
-        message( STATUS "  PYTHON_VERSION_MINOR              : ${PYTHON_VERSION_MINOR}" )
-        message( STATUS "  PYTHON_VERSION_PATCH              : ${PYTHON_VERSION_PATCH}" )
-        message( STATUS "  PYTHON_CONFIG_EXECUTABLE          : ${PYTHON_CONFIG_EXECUTABLE}" )
-        message( STATUS "  PYTHON_EXECUTABLE                 : ${PYTHON_EXECUTABLE}" )
-        message( STATUS "  PYTHON_INCLUDE_DIRS               : ${PYTHON_INCLUDE_DIRS}" )
-        message( STATUS "  PYTHON_LIBRARIES                  : ${PYTHON_LIBRARIES}" )
-
-        if ( Boost_MINOR_VERSION GREATER 66 )
-          # cmake 3.15
-          # see: https://gitlab.kitware.com/cmake/cmake/issues/19656
-          # INTERFACE_LIBRARY targets may only have whitelisted properties."
-          set(ECFLOW_BOOST_PYTHON_COMPONENT python${Python2_VERSION_MAJOR}${Python2_VERSION_MINOR})
-        else()
-          set(ECFLOW_BOOST_PYTHON_COMPONENT python)
-        endif()
-        find_package( Boost ${ECFLOW_BOOST_VERSION} COMPONENTS ${ECFLOW_BOOST_PYTHON_COMPONENT} )
-
-        if (Boost_PYTHON_FOUND OR Boost_PYTHON${Python2_VERSION_MAJOR}${Python2_VERSION_MINOR}_FOUND)
-          # Indicate that both Python and Boost.Python have been found
-          set(ECF_PYTHON_FOUND "ECF_PYTHON_FOUND")
-          add_subdirectory( python2 )
-        else()
-          message( STATUS "  Boost python2 libraries *NOT* found" )
-        endif()
-      endif()
-    else()
-      message( STATUS "  Python2 libraries *NOT* found" )
-    endif()
-  endif()
-
-  message( STATUS "====================================================================================================================" )
-  message( STATUS "PYTHON3" )
-  message( STATUS "====================================================================================================================" )
-  # The python must include the Development packages. As the headers in these packages is used by boost python.
-  find_package(Python3 COMPONENTS Interpreter Development)
-  if (Python3_FOUND)
-    message( STATUS "  Python3_Interpreter_FOUND         : ${Python3_Interpreter_FOUND}" )
-    message( STATUS "  Python3_EXECUTABLE                : ${Python3_EXECUTABLE}" )
-    message( STATUS "  Python3_STDLIB                    : ${Python3_STDLIB}    Standard platform independent installation directory" )
-    message( STATUS "  Python3_STDARCH                   : ${Python3_STDARCH}   Standard platform dependent installation directory." )
-    message( STATUS "  Python3_Development_FOUND         : ${Python3_Development_FOUND}" )
-    message( STATUS "  Python3_INCLUDE_DIRS              : ${Python3_INCLUDE_DIRS}" )
-    message( STATUS "  Python3_LIBRARIES                 : ${Python3_LIBRARIES}" )
-    message( STATUS "  Python3_LIBRARY_DIRS              : ${Python3_LIBRARY_DIRS}" )
-    message( STATUS "  Python3_VERSION                   : ${Python3_VERSION}" )
-    message( STATUS "  Python3_VERSION_MAJOR             : ${Python3_VERSION_MAJOR}" )
-    message( STATUS "  Python3_VERSION_MINOR             : ${Python3_VERSION_MINOR}" )
-    message( STATUS "  Python3_VERSION_PATCH             : ${Python3_VERSION_PATCH}" )
-
-    # Set (deprecated) FindPython variables
-    # These need to be available, as they are used by `ecbuild_add_test(... TYPE PYTHON ...)`
-    set(PYTHONINTERP_FOUND "${Python3_Interpreter_FOUND}")
-    set(PYTHON_EXECUTABLE "${Python3_EXECUTABLE}")
-
-    if ( Boost_MINOR_VERSION GREATER 66 )
-      # cmake 3.15
-      # see: https://gitlab.kitware.com/cmake/cmake/issues/19656
-      # INTERFACE_LIBRARY targets may only have whitelisted properties.
-      set(ECFLOW_BOOST_PYTHON_COMPONENT python${Python3_VERSION_MAJOR}${Python3_VERSION_MINOR})
-    else()
-      set(ECFLOW_BOOST_PYTHON_COMPONENT python3)
-    endif()
-    find_package( Boost ${ECFLOW_BOOST_VERSION} COMPONENTS ${ECFLOW_BOOST_PYTHON_COMPONENT} )
-
-    if (Boost_PYTHON3_FOUND OR Boost_PYTHON${Python3_VERSION_MAJOR}${Python3_VERSION_MINOR}_FOUND)
-      # Indicate that both Python and Boost.Python have been found
-      set(ECF_PYTHON_FOUND "ECF_PYTHON_FOUND")
-      add_subdirectory( python3 )
-    else()
-      message( STATUS "  Boost python3 libraries *NOT* found" )
-    endif()
-  endif()
-  
-  if (NOT ECF_PYTHON_FOUND)
-    ecbuild_error("ecflow python extension is enabled, but python2/python3 libraries or python boost libraries not found")
-  endif()
-endif()
-message( STATUS "====================================================================================================================" )
-message( STATUS "END PYTHON" )
-message( STATUS "====================================================================================================================" )
diff -pruN 5.12.4-1/Pyext/ecflow/__init__.py 5.13.0-1/Pyext/ecflow/__init__.py
--- 5.12.4-1/Pyext/ecflow/__init__.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/ecflow/__init__.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-from .ecflow import *
-
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $ 
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0 
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-# In applying this licence, ECMWF does not waive the privileges and immunities 
-# granted to it by virtue of its status as an intergovernmental organisation 
-# nor does it submit to any jurisdiction.  
-
-"""
-The ecFlow python module
-"""
-
-__version__ = '5.12.4'
-
-# http://stackoverflow.com/questions/13040646/how-do-i-create-documentation-with-pydoc
diff -pruN 5.12.4-1/Pyext/ecflow/__init__.py.in 5.13.0-1/Pyext/ecflow/__init__.py.in
--- 5.12.4-1/Pyext/ecflow/__init__.py.in	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/ecflow/__init__.py.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-from .ecflow import *
-
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $ 
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0 
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-# In applying this licence, ECMWF does not waive the privileges and immunities 
-# granted to it by virtue of its status as an intergovernmental organisation 
-# nor does it submit to any jurisdiction.  
-
-"""
-The ecFlow python module
-"""
-
-__version__ = '@ecflow_VERSION@'
-
-# http://stackoverflow.com/questions/13040646/how-do-i-create-documentation-with-pydoc
diff -pruN 5.12.4-1/Pyext/migrate/abort_and_label_bug.def 5.13.0-1/Pyext/migrate/abort_and_label_bug.def
--- 5.12.4-1/Pyext/migrate/abort_and_label_bug.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/abort_and_label_bug.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-# 3.1.7
-defs_state MIGRATE state>:aborted flag:late,message state_change:983039 modify_change:1018
-  edit SLEEP '10'
-suite suite #  begun:1 state:aborted dur:01:29:57 flag:message,no_reque
-  defstatus suspended
-  edit ECF_EXTN '.sms'
-  clock real 
-  calendar initTime:2013-Sep-10 12:37:03 suiteTime:2013-Sep-10 15:56:00 duration:03:18:57 initLocalTime:2013-Sep-10 12:37:03 lastTime:2013-Sep-10 15:56:00 calendarIncrement:00:01:00
-  family family # state:aborted dur:02:18:57 flag:message
-    task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/task.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
-      edit VARIABLE 'VALUE'
-    task rescue # passwd:Bs7hroqB abort<:   Script for /suite/family/rescue cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/rescue.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
-      late -s +00:05 -c 00:05
-      complete task eq complete
-      trigger task == aborted
-    task step # passwd:4N9cOzVA abort<:   Script for /suite/family/step cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/step.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
-      trigger task:step le step:STEP
-      trigger -o task eq complete
-      repeat integer STEP 0 100
-    family loop_in_time # state:complete
-      defstatus complete
-      time 12:00
-      task hold # state:complete
-        complete 1==1
-        trigger 1==0
-    endfamily
-  endfamily
-  task household # passwd:31NZt9lV abort<:   Script for /suite/household cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/household.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:22:57 flag:task_aborted,no_script
-    cron 00:00 23:59 01:00 # nextTimeSlot/13:00
-  task monthly # state:queued
-    date 1.*.*
-  family remote # state:aborted dur:01:29:57 flag:message,no_reque suspended:1
-    edit ECF_TRIES '1'
-    family c2a # state:aborted dur:01:29:57 flag:no_reque
-      edit LOGDIR '/s2o1/emos_esuite/emos_data/log'
-      task sub # passwd:gyBC8q.O abort<: PID(28027)  path(/suite/remote/c2a/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos c2a /vol/emos_nc/output/suite/remote/c2a/sub.job1 /s2o1/emos_esuite/emos_data/log/suite/remote/c2a/sub.1 ]>abort try:1 state:aborted dur:01:29:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'c2a'
-    endfamily
-    family ecgate # state:aborted dur:02:02:57 flag:no_reque
-      task sub # passwd:6pIZXvrl abort<: PID(32480)  path(/suite/remote/ecgate/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos ecgate /vol/emos_nc/output/suite/remote/ecgate/sub.job1 /vol/emos_nc/output/suite/remote/ecgate/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'ecgate'
-    endfamily
-    family ibis # state:aborted dur:02:02:57 flag:no_reque
-      task sub # passwd:AEX5NtyU abort<: PID(32532)  path(/suite/remote/ibis/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos ibis /vol/emos_nc/output/suite/remote/ibis/sub.job1 /vol/emos_nc/output/suite/remote/ibis/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'ibis'
-    endfamily
-    family bilbo # state:aborted dur:02:02:57 flag:no_reque
-      task sub # passwd:30IPtlxu abort<: PID(32543)  path(/suite/remote/bilbo/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos bilbo /vol/emos_nc/output/suite/remote/bilbo/sub.job1 /vol/emos_nc/output/suite/remote/bilbo/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'bilbo'
-    endfamily
-  endfamily
-  family catchup2rt # state:aborted dur:03:18:57 flag:message suspended:1
-    task doer # passwd:OXQkmELW abort<:   Script for /suite/catchup2rt/doer cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/catchup2rt/doer.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:1 state:aborted dur:03:18:57 flag:task_aborted,no_script,message,no_reque
-      complete timer eq complete
-      trigger 1==0
-  endfamily
-endsuite
-#
-# Label that spans multiple lines
-suite made_up
-    label info "110 nodes for 1 minutes in 55 minutes, emos12Aeda"
-    label info1 "((11*10*64)) for 30"
-    label info2 ""
-    label info3 "have you? set START_LOBSVR=1 in the task, once, to launch the logserver,
-setup ssh login
-created remote /tmp/map/cray"
-  zombie ecf:fob:label:3600 
-endsuite
diff -pruN 5.12.4-1/Pyext/migrate/aborted_reason_bug.def 5.13.0-1/Pyext/migrate/aborted_reason_bug.def
--- 5.12.4-1/Pyext/migrate/aborted_reason_bug.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/aborted_reason_bug.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,82 +0,0 @@
-# 3.1.7
-defs_state MIGRATE state>:aborted flag:late,message state_change:983039 modify_change:1018
-  edit SLEEP '10'
-suite suite #  begun:1 state:aborted dur:01:29:57 flag:message,no_reque
-  defstatus suspended
-  edit ECF_EXTN '.sms'
-  clock real 
-  calendar initTime:2013-Sep-10 12:37:03 suiteTime:2013-Sep-10 15:56:00 duration:03:18:57 initLocalTime:2013-Sep-10 12:37:03 lastTime:2013-Sep-10 15:56:00 calendarIncrement:00:01:00
-  family family # state:aborted dur:02:18:57 flag:message
-    task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/task.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
-      edit VARIABLE 'VALUE'
-    task rescue # passwd:Bs7hroqB abort<:   Script for /suite/family/rescue cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/rescue.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
-      late -s +00:05 -c 00:05
-      complete task eq complete
-      trigger task == aborted
-    task step # passwd:4N9cOzVA abort<:   Script for /suite/family/step cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/step.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
-      trigger task:step le step:STEP
-      trigger -o task eq complete
-      repeat integer STEP 0 100
-    family loop_in_time # state:complete
-      defstatus complete
-      time 12:00
-      task hold # state:complete
-        complete 1==1
-        trigger 1==0
-    endfamily
-  endfamily
-  task household # passwd:31NZt9lV abort<:   Script for /suite/household cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/household.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:2 state:aborted dur:02:22:57 flag:task_aborted,no_script
-    cron 00:00 23:59 01:00 # nextTimeSlot/13:00
-  task monthly # state:queued
-    date 1.*.*
-  family remote # state:aborted dur:01:29:57 flag:message,no_reque suspended:1
-    edit ECF_TRIES '1'
-    family c2a # state:aborted dur:01:29:57 flag:no_reque
-      edit LOGDIR '/s2o1/emos_esuite/emos_data/log'
-      task sub # passwd:gyBC8q.O abort<: PID(28027)  path(/suite/remote/c2a/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos c2a /vol/emos_nc/output/suite/remote/c2a/sub.job1 /s2o1/emos_esuite/emos_data/log/suite/remote/c2a/sub.1 ]>abort try:1 state:aborted dur:01:29:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'c2a'
-    endfamily
-    family ecgate # state:aborted dur:02:02:57 flag:no_reque
-      task sub # passwd:6pIZXvrl abort<: PID(32480)  path(/suite/remote/ecgate/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos ecgate /vol/emos_nc/output/suite/remote/ecgate/sub.job1 /vol/emos_nc/output/suite/remote/ecgate/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'ecgate'
-    endfamily
-    family ibis # state:aborted dur:02:02:57 flag:no_reque
-      task sub # passwd:AEX5NtyU abort<: PID(32532)  path(/suite/remote/ibis/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos ibis /vol/emos_nc/output/suite/remote/ibis/sub.job1 /vol/emos_nc/output/suite/remote/ibis/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'ibis'
-    endfamily
-    family bilbo # state:aborted dur:02:02:57 flag:no_reque
-      task sub # passwd:30IPtlxu abort<: PID(32543)  path(/suite/remote/bilbo/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos bilbo /vol/emos_nc/output/suite/remote/bilbo/sub.job1 /vol/emos_nc/output/suite/remote/bilbo/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
-        edit SCHOST 'bilbo'
-    endfamily
-  endfamily
-  family catchup2rt # state:aborted dur:03:18:57 flag:message suspended:1
-    task doer # passwd:OXQkmELW abort<:   Script for /suite/catchup2rt/doer cannot be found:
-   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/catchup2rt/doer.sms) does not exist:
-   Variable ECF_FETCH not defined:
-   Variable ECF_FILES not defined:
-   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
->abort try:1 state:aborted dur:03:18:57 flag:task_aborted,no_script,message,no_reque
-      complete timer eq complete
-      trigger 1==0
-  endfamily
-endsuite
diff -pruN 5.12.4-1/Pyext/migrate/ecflow_migrate.py 5.13.0-1/Pyext/migrate/ecflow_migrate.py
--- 5.12.4-1/Pyext/migrate/ecflow_migrate.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/ecflow_migrate.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,421 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# 
-# Handle bugs, produced by old versions of ecflow_client --migrate
-#   - Mostly to do with handling newlines
-#
-
-import os          # for getenv
-import shutil      # used to remove directory tree
-#import argparse   # requires python 2.7
-import getopt, sys # for argument parsing  
-
-class Migrator(object):
-    def __init__(self, list_of_input_lines):
-        self.list_of_input_lines =  list_of_input_lines
-        self.list_of_output_lines = []
-        
-    def _migration_hook(self,default_version_number):
-        """Derived suite should override this function to perform the migration
-        """
-        return False;
-    
-    def output_lines(self):
-        return self.list_of_output_lines
-    
-    def migrate(self, default_version_number):
-        """Template/skeleton function, which will call the hooks
-        """
-        version = self.version_number_as_integer(default_version_number) 
-        if version >= default_version_number:
-            self.list_of_output_lines = self.list_of_input_lines
-            return False
-
-        self.list_of_output_lines = [] 
-        migrated = self._migration_hook(default_version_number)
-        if migrated : 
-            self.list_of_input_lines = self.list_of_output_lines   # preserve this migration
-            print("Applying ", type(self).__name__)  
-        else:
-            self.list_of_output_lines = self.list_of_input_lines   
-        return migrated         
-
-    def version_number_as_integer(self,default_version):
-        """Determine the version number used in ecflow_client --migrate
-           This should be in the very first line
-           # 3.1.8
-        """
-        if len(self.list_of_input_lines) > 0:
-            tokens = self.list_of_input_lines[0].split()
-            if len(tokens) > 1:
-                # print(tokens)
-                version = (int)(tokens[1].replace(".",""))
-                # print("******************* found version " , str(version))
-                return version;
-        return default_version
-    
-    
-class MigrateForTaskAbort(Migrator):
-    """Fix bug where the task abort states(i.e a string) will contain new lines and hence
-       spill over the next line, and affecting the parser. This will move the abort string
-       into the same line, and remove the interleaving new lines
-    """
-    def __init__(self, list_of_input_lines):
-        Migrator.__init__(self, list_of_input_lines)
- 
-    def _migration_hook(self,default_version_number):
-        """
-        The correct format is: where abort state is on the same line
-        task task # passwd:jxX0gIbR abort<: reason for abort >abort:
-        ensure_start_abort_and_end_abort_on_sameline
-        """
-        migrated = False
-        start_line_append = ""
-        for line in self.list_of_input_lines:
-            # process line
-            end_abort_pos = line.find(">abort")
-            task_pos = line.find("task")
-            if task_pos != -1:
-                start_abort_pos = line.find("abort<:")
-                if start_abort_pos != -1 and end_abort_pos != -1:
-                    # start and end found on same line. This is the correct format
-                    start_line_append = ""
-                
-                if start_abort_pos != -1 and end_abort_pos == -1:
-                    # print("start abort found with no end abort")
-                    start_line_append = line
-                    start_line_append = start_line_append.rstrip('\n')
-                    start_line_append += " "
-                    migrated = True
-                    continue
-    
-            if len(start_line_append) > 0:
-                start_line_append += line
-                if end_abort_pos != -1:
-                    self.list_of_output_lines.append(start_line_append) # preserve'\n' for this case                   
-                    # print(start_line_append)
-                    start_line_append = "";
-                else:
-                    start_line_append = start_line_append.rstrip('\n')
-                    start_line_append += " "
-    
-                continue;
-                  
-            self.list_of_output_lines.append(line)
-           
-        return migrated  
-    
-    
-class MigrateForLabel(Migrator):
-    """Fix bug where label value has new lines, and hence spills over to next line
-       This will remove place newline back onto the same line
-    """
-    def __init__(self, list_of_input_lines):
-        Migrator.__init__(self, list_of_input_lines)
- 
-    def _migration_hook(self,default_version_number):
-        """
-        The correct format is where label in on the same line
-            label name "value" # "new value"
-        However if the value or new value has new line it can mess up the parsing
-            label info "have you? set START_LOBSVR=1 in the task, once, to launch the logserver,
-    setup ssh login
-    created remote /tmp/map/cray"
-        """
-        #count = 0;
-        no_of_label_quotes = 0
-        migrated = False
-        start_line_append = ""
-        for line in self.list_of_input_lines:
-            #count =  count + 1
-            #print(str(count) , ": " , line)
-            #if count == 383119:
-            #    print("debug mee")
-            if len(start_line_append) > 0:
-                no_of_label_quotes += line.count('"')
-                start_line_append += line
-                if no_of_label_quotes % 2 == 0:
-                    # even number of quotes
-                    self.list_of_output_lines.append(start_line_append) # preserve last '\n'  
-                    start_line_append = ""
-                    no_of_label_quotes = 0 
-                else:
-                    start_line_append = start_line_append.rstrip('\n')
-                continue            
-            else:
-            
-                # process line
-                tokens = line.split()
-                if len(tokens) >0 and tokens[0] == "label":
-                    no_of_label_quotes = line.count('"')
-                    if no_of_label_quotes % 2 != 0 : 
-                        start_line_append = line
-                        start_line_append = start_line_append.rstrip('\n')
-                        migrated = True
-                        continue
-                  
-            self.list_of_output_lines.append(line)
-           
-        return migrated
-     
-class MigrateForVariable(Migrator):
-    """Fix bug where variable value has new lines, and hence spills over to next line
-       This will remove place newline back onto the same line
-    """
-    def __init__(self, list_of_input_lines):
-        Migrator.__init__(self, list_of_input_lines)
- 
-    def _migration_hook(self,default_version_number):
-        """
-        The correct format is where variable in on the same line
-            edit EMOS_TYPE '  family prod_wparam
-  endfamily
-'         
-        """
-        #count = 0;
-        no_of_label_quotes = 0
-        migrated = False
-        start_line_append = ""
-        for line in self.list_of_input_lines:
-            #count =  count + 1
-            #print(str(count) , ": " , line)
-            #if count == 383119:
-            #    print("debug mee")
-            if len(start_line_append) > 0:
-                no_of_label_quotes += line.count("'")
-                start_line_append += line
-                if no_of_label_quotes % 2 == 0:
-                    # even number of quotes
-                    self.list_of_output_lines.append(start_line_append) # preserve last '\n'  
-                    start_line_append = ""
-                    no_of_label_quotes = 0 
-                else:
-                    start_line_append = start_line_append.rstrip('\n')
-                continue            
-            else:
-            
-                # process line, avoid ECF_URL_CMD as that could by error have uneven number of "'' i.e
-                #   edit ECF_URL_CMD '${BROWSER:=firefox} -new-tab %URL%'
-                # hence we use 
-                #    if no_of_label_quotes == 1: 
-                # instead of
-                #    if no_of_label_quotes % 2 == 0:
-                tokens = line.split()
-                if len(tokens) >= 3 and tokens[0] == "edit":
-                    no_of_label_quotes = line.count("'")
-                    if no_of_label_quotes == 1: 
-                        start_line_append = line
-                        start_line_append = start_line_append.rstrip('\n')
-                        migrated = True
-                        continue
-                  
-            self.list_of_output_lines.append(line)
-           
-        return migrated
-     
-     
-class MigrateForHistory(Migrator):
-    """Fix bug where history spans multiple lines.  
-       See File: history_bug.def
-    """
-    def __init__(self, list_of_input_lines):
-        Migrator.__init__(self, list_of_input_lines)
- 
-    def _migration_hook(self,default_version_number):
-        """
-        The history should all be on one line
-            defs_state MIGRATE state>:queued flag:message state_change:1500811 modify_change:48
-            edit ECF_LOG '/vol/emos_nc/output/ecflow/vali.21801.ecf.log'
-            edit SMSNAME '0'
-            history /s2s_devel/ecmf/back MSG:[15:53:06 21.10.2014] --replace=/s2s_devel/ecmf/back s2s_devel.def parent  :emos
-            history /s2s_devel/ecmf/enfh MSG:[13:45:53 12.11.2014] -alter change label last_run 20140929
-            20141002
-            20141016
-            20141023 /s2s_devel/ecmf/enfh/  :emos    MSG:[14:05:53 14.11.2014] --requeue force /s2s_devel/ecmf/enfh  :emos
-            history /s2s_devel/ecmf/enfh/back MSG:[13:38:30 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emos
-            suite limits #  begun:1 state:complete flag:message suspended:1
-            endsuite
-        """
-        migrated = False
-        history_started = False
-        for line in self.list_of_input_lines:
-            # process line
-            tokens = line.split()
-            if len(tokens) >= 2 and tokens[0] == "suite":
-                history_started = False
-
-            if not history_started and len(tokens) >= 2 and tokens[0] == "history":
-                history_started = True
- 
-            if history_started:
-                # append to previous line
-                if len(tokens) >= 1 and tokens[0] != "history":
-                    # get last line of output lines, string the new line and append
-                    self.list_of_output_lines[-1] = self.list_of_output_lines[-1].rstrip()
-                    self.list_of_output_lines[-1] = self.list_of_output_lines[-1] + line
-                    migrated = True
-                    continue;
-                  
-            self.list_of_output_lines.append(line)
-           
-        return migrated  
-    
-    
-def do_migrate(defs_file):
-    
-    migration_count = 0
-    fileName, fileExtension = os.path.splitext(defs_file)
-    output_file_name = fileName + ".mig";
-    
-    input_file_object = open(defs_file,'r')
-    output_file_object = open(output_file_name,'w')
-    try:
-        list_of_input_lines = input_file_object.readlines()  # preserves new lines, we want this
-        
-        list_of_output_lines = []
-        abort_migrator = MigrateForTaskAbort(list_of_input_lines)
-        if abort_migrator.migrate(401):
-            migration_count += 1
-            # did migration, update input lines for next migration
-            list_of_input_lines = abort_migrator.output_lines()
-        list_of_output_lines = abort_migrator.output_lines()
-         
-         
-        label_migrator = MigrateForLabel(list_of_input_lines)
-        if label_migrator.migrate(319):
-            migration_count += 1
-            # did migration, update input lines for next migration
-            list_of_input_lines = label_migrator.output_lines()
-        list_of_output_lines = label_migrator.output_lines()
-
-
-        variable_migrator = MigrateForVariable(list_of_input_lines)
-        if variable_migrator.migrate(401):
-            migration_count += 1
-            # did migration, update input lines for next migration
-            list_of_input_lines = variable_migrator.output_lines()
-        list_of_output_lines = variable_migrator.output_lines()
-        
-        
-        variable_migrator = MigrateForHistory(list_of_input_lines)
-        if variable_migrator.migrate(406):
-            migration_count += 1
-            # did migration, update input lines for next migration
-            list_of_input_lines = variable_migrator.output_lines()
-        list_of_output_lines = variable_migrator.output_lines()
-            
-        output_file_object.writelines(list_of_output_lines)
-    finally:
-        input_file_object.close()
-        output_file_object.close()
-        
-    return migration_count 
-
-def usage():
-    DESC = """\nThis python file is used to *FIX* migration bugs, when migrating from one release of ecflow to another.
-
- Migration may be required when the release number changes:
- <release-number>.<major>.<minor>
-    6.1.7   ->  7.0.0
- as the checkpoint files *may* not be compatible. 
-        
- This can be *checked* before hand. By attempting to load the check pt into the new server. 
- On the old server run:
-    ecflow_client --check_pt  # this will write out a checkpt file  
- Now copy this file to a separate directory, and start the *new* server using the same port number
- If no errors are reported, you do not need to migrate.  
- If loading the checkpt file into the new server fails for any reason then
- then please follow these steps.
-
- Steps for Old server:
-   o shutdown
-        # ecflow_client --shutdown
-   o suspend all suites
-        # CL="ecflow_client --port=32222 --host=vsms1"
-        # for s in $($CL --suites); do $CL --suspend=/$s; done
-   o wait for active/submitted tasks to complete
-   o halt the server
-        # ecflow_client --halt=yes
-   o Use --migrate to dump state and structure to a file
-        # ecflow_client --migrate > all_suites.def
-   o terminate server *or* leave server running but start new server on different machine
-     to avoid port number clash.
-   o remove checkpt and backup checkpt files, to prevent new server from loading them
-     *Only* applicable if starting new server on same machine
-   o Run this script 
-     python ecflow_migrate.py -d all_suites.def
-     This will fix any issues associated with reloading this defs into the new server.
-     It write a file called 'all_suites.mig', which we will need to load into the new server. 
-     See below.
-
- Steps for New server:
-   o start server
-   o load the migration file
-       # ecflow_client --load all_suites.mig
-   o set server running:
-       # ecflow_client --restart
-   o resume suspended suites
-       # CL="ecflow_client --port=32222 --host=vsms1"
-       # for s in $($CL --suites); do $CL --resume=/$s; done
-
-
- There could be bugs with *old* "ecflow_client --migrate > all_suites.def"
- This file, will fix any bugs associated --migrate, so that the subsequent
- load with  *new* client (ecflow_client --load all_suites.mig) will work
-
- Usage:
-    python ecflow_migrate.py --defs_file <filename>
-    python ecflow_migrate.py --d <filename>
-    python ecflow_migrate.py --defs_file all_suites.def 
-    
-    The fixed definition is written as filename.mig, i.e. all_suites.mig
-    """
-    return DESC;
-    
-    
-if __name__ == "__main__":
-    
-#     PARSER = argparse.ArgumentParser(description=usage(),  
-#                                      formatter_class=argparse.RawDescriptionHelpFormatter)
-#     PARSER.add_argument('defs_file',  help="The definition file to *fix* for migration")
-#     ARGS = PARSER.parse_args()
-#     ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
-#     print(ARGS)    
-#     do_migrate( ARGS.defs_file )
-    
-    try:
-        opts, args = getopt.getopt(sys.argv[1:], "hd", ["help", "defs_file="])
-    except getopt.GetoptError as err:
-        # print("help information and exit:")
-        print(err) # will print something like "option -a not recognised"
-        print(usage())
-        sys.exit(2)
-        
-    defs_file = None
-    for o, a in opts:
-        if o in ("-h", "--help"):
-            print(usage())
-            sys.exit()
-        elif o in ("-d", "--defs_file"):
-            defs_file = a
-        else:
-            assert False, "un-handled option"
-    
-    if defs_file is None:
-        print("Please enter path to the defs file i.e ecflow_migrate --d ./defs_file.def")
-        sys.exit(1)
-        
-    defs_file = os.path.expandvars(defs_file); # expand references to any environment variables
-    do_migrate( defs_file )
diff -pruN 5.12.4-1/Pyext/migrate/history_bug.def 5.13.0-1/Pyext/migrate/history_bug.def
--- 5.12.4-1/Pyext/migrate/history_bug.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/history_bug.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,18 +0,0 @@
-# 4.0.1
-defs_state MIGRATE state>:queued flag:message state_change:1500811 modify_change:48
-  edit ECF_LOG '/vol/emos_nc/output/ecflow/vali.21801.ecf.log'
-  edit SMSNAME '0'
-  history /s2s_devel/ecmf/back MSG:[15:53:06 21.10.2014] --replace=/s2s_devel/ecmf/back s2s_devel.def parent  :emos
-  history /s2s_devel/ecmf/enfh MSG:[13:45:53 12.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[13:45:53 12.11.2014] --alter change label next_run 99999999 /s2s_devel/ecmf/enfh/  :emosMSG:[16:54:11 12.11.2014] --alter change label last_run 20140929
-20141002
-20141016
-20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[16:54:11 12.11.2014] --alter change label next_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[16:58:54 12.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[16:58:54 12.11.2014] --alter change label next_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[17:01:39 12.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[17:01:39 12.11.2014] --alter change label next_run 20141027 /s2s_devel/ecmf/enfh/  :emosMSG:[14:17:38 13.11.2014] --resume  :marmMSG:[14:27:42 13.11.2014] --resume  :marmMSG:[14:44:53 13.11.2014] --resume  :marmMSG:[16:36:20 13.11.2014] --resume  :marmMSG:[16:42:34 13.11.2014] --resume  :marmMSG:[10:54:42 14.11.2014] --resume  :marmMSG:[11:07:40 14.11.2014] --alter change label next_run 20141030 /s2s_devel/ecmf/enfh  :emosMSG:[11:07:40 14.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh  :emosMSG:[11:07:40 14.11.2014] --requeue force /s2s_devel/ecmf/enfh  :emosMSG:[11:29:28 14.11.2014] --resume  :marmMSG:[11:46:15 14.11.2014] --resume  :marmMSG:[14:05:53 14.11.2014] --requeue force /s2s_devel/ecmf/enfh  :emos
-  history /s2s_devel/ecmf/enfh/back MSG:[13:38:30 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[15:14:11 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[15:15:54 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[15:18:10 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[16:21:22 11.11.2014] --requeue force /s2s_devel/ecmf/enfh/back  :marmMSG:[16:28:32 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[17:01:18 13.11.2014] --replace=/s2s_devel/ecmf/enfh/back s2s_devel.def parent  :emosMSG:[10:53:07 14.11.2014] --replace=/s2s_devel/ecmf/enfh/back s2s_devel.def parent  :emos
-suite limits #  begun:1 state:complete flag:message suspended:1
-  defstatus complete
-  limit archive 3
-  calendar initTime:2014-Feb-20 09:26:31 suiteTime:2014-Sep-24 13:36:00 duration:6484:09:29 initLocalTime:2014-Feb-20 09:26:31 lastTime:2014-Nov-17 13:36:00 calendarIncrement:00:01:00
-endsuite
-suite tigge_lam #  begun:1 state:queued dur:9742:11:35 flag:message,no_reque suspended:1
-  defstatus suspended
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/migrate/label_bug.def 5.13.0-1/Pyext/migrate/label_bug.def
--- 5.12.4-1/Pyext/migrate/label_bug.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/label_bug.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-# 3.1.7
-defs_state MIGRATE state>:aborted flag:late,message state_change:2058963 modify_change:1954
-  edit ECF_INCLUDE '/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/includes'
-  history /test MSG:[11:40:24 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:41:01 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:51:53 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:52:53 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:53:24 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:54:51 20.9.2013] --replace=/test <empty> parent  :map
-suite made_up
-    label info ""
-    label info "have you? set START_LOBSVR=1 in the task, once, to launch the logserver,
-setup ssh login
-created remote /tmp/map/cray"
-  zombie ecf:fob:label:3600 
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/migrate/no_migration.def 5.13.0-1/Pyext/migrate/no_migration.def
--- 5.12.4-1/Pyext/migrate/no_migration.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/no_migration.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-# 3.1.7
-defs_state MIGRATE state>:aborted flag:late,message state_change:983039 modify_change:1018
-  edit SLEEP '10'
-suite suite #  begun:1 state:aborted dur:01:29:57 flag:message,no_reque
-   task a
-   task b
-endsuite
-suite made_up
-   task a
-   task b
-endsuite
diff -pruN 5.12.4-1/Pyext/migrate/py_u_TestMigrate.py 5.13.0-1/Pyext/migrate/py_u_TestMigrate.py
--- 5.12.4-1/Pyext/migrate/py_u_TestMigrate.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/py_u_TestMigrate.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,192 +0,0 @@
-
-import os
-import ecflow_migrate
-import unittest
-import filecmp
-
-def get_parent_dir(file_path):
-    return os.path.dirname(file_path)
-
-def get_root_source_dir():
-    cwd = os.getcwd()
-    #print("get_root_source_dir from: " + cwd)
-    while (1):
-        # Get to directory that has ecflow
-        head, tail = os.path.split(cwd)
-        #print("   head:" + head)
-        #print("   tail:" + tail)
-        if tail.find("ecflow") != -1 :
-            
-            # bjam, already at the source directory
-            if os.path.exists(cwd + "/Jamroot.jam"): 
-                print("   Found Jamroot.jam in " + cwd)
-                return cwd
-        
-        if tail != "Pyext" and tail != "migrate":
-            # in cmake, we may be in the build directory, hence we need to determine source directory
-            file = cwd + "/CTestTestfile.cmake"
-            #print("   searching for " + file)
-            if os.path.exists(file):
-                # determine path by looking into this file:
-                for line in open(file):
-                    ## Source directory: /tmp/ma0/workspace/ecflow/ACore
-                    if line.find("Source directory"):
-                        tokens = line.split()
-                        if len(tokens) == 4:
-                            #print("   returning root_source_dir:", tokens[3])
-                            return tokens[3]
-                raise RuntimeError("ERROR could not find Source directory in CTestTestfile.cmake")
-            else:
-                raise RuntimeError("ERROR could not find file CTestTestfile.cmake in " + cwd)
-                
-        cwd = head
-    return cwd
-
-
-
-# These tests the migration for  ecflow < 318 to ecflow 318
-#
-# In ecflow_client --migrate, we can get abort reason to span multiple line, hence messing up load
-#
-class TestMigrate318(unittest.TestCase):
-    def setUp(self):
-        # perform setup actions if any
-        self.workspace_dir = get_root_source_dir()
-        #print("setup : " + self.workspace_dir)
-        
-    def tearDown(self):
-        # Perform clean -up actions if any
-        pass
-    
-    def locate(self,file):
-        return self.workspace_dir + "/Pyext/" + file
-    
-    def testMigrateVersionNumber(self):
-        list_of_defs_lines =[ "# 3.1.2"]
-  
-        mig = ecflow_migrate.Migrator(list_of_defs_lines)
-        self.assertEqual(mig.version_number_as_integer(0), 312,"expected version 3.1.2")
-  
-        list_of_defs_lines =[ "# "]
-        mig = ecflow_migrate.Migrator(list_of_defs_lines)
-        self.assertEqual(mig.version_number_as_integer(10), 10,"Expected 10, since valid version not provided")
-  
-    def test_no_migration(self):
-        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/no_migration.def"))
-        self.assertEqual(migration_count,0,"Expected no migration")
-        self.assertTrue(filecmp.cmp(self.locate("migrate/no_migration.def"),self.locate("migrate/no_migration.mig")))
-        # remove the generated file
-        try: os.remove(self.locate("migrate/no_migration.mig"))
-        except: pass
-   
-# ==============================================================================================
-    # Test for abort bug
-       
-    def test_normal_abort_case(self):
-        list_of_defs_lines = [ "# 3.1.2", "task task abort<: aa >abort\n" ]      
-        abort_migrator = ecflow_migrate.MigrateForTaskAbort(list_of_defs_lines)
-        abort_migrator.migrate(318)
-          
-        expected_output_lines = ["# 3.1.2", "task task abort<: aa >abort\n"]
-        self.assertEqual(abort_migrator.output_lines(),expected_output_lines)
-    
-    def test_task_abort_reason_bug_simple(self):
-        list_of_defs_lines = ["# 3.1.2", "task task abort<: aa\n",">abort\n" ] 
-        abort_migrator = ecflow_migrate.MigrateForTaskAbort(list_of_defs_lines)
-        abort_migrator.migrate(318)
-       
-        expected_output_lines = ["# 3.1.2","task task abort<: aa >abort\n"]
-        self.assertEqual(abort_migrator.output_lines(),expected_output_lines)
-   
-    def test_task_abort_reason_bug(self):
-        # In ecflow_client --migrate, we can get abort reason to span multiple line, hence messing up load
-        list_of_defs_lines = ["# 3.1.2","task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found:\n",
-                              "line2\n", "line3\n",">abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script\n" ]
-           
-        abort_migrator = ecflow_migrate.MigrateForTaskAbort(list_of_defs_lines)
-        abort_migrator.migrate(318)
-            
-        expected_output_lines = ["# 3.1.2","task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found: line2 line3 >abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script\n"]
-        self.assertEqual(abort_migrator.output_lines(),expected_output_lines)
-            
-    def test_migrate_abort_file(self):
-        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/aborted_reason_bug.def"))
-        self.assertEqual(migration_count,1,"Expected defs file to be migrated")
-                   
-        # remove the generated file
-        try: os.remove(self.locate("migrate/aborted_reason_bug.mig"))
-        except: pass
-           
-# ===============================================================================================
-   
-    def test_normal_label(self):
-        list_of_defs_lines = ["# 3.1.2","label name \"value\"\n" ]      
-  
-        migrator = ecflow_migrate.MigrateForLabel(list_of_defs_lines)
-        migrator.migrate(319)
-      
-        expected_output_lines = ["# 3.1.2","label name \"value\"\n" ]
-        self.assertEqual(migrator.output_lines(),expected_output_lines)
-   
-    def test_label_over_multiple_lines(self):
-        list_of_defs_lines = ["# 3.1.2","label name \"value1\n", "value2\n", "value3\"\n" ]  
-          
-        migrator = ecflow_migrate.MigrateForLabel(list_of_defs_lines)
-        migrator.migrate(319)
-      
-        expected_output_lines = ["# 3.1.2","label name \"value1value2value3\"\n" ]
-        self.assertEqual(migrator.output_lines(),expected_output_lines)
-          
-    def test_label_over_multiple_lines_with_state(self):
-        list_of_defs_lines = ["# 3.1.2","label name \"value1\n", "value2\n", "value3\" # \"value4\n", "value5\"\n" ]  
-          
-        migrator = ecflow_migrate.MigrateForLabel(list_of_defs_lines)
-        migrator.migrate(319)
-      
-        expected_output_lines = ["# 3.1.2","label name \"value1value2value3\" # \"value4value5\"\n" ]
-        self.assertEqual(migrator.output_lines(),expected_output_lines)
-   
-   
-    def test_migrate_label_file(self):
-        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/label_bug.def"))
-        self.assertEqual(migration_count,1,"Expected defs file to be migrated")
-                   
-        # remove the generated file
-        try: os.remove(self.locate("migrate/label_bug.mig"))
-        except: pass
-  
-    def test_migrate_variable_file(self):
-        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/variable_bug.def"))
-        self.assertEqual(migration_count,1,"Expected defs file to be migrated")
-                   
-        # remove the generated file
-        try: os.remove(self.locate("migrate/variable_bug.mig"))
-        except: pass
-   
-# ====================================================================================================
-# test both together
-   
-    def test_migrate_abort_and_label(self):
-        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/abort_and_label_bug.def"))
-        self.assertEqual(migration_count,2,"Expected 2 migrations, one for abort and one for label")
-                   
-        # remove the generated file
-        try: os.remove(self.locate("migrate/abort_and_label_bug.mig"))
-        except: pass
-           
-#====================================================================================================
-#test history
- 
-    def test_migrate_history(self):
-        print("test_migrate_history")
-        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/history_bug.def"))
-        self.assertEqual(migration_count,1,"Expected 1 migrations,for history")
-                 
-        # remove the generated file
-        try: os.remove(self.locate("migrate/history_bug.mig"))
-        except: pass
-
-#run the tests 
-if __name__  == '__main__':
-    #print("Current working directory: " + os.getcwd())
-    unittest.main()
diff -pruN 5.12.4-1/Pyext/migrate/variable_bug.def 5.13.0-1/Pyext/migrate/variable_bug.def
--- 5.12.4-1/Pyext/migrate/variable_bug.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/migrate/variable_bug.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-# 3.0.0
-suite s
-   task q2diss
-      defstatus complete
-      late -s +00:05 -c +00:15
-      trigger pdb==complete 
-      edit ECF_URL_CMD '${BROWSER:=firefox} -new-tab %URL%'
-      edit EMOS_TYPE '  family prod_wparam
-  endfamily
-'
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/python2/CMakeLists.txt 5.13.0-1/Pyext/python2/CMakeLists.txt
--- 5.12.4-1/Pyext/python2/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/python2/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,180 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-ecbuild_add_library(
-  TARGET
-    ecflow2
-  NOINSTALL
-  TYPE MODULE
-  SOURCES
-    ${srcs}
-  PRIVATE_INCLUDES
-    ../src
-  PUBLIC_LIBS
-    libclient
-    libsimulator
-    base
-    node
-    attributes
-    core
-    Python2::Python
-    Boost::${ECFLOW_BOOST_PYTHON_COMPONENT}
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-  CXXFLAGS
-    $<$<CXX_COMPILER_ID:Clang>:-Wno-macro-redefined>
-)
-
-target_clangformat(ecflow2)
-
-#
-# Override default behaviour that add RPATHS during install
-# The only thing that seem to work is set INSTALL_RPATH to ""
-# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
-# had no effect
-#         
-# by default cmake add prefix 'lib', we don't want this hence disable
-#
-# To avoid duplicate target names we chose to name the targets: ecflow2/ecflow3.
-# however test and user code  depend on name 'ecflow', hence we rename the output to 'cflow'
-set_target_properties(ecflow3
-  PROPERTIES
-    OUTPUT_NAME "ecflow"
-    PREFIX ""
-    INSTALL_RPATH ""
-)
-
-# =====================================================================
-# tests
-
-foreach( test ${u_tests} )
-  ecbuild_add_test(
-    TARGET
-      py2_${test}
-    LABELS
-      python nightly
-    TYPE PYTHON
-    ARGS
-      ${CMAKE_CURRENT_SOURCE_DIR}/../test/${test}.py
-    ENVIRONMENT
-      "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
-    TEST_DEPENDS
-      u_base
-  )
-endforeach()
-
-
-if ( ENABLE_ALL_TESTS AND ENABLE_SERVER)
-
-  foreach( test ${s_tests} )
-    ecbuild_add_test(
-      TARGET
-        py2_${test}
-      LABELS
-        python nightly
-      TYPE PYTHON
-      ARGS
-        ${CMAKE_CURRENT_SOURCE_DIR}/../test/${test}.py
-      ENVIRONMENT
-        "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
-      TEST_DEPENDS
-        u_base
-    )
-  endforeach()
-  
-  set_property(TEST py2_s_TestClientApi      APPEND PROPERTY DEPENDS s_test)
-  set_property(TEST py2_s_TestPythonChildApi APPEND PROPERTY DEPENDS py_s_TestClientApi)
-endif()
-
-
-# ==========================================================================
-# install
-#    -DCMAKE_PYTHON_INSTALL_TYPE = [ local | setup | not defined ]
-#
-#    local | not defined : this will install to:
-#                          $INSTALL_PREFIX/$release.$major.$minor/lib/python2.7/site-packages/ecflow/
-#    setup               : experimental only,python way of installing
-#
-#    -DCMAKE_PYTHON_INSTALL_PREFIX should *only* used when using python setup.py (CMAKE_PYTHON_INSTALL_TYPE=setup)
-#    *AND* for testing python install to local directory
-#
-# Note:  To install only the python module
-#       cd  buildir
-#       cmake -DCMAKE_INSTALL_PREFIX=$INSTALL_DIR -DCOMPONENT=python -P cmake_install.cmake -- make install
-# ==========================================================================
-
-if( CMAKE_PYTHON_INSTALL_TYPE MATCHES  "local"  OR NOT DEFINED CMAKE_PYTHON_INSTALL_TYPE )
-
-  message(STATUS "python install *LOCAL* +++ lib/python${PYTHON_VERSION_MAJOR}.${PYTHON_VERSION_MINOR}/site-packages/ecflow +++++++")
-  if( NOT INSTALL_PYTHON2_DIR )
-    set(PYTHON_SITE "lib/python${PYTHON_VERSION_MAJOR}.${PYTHON_VERSION_MINOR}/site-packages" )
-  else()
-    # Resolve ${VAR} in the value provided
-    string(CONFIGURE "${INSTALL_PYTHON2_DIR}" PYTHON_SITE)
-  endif()
-  set(PYTHON_DEST "${PYTHON_SITE}/ecflow" )
-
-  install(
-    TARGETS
-      ecflow2
-    DESTINATION
-      ${PYTHON_DEST}
-    RENAME
-      ecflow.so
-    COMPONENT
-      python
-  )
-  install(
-    FILES
-      ../ecflow/__init__.py
-      ../samples/api/ecf.py
-      ../samples/api/sms2ecf.py
-    DESTINATION
-      ${PYTHON_DEST}
-    COMPONENT
-      python
-  )
-
-else()
-
-  message( STATUS "python found,  CMAKE_PYTHON_INSTALL_TYPE=${CMAKE_PYTHON_INSTALL_TYPE}")
-
-  # -------------------------------------------------------------------------------------
-  # Install using setup.py
-  # See: http://bloerg.net/2012/11/10/cmake-and-distutils.html
-  # -------------------------------------------------------------------------------------
-  message(STATUS "python install using *setup.py* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
-  message(STATUS "CMAKE_CURRENT_SOURCE_DIR=${CMAKE_CURRENT_SOURCE_DIR}")
-  message(STATUS "CMAKE_BINARY_DIR=${CMAKE_BINARY_DIR}")
-  message(STATUS "CMAKE_PYTHON_INSTALL_PREFIX : ${CMAKE_PYTHON_INSTALL_PREFIX}" )
-
-  set(SETUP_PY_IN "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py.in")
-  set(SETUP_PY    "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py")
-  set(DEPS        "${CMAKE_CURRENT_SOURCE_DIR}/../ecflow/__init__.py")
-  set(OUTPUT      "${CMAKE_CURRENT_SOURCE_DIR}/timestamp")
-
-  configure_file(${SETUP_PY_IN} ${SETUP_PY} )
-
-  add_custom_command(
-    OUTPUT ${OUTPUT}
-    COMMAND ${PYTHON} ${SETUP_PY} build
-    COMMAND ${CMAKE_COMMAND} -E touch ${OUTPUT}
-    DEPENDS ${DEPS}
-  )
-  add_custom_target(target ALL DEPENDS ${OUTPUT})
-
-  install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} build_ext)")
-
-  if( DEFINED CMAKE_PYTHON_INSTALL_PREFIX )
-    message(STATUS "custom/*test* python install prefix defined CMAKE_PYTHON_INSTALL_PREFIX=${CMAKE_PYTHON_INSTALL_PREFIX}")
-    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install -f --prefix=${CMAKE_PYTHON_INSTALL_PREFIX})")
-  else()
-    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install)")
-  endif()
-endif()
diff -pruN 5.12.4-1/Pyext/python3/CMakeLists.txt 5.13.0-1/Pyext/python3/CMakeLists.txt
--- 5.12.4-1/Pyext/python3/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/python3/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,191 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-#
-#   Important!
-#
-# Notice that ecflow Python module is linked with `Python3::Module` CMake imported target,
-# to enable a loose linkage with Python development libraries -- this is necessary in some
-# platforms, such as conda-forge+macOS.
-#
-# In practice, this implies that `-undefined` and `-dynamic_lookup` linkage flags are used
-# and the Python development libraries are not linked directly into the ecflow Python module.
-#
-
-ecbuild_add_library(
-  TARGET
-    ecflow3
-  NOINSTALL
-  TYPE MODULE
-  SOURCES
-    ${srcs}
-  PRIVATE_INCLUDES
-    ../src
-  PUBLIC_LIBS
-    libclient
-    libsimulator
-    base
-    node
-    attributes
-    core
-    Python3::Module
-    Boost::${ECFLOW_BOOST_PYTHON_COMPONENT}
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-  CXXFLAGS
-    $<$<CXX_COMPILER_ID:Clang>:-Wno-macro-redefined>
-)
-
-target_clangformat(ecflow3)
-
-#
-# Override default behaviour that add RPATHS during install
-# The only thing that seem to work is set INSTALL_RPATH to ""
-# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
-# had no effect
-#         
-# by default cmake add prefix 'lib', we don't want this hence disable
-#
-# To avoid duplicate target names we chose to name the targets: ecflow2/ecflow3.
-# however test and user code  depend on name 'ecflow', hence we rename the output to 'cflow'
-set_target_properties(ecflow3
-  PROPERTIES
-    OUTPUT_NAME "ecflow"
-    PREFIX ""
-    INSTALL_RPATH ""
-)
-
-# =====================================================================
-# tests
-
-foreach( test ${u_tests} )
-  ecbuild_add_test(
-    TARGET
-      py3_${test}
-    LABELS
-      python nightly
-    TYPE PYTHON
-    ARGS
-      ${CMAKE_CURRENT_SOURCE_DIR}/../test/${test}.py
-    ENVIRONMENT
-      "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
-    TEST_DEPENDS
-      u_base
-  )
-endforeach()
-
-
-if ( ENABLE_ALL_TESTS AND ENABLE_SERVER)
-
-  foreach( test ${s_tests} )
-    ecbuild_add_test(
-      TARGET
-        py3_${test}
-      LABELS
-        python nightly
-      TYPE PYTHON
-      ARGS
-        ${CMAKE_CURRENT_SOURCE_DIR}/../test/py_${test}.py
-      ENVIRONMENT
-        "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
-      TEST_DEPENDS
-        u_base
-    )
-  endforeach()
-  
-  set_property(TEST py3_s_TestClientApi      APPEND PROPERTY DEPENDS s_test)
-  set_property(TEST py3_s_TestPythonChildApi APPEND PROPERTY DEPENDS py3_s_TestClientApi)
-endif()
-
-
-# ==========================================================================
-# install
-#    -DCMAKE_PYTHON_INSTALL_TYPE = [ local | setup | not defined ]
-#
-#    local | not defined : this will install to:
-#                          $INSTALL_PREFIX/$release.$major.$minor/lib/python2.7/site-packages/ecflow/
-#    setup               : experimental only,python way of installing
-#
-#    -DCMAKE_PYTHON_INSTALL_PREFIX should *only* used when using python setup.py (CMAKE_PYTHON_INSTALL_TYPE=setup)
-#    *AND* for testing python install to local directory
-#
-# Note:  To install only the python module
-#       cd  buildir
-#       cmake -DCMAKE_INSTALL_PREFIX=$INSTALL_DIR -DCOMPONENT=python -P cmake_install.cmake -- make install
-# ==========================================================================
-
-if( CMAKE_PYTHON_INSTALL_TYPE MATCHES  "local"  OR NOT DEFINED CMAKE_PYTHON_INSTALL_TYPE )
-
-  message(STATUS "python install *LOCAL* +++ lib/python${Python3_VERSION_MAJOR}.${Python3_VERSION_MINOR}/site-packages/ecflow +++++++")
-  if( NOT INSTALL_PYTHON3_DIR )
-    set(PYTHON_SITE "lib/python${Python3_VERSION_MAJOR}.${Python3_VERSION_MINOR}/site-packages" )
-  else()
-    # Resolve ${VAR} in the value provided
-    string(CONFIGURE "${INSTALL_PYTHON3_DIR}" PYTHON_SITE)
-  endif()
-  set(PYTHON_DEST "${PYTHON_SITE}/ecflow" )
-
-  install(
-    TARGETS
-      ecflow3
-    DESTINATION
-      ${PYTHON_DEST}
-    RENAME
-      ecflow.so
-    COMPONENT
-      python
-  )
-  install(
-    FILES
-      ../ecflow/__init__.py
-      ../samples/api/ecf.py
-      ../samples/api/sms2ecf.py
-    DESTINATION
-      ${PYTHON_DEST}
-    COMPONENT
-      python
-  )
-
-else()
-
-  message( STATUS "python found,  CMAKE_PYTHON_INSTALL_TYPE=${CMAKE_PYTHON_INSTALL_TYPE}")
-
-  # -------------------------------------------------------------------------------------
-  # Install using setup.py
-  # See: http://bloerg.net/2012/11/10/cmake-and-distutils.html
-  # -------------------------------------------------------------------------------------
-  message(STATUS "python install using *setup.py* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
-  message(STATUS "CMAKE_CURRENT_SOURCE_DIR=${CMAKE_CURRENT_SOURCE_DIR}")
-  message(STATUS "CMAKE_BINARY_DIR=${CMAKE_BINARY_DIR}")
-  message(STATUS "CMAKE_PYTHON_INSTALL_PREFIX : ${CMAKE_PYTHON_INSTALL_PREFIX}" )
-
-  set(SETUP_PY_IN "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py.in")
-  set(SETUP_PY    "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py")
-  set(DEPS        "${CMAKE_CURRENT_SOURCE_DIR}/../ecflow/__init__.py")
-  set(OUTPUT      "${CMAKE_CURRENT_SOURCE_DIR}/timestamp")
-
-  configure_file(${SETUP_PY_IN} ${SETUP_PY} )
-
-  add_custom_command(
-    OUTPUT ${OUTPUT}
-    COMMAND ${PYTHON} ${SETUP_PY} build
-    COMMAND ${CMAKE_COMMAND} -E touch ${OUTPUT}
-    DEPENDS ${DEPS}
-  )
-  add_custom_target(target ALL DEPENDS ${OUTPUT})
-
-  install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} build_ext)")
-
-  if( DEFINED CMAKE_PYTHON_INSTALL_PREFIX )
-    message(STATUS "custom/*test* python install prefix defined CMAKE_PYTHON_INSTALL_PREFIX=${CMAKE_PYTHON_INSTALL_PREFIX}")
-    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install -f --prefix=${CMAKE_PYTHON_INSTALL_PREFIX})")
-  else()
-    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install)")
-  endif()
-endif()
diff -pruN 5.12.4-1/Pyext/samples/ListVariables.py 5.13.0-1/Pyext/samples/ListVariables.py
--- 5.12.4-1/Pyext/samples/ListVariables.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/ListVariables.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-import ecflow
-import argparse # for argument parsing  
-import sys   
-
-if __name__ == "__main__":
-    
-    DESC = """Will list variables for any node
-              Usage:
-                Example1: List all the server variables
-                   ListVariables.py --host cca --port 4141 --path /
-                   
-                Example2: List the variables for the given node
-                   ListVariables.py --host cca --port 4141 --path /path/to/node
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--host', default="localhost",   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default="3141",   
-                        help="The port on the host, defaults to 3141")
-    PARSER.add_argument('--path', default="/",   
-                        help="The path to the node. i.e /suite/family/task")
-    ARGS = PARSER.parse_args()
-    #print ARGS    
-    
-    # ===========================================================================
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    try:
-        CL.ping() 
-
-        # get the incremental changes, and merge with defs stored on the Client 
-        CL.sync_local()
-        
-        # check to see if definition exists in the server
-        defs = CL.get_defs()
-        if len(defs) == 0 :
-            print("No suites found, exiting...")
-            sys.exit(0) 
-            
-        # print defs;
-        if ARGS.path == "/":
-            for var in defs.server_variables:  print("edit " + var.name() + " '" + var.value() + "'")
-            for var in defs.user_variables:    print("edit " + var.name() + " '" + var.value() + "'")
-        else:
-            node = defs.find_abs_node(ARGS.path)
-            if node is None:  
-                print("No node found at path " + ARGS.path)
-            else:
-                for var in node.variables:     print("edit " + var.name() + " '" + var.value() + "'")
-
-    except RuntimeError as ex:
-        print("Error: " + str(ex))
-        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/Pyext/samples/TestBench.py 5.13.0-1/Pyext/samples/TestBench.py
--- 5.12.4-1/Pyext/samples/TestBench.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/TestBench.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,258 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# =============================================================================
-# Code for testing *any* definition
-#   Since any ad hoc definition will reference local directories in the
-#   ECF_ variables, we need to remove them and inject our own.
-#
-#   This script is re-runnable, and hence will delete suites in the server
-#   matching those in the input definition. Hence it is best to use this 
-#   script with a *test* server to avoid accidentally deleting existing suites 
-#   of the same name.
-# =============================================================================
-import ecflow
-import os       # for getenv
-import sys
-import shutil   # used to remove directory tree
-import argparse # for argument parsing     
-
-def get_root_source_dir():
-    cwd = os.getcwd()
-    #print "get_root_source_dir from: " + cwd
-    while (1):
-        # Get to directory that has ecflow
-        head, tail = os.path.split(cwd)
-        #print "   head:" + head
-        #print "   tail:" + tail
-        if tail.find("ecflow") != -1 :
-            
-            # bjam, already at the source directory
-            if os.path.exists(cwd + "/Jamroot.jam"): 
-                print("   Found Jamroot.jam in " + cwd)
-                return cwd
-        
-        if tail != "Pyext" and tail != "migrate":
-            # in cmake, we may be in the build directory, hence we need to determine source directory
-            file = cwd + "/CTestTestfile.cmake"
-            #print "   searching for " + file
-            if os.path.exists(file):
-                # determine path by looking into this file:
-                with open(file) as fp:
-                    for line in fp:
-                        ## Source directory: /tmp/ma0/workspace/ecflow/Acore
-                        if line.find("Source directory"):
-                            tokens = line.split()
-                            if len(tokens) == 4:
-                                #print "   returning root_source_dir:", tokens[3]
-                                return tokens[3]
-                raise RuntimeError("ERROR could not find Source directory in CTestTestfile.cmake")
-            else:
-                raise RuntimeError("ERROR could not find file CTestTestfile.cmake in " + cwd)
-                
-        cwd = head
-    return cwd
-
-    
-def delete_variables_affecting_job_generation(node): 
-    """delete customer related ECF variables, these will point to directories
-       that don't exist. Its ok we will regenerate our own local ones"""
-    var = node.find_variable("ECF_HOME")
-    if not var.empty() :  
-        node.delete_variable("ECF_HOME")    
-    var = node.find_variable("ECF_FILES")
-    if not var.empty() :  
-        node.delete_variable("ECF_FILES")    
-    var = node.find_variable("ECF_INCLUDE")
-    if not var.empty() :  
-        node.delete_variable("ECF_INCLUDE")    
-    var = node.find_variable("ECF_JOB_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_JOB_CMD")    
-    var = node.find_variable("ECF_KILL_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_KILL_CMD")    
-    var = node.find_variable("ECF_STATUS_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_STATUS_CMD")    
-    var = node.find_variable("ECF_OUT")
-    if not var.empty() :  
-        node.delete_variable("ECF_OUT")
-    var = node.find_variable("ECF_MICRO")
-    if not var.empty() :  
-        node.delete_variable("ECF_MICRO")   # generation depend on % 
-         
-      
-def traverse_container(node_container):
-    """Recursively traverse definition node hierarchy and delete
-       the variables that affect job generation.
-    """
-    delete_variables_affecting_job_generation(node_container)
-    for node in node_container.nodes:
-        delete_variables_affecting_job_generation(node)
-        if not isinstance(node, ecflow.Task):
-            traverse_container(node)  
-    
-if __name__ == "__main__":
-    
-    DESC = """Will allow any definition to be loaded and played on the server
-            This is done by:
-            o Remove existing ECF_ variables that affect job generation. 
-              i.e variables that refer to customer specific directories are removed
-            o Allows ECF_HOME to specified, defaults to ./CUSTOMER/ECF_HOME
-            o Generates the scripts(.ecf files) automatically based on the definition.
-              i.e if a task has events,meters,labels then the client request for these are
-              automatically injected in the generated .ecf script files
-            o Will clear out existing data both on disk and on the server to allow 
-              multiple re-runs of this script. ** If this is an issue please use
-              a test server **
-            o All suites are put into a suspended state. This allows the GUI to resume them
-            o The server is restarted and suites are begun
-            This programs assumes that ecflow module is accessible
-
-            example:
-                python Pyext/samples/TestBench.py --port=3141 --verbose=True ANode/parser/test/data/good_defs/trigger/late.def
-            """    
-            
-    print("####################################################################")
-    print("Running ecflow version " + ecflow.Client().version()  + " debug build(" + str(ecflow.debug_build()) +")")
-    if 'PYTHONPATH' in os.environ:
-        print("PYTHONPATH: " + str(os.environ['PYTHONPATH'].split(os.pathsep)))
-    print("sys.path:   " + str(sys.path))
-    print("####################################################################")
- 
-    default_port = "3141"
-    if "ECF_PORT" in os.environ:
-         default_port = os.environ["ECF_PORT"]
- 
-    default_host = "localhost"
-    if "ECF_HOST" in os.environ:
-        default_host  = os.environ["ECF_HOST"]
-
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('defs_file', 
-                        help="The definition file")
-    PARSER.add_argument('--host', default=default_host,   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default=default_port,   
-                        help="The port on the host, defaults to 3141")
-    PARSER.add_argument('--path', default="/",   
-                        help="replace only the node path in the suite")
-    PARSER.add_argument('--ecf_home', default=os.getcwd() + "/CUSTOMER/ECF_HOME",
-                        help="Directory to be used for generated scripts(ECF_HOME), defaults to ./CUSTOMER/ECF_HOME")
-    PARSER.add_argument('--verbose', nargs='?', default=False, const=True, type=bool,
-                        help="Show verbose output")
-    ARGS = PARSER.parse_args()
-    ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
-    print(ARGS  )  
-    
-    # If running on local work space, use /Pyext/test/data/CUSTOMER/ECF_HOME as ecf_home
-    using_workspace = False;
-    ecflow_source_dir = ""
-    try:
-        ecflow_source_dir = get_root_source_dir();
-        ARGS.ecf_home = ecflow_source_dir + "/Pyext/test/data/CUSTOMER/ECF_HOME"
-        using_workspace = True
-        if ARGS.verbose:
-            print("Workspace is defined ecflow_source_dir: ",ecflow_source_dir)
-                
-    except:
-        pass
-    
-    if ARGS.verbose:
-        print("Using ECF_HOME=" + ARGS.ecf_home)
-         
-    try:
-        if ARGS.verbose: 
-            print("\nloading the definition from the input arguments(" + ARGS.defs_file + ")\n")
-        DEFS = ecflow.Defs(ARGS.defs_file)
-    except RuntimeError as ex:
-        print("   ecflow.Defs(" + ARGS.defs_file + ") failed:\n" + str(ex))
-        sys.exit(1)
-    
-    if ARGS.verbose: 
-        print("remove test data associated with the DEFS, so we start fresh, Allows rerun")
-    for suite in DEFS.suites:
-        dir_to_remove = ARGS.ecf_home + suite.get_abs_node_path()
-        if ARGS.verbose: 
-            print("   Deleting directory: " + dir_to_remove + "\n")
-        shutil.rmtree(dir_to_remove, True)  
-        
-    if ARGS.verbose: 
-        print("remove remote reference to ECF_HOME and ECF_INCLUDE, since we inject or own\n")
-    for suite in DEFS.suites:
-        traverse_container(suite)
-  
-    DEFS.add_variable("ECF_HOME", ARGS.ecf_home)
-    
-    if using_workspace: 
-        path_to_ecflow_client = ecflow.File.find_client()
-        if os.path.exists( path_to_ecflow_client ):
-            DEFS.add_variable("ECF_CLIENT_EXE_PATH", path_to_ecflow_client )
-            if ARGS.verbose: print("Adding ECF_CLIENT_EXE_PATH:",path_to_ecflow_client)
-
-    DEFS.add_variable("SLEEP", "10")  # not strictly required since default is 1 second
-    DEFS.add_variable("ECF_INCLUDE", ARGS.ecf_home + "/includes")
-
-    for suite in DEFS.suites:
-        suite.add_defstatus(ecflow.DState.suspended)
-    
-    if ARGS.verbose: 
-        #ecflow.PrintStyle.set_style(ecflow.Style.STATE)
-        print(DEFS)
-
-    if ARGS.verbose: 
-        print("Generating script files(.ecf) from the definition")
-    DEFS.generate_scripts()
-
-    if ARGS.verbose: 
-        print("\nchecking script file generation, pre-processing & variable substitution\n")
-    msg = DEFS.check_job_creation()       
-    assert len(msg) == 0, msg
-    
-    # ===========================================================================
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    try:
-        if ARGS.verbose: 
-            print("check server " + ARGS.host + ":" + ARGS.port + " is running")
-        CL.ping() 
-
-        if ARGS.verbose: 
-            print("Server is already running. re-start the server")
-        CL.restart_server() 
-
-        if ARGS.verbose: 
-            print("Remove suites associated with this DEFS, allows rerun *******************************************")
-        for suite in DEFS.suites:
-            try:
-                CL.delete(suite.get_abs_node_path(), True)
-            except RuntimeError as ex:
-                pass # For first run this will fail, hence ignore
-        
-        if ARGS.verbose: 
-            print("Load the definition into " + ARGS.host + ":" + ARGS.port)
-        if ARGS.path == "/":
-            CL.load(DEFS) 
-        else:
-            CL.replace(ARGS.path, DEFS)
-
-        if ARGS.verbose: 
-            print("Begin all suites. They should be suspended.")
-        print("Loaded suites:")
-        for suite in DEFS.suites:
-            CL.begin_suite(suite.name())
-            print("   " + suite.name())
-        print("into server " + ARGS.host  + ":" + ARGS.port + ", please view the playable suites in the GUI")
-    except RuntimeError as ex:
-        print("Error: " + str(ex))
diff -pruN 5.12.4-1/Pyext/samples/TestBenchConfluence.py 5.13.0-1/Pyext/samples/TestBenchConfluence.py
--- 5.12.4-1/Pyext/samples/TestBenchConfluence.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/TestBenchConfluence.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,193 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# =============================================================================
-# Code for testing *any* definition
-#   Since any ad hoc definition will reference local directories in the
-#   ECF_ variables, we need to remove them and inject our own.
-#
-#   This script is re-runnable, and hence will delete suites in the server
-#   matching those in the input definition. Hence it is best to use this 
-#   script with a *test* server to avoid accidentally deleting existing suites 
-#   of the same name.
-# =============================================================================
-import ecflow
-import os       # for getenv
-import shutil   # used to remove directory tree
-import argparse # for argument parsing     
-
-def delete_variables_affecting_job_generation(node): 
-    """delete customer related ECF variables, these will point to directories
-       that don't exist. Its ok we will regenerate our own local ones"""
-    var = node.find_variable("ECF_HOME")
-    if not var.empty() :  
-        node.delete_variable("ECF_HOME")    
-    var = node.find_variable("ECF_FILES")
-    if not var.empty() :  
-        node.delete_variable("ECF_FILES")    
-    var = node.find_variable("ECF_INCLUDE")
-    if not var.empty() :  
-        node.delete_variable("ECF_INCLUDE")    
-    var = node.find_variable("ECF_JOB_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_JOB_CMD")    
-    var = node.find_variable("ECF_KILL_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_KILL_CMD")    
-    var = node.find_variable("ECF_STATUS_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_STATUS_CMD")    
-    var = node.find_variable("ECF_OUT")
-    if not var.empty() :  
-        node.delete_variable("ECF_OUT")    
-      
-def traverse_container(node_container):
-    """Recursively traverse definition node hierarchy and delete
-       the variables that affect job generation.
-    """
-    delete_variables_affecting_job_generation(node_container)
-    for node in node_container.nodes:
-        delete_variables_affecting_job_generation(node)
-        if not isinstance(node, ecflow.Task):
-            traverse_container(node)  
-    
-if __name__ == "__main__":
-    
-    default_port = "3141"
-    if "ECF_PORT" in os.environ:
-        default_port = os.environ["ECF_PORT"]
-
-    default_host = "localhost"
-    if "ECF_HOST" in os.environ:
-        default_host  = os.environ["ECF_HOST"]
-
-    DESC = """Will allow any definition to be loaded and played on the server
-            This is done by:
-            o Remove existing ECF_ variables that affect job generation. 
-              i.e. variables that refer to customer specific directories are removed
-            o Allows ECF_HOME to specified, defaults to cwd + /CUSTOMER/ECF_HOME
-            o Generates the scripts(.ecf files) automatically based on the definition.
-              i.e. if a task has events,meters,labels then the client request for these are
-              automatically injected in the generated .ecf script files
-            o Will clear out existing data both on disk and on the server to allow 
-              multiple re-runs of this script. ** If this is an issue please use
-              a test server **
-            o All suites are put into a suspended state. This allows the GUI to resume them
-            o The server is restarted and suites are begun
-            This programs assumes that ecflow module is accessible.
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('defs_file', 
-                        help="The definition file")
-    PARSER.add_argument('--host', default=default_host,   
-                        help="The name of the host machine, defaults to ECF_HOST otherwise 'localhost'")
-    PARSER.add_argument('--port', default=default_port,   
-                        help="The port on the host, defaults to ECF_PORT otherwise uses 3141")
-    PARSER.add_argument('--path', default="/",   
-                        help="replace only the node path in the suite")
-    PARSER.add_argument('--ecf_home', default=os.getcwd() + "/CUSTOMER/ECF_HOME",
-                        help="Directory to be used for generated scripts(ECF_HOME), defaults to ./CUSTOMER/ECF_HOME")
-    PARSER.add_argument('--verbose', nargs='?', default=False, const=True, type=bool,
-                        help="Show verbose output")
-    ARGS = PARSER.parse_args()
-    ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
-    print(ARGS) 
-    
-    # If running on local work space, use /Pyext/test/data/CUSTOMER/ECF_HOME as ecf_home
-    if ARGS.verbose:
-        print("Using ECF_HOME=" + ARGS.ecf_home)
-         
-    if ARGS.verbose: 
-        print("\nloading the definition from the input arguments(" + ARGS.defs_file + ")\n")
-    try:
-        DEFS = ecflow.Defs(ARGS.defs_file)
-    except RuntimeError as ex:
-        print("   ecflow.Defs(" + ARGS.defs_file + ") failed:\n" + str(ex))
-        sys.exit(1)
-    
-    if ARGS.verbose: 
-        print("remove test data associated with the DEFS, so we start fresh, Allows rerun")
-    for suite in DEFS.suites:
-        dir_to_remove = ARGS.ecf_home + suite.get_abs_node_path()
-        if ARGS.verbose: 
-            print("   Deleting directory: " + dir_to_remove + "\n")
-        shutil.rmtree(dir_to_remove, True)  
-        
-    if ARGS.verbose: 
-        print("remove remote reference to ECF_HOME and ECF_INCLUDE, since we inject or own\n")
-    for suite in DEFS.suites:
-        traverse_container(suite)
-  
-    if ARGS.verbose: 
-        print("add variables required for script generation, for all suites\n")
-    DEFS.add_variable("ECF_HOME", ARGS.ecf_home)
-    DEFS.add_variable("SLEEP", "10")  # not strictly required since default is 1 second
-    DEFS.add_variable("ECF_INCLUDE", ARGS.ecf_home + "/includes")
-
-
-    if ARGS.verbose: 
-        print("Place all suites into suspended state, so they can be started by the GUI\n")  
-    for suite in DEFS.suites:
-        suite.add_defstatus(ecflow.DState.suspended)
-    
-    if ARGS.verbose: 
-        #ecflow.PrintStyle.set_style(ecflow.Style.STATE)
-        print(DEFS)
-
-    if ARGS.verbose: 
-        print("Generating script files(.ecf) from the definition")
-    DEFS.generate_scripts()
-
-    if ARGS.verbose: 
-        print("\nchecking script file generation, pre-processing & variable substitution\n")
-    msg = DEFS.check_job_creation()       
-    assert len(msg) == 0, msg
-
-    # ===========================================================================
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    try:
-        if ARGS.verbose: 
-            print("check server " + ARGS.host + ":" + ARGS.port + " is running")
-        CL.ping() 
-
-        if ARGS.verbose: 
-            print("Server is already running. re-start the server")
-        CL.restart_server() 
-
-        if ARGS.verbose: 
-            print("Remove suites associated with this DEFS, allows rerun *******************************************")
-        for suite in DEFS.suites:
-            try:
-                CL.delete(suite.get_abs_node_path(), True)
-            except RuntimeError as ex:
-                pass # For first run this will fail, hence ignore
-        
-        if ARGS.verbose: 
-            print("Load the definition into " + ARGS.host + ":" + ARGS.port)
-        if ARGS.path == "/":
-            CL.load(DEFS) 
-        else:
-            CL.replace(ARGS.path, DEFS)
-
-        if ARGS.verbose: 
-            print("Begin all suites. They should be suspended.")
-        print("Loaded suites:")
-        for suite in DEFS.suites:
-            CL.begin_suite(suite.name())
-            print("   " + suite.name())
-        print("into server " + ARGS.host \
-                             + ":" + ARGS.port + ", please view the playable suites in the GUI")
-    except RuntimeError as ex:
-        print("Error: " + str(ex))
diff -pruN 5.12.4-1/Pyext/samples/TestGui.py 5.13.0-1/Pyext/samples/TestGui.py
--- 5.12.4-1/Pyext/samples/TestGui.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/TestGui.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,1507 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-import argparse # for argument parsing  
-import time
-import os
-import sys
-import pwd
-from datetime import datetime
-from socket import gethostname 
-import shutil   # used to remove directory tree
-
-# ecflow_test_util, see File ecflow_test_util.py
-import ecflow
-from ecflow import Defs, Clock, DState,  Style, State, RepeatDate, PrintStyle, File, Client, SState, \
-                   CheckPt, Cron, Late, debug_build, Flag, FlagType
-
-class Tester(object) : 
-    def __init__(self,ci,args):
-        self.ci_ = ci
-        self.port_ = self.ci_.get_port()
-        self.ARGS_ = args
-        
-    def clean_up_server(self):
-        self.log_msg("   clean_up server, clear log, remove check-pt, and white list file" )
-        self.ci_.clear_log()    
-        try: os.remove(self.checkpt_file_path())
-        except: pass
-        try: os.remove(self.backup_checkpt_file_path())
-        except: pass
-        try: os.remove(self.white_list_file_path())  
-        except: pass
-    
-    def clean_up_data(self):
-        self.log_msg("   Attempting to Removing ECF_HOME " + self.ecf_home())
-        try: 
-            shutil.rmtree(self.ecf_home(),True)   # True means ignore errors
-            shutil.rmtree("test_gui",True)   # True means ignore errors 
-            print("   Remove OK") 
-        except: 
-            print("   Remove Failed") 
-            pass
-        
-    def ecf_home(self): 
-        # debug_build() is defined for ecflow. Used in test to distinguish debug/release ecflow
-        # Vary ECF_HOME based on debug/release/port allowing multiple invocations of these tests
-        if debug_build():
-            return os.getcwd() + "/test_gui/data/ecf_home_debug_" + str(self.port_)
-        return os.getcwd() + "/test_gui/data/ecf_home_release_" + str(self.port_)
-
-    def ecf_includes(self) :  return os.getcwd() + "/Pyext/test/data/includes"
-    def log_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.log"
-    def checkpt_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.check"
-    def backup_checkpt_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.check.b"
-    def white_list_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.lists"
-
-    def path_to_ecflow_client(self):
-        if self.ARGS_.ecflow_client != "":
-            return self.ARGS_.ecflow_client
-        # to use the local build, in preference, to release version of ecflow
-        path_to_client = File.find_client() # version used by the ecflow module, may not exist anymore
-        if os.path.exists(path_to_client):
-            return path_to_client
-        path_to_client = "/usr/local/apps/ecflow/" + self.ci_.version() + "/bin/ecflow_client"
-        if os.path.exists(path_to_client):
-            return path_to_client
-        return "ecflow_client" # fall back, just search on $PATH *IN* the shell where the server was started
-     
-    def create_defs(self,name=""):
-        defs = Defs()
-        suite_name = name
-        if len(suite_name) == 0: suite_name = "s1"
-        suite = defs.add_suite(suite_name);
-        
-        ecfhome = self.ecf_home()
-        suite.add_variable("ECF_HOME", ecfhome)
-        suite.add_variable("ECF_CLIENT_EXE_PATH", self.path_to_ecflow_client())
-        suite.add_variable("SLEEP", "1");  # not strictly required since default is 1 second
-        suite.add_variable("ECF_INCLUDE", self.ecf_includes());
-    
-        family = suite.add_family("f1")
-        family.add_task("t1")
-        family.add_task("t2")
-        return defs;        
-        
-    def sync_local(self,sleep_time=4):
-        """Delay added so that we can see the change in the GUI.
-           The GUI refresh rate should be set to 1 second
-           """
-        self.ci_.sync_local()
-        if self.ARGS_.sync_sleep != 0 and sleep_time != 0:
-            time.sleep(self.ARGS_.sync_sleep)
-     
-    def log_msg(self,msg):
-        print(msg)
-        self.ci_.log_msg("======================== " + msg + " ========================")
-    
-    def test_version(self):
-        self.log_msg("test_version Client_version(" + self.ci_.version() + ") server version(" + self.ci_.server_version() + ")")
-        
-    def test_client_get_server_defs(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        self.ci_.load(self.create_defs(test))  
-        self.sync_local()  
-        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite of name " + test + ":\n" + str(self.ci_.get_defs())
-        
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-        self.sync_local()  
-    
-    def test_client_restart_server(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        self.ci_.restart_server()
-        self.sync_local()
-        assert self.ci_.get_defs().get_server_state() == SState.RUNNING, "Expected server to be running"
-        
-        paths = list(self.ci_.changed_node_paths)
-        #for path in self.ci_.changed_node_paths:
-        #    print("   changed node path " + path);
-        assert len(paths) == 1, "expected changed node to be the root node"
-        assert paths[0] == "/", "Expected root path but found " + str(paths[0])
-    
-    def test_client_halt_server(self):
-        self.log_msg(sys._getframe().f_code.co_name)
-        self.ci_.halt_server()
-        self.sync_local()
-        assert self.ci_.get_defs().get_server_state() == SState.HALTED, "Expected server to be halted"
-        
-        paths = list(self.ci_.changed_node_paths)
-        #for path in self.ci_.changed_node_paths:
-        #    print("   changed node path " + path);
-        assert len(paths) == 1, "expected changed node to be the root node"
-        assert paths[0] == "/", "Expected root path but found " + str(paths[0])
-        self.ci_.restart_server()   
-    
-    def test_client_shutdown_server(self):
-        self.log_msg(sys._getframe().f_code.co_name)
-        self.ci_.shutdown_server()
-        self.sync_local()
-        assert self.ci_.get_defs().get_server_state() == SState.SHUTDOWN, "Expected server to be shutdown"
-        
-        paths = list(self.ci_.changed_node_paths)
-        #for path in self.ci_.changed_node_paths:
-        #    print("   changed node path " + path);
-        assert len(paths) == 1, "expected changed node to be the root node"
-        assert paths[0] == "/", "Expected root path but found " + str(paths[0])
-    
-    def test_client_load_in_memory_defs(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        self.ci_.load(self.create_defs(test))  
-        self.sync_local() 
-        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite of name " + test + ":\n" + str(self.ci_.get_defs())              
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def test_client_load_from_disk(self):            
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test);
-        defs_file = test + ".def"
-        defs.save_as_defs(defs_file)     
-        assert os.path.exists(defs_file), "Expected file " + defs_file + " to exist after defs.save_as_defs()"
-        self.ci_.load(defs_file) # open and parse defs file, and load into server.\n"
-            
-        # check load worked
-        self.sync_local() 
-        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite of name " + test + ":\n" + str(self.ci_.get_defs())
-        os.remove(defs_file)
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def test_client_checkpt(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        try:    
-            os.remove(self.checkpt_file_path())
-            os.remove(self.backup_checkpt_file_path())
-        except: pass
-        
-        self.ci_.load(self.create_defs(test))  
-        self.sync_local() 
-        self.ci_.checkpt()
-        assert os.path.exists(self.checkpt_file_path()), "Expected check pt file " + self.checkpt_file_path() + " to exist after self.ci_.checkpt()"
-        assert os.path.exists(self.backup_checkpt_file_path()) == False, "Expected back up check pt file to *NOT* exist"
-        
-        self.ci_.checkpt()   # second check pt should cause backup check pt to be written
-        assert os.path.exists(self.backup_checkpt_file_path()), "Expected back up check pt file to exist after second self.ci_.checkpt()"
-    
-        self.ci_.checkpt(CheckPt.NEVER)         # switch of check pointing
-        self.ci_.checkpt(CheckPt.ALWAYS)        # always check point, at any state change
-        self.ci_.checkpt(CheckPt.ON_TIME)       # Check point periodically, by interval set in server
-        self.ci_.checkpt(CheckPt.ON_TIME, 200)  # Check point periodically, by interval set in server
-        self.ci_.checkpt(CheckPt.UNDEFINED, 0, 35)  # Change check point save time alarm
-    
-        os.remove(self.checkpt_file_path())
-        os.remove(self.backup_checkpt_file_path())
-        
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def test_client_restore_from_checkpt(self):          
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        try:    
-            os.remove(self.checkpt_file_path())
-            os.remove(self.backup_checkpt_file_path())
-        except: pass
-        
-        self.ci_.load(self.create_defs(test))  
-        self.sync_local()  
-        self.ci_.checkpt()
-        self.ci_.delete_all() 
-        
-        self.sync_local() 
-        assert len(list(self.ci_.get_defs().suites)) == 0, "Expected all suites to be delete:\n"
-        
-        self.ci_.halt_server()  # server must be halted, otherwise restore_from_checkpt will throw
-        self.ci_.restore_from_checkpt()
-        
-        self.sync_local() 
-        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite " + test + " after restore from checkpt:\n" + str(self.ci_.get_defs())
-    
-        os.remove(self.checkpt_file_path())
-        self.ci_.restart_server()   
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def get_username(self): return pwd.getpwuid(os.getuid())[ 0 ]
-    
-    def test_client_reload_wl_file(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        
-        expected = False
-        try:    self.ci_.reload_wl_file();            
-        except: expected = True
-        assert expected, "Expected reload to fail when no white list specified"
-        
-        # create a white list file
-        wl_file = open(self.white_list_file_path(), 'w')
-        wl_file.write("#\n")
-        wl_file.write("4.4.14   #   comment\n\n")
-        wl_file.write("# These user have read and write access to the server\n")
-        wl_file.write(self.get_username() + "\n")  # add current user otherwise remaining test's, wont have access from server anymore
-        wl_file.write("axel  # admin\n")
-        wl_file.write("john  # admin\n\n")
-        wl_file.write("# Read only users\n")
-        wl_file.write("-fred   # needs read access only\n")
-        wl_file.write("-joe90  # needs read access only\n")
-        wl_file.close();
-        
-        self.ci_.reload_wl_file();  
-        os.remove(self.white_list_file_path())          
-    
-    def generate_scripts_and_load_defs(self,defs):
-        defs.generate_scripts();
-        msg = defs.check_job_creation()       
-        assert len(msg) == 0, msg
-        
-        self.ci_.restart_server()
-        self.ci_.load(defs)           
-        self.sync_local() # clear changed_node_paths 
-
-    def create_and_load_defs(self,test,add_defstatus = True):
-        self.log_msg(test)
-        defs = self.create_defs(test)  
-        suite = defs.find_suite(test)
-        if add_defstatus :
-            suite.add_defstatus(DState.suspended)
-    
-        self.generate_scripts_and_load_defs(defs);
-        self.ci_.begin_suite(test)
-
-    def test_client_run(self):            
-        test = sys._getframe().f_code.co_name # returns function name
-        self.create_and_load_defs(test)
-        
-        self.ci_.run("/" + test, False)
-        
-        count = 0
-        while 1:
-            count += 1
-            self.sync_local(0) # get the changes, synced with local defs
-            suite = self.ci_.get_defs().find_suite(test)
-            assert suite is not None, "Expected to find suite " + test + ":\n" + str(self.ci_.get_defs())
-            if suite.get_state() == State.complete:
-                break;
-            time.sleep(3)
-            if count > 20:
-                assert False, "test_client_run aborted after " + str(count) + " loops:\n" + str(self.ci_.get_defs())
-            
-        self.ci_.log_msg("Looped " + str(count) + " times")
-        
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def test_client_run_with_multiple_paths(self):            
-        test = sys._getframe().f_code.co_name # returns function name
-        self.create_and_load_defs(test)
-
-        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2"]
-        self.ci_.run( path_list, False)
-    
-        count = 0
-        while 1:
-            count += 1
-            self.sync_local(0) # get the changes, synced with local defs
-            suite = self.ci_.get_defs().find_suite(test)
-            assert suite is not None, "Expected to find suite " + tests + ":\n" + str(self.ci_.get_defs())
-            if suite.get_state() == State.complete:
-                break;
-            time.sleep(3)
-            if count > 20:
-                assert False, test + " aborted after " + str(count) + " loops:\n" + str(self.ci_.get_defs())
-            
-        self.ci_.log_msg("Looped " + str(count) + " times")
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this   
-    
-    def test_client_requeue(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.create_and_load_defs(test)
-        
-        self.ci_.force_state_recursive("/" + test,State.unknown)
-        self.sync_local();
-        suite = self.ci_.get_defs().find_suite(test)
-        assert suite.get_state() == State.unknown, "Expected to find suite with state unknown"
-    
-        self.ci_.requeue("/" + test)
-        self.sync_local();
-        suite = self.ci_.get_defs().find_suite(test)
-        assert suite.get_state() == State.queued, "Expected to find suite with state queued"
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def test_client_requeue_with_multiple_paths(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.create_and_load_defs(test)
-
-        self.ci_.force_state_recursive("/" + test,State.unknown)
-        self.sync_local();
-        task1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
-        task2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
-        assert task1.get_state() == State.unknown, "Expected to find t1 with state unknown"
-        assert task2.get_state() == State.unknown, "Expected to find t2 with state unknown"
-    
-        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]
-        self.ci_.requeue( path_list)
-        self.sync_local();
-        task1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
-        task2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
-        assert task1.get_state() == State.queued, "Expected to find task t1 with state queued"
-        assert task2.get_state() == State.queued, "Expected to find task t2 with state queued"
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def test_client_free_dep(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-           
-        # add a real clock, since we are adding date dependencies
-        # Note: adding a future time dependency on a task, will cause it to requeue, when complete
-        # Hence even when we free these dependency they get requeued.
-        # So we use todays date.
-        ltime = time.localtime();
-        day = ltime.tm_mday
-        month = ltime.tm_mon
-        year = ltime.tm_year
-        
-        defs = Defs()
-        suite = defs.add_suite(test);
-        suite.add_clock(Clock(False)) # true means hybrid, False means real
-        ecfhome = self.ecf_home();
-        suite.add_variable("ECF_HOME", ecfhome);
-        suite.add_variable("ECF_CLIENT_EXE_PATH", self.path_to_ecflow_client());
-        suite.add_variable("SLEEPTIME", "1");
-        suite.add_variable("ECF_INCLUDE", self.ecf_includes());
-        family = suite.add_family("f1")
-        family.add_task("t1").add_time("00:01")
-        family.add_task("t2").add_date(day,month,year)
-        family.add_task("t3").add_trigger("1 == 0")
-        t4 = family.add_task("t4")
-        t4.add_time("00:01")
-        t4.add_date(day,month,year)
-        t4.add_trigger("1 == 0")
-    
-        self.generate_scripts_and_load_defs(defs);
-        self.ci_.begin_suite(test)
-        
-        t1_path = "/" + test + "/f1/t1"
-        t2_path = "/" + test + "/f1/t2"
-        t3_path = "/" + test + "/f1/t3"
-        t4_path = "/" + test + "/f1/t4"
-        while 1:
-            self.sync_local(0)
-            t1 = self.ci_.get_defs().find_abs_node(t1_path)
-            t2 = self.ci_.get_defs().find_abs_node(t2_path)
-            t3 = self.ci_.get_defs().find_abs_node(t3_path)
-            t4 = self.ci_.get_defs().find_abs_node(t4_path)
-     
-            if t1.get_state() == State.queued: self.ci_.free_time_dep(t1_path)
-            if t2.get_state() == State.queued: self.ci_.free_date_dep(t2_path)
-            if t3.get_state() == State.queued: self.ci_.free_trigger_dep(t3_path)
-            if t4.get_state() == State.queued: self.ci_.free_all_dep(t4_path)
-    
-            suite = self.ci_.get_defs().find_suite(test)
-            if suite.get_state() == State.complete:
-                break;
-            time.sleep(3)       
-                
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-
-    
-    def test_client_check(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        
-        defs = Defs()
-        defs.add_extern("/a/b/c/d")
-        defs.add_extern("/a/b/c/d/e:event")
-        defs.add_extern("/a/b/c/d/e:meter")
-        defs.add_extern("/made/up/redundant/extren")
-        defs.add_extern("/made/up/redundant/extren")
-        defs.add_extern("/limits:c1a")
-        defs.add_extern("/limits:c1a")
-        defs.add_extern("fred")
-        defs.add_extern("limits:hpcd")
-        defs.add_extern("/suiteName:sg1")
-        defs.add_extern("/obs/limits:hpcd")
-        suite = defs.add_suite(test)
-        family_f1 = suite.add_family("f1")
-        family_f1.add_task("p").add_trigger("/a/b/c/d == complete")      # extern path
-        family_f1.add_task("q").add_trigger("/a/b/c/d/e:event == set")   # extern event path
-        family_f1.add_task("r").add_trigger("/a/b/c/d/e:meter le 30")    # extern meter path
-    
-        suite.add_inlimit("c1a","/limits")
-        suite.add_inlimit("fred")
-        
-        family_anon = suite.add_family("anon")
-        family_anon.add_inlimit("hpcd","limits")
-        family_anon.add_task("t1").add_inlimit("sg1","/suiteName")
-        family_anon.add_task("t2").add_inlimit("hpcd","/obs/limits")
-        family_anon.add_task("t3").add_inlimit("c1a","/limits")
-     
-        # CLIENT side check
-        client_check = defs.check()
-        assert len(client_check) == 0, "Expected clean defs check due to externs but found:\n" + client_check + "\n" + str(defs)
-    
-        # SERVER side check
-        self.ci_.load(defs)
-        self.sync_local()  
-        server_check = self.ci_.check("") # empty string means check the whole defs, otherwise a node path can be specified.
-        server_check = self.ci_.check("/" + test)  
-        # print server_check
-        assert len(server_check) > 0, "Expected defs to fail, since no externs in server "
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-        
-    def test_client_suites(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        no_of_suites = len(self.ci_.suites())
-    
-        defs = self.create_defs("test_client_suites")
-        self.ci_.load(defs)  
-        assert len(self.ci_.suites()) == no_of_suites + 1 ,"expected " + str(no_of_suites + 1) + " suites"
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-        
-    def test_client_ch_suites(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        
-        defs = Defs()
-        for i in range(1,7): defs.add_suite(test + str(i))
-        self.ci_.load(defs)
-        self.sync_local()  
-        
-        suite_names = [ test + '1', test + '2', test + '3' ]
-        self.ci_.ch_register(True,suite_names)      # register interest in suites s1,s2,s3 and any new suites
-        self.ci_.ch_register(False,[ test + "1"])   # register interest in suites s1 
-        self.sync_local();
-        
-        self.ci_.ch_suites()  # writes to standard out, list of suites and handles
-        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
-        self.sync_local();    
-    
-    def test_client_ch_register(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg("test_client_ch_register")
-        
-        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        except: pass              # Drop throws if no handle registered
-        
-        defs = Defs()
-        for i in range(1,7): defs.add_suite( test + str(i))
-        self.ci_.load(defs)
-        self.sync_local();
-        
-        suite_names = [ test + '1', test + '2', test + '3' ]
-        self.ci_.ch_register(True, suite_names)    # register interest in suites s1,s2,s3 and any new suites
-        self.ci_.ch_register(False,suite_names)    # register interest in suites s1,s2,s3 only
-        self.sync_local();
-        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
-                
-    def test_client_ch_drop(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        
-        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        except: pass              # Drop throws if no handle registered
-        
-        defs = Defs()
-        for i in range(1,7): defs.add_suite(test + str(i))
-        self.ci_.load(defs)
-        self.sync_local()  
-        
-        try:
-            # register interest in suites s1,s2,s3 and any new suites
-            suite_names = [ test + '1', test + '2', test + '3' ]
-            self.ci_.ch_register(True, suite_names)    
-            self.sync_local();
-        finally:  
-            self.ci_.ch_drop()  # drop using handle stored in self.ci_., from last register
-        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
-              
-    def test_client_ch_drop_user(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        except: pass              # Drop throws if no handle registered
-        
-        defs = Defs()
-        for i in range(1,7): defs.add_suite(test + str(i))
-        self.ci_.load(defs)
-        self.sync_local()  
-        
-        try:
-            # register interest in suites s1,s2,s3 and any new suites
-            suite_names = [ test + '1', test + '2', test + '3' ]
-            self.ci_.ch_register(True, suite_names)
-            self.sync_local();
-        except RuntimeError as e:
-            print(str(e))
-        
-        self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
-                
-    def test_client_ch_add(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        except: pass              # Drop throws if no handle registered
-        
-        defs = Defs()
-        for i in range(1,7): defs.add_suite(test + str(i))
-        self.ci_.load(defs)
-        self.sync_local()  
-        
-        try:
-            suite_names = []
-            self.ci_.ch_register(True,suite_names)        # register interest in any new suites
-            suite_names = [ test + '1', test + '2' ]
-            self.ci_.ch_add(suite_names)                  # add suites s1,s2 to the last added handle
-            suite_names = [ test + '3', test + '4' ]
-            self.ci_.ch_add( self.ci_.ch_handle(),suite_names)  # add suites s3,s4 using last handle
-            self.sync_local();
-        except RuntimeError as e:
-            print(str(e))
-            
-        self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
-                
-    def test_client_ch_auto_add(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        except: pass              # Drop throws if no handle registered
-        
-        defs = Defs()
-        for i in range(1,7): defs.add_suite(test + str(i))
-        self.ci_.load(defs)
-        self.sync_local()  
-        
-        try:
-            suite_names = [ test + '1', test + '2', test + '3' ]
-            self.ci_.ch_register(True,suite_names)     # register interest in suites s1,s2,s3 and any new suites
-            self.ci_.ch_auto_add( False )              # disable adding newly created suites to last registered handle
-            self.ci_.ch_auto_add( True )               # enable adding newly created suites to last registered handle
-            self.ci_.ch_auto_add( self.ci_.ch_handle(), False ) # disable adding newly created suites to handle
-            self.sync_local();
-        except RuntimeError as e:
-            print(str(e))
-            
-        self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
-               
-    def test_client_ch_remove(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        except: pass              # Drop throws if no handle registered
-        
-        defs = Defs()
-        for i in range(1,7): defs.add_suite(test + str(i))
-        self.ci_.load(defs)
-        self.sync_local()  
-        
-        try:
-            suite_names = [ test + '1', test + '2', test + '3' ]
-            self.ci_.ch_register(True,suite_names)     # register interest in suites s1,s2,s3 and any new suites
-            suite_names = [ test + '1' ]
-            self.ci_.ch_remove( suite_names )          # remove suites s1 from the last added handle\n"
-            suite_names = [  test + '2'  ]
-            self.ci_.ch_remove( self.ci_.ch_handle(), suite_names )  # remove suites s2 from the last added handle\n"
-            self.sync_local();
-        except RuntimeError as e:
-            print(str(e))
-            
-        self.ci_.ch_drop_user("")  # drop all handle associated with current user
-        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
-               
-    def test_client_get_file(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.create_and_load_defs(test,False)
-  
-        while 1:
-            if self.ci_.news_local():
-                self.sync_local(0) # get the changes, synced with local defs
-                suite = self.ci_.get_defs().find_suite(test)
-                assert suite is not None, "Expected to find suite"
-                if suite.get_state() == State.complete:
-                    break;
-            time.sleep(3)
-        try:
-            for file_t in [ 'script', 'job', 'jobout', 'manual' ]:
-                the_returned_file = self.ci_.get_file('/' + test +'/f1/t1',file_t)  # make a request to the server
-                assert len(the_returned_file) > 0,"Expected self.ci_.get_file(/" + test + "/f1/t1," + file_t + ") to return something"
-        except RuntimeError as e:
-            print(str(e))
-    
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-        
-    def test_client_alter_add(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        self.ci_.load(self.create_defs(test))   
-        self.sync_local()  
-    
-        t1 = "/" + test + "/f1/t1"
-        self.ci_.alter(t1,"add","variable","var","var_name")
-        self.ci_.alter(t1,"add","time","+00:30")
-        self.ci_.alter(t1,"add","time","01:30")
-        self.ci_.alter(t1,"add","time","01:30 20:00 00:30")
-        self.ci_.alter(t1,"add","today","+00:30")
-        self.ci_.alter(t1,"add","today","01:30")
-        self.ci_.alter(t1,"add","today","01:30 20:00 00:30")
-        self.ci_.alter(t1,"add","date","01.01.2001")
-        self.ci_.alter(t1,"add","date","*.01.2001")
-        self.ci_.alter(t1,"add","date","*.*.2001")
-        self.ci_.alter(t1,"add","date","*.*.*")
-        self.ci_.alter(t1,"add","day","sunday")
-        self.ci_.alter(t1,"add","day","monday")
-        self.ci_.alter(t1,"add","day","tuesday")
-        self.ci_.alter(t1,"add","day","wednesday")
-        self.ci_.alter(t1,"add","day","thursday")
-        self.ci_.alter(t1,"add","day","friday")
-        self.ci_.alter(t1,"add","day","saturday")
-        self.ci_.alter(t1,"add","late","late -s +00:15 -a 20:00 -c +02:00")
-    
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.variables))) == 1 ,"Expected 1 variable :\n" + str(self.ci_.get_defs())
-        assert( len(list(task_t1.times))) == 3 ,"Expected 3 time :\n" + str(self.ci_.get_defs())
-        assert( len(list(task_t1.todays))) == 3 ,"Expected 3 today's :\n" + str(self.ci_.get_defs())
-        assert( len(list(task_t1.dates))) == 4 ,"Expected 4 dates :\n" + str(self.ci_.get_defs())
-        assert( len(list(task_t1.days))) == 7 ,"Expected 7 days :\n" + str(self.ci_.get_defs())
-        assert str(task_t1.get_late()) == "late -s +00:15 -a 20:00 -c +02:00", "Expected late 'late -s +00:15 -a 20:00 -c +02:00'" + str(self.ci_.get_defs())
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-               
-    def test_client_alter_delete(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        defs = self.create_defs(test)  
-         
-        t1 = "/" + test + "/f1/t1"
-        task_t1 = defs.find_abs_node(t1)
-        task_t1.add_variable("var","value")
-        task_t1.add_variable("var1","value")
-        task_t1.add_time("00:30")
-        task_t1.add_time("00:31")
-        task_t1.add_today("00:30")
-        task_t1.add_today("00:31")
-        task_t1.add_date(1,1,2001)
-        task_t1.add_date(1,1,2002)
-        task_t1.add_day("sunday")
-        task_t1.add_day("monday")
-        cron = Cron()
-        cron.set_week_days( [0,1,2,3,4,5,6] )
-        cron.set_time_series( "+00:30" )
-        task_t1.add_cron(cron)
-        task_t1.add_cron(cron)
-        task_t1.add_event("event")
-        task_t1.add_event("event1")
-        task_t1.add_meter("meter",0,100,100)
-        task_t1.add_meter("meter1",0,100,100)
-        task_t1.add_label("label","name")
-        task_t1.add_label("label1","name")
-        task_t1.add_limit("limit",10)
-        task_t1.add_limit("limit1",10)
-        task_t1.add_inlimit( "limit",t1,2)
-        task_t1.add_inlimit( "limit1",t1,2)
-        task_t1.add_trigger( "t2 == active" )
-        task_t1.add_complete( "t2 == complete" )
-        
-        assert task_t1.get_late() is None, "expected no late" 
-        late = Late()
-        late.submitted(20, 10)
-        late.active(20, 10)
-        late.complete(20, 10, True)
-        task_t1.add_late(late)
-        assert task_t1.get_late() is not None, "expected late" 
-        
-        t2 = "/" + test + "/f1/t2"
-        task_t2 = defs.find_abs_node(t2)
-        task_t2.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
-        
-        self.ci_.load(defs)   
-        self.sync_local()  
-    
-        self.ci_.alter(t1,"delete","variable","var")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.variables))) == 1 ,"Expected 1 variable :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","variable")  # delete all variables
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.variables))) == 0 ,"Expected 0 variable :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","time","00:30")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.times))) == 1 ,"Expected 1 time :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","time")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.times))) == 0 ,"Expected 0 time :\n" + str(self.ci_.get_defs())
-        
-        self.ci_.alter(t1,"delete","today","00:30")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.todays))) == 1 ,"Expected 1 today :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","today")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.todays))) == 0 ,"Expected 0 today :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","date","01.01.2001")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.dates))) == 1 ,"Expected 1 date :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","date")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.dates))) == 0 ,"Expected 0 date :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","day","sunday")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.days))) == 1 ,"Expected 1 day :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","day")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.days))) == 0 ,"Expected 0 day :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","event","event")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.events))) == 1 ,"Expected 1 event :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","event")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.events))) == 0 ,"Expected 0 event :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","meter","meter")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.meters))) == 1 ,"Expected 1 meter :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","meter")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.meters))) == 0 ,"Expected 0 meter :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","label","label")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.labels))) == 1 ,"Expected 1 label :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","label")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.labels))) == 0 ,"Expected 0 label :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","limit","limit")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.limits))) == 1 ,"Expected 1 limit :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","limit")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.limits))) == 0 ,"Expected 0 limit :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","inlimit","limit")
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.inlimits))) == 1 ,"Expected 1 inlimit :\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","inlimit")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.inlimits))) == 0 ,"Expected 0 inlimit :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","cron")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert( len(list(task_t1.crons))) == 0 ,"Expected 0 crons :\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t1,"delete","late")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert task_t1.get_late() is None, "expected no late after delete" 
-    
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert task_t1.get_trigger() is not None, "Expected trigger:\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","trigger")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert task_t1.get_trigger() is None, "Expected trigger to be deleted:\n" + str(self.ci_.get_defs())
-    
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert task_t1.get_complete() is not None, "Expected complete:\n" + str(self.ci_.get_defs())
-        self.ci_.alter(t1,"delete","complete")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        assert task_t1.get_complete() is None, "Expected complete to be deleted:\n" + str(self.ci_.get_defs())
-    
-        self.ci_.alter(t2,"delete","repeat")   
-        self.sync_local()
-        task_t2 = self.ci_.get_defs().find_abs_node(t2)
-        repeat = task_t2.get_repeat()
-        assert repeat.empty(), "Expected repeat to be deleted:\n" + str(self.ci_.get_defs())
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-     
-    def test_client_alter_change(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)   
-        t1 = "/" + test + "/f1/t1"
-        repeat_date_path = "/" + test + "/f1/repeat_date"
-        
-        task_t1 = defs.find_abs_node(t1)
-        task_t1.add_variable("var","value")
-        task_t1.add_variable("var1","value")
-        task_t1.add_event("event")
-        task_t1.add_event("event1")
-        task_t1.add_meter("meter",0,100,100)
-        task_t1.add_meter("meter1",0,100,100)
-        task_t1.add_label("label","name")
-        task_t1.add_label("label1","name1")
-        task_t1.add_limit("limit",10)
-        task_t1.add_limit("limit1",10)
-        task_t1.add_inlimit( "limit",t1,2)
-        task_t1.add_inlimit( "limit1",t1,2)
-        task_t1.add_trigger( "t2 == active" )
-        task_t1.add_complete( "t2 == complete" )
-        late = Late()
-        late.submitted(20, 10)
-        late.active(20, 10)
-        late.complete(20, 10, True)
-        task_t1.add_late(late)
-                
-        f1 = defs.find_abs_node("/" + test + "/f1")
-        repeat_date = f1.add_task("repeat_date")
-        repeat_date.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
-               
-        self.ci_.load(defs)   
-        self.sync_local()  
-    
-        self.ci_.alter(t1,"change","late","-s +10:00")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        variable = task_t1.get_late()
-        assert str(task_t1.get_late()) == "late -s +10:00", "Expected alter of late to be 'late -s +10:00' but found " + str(task_t1.get_late())
-    
-        self.ci_.alter(t1,"change","variable","var","changed_var")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        variable = task_t1.find_variable("var")
-        assert variable.value() == "changed_var", "Expected alter of variable to be 'change_var' but found " + variable.value()
-    
-        self.ci_.alter(t1,"change","meter","meter","10")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        meter = task_t1.find_meter("meter")
-        assert meter.value() == 10, "Expected alter of meter to be 10 but found " + str(meter.value())
-    
-        self.ci_.alter(t1,"change","event","event","set")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        event = task_t1.find_event("event")
-        assert event.value() == True, "Expected alter of event to be set but found " + str(event.value())
-    
-        self.ci_.alter(t1,"change","trigger","t2 == aborted")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        trigger = task_t1.get_trigger()
-        assert trigger.get_expression() == "t2 == aborted", "Expected alter of trigger to be 't2 == aborted' but found " + trigger.get_expression()
-    
-        self.ci_.alter(t1,"change","trigger","/test_client_alter_change/f1/t2 == complete")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        trigger = task_t1.get_trigger()
-        assert trigger.get_expression() == "/test_client_alter_change/f1/t2 == complete", "Expected alter of trigger to be '/test_client_alter_change/f1/t2 == complete' but found " + trigger.get_expression()
-    
-        self.ci_.alter(t1,"change","complete","t2 == aborted")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        complete = task_t1.get_complete()
-        assert complete.get_expression() == "t2 == aborted", "Expected alter of complete to be 't2 == aborted' but found " + complete.get_expression()
-    
-        self.ci_.alter(t1,"change","complete","/test_client_alter_change/f1/t2 == active")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        complete = task_t1.get_complete()
-        assert complete.get_expression() == "/test_client_alter_change/f1/t2 == active", "Expected alter of complete to be '/test_client_alter_change/f1/t2 == active' but found " + complete.get_expression()
-    
-        self.ci_.alter(t1,"change","limit_max","limit", "2")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        limit = task_t1.find_limit("limit")
-        assert limit is not None, "Expected to find limit"
-        assert limit.limit() == 2, "Expected alter of limit_max to be 2 but found " + str(limit.limit())
-    
-        self.ci_.alter(t1,"change","limit_value","limit", "2")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        limit = task_t1.find_limit("limit")
-        assert limit is not None, "Expected to find limit"
-        assert limit.value() == 2, "Expected alter of limit_value to be 2 but found " + str(limit.value())
-    
-        self.ci_.alter(t1,"change","label","label","new-value")   
-        self.sync_local()
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        label = task_t1.find_label("label")
-        assert label.new_value() == "new-value", "Expected alter of label to be 'new-value' but found " + label.new_value()
-        
-        self.ci_.alter(repeat_date_path,"change","repeat","20100113")   
-        self.sync_local()
-        task = self.ci_.get_defs().find_abs_node(repeat_date_path)
-        repeat = task.get_repeat()
-        assert repeat.value() == 20100113, "Expected alter of repeat to be 20100113 but found " + str(repeat.value())
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-     
-    def test_client_alter_flag(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)  
-         
-        t1 = "/" + test + "/f1/t1"
-        task_t1 = defs.find_abs_node(t1)
-               
-        self.ci_.load(defs)   
-        self.sync_local()  
-    
-        flag = Flag()
-        flag_list = flag.list() # flag_list is of type FlagTypeVec
-        for flg in flag_list: 
-            self.ci_.alter(t1,"set_flag",flag.type_to_string(flg) )   
-            self.sync_local()
-            task_t1 = self.ci_.get_defs().find_abs_node(t1)
-            task_flag = task_t1.get_flag()
-            assert task_flag.is_set( flg ),"expected flag %r to be set" % task_flag.type_to_string(flg)
-    
-            # alter itself causes the flag message to be set, and preserved
-            if flg == FlagType.message: continue 
-            
-            self.ci_.alter(t1,"clear_flag",flag.type_to_string(flg) )   
-            self.sync_local()
-            task_t1 = self.ci_.get_defs().find_abs_node(t1)
-            task_flag = task_t1.get_flag()
-            assert not task_flag.is_set( flg ),"expected flag %r NOT to be set" % task_flag.type_to_string(flg)
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-    
-    def test_client_force(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test) 
-         
-        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]       
-        t1 = path_list[0]      
-        for path in path_list:
-            task = defs.find_abs_node(path)
-            assert task is not None, "Expected to find task at path " + path
-            task.add_event("event")
-    
-        self.ci_.load(defs)   
-        self.sync_local()  
-        
-        state_list = [ State.unknown, State.active, State.complete, State.submitted, State.aborted, State.queued ]
-        for state in state_list:
-            self.ci_.force_state(t1,state) 
-            self.sync_local()
-            task = self.ci_.get_defs().find_abs_node(t1)
-            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())      
-        for state in state_list:
-            self.ci_.force_state( path_list,state) 
-            self.sync_local()
-            for path in path_list:
-                task = self.ci_.get_defs().find_abs_node(path)
-                assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())     
-     
-        for state in state_list:
-            self.ci_.force_state_recursive("/" + test,state) 
-            self.sync_local()
-            task = self.ci_.get_defs().find_abs_node(t1)
-            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())
-        suite_paths = [ "/" + test ]
-        for state in state_list:
-            self.ci_.force_state_recursive( suite_paths,state) 
-            self.sync_local()
-            task = self.ci_.get_defs().find_abs_node(t1)
-            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())           
-        
-        event_states = [ "set", "clear" ]
-        for ev_state in event_states:
-            for path in path_list:
-                self.ci_.force_event(path + ":event" , ev_state)
-                self.sync_local()
-                task = self.ci_.get_defs().find_abs_node(path)
-                event_fnd = False
-                for event in task.events:
-                    event_fnd = True
-                    if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
-                    else:                   assert event.value() == False ," Expected event value to be clear"
-                assert event_fnd == True," Expected event to be found"
-    
-        event_path_list = [ "/" + test + "/f1/t1:event", "/" + test + "/f1/t2:event" ]       
-        event_states = [ "set", "clear" ]
-        for ev_state in event_states:
-            self.ci_.force_event( event_path_list , ev_state)
-            self.sync_local()
-            for path in path_list:
-                task = self.ci_.get_defs().find_abs_node(path)
-                event_fnd = False
-                for event in task.events:
-                    event_fnd = True
-                    if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
-                    else:                   assert event.value() == False ," Expected event value to be clear"
-                assert event_fnd == True," Expected event to be found"
-    
-        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
-          
-    def test_client_replace(self,on_disk):
-        test = sys._getframe().f_code.co_name # returns function name
-        if on_disk:
-            test = test + "on_disk"
-        self.log_msg(test)
-        self.ci_.log_msg(str(on_disk))
-         
-        # Create and load the following defs
-        # s1
-        #   f1
-        #     t1
-        #     t2
-        self.ci_.load(self.create_defs(test))  
-        self.sync_local()  
-        
-        #===============================================================================
-        # Example of using replace to ADD a *NEW* node hierarchy to an existing suite
-        # we should end up with:
-        # s1
-        #   f1
-        #     t1
-        #     t2
-        #   f2
-        #     t1
-        client_def = self.create_defs(test)
-        client_def.find_suite(test).add_family("f2").add_task("t1")
-        if on_disk:
-            client_def.save_as_defs(test + ".def")
-            client_def = test + ".def"
-        
-        self.ci_.replace("/" + test + "/f2",client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
-        self.sync_local()  
-        assert self.ci_.get_defs().find_abs_node("/" + test + "/f2/t1") is not None, "Expected to find task /" + test + "/f2/t1\n" + str(self.ci_.get_defs())
-    
-        # Example of using replace to *REMOVE* node hierarchy to an existing suite, could have used delete
-        assert self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1") is not None, "Expected to find task /" + test + "/f1/t1\n" + str(self.ci_.get_defs())
-        assert self.ci_.get_defs().find_abs_node("/" + test + "/f2/t1") is not None, "Expected to find task /" + test + "/f2/t1\n" + str(self.ci_.get_defs())
-        client_def = Defs()
-        client_def.add_suite(test)    # should only have the suite
-        if on_disk:
-            client_def.save_as_defs(test + ".def")
-            client_def = test + ".def"
-    
-        self.ci_.replace("/" + test,client_def)   
-        self.sync_local()  
-        assert self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1") is None, "Expected NOT to find task /" + test + "/f1/t1\n" + str(self.ci_.get_defs())
-        assert self.ci_.get_defs().find_abs_node("/" + test + "/f2/t1") is None, "Expected NOT to find task /" + test + "/f2/t1\n" + str(self.ci_.get_defs())
-    
-        #===============================================================================
-        # Example of using replace to add a *NEW* suite
-        test2 = test + "2";
-        client_def = Defs();
-        client_def.add_suite(test2)
-        if on_disk:
-            client_def.save_as_defs(test + ".def")
-            client_def = test + ".def"
-    
-        self.ci_.replace("/" + test2,client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
-        self.sync_local()  
-        suite = self.ci_.get_defs().find_suite(test2)
-        assert suite is not None ,"Expected to find suite :" + test2 + "\n" + str(self.ci_.get_defs())
-               
-        # replace added suite s2 with a new s2 which has a task, 
-        # s2 must exist on the client defs
-        client_def = Defs();
-        client_def.add_suite(test2).add_task("t1")
-        if on_disk:
-            client_def.save_as_defs(test + ".def")
-            client_def = test + ".def"
-    
-        self.ci_.replace("/" + test2,client_def) 
-        self.sync_local()  
-            
-        assert self.ci_.get_defs().find_abs_node("/" + test2 + "/t1") is not None, "Expected to find task /" + test2 + "/t1\n" + str(self.ci_.get_defs())
-        if on_disk:
-            os.remove(client_def)
-    
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
-        self.ci_.suspend("/" + test2  ) # stop  downstream test from re-starting this
-        self.sync_local()  
-    
-    def test_client_suspend(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        
-        defs = self.create_defs(test)  
-        defs.find_suite(test).add_variable("ECF_DUMMY_TASK","")
-            
-        self.ci_.load(defs)  
-        self.sync_local()  
-        self.ci_.begin_suite(test)  
-        
-        self.ci_.suspend("/" + test )  
-               
-        self.sync_local();
-        suite = self.ci_.get_defs().find_suite(test)
-        assert suite.is_suspended(), "Expected to find suite suspended"
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
-        
-    def test_client_suspend_multiple_paths(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)  
-        suite = defs.find_suite(test)
-        suite.add_variable("ECF_DUMMY_TASK","")
-        
-        self.ci_.load(defs)  
-        self.ci_.begin_suite(test)  
-        self.sync_local()  
-        
-        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]
-        self.ci_.suspend( path_list )  
-               
-        self.sync_local();
-        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
-        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
-        assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
-        assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
-                
-    def test_client_resume(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)  
-        defs.find_suite(test).add_variable("ECF_DUMMY_TASK","")
-            
-        self.ci_.load(defs)  
-        self.ci_.begin_suite(test)  
-        self.sync_local()  
-        
-        self.ci_.suspend("/" + test )  
-        self.sync_local();
-        suite = self.ci_.get_defs().find_suite(test)
-        assert suite.is_suspended(), "Expected to find suite suspended"
-        
-        self.ci_.resume("/" + test )  
-        self.sync_local();
-        suite = self.ci_.get_defs().find_suite(test)
-        assert suite.is_suspended() == False, "Expected to find suite resumed"
-    
-        # suspend to stop down stream tests from restarting this test
-        self.ci_.suspend("/" + test )  
-    
-    def test_client_resume_multiple_paths(self):
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)  
-        defs.find_suite(test).add_variable("ECF_DUMMY_TASK","")
-            
-        self.ci_.load(defs)  
-        self.ci_.begin_suite(test)  
-        self.sync_local()  
-        
-        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]
-        self.ci_.suspend( path_list )  
-      
-        self.sync_local();
-        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
-        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
-        assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
-        assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
-    
-        self.ci_.resume( path_list )  
-        self.sync_local();
-        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
-        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
-        assert task_t1.is_suspended() == False, "Expected to find task t1 to be resumed"
-        assert task_t2.is_suspended() == False, "Expected to find task t2 to be resumed"
-        
-         # suspend to stop down stream tests from restarting this test
-        self.ci_.suspend("/" + test )  
-      
-    def test_client_delete_node(self): 
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)
-        
-        task_vec = defs.get_all_tasks();
-        assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
-    
-        self.ci_.load(defs)  
-        self.sync_local();
-        for task in task_vec:
-            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
-            assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(self.ci_.get_defs()) 
-    
-        for task in task_vec:
-            self.ci_.delete(task.get_abs_node_path())
-    
-        self.sync_local();
-        for task in task_vec:
-            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
-            assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(self.ci_.get_defs())   
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
-        
-    def test_client_delete_node_multiple_paths(self): 
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)
-        
-        task_vec = defs.get_all_tasks();
-        assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
-    
-        paths = []
-        for task in task_vec:
-            paths.append(task.get_abs_node_path()) 
-     
-        self.ci_.load(defs)  
-        
-        self.sync_local();
-        for task in task_vec:
-            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
-            assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(self.ci_.get_defs()) 
-    
-        self.ci_.delete(paths)
-    
-        self.sync_local();
-        for task in task_vec:
-            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
-            assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(self.ci_.get_defs())   
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this    
-    
-    def test_client_check_defstatus(self):            
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        defs = self.create_defs(test)  
-        
-        # stop defs from running when begin is called.
-        defs.find_suite(test).add_defstatus(DState.suspended)
-    
-        t1 = "/" + test + "/f1/t1"
-        t2 = "/" + test + "/f1/t2"
-        task_t1 = defs.find_abs_node(t1)
-        task_t1.add_defstatus(DState.suspended)
-        
-        self.generate_scripts_and_load_defs(defs);
-        self.ci_.begin_suite(test)
-         
-        self.sync_local() # get the changes, synced with local defs
-        #print self.ci_.get_defs();
-        task_t1 = self.ci_.get_defs().find_abs_node(t1)
-        task_t2 = self.ci_.get_defs().find_abs_node(t2)
-        assert task_t1 is not None,"Could not find t1"
-        assert task_t2 is not None,"Could not find t2"
-      
-        assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
-        assert task_t2.get_state() == State.queued, "Expected state queued " + str(task_t2.get_state())
-    
-        assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_state())
-        assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_state())
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
-       
-    def test_ECFLOW_189(self):
-        # Bug, when a node is resumed it ignored holding dependencies higher up the tree.
-        # i.e Previously when we resumed a node, it ignored trigger/time/node state, dependencies higher up the tree
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        self.generate_scripts_and_load_defs(self.create_defs(test));
-        
-        self.ci_.suspend("/" + test  )
-        self.ci_.suspend("/" + test + "/f1/t1")
-        self.ci_.suspend("/" + test + "/f1/t2")
-            
-        self.ci_.begin_suite(test)
-        
-        self.sync_local() # get the changes, synced with local defs
-        #print self.ci_.get_defs();
-        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
-        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
-        assert task_t1 is not None,"Could not find /" + test + "/f1/t1"
-        assert task_t2 is not None,"Could not find /" + test + "/f1/t2"
-      
-        assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
-        assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
-        assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_dstate())
-        assert task_t2.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t2.get_dstate())
-    
-        # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
-        self.ci_.resume("/" + test + "/f1/t1")
-        self.ci_.resume("/" + test + "/f1/t2")
-         
-        self.sync_local() # get the changes, synced with local defs
-        #print self.ci_.get_defs();
-        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
-        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
-        assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
-        assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
-        assert task_t1.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t1.get_dstate())
-        assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_dstate())
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
-    
-    def test_ECFLOW_199(self):
-        # Test ClientInvoker::changed_node_paths
-        test = sys._getframe().f_code.co_name # returns function name
-        self.log_msg(test)
-        self.generate_scripts_and_load_defs(self.create_defs(test));
-        
-        self.ci_.suspend("/" + test  )
-        self.ci_.suspend("/" + test + "/f1/t1")
-        self.ci_.suspend("/" + test + "/f1/t2")
-        self.sync_local() # get the changes, synced with local defs
-    
-        self.ci_.begin_suite(test)
-        
-        self.sync_local() # get the changes, synced with local defs
-        #print self.ci_.get_defs();
-        assert len(list(self.ci_.changed_node_paths)) == 0, "Expected first call to sync_local, to have no changed paths but found " + str(len(list(self.ci_.changed_node_paths)))
-        
-        # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
-        self.ci_.resume("/" + test + "/f1/t1")
-        self.sync_local() 
-        if len(list(self.ci_.changed_node_paths)) != 1:
-            for path in self.ci_.changed_node_paths:
-                print("   changed node path " + path);
-            assert False, "Expected 1 changed path but found " + str(len(list(self.ci_.changed_node_paths)))
-    
-        self.ci_.resume("/" + test + "/f1/t2")
-        self.sync_local() 
-        if len(list(self.ci_.changed_node_paths)) != 1:
-            for path in self.ci_.changed_node_paths:
-                print("   changed node path " + path);
-            assert False, "Expected 1 changed path but found " + str(len(list(self.ci_.changed_node_paths)))
-            
-        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
-
-    
-    def test_gui(self):   
-        self.ci_.delete_all() # start fresh
-        self.test_version()
-        PrintStyle.set_style( Style.STATE ) # show node state 
-        self.test_client_get_server_defs()             
-                 
-        self.test_client_restart_server()             
-        self.test_client_halt_server()             
-        self.test_client_shutdown_server()   
-             
-        self.test_client_load_in_memory_defs()             
-        self.test_client_load_from_disk()             
-        self.test_client_checkpt()             
-        self.test_client_restore_from_checkpt()             
-                  
-        self.test_client_reload_wl_file()             
-          
-        self.test_client_run()  
-        self.test_client_run_with_multiple_paths()     
-        self.test_client_requeue()             
-        self.test_client_requeue_with_multiple_paths()             
-        self.test_client_free_dep()              
-         
-        self.test_client_suites()
-        self.test_client_ch_suites()  
-        self.test_client_ch_register()             
-        self.test_client_ch_drop()             
-        self.test_client_ch_drop_user()             
-        self.test_client_ch_add()             
-        self.test_client_ch_auto_add()             
-        self.test_client_ch_remove()             
-                    
-        self.test_client_get_file()             
-        self.test_client_alter_add() 
-        self.test_client_alter_delete() 
-        self.test_client_alter_change() 
-        self.test_client_alter_flag() 
-       
-        self.test_client_force()             
-        self.test_client_replace(False)             
-        self.test_client_replace(True)             
-         
-        self.test_client_suspend()             
-        self.test_client_suspend_multiple_paths()             
-        self.test_client_resume()             
-        self.test_client_resume_multiple_paths()             
-        self.test_client_delete_node()             
-        self.test_client_delete_node_multiple_paths()             
-         
-        self.test_client_check()  
-        self.test_client_check_defstatus()  
-         
-        self.test_ECFLOW_189()         
-        self.test_ECFLOW_199()         
-
-if __name__ == "__main__":
-    
-    DESC = """Will run various tests on the server. These will be used to test the GUI
-              This assumes that gui has been set to sync every second, as this will allows changes
-              in the server to be reflected in the GUI.
-              The test will sleep for sync_sleep seconds, after each change to the server.
-              This should allow GUI (1 second poll), to see the effects of this test.
-              To debug this tests, just set sync_sleep = 0, this will also preserve the test data.
-                 - Test data is created in directory: test_gui, this will deleted at the end of the test.
-                 - Assumes includes head.h and tail.h are in CWD + /Pyext/test/data/includes
-                 - We will look for the ecflow_client in the embedded child commands in the generated scripts, 
-                   o first look in the current cmake build tree of the ecflow module(this may no longer exist)
-                   o Next will use /usr/local/apps/ecflow/ with same version as this ecflow python api *IF* it exists
-                   o Finally use 'ecflow_client' hence will expect to find it on $PATH, *ON* the server environment
-                   To override this use --ecflow_client=/path/to/your/ecflow_client
-              Usage:
-                   TestGui.py --host <hostname> --port <portname> --time <sec> --sync_sleep <sec> --ecflow_client <path>
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--host', default="localhost",   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default="3141",   
-                        help="The port on the host, defaults to 3141")
-    PARSER.add_argument('--time', default=0,   
-                        help="How long to run the tests in seconds. default is 0, which is one test loop")
-    PARSER.add_argument('--sync_sleep', type=int,default=4,   
-                        help="Time to wait after sync_local. Allow GUI to refresh. Set to 0 for debug.")
-    PARSER.add_argument('--ecflow_client',default="",   
-                        help="Path to ecflow_client.")
-    ARGS = PARSER.parse_args()
-    print ARGS   
-    if ARGS.ecflow_client != "":
-        if not os.path.exists(ARGS.ecflow_client):
-            print("Could not find ecflow_client on path ",ARGS.ecflow_client)
-            sys.exit(1)
-     
-    # ===========================================================================
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    tester = Tester(CL,ARGS)
-    try:
-        CL.ping() 
-        tester.clean_up_data()
-        tester.clean_up_server()
-        
-        count = 1
-        start_time = time.time()
-        while True:
-            tester.test_gui()
-            elapsed = int(time.time() - start_time)
-            print "======================================================"
-            print "elapsed time :",elapsed, "s loop:",count
-            print "======================================================"
-            count += 1
-            if elapsed > int(ARGS.time):
-                break
-                
-    except RuntimeError, ex:
-        print "Error: " + str(ex)
-        print "Check host and port number are correct."
-
-    # When debugging keep test data.
-    if ARGS.sync_sleep != 0:
-        tester.clean_up_server()
-        tester.clean_up_data()
diff -pruN 5.12.4-1/Pyext/samples/TestJobGenPerf.py 5.13.0-1/Pyext/samples/TestJobGenPerf.py
--- 5.12.4-1/Pyext/samples/TestJobGenPerf.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/TestJobGenPerf.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,156 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# =============================================================================
-# Code for testing *any* definition
-#   Since any ad hoc definition will reference local directories in the
-#   ECF_ variables, we need to remove them and inject our own.
-#
-#   This test was created aid the performance testing of job generation
-#   It is tied to ANode/parser/test/TestJobGenPerf.cpp
-# =============================================================================
-import ecflow
-import os       # for getenv
-import sys
-import shutil   # used to remove directory tree
-import argparse # for argument parsing     
-
-def delete_variables_affecting_job_generation(node): 
-    """delete customer related ECF variables, these will point to directories
-       that don't exist. Its ok we will regenerate our own local ones"""
-    var = node.find_variable("ECF_HOME")
-    if not var.empty() :  
-        node.delete_variable("ECF_HOME")    
-    var = node.find_variable("ECF_FILES")
-    if not var.empty() :  
-        node.delete_variable("ECF_FILES")    
-    var = node.find_variable("ECF_INCLUDE")
-    if not var.empty() :  
-        node.delete_variable("ECF_INCLUDE")    
-    var = node.find_variable("ECF_JOB_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_JOB_CMD")    
-    var = node.find_variable("ECF_KILL_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_KILL_CMD")    
-    var = node.find_variable("ECF_STATUS_CMD")
-    if not var.empty() :  
-        node.delete_variable("ECF_STATUS_CMD")    
-    var = node.find_variable("ECF_OUT")
-    if not var.empty() :  
-        node.delete_variable("ECF_OUT")    
-      
-def traverse_container(node_container):
-    """Recursively traverse definition node hierarchy and delete
-       the variables that affect job generation.
-    """
-    delete_variables_affecting_job_generation(node_container)
-    for node in node_container.nodes:
-        delete_variables_affecting_job_generation(node)
-        if not isinstance(node, ecflow.Task):
-            traverse_container(node)  
-    
-if __name__ == "__main__":
-    
-    DESC = """Will allow any definition to be loaded and played on the server
-            This is done by:
-            o Remove existing ECF_ variables that affect job generation. 
-              i.e variables that refer to customer specific directories are removed
-            o Allows ECF_HOME to specified, defaults to ./CUSTOMER/ECF_HOME
-            o Generates the scripts(.ecf files) automatically based on the definition.
-              i.e if a task has events,meters,labels then the client request for these are
-              automatically injected in the generated .ecf script files
-            o Will clear out existing data both on disk and on the server to allow 
-              multiple re-runs of this script. ** If this is an issue please use
-              a test server **
-            This programs assumes that ecflow module is accessible.
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('defs_file', 
-                        help="The definition file")
-    PARSER.add_argument('--ecf_home', default="/var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf/ECF_HOME",
-                        help="Directory to be used for generated scripts(ECF_HOME), defaults to /var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf/ECF_HOME")
-    PARSER.add_argument('--verbose', nargs='?', default=False, const=True, type=bool,
-                        help="Show verbose output")
-    ARGS = PARSER.parse_args()
-    ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
-    print(ARGS)    
-    
-    # If running on local work space, use /Pyext/test/data/CUSTOMER/ECF_HOME as ecf_home
-    if not ARGS.ecf_home:
-        if os.getenv("WK") is None:
-            print("No ecf_home specified. Please specify a writable directory")
-            sys.exit(1)
-        ARGS.ecf_home = "/var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf/ECF_HOME"
-        if ARGS.verbose:
-            print("Workspace is defined") 
-            print("using /Client/bin/gcc\-4.5/debug/ecflow_client")
-
-    print("Using ECF_HOME=" + ARGS.ecf_home)
-    print("removing directory " + ARGS.ecf_home)
-    try:
-        shutil.rmtree(ARGS.ecf_home)   
-    except:
-        pass   
-        
-    if not os.path.exists(ARGS.ecf_home): 
-        print(ARGS.ecf_home + " directory does not exist, creating")
-        os.makedirs(ARGS.ecf_home)
-
-    print("\nloading the definition from the input arguments(" + ARGS.defs_file + ")\n")
-    
-    try:
-        DEFS = ecflow.Defs(ARGS.defs_file)
-    except RuntimeError as ex:
-        print("   ecflow.Defs(" + ARGS.defs_file + ") failed:\n" + str(ex))
-        sys.exit(1)
-    
-    if ARGS.verbose: 
-        print("remove test data associated with the DEFS, so we start fresh, Allows rerun")
-    for suite in DEFS.suites:
-        dir_to_remove = ARGS.ecf_home + suite.get_abs_node_path()
-        if ARGS.verbose: 
-            print("   Deleting directory: " + dir_to_remove + "\n")
-        shutil.rmtree(dir_to_remove, True)  
-        
-    if ARGS.verbose: 
-        print("remove remote reference to ECF_HOME and ECF_INCLUDE, since we inject or own\n")
-    for suite in DEFS.suites:
-        print("add variables required for script generation, for all suites\n")
-        traverse_container(suite)
-  
-        suite.add_variable("ECF_HOME", ARGS.ecf_home)
-        suite.add_variable("ECF_INCLUDE", ARGS.ecf_home + "/includes")
-        suite.add_variable("ECF_CLIENT_EXE_PATH", os.getenv("WK") + "/Client/bin/gcc\-4.8/debug/ecflow_client")
-        suite.add_variable("SLEEP", "10")  # not strictly required since default is 1 second
-
-
-    
-    # ecflow.PrintStyle.set_style(ecflow.Style.STATE)
-    #if ARGS.verbose: 
-    #print DEFS
-    DEFS.generate_scripts()
-
-    if ARGS.verbose: 
-        print("\nchecking script file generation, pre-processing & variable substitution\n")
-    JOB_CTRL = ecflow.JobCreationCtrl()
-    DEFS.check_job_creation(JOB_CTRL)       
-    assert len(JOB_CTRL.get_error_msg()) == 0, JOB_CTRL.get_error_msg()
-    
-    
-    newDefs = ARGS.ecf_home + "/../" + os.path.basename(ARGS.defs_file)
-    print("Saving modified defs as " + newDefs) 
-    DEFS.save_as_defs(newDefs)
-
diff -pruN 5.12.4-1/Pyext/samples/TestServerGetDefs.py 5.13.0-1/Pyext/samples/TestServerGetDefs.py
--- 5.12.4-1/Pyext/samples/TestServerGetDefs.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/TestServerGetDefs.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# This test is a simple client that, repeatedly calls gets defs
-# This is used to stress test the server to determine how many defs
-# can be called before the server gets overloaded
-
-import datetime
-import time, sys
-from ecflow import Client   
-      
-def main(ci,inc = 2):
-    while True:
-        start_time = datetime.datetime.now()
-        try:
-            ci.get_server_defs() 
-        except RuntimeError as e : 
-            print("Error:" + str(e))
-
-        print("get_server_defs took: " + str(datetime.datetime.now() - start_time))
-        time.sleep(inc)
-
-if __name__ == "__main__":
-
-    numargs = len(sys.argv) - 1
-    #print "numargs = " + str(numargs)
-    #i = 0;
-    #while i < len(sys.argv):
-        #print "arg " + str(i) + ": " + sys.argv[i]
-        #i =  i + 1
-        
-    if  numargs > 3:
-        print("usage: " + sys.argv[0] + " host port  seconds_delay")
-        sys.exit(1)
-        
-    port = "3142"
-    host = "localhost"
-    inc  = 1
-    if numargs >= 1:  host = sys.argv[1];
-    if numargs >= 2:  port = sys.argv[2]
-    if numargs >= 3:  inc = int(sys.argv[3])
-        
-    #print "host(" + host + ") port(" + port + ") delay between get_server_defs(" + str(inc)   +")"
-
-    ci = Client(host,port)
-    ci.ping()    
-
-    main(ci,inc)
-    
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/samples/TestSyncLocalPerf.py 5.13.0-1/Pyext/samples/TestSyncLocalPerf.py
--- 5.12.4-1/Pyext/samples/TestSyncLocalPerf.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/TestSyncLocalPerf.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,65 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import time
-import argparse # for argument parsing  
-from ecflow import Client, debug_build
-
-def timing_decorator(function_to_time):
-    def scafold(*function_args):
-        # function_args is a tuple, the second argument is the suite name
-        start = time.time()
-        function_return = function_to_time(*function_args)
-        end = time.time()
-        print('%s function took %0.3f ms for %s' % (function_to_time.__name__, (end-start)*1000.0, function_args[1]))
-        return function_return
-    return scafold
-
-@timing_decorator
-def sync_local(ci,suite_name):
-    ci.sync_local()
-
-if __name__ == "__main__":
-    
-    DESC = """This test is use to show the performance of sync local on the given server
-              It should show that it is quicker to register and then sync_local()
-              as this limits the amount of data that needs to be down loaded from the
-              server.
-              Usage:
-                   TestSyncLocalPerf.py --host <hostname> --port <portname>  
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--host', default="localhost",   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default="3141",   
-                        help="The port on the host, defaults to 3141")
-    ARGS = PARSER.parse_args()
-    print(ARGS)   
-     
-    print("####################################################################")
-    print(("Test performance of sync local using " + Client().version() + " debug build(" + str(debug_build()) +")"))
-    print("####################################################################")
-
-    CL = Client(ARGS.host, ARGS.port)
-    sync_local(CL,"* All suites *")   # timing for downloading all suites
-    print("")
-
-    suites = CL.get_defs().suites
-    for suite in suites:
-        CL.ch_register(False,[suite.name()])
-        
-        sync_local(CL,suite.name()) # time this
-        
-        CL.ch_drop()  # drop the last registered handle
-            
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/samples/add_stdexept_include.py 5.13.0-1/Pyext/samples/add_stdexept_include.py
--- 5.12.4-1/Pyext/samples/add_stdexept_include.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/add_stdexept_include.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-# find all cpp file that have std::runtime_error.
-# if these file dont have #include <stdexcept> add it as the first include
-
-import os,fnmatch
-
-def all_files(root, patterns='*', single_level=False, yield_folders=False):
-    """Expand patterns from semi-colon separated string to list"""
-    patterns = patterns.split(';')
-    for path, subdirs, files in os.walk(root):
-        if yield_folders:
-            files.extend(subdirs)
-        files.sort()
-        for name in files:
-            for pattern in patterns:
-                if fnmatch.fnmatch(name,pattern):
-                    yield os.path.join(path, name)
-                    break
-        if single_level:
-            break    
-        
-for cpp_file in all_files('.', '*.cpp'):
-    if 'cereal' in cpp_file:
-        continue
-    #print(cpp_file)
-    file_obj = open(cpp_file,'r')
-    try:
-        list_of_all_lines = file_obj.readlines()
-        
-        has_runtime_error = False
-        has_correct_include = False
-        for line in list_of_all_lines:
-            if 'std::runtime_error' in line:
-                has_runtime_error = True
-            if '#include <stdexcept>' in line:
-                has_correct_include = True
-                
-        if has_runtime_error:
-            #print(cpp_file, " uses std::runtime_error ", has_correct_include )
-            if not has_correct_include:
-                print(cpp_file," modifying")
-                # add #include <stdexcept>
-                added_include = False
-                new_list = []
-                for line in list_of_all_lines:
-                    if not added_include and '#include' in line:
-                        new_list.append('#include <stdexcept>\n')
-                        added_include = True
-                    new_list.append(line)
-                    
-                changed_file = open(cpp_file,'w')
-                changed_file.writelines(new_list)
-                changed_file.close()
-    finally:
-        file_obj.close()
-        
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/samples/api/README 5.13.0-1/Pyext/samples/api/README
--- 5.12.4-1/Pyext/samples/api/README	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/api/README	1970-01-01 00:00:00.000000000 +0000
@@ -1,2 +0,0 @@
-This folder contains an example of extending the ecflow python API.
-It adds another convenience layer, that is used by operations.
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/samples/api/ecf.py 5.13.0-1/Pyext/samples/api/ecf.py
--- 5.12.4-1/Pyext/samples/api/ecf.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/api/ecf.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,2603 +0,0 @@
-#!/usr/bin/env python
-# coding=utf-8
-# This software is provided under the ECMWF standard software license agreement.
-# file deepcode ignore PythonConstantBinaryExpression: legacy
-""" a layer over raw ecflow api
-
-use 'export ECF_DEBUG_LEVEL=10' to remove warning message related to
-variables overwrite
-
-specialisation module for ecFlow nodes/attributes:
-initially it was simple derivation
-then it is composition
-
-
-https://pypi.python.org/pypi/anytree
-pip install anytree --user
-
-20180126 https://www.python.org/dev/peps/pep-0343/
-"""
-from __future__ import print_function    # (at top of module)
-import sys
-import pwd
-import os
-import unittest
-try:
-    import ecflow
-except ImportError:
-    loc = "/usr/local/apps/ecflow/current/lib/python2.7/site-packages/ecflow"
-    sys.path.append(loc)  # centre
-    loc = "/usr/local/lib/python2.7/site-packages"
-    sys.path.append(loc)  # elearning
-    import ecflow
-ecflow.Ecf.set_debug_level(3)
-global DEFS
-
-DEFS = ecflow.Defs()
-# DEBUG = True
-DEBUG = False
-DECORATE = "ALL"
-# DECORATE = "ONLY_TRIGGER"
-# DECORATE = "NO_TRIGGER"
-# DECORATE = "ONLY_EVENT"
-# DECORATE = "NO_ATTRIBUTE"
-
-USE_TIME = True
-USE_LATE = False
-USE_TRIGGER = True
-USE_LIMIT = True
-CPUTIME = True
-USE_VERIFY = True
-
-
-class DefError(Exception):
-    pass
-
-
-if DECORATE == "NO_TRIGGER":
-    USE_TRIGGER = False
-    USE_LIMIT = True
-    USE_EVENT = True
-elif DECORATE == "ALL":
-    USE_TRIGGER = True
-    USE_LIMIT = True
-    USE_EVENT = True
-else:
-    raise DefError
-
-
-def get_username():
-    return pwd.getpwuid(os.getuid())[0]
-
-
-def get_uid():
-    return pwd.getpwnam(get_username()).pw_uid
-
-
-home = os.getenv("HOME") + "/ecflow_server"
-user = os.getenv("USER")
-
-ECF_PORT = os.getenv("ECF_PORT", 1500 +
-                     int(pwd.getpwnam(get_username()).pw_uid))
-ECF_HOME = os.getenv("ECF_HOME", "localhost")
-CLIENT = ecflow.Client(ECF_HOME + ":%s" % ECF_PORT)  # PYTHON CLIENT
-deployed = []
-
-
-def deploy(script, pathname, extn=".ecf"):
-    if pathname in deployed:
-        return  # create once
-    else:
-        deployed.append(pathname)
-    if extn in pathname:  # surround .ecf with head, tail:
-        script = "%include <head.h>\n" + script + "\n%include <tail.h>"
-    with open(pathname, 'w') as destination:  # overwrite!
-        print(script, file=destination)
-        print("#MSG: created", pathname)
-# deploy("echo acq %TASK%", files + acq + extn)  # create wrapper
-# deploy("ecflow_client --label info %TASK%", files + post + extn)
-
-
-###################################################################################################
-head_h = """#!%SHELL:/bin/bash%
-#set -e # stop the shell on first error
-#set -u # fail when using an undefined variable
-#set -x # echo script lines as they are executed
-
-# Defines the variables that are needed for any communication with ECF
-export ECF_PORT=%ECF_PORT%    # The server port number
-export ECF_HOST=%ECF_HOST%    # where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-export ECF_RID=$$             # record the process id. Also used for
-                              # zombie detection
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%   # if server is SSL make sure client is
-fi
-
-# Define the path where to find ecflow_client
-# make sure client and server use the *same* version.
-# Important when there are multiple versions of ecFlow
-export PATH=/usr/local/apps/ecflow/%ECF_VERSION%/bin:$PATH
-export PATH=$PATH:/usr/local/apps/ecflow/bin:/usr/local/bin
-
-# Define a error handler
-ERROR() {
-   set +e                      # Clear -e flag, so we don't fail
-   wait                        # wait for background process to stop
-   ecflow_client --abort=trap  # Notify ecFlow that something went
-                               # wrong, using 'trap' as the reason
-   trap 0                      # Remove the trap
-   exit 0                      # End the script
-}
-
-# Tell ecFlow we have started
-ecflow_client --init=$$
-set -eux
-"""
-
-tail_h = """
-set +x
-wait           # wait for background process to stop
-ecflow_client --complete  # Notify ecFlow of a normal end
-trap 0                    # Remove all traps
-exit 0                    # End the shell
-"""
-
-
-def create_head_and_tail(ecf_home=None, head="head.h", tail="tail.h"):
-    if ecf_home is None:
-        HOME = os.getenv("HOME")
-        ecf_home = HOME + "/ecflow_server/include/"
-
-    if not os.path.exist(head):
-        with open(ecf_home + head, 'w') as fip:
-            write(head_h, file=fip)
-
-    if not os.path.exist(tail):
-        with open(ecf_home + tail, 'w') as fip:
-            write(tail_h, file=fip)
-
-
-class CWN(object):
-    """ CWN is for current working node
-    so that new attributes and node are attached to it,
-    when there is wish not to use .add() FP syntax """
-
-    __CDP = False
-    __CWN = []
-
-    @classmethod
-    def cdp(cls, active=False):
-        CWN.__CDP = active
-        if active and CWN.is_empty():
-            return
-        if DEBUG:
-            print("#DBG: CWN reset")
-        CWN.__CWN = []
-
-    @classmethod
-    def is_empty(cls):
-        return len(CWN.__CWN) == 0
-
-    @classmethod
-    def pop(cls):
-        if CWN.is_empty():
-            return
-        if DEBUG:
-            print("#BDG: pop")
-        CWN.__CWN.pop()
-
-    @classmethod
-    def last(cls):
-        if CWN.is_empty():
-            return None
-        return CWN.__CWN[-1]
-
-    def __init__(self, item=None):
-
-        def name(item):
-            if DEBUG:
-                if type(item) in (Event, Meter, Label):
-                    print("#BDG:", type(item), "%s" % item.real)
-                elif type(item) in (Clock, ):
-                    print("#BDG:", type(item), "%s" % item.real)
-                else:
-                    print("#BDG:", type(item), item.real.name())
-
-        if item is None or not CWN.__CDP:
-            # print("#BDG: no item")
-            return
-
-        if type(item) == Suite and CWN.is_empty():
-            DEFS.add_suite(item.real)
-            CWN.__CWN.append(item)
-            print("#BDG: append suite", item.name())
-            return
-
-        if id(item) == id(CWN.last()):  # __eq__ is used for trigger str
-            return
-
-        if type(item) == Suite:
-            if not CWN.is_empty():
-                print("#WAR: changing CWN from", CWN.__CWN.name(), "to",
-                      item.name())
-            CWN.__CWN.append(item)
-        elif item is None:
-            pass
-        elif item.real is None:
-            pass
-        elif CWN.is_empty():
-            raise DefError("#ERR: no node!")
-        else:
-            if type(CWN.last()) == Task and type(item) in (Task, Family):
-                CWN.pop()
-            # print("#DBG:", CWN.last().name(), type(item))
-            name(item)
-            item.add_to(CWN.last())
-            if type(item) in (Task, Family):
-                # print("#DBG: append", item.name(), type(item))
-                CWN.__CWN.append(item)
-            # else: print("#DBG: add", type(item), "to", CWN.last().name())
-
-
-def obsolete():
-    if 1:
-        return
-    raise DefError
-
-
-def raise_int(arg):
-    if 0:
-        return
-    if "/none" in arg:
-        raise DefError("None!!!", arg)
-    if arg in ("1==0", "0==1", "1==1", "0==0"):
-        return
-    if arg[0] in ("0", "1", "2", "3", "4", "5", "6", "7", "8", "9"):
-        raise DefError("please add ./", arg)
-
-
-def set_raw_mode(kind=True):
-    import sms2ecf
-    sms2ecf.RAW_MODE = kind
-
-
-LINKTASK = False  # FD
-# LINKTASK = True  # RD mode v we turn task into families,
-# with a leaf a task matching script name
-
-
-def linktask(name, real="get", add=None, fam=None, task=True):
-    """ give a change to avoid UNIX links time consuming for maintenance, update
-    perforce git
-    name: original name
-    real: script/task wrapper name
-    add: attributes that shall be added to the leaf task,
-         eg Label, Event, Meter
-    """
-    if fam is None:
-        fam = name
-    try:
-        import parameters as ip
-        # if ip.USER == "rdx": global LINKTASK; LINKTASK = True  # acceptance
-        # if ip.USER == "emos": global LINKTASK; LINKTASK = False  # acceptance
-    except ImportError:
-        pass
-    if LINKTASK:
-        return Task(name)  # RD???
-    return Family(fam).add(
-        Task(real).add(add, If(task, Edit("TASK", name))))
-
-
-def translate(name, value=None):
-    """ Translate from sms to ecflow """
-    try:
-        import sms2ecf
-    except ImportError:
-        return name, value
-
-    def is_sms():
-        if sys.argv[-1] in ("sms", "ligarius"):
-            sms2ecf.ECF_MODE = "sms"
-            return True
-        return sms2ecf.ECF_MODE == "sms"
-    if is_sms():
-        sms2ecf.ECF_MODE = "sms"
-        return sms2ecf.translate(name, value)
-    return name, value
-
-
-# USE_EXTERN = 1
-# NO_EXTERN_ALONE = 0 # set to 1 for test/activate
-
-
-class Extern(object):
-    """ extern may be collected and added as soon as Defs is created """
-
-    def __init__(self, path):
-        # if type(path) not in (tuple, list, str): raise DefError(type(path))
-
-        if type(path) in (tuple, list):
-            for ppp in path:
-                Extern(ppp)
-
-        elif isinstance(path, str):
-            if DEBUG:
-                print("#MSG: extern", path)
-            if ".Extern" in path:
-                raise Exception
-            if ":" in path:
-                # define parent so user does not have to
-                Extern(path.split(":")[0])
-
-            if path == "":
-                pass
-            elif DEFS is not None:
-                if ".Extern" in path:
-                    raise DefError(type(path))
-                DEFS.add_extern(str(path))
-            else:
-                raise DefError
-
-        elif path is None:
-            pass
-
-        else:
-            raise DefError(type(path), path)
-
-    def add_to(self, node):
-        return None
-
-
-class State(object):
-    """ this class aims at affording a user the possibility to add Triggers as
-    t1 = Task("t1")
-    Task("ts").add(Trigger(t1 == COMPLETE))
-
-    SUBMITTED, ACTIVE, SUSPENDED, ABORTED, QUEUED, COMPLETE, UNKNOWN
-    are instance of this class.
-    """
-
-    def __init__(self, state):
-        """ store the status """
-        self.state = str(state)
-
-    def __str__(self):
-        """ translate into string """
-        return "%s" % self.state
-
-    def __protect(self, num):
-        if type(num[0]) == int:
-            return "./" + num
-        return num
-
-    def __eq__(self, arg):
-        """ when == is used,
-        we should care about task name starting with 0-9"""
-        if type(arg) == str:
-            return self.__protect(arg) + " == " + self.state
-        elif isinstance(arg, Node):
-            return arg.fullname() + " == " + self.state
-        elif isinstance(arg, ecflow.Node):
-            return arg.get_abs_node_path() + " == " + self.state
-        return False
-
-    def __ne__(self, arg):
-        """ aka != """
-        if type(arg) == str:
-            return self.protect(arg) + " != " + self.state
-        elif isinstance(arg, Node):
-            return arg.load.get_abs_node_path() + " != " + self.state
-        return False
-
-    def value(self):
-        """ return state """
-        return self.state
-
-    def eval(self, node):
-        """ return state """
-        return self.state == node.get_state()
-
-
-SUBMITTED = State("submitted")
-ACTIVE = State("active")
-SUSPENDED = State("suspended")
-ABORTED = State("aborted")
-QUEUED = State("queued")
-COMPLETE = State("complete")
-UNKNOWN = State("unknown")
-
-
-class Attribute(object):
-    """ generic attribute to be attached to a node"""
-
-    def __init__(self):
-        self.load = None
-        # CWN(self)
-
-    def __enter__(self):
-        CWN(self)
-
-    def __exit__(self, type, value, traceback):
-        pass
-    # def __exit__(self): pass
-
-    def add_to(self, node):
-        """ use polymorphism to attach attribute to a node"""
-        raise DefError("ERR: virtual class")
-
-    def __get_attr__(self, attr):
-        return getattr(self.load, attr)
-
-    @property
-    def real(self):
-        return self.load
-
-
-class Label(Attribute):
-    """wrap around label"""
-
-    def __init__(self, name, msg=""):
-        self.load = ecflow.Label(name, msg)
-        CWN(self)
-
-    def add_to(self, node):
-        """add_label"""
-        node.load.add_label(self.load)
-        return node
-
-
-class Meter(Attribute):
-    """wrap around meter"""
-
-    def __init__(self, name, beg, end, thr=None):
-        if thr is None:
-            thr = end
-        self.load = ecflow.Meter(name, beg, end, thr)
-        CWN(self)
-
-    def add_to(self, node):
-        """ add_meter"""
-        node.load.add_meter(self.load)
-        return node
-
-
-class Event(Attribute):
-    """ wrap around event"""
-
-    def __init__(self, name="", num=0):
-        if type(name) == str:
-            if " " in name:
-                num, name = name.split(" ")
-        try:
-            if int(num) > 100000:
-                num = ""
-        except:
-            pass
-        self.load = None
-        if type(name) is int and num == 0:
-            num = name
-            name = ""
-
-        if type(name) is int and type(num) == str:
-            self.load = ecflow.Event(name, num)
-        elif type(name) is str and type(num) == int:
-            self.load = ecflow.Event(num, name)
-        elif type(name) is str and type(num) == str:
-            if num == "":
-                self.load = ecflow.Event(name)
-            elif name == "":
-                self.load = ecflow.Event(num)
-            else:
-                self.load = ecflow.Event(int(num), name)  # print("#str str")
-        else:
-            self.load = ecflow.Event(name)
-        CWN(self)
-
-    def add_to(self, node):
-        """ add_event"""
-        for test in node.load.events:
-            if test.name() == self.load.name():
-                if (test.number() == self.load.number() and
-                        test.name() == self.load.name()):
-                    return
-                # else: raise Exception(test.number(), self.load.number(),
-                #                      test.name(), self.load.name())
-        node.load.add_event(self.load.number(), self.load.name())
-        return node
-
-
-class Inlimit(Attribute):
-    """ a class to host a path for a limit
-        silently ignore if USE_LIMIT is False,
-        (in debug mode) """
-
-    def __init__(self, fullpath, tokens=1):
-        self.load = None
-        if USE_LIMIT:
-            try:
-                (path, name) = fullpath.split(":")
-            except ValueError:
-                name = fullpath
-                path = ""
-            if name is None:
-                raise DefError
-            # if '-prod' in name: name = name.split('-')[0]  # vdiss-prod
-            if '-' in name:
-                name = name.replace('-', '_')
-            if "None" in path or "None" in name:
-                raise DefError(path, name, fullpath)
-            if " " in name:
-                name, tokens = name.split(" ")
-            self.load = ecflow.InLimit(name, path, int(tokens))
-            self.path_ = path
-            self.name_ = name
-            self.tokens_ = tokens
-            CWN(self)
-
-    def add_to(self, node):
-        """ add_inlimit"""
-        if not USE_LIMIT:
-            return
-        if self.load is None:
-            raise DefError
-        # if type(node.real) in (ecflow.Task, ecflow.Family):
-        for dup in node.real.inlimits:
-            # print(dup.name, self.load.name())
-            if (dup.name() == self.load.name() and
-                    dup.path_to_node() == self.load.path_to_node()):
-                return None
-        node.load.add_inlimit(self.load)
-        return node
-
-    def value(self):
-        """ get limit fullpath-name """
-        return self.path_ + ":" + self.name_
-
-    def name(self):
-        """ get limit name """
-        return self.name_
-
-
-class InLimit(Inlimit):
-    pass
-
-
-def item_to_string(prev, index, name):
-    """ index not used... """
-    if name is None:
-        return ""
-    if name == "":
-        return prev
-    if "<main>" in name:
-        raise DefError
-    if "==" in name:
-        return name
-    if len(name) > 0:
-        if name[0].isdigit():
-            pre = "./"  # "0123456789":
-            name = pre + name
-    if prev is None or prev == "":
-        if ':' in name or name == "":
-            return name
-        else:
-            return "%s == complete" % name
-    if ' or ' in name:
-        if "complete" in name:
-            return prev + "%s" % name
-        elif ":" in name:
-            return prev + "%s" % name
-        else:
-            return prev + "%s == complete" % name
-    elif ':' in name:  # event: and x:1
-        return prev + " and %s" % name
-    elif 'complete' in name:  # complete: and x == complete
-        return prev + " and %s" % name
-    else:
-        return prev + " and %s == complete" % name
-
-
-class Trigger(Attribute):
-    """ add trigger (string, list of task names, or directly
-           expression and: and'ed (True) or or'ed (False) unk: add or
-           [name]==unknown for RD """
-
-    def __init__(self, expr, unk=False, anded=True):
-        self.expr = ""
-        self.load = None
-        if expr is None or expr == "":
-            return
-        if type(expr) == str:
-            if "%s" in expr:
-                raise DefError("ERR:", expr)
-            if "%d" in expr:
-                raise DefError("ERR:", expr)
-            self.expr = expr
-            try:
-                import parameters as ip
-                dim = len(ip.SELECTION)
-                for ploc in expr.split():
-                    if ploc[0] == '/' and ip.SELECTION != ploc[1:dim + 1]:
-                        if ploc in ("eq", "ne", "==", "!=", "and", "or",
-                                    "active", "complete", "queued", ):
-                            continue
-                        if ploc.isdigit():
-                            continue
-                        # Extern(ploc.replace("==complete", "").replace(")", ""))
-            except AttributeError:
-                pass
-            except ImportError:
-                pass
-            # NO_EXTERN_ALONE = 0 # set to 1 for test/activate
-            return
-        if type(expr) == tuple:
-            prep = list(expr)
-            expr = prep
-
-        if type(expr) == Task:
-            pnode = expr.fullname()
-            if pnode[0] != '/':
-                pnode = expr.name()
-            try:
-                import inc_common as ic
-                if ic.psel() not in pnode:
-                    pnode = expr.name()
-            except ImportError:
-                pass
-            # if 1: raise DefError("really?", pnode)
-            self.expr += item_to_string(None, 0, pnode)
-
-        elif type(expr) in (list, set, tuple):
-            for index, name in enumerate(expr):
-                if name is None:
-                    continue
-                pre = ""
-
-                if name is None:
-                    continue
-                if type(name) in (set, list, tuple):
-                    print("#WAR: please avoid list in list", expr, name)
-                    if 1:
-                        print("#WAR: list in list")
-                    elif 1:
-                        raise DefError(
-                            "please avoid list in list", expr, name)
-                    name = ""
-                    for index, another in enumerate(name):
-                        name += item_to_string(name, index, another)
-                elif type(name) in (Node, Task, Family, Suite):
-                    # if DEBUG: print(name.name())
-                    fullname = name.fullname()
-                    if fullname[0] == '/':
-                        try:
-                            import inc_common as ic
-                            if ic.psel() not in fullname:
-                                fullname = name.name()
-                        except:
-                            print("#WAR: trigger expcept")
-                    name = fullname
-                elif type(name) in (ecflow.Task, ecflow.Family):
-                    name = name.name()
-                elif type(name) == str:
-                    pass
-                else:
-                    raise DefError(type(name), name)
-
-                if "==" in name:
-                    pass
-                elif len(name) > 0:
-                    # if "==" in name: pass
-                    # if "1==0" in name or "0==1" in name or "1==1" in name: pass
-                    if name[0].isdigit():
-                        pre = "./"  # "0123456789":
-
-                self.expr = item_to_string(self.expr, index, name)
-                continue
-
-        elif type(expr) in (ecflow.Expression,
-                            ecflow.PartExpression):
-            self.expr = ecflow.Expression(str(item))
-
-        elif type(expr) in (Family, Task):
-            fullname = expr.fullname()
-            if fullname[0] == '/':
-                try:
-                    import inc_common as ic
-                    if ic.psel() not in fullname:
-                        fullname = name.real.name()
-                except ImportError:
-                    print("#WAR: trigger expcept")
-            self.expr = fullname
-            # check full name is really full name, not /name
-            # print("#REM:", self.expr)
-            if self.expr == "/%s" % expr.name():
-                self.expr = expr.name()
-        else:
-            raise DefError("what? trigger?", type(expr))
-
-        if "YMD+1" in self.expr:
-            raise DefError(self.expr)
-        # self.load = "trigger"  # ecflow.Trigger(self.expr)
-        CWN(self)
-        # NO_EXTERN_ALONE = 0 # set to 1 for test/activate
-
-    def expression(self):
-        return self.expr
-
-    def add_to(self, node):
-        if self.expr is None or self.expr == "" or not USE_TRIGGER:
-            return None
-        if 0 and "/prod/wave" in "%s" % self.expr:
-            raise DefError(self.expr, node.fullname())  # help DEBUG
-
-        if "trigger " in self.expr:
-            raise DefError(self.expr)
-        if "%s" in self.expr:
-            raise DefError(self.expr)
-        if "%d" in self.expr:
-            raise DefError(self.expr)
-        # if "make/nemoconst" in self.expr: raise DefError(self.expr)
-        if node.load.get_trigger() is None:
-            node.load.add_trigger(self.expr)
-        else:
-            node.load.add_part_trigger(ecflow.PartExpression(self.expr, True))
-        return node
-
-
-class TriggerImpossible(Trigger):
-    """attribute to be added to node when it is not expected to run any task"""
-
-    def __init__(self):
-        """ add an 'impossible trigger', for a task not to run """
-        super(TriggerImpossible, self).__init__("1==0")
-
-
-class TriggerAlways(Trigger):
-    """attribute to be added to node when it is not expected to run any task"""
-
-    def __init__(self):
-        """ add an 'impossible trigger', for a task not to run """
-        super(TriggerAlways, self).__init__("1==1")
-
-
-class Complete(Trigger):
-    """ class to host complete expression, added later to a node"""
-
-    def __init__(self, expr, unk=False, anded=False):
-        if sys.version_info.major == 2:
-            super(Complete, self).__init__(expr, unk, anded)
-        else:
-            super().__init__(expr, unk, anded)  # python3
-
-    def add_to(self, node):
-        if USE_TRIGGER and self.expr is not None:
-            if "%s" in self.expr:
-                raise DefError
-            if "%d" in self.expr:
-                raise DefError
-            node.load.add_complete(self.expr)
-        return node
-
-
-class CompleteAlways(Complete):
-    """ attribute """
-
-    def __init__(self):
-        """ always True as soon as evaluated """
-        super(CompleteAlways, self).__init__("1==1")
-
-
-class Clock(Attribute):
-    """ wrapper to add clock """
-
-    def __init__(self, arg="24:00", hybrid=0):
-        self.load = None
-        if arg == "real":
-            self.load = ecflow.Clock(False)
-        elif arg == "hybrid":
-            self.load = ecflow.Clock(True)
-        elif type(arg) == str:
-            hybrid = "hybrid" in arg
-            if "hybrid " in arg:
-                arg = nat(arg, "hybrid")
-                hybrid = 1
-            elif "real " in arg:
-                arg = nat(arg, "real")
-                hybrid = 0
-            if " -s" in arg:
-                arg = arg.replace(" -s", "")
-                sync = True
-            else:
-                sync = False
-            hhh, mmm, sss = [0, 0, 0]
-            if 1:
-                if "." in arg and " " in arg:
-                    ymd, hhh = arg.split(" ")
-                    ddd, mmm, yyy = ymd.split('.')
-                    self.load = ecflow.Clock(int(ddd), int(mmm), int(yyy),
-                                             hybrid)
-                    rel = "+" in hhh
-                    if hhh != "":
-                        self.load.set_gain_in_seconds(int(hhh), rel)
-                elif "+" in arg:
-                    rel = "+" in arg
-                    self.load = ecflow.Clock(hybrid)
-                    self.load.set_gain_in_seconds(int(arg), rel)
-                elif arg is None and hybrid is False:
-                    pass
-                elif arg == "None" and hybrid is False:
-                    pass
-                else:
-                    rel = "+" in arg
-                    from datetime import date
-                    if 0:
-                        ymd = "%s" % date.today()
-                        yyy, mmm, ddd = ymd.split("-")
-                        self.load = ecflow.Clock(
-                            int(ddd), int(mmm), int(yyy), hybrid)
-                    else:
-                        self.load = ecflow.Clock(hybrid)
-                    if arg != "":
-                        self.load.set_gain_in_seconds(int(arg), rel)
-            # except ValueError:
-            #    print("#Value Error", arg, hybrid)
-            #    self.load = ecflow.Clock(hybrid)
-        else:
-            self.load = ecflow.Clock(arg, hybrid)
-
-        if arg is None and hybrid is False:
-            self.load = None
-        CWN(self)
-
-    def add_to(self, node):
-        if type(node) != Suite:
-            print("#WAR: clock can only be attached to suite node,\n",
-                  "#WAR: clock is ignored")
-            return
-        if node.real.get_clock() is None and self.load is not None:
-            node.load.add_clock(self.load)
-        return node
-
-
-class Autocancel(Attribute):
-    """ wrapper to add time """
-
-    def __init__(self, arg):
-        if type(arg) == str:
-            if ':' in arg:  # hh:mm +hh:mm
-                hhh, mmm = arg.split(':')
-                rel = '+' in arg
-                self.load = ecflow.Autocancel(int(hhh), int(mmm), rel)
-            else:
-                self.load = ecflow.Autocancel(int(arg))
-        else:
-            self.load = ecflow.Autocancel(arg)  # days
-
-    def add_to(self, node):
-        node.load.add_autocancel(self.load)
-        return node
-
-
-class AutoCancel(Autocancel):
-    pass
-
-
-class AutoMigrate(Attribute):
-    pass
-
-
-ECG = ".ecg"
-
-
-class Script(Attribute):
-
-    def __init__(self, script, extn=ECG):
-        self._script = script
-        self.extn = extn
-
-    def add_to(self, node):
-        print("#WAR: Script attribute, not yet ... ignored")
-        return node
-
-
-class Verify(Attribute):
-    """ wrapper to add time """
-
-    def __init__(self, arg):
-        if "verify " in arg:
-            arg = nat(arg, "verify")
-        y, z = str(arg).split(":")
-        kinds = {
-            "aborted": ecflow.State.aborted,
-            "complete": ecflow.State.complete,
-            "active": ecflow.State.active,
-            "submitted": ecflow.State.submitted,
-            "unknown": ecflow.State.unknown,
-            "queued": ecflow.State.queued,
-        }
-        self.load = ecflow.Verify(kinds[y], int(z))
-
-    def add_to(self, node):
-        if USE_VERIFY and self.load is not None:
-            node.load.add_verify(self.load)
-        return node
-
-
-class Time(Attribute):
-    """ wrapper to add time """
-
-    def __init__(self, arg):
-        self.load = arg
-
-    def add_to(self, node):
-        if USE_TIME and self.load is not None:
-            node.load.add_time(self.load)
-        return node
-
-
-class Today(Time):
-    """ wrapper to add time """
-
-    def add_to(self, node):
-        if USE_TIME and self.load is not None:
-            node.load.add_today(self.load)
-        return node
-
-
-class Cron(Time):
-    """ wrapper to add time """
-
-    def __init__(self, bes, wdays=None, days=None, months=None):
-        import argparse
-        self.load = ecflow.Cron()
-
-        if not ("-w" in bes or
-                "-m" in bes or
-                "-d" in bes or
-                "-s" in bes):
-            self.load.set_time_series(bes)
-            return
-
-        parser = argparse.ArgumentParser()
-        parser.add_argument("-w", nargs=1, default=None, help="weekdays")
-        parser.add_argument("-m", nargs=1, default=None, help="months")
-        parser.add_argument("-d", nargs=1, default=None, help="days")
-        parser.add_argument("-s", action="store_true", help="sync")
-        parser.add_argument("begin", nargs='+', help="begin")
-        if " -s" in bes:
-            bes = bes.replace(" -s", "")
-            sync = True
-        else:
-            sync = False
-        parsed = parser.parse_args(bes.split())
-
-        if wdays is not None:
-            self.load.set_week_days(wdays)
-        if parsed.w:
-            self.load.set_week_days([
-                int(x) for x in str(parsed.w[0]).split(',')])
-        if days is not None:
-            self.load.set_day_of_month(days)
-        if parsed.d:
-            self.load.set_days_of_month([
-                int(x) for x in parsed.d[0].split(',')])
-        if months is not None:
-            self.load.set_months(month)
-        if parsed.m:
-            self.load.set_months([
-                int(x) for x in parsed.m[0].split(',')])
-        self.load.set_time_series(' '.join(parsed.begin))
-
-    def add_to(self, node):
-        if USE_TIME and self.load is not None:
-            node.load.add_cron(self.load)
-        else:
-            print("#WAR: ignoring: %s" % self.load)
-        return node
-
-
-class Date(Time):
-    """ wrapper to add date """
-
-    def __init__(self, arg, mask=False):
-        super(Date, self).__init__(arg)
-        self.mask = mask
-
-    def add_to(self, node):
-        if USE_TIME and self.load is not None:
-            # ??? emos avoids dates, datasvc would not
-            if self.mask:
-                node.load.add_variable("DATEMASK", self.load)
-            else:
-                ddd, mmm, yyy = self.load.split('.')
-                if ddd == '*':
-                    ddd = 0
-                if mmm == '*':
-                    mmm = 0
-                if yyy == '*':
-                    yyy = 0
-
-                node.load.add_date(int(ddd), int(mmm), int(yyy))
-        return node
-
-
-class Day(Date):
-    """ wrapper to add day """
-
-    def add_to(self, node):
-        if not USE_TIME or self.load is None:
-            return
-        if isinstance(self.load, str):
-            days = {"monday": ecflow.Days.monday,
-                    "sunday": ecflow.Days.sunday,
-                    "tuesday": ecflow.Days.tuesday,
-                    "wednesday": ecflow.Days.wednesday,
-                    "thursday": ecflow.Days.thursday,
-                    "saturday": ecflow.Days.saturday,
-                    "friday": ecflow.Days.friday,
-
-                    "mon": ecflow.Days.monday,
-                    "sun": ecflow.Days.sunday,
-                    "tue": ecflow.Days.tuesday,
-                    "wed": ecflow.Days.wednesday,
-                    "thu": ecflow.Days.thursday,
-                    "sat": ecflow.Days.saturday,
-                    "fri": ecflow.Days.friday, }
-            node.load.add_day(ecflow.Days(days[self.load]))
-        else:
-            node.load.add_day(ecflow.Days(self.load))
-        return node
-
-
-class Defstatus(Attribute):
-    """ add defstatus attribute"""
-
-    def __init__(self, kind):
-        if type(kind) == str:
-            kinds = {"suspended": ecflow.DState.suspended,
-                     # "halted": ecflow.DState.halted, "shutdown": ecflow.DState.shutdown,
-                     "aborted": ecflow.DState.aborted,
-                     "complete": ecflow.DState.complete,
-                     "active": ecflow.DState.active,
-                     "submitted": ecflow.DState.submitted,
-                     "unknown": ecflow.DState.unknown,
-                     "queued": ecflow.DState.queued, }
-            self.load = kinds[kind]
-        elif type(kind) in (ecflow.DState, ):
-            self.load = kind
-        else:
-            raise DefError(type(kind), kind)
-
-    def add_to(self, node):
-        if type(node) in (Suite, Family, Task):
-            node.load.add_defstatus(self.load)
-        else:
-            node.add_defstatus(self.load)
-        return node
-
-
-SORT = False
-SORT = True
-
-
-def sorted_or_not(items, sort=False):
-    if SORT or sort:
-        return sorted(items)
-    return items
-
-
-class Limit(Attribute):
-    """ wrapper to add limit """
-
-    def __init__(self, name=None, size=1, inlimit=0):
-        self.name = name
-        self.size = int(size)
-        self.addi = inlimit
-
-    def add_to(self, node):
-        if USE_LIMIT and self.name is not None:
-            if type(self.name) is dict:
-                for name, size in sorted_or_not(list(self.name.items()),
-                                                sort=not LINKTASK):
-                    size = self.name[name]
-                    node.load.add_limit(name, size)
-                    if self.addi:
-                        node.load.add_inlimit(name)
-                    else:
-                        pass
-            else:
-                node.load.add_limit(self.name, self.size)
-                if self.addi:
-                    node.load.add_inlimit(name)
-        return node
-
-
-class Late(Attribute):
-    """ wrapper around late, to be add'ed to families and tasks """
-
-    def __init__(self, arg):
-        self.load = None
-        if not USE_LATE:
-            # print("#MSG: late is disabled")
-            return
-        sub = False
-        act = False
-        com = False
-        rel = False
-        self.load = ecflow.Late()
-        for item in arg.split(" "):
-            if item == "-s":
-                sub = True
-            elif item == "-c":
-                com = True
-            elif item == "-a":
-                act = True
-            else:
-                hour, mins = item.split(":")
-                rel = "+" in hour
-                if "+" in hour:
-                    hour = hour[1:]
-                if sub:
-                    self._add_sub(hour, mins)
-                elif com:
-                    self._add_com(hour, mins, rel)
-                elif act:
-                    self._add_act(hour, mins)
-                sub = False
-                act = False
-                com = False
-
-    def _add_sub(self, hour, mins):
-        """ submitted"""
-        self.load.submitted(ecflow.TimeSlot(int(hour), int(mins)))
-
-    def _add_com(self, hour, mins, rel):
-        """ complete"""
-        self.load.complete(ecflow.TimeSlot(int(hour), int(mins)), rel)
-
-    def _add_act(self, hour, mins):
-        """ active"""
-        self.load.active(ecflow.TimeSlot(int(hour), int(mins)))
-
-    def add_to(self, node):
-        if USE_LATE and self.load is not None:
-            if type(node) in (ecflow.Family, ecflow.Task):
-                node.add_late(self.real)
-            else:
-                node.real.add_late(self.real)
-        return node
-
-
-def python_true(key, val):
-    if "%s" % val == "True":
-        if key in ("HYPERTHREADING",
-                   "CLIM5YR",
-                   "FLEX_SUBMIT",
-                   "USE_HUGEPAGE"):
-            return  # OK
-        print("#WAR: really???", key, val)
-
-
-class Edit(Attribute):
-    """ dedicated class to enable variable addition with different
-    syntax """
-
-    def __init__(self, name, value=""):
-        self.load = ecflow.Edit(name, value)
-
-    def _set_tvar(self, key, val):
-        """ facilitate to load a ecflow suite to SMS, translating
-        variable names"""
-        keyt, edit = translate(str(key), str(val))
-        # if keyt == "SCHOST" and val == "ccb": raise DefError
-        if self.load is None:
-            self.load = ecflow.Variable(keyt, edit)
-        else:
-            next = self.next
-            self.next = Edit(keyt, edit, next)
-
-    def __init__(self, __a=None, __b=None, __next=None,
-                 *args, **kwargs):
-        self.load = None
-        self.next = __next
-
-        if len(args) > 0:
-            if type(args) == list:
-                for item in args.items():
-                    key = item.name()
-                    val = item.value()
-                    python_true(key, val)
-                    self._set_tvar(item.name(), item.value())
-            elif type(args) == tuple:
-                for key, val in list(args.items()):
-                    python_true(key, val)
-                    self._set_tvar(key, val)
-            else:
-                raise DefError
-        if len(kwargs) > 0:
-            for key in sorted_or_not(list(kwargs.keys())):
-                val = kwargs[key]
-                python_true(key, val)
-                self._set_tvar(key, val)
-        if type(__a) == dict:
-            for key in sorted_or_not(list(__a.keys())):
-                val = __a[key]
-                python_true(key, val)
-                self._set_tvar(key, val)
-        elif type(__a) == tuple:
-            raise DefError
-        elif type(__a) == list:
-            raise DefError
-        elif type(__a) == Variable:
-            self.load = __a
-        elif __a is not None and __b is not None:
-            python_true(__a, __b)
-            self._set_tvar(__a, __b)
-        elif __a is None and __b is None:
-            pass
-        else:
-            raise DefError(__a, __b, __next, args, kwargs)
-
-    def add_to(self, node):
-        if self.load is not None:
-            edit = "%s" % self.load
-            if "CPUTIME" in edit and not CPUTIME:
-                pass
-            if node in (Suite, Family, Task):
-                node.load.add_variable(self.load)
-            else:
-                node.add_variable(self.load)
-            if node.name() == "o" and "QUEUE 'emos" in edit:
-                raise DefError(node.name(), edit)  # intercept, DEBUG
-
-            if 1:  # try:  # Operators' request
-                labels = {"WSHOST": "infopws",
-                          "SCHOST": "infopsc",
-                          "HOST": "infophs", }
-                # if 'seas' in ip.SELECTION: pass
-                for key in list(labels.keys()):
-                    try:
-                        info = labels[key]
-                        msg = ""
-                        find = ""
-                        if "ECF_JOB_CMD" in edit:
-                            find = "%" + key + "%"
-                            info = "infopcmd"
-                            msg = key
-                        elif "ECF_KILL_CMD" in edit:
-                            find = "edit %s " % key
-                        if find != "" and find in edit:
-                            node.real.add_label(info, msg)
-                    except:
-                        print("#WAR: duplicated label", "edit", edit)
-        if self.next is not None:
-            self.next.add_to(node)
-        return node
-
-    def add(self, what):
-        print("#ERR: add???", "%s" % self.load)
-        if type(what) in (Suite, Family, Task):
-            raise DefError(what.fullname())
-        else:
-            raise DefError(type(what))
-
-
-class Variable(Edit):
-    pass
-
-
-class Variables(Edit):
-    pass
-
-
-class Repeat(Attribute):
-    """ repeat date/int/string/enum """
-
-    def __init__(self, name="YMD", start=20120101, end=21010101,
-                 step=1, kind="date"):
-        # print("repeat", name, "#", start, "#", end, "#", step, "#", kind)
-        if len(name) > 4:
-            if (name[:4] == "enum" or
-                name[:4] == "date" or
-                "string " in name or
-                name[:3] == "int" or
-                    "day " in name):
-                pars = name.split(" ")
-                kind = pars[0]
-                name = pars[1]
-                if "enum" in kind or "string" in kind:
-                    start = [i.strip("'").strip('"') for i in pars[2:]]
-                elif "int" in kind or "date" in kind:
-                    start = pars[2]
-                    if len(pars) > 3:
-                        end = pars[3]
-                    if len(pars) > 4:
-                        step = pars[4]
-
-        if kind in ("date", ):
-            self.load = ecflow.RepeatDate(
-                name, int(start), int(end), int(step))
-        elif "int" in kind:
-            self.load = ecflow.RepeatInteger(
-                name, int(start), int(end), int(step))
-        elif kind == "string":
-            if len(start) == 0:
-                raise Exception
-            self.load = ecflow.RepeatString(name, start)
-        elif "enum" in kind:
-            if len(start) == 0:
-                raise Exception
-            self.load = ecflow.RepeatEnumerated(name, start)
-        elif kind == "day":
-            self.load = ecflow.RepeatDay(step)
-        else:
-            self.load = None
-
-    def add_to(self, node):
-        if self.load is not None:
-            node.load.add_repeat(self.load)
-        return node
-
-
-class Zombie(Attribute):
-    """
- |     ZombieAttr(ZombieType,ChildCmdTypes, ZombieUserActionType, lifetime)
- |        ZombieType            : Must be one of ZombieType.ecf, ZombieType.path, ZombieType.user
- |        ChildCmdType          : A list(ChildCmdType) of Child commands. Can be left empty in
- |                                which case the action affect all child commands
- |        ZombieUserActionType  : One of [ fob, fail, block, remove, adopt ]
- |        int lifetime<optional>: Defines the life time in seconds of the zombie in the server.
- |                                On expiration, zombie is removed automatically
-"""
-
-    def __init__(self, arg="ecf:remove:3600"):
-        if "zombie " in arg:
-            arg = nat(arg, "zombie")
-        typ, act, kid, num = arg.split(":")
-        types = ecflow.ZombieType.names  # ecf user path
-        kids = ecflow.ChildCmdType.names  # complete label init abort event wait
-        acts = ecflow.ZombieUserActionType.names  # adopt remove kill fob fail block
-        when = []
-        if kid == "":
-            pass
-        elif "," in kid:
-            for k in kid.split(","):
-                when.append(kids[k])
-        else:
-            when.append(kids[kid])
-
-        self.load = ecflow.ZombieAttr(types[typ], when, acts[act],
-                                      int(num))
-
-    def add_to(self, node):
-        """add_zombie"""
-        node.load.add_zombie(self.load)
-        return node
-
-
-def If(test=True, then=None, otow=None, *args):
-    """ enable Task("t1").add(If(test=(1==1),
-                                 then=Edit(ONE=1),
-                                 otow=Edit(TWO=2)))
-        appreciate that both branches are evaluated, using this If class
-        ie there is no 'dead code' as it is with python language 'if' structure
-
-        using If to distinguish od/rd mode request that both users share
-        the variables (parameter.py) and ecf.py
-
-        otow: on the other way?
-        """
-    if len(args) > 1:
-        try:
-            print("#ERR:", then.name())
-            print("#ERR:", otow.name())
-        except Exception as exc:
-            print("#ERR:", exc.args)
-        raise DefError("test",
-                       test, "\nthen\n",
-                       then, "\nelse",
-                       otow, "arg", args)
-    if test:
-        return then
-    return otow
-
-
-class Root(object):  # from where Suite and Node derive
-    """ generic tree node """
-
-    def __init__(self):
-        self.load = None  # to be filled with ecFlow item
-        # CWN(self)
-
-    @property
-    def real(self):
-        return self.load
-
-    def __enter__(self):
-        # CWN(self)
-        raise DefError("#ERR: this shall be overwritten by kid")
-
-    def __exit__(self, type, value, traceback):
-        CWN.pop()
-
-    def __get_attr__(self, attr):
-        return getattr(self.load, attr)
-
-    def get_parent(self):
-        return self.load.get_parent()
-
-    def __str__(self):
-        return self.fullname()
-
-    def __repr__(self):
-        return "%s" % self.load
-
-    def is_eq(self, node):
-        return super(self, self.__eq__), (self, node)
-
-    def __eq__(self, node):
-        if isinstance(self.load, ecflow.Node):
-            return "%s == " % self + str(node)
-        return self  # False
-
-    def __ne__(self, node):
-        if isinstance(self.load, ecflow.Node):
-            return "%s != " % self + str(node)
-        return False
-
-    def __and__(self, node):
-        if isinstance(self.load, ecflow.Node):
-            return "%s and " % self + str(node)
-        return False
-
-    def __or__(self, node):
-        if isinstance(self.load, ecflow.Alias):
-            return True
-        if isinstance(self.load, ecflow.Node):
-            return "%s or " % self + str(node)
-        return False
-
-    def get_abs_node_path(self):
-        return self.fullname()
-
-    def fullname(self):
-        """ simple syntax """
-        if isinstance(self.load, ecflow.Node):
-            return self.load.get_abs_node_path()
-        return str(self)
-
-    def repeat(self, name="YMD", start=20120101, end=20321212, step=1,
-               kind="date"):
-        """ add repeat attribute"""
-        if kind in ("date", "integer"):
-            self.add(Repeat(name, start, end, step, kind))
-        elif kind in ("string", "enumerated"):
-            self.add(Repeat(name, start, kind=kind))
-        elif kind == "day":
-            self.add(Repeat(step, kind="day"))
-        else:
-            raise DefError
-        return self
-
-    def defstatus(self, kind):
-        """ add defstatus attribute"""
-        status = kind
-        if type(kind) == str:
-            kinds = {  # "suspended": ecflow.DState.suspended,
-                "halted": ecflow.DState.halted, "shutdown": ecflow.DState.shutdown,
-                "aborted": ecflow.DState.aborted,
-                "complete": ecflow.DState.complete,
-                "active": ecflow.DState.active,
-                "submitted": ecflow.DState.submitted,
-                "unknown": ecflow.DState.unknown,
-                "queued": ecflow.DState.queued, }
-            status = kinds[kind]
-        elif type(kind) == ecflow.DState:
-            pass
-        else:
-            raise DefError("defstatus?")
-        self.load.add_defstatus(status)
-        return self
-
-    def __add__(self, item):
-        self.add(item)
-
-    def append(self, item=None, *args):
-        """ we get compatible with list then """
-        return self.add(item, args)
-
-    def add(self, item=None, *args):
-        """ add a task, a family or an attribute """
-        if DEBUG:
-            print(self.fullname(), item, args)
-
-        if item is not None:
-            if type(item) in (tuple, list):
-                for val in item:
-                    self.add(val)
-            elif type(item) == str:
-                raise DefError(item)
-            elif type(item) == int:
-                pass
-            elif type(item) == dict:
-                if item != {}:
-                    raise DefError(item)
-            else:
-                item.add_to(self)
-
-        if len(args) > 0:
-            assert type(args) in (tuple, list)
-            for val in args:
-                self.add(val)
-            return self
-
-        if not isinstance(self.load, ecflow.Node):
-            raise DefError("please dont", type(self))
-
-        return self
-
-    def limit(self, name=None, size=1, inlimit=0):
-        """ add limit attribute"""
-        if name is None:
-            raise DefError
-        self.load.add_limit(name, size)
-        return self
-
-    def inlimit(self, full_path):
-        """ add inlimit attribute"""
-        if not USE_LIMIT:
-            return self
-
-        try:
-            path, name = full_path.split(":")
-        except ValueError:
-            raise ValueError('invalid limit: {}'.format(full_path))
-
-        self.load.add_inlimit(name, path)
-        return self
-
-    # follow pyflow
-    shape = None
-
-    def draw_tree(self):
-        dot = Dot(fullnames=False)
-        self._tree(dot)
-        return dot
-
-    def _tree(self, dot):
-        try:
-            dot.edge(self.load.get_parent(), self)
-        except:
-            pass
-        if type(self.load) in (Alias, ecflow.Alias):
-            return
-        for n in self.load.nodes:
-            if n.name() != '_':
-                _tree(dot, n)
-
-    def draw_graph(self):
-        dot = Dot()
-        self._graph(dot)
-        dot.save("test.gv")
-        return dot
-
-    def _graph(self, dot):
-        for n in self.load.nodes:
-            if n.name() != '_':
-                _tree(dot, n)
-
-    def to_html(self):
-        # from .html import HTMLWrapper
-        return "%s" % HTMLWrapper("%s" % self)  # .generate_node()))
-
-    def _repr_html_(self):
-        return str(self.to_html())
-
-
-def _tree(dot, node):
-    if type(node) in (ecflow.Node, ecflow.Family, ecflow.Task, ):
-        dot.edge(node.get_parent(), node)
-        for n in node.nodes:
-            if n.name() != '_':
-                _tree(dot, n)
-    elif type(node) in (Node, Family, Task):
-        dot.edge(node.load.parent, node)
-        _tree(dot, node.load)
-    else:
-        raise DefError(type(node))
-
-
-def get_kind(item):
-    if type(item) in (Defs, ecflow.Defs):
-        return "definition"
-    if type(item) in (Suite, ecflow.Suite):
-        return "suite"
-    if type(item) in (Family, ecflow.Family):
-        return "family"
-    if type(item) in (Task, ecflow.Task):
-        return "task"
-    if type(item) in (Alias, ecflow.Alias, ):
-        return "alias"
-    return "ignore"
-
-
-def to_d3js(node):
-    if type(node) == ecflow.Defs:
-        name = 'definition'
-        kids = [to_d3js(item) for item in node.suites]
-        status = "%s" % node.get_state()
-    else:
-        kids = [to_d3js(item) for item in node.nodes]
-        name = node.name()
-        status = "%s" % node.get_state()
-
-    return {'children': [kids],
-            'kind': get_kind(node),
-            'name': '%s' % name,
-            '_status': '%s' % status,
-            'size': len(kids), }
-
-
-def to_pyflow(node, container=None):
-    if container is None:
-        container = dict()
-    if type(node) in (tuple, list):
-        for item in node:
-            container.update(to_pyflow(item, container))
-        return container
-
-    if type(node) in (Alias, ecflow.Alias):
-        return
-    if node.name() not in container.keys():
-        container[node.name()] = dict()
-    # steps follow
-    upd = {
-        'variables': dict(),
-        'events': [(item.number(), item.name()) for item in node.events],
-        'meters': dict(),
-        'labels': dict(),
-        'limits': dict(),
-        'inlimits': dict(),
-    }
-    for item in node.variables:
-        upd['variables'][item.name()] = item.value()
-    for item in node.meters:
-        upd['meters'][item.name()] = [item.min(), item.max()]
-    for item in node.labels:
-        upd['labels'][item.name()] = item.value()
-    for item in node.limits:
-        upd['limits'][item.name()] = item.limit()
-    for item in node.inlimits:
-        arg = item.name()
-        if item.path_to_node() != "":
-            arg = item.path_to_node() + ":" + item.name()
-        if item.tokens() > 1:
-            arg += " %d" % item.tokens()
-        upd['inlimits'][item.name()] = arg
-    for key in upd.keys():
-        if len(upd[key]) == 0:
-            del upd[key]
-    # repeat time date days today
-    if node.get_autocancel():
-        upd['autocancel'] = True
-    if '%s' % node.get_defstatus() != 'queued':
-        upd['defstatus'] = '%s' % node.get_defstatus()
-    if node.get_late() != None:
-        upd['late'] = nat('%s' % node.get_late(), "late")
-    for item in node.nodes:
-        upd.update(to_pyflow(item, container[node.name()]))
-
-    container['%s' % node.name()].update(upd)
-    return container
-
-
-def nat(name, key):
-    res = '%s' % str(name)
-    return res.replace('%s ' % key, '')
-
-
-def to_dict(node, container=None):
-    kids = dict()
-    if isinstance(node, ecflow.Defs):
-        res = {':suites': [], }
-        for item in node.suites:
-            res[':suites'].append(to_dict(item))
-        for item in node.externs:
-            if ':externs' not in res.keys():
-                res[':externs'] = []
-            res[':externs'].append("%s" % item)
-        return res
-
-    if type(node) in (ecflow.Alias, Alias):
-        print("#WAR: aliases are ignored")
-        return dict()
-
-    for item in node.nodes:
-        kids[item.name()] = to_dict(item)
-
-    temp = {'edits': {item.name(): '%s' % item.value()
-                      for item in node.variables},
-            'events': ["%d " % item.number() + '%s' % item.name()
-                       for item in node.events],
-            # 'externs': [],
-            'meters': [
-                {'%s' % item.name(): {
-                    'min': item.min(),
-                    'max': item.max(),  # aka threshold(),
-                    'thr': item.color_change(), }}
-                for item in node.meters],
-            'labels': {item.name(): '%s' % item.value()
-                       for item in node.labels},
-            'limits': {item.name(): item.limit() for item in node.limits},
-            'inlimits': [],
-            'verifies': ["%s" % item for item in node.verifies],
-            'zombies': ["%s" % item for item in node.zombies],
-            'dates': [nat(item, 'date') for item in node.dates],
-            'days': [nat(item, 'day') for item in node.days],
-            'times': [nat(item, 'time') for item in node.times],
-            'crons': [nat(item, 'cron') for item in node.crons],
-            'todays': [nat(item, 'today') for item in node.todays],
-            'trigger': '%s' % node.get_trigger(),
-            'complete': '%s' % node.get_complete(),
-            'children': kids,
-            # 'late': "%s" % node.get_late(),
-            # 'clock': '%s' % node.get_clock(),
-            }
-
-    for item in node.inlimits:
-        arg = item.name()
-        if item.path_to_node() != "":
-            arg = item.path_to_node() + ":" + item.name()
-        if item.tokens() > 1:
-            arg += " %d" % item.tokens()
-        temp['inlimits'].append(arg)
-    out = {':name': '%s' % node.name(),
-           ':kind': '%s' % get_kind(node),
-           ':status': '%s' % node.get_state(), }
-    defstatus = '%s' % node.get_defstatus()
-    if defstatus != 'queued':
-        out[':defstatus'] = "%s" % defstatus
-    if get_kind(node) == "suite":
-        out[':clock'] = nat("%s" % node.get_clock(), "clock")
-    if node.get_late() is not None:
-        out[':late'] = nat("%s" % node.get_late(), "late")
-    rep = node.get_repeat()
-    if not rep.empty():
-        out[':repeat'] = nat("%s" % node.get_repeat(), "repeat")
-
-    # for key in sorted(temp.keys()):
-    for key in temp.keys():
-        if temp[key] == 'None':
-            continue  # WARNING ???
-        out[':' + key] = temp[key]
-
-    return out
-
-
-def to_json(item, pyflow=False):
-    import json
-    if type(item) in (list, tuple):
-        pass
-    elif type(item) != dict:
-        item = to_dict(item, pyflow)
-    return json.dumps(item,
-                      # default= lambda o:
-                      ensure_ascii=True,
-                      skipkeys=True,
-                      sort_keys=True,
-                      indent=2)
-
-
-def json_to_defs(treedict, parent=None):
-    if treedict is None:
-        return
-    res = []
-    if ":externs" in treedict.keys():
-        for item in treedict[":externs"]:
-            res.append("extern %s" % item)
-            # Extern(nat(item, "extern")))
-    elif ":suites" in treedict.keys():
-        for suite in treedict[":suites"]:
-            res.append(from_json(suite))
-    for key in treedict.keys():
-        if key not in (":externs", ":suites"):
-            raise DefError("please use from_json", key)
-    return res
-
-
-def from_json(tree):
-    out = []
-    res = None
-
-    if type(tree) in (tuple, list):
-        if tree == []:
-            return  # IGN
-        if len(tree) == 2:
-            if type(tree[0]) == dict:
-                return from_json(tree[0])
-            return {str(tree[0]): from_json(tree[1])}
-        elif len(tree) == 1:
-            return str(tree[0])
-        raise Exception("#wwwwww", tree, type(tree))
-
-    elif isinstance(tree, str):
-        print("#IGN", tree)
-        return
-
-    elif type(tree) is not dict:
-        raise Exception("#wwwwww", tree, type(tree))
-
-    for k in sorted(tree.keys()):
-        sk = k
-        if sk in (':name', ):
-            res = ITEMS[tree[':kind']](str(tree[':name']))
-
-        elif sk in (':status', ':kind'):
-            continue
-
-        elif sk in (':children', ":kids", ):
-            for kid in sorted(tree[k].keys()):
-                out.append(from_json(tree[k][kid]))
-
-        elif sk in (":suites", ):
-            for item in tree[k]:
-                out.append(from_json(item))
-
-        elif sk in (':defstatus', ':trigger', ':complete', ':clock',
-                    ':late', ':externs', ':repeat',):
-            out.append(ITEMS[k](tree[k]))
-
-        elif sk in (':meters', ):
-            for item in tree[k]:
-                name = item.keys()[0]
-                out.append(ITEMS[k](str(name),
-                                    int(item[name]['min']),
-                                    int(item[name]['max']),
-                                    int(item[name]['thr'])))
-        elif sk in (':edits', ':labels', ':limits', ):
-            for item in sorted(tree[k].keys()):
-                out.append(ITEMS[k](str(item), str(tree[k][item])))
-        elif sk in (':events', ':repeat', ':inlimits', ':crons',
-                    ':verifies', ':dates',
-                    ':times', ':days', ':zombies', ":todays", ):
-            for item in tree[k]:
-                out.append(ITEMS[k](str(item)))
-        # elif ':' in k:
-        #     print(":key",k)
-        #     v = tree[k]
-        #     if type(v) == dict:
-        #         for key in v.keys():
-        #             out.append(ITEMS[k](key, v[key]))
-        #     else:
-        #         for item in v:
-        #             if item != '':
-        #                 out.append(ITEMS[k](item))
-        elif sk in list(ITEMS.keys()):
-            raise Exception
-
-        else:
-            if (type(tree[k]) == dict and
-                len(tree[k]) == 1 and
-                    ['children', ] == list(tree[k].keys())):
-                kids = tree[k]['children']
-                if type(kids) not in (list, tuple):
-                    raise Exception(type(kids))
-                for kid in kids:
-                    if isinstance(kid, str):
-                        out.append((str(k), str(kid)))
-                    elif type(kid) in (dict, ):
-                        for elt in list(kid.keys()):
-                            out.append((str(k), str(elt)))
-                        anot = from_json(kid)
-                        if anot is not None:
-                            out.append(anot)
-
-                return out
-            elif 1:
-                raise Exception(k, tree[k], type(tree[k]),
-                                len(tree[k]),
-                                list(tree[k].keys()))
-            else:
-                out.append(from_json(tree[k]))
-
-    if res is None:
-        return out
-    return res.add(out)
-
-
-class Node(Root):  # from where Task and Family derive
-    """ Node class is shared by family and task """
-
-    def __enter__(self):
-        CWN(self)
-        return self
-
-    # def __exit__(self, exc_type, exc_val, exc_tb): pass  # return self
-
-    def events(self):
-        return [event for event in self.load.events]
-
-    def meters(self):
-        return [meter for meter in self.load.meters]
-
-    def name(self):
-        return self.load.name()
-
-    def find_variable(self, name):
-        if self.load:
-            return self.load.find_variable(name)
-        return None
-    # def event(self, name=1):
-    #     """ add event attribute"""
-    #     if USE_EVENT:
-    #         self.load.add_event(name)
-    #     return self
-
-    # def meter(self, name, start, end, threshold=None):
-    #     """ add meter attribute"""
-    #     if threshold is None:
-    #         threshold = end
-    #     self.load.add_meter(name, start, end, threshold)
-    #     return self
-
-    # def label(self, name, default=""):
-    #     """ add label attribute"""
-    #     self.load.add_label(name, default)
-    #     return self
-
-    # def edit(self, name, value=""):
-    #     """ add variable attribute"""
-    #     self.load.add_variable(name, value)
-    #     return self
-
-    def variable(self, name, value=""):
-        """ add variable attribute """
-        return self.edit(name, value)
-
-    def cron(self, time, dom=False, wdays=False, month=False):
-        """ wrapper for add_cron """
-        cron = ecflow.Cron()
-        cron.set_time_series(time)
-        if wdays is not False:
-            cron.set_week_days(wdays)
-        if month is not False:
-            cron.set_months(month)
-        if dom is not False:
-            cron.set_day_of_month(dom)
-
-        self.load.add_cron(cron)
-        return self
-
-    def complete(self, arg):
-        """ add complete attribute"""
-        if USE_TRIGGER and arg is not None:
-            self.load.add_complete(arg)
-        return self
-
-    def complete_and(self, arg):
-        """ append to existing complete"""
-        if USE_TRIGGER and arg is not None:
-            self.load.add_part_complete(ecflow.PartExpression(arg, True))
-        return self
-
-    def complete_or(self, arg):
-        """ append to existing complete"""
-        if USE_TRIGGER and arg is not None:
-            self.load.add_part_complete(ecflow.PartExpression(arg, False))
-        return self
-
-    def up(self):
-        """ get parent, one level up"""
-        return self.load.get_parent()
-
-
-class Defs(object):
-    """ wrapper for the definition """
-
-    def __init__(self):
-        self.load = ecflow.Defs()
-
-    def __get_attr__(self, attr):
-        return getattr(self.load, attr)
-
-    @property
-    def real(self):
-        return self.load
-
-    def auto_add_externs(self, true):
-        self.load.auto_add_externs(true)
-
-    def check(self):
-        return self.load.check()
-
-    def simulate(self):
-        return self.load.simulate()
-
-    def generate_scripts(self):
-        return self.load.generate_scripts()
-
-    def add_extern(self, path):
-        if type(path) != str:
-            raise DefError(type(path))
-        if ".Extern" in path:
-            raise DefError(type(path))
-        self.load.add_extern(path)  # TODO list
-
-    def save_as_defs(self, fname):
-        self.load.save_as_defs(fname)
-
-    def get_all_tasks(self):
-        return self.load.get_all_tasks()
-
-    def suites(self):
-        return [suite for suite in self.load.suites]
-
-    def add_suite(self, node):
-        if type(node) == Suite:
-            self.load.add_suite(node.load)  # TODO list
-        elif type(node) == ecflow.Suite:
-            self.load.add_suite(node)  # TODO list
-        else:
-            raise DefError("what?")
-
-    def __str__(self):
-        return "%s" % self.load
-
-    __repr__ = __str__
-
-    def __add__(self, item):
-        self.add(item)
-
-    def append(self, item=None, *args):
-        """ get compatible with list """
-        return self.add(item, args)
-
-    def add(self, item):
-        """ add suite """
-        if type(item) == Suite:
-            self.load.add_suite(item.load)
-        elif type(item) == Extern:  # back again
-            path = "%s" % item
-            if type(path) != str:
-                raise DefError(type(path), item)
-            if ".Extern" in path:
-                raise DefError(type(path), path, item)
-            self.load.add_extern(path)
-        elif type(item) in (tuple, list):
-            for one in item:
-                self.add(one)
-        elif item is None:
-            pass
-        elif isinstance(item, str):
-            if "extern " in item:
-                self.load.add_extern(nat(item, "extern"))
-            else:
-                raise DefError("ERR:load add, what?", type(item), item)
-        else:
-            raise DefError("ERR:load add, what?", type(item), item)
-        return self
-
-    def find_abs_node(self, name):
-        return self.load.find_abs_node(name)
-
-    def find_node(self, name):
-        return self.get_abs_node(name)
-
-    def suite(self, name):
-        """ add suite providing its name """
-        suite = Suite(name)
-        self.add(suite)
-        return suite
-
-
-class Client(object):
-    """ wrapper around client """
-
-    def __init__(self, host="localhost", port="31415"):
-        if host is None:
-            host = "localhost"
-        self.clnt = ecflow.Client(host, port)
-        if "@" in host:
-            host, port = host.split("@")
-            self.clnt.set_host_port(host, int(port))
-        else:
-            super(Client, self).__init__()
-            self.clnt.set_host_port(host, int(port))
-        self.host = host
-        self.port = port
-
-    def load(self, defs):
-        if type(defs) == Defs:
-            self.clnt.load(defs.load)
-        elif type(defs) == ecflow.Defs:
-            self.clnt.load(defs)
-        else:
-            raise DefError("defs: really?")
-
-    def get_file(self, node, kind="script"):
-        return self.clnt.get_file(node, kind)
-
-    def replace(self, path, defs=None, parent=True, force=False):
-        if defs is None:
-            self.clnt.replace(path, DEFS, parent, force)
-        elif type(defs) is Defs:
-            self.clnt.replace(path, defs.load, parent, force)
-        else:
-            self.clnt.replace(path, defs, parent, force)
-
-    def suites(self):
-        return self.clnt.suites()
-
-    def begin_suite(self, name):
-        return self.clnt.begin_suite(name)
-
-    def resume(self, path):
-        return self.clnt.resume(path)
-
-    def suspend(self, path):
-        return self.clnt.suspend(path)
-
-    def ping(self):
-        self.clnt.ping()
-
-    def version(self):
-        self.clnt.version()
-
-    def __str__(self):
-        return "ecflow client %s@%s v%s" % (
-            self.host, self.port, self.version())
-
-
-class Suite(Root):
-    """ wrapper for a suite """
-
-    def __enter__(self):
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        pass
-
-    def __init__(self, name):
-        self.load = ecflow.Suite(name)
-        CWN(self)
-
-    def name(self):
-        return self.load.name()
-
-    def family(self, name):
-        """ add a family """
-        if "%" in name:
-            raise DefError(name)
-        obsolete()
-        fam = Family(str(name))
-        self.add(fam)
-        return fam
-
-    def task(self, name):
-        """ add a task """
-        if "%" in name:
-            raise DefError(name)
-        obsolete()
-        tsk = Task(name)
-        self.add(tsk)
-        return tsk
-
-    def add_to(self, defs):
-        if type(defs) == ecflow.Defs:
-            defs.add_suite(self.real)
-        else:
-            defs.add_suite(self)
-
-    # def __enter__(self): return self
-
-    # def __exit__(self, *args): pass
-
-
-class Family(Node, Attribute):
-    """ wrapper around family """
-
-    def __init__(self, name):
-        self.load = ecflow.Family(str(name))
-        CWN(self)
-
-    def family(self, name):
-        """ add a family """
-        if "%" in name:
-            raise DefError(name)
-        obsolete()
-        fam = Family(str(name))
-        self.add(fam)
-        return fam
-
-    def task(self, name):
-        """ add a task """
-        if "%" in name:
-            raise DefError(name)
-        obsolete()
-        tsk = Task(name)
-        self.add(tsk)
-        return tsk
-
-    def add_to(self, node):
-        if DEBUG:
-            print("#BDG: add: %s %s" % (node.name(), self.name()))
-        parent = self.load.get_parent()
-        if parent:
-            raise DefError("already attached...",
-                           parent.name(),
-                           node.name(), self.name())
-        if type(node) in (Suite, Family, Task):
-            node.load.add_family(self.load)
-        else:
-            node.add_family(self.load)
-
-    def nodes(self):
-        return [node for node in self.load.nodes]
-
-    # def __enter__(self): return self
-
-    # def __exit__(self, *args): pass
-
-
-class Task(Node, Attribute):
-    """ wrapper around task """
-
-    def __init__(self, name):
-        # super(Task, self).__init__(name)
-        self.load = ecflow.Task(name)
-        CWN(self)
-
-    def add_to(self, node):
-        if type(node) in (Family, Suite):
-            load = self.load  # deep copy
-            if load.get_parent() != None:
-                new = load
-                load = new
-            node.load.add_task(load)
-            return
-        node.add_task(self.load)
-
-    def add_family(self, node):
-        raise DefError(self.name(), node.name(), self.fullname())
-
-    def add_task(self, node):
-        raise DefError(node.name(), self.name())
-
-
-class Alias(Root, ecflow.Alias):  # from where Suite and Node derive
-
-    def __get_attr__(self, attr):
-        return None
-
-    def nodes(self):
-        return None
-
-
-class AttributeList(Attribute):
-
-    def __init__(self, items):
-        self.store = items
-        if (sys.version_info > (3, 0)):
-            super().__init__()
-        else:
-            super(AttributeList, self).__init__()
-
-    def add_to(self, node):
-        for item in self.store:
-            node.add(item)
-        return node
-
-
-def display(defs, fname=None):
-    """ print defs"""
-    if fname is not None:
-        with open(fname, 'w') as fop:
-            fop.write("%s" % defs)
-
-
-class TestEcf(unittest.TestCase):
-    """ a test case aka use-case """
-
-    def test_edge(self):
-        import json
-        s = '{"A": {"children": ["B", {"C": {"children": [{"D": {"children": ["E"]}}, "F"]}}]}}'
-        data = json.loads(s)
-        edges = from_json(data)
-
-        def rec_form(row, fop):
-            if len(row) == 0:
-                return
-            elif len(row) == 1:
-                row = row[0]
-            if len(row) == 2:
-                fop.write('  {0} -> {1};'.format(*row))
-            else:
-                for item in row:
-                    rec_form(item, fop)
-        with open('tree.dot', 'w') as fop:
-            fop.write('\nstrict digraph tree {')
-            print("#s\n", s, "\n", edges)
-            rec_form(edges, fop)
-            fop.write('}')
-        """
-        python ecf.py;  # generate tree.dot
-        cat tree.dot | dot -Tpng -otree.png && xdg-open tree.png
-        cat tree.dot | neato -Tpng -otree.png && xdg-open tree.png
-        cat tree.dot | twopi -Tpng -otree.png && xdg-open tree.png
-        """
-
-    def xtest_xxx(self):
-        """ a test """
-        CWN.cdp(False)
-        suite = Suite("Suite").add(Clock("real"),
-                                   Autocancel(3))
-        suite.add(Defstatus("suspended"))
-        suite.add(AutoRestore(["Family", ]))
-
-        fam = Family("Family")
-        fam.add(AutoArchive(3))
-        # empty, index, name, value
-        fam.add(Queue("param", ["u", "v", "t", "q"]))
-        tsk = Task("Task")
-
-        ft2 = Task("Fam")
-        ft2.add_to(fam)
-
-        tsk.VAR = "VALUE"  # edit VAR "VALUE"
-        tsk.add(Late("-s 00:05 -c 01:00"))
-
-        fam.add(tsk,
-                (Task("1"), Task("2")),
-                [Task("11"), Task("12")],
-                Task("111"), Task("211"),
-                # Task("t2").add(Trigger(tsk == COMPLETE),
-                # Late("-s 00:05 -a 01:00 -c 20:00"),
-                #              Time("01:00")),
-                Task("t21").add(Cron("00:00 23:59 01:00")),
-                # each 1st 5th ... by 0900
-                Task("d").add(Cron("-d 1,5,10,15,20,25 09:00")),
-                Task("t22").add(Today("14:00")),
-                Task("t23").add(Date("1.*.*")),
-                Task("t24").add(Day("monday")),
-                )
-
-        fam.add(
-            Task("t3").add(
-                If(test=(1 == 1),
-                   then=Edit(ADD_ONE=1),
-                   otow=Edit(ADD_TWO=1)),
-
-                If(test=(1 == 0),
-                   then=Edit(ADD_ONE=0),
-                   otow=Edit(ADD_TWO=0)),
-                Trigger(tsk != ABORTED),
-                # Complete(tsk == COMPLETE)),
-            ))  # longer
-
-        fam.add(
-            Task("2t"),
-            # Task("t4").add(                Trigger(tsk.name() != COMPLETE)),
-            Late("-s 00:05 -c 01:00"),
-            Edit(VAR="VALUE"),
-            Task("t5").add(Trigger(["t4", "t3", "t2"])),
-            Task("t6").add(Trigger("2t" == COMPLETE)),
-            Task("t7").add(Trigger("2t eq complete")), )
-
-        tsk.add(Limit("a_limit", 10),
-                Inlimit("a_task:a_limit"),
-                Meter("step", -1, 100),
-                Label("info", "none"),
-                Event(num=1, name="1"),
-                Event("a"),
-                Defstatus("complete"))
-
-        Extern("/oper/main:YMD")
-        tsk.add(Edit({"A": "a", "B": "b"}))  # dict
-        tsk.add(Edit(D="d", E="e"))  # list name=value,
-        tsk.add(Edit("C", "c"))  # name, value
-        suite.add(fam,
-                  Task("t321").add(Trigger("Family/t2 eq complete"),
-                                   # TriggerOr("Family/1 eq complete"),
-                                   ),
-                  Family("main").add(
-                      Repeat("YMD", 20200202, 20320202, 7, "date"),
-                      Task("doer").add(Time("04:55"))))
-
-        fam.family("fam").add(Defstatus("complete"))
-
-        DEFS.add(suite)
-        another = DEFS.suite("suite")
-        another.add(Defstatus("suspended"))
-        another.task("tn")
-        afam = another.family("family")
-        afam.task("t2n")
-
-        display(DEFS, fname="test_ecf.tmp")
-        suite.draw_tree()
-        suite.draw_graph()
-        suite.to_html()
-
-        to_json(suite)
-        print("%s" % suite)  # print name
-        print(suite)  # print name
-        print(repr(suite))  # print content
-        print(DEFS)  # print content
-        cmd = "xdg-open test.gv.pdf;"
-        cmd += "dot -Tps test.gv > test.ps && xdg-open test.ps"
-        os.system(cmd)
-
-    def test_cdp_aka_pyflow(self):
-        CWN.cdp(True)
-        with Suite("test",  # trigger="1==1"
-                   ) as s1:
-            with Family("f1"):
-                with Task("t1"):
-                    Event(num=0, name="0")
-                    Event(num=1, name="1")
-                    Meter("step", -1, 120)
-                    Label("info", "msg")
-                with Task("t2"):
-                    pass
-                with Family("f2"):
-                    with Task("t3"):
-                        pass
-
-                with Task("t321").add(
-                        Trigger("Family/t2 eq complete"),
-                        # TriggerOr("Family/1 eq complete"),
-                        ):
-                    pass
-
-                with Task("t123").add(
-                        Trigger("Family/t1 eq complete"),
-                        Trigger("Family/1 eq complete")):
-                    pass
-            if DEBUG:
-                print("#DBG: up*3")
-            with Family("f22"):
-                Task("t01")
-                if DEBUG:
-                    print("#DBG: up")
-                with Task("t11"):
-                    pass
-        if DEBUG:
-            print("#DBG: up*2")
-        print(s1)
-        print(DEFS)
-        CWN.cdp(False)
-
-# from pyflow, COMPAT
-
-
-def definition_to_html(d):
-    result = []
-    for n in d.split("\n"):
-        result.append(n)
-    return "<pre>%s</pre>" % ("\n".join(result),)
-
-
-class HTMLWrapper(object):
-
-    def __init__(self, defs):
-        self._def = defs
-
-    def _repr_html_(self):
-        return definition_to_html(self._def)
-
-    __str__ = _repr_html_
-
-
-def shapes(node):
-    if type(node) in (ecflow.Task, Task):
-        return "triangle"
-    elif type(node) in (ecflow.Family, Family):
-        return "rect"
-    elif type(node) in (ecflow.Suite, Suite):
-        return "invtriangle"
-    return None
-
-
-class Dot(object):
-    """ follow tracks from pyflow """
-
-    def __init__(self, fullnames=True):
-        try:
-            from graphviz import Digraph
-        except ImportError:
-            raise DefError("pip install --user graphviz # ???")
-        self._dot = Digraph()
-        self._nodes = {}
-        self._fullnames = fullnames
-
-    def edge(self, node1, node2):
-        self._dot.edge(self.node(node1), self.node(node2))
-
-    def node(self, node):
-        if node is None:
-            return '/'
-        full = node.get_abs_node_path()
-        if full not in self._nodes:
-            self._nodes[full] = '%s' % node.name()
-        self._dot.node(self._nodes[full],
-                       # fillcolor="shape",
-                       # fontcolor="blue",
-                       # fontsize=32,
-                       # width=0.5,
-                       # style="filled",
-                       # fixedsize="shape",
-                       # fixedsize="true",
-                       # label="xxx",
-                       shape=shapes(node))
-        return self._nodes[full]
-
-    def save(self, path, view=True):
-        if os.path.exists(path):
-            os.unlink(path)
-        self._dot.render(path, view=view)
-
-    # For jupyter notbeook
-    def _repr_svg_(self):
-        return self._dot._repr_svg_()
-
-
-ITEMS = {'suite': Suite,
-         'family': Family,
-         'task': Task,
-
-         ':state': State,
-         ':repeat': Repeat,
-
-         ':event': Event,
-         ':events': Event,
-
-         ':externs': Extern,
-         ':extern': Extern,
-
-         ':meter': Meter,
-         ':meters': Meter,
-
-         ':label': Label,
-         ':labels': Label,
-
-         ':edit': Edit,
-         ':edits': Edit,
-
-         ':inlimit': Inlimit,
-         ':limit': Limit,
-
-         ':inlimits': Inlimit,
-         ':limits': Limit,
-
-         ':trigger': Trigger,
-         ':complete': Complete,
-         ':defstatus': Defstatus,
-         # ':kids': Limit,
-
-         ':time': Time,
-         ':times': Time,
-         ':cron': Cron,
-         ':crons': Cron,
-         ':date': Date,
-         ':dates': Date,
-         ':day': Day,
-         ':days': Day,
-         ':today': Today,
-         ':todays': Today,
-
-         ':zombies': Zombie,  # ecflow.ZombieAttr,
-         ':zombie': Zombie,  # ecflow.ZombieAttr,
-
-         ':late': Late,
-         ':verifies': Verify,
-         ':clock': Clock,
-         ':autocancel': Autocancel,
-
-         ':suites': Suite,  # dict(),
-         ':suite': Suite,  # dict(),
-         }
-
-
-if __name__ == '__main__':
-    unittest.main()
diff -pruN 5.12.4-1/Pyext/samples/api/ls.py 5.13.0-1/Pyext/samples/api/ls.py
--- 5.12.4-1/Pyext/samples/api/ls.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/api/ls.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,359 +0,0 @@
-#!/usr/bin/env python3
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-"""
-dump server content, or a suite, line by line, fullname, for eas
-"""
-from __future__ import print_function
-import pwd
-import sys
-import os
-assert sys.version_info >= (3, )
-import ecflow
-
-
-def printer(opt, iterate, full):
-    if opt:
-        for item in iterate:
-            print(full + ":%s" % item)
-
-
-def liner(full, name, fct):
-    try:
-        item = fct()
-        if item:
-            print(full + ":%s " % name + "%s" % item)
-    except:
-        pass
-
-
-def def_port():
-    port = os.getenv("ECF_PORT", None)
-    if port is None: return 1500 + int(pwd.getpwnam(get_username()).pw_uid)
-    else: return int(port)
-
-
-def get_defs(host=None, port=None, path=None):
-    if host is None:
-        host = os.getenv("ECF_HOST", "localhost")
-    if port is None:
-        port = os.getenv("ECF_PORT", def_port())
-
-    client = ecflow.Client(host, port)
-    reg = False
-    if path:
-        if '/' in path and '/' != path:
-            reg = str(path.split('/')[1])
-            client.ch_register(False, [reg, ])
-            print(reg)
-            reg = True
-        elif path == '/': pass
-        else:
-            raise Exception(path)
-    else:
-        raise Exception(path)
-    client.sync_local()
-    if reg:
-        client.ch_drop()
-    return client.get_defs()
-
-
-def print_trigger(full, kind, expr):
-    if not expr:
-        return
-    expr = "'%s'" % expr
-    print(full, kind, expr.replace(
-        " and ", " AND ").replace(
-            " or ", " OR ").replace(
-                " eq ", " == "))
-
-
-class Ls(object):
-
-    def __init__(self, parsed=None):
-        # print(parsed)
-        if parsed is None:
-            parsed.path = '/'
-            parsed.recursive = True
-            parsed.triggers = True
-            parsed.variables = True
-            parsed.status = True
-            parsed.display = True
-
-        if parsed.path is None:
-            parsed.path = '/'
-            if parsed.node != '/':
-                parsed.path = parsed.node
-
-        if parsed.all:
-            parsed.recursive = True
-            parsed.verbose = True
-            parsed.display = True
-            parsed.dates = True
-            parsed.times = True
-            parsed.meters = True
-            parsed.events = True
-            parsed.labels = True
-            parsed.limits = True
-            parsed.inlimits = True
-            parsed.triggers = True
-            # parsed.gvar = True
-            parsed.status = True
-            # parsed.sms = True
-            parsed.variables = True
-
-        self.parsed = parsed
-
-        # path = parsed.path
-        if parsed.path is not None:
-            filename = parsed.path.replace("/", "_") + ".tmp"
-
-        if parsed.sms:
-            user = os.getlogin()
-            log = "set SMS_PROG %s; login %s %s 1;" % (
-                parsed.port, parsed.host, user)
-            grep = "|grep -v 'trigger ( an eq complete or an eq unknown)'"
-            grep = "|grep -v 'fsobs eq complete or fsobs eq unknown'"
-            get = "get %s; show %s %s > %s; " % (
-                parsed.path, parsed.path, grep, filename)
-            cdp = "/usr/local/apps/sms/bin/cdp"
-            cmd = cdp + "<<EOF\n" + log + get + "exit 0\nEOF"
-            print("#cmd:", cmd)
-            os.system(cmd)
-        elif parsed.file:
-            defs = ecflow.Defs(parsed.file)
-            # defs.add(ecflow.Suite("o").add(ecflow.Family("lag")))
-            num = 0
-            for s in defs.suites:
-                name = s.name()
-                num += 1
-            if parsed.path is None and num == 1:
-                parsed.path = "/" + name
-        else:
-            defs = get_defs(parsed.host, parsed.port, parsed.path)
-            defs.auto_add_externs(True)
-            try: defs.save_as_defs(filename)
-            except: print("cannot save", filename)
-
-        # defs = ecflow.Defs(filename)
-        # defs.auto_add_externs(True)
-        for s in defs.suites:
-            # print(s)
-            if s.get_abs_node_path() is None:
-                continue
-            if parsed.path is None:
-                continue
-            if s.get_abs_node_path() in parsed.path or parsed.path == "/":
-                self.process(s, parsed.path)
-
-    def process(self, node, path):
-        full = node.get_abs_node_path()
-        # print(node.name(), path)
-        if ":" in path:
-            top, nam = path.split(":")
-        else:
-            nam = None
-            top = path
-        if top in full:
-            pass
-        elif full in top:
-            rc = None
-            for curr in node.nodes:
-                res = self.process(curr, path)
-                if res is not None:
-                    rc = res
-            return rc
-        else:
-            return None
-
-        status = None        
-        if nam is None or self.parsed.display:
-            if status is None: status = "%s" % node.get_state()
-            if type(node) == ecflow.Task:
-                num = 10
-                kind = "task"
-            elif type(node) == ecflow.Family:
-                num = 11
-                kind = "family"
-            elif type(node) == ecflow.Suite:
-                num = 12
-                kind = "suite"
-            elif type(node) == ecflow.Alias:
-                # return
-                num = 13
-                kind = "alias"
-            else:
-                print(type(node))
-                raise BaseException("node kind?", type(node))
-            print(node.get_abs_node_path(), num, kind, status, end="\n")
-
-        elif self.parsed.display:
-            status = "%s" % node.get_state()
-            nums = {"unknown": 0,
-                    "suspended": 1,
-                    "complete": 2,
-                    "queued": 3,
-                    "submitted": 4,
-                    "active": 5,
-                    "aborted": 6,
-                    "shutdown": 7,
-                    "halted": 8}
-            print(nums[status], status)
-
-        elif self.parsed.status:
-            status = "%s" % node.get_state()
-            print(status)
-
-        else:
-            print()
-        # print(self.parsed)
-        printer(self.parsed.events, node.events, full)
-        printer(self.parsed.meters, node.meters, full)
-        printer(self.parsed.labels, node.labels, full)
-
-        printer(self.parsed.limits, node.limits, full)
-        printer(self.parsed.inlimits, node.inlimits, full)
-
-        printer(self.parsed.dates, node.dates, full)
-        printer(self.parsed.dates, node.days, full)
-
-        printer(self.parsed.times, node.times, full)
-        printer(self.parsed.times, node.crons, full)
-        printer(self.parsed.times, node.todays, full)
-        if self.parsed.triggers:
-            print_trigger(full, ":trigger", node.get_trigger())
-            print_trigger(full, ":complete", node.get_complete())
-        # for item in node.zombies: print(full + ":%s" % item, end="")
-        if self.parsed.variables or ":" in path:
-            item = node.get_repeat()
-            if not item.empty():
-                if nam == item.name() or not nam:
-                    print(full + ":repeat", item.name(), item.value(), "'%s'" % item, end="\n")
-
-            # for item in sorted(node.variables):
-            for item in node.variables:
-                if 1: #  and nam == item.name() or not nam:
-                    if " " in item.value() and not "'" in item.value() and not "\"" in item.value():
-                        print(full + ":%s" % item.name(), "'%s'" % item.value(), end="\n")
-                    else: print(full + ":%s" % item.name(), item.value(), end="\n")
-                    # if self.parsed.verbose: print(" " + item.value())
-                    # else: print()
-                    if nam == item.name():
-                        sys.exit(0)
-
-            gvar = ecflow.VariableList()
-            if self.parsed.gvar:
-                node.get_generated_variables(gvar)
-            for item in gvar:
-                if 1 and nam == item.name() or not nam:
-                    try:
-                        print(full + ":gedit", item.name(), )
-                        if self.parsed.verbose:
-                            print(" %s" % item.value())
-                        else:
-                            print()
-                    except:
-                        pass
-                    if nam == item.name():
-                        sys.exit(0)
-
-        item = node.get_late()
-        if item and self.parsed.verbose:
-            print(full, ":late", item)
-        #item = node.get_defstatus();
-        # if item:
-        #    item = "%s" % item
-        #    if "queued" not in item: print(full, ":defstatus", item)
-        item = node.get_autocancel()
-        if item and self.parsed.verbose:
-            print(full, ":autocancel", item)
-
-        # #liner(full, "late", node.get_late)
-        # liner(full, "clock", node.get_clock)
-        if self.parsed.verbose:
-            liner(full, "defstatus", node.get_defstatus)
-        # liner(full, "autocancel", node.get_autocancel)
-        # liner(full, "complete", node.get_complete)
-        # liner(full, "trigger", node.get_trigger)
-
-        if type(node) == ecflow.Alias:
-            return node
-
-        if self.parsed.recursive:
-            for curr in node.nodes:
-                self.process(curr, path)
-        return node
-
-
-def pars():
-    import argparse
-    parser = argparse.ArgumentParser(add_help=False)
-    # parser.add_argument("-h", default=0, help="help")
-    parser.add_argument("-H", "--host", default="localhost", help="host")
-    parser.add_argument("-p", "--port", default="%d" % def_port(), help="port")
-    parser.add_argument("-a", "--all", action="store_true", help="all")
-    parser.add_argument("-A", "--Alias", action="store_true", help="aliases")
-    parser.add_argument("-f", "--file", default=None, help="file")
-    parser.add_argument("-F", "--force", action="store_true", help="force")
-    # parser.add_argument("-n", "--node", default="/", help="node")
-    parser.add_argument("-N", "--node", default=None, help="node")
-    parser.add_argument("-P", "--path", default=None, help="path")
-    parser.add_argument("-R", "--recursive", action="store_true", help="recursive")
-    parser.add_argument("-v", "--verbose", action="store_true", help="verbose")
-    parser.add_argument("-d", "--display", action="store_true", help="display")
-    parser.add_argument("-D", "--dates", action="store_true", help="Dates")
-    parser.add_argument("-t", "--times", action="store_true", help="times")
-    parser.add_argument("-m", "--meters", action="store_true", help="meters")
-    parser.add_argument("-e", "--events", action="store_true", help="events")
-    parser.add_argument("-l", "--labels", action="store_true", help="labels")
-    parser.add_argument("-L", "--limits", action="store_true", help="limits")
-    parser.add_argument("-i", "--inlimits",
-                        action="store_true", help="inlimits")
-    parser.add_argument("-T", "--triggers",
-                        action="store_true", help="triggers")
-    parser.add_argument("-G", "--gvar", action="store_true", help="gvars")
-    parser.add_argument("-S", "--status", action="store_true", help="Status")
-    parser.add_argument("-s", "--sms", action="store_true", help="sms")
-    parser.add_argument("-V", "--variables", action="store_true", help="variables")
-    parser.add_argument('node', nargs="?", type=str)
-    return parser
-
-
-def get_username():
-    return pwd.getpwuid(os.getuid())[0]
-
-
-if __name__ == "__main__":
-    parsed = pars().parse_args()
-    # print("#", parsed)
-    Ls(parsed)
-
-
-"""
-aaa
-ECF_HOST=localhost ECF_PORT=3141 ./ls.py -Rv --path /eda
-
-./ls.py --host=localhost --port=3141 -n vsms1 -R -v -N /eda
-
-ECF_HOST=vsms1 ECF_PORT=32222 python ls.py /seas_mm/main
-ECF_HOST=vsms1 ECF_PORT=43333 python t3.py e_sapp main
-ecflow_client --port 32222 --host vsms1 --get_state /seas_mm
-ecflow_client --port 32222 --host vsms1 --stats | grep Stat
-cdp -c "od; sms -s " | grep Status
-rcp ls.py emos@ibis:/home/ma/emos/bin/ls.py
-
-ls.py -h vsmsrdna -p 314122 -s -n /map
-python ~/git/suites/o/def/tkinter/ls.py -h vsmsrdna -p 314122 -s -n /map
-
-python ./cli_proc.py -c -r vsms1:32112 o /o eurus:1630
-python ./cli_proc.py -c -r vecfrdda1:11001 dag /dag/gsup eurus:1630
-
-./ls.py -V -t -R -P /USER
-./ls.py -T -R -V -v -t -d -D -e -m -l -P /USER
-/ls.py -T -p $ECF_PORT -h $ECF_HOST -NRVvtdDemlT /
-
-"""
diff -pruN 5.12.4-1/Pyext/samples/api/sms2ecf.py 5.13.0-1/Pyext/samples/api/sms2ecf.py
--- 5.12.4-1/Pyext/samples/api/sms2ecf.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/api/sms2ecf.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,193 +0,0 @@
-#!/usr/bin/env python
-""" one module to store needed function to translate SMS-ECFLOW suites """
-import sys
-ECF_MODE = "ecflow" # "sms"
-
-# RAW_MODE:
-# False: translate *_CMD (submit, kill, status) variables values for %ECF_ + number args
-# True:  just translate the name, and %ECF_, not arguments number
-
-RAW_MODE = False    
-# ECF_MODE = "sms"
-CDP = "/usr/local/apps/sms/bin/cdp"
-subm = "/home/ma/emos/bin/trimurti"
-kill = subm
-stat = subm
-
-DICT_SMS_ECF = {
-    'SMSNAME': 'ECF_NAME',
-    'SMSNODE': 'ECF_HOST',
-    'SMSPASS': 'ECF_PASS',
-    'SMS_PROG': 'ECF_PORT',
-    'SMSFILES': 'ECF_FILES',
-    'SMSINCLUDE': 'ECF_INCLUDE',
-    'SMSTRIES':   'ECF_TRIES',
-    'SMSTRYNO': 'ECF_TRYNO',
-    'SMSTRIE': 'ECF_TRIE',
-    'SMSHOME': 'ECF_HOME',
-    'SMSRID': 'ECF_RID',
-    'SMSJOB': 'ECF_JOB',
-    'SMSJOBOUT': 'ECF_JOBOUT',
-    'SMSOUT': 'ECF_OUT',
-    'SMSCHECKOLD': 'ECF_CHECKOLD',
-    'SMSCHECK': 'ECF_CHECK',
-    'SMSLOG': 'ECF_LOG',
-    'SMSLIST': 'ECF_LIST',
-    'SMSPASSWD': 'ECF_PASSWD',
-    'SMSSERVER': 'ECF_SERVER',
-    'SMSMICRO': 'ECF_MICRO',
-    'SMSPID': 'ECF_PID',
-    'SMSHOST': 'ECF_HOST',
-    'SMSDATE': 'ECF_DATE',
-    'SMSURL': 'ECF_URL',
-    'SMSURLBASE': 'ECF_URLBASE',
-    'SMSCMD': 'ECF_JOB_CMD',
-    'SMSKILL': 'ECF_KILL_CMD',
-    'SMSSTATUSCMD': 'ECF_STATUS_CMD',
-    'SMSJOBCHECK': 'ECF_CHECK_CMD',
-    'SMSURLCMD': 'ECF_URL_CMD',
-    'SMSWEBACCES': 'ECF_WEBACCES',
-    'SMS_VER': 'ECF_VER',
-    'SMS_VERSION': 'ECF_VERSION',
-    'SMSLOGHOST': 'ECF_LOGHOST',
-    'SMSLOGPORT': 'ECF_LOGPORT',
-    'SMSLOGTIMEOUT': 'ECF_LOGTIMEOUT',
-}
-
-DICT_ECF_SMS = dict((v, k) for k, v in DICT_SMS_ECF.items())
-      
-def translate(name, value=None):
-    """ find and replace submit, kill and status command, according to
-    sms/ecflow mode """
-    value2 = value
-    transl = name
-    smssubmit = "trimurti"
-    ecfsubmit = "/home/ma/emos/bin/ecflow_submit"
-
-    def add_ext(name, value):
-            if "_v2" in value: rc = " %ECF_JOB% %SCHOST% %USER%"
-            elif "kill" in value or "stat" in value:
-                if "WSHOST" in value: rc = RIDCLWS
-                else: rc = RIDCL
-            # if "submit" in value: 
-            #     if "WSHOST" in value: rc = JOBCLWS
-            #     else: rc = JOBCL
-            elif "WSHOST" in value: rc = JOBCLWS
-            else: rc = JOBCL
-
-            if name in  ('ECF_JOB_CMD', 'SMSCMD'):
-                 rc = SUBCMD + " " + rc 
-            elif name in ('ECF_KILL_CMD', 'SMSKILL'):
-                if "submit" in KILLCMD:
-                    rc = KILLCMD + " %s kill" % rc
-                else: rc = KILLCMD + " %s " % rc
-            elif name in ('ECF_STATUS_CMD', 'SMSSTATUS', 
-                           'ECF_CHECK_CMD', 'SMSJOBCHECK'):
-                if "submit" in STATCMD:
-                     rc = STATCMD + " %s status" % rc
-                else: rc = STATCMD + " %s" % rc
-            return rc
-
-    if ECF_MODE == "ecflow" and name in DICT_SMS_ECF:
-        if name in ('SMSCMD', 'SMSKILL', 'SMSSTATUSCMD', 'SMSHOME'):
-            value2 = value.replace('SMS', 'ECF_')
-            value  = value2.replace(smssubmit, ecfsubmit)
-        elif name in ('ECF_JOB_CMD', 'ECF_KILL_CMD', 'ECF_STATUS_CMD'):
-            value2 = value.replace('SMS', 'ECF_')
-            value  = value2.replace(smssubmit, ecfsubmit)
-        transl = DICT_SMS_ECF[name]
-
-    elif ECF_MODE == "sms"  and name in DICT_ECF_SMS:
-        if name in  ('ECF_CMD_CMD', 'ECF_KILL_CMD', 'ECF_STATUS_CMD'):
-            value2 = value.replace('ECF_', 'SMS')  
-        transl = DICT_ECF_SMS[name]
-
-    else: pass
-
-    if ECF_MODE == "sms" and RAW_MODE:
-        value2 = value.replace("ECF_", "SMS")
-        return transl, value2
- 
-    elif ECF_MODE == "sms" and "CMD" in name and not "submit" in value:
-        if name in ('ECF_JOB_CMD'): name = "SMSCMD"
-        elif name in ('ECF_KILL_CMD'): name = "SMSKILL"
-        elif name in ('ECF_STATUS_CMD'): name = "SMSSTATUS"
-        value2 = value.replace("ECF_", "SMS")
-        value  = value2
-
-    elif ECF_MODE == "sms":
-             SUBCMD  = subm
-             KILLCMD = kill
-             STATCMD = stat
-
-             JOBCL  = ' %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
-             RIDCL  = ' %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
-             STATL  = ' %USER% %SCHOST% %SMSRID% %SMSJOB%'
-             STATLWS  = ' %USER% %WSHOST% %SMSRID% %SMSJOB%'
-
-             JOBCLWS = JOBCL.replace("%SC", "%WS")
-             RIDCLWS = RIDCL.replace("%SC", "%WS") # .replace("HOST%", "HOST% %SMSRID%")
-             if name in  ('ECF_JOB_CMD', 'SMSCMD'):
-                 value2 = add_ext(name, value)
-             elif name in ('ECF_KILL_CMD', 'SMSKILL'):
-                 if "submit" in KILLCMD:
-                     value2 = KILLCMD + add_ext(value, value) + " kill"
-                 else: value2 = KILLCMD + add_ext(value, value)
-             elif name in ('ECF_STATUS_CMD', 'SMSSTATUS', 
-                           'ECF_CHECK_CMD', 'SMSJOBCHECK'):
-                 if "submit" in STATCMD:
-                     value2 = STATCMD + add_ext(value, value) + " status"
-                 else: value2 = STATCMD + add_ext(value, value)
-             return transl, value2
-    return transl, value
-
-
-def get(name, host="localhost", port=314159):
-    import os, pwd
-    os.getlogin = lambda: pwd.getpwuid(os.getuid())[0]
-    user = os.getlogin()
-    cmd = "setenv -i HOME USER; set SMS_PROG %d; login %s %s 1; status > /dev/null ; get; show > %s; " % (port, host, user, name)
-    os.system("cdp -c '%s'" % cmd)
-
-def ignore(): pass
-
-ignored = ( "action", "owner", "text", "migrate", "automigrate", "autorestore")
-def sms2ecf(orig, dest):
-   import re
-   with open(dest, 'w') as fop:
-       with open(orig, 'r') as source:
-            try:
-                for line in source:
-                    for key in ignored:
-                        if " %s " % key in line: 
-                            continue                
-                    print(line, file=fop)
-            except:
-                print("oops")
-
-def load(name, host="localhost", port=31415):
-    import ecflow as ec
-    client = ec.Client(host, port)
-    try:
-        client.load(name)
-    except:
-        client.replace("/", name)
-
-if __name__ == "__main__":
-    import sys
-    try:
-        sms  = sys.argv[1]
-        prog = sys.argv[2]
-        ecf  = sys.argv[3]
-        port = sys.argv[4]
-    except:
-        sms  = "localhost"
-        prog = 314159
-        ecf  = "localhost"
-        port = 31415
-
-    before = "from_sms.exp"
-    become = "prep_ecf.exp"
-    get(name=before)
-    sms2ecf(orig=before, dest=become)
-    load(name=become)
diff -pruN 5.12.4-1/Pyext/samples/check_modules.py 5.13.0-1/Pyext/samples/check_modules.py
--- 5.12.4-1/Pyext/samples/check_modules.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/check_modules.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,156 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-"""Check if expected modules are loaded.
-
-Usage:
- ./check_modules.py --m "module load git module swap PrgEnv-cray PrgEnv-gnu " --f module_list_file
- ./check_modules.py --m "module swap PrgEnv-cray PrgEnv-gnu" --f module_list_file
- ./check_modules.py --m "module unload grib_api" --f module_list_file
- ./check_modules.py --m "module load gnu/4.8.1 module load python/2.7.8-01" --f module_list_file
- ./check_modules.py --m "module swap PrgEnv-cray PrgEnv-gnu module load cdt/16.03" --f module_list_file
- ./check_modules.py --m "module swap craype-network-aries craype-network-none module switch fftw/3.3.4.7" --f module_list_file
-
-module_list_file is the output of module list e.g.
-
-Currently Loaded Modulefiles:
-  1) version/3.2.10(default)             7) ecfs/2.2.1-rc2(new:prodn:default)
-  2) verbose/true(default)               8) metview/4.6.4(default)
-  3) mode/64(default)                    9) ecaccess/4.0.2(default)
-  4) gnu/4.8.1(default)                 10) fftw/3.3.4(default)
-  5) python/2.7.8-01(default)           11) emos/437(default)
-  6) sms/4.4.14(default)                12) ecmwf/1.0(default)
-"""
-
-import argparse
-import re
-import sys
-
-def main():
-    PARSER = argparse.ArgumentParser(description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--m', help="Space separated list of module commands")
-    PARSER.add_argument('--f', help="Path to a file that is the output of module list")
-    PARSER.add_argument('--remote_host', help="remote host")
-    ARGS = PARSER.parse_args()
-
-    delimter = "module "
-    module_cmds = [e.strip() for e in ARGS.m.split(delimter) if e.strip() != ""]
-    print("module_cmds ",module_cmds)
-
-    module_actions = ("load", "add", "rm", "unload", "swap", "switch")
-    modules_required = dict()
-    modules_missing = set()
-
-    def set_version(s):
-        print(" set_version ",s)
-        try:
-            mod, version = s.split('/')
-        except ValueError:
-            mod = s
-            version = None
-        modules_required[mod] = version
-        if mod in modules_missing:
-             modules_missing.remove(mod)
-
-    def unset_version(s):
-        # Unloading a specific version has no effect if a different version is loaded!
-        print(" unset_version ",s)
-        try:
-            mod, version = s.split('/')
-            if mod in modules_required and modules_required[mod] == version:
-                modules_required.pop(mod)
-            modules_missing.add(s)
-        except ValueError:
-            if s in modules_required:
-                modules_required.pop(s)
-            modules_missing.add(s)
-
-    print("=========================================================")
-    print("Read input module list->",module_cmds)
-    print("=========================================================")
-    for mod in module_cmds:
-        module_cmd = mod.split()
-        print("module_cmd ",module_cmd)
-        action = module_cmd[0]
-        if action not in module_actions:
-            print("Error: Module command ", module_cmd, " is not correctly formed, second arg must be one of", ', '.join(module_actions))
-            return 1
-        if action in ('load', 'add'):
-            if len(module_cmd) != 2:
-                print("Error: invalid module command '%s'" % ' '.join(module_cmd))
-            set_version(module_cmd[1])
-        if action in ('swap', 'switch'):
-            # Swap takes either 1 or 2 arguments
-            # module swap pkg/version <-- unloads pkg, loads pkg/version
-            # module swap pkg1/v1 pkg2/v2 <-- unloads pkg1/v1, loads pkg2/v2
-            if len(module_cmd) > 3:
-                print("Error: invalid module command '%s'" % ' '.join(module_cmd))
-            if len(module_cmd) == 3:
-                unset_version(module_cmd[1])
-            set_version(module_cmd[-1])
-        if action in ('rm', 'unload'):
-            if len(module_cmd) != 2:
-                print("Error: invalid module command '%s'" % ' '.join(module_cmd))
-            unset_version(module_cmd[1])
-
-    print("=========================================================")
-    print("Read module list file->",ARGS.f)
-    print("=========================================================")
-    modules_loaded = dict()
-    module_list = list()
-    with open(ARGS.f) as module_list_file:
-        for line in module_list_file:
-            #print line
-            line = line.rstrip()
-            if line.find("Currently Loaded") == 0: continue;
-            tokens = re.split(r'\s|\d+\)',line)
-            while '' in tokens: tokens.remove('')
-            #print "tokens",tokens
-            for tok in tokens:
-                #print "tok",tok
-                count = tok.count('/')
-                if count == 1:
-                   mod,version = tok.split('/')
-                   version = version.split("(")[0]
-                   print("->(",mod,",",version,")")
-                   modules_loaded[mod] = version
-                else:
-                   print("->(",tok,",None)")
-                   modules_loaded[tok] = None
-
-    print("=========================================================")
-    print("Checking")
-    print("=========================================================")
-    print("->module_missing:   ",modules_missing)
-    print("->modules_required: ",modules_required)
-    print("->module list:      ",modules_loaded)
-    failed = 0
-    for mod, version in list(modules_required.items()):
-        if version and modules_loaded.get(mod) != version or version is None and mod not in modules_loaded:
-            print("Error: expected module %s/%s not found in module list" % (mod, version))
-            failed = 1
-    for module in modules_missing:
-        print("modules_missing - ", module)
-        if '/' in module:
-            mod, version = module.split('/')
-            if modules_loaded.get(mod) == version:
-                print("Error: unexpected module %s/%s found in module list" % (mod, version))
-                failed = 1
-        else:
-            if module in modules_loaded:
-                print("Error: unexpected module %s found in module list" % module)
-                failed = 1
-    return failed
-
-if __name__ == "__main__":
-    sys.exit(main())
diff -pruN 5.12.4-1/Pyext/samples/cray.py 5.13.0-1/Pyext/samples/cray.py
--- 5.12.4-1/Pyext/samples/cray.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/cray.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,2189 +0,0 @@
-#!/usr/bin/env python
-# -*- coding= UTF-8 -*-
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# file deepcode ignore MissingCloseOnSomePath: <comment the reason here>
-
-import sys, os, pwd, getopt
-sys.path.append('/home/ma/emos/def/o/def')
-import inc_emos as ic
-from ecf import *
-import ecf
-from inc_emos import Family, Task, Variables, Time, Meter, Event, Label, Late
-import sms2ecf
-
-# ecf.USE_TRIGGER = 0 # DEBUG MODE: do not load triggers
-
-def get_username():
-    return pwd.getpwuid( os.getuid() )[ 0 ]
-def get_uid():
-    return pwd.getpwnam(get_username()).pw_uid
-
-def create_wrapper(name, content):
-    print("#MSG: creating file %s/" % wdir + name)
-    wrapper = open(wdir + "/%s" % name, 'w')
-    print(content, file=wrapper)
-    wrapper.close()    
-##############################################
-
-# ic.SUBM = "/home/ma/emos/bin/smssubmit.cray"
-# ic.KILL = "/home/ma/emos/bin/smssubmit.cray"
-# ic.STAT = "/home/ma/emos/bin/smssubmit.cray"
-# sms2ecf.subm = "/home/ma/emos/bin/smssubmit.cray"
-# sms2ecf.kill = "/home/ma/emos/bin/smssubmit.cray"
-# sms2ecf.stat = "/home/ma/emos/bin/smssubmit.cray"
-
-def create_task():
-    ### PRODUCER/CONSUMER TASK
-    produce = '''#!/bin/ksh
-%manual
-  start - check - stop logsvr
-%end
-%include <qsub.h>
-%include <trap.h>
-
-step=%BEG:0%
-while [ $step -le %FIN:48% ]; do
-  if [[ %PRODUCE:1% = yes ]]; then
-    xevent p
-  elif [[ %CALL_WAITER:0% != 0 ]]; then
-case %ECF_PROG:0% in 
-0) smswait %TRIGGER:1==1%;;
-*) ecflow_client --wait "%TRIGGER:1==1%";;
-esac
-  fi
-
-  if [[ %CONSUME:no% = yes ]]; then
-    xevent c
-  fi
-
-  xmeter step $step
-  step=$((step + %BY:1%))
-done
- 
-%include <endt.h>
-'''
-    create_wrapper("produce.sms", produce)
-
-    create_wrapper("consume.sms", produce)
-    ### PURE PYTHON
-
-    head = """import os, time, signal
-import ecflow
-  
-print "PYTHONPATH====================================================="
-print os.environ['PYTHONPATH'].split(os.pathsep)
- 
-class Client(object):
-    ''' communication with the ecflow server. This will automatically call
-       the child command init()/complete(), for job start/finish. It will also
-       handle exceptions and signals, by calling the abort child command.
-       *ONLY* one instance of this class, should be used. Otherwise zombies will be created.
-    '''
-    def __init__(self):
-      print "Creating Client"
-      self.ci = ecflow.Client()
-      self.ci.set_host_port("$ECF_HOST$","$ECF_PORT$")
-      self.ci.set_child_pid(os.getpid())
-      self.ci.set_child_path("$ECF_NAME$")
-      self.ci.set_child_password("$ECF_PASS$")
-      self.ci.set_child_try_no($ECF_TRYNO$)
-    
-      print "Only wait 20 seconds, if the server cannot be contacted (note default is 24 hours) before failing"
-      self.ci.set_child_timeout(20)
-      self.ci.set_zombie_child_timeout(10)
-     
-      # Abort the task for the following signals
-      signal.signal(signal.SIGINT,  self.signal_handler)
-      signal.signal(signal.SIGHUP,  self.signal_handler)
-      signal.signal(signal.SIGQUIT, self.signal_handler)
-      signal.signal(signal.SIGILL,  self.signal_handler)
-      signal.signal(signal.SIGTRAP, self.signal_handler)
-      signal.signal(signal.SIGIOT,  self.signal_handler)
-      signal.signal(signal.SIGBUS,  self.signal_handler)
-      signal.signal(signal.SIGFPE,  self.signal_handler)
-      signal.signal(signal.SIGUSR1, self.signal_handler)
-      signal.signal(signal.SIGUSR2, self.signal_handler)
-      signal.signal(signal.SIGPIPE, self.signal_handler)
-      signal.signal(signal.SIGTERM, self.signal_handler)
-      signal.signal(signal.SIGXCPU, self.signal_handler)
-      signal.signal(signal.SIGPWR,  self.signal_handler)
-     
-    def signal_handler(self,signum, frame):
-      print 'Aborting: Signal handler called with signal ', signum
-      self.ci.child_abort("Signal handler called with signal " + str(signum));
-     
-    def __enter__(self):
-      self.ci.child_init()
-      return self.ci
-     
-    def __exit__(self,ex_type,value,tb):
-      print "Client:__exit__: ex_type:" + str(ex_type) + " value:" + str(value) + "\\\n" + str(tb)
-      if ex_type is not None:
-         self.ci.child_abort("Aborted with exception type " + str(ex_type) + ":" + str(value))
-         return False
-      self.ci.child_complete()
-      return False
-"""
-    body = """#!/usr/bin/env python
-$include <head.py>
- 
-if __name__ == "__main__":
-# This will also handle call to sys.exit(), i.e Client.__exit__ will still be called.
-   with Client() as ci:
-   # *******************************************************************************
-   # This is where the main work is done.
-   # *******************************************************************************
-      for i in range(1,100):
-         ci.child_meter('step',i)
-         ci.child_label('info', "value_" + str(i))
-         time.sleep(1)
-       
-      ci.child_event('1')
-      print "Finished event,meter and label child commands"
- 
-$manual
-   This is the manual section. Instead of calling python from the ECF_JOB_CMD we could alternatively place,
-       #!/bin/env/python
-   on the first line of this file.
-$end
- 
-$comment
-   Note: We do not need a include a tail.py, the head.py does it all.
-$end
-
-"""
-    create_wrapper("head.py", head)
-    create_wrapper("pure_python.sms", body)
-    ### PYTHON TASK
-    content = """$include <python_header.h>
-# header files are located in the same directory as wrapper (quotes)
-for step in range(0,101):
-    print step
-    xmeter("step", step)
-else:
-    print 'the loop is over'
-xevent("1")
-xlabel("info", "news from pure python world")
-
-$include <python_endt.h>
-"""
-    create_wrapper("python.sms", content)
-
-    content = """#!/usr/bin/env python
-import os
-import sys
-import signal 
-
-ECF_PORT=$ECF_PORT:0$
-XECF="/usr/local/apps/ecflow/current/bin/ecflow_client ";
-# --port=$ECF_PORT:0$ --host=$ECF_HOST:0$ ";
-def SigHandler(signum, frame):
-   print "caught signal " + signum
-   xabort()
-   sys.exit(0);
-   return
-
-print ECF_PORT
-# set -eux ?
-# trap 0 ?
-# time stamp per executed line
-
-import atexit
-early_exit = True
-@atexit.register
-def goodbye():
-  if early_exit: 
-    print "too early"
-    xabort()
-  else: 
-    xcomplete()
-
-# TIME_STAMP
-# http://shop.oreilly.com/product/9780596007973.do # recipie p436
-import syslog, time
-
-class FunctionFileLikeWrapper():
-    def __init__(self, func): self.func = func
-    def write(self, msg): self.func(msg)
-    def flush(self): pass
-
-class TimeStamper(object):
-    msg_format = "[%y%m%d %H:%M:%S]", time.gmtime, "%s: %s"
-    msg_format = "+ %H:%M:%S", time.gmtime, "%s %s"
-
-    def __call__(self, msg):
-        tfmt, tfun, gfmt = self.msg_format
-        return "%s %s\\\n" % (time.strftime(tfmt, tfun()), msg)
-
-class TeeFileLikeWrapper():
-    def __init__(self, *files): self.files = files
-    def write(self, msg): 
-        for f in self.files: f.write(timestamp(msg.strip()))
-
-class FlushingWrapper:
-    def __init__(self, *files): self.files = files
-    def write(self, msg):
-        for f in self.files:
-            f.write(timestamp(msg))
-            # f.write(timestamp(msg.strip()))
-            f.flush()
-
-def logto(*files):
-    # sys.stdout = TeeFileLikeWrapper(*files)
-    sys.stdout = FlushingWrapper(*files)
-
-syslogger = syslog.syslog
-syslogfile = FunctionFileLikeWrapper(syslogger)
-timestamp = TimeStamper()
-logto(sys.stdout, syslogfile, open("log.tmp", "w"))
-# end time stamp
-
-if ECF_PORT > 0:
-  os.environ['ECF_PORT'] = "$ECF_PORT:0$"
-  os.environ['ECF_NAME'] = "$ECF_NAME:0$"
-  os.environ['ECF_HOST'] = "$ECF_HOST:0$"
-  os.environ['ECF_PASS'] = "$ECF_PASS:0$"
-
-  def xinit():
-    os.system(XECF + " --init=" + str(os.getpid()))  
-    print "init"
-  def xabort():
-    os.system(XECF + " --abort")  
-  def xcomplete():
-    os.system(XECF + " --complete")  
-  def xmeter(name, step):
-    os.system(XECF + " --meter=" + name + " " + str(step))  
-  def xevent(name):
-    os.system(XECF + " --event=" + name)  
-  def xlabel(name, msg):
-    os.system(XECF + " --label=" + name + " '%s'" % msg)  
-else:
-  os.environ['SMS_PROG'] = "$SMS_PROG:0$"
-  os.environ['SMSNAME'] = "$SMSNAME:0$"
-  os.environ['SMSNODE'] = "$SMSNODE:0$"
-  os.environ['SMSPASS'] = "$SMSPASS:0$"
-
-  def xinit():
-    os.system('smsinit ' + str(os.getpid()))
-  def xabort():
-    os.system('smsabort')
-  def xcomplete():
-    os.system('smscomplete')
-  def xmeter(name, step):
-    os.system("smsmeter " + name + " " + str(step))
-  def xevent(name):
-    os.system("smsevent " + name)
-  def xlabel(name, msg):
-    os.system("smslabel " + name + " '%s'" % msg)
-
-signal.signal (signal.SIGHUP,  SigHandler)
-signal.signal (signal.SIGINT,  SigHandler)
-signal.signal (signal.SIGQUIT, SigHandler)
-signal.signal (signal.SIGILL,  SigHandler)
-signal.signal (signal.SIGTRAP, SigHandler)
-signal.signal (signal.SIGIOT,  SigHandler)
-signal.signal (signal.SIGBUS,  SigHandler)
-signal.signal (signal.SIGFPE,  SigHandler)
-
-"""
-    create_wrapper("python_header.h", content)
-
-    content = """# os.system('smscomplete')
-early_exit = False
-# xcomplete() # managed with atexit
-# os.system('/usr/local/apps/sms/bin/ecflow/bin/ecf_client --complete')
-"""
-    create_wrapper("python_endt.h", content)
-
-    ### PERL TASK
-    create_wrapper("perl.sms", """#!/usr/bin/perl -w
-^include <perl_header.h>
-# header files are located in the same directory as wrapper (quotes)
-print "Pure perl SMS task";
-for ( my $step=1; $step <= 100 ; $step++ ) {
-   print "this is the number $step\\\n";
-   xmeter("step", $step);
-}
-xevent("1");
-            
-xlabel("info", "news from pure perl world");      
-^include <perl_endt.h>
-""")
-    # create_wrapper("perl.sms", content)
-
-    source = """use strict;
-
-my $xmeter = "smsmeter"; my $arg_m = "";
-my $xlabel = "smslabel"; my $arg_l = "";
-my $xevent = "smsevent"; my $arg_e = "";
-my $xcomplete = "smscomplete"; my $arg_c = "";
-my $xabort = "smsabort";
-
-if (^ECF_PORT:0^ != 0) {
-$ENV{'ECF_PORT'}  = "^ECF_PORT:0^" ;  # ecFlow port number
-$ENV{'ECF_HOST'}  = "^ECF_HOST:0^"  ; # ecFlow host
-$ENV{'ECF_NAME'}  = "^ECF_NAME:0^"  ; # task path into the suite
-$ENV{'ECF_PASS'}  = "^ECF_PASS:0^"  ; # password for the job
-$ENV{'ECF_TRYNO'} = "^ECF_TRYNO:0^" ; # job occurence number
-my $client = "/usr/local/apps/ecflow/current/bin/ecflow_client";
-$xmeter = $client; $arg_m = "--meter";
-$xlabel = $client; $arg_l = "--label";
-$xevent = $client; $arg_e = "--event";
-$xcomplete = $client; $arg_c = "--complete";
-$xabort = $client; 
-
-system($client, "--init", "$$");
-} else {
-  $ENV{'SMS_PROG'} = "^SMS_PROG:0^" ; # SMS Program Number
-  $ENV{'SMSNODE'}  = "^SMSNODE:0^"  ; # SMS host
-  $ENV{'SMSNAME'}  = "^SMSNAME:0^"  ; # task path into the suite
-  $ENV{'SMSPASS'}  = "^SMSPASS:0^"  ; # password for the job occurence
-  $ENV{'SMSTRYNO'} = "^SMSTRYNO:0^" ; # job occurence number
-}
-
-sub xmeter($$){ my ($name, $step) = @_; 
-  system($xmeter, $arg_m, $name, $step); }
-sub xevent($){ my ($name) = @_; 
-  system($xevent, $arg_e, $name); }
-sub xlabel($$){ my ($name, $msg) = @_; 
-  system($xlabel, $arg_l, $name, $msg); }
-sub xabort(){ system($xabort); }
-sub xcomplete(){ system($xcomplete, $arg_c, "$$"); }
-
-print "start";
-eval '
-"""
-    create_wrapper("perl_header.h", source)
-
-    source="""';
-if ($@){
-    print "caught signal: $@\n";
-    xabort();
-    exit;
-  }
-print "the job is now complete\n";
-xcomplete();
-exit;"""
-    create_wrapper("perl_endt.h", source)
-
-    ### LOGER TASK
-    content = """#!/bin/ksh
-%manual
-  start - check - stop logsvr
-%end
-%include <qsub.h>
-%include <trap.h>
-SLEEP=%SLEEP:0%
-KIND=%KIND:start%
-type rsh && RSH=rsh || RSH=ssh
-
-case $HOST in 
-c2a*) rhost=c2a;;
-c2b*) rhost=c2b;;
-xxcct*) rhost=cctdtn1 ; RSH=ssh;;
-cct*) rhost=cct-log ; RSH=ssh;;
-cca*) rhost=cca-log ; RSH=ssh ;;
-xxcca*) rhost=cca-il2 ; RSH=ssh ;;
-xxccb*) rhost=ccb-il2 ; RSH=ssh ;;
-ccb*) rhost=ccb-log ; RSH=ssh ;;
-esac
-
-case $KIND in
-start)
-
-ps -elf | grep logsvr | grep -v grep | grep $USER && \\\
-ps -elf | grep logsvr | grep $USER | grep -v grep | \\\
-awk '{print $1}' | xargs kill -9
-
-case $ARCH in
-cray)  
-  case $HOST in
-  cct*) logsvr=/usr/local/apps/sms/bin/logsvr.sh
-        # /usr/local/apps/emos/bin/logsvr.sh
-        # $RSH $rhost 
-        nohup $logsvr > /tmp/emos_logsvr.tmp 2>&1 &
-        rhost=cct # start on both nodes cctdtn1  + cct (Avi serial jobs)
-        trap 0; xcomplete; exit 0
-  ;;
-  cca*|ccb*) logsvr=/usr/local/apps/emos/bin/logsvr.sh;;
-  *)    exit 1;;
-  esac
-
-  $RSH $rhost nohup $logsvr > /tmp/emos_logsvr.tmp 2>&1 &
-;;
-ibm*) $RSH $rhost nohup $HOME/bin/boot/logsvr.sh > /tmp/emos_logsvr.tmp 2>&1 &
-;;
-*)    nohup logsvr.sh > /tmp/emos_logsvr.tmp 2>&1 &
-;;
-esac
-xlabel info "logserver is started"
-
-;;
-stop)
-pid=$($RSH $rhost ps -elf | grep logsvr | grep $USER | grep -v grep | awk '{print $1}' )
-kill -9 $pid
-xlabel info "logserver is stoped"
-;;
-
-ping)
-case $ARCH in
-cray) ps -elf | grep logsvr | grep $USER # grep -v grep || exit 1
-      xlabel info "???"
-     trap 0; xcomplete; exit 0
-;;
-*) $RSH $rhost ps -elf | grep logsvr | grep -v grep | grep $USER || exit 1 
-;;
-esac
-
-xlabel info "$($RSH $rhost ps -elf | grep logsvr | grep -v grep | grep $USER)"
-;;
-esac
-
-%include <endt.h>
-"""
-    create_wrapper("logsvr.sms", content)
-
-    ### task
-    content = """#!/bin/ksh
-%manual 
-manual - this task is automatically created by cray.py
-%end
-%include <qsub.h>
-if [[ $ARCH = hp* ]]; then export PATH=/usr/local/bin:$PATH; fi
-if [[ $HOST = lxop* ]]; then export PATH=/usr/local/apps/ecflow/current:/usr/local/apps/sms/bin:$PATH; fi
-%include <trap.h>
-SLEEP=%SLEEP:0%
-echo OK
-
-case %ECF_PORT:0% in
-0) base=900000; LOGPORT=%LOGPORT:0%;;
-*) base=1000; LOGPORT=%LOGPORT:0%;;
-esac
-base=1000
-
-case $HOST in
-cc*)xlabel info $(printenv | grep -E '(SUBMIT_|EC_)') ;;
-*) xlabel info OK
-esac
-  
-printenv | sort
-xevent 1
-step=0
-while (( $step <= 12 )); do
-  xmeter step $step
-  ((step = step + 1))
-  sleep $SLEEP
-done
-%include <endt.h>
-"""
-    create_wrapper("test.sms", content)
-
-    content = """#!/bin/ksh
-%manual 
-manual - this task is automatically created by cray.py
-
-expected to run in real-time mode only
-
-%end
-#include <qsub.h>
-#include <step1.h>
-%include <trap.h>
-
-KIND=%KIND:when%
-NOW=$(date +%%H%%M)
-
-case $KIND in 
-when) TIME=0; 
-for when in $(echo %WHENS:0%); do
-  if [[ $((NOW - when)) -le 1 ]]; then break; fi
-  TIME=$when
-done
-for when in $(echo %WHENS:0%); do
-  if   [[ $when -le $NOW ]] then  xmeter time $when; sleep %SLEEP:5%; fi
-  done;; 
-time) TIME=%TIME:0%
-
-main=/sapp/run/ext
-case $TIME in 
-1350) path=$main/DC1/00;;
-0120) path=$main/DC1/12;;
-0205) path=$main/DC1/18;;
-1405) path=$main/DC1/06;;
-1605) path=$main/DA1/12;;
-2205) path=$main/DA1/18;;
-0405) path=$main/DA1/00;;
-1005) path=$main/DA1/06;;
-*) xabort;;
-esac
-
-case %ECF_PORT:0% in
-0) login="set SMS_PROG %SMS_PROG:0%; login %SMSNODE:0% $USER 1"
-   cdp -c "$login; force -r complete $path";;
-*) ecflow_client --force=complete recursive $path;;
-esac
-
-;;
-esac
-%include <endt.h>
-#include <step2.h>
-"""
-
-    create_wrapper("sapp.sms", content)
-
-    content = """
-%manual 
-manual - this task is automatically created by cray.py
-
-expected to run in real-time mode only
-%end
-#include <qsub.h>
-#include <step1.h>
-%include <trap.h>
-
-if [[ $USER == map ]]; then
-cd /tmp/map/work/p4/metapps/suites/o/def
-make etest | grep -v Node::addVariable:
-make teste | grep -v Node::addVariable:
-
-TEST="" make oe edae lawe lbce rd mce mofce
-TEST= "" make e eeda elbc elaw 
-
-fi
-
-cd /home/ma/emos/def/o/def
-# make etest| grep -v Node::addVariable:
-# make teste| grep -v Node::addVariable:
-
-TEST="" make oe edae lawe lbce rd mce mofce| grep -v Node::addVariable:
-TEST="" make e eeda elbc elaw | grep -v Node::addVariable:
-
-make doc
-make covtest
-make cov| grep -v Node::addVariable:
-
-# e o rd
-
-%include <endt.h>
-#include <step2.h>
-"""
-    create_wrapper("maker.sms", content)
-
-    content = """#!/bin/ksh
-%manual 
-manual - this task is automatically created by cray.py
-expected to run in real-time mode only
-%end
-#include <qsub.h>
-#include <step1.h>
-%include <trap.h>
-
-KIND=%KIND:when%
-NOW=$(date +%%H%%M)
-
-YMD=%YMD:20010101%
-BASETIME=%YMD:20010101%%EMOS_BASE:00%
-BASE=%EMOS_BASE:00%
-STREAM=%STREAM:elda%
-MEMBER_FROM=%MEMBER_FROM:%
-MEMBER=%MEMBER:%
-EXPVER_FROM=%EXPVER_FROM:9093%
-EXPVER=%EXPVER:9963%
-
-case $HOST in
-c2*) FDB_ROOT=%STHOST:/s2o1%/ma_fdb;;
-cc*) FDB_ROOT=%STHOST:/sc1%/tcwork/emos/ma_fdb;;
-*) exit 1;;
-esac
-
-cd $FDB_ROOT
-mkdir fix
-cd fix
-scp emos@%SCHOST_BKUP:cca:$FDB_ROOT/:od:$STREAM:g:$EXPVER_FROM:$YMD::/:${EMOS_BASE}00:$MEMBER_FROM:*: .
-
-cat > rules.txt <<EOF
-set expver="$EXPVER";
-write;
-EOF
-
-for f in $(ls :${EMOS_BASE}00:$MEMBER_FROM:*:); do
-  grib_filter -o $f.0001 rules.txt $f
-done
-
-echo "mkdir -p test; for f in $(ls :${EMOS_BASE}00:$MEMBER_FROM:*:); do FDB_ROOT=$(pwd)/test grib2fdb $f; done"
-echo "mv test/*$STREAM:*/* $FDB_ROOT/:od:$STREAM:g:$EXPVER:$YMD::/."
-done
-
-case $KIND in 
-VERSION) echo;;
-MEMBER) echo;;
-*) xabort;;
-esac
-
-;;
-esac
-%include <endt.h>
-#include <step2.h>
-"""
-
-    create_wrapper("safety.sms", content)
-
-def create_de():
-    try:    os.stat(wdir + "/de")
-    except: os.makedirs(wdir + "/de")       
-    task = open(wdir + "/de/setup.ecf", 'w')
-    print('''#!/bin/ksh
-%include <head.h>
-%ecfmicro ~
-~includenopp <scripts/setup.run>
-~ecfmicro %
-%include <tail.h>
-''', file=task)
-
-    task = open(wdir + "/de/model.ecf", 'w')
-    print('''#!/bin/ksh
-# QSUB -lh  %THREADS:1%
-# QSUB -lPv %NPES:1%
-# @ tasks_per_node = 64
-%include <head.h>
-%ecfmicro ~
-~includenopp <scripts/model.run>
-~ecfmicro %
-%include <tail.h>
-''', file=task)
-
-    logdir = "/s2o2/emos_dir"
-    return Family("de").add(
-        Defcomplete(),
-        Repeat("YMD", 20100101, 20121212),
-        Variables(ECF_EXTN= ".ecf",
-                  ACCOUNT= "oesu",
-                  SCHOST= "cca",
-                  ECF_LOGHOST= "cca",
-                  ECF_OUT= logdir,
-                  LOGDIR= logdir,
-                  QUEUE= "ns",
-                  TURTLES= 1000*'I LIKE ',
-                  ),
-        Task("setup"),
-        Task("obs").add(Trigger("setup==complete")),
-        Task("namelist").add(Trigger("obs==complete")),
-        Task("model").add(
-            Variables(NPES= 1,
-                      THREADS= 1,
-                      QUEUE= "np",),
-            Trigger("namelist==complete")),
-        Task("postproc").add(Trigger("model==complete")),
-        )
-
-def create_smhi():
-    submit = open(wdir + "/smhi_run.sh", 'w')
-    print('''#!/bin/ksh
-set -eux
-ECF_NAME=$1
-ECF_PASS=$2
-ECF_JOB=$3
-ECF_JOBOUT=$4
-ECF_HOST=$5
-ECF_PORT=$6
-export ECF_NAME ECF_PASS ECF_HOST ECF_PORT ECF_JOB ECF_JOBOUT
-echo "#MSG: START USER SCRIPT"
-. $ECF_JOB # >> $ECF_JOBOUT 2>&1
-''', file=submit)
-
-    man = open(wdir + "/smhi_man.h", 'w')
-    print('''
-an example for include manual page
-''', file=man)
-    man.close()
-
-    shell = open(wdir + "/smhi.sh", 'w')
-    print('''#!/bin/ksh
-set -eux
-# use ecflow || 
-export PATH=/usr/local/apps/ecflow/current/bin:$PATH
-export SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
-ecflow_client --init=$$
-
-ERROR() {
-  ecflow_client --abort # raison:trap
-  echo "#WAR: TRAPPING ERROR"
-  trap 0  
-  uname -a; date; times
-  sleep 0
-  exit 0
-}
-trap ERROR 0 $SIGNAL_LIST
-
-ecflow_client --event=1
-ecflow_client --meter=step 10
-
-echo "simulates an error"; exit 1
-echo "simulates an early exit: expect this to be trapped and reflected as error"
-exit 0 # test bubbling up an error through ssh
-
-''', file=shell)
-    wrapper = open(wdir + "/smhi_v.sms", 'w')
-    print('''
-%manual
-  example of minimalist script: only variables, wrapper is added at submission time
-%end
-#SET ECF_NAME=%ECF_NAME%
-#SET ECF_HOST=%ECF_HOST%
-#SET ECF_PORT=%ECF_PORT%
-#SET ECF_PASS=%ECF_PASS%
-#SET ECF_JOB=%ECF_JOB%
-#SET ECF_JOBOUT=%ECF_JOBOUT%
-#SET ECF_TRYNO=%ECF_TRYNO%
-#SET SCRIPT_PATH=%SCRIPT_PATH%
-#SET SCRIPT_NAME=%SCRIPT_NAME%
-''', file=wrapper)
-
-    submit = open(wdir + "/smhisubmit.sh", 'w')
-    print('''#!/bin/ksh
-set -eux
-ECF_JOB=$1
-grep "#SET " $ECF_JOB | sed -e "s:#SET ::" > $ECF_JOB.set
-grep "#SET " $ECF_JOB > $ECF_JOB.var
-. $ECF_JOB.set
-echo "#!/bin/ksh" > $ECF_JOB
-cat $ECF_JOB.set $ECF_JOB.var >> $ECF_JOB
-cat >> $ECF_JOB <<\@@
-set -eux
-export ECF_NAME ECF_PASS ECF_HOST ECF_PORT
-export PATH=/usr/local/apps/ecflow/current/bin:$PATH
-export SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
-ERROR() {
-  ecflow_client --abort trap
-  echo "#WAR: TRAPPING ERROR"
-  trap 0 
-  uname -a; date; times
-  exit 1
-}
-trap ERROR 0 $SIGNAL_LIST
-
-if [[ ${USE_SSH_SUB:=0} == 1 ]]; then
-ssh $SCHOST mkdir -p $(dirname $ECF_JOBOUT)
-ssh $SCHOST -R$ECF_PORT:$ECF_HOST:$ECF_PORT ''' + wdir + '''/smhi_run.sh \
-  $ECF_NAME $ECF_PASS $SCRIPT_PATH/$SCRIPT_NAME $ECF_JOBOUT $ECF_HOST $ECF_PORT
-echo "#MSG: ssh exits with $?"
-else
-ecflow_client --init=$$
-
-i=0
-while [[ $i -lt ${STEPS:=1} ]]; do
-  ecflow_client --meter=step $i
-  ((i=i+1))
-done
-
-ecflow_client --event=1
-
-fi
-
-wait
-trap 0
-ecflow_client --complete
-uname -a; date; times
-exit 0
-@@
-
-chmod 755 $ECF_JOB
-$ECF_JOB > $ECF_JOBOUT 2>&1 &
-
-''', file=submit)
-
-    os.system("chmod 755 " + wdir + "/smhisubmit.sh")
-    wrapper = open(wdir + "/smhi.sms", 'w')
-    os.system("chmod 755 " + wdir + "/smhi_run.sh")
-    cmd = "ln -sf %s/test.sms " % wdir + wdir + "/"
-    os.system(cmd + "a.sms")
-    os.system(cmd + "a1.sms")
-    os.system(cmd + "a11.sms")
-    print("##cmd", cmd)
-
-    print('''#!/bin/ksh
-%manual 
-%include <smhi_man.h>
-%end
-set -eux
-# use ecflow ||
-export PATH=/usr/local/apps/ecflow/current/bin:$PATH
-export SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
-ECF_NAME=%ECF_NAME%
-ECF_PASS=%ECF_PASS%
-ECF_HOST=%ECF_HOST%
-ECF_PORT=%ECF_PORT%
-export ECF_NAME ECF_PASS ECF_HOST ECF_PORT
-
-ERROR() {
-  ecflow_client --abort # raise:trap
-  echo "#WAR: TRAPPING ERROR"
-  trap 0  
-  uname -a; date; times; sleep 0
-  exit 1
-}
-
-SLEEP=%SLEEP:0%
-trap ERROR 0 $SIGNAL_LIST
-
-if [[ %USE_SSH_SUB:0% == 1 ]]; then
-ssh %SCHOST% mkdir -p $(dirname %ECF_JOBOUT%)
-ssh %SCHOST% -R%ECF_PORT%:%ECF_HOST%:%ECF_PORT% ''' + wdir + '''/smhi_run.sh \
-  %ECF_NAME% %ECF_PASS% %SCRIPT_PATH%/%SCRIPT_NAME% %ECF_JOBOUT% %ECF_HOST% %ECF_PORT%
-  echo "#MSG: ssh exits with $?"
-else
-ecflow_client --init=$$
-
-i=0
-while [[ $i -lt ${STEPS:=1} ]]; do
-  ecflow_client --meter=step $i
-  ((i=i+1))
-done
-
-ecflow_client --event=1
-
-fi
-
-wait
-trap 0
-ecflow_client --complete
-uname -a; date; times
-exit 0
-''', file=wrapper)
-
-def dummy(): return Task("test")
-
-def logsvr(kind): return Task("logsvr").add(
-    Label("man", "kind may be start, stop, ping"),
-    Label("info", ""),
-    Variables(KIND= kind))
-
-def limits():
-    return (Family("Test").add(Defcomplete(),
-                               Label("info", "test find reg exp, case sens"),
-                               Task("Ecmwf"),
-                               Task("ECMWF"),
-                               Task("ecmwf"),
-                               Task("ecm")),
-            Family("limits").add(
-            Defcomplete(),
-            Limit("lim", 10),
-            Limit("test", 10),
-            Limit("hpc", 10),
-            Limit("cca", 10),
-            Limit("ccb", 10),
-            # Limit("cct", 10),
-            # Limit("c2a", 10),
-            # Limit("c2b", 10),
-            Inlimit(ic.psel() + "/limits:lim")))
-
-def repeat():
-    return Family("repeat").add(
-        Defcomplete(),
-        Family("int").add(
-            Repeat("YMD", 21000101, 21001212, 1, "integer"),
-            dummy()),
-        Family("date").add(
-            Repeat("YMD", 21000101, 21001212, 1, "date"),
-            dummy()),
-        Family("string").add(
-            Repeat("YMD", ["1", "2", "3", "4", "5"], kind="string"),
-            dummy()),
-        Family("enum").add(
-            Repeat("YMD", "1 2 3 4 5".split(), kind="enum"),
-            dummy()),
-        )
-        
-
-def fam_ui():
-    return Family("ui").add(
-        Defcomplete(),
-        repeat(),
-        
-        Variables(VAR= 1),
-
-        Family("limit").add(Limit("mutex", 1),
-                            InLimit("limit:mutex"),
-                            Defstatus("complete"),
-                            dummy()),
-
-        Family("autocancel").add(AutoCancel("+01:00"),
-                                 dummy()),
-
-        dummy().add(Meter("step", -1, 100),
-                          Event(1),
-                          Label("info", ""),
-                          Late("-s 00:10 -c 01:00"),
-                          ),
-
-        Family("complete").add(Complete("test:1"),
-                               Trigger("test==complete")),
-
-        Task("time").add(Time("10:00"),
-                         Today("11:00"),
-                         Cron("12:00 13:00 00:05"),
-                         ),
-        Task("date").add(Date("01.*.*"),)
-        )
-
-def smhi():
-    return Family("smhi").add(
-        Defcomplete(),
-
-        Variables(ECF_FILES= wdir,
-                  QUEUE= "none",
-                  LOGDIR= jdir, # "/vol/lxop_emos_nc/output",
-                  MANPATH= "%ECF_SCRIPT%",
-                  ECF_JOB_CMD= "%ECF_JOB% > %ECF_JOBOUT% 2>&1",
-                  ECF_HOME= jdir, # "/tmp/smhi",
-                  ECF_INCLUDE= wdir,),
-
-        acq(),
-
-        Family("ex1").add(Cron("00:00 23:59 00:03"),
-                          Task("scan").add(Label("info", "one min"),
-                                           Event("1")),
-                          Task("proc").add(Label("info", "one min"),
-                                           Trigger("scan:1"),
-                                           Complete("scan eq complete and not scan:1"))),
-        Family("ex2").add(
-            Task("scan").add(Label("info", "one min"),
-                             Cron("00:00 23:59 00:03"),
-                             Event("1")),
-            Family("consume").add(
-                Label("info", "event is set by scan task"),
-                Event("1"),
-                Cron("00:00 23:59 00:05"),
-                Trigger("consume:1"),                
-                Task("proc1").add(Trigger("1==0", Complete("1==1"))),
-                Task("proc2").add(Trigger("1==0", Complete("1==1"))),
-                )),
-        Family("name").add(
-            Variables(ECF_JOB_CMD= SUBMIT,
-                      ECF_KILL_CMD= KILL,
-                      ECF_STATUS_CMD= STATUS,
-                      ECF_CHECK_CMD= CHECK,
-                      # ECF_EXTN= ".sms",
-                      ACCOUNT=  "UNSET",                      
-                      ECF_INCLUDE= idir,
-                      ECF_HOME= jdir,
-                      ECF_FILES= wdir,
-                      TOPATH= udir + "/logs",
-                      SLEEP=    1,
-                      SCHOST= "ibis",
-                      ECF_TRIES= 1,),
-            Task("a").add(Meter("step", -1, 100), Event("1")),
-            Task("a1").add(Meter("step", -1, 100), Event("1")),
-            Task("a11").add(Meter("step", -1, 100), Event("1")),
-            ),
-        
-        Family("ssh").add(
-            Variables(USE_SSH_SUB= 1,
-                      SCRIPT_PATH= wdir,
-                      SCRIPT_NAME= "smhi.sh"),            
-            smhi_unit("ibis", "ibis", "none", jdir),
-            smhi_unit("pikachu", "pikachu", "none", jdir),
-            ),
-
-        Family("alter").add(
-            Variables(USE_SSH_SUB= 1,
-                      ECF_JOB_CMD= "/home/ma/map/course/cray/smhisubmit.sh %ECF_JOB%",
-                      SCRIPT_PATH= wdir,
-                      SCRIPT_NAME= "smhi.sh"),            
-            smhi_unit_alter("ibis", "ibis", "none", jdir),
-            smhi_unit_alter("pikachu", "pikachu", "none", jdir),
-                          )
-        )        
-                          
-def acq():
-    name = "acq_ex"
-
-    fam = Family(name).add(
-        Defcomplete(),
-        Family("times").add(
-            dummy().add(
-                Time("10:00 20:00 00:30"))),
-        Complete(name + "/data eq complete"),
-        Task("data").add(
-            Event("ready"),
-            Trigger("rt/wait:data"),
-            ),
-        Family("rt").add(
-            Complete("data:ready"),
-            Task("wait").add(
-                Event("data"),
-                # Cron("10:00 12:00 00:05")
-                )),
-        Task("late").add(
-            Time("11:00"),
-                Trigger("not data:ready")))
-    return fam
-
-
-HCRAY="cct"
-
-SUBMIT=ic.SUBM + " %USER% %SCHOST% %ECF_JOB% %ECF_JOBOUT% submit"
-GSUB=SUBMIT.replace("%SCHOST%", "%SCHOST% %ECF_RID%")
-KILL=GSUB.replace(" submit", " kill")
-STATUS=GSUB.replace(" submit", " status")
-CHECK=STATUS
-
-
-def unit(name, schost, queue, rdir, account="", leaf=True, add=None):
-    return Family(name).add(
-        If(account != "",
-           Variables(ACCOUNT= account)),
-        Variables(QUEUE=    queue, 
-                  SCHOST=   schost,
-                  ECF_OUT=  rdir,
-                  LOGDIR=   rdir,),        
-        If (leaf, Task("test").add(
-                add,
-            Event(1),
-            Meter("step", -1, 120, 100),
-            Label("info", "nop"))))
-
-def smhi_nit(name, schost, queue, rdir, account=""):
-    return Family(name).add(
-        If(account != "", Variables(ACCOUNT= account)),
-        Variables(QUEUE=    queue, 
-                  SCHOST=   schost,
-                  ECF_OUT=  rdir,
-                  LOGDIR=   rdir,),        
-        Task("smhi").add(
-            Event(1),
-            Meter("step", -1, 120, 100),
-            Label("info", "nop")))
-
-def smhi_unit(name, schost, queue, rdir, account=""): return None
-
-def smhi_unit_alter(name, schost, queue, rdir, account=""):
-    return Family(name).add(
-        If(account != "", Variables(ACCOUNT= account)),
-        Variables(QUEUE=    queue, 
-                  SCHOST=   schost,
-                  ECF_OUT=  rdir,
-                  LOGDIR=   rdir,),        
-        Task("smhi_v").add(
-            Event(1),
-            Meter("step", -1, 120, 100),
-            Label("info", "nop")))
-
-def turkey_main(day, path):
-    def runs(num, time):
-        return Family('run%d' % num).add(
-               Trigger(path + '/deps/%s eq complete' % time),
-            
-               Family('feed_meb').add(
-                Task('strip_message'),                  
-
-                Task('insert_meb').add(
-                    Trigger('strip_message eq complete'),
-                  ),
-               ),               
-               Family('feed_reb').add(
-                  Task('decode_synop').add(
-                     Trigger('../feed_meb/insert_meb eq complete'),
-                  ),
-                  Task('decode_temp').add(
-                     Trigger('../feed_reb/decode_synop eq complete'),
-                  ),
-                  Task('decode_ship').add(
-                     Trigger('../feed_reb/decode_temp eq complete'),
-                  ),
-                  Task('decode_metar').add(
-                     Trigger('../feed_reb/decode_ship eq complete'),
-                  ),
-               ),               
-               Family('rdb').add(
-                  Task('rdb_synop').add(
-                     Trigger('../feed_reb/decode_synop eq complete'),
-                  ),
-                  Task('rdb_temp').add(
-                     Trigger('../feed_reb/decode_temp eq complete'),
-                  ),
-                  Task('rdb_ship').add(
-                     Trigger('../feed_reb/decode_ship eq complete'),
-                  ),
-                  Task('rdb_metar').add(
-                     Trigger('../feed_reb/decode_metar eq complete'),
-                  ),
-               ),               
-            ),            
-
-    def task_trigger(name, condition):
-        return Task(name).add(Trigger(condition))
-
-    def echos():
-        echo = { 
-            "cleandb" : "0131",
-            "cleanerrdb": "0136",
-            "silmeb": "0141",
-            "silreb": "0146",
-            "run1": "0221",
-            "run2": "0421",
-            "run3":"0621",
-            "run4": '0821',
-            'run5': '1021',
-            'run6': '1321',
-            'run7': '1421',
-            'run8': '1621',
-            'run9': '1821',
-            'run10': '2121',
-            'eksikveritamamla': '2201',
-            'uydutsm': '0201',
-            'model_all_gunluk_tsm': '0131',
-            'radar_lokasyon_tip_tsm': '0501',
-            'retObsAndFtp_for_00': '0231',
-            'retObsAndFtp_for_18': '0241',
-            'retObsAndFtp_for_12': '1541',
-            'retObsAndFtp_for_06': '1101',
-            'retObsAndFtp_for_06gungeri': '0801',
-            'uydureport': '1655',
-            'radarreport': '0701',
-            'backuplog': '2301',
-            'cleanup': '2316'
-            }
-        out = []
-
-        for key in sorted(echo, key=echo.get, reverse=False): # order by value
-            # for key in sorted(echo.keys()): # order by key
-            out.append(task_trigger("echo_%s" % key, 
-                                    path + "/deps/%s" % echo[key] + " eq complete"))
-        return out
-        
-    return Family('main').add(
-            Trigger('deps/0000 eq complete'),
-         
-            Family('clean').add(
-               task_trigger('cleandb',
-                            path + '/deps/0130 eq complete'),
-
-               Task('clean_errdb').add(
-                  Trigger(path + '/deps/0135 eq complete'),
-               ),
-               Task('silmeb').add(
-                  Trigger(path + '/deps/0140 eq complete'),
-               ),
-               Task('silreb').add(
-                  Trigger(path + '/deps/0145 eq complete'),
-               ),
-            ),         
-            runs(1, "0220"),
-            runs(2, "0420"),
-            runs(3, "0620"),
-            runs(4, "0820"),
-            runs(5, "1020"),
-            runs(6, "1320"),
-            runs(7, "1420"),
-            runs(8, "1620"),
-            runs(9, "1820"),
-            runs(10, "2120"),
-            Family('model').add(
-               Task('eksikveritamamla').add(
-                  Trigger(path + '/deps/2200 eq complete'),
-               ),
-            ),            
-            Family('tsmarc').add(
-               Task('uydu_tsm').add(
-                  Trigger(path + '/deps/0200 eq complete'),
-               ),
-               Task('model_all_gunluk_tsm').add(
-                  Trigger(path + '/deps/0130 eq complete'),
-               ),
-               Task('radar_lokasyon_tip_tsm').add(
-                  Trigger(path + '/deps/0500 eq complete'),
-               ),
-            ),            
-            Family('ftpsenddata').add(
-               Task('retObsAndFtp_for_00').add(
-                  Trigger(path + '/deps/0230 eq complete'),
-               ),
-               Task('retObsAndFtp_for_18').add(
-                  Trigger(path + '/deps/0240 eq complete'),
-               ),
-               Task('retObsAndFtp_for_12').add(
-                  Trigger(path + '/deps/1540 eq complete'),
-               ),
-               Task('retObsAndFtp_for_06').add(
-                  Trigger(path + '/deps/1100 eq complete'),
-               ),
-               Task('retObsAndFtp_for_06gungeri').add(
-                  Trigger(path + '/deps/0800 eq complete'),
-               ),
-               Task('uydu_report').add(
-                  Trigger(path + '/deps/1654 eq complete'),
-               ),
-               Task('radar_report').add(
-                  Trigger(path + '/deps/0700 eq complete'),
-               ),
-            ),            
-            Family('cleanup').add(
-               Task('backuplog').add(
-                  Trigger(path + '/deps/2300 eq complete'),
-               ),
-               Task('cleanup').add(
-                  Trigger(path + '/deps/2315 eq complete'),
-               ),
-            ),            
-            Family('echo').add(
-               Variables(
-                  ECF_FILES= '/pp1/bin/dpp_sms/echo',),
-
-               echos(),           
-         ))
-
-
-def turkey_deps(num):
-    def item(hhmm):
-        return  Family(hhmm).add(
-               Complete("./%s/compl eq complete and " % hhmm + 
-                        './%s/dummy eq queued' % hhmm),
-            
-               Task('dummy').add(
-                  Cron('-w %d' % num + ' ' + hhmm[:2] + ":" + hhmm[-2:]),
-               ),
-               Task('compl').add(
-                  Complete("dummy eq active or " +
-                           "dummy eq submitted or " +
-                           'dummy eq complete'),
-                  Trigger('1 eq 0'),
-               ),
-            )
-
-    items = [ "0000",
-"0130",
-"0135",
-"0140",
-"0145",
-"0220",
-"0420",
-"0620",
-"0820",
-"1020",
-"1320",
-"1420",
-"1620",
-"1820",
-"2120",
-"2200",
-"0200",
-"0500",
-"0230",
-"0240",
-"1540",
-"1100",
-"0800",
-"1654",
-"0700",
-"2300",
-"2315",
-"0131",
-"0136",
-"0141",
-"0146",
-"0221",
-"0421",
-"0621",
-"0821",
-"1021",
-"1321",
-"1421",
-"1621",
-"1821",
-"2121",
-"2201",
-"0201",
-"0501",
-"0231",
-"0241",
-"1541",
-"1101",
-"0801",
-"1655",
-"0701",
-"2301",
-"2316", ]
-    def loop_items(): 
-        out = []
-        for hhmm in items: 
-            out.append(item(hhmm))
-        return out 
-
-    return Family('deps').add(
-            Variables(
-               ECF_FILES= '/pp1/bin/dpp_sms/haftalik',),
-            loop_items())
-
-def turkey_loop(suite_name):
-    out = []
-    days = [ "Pazartesi", "Sali", "Carsamba", "Persembe", "Cuma", "Cumartesi", "Pazar"]
-    days = [ "mon", "tue", "wed", "thu", "fri", "sat", "sun"]
-    start = 20120723; end=20301231 # beware addition below does not consider start as a date
-    path = "/%s/weekly/" % suite_name
-
-    for num in range(7): 
-        out.append(Family(days[num]).add(
-                Repeat(kind='date', name='YMD', 
-                       start= start + num, end=end, step=7),
-                turkey_deps(1),
-                turkey_main(days[num], path=path + days[num]),))
-    return out
-
-def turkey(suite_name):
-    return    Family('weekly').add(
-        Label("repeat", "run one family per week day"),
-        Label("time_trigger", "replace time dependencies with trigger"),
-        Label("aborted", "one aborted task requests being fixed within one week"),
-        Defcomplete(),
-        turkey_loop(suite_name),)
-
-##########################################################################
-## PURE
-
-class Languages(object):
-    def __init__(self): pass 
-    def task(self): return None
-    def scripts(self): pass
-
-class Python(Languages):
-    def task(self):
-        return (
-            Task("pure_python").add(
-                Variables(ECF_MICRO= "$",
-                          ECF_INCLUDE= wdir,
-                          SCHOST= "localhost",
-                          ECF_JOB_CMD= "use ecflow; $ECF_JOB$ > $ECF_JOBOUT$ 2>&1 &"),
-        Event("1"),
-        Label("info", ""),
-        Meter("step", -1, 100),
-        # Defstatus("complete"),
-        ),
-
-        Task("python").add(
-        Variables(ECF_MICRO= "$",
-                  ECF_INCLUDE= wdir,
-                  SCHOST= "localhost",
-                  ECF_JOB_CMD= "$ECF_JOB$ > $ECF_JOBOUT$ 2>&1 &"),
-        Event("1"),
-        Label("info", ""),
-        Meter("step", -1, 100),
-        # Defstatus("complete"),
-        ), )
-
-class Perl(object):
-    def task(self):
-        return Task("perl").add(
-            Label("todo", "time-stamp PS4, set eux, exit 0 1,"),
-            Variables(ECF_MICRO= "^",
-                      ECF_INCLUDE= wdir,
-                      SCHOST= "localhost",
-                      ECF_JOB_CMD= "^ECF_JOB^ > ^ECF_JOBOUT^ 2>&1 &"),
-            Event("1"),
-            Label("info", ""),
-            Meter("step", -1, 100),
-            # Defstatus("complete"),
-            )
-
-class Ruby(object):
-    def task(self):
-        return Task("ruby").add(
-            Label("todo", "time-stamp PS4, set eux, exit 0 1,"),
-            Variables(ECF_MICRO= "^",
-                      ECF_INCLUDE= wdir,
-                      SCHOST= "localhost",
-                      ECF_JOB_CMD= "^ECF_JOB^ > ^ECF_JOBOUT^ 2>&1 &"),
-            Event("1"),
-            Label("info", ""),
-            Meter("step", -1, 100),
-            Defstatus("complete"),
-            )
-
-    def scripts(self):
-        head = """#!/usr/bin/env ruby"""
-        tail = """ """
-        body = """ """
-        create_wrapper("head.rb", head)
-        create_wrapper("tail.rb", tail)
-        create_wrapper("ruby.sms", body)
-
-ruby = Ruby()
-perl = Perl()
-pyth = Python()
-
-WDIR= "/scratch/ma/map/sms"
-HLOG= "/home/ma/map/logs"
-
-hosts = {"lxb" : { "COMPILER": "gcc-4.3", # linux64
-                   "SCHOST": "lxb", 
-                   "QUEUE_EPILOG": "serial",
-                   "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                   "QUEUE": "serial",
-                   "WDIR": WDIR, }, 
-         "ibis" : { "COMPILER": "gcc",
-                    "SCHOST": "ibis", 
-                    "WDIR": WDIR, }, 
-         "lxop" : {  "COMPILER": "gcc-4.3",
-                    "SCHOST": "lxop",
-                     "QUEUE": "test", 
-                     "QUEUE_EPILOG": "test",
-                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                     "COMPILE_DIR": "/gpfs/lxop/emos_data/sms", 
-                    "WDIR": "/gpfs/lxop/emos_data/sms", 
-                     }, 
-         "opensuse103": { "COMPILER": "gcc-4.5",
-                         "SCHOST": "opensuse103", 
-                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                         "WDIR": WDIR, }, 
-         "opensuse113": { "COMPILER": "gcc-4.5",
-                         "SCHOST": "opensuse113", 
-                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                         "WDIR": WDIR, }, 
-         "opensuse131": { "COMPILER": "gcc-4.8",
-                         "SCHOST": "opensuse131", 
-                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                         "WDIR": WDIR, }, 
-         "ecgb": { "COMPILER": "gcc-4.4.7", # redhat
-                   "QUEUE": "normal", 
-                   "QUEUE_EPILOG": "normal",
-                   "SCHOST": "ecgb", 
-                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                    "WDIR": WDIR, }, 
-         "lxc": { "COMPILER": "gcc-4.4.7", # redhat
-                   "QUEUE": "normal", 
-                   "QUEUE_EPILOG": "normal",
-                   "SCHOST": "lxc", 
-                   "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                   "WDIR": WDIR, }, 
-         "cct": { "COMPILER": "gcc",
-                  "QUEUE_EPILOG": "ns",
-                  "SCHOST": "cct", 
-                  "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                  "COMPILE_DIR": "/home/ma/map/sms", 
-                  "WDIR": "/home/ma/map/sms", }, 
-         "cca": { "COMPILER": "gcc",
-                  "QUEUE_EPILOG": "ns",
-                      "SCHOST": "cca", 
-                       "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                       "WDIR": "/home/ma/map/sms", }, 
-         "ccb": { "COMPILER": "gcc",
-                  "QUEUE_EPILOG": "ns",
-                      "SCHOST": "ccb", 
-                       "LOGDIR": HLOG, "ECF_OUT": HLOG, 
-                      "WDIR": "/home/ma/map/sms", 
-                  "COMPILE_DIR": "/home/ma/map/sms", 
-                  },          }
-
-class Compile(object):
-
-    def __init__(self):
-        pass
-
-    def compile(self, host=None, add=None, but=None):
-        version = "4.4.15"
-        if host is None: dest = list(hosts.keys())
-        else: dest = (host, )
-        out = []
-        for host in sorted(dest):
-            if not but: pass
-            elif host == but or host in but: continue
-            out.append(Family(host).add(
-                    add,
-                    Variables(hosts[host]),
-                    Variables(ECF_FILES= wdir,
-                              VERSION= version,
-                              ECF_INCLUDE= idir,         ),
-                    Task("get"),
-                    Task("make").add(Trigger(["get"])),
-                    Task("install").add(Defcomplete(),
-                                     Trigger(["make"])),
-                    Task("testit").add(Event("cdp"),
-                                       Event("sms"),
-                                       Event("child"),
-                                       Event("xcdp"),
-                                       Trigger(["make"])),
-                    Task("child").add(Defcomplete(),
-                                      Variables(SMS_VERSION= "4.4.15",),
-                                      Label("info", ""),
-                                      Event("1"),
-                                      Meter("step", -1, 100)),
-                    ))
-        return out
-
-    def main(self):
-        self.create_tasks()
-        return Family("sms").add(Family("compile").add(
-            Defstatus("suspended"),
-            # onws("localhost"),
-            Variables(SCHOST= "localhost"),
-            Task("prepare"),
-            self.compile("ibis", add=Trigger("prepare==complete")),
-            Family("remote").add(Trigger("prepare==complete"),
-                                 self.compile(but="ibis"),)))
-
-    def wrap(self, content):
-        return '''#!/bin/ksh
-# generated by cray.py
-%%manual
-  start - check - stop logsvr
-%%end
-%%include <qsub.h>
-%%include <step1.h>
-%%include <trap.h>
-%s 
-%%include <endt.h>
-%%include <step2.h>''' % content
-
-    def create_tasks(self):
-        source = "%SOURCE_DIR:/tmp/map/work/git/sms%"
-        compil = "%COMPILE_DIR:/scratch/ma/map/sms/$ARCH/%/%SCHOST:$HOST%"
-        task = self.wrap("cd %s/sms; make clean; cd ../; tar -czf sms.tgz sms; " % source)
-        create_wrapper("prepare.sms", task)
-        
-        task = self.wrap("comp=%s; " % compil + 
-                         "mkdir -p $comp; cd $comp; scp ibis:%s/sms.tgz .;" % source +
-'''rm -rf sms.tar sms || :
-gzip -d sms.tgz; tar -xf sms.tar''')
-        create_wrapper("get.sms", task)
-
-        task = self.wrap("comp=%s;" % compil + 
-                         '''cd $comp/sms; 
-if [[ $ARCH == cray ]]; then
-module switch PrgEnv-cray PrgEnv-intel
-export CRAYPE_LINK_TYPE=dynamic
-fi
-make %TARGET:linux%''')
-        create_wrapper("make.sms", task)
-
-        task = self.wrap("comp=%s;" % compil +  
-                         '''cd $comp/sms; make tester; 
-mkdir -p %SMSHOME:/tmp/$USER%
-SMS_PROG=900001 sms &
-sleep 10
-xevent sms
-SMS_PROG=900001 smsping localhost || :
-./cdp/cdp -c 'set SMS_PROG 900001; login $HOST $USER 1; terminate -y; exit 0'
-xevent cdp
-DISPLAY=ibis:0.0 ./xcdp/xcdp &
-xevent xcdp
-ln -sf ./cdp/child smsevent
-./smsevent child
-rm -f smsevent''')
-        create_wrapper("testit.sms", task)
-
-        task = self.wrap("xevent 1; xlabel info test; xmeter step 0; xmeter step 100;")
-        create_wrapper("child.sms", task)
-
-##########################################################################
-## BARBER
-
-def call_barber_passerby():
-    # family passby
-    # limit to one at a time entering the
-    # shop to check if there is room to
-    # stay in there
-    return Task("passby").add(
-        Cron("00:00 23:59 00:01"),
-    # this one is regular
-        Variables(ID= 0),
-        Inlimit("limit:passby"))
-    # other frequent passers by can be added here
-# called by client generator task
-
-def call_barber_client(id):
-    return Family(id).add(
-    # to be called by passby to create a new client
-        Task("cut").add(
-            Inlimit("../limit:barbers")),
-    # there may be many barbers in the shop
-    # but one cashier only
-        Task("pay").add(
-            Trigger("./cut == complete"),
-            Inlimit("../limit:barbers"),
-            Inlimit("../limit:cashiers")),
-        Task("leave").add(
-            Trigger("cut==complete and pay==complete"),
-            If(id % 2 == 0,
-               Defcomplete(),
-               Autocancel( "0" ))))
-
-# main definition
-def call_barber_shop():
-    return Family("shop").add(
-        Defstatus("suspended"),
-        Variables(NB_CHAIRS= 4),
-
-        Family("limit").add(
-            Defcomplete(),
-            Limit("passby", 1),
-            Limit("barbers", 1),
-            Limit("cashiers", 1)),
-
-        call_barber_passerby(),)
-
-##########################################################################
-## dinner
-total_number = 5
-life_expectency = 100
-def requeued():
-    return Repeat("iter", 1, life_expectency, kind= "integer")
-    # possibility to requeue the task without duration limit
-    # provided 02:00 is below the task duration:
-    # cron 00:00 23:59 02:00
-
-def triggered(ref, tor=None, tand=None):
-    trg = ""
-    tr2 = ""
-    if tand: trg = " and %s" % tand
-    if tor:  tr2 = " or %s" % tor
-    return Trigger("(%s != active and %s != submitted and %s != aborted" 
-                % (ref, ref, ref) + trg + ")" + tr2)
-
-def philosopher(id, s1, s2, version):
-    return Family("%d" % id).add(
-        Task("eat").add(
-            Inlimit("../limit:"+str(s1)),
-            Inlimit("../limit:"+str(s2)),
-            Event("release")),
-        If( version == "normal",
-                # eat task a3ttribute
-                # TBD triggered("think")
-                ( requeued(),
-
-                  Task("think").add(
-                        requeued(),
-                        triggered( "eat", tor="eat:release or eat==complete")))),
-        If( version == "simple",
-                (Task("release").add(
-                        Trigger("eat:release or eat==complete"),),
-                 requeued())))
-
-def call_dinner():
-    out = Family("dinner").add(
-        Variables(SLEEP= 10),
-        Defstatus("suspended"),
-        )
-    for version in "simple normal".split():
-        # Xcdp would fold parent family when limits change
-        # we prefer to store them in a dedicated family then
-        lim = Family("limit").add(
-                    Defcomplete(),)
-# for num 1 $total_number do num 1 $total_number do
-# $total_number do num 1 $total_number do
-        num = 1
-        while num <= total_number:
-            lim.add(Limit(str(num), 1))
-            num += 1; # endfor
-        ver = Family(version).add(lim)
-        out.add(ver)
-# for num 1 $total_number do num 1 $total_number do
-# $total_number do num 1 $total_number do
-        num = 1
-        while num <= total_number:
-            stick1 = num
-            stick2 = 1 + ((num) % total_number)
-            ver.add(philosopher( num, stick1, stick2, version))
-            num += 1; # endfor
-    return out
-
-##########################################################################
-## CONSUMER
-# /home/ma/map/course/course2011/src/consumer.py
-beg =  0
-fin = 48
-by  =  3
-    
-def not_consumer(): return Variables(CONSUME= "no")
-
-def not_producer(): return Variables(PRODUCE= "no")
-
-def ev():return (Event("p"), Event("c"))
-
-def call_task(name, start, stop, inc):
-    meter = None
-    if start != stop:
-        meter = Meter( "step", -1, int(stop))
-
-    return Task(name).add(
-        ev(),
-        Variables(BEG= start,
-                  FIN= stop,
-                  BY= inc),
-        meter)
-
-def call_consumer(SELECTION):
-    # defstatus suspended # avoid early start
-    def consume1(leap = 1, leap_nb = 3):
-        out = []
-        while leap <= leap_nb:
-            leap_beg = beg + by * (leap - 1)
-            leap_by = by * leap_nb
-            out.append(Family("%d" % leap).add(
-                    call_task( "consume", "'%STEP%'", "'%STEP%'", leap_by).add(
-                        Repeat("STEP", leap_beg, fin, leap_by, kind="integer"),
-                        # same trigger as consume0
-                        # Trigger("(%s and (consume:STEP le %s1/produce:STEP)) or " % (lead, prod) + 
-                        #         "(not %s and (consume:STEP le %s0/produce:step))" % (lead, prod))
-                        Trigger("(consume:STEP le %s1/produce:STEP)" % prod),
-                       )))
-            leap += 1;
-        return out
-
-    def consume2(idx, fin):
-        out = []
-        while idx <= fin:  
-            out.append(Family("%03d" % idx).add(
-                    call_task( "consume", idx, idx, by).add(
-                        Variables(STEP= idx),
-                        # Same trigger as consume0
-                        # Trigger("(%s and (consume:STEP le %s1/produce:STEP)) or " % (lead, prod) +
-                        #         "(not %s and (consume:STEP le %s0/produce:step))" % (lead, prod))))
-                        Trigger("consume:STEP le %s1/produce:STEP" % prod),
-                       )))
-            idx += by
-        return out
-
-    lead = "/%s/consumer/admin/leader:1" % SELECTION
-    prod = "/%s/consumer/produce" % SELECTION
-    if 1: return Family("consumer").add(Defcomplete()) # FIXME
-    return Family("consumer").add(
-        Defcomplete(),
-
-        Variables(SLEEP= 10,
-                  PRODUCE= "no",
-                  CONSUME= "no"),
-
-             Family("limit").add(
-                Defcomplete(),
-                Limit("consume", 7),),
-
-             Family("admin").add(
-                # set manually with Xcdp or alter the event 1 so
-                # that producer 1 becomes leader
-                # default is producer0 leads
-                Task("leader").add(
-                    Event("1"),
-                    Defcomplete())),
-             # text this task is dummy task not designed to run
-
-             # default : task does both :
-                 Variables(PRODUCE= "yes",
-                           CONSUME= "yes"),
-             # this task will do both, ie serial
-
-             call_task( "produce", beg, fin, by).add(
-            Label("info", "do both at once"),),
-             # this will loop inside the task, reporting
-             # its processed step as a meter indication
-
-             Family("produce0").add(
-                not_consumer(),
-                call_task( "produce", beg, fin, by )),
-             # here, choice is to push a new task for each step
-
-             Family("produce1").add(
-                not_consumer(),
-                call_task( "produce", '%STEP%', "%STEP%", by ).add(
-                Repeat("STEP", beg, fin, by , kind="integer"), )),
-             # PRB edit FIN '$((%STEP% + %BY%))'
-
-             Family("consume").add(
-                not_producer(),
-                Inlimit("limit:consume"),
-                Variables(CALL_WAITER= 1,
-                          # $step will be interpreted in the job!
-                          TRIGGER= "../produce:step -gt consume:$step or ../produce eq complete"),
-                call_task( "consume", beg, fin, by ).add(
-                )),
-             
-             Family("consume0or1").add(
-                not_producer(),
-                Inlimit("limit:consume"),
-                call_task( "consume", "%STEP%", "%STEP%", by, ),
-                Repeat( "STEP", beg, fin, by, kind="integer"),
-                Trigger("(%s and (consume0or1:STEP le %s1/produce:STEP)) or "
-                        % (lead, prod) +
-                        "(not %s and (consume0or1:STEP le %s0/produce:step))"
-                        % (lead, prod))),
-
-             Family("consume1").add(
-                not_producer(),
-                Inlimit("limit:consume"),
-                consume1()),
-
-             Family("consume2").add(
-    # loop is "exploded"
-    # consume limit may be changed manually with Xcdp
-    # to reduce or increase the load
-                Inlimit("limit:consume"),
-                not_producer(),
-                consume2(beg, fin)))
-
-##########################################################################
-class Cray(ic.SeedOD):
-    def __init__(self):
-        super(Cray, self).__init__()
-
-    def setup(self, node):
-        account= "UNSET"
-        global user, host
-        if user == "emos" or host in ("ode", "eode", "ecf"):
-            rdir = "/vol/lxop_emos_nc/output"
-            user= "emos"
-            account= "oesu"
-        else: pass
-        self.defs.add_extern("/o/main:YMD")
-
-        node.add(
-            Clock("real"),
-            Defstatus("suspended"),
-            Label("info", "test,logsvr tasks generated by cray.py"),
-            Event("1"),
-            Meter("step", -1, 100),
-            Repeat(kind="day", step=1),
-            limits(),
-
-            Variables(ECF_JOB_CMD= SUBMIT,
-                      ECF_KILL_CMD= KILL,
-                      ECF_STATUS_CMD= STATUS,
-                      ECF_CHECK_CMD= CHECK,
-                      # ECF_EXTN= ".sms",
-                      ACCOUNT=  "UNSET",
-                      SCHOST= "localhost",
-                      ECF_INCLUDE= idir,
-                      ECF_HOME= jdir,
-                      ECF_FILES= wdir,
-                      QUEUE= "ns", USER= user, LOGDIR= "/tmp",
-                      TOPATH= udir + "/logs",
-                      SLEEP=    1,     # x120
-                      ECF_TRIES= 1,),
-
-            Family("looper").add(Time("09:00"),
-                                 Variables(SCHOST= "ibis"),
-                                 dummy()), # .add(Defcomplete())),
-
-            create_de(),
-
-            smhi(),
-
-            Compile().main(),
-
-            Task("dummy").add(Time("16:00"),
-                              Variables(SCHOST= "localhost",
-                                        FAMILY= "unset",
-                                        FAMILY1= "unset"),
-                              Time("17:00"),),
-
-            fam_ui(),
-
-            # turkey(ic.selection()),
-
-            sapp(),
-
-            Family("maker").add(maker(),),
-
-            call_consumer(ic.selection()).add(
-                Label("repeat", "repeat may be attached to a family, or a task, to facilitate requeue or not"),
-                Label("event", "event may be set by the task itself, by a user, by a third party job"),
-                Label("trigger", "can be on the task-family node, or inside a task (wait)"),
-                Label("deadlock", "produce0/produce complete with step=-1"),
-                Label("latency", "between task wrapper creation, and new file visible from the server"),
-                Label("ZZZ", "icon when the job is waiting the trigger condition"),
-                Variables(QUEUE= "ns", USER= user, LOGDIR= "/tmp",
-                          SCHOST="localhost"),),
-
-            call_barber_shop().add(Defstatus("complete"),),
-
-            call_dinner().add(Defstatus("complete"),),
-
-            pyth.task(),
-
-            perl.task(),
-
-            ruby.task(),
-
-            Family("blacklist").add(
-                Event("cca"),
-                Event("ccb"),
-                Event("hps"),
-                
-                Defstatus("complete"))            )
-
-        msg = "have you? setup ssh login, created remote directory" 
-        msg += ", set START_LOGSVR=1 (edit task), once, to launch the logserver"
-        if "eod" in host: user = "emos"
-        print("#MSG: host, user", host, user)
-
-        node = node.family("submit").add(
-            unit("jonas", "ibis", "no", "/tmp/$USER/jobs", add=(Today("07:00"),
-                                                                Today("21:00"))),
-            Variables(USER=     user,
-                      ACCOUNT=  account), # 
-
-            # Time("09:00"),
-
-            self.arg4(),
-            self.burst(),
-            # self.arg3(),
-            # self.prb(),
-
-            )
-
-    def burst(self):
-        sub = "/home/ma/emos/bin/smssubmit "
-        out = []
-        for num in range(0, 10):
-            out.append(Family("%03d" % num).add(Task("test")))
-        
-        return Family("arg3").add(
-            Defstatus("complete"),
-            Variables(SCHOST= "cca-b"),
-            out
-            )
-
-    def arg3(self):
-        sub = "/home/ma/emos/bin/smssubmit "
-        return Family("arg3").add(
-            Defstatus("complete"),
-
-            self.submits(),
-
-            Variables(ECF_JOB_CMD= sub +"%USER% %SCHOST% %ECF_JOB%",
-                      ECF_KILL_CMD= sub + "%USER% %SCHOST% %ECF_JOB% kill",
-                      ECF_STATUS_CMD= sub + "%USER% %SCHOST% %ECF_JOB% status",
-                      ),
-            )
-
-    def arg4(self):
-        return Family("arg4").add(self.submits())
-
-    def prb(self):
-        sub = "/home/ma/emos/bin/smssubmit "
-        return Family("prb").add(
-            Defstatus("complete"),
-            self.submits(),
-            Label("info", "simulate prb at submission with % remaining"),
-            Variables(ECF_JOB_CMD= sub +"%USER% %SCHOST% %ECF_JOB% %STTHOST%%ECF_JOBOUT%",
-                      ECF_KILL_CMD= sub + "%USER% %SCHOST% %ECF_JOB% %STTHOST%%ECF_JOBOUT% kill",
-                      ECF_STATUS_CMD= sub + "%USER% %SCHOST% %ECF_JOB%  %STTHOST%%ECF_JOBOUT% status",
-                      ),                  )
-
-    def submits(self):
-        global host, user
-        def parallel(pes=1, thr=1, hyp="no"):
-            return Family("p%d_%d_%s" %(pes, thr, hyp)).add(
-                Variables(NPES=pes, THREADS=thr,                           
-                          HYPER=hyp), 
-                Task("test").add(Label("info", ""), 
-                                 Meter("step", -1, 120),
-                                 Event(1)))
-        ct1logs= "/sc1/tcwork/emos/logs"
-        # ct1logs = '/home/ma/%s/logs' % user
-        if ecflow: base = 1000
-        else: base = 900000
-        base = 1000
-        if "eod" in host: user = "emos"
-
-        out = [
-
-            unit("cray", HCRAY, "ns", ct1logs, leaf=False).add(
-                unit("ccp", "cca-login1", "ns", ct1logs).add(
-                    Complete(ic.psel() + "/blacklist:cca"),),
-                unit("cca", "cca-login1", "ns",    ct1logs).add(
-                    logsvr("ping"),
-                    Complete(ic.psel() + "/blacklist:cca"),),
-                unit("ccb", "ccb-login1", "ns",    ct1logs).add(
-                    logsvr("ping"),                    ),
-                Family("parallel_a").add(
-                    # Defcomplete(), ###
-                    Complete(ic.psel() + "/blacklist:cca"),
-                    Variables(SCHOST= "cca",
-                              QUEUE= "os",
-                              LOGHOST= "cca-il2",
-                              ECF_OUT= ct1logs,
-                              LOGDIR=  ct1logs,),
-                    parallel(1, 1),
-                    parallel(1, 24),
-                    parallel(2, 12),
-                    parallel(2, 24),
-                    parallel(2, 15),
-                    
-                    parallel(1, 2, "yes"),
-                    parallel(2, 24, "yes"),
-                    parallel(24, 2, "yes"),
-                    parallel(10, 5, "yes"),),
-
-                Family("parallel_b").add(
-                    Complete(ic.psel() + "/blacklist:ccb"),
-                    Variables(SCHOST= "ccb",
-                              QUEUE= "os",
-                              LOGHOST= "ccb-il2",
-                              ECF_OUT= ct1logs,
-                              LOGDIR=  ct1logs,),
-                    parallel(1, 1),
-                    parallel(1, 24),
-                    parallel(2, 12),
-                    parallel(2, 24),
-                    parallel(2, 15),
-                    
-                    parallel(1, 2, "yes"),
-                    parallel(2, 24, "yes"),
-                    parallel(24, 2, "yes"),
-                    parallel(10, 5, "yes"),),
-
-                If(user == "emos",
-                   Variables(LOGHOST= HCRAY,
-                             LOGPORT= base + get_uid()),
-                   Variables(LOGHOST= HCRAY,
-                             LOGPORT= base + get_uid())),
-                )
-            ]      
-
-        lxop_out = "/vol/lxop_emos_nc/output"
-        if user == "emos" or host in ("ode", "eode", "ecf"):
-            ic.SUBM = "/home/ma/emos/bin/trimurtu"
-            sms2ecf.subm = "/home/ma/emos/bin/trimurti"
-
-            out += (
-                Variables(LOGPORT= 9316),
-                unit("cca", "cca", "ns", "/sc1/tcwork/emos_dir", "oesu").add(
-                    Variables(STHOST= "/c1",
-                              LOGHOST= "cca"),
-                    logsvr("ping"),
-                    Complete(ic.psel() + "/blacklist:cca"),),
-
-                unit("ecgb", "ecgb", "emos", "/vol/emos_nc/output"),
-                unit("lxc", "lxc", "emos", "/vol/emos_nc/output"),
-                unit("lxab", "lxab", "serial", "/vol/emos_nc/output"),
-                unit("lxop", "lxop", "emos", lxop_out
-                     ).add(Variables(ECF_OUT= lxop_out,
-                                     ECF_LOGHOST= "lxop",
-                                     ECF_LOGPORT= 9316,
-                                     LOGDIR=  lxop_out, )),
-                unit("sappa", "sappa", "serial", "/vol/emos_nc/output"),
-                unit("sappb", "sappb", "serial", "/vol/emos_nc/output"),
-                unit("opensuse131", "opensuse131", "serial", "/vol/emos_nc/output"),
-                Family("hps").add(
-                    Complete(ic.psel() + "/blacklist:hps"),
-                    unit("acq", "acq", "emos", "/tmp/emos"),
-                    unit("pp1", "pp1", "emos", "/tmp/emos"),
-                    unit("pp2", "pp2", "emos", "/tmp/emos"),
-                    unit("pp3", "pp3", "emos", "/tmp/emos"),
-                    unit("pp4", "pp4", "emos", "/tmp/emos"),
-                    unit("bilbo", "bilbo", "emos", "/tmp/emos"),
-                    unit("hallas", "hallas", "emos", "/tmp/emos"),
-                    # unit("itanium", "itanium", "emos", "/tmp/emos"),),
-                unit("localhost", "localhost", "ns", "/tmp/emos/logs"),
-                unit("ibis", "ibis", "ns", "/tmp/emos/logs"),
-                ))
-        else:
-            rdir = "/tmp"
-            out += (unit("localhost", "localhost", "ns", "/tmp/%s/logs" % user),
-                     unit("lxab", "lxab", "serial", udir + "/logs"),
-                     unit("lxop", "lxop", "emos", udir + "/logs"),
-                     unit("ecgb", "ecgb", "ns", udir + "/logs"),
-                     unit("lxc", "lxc", "ns", udir + "/logs"),         )
-        return out
-
-def maker():
-    return Task("maker").add(
-        Variables(ECF_FILES= wdir,
-                  ECF_INCLUDE= "/home/ma/emos/def/o/include",
-                  WSHOST= "ibis",
-                  USER= "emos",
-                  SCHOST= "ibis",
-                  ECF_OUT= "/vol/lxop_emos_nc/output",),   )
-
-def usage():
-    print('''cray.py -h -u [user] -n [node] -s [suite-name] \
- -e: ecflow''')
-
-if __name__ == "__main__":
-    global user, udir, ecflow, host
-    suites = { "cray": Cray,
-               "test": Cray,
-           }
-    # suite = "test"; node = "eode"
-    # argv = cli_proc.process(suites, selection=suite, host=node)
-    user = get_username()
-    try: host = sys.argv[-1]
-    except: host= "localhost"
-    ecflow  = False
-    ecflow  = True
-    suite   = None
-    user = get_username()
-    opts, args = getopt.getopt(
-          sys.argv[1:], "hp:u:es:n:p:", 
-          ["help", "port", "user", "ecflow", "suite", "node", "path"])
-    print("#MSG: opts, args", opts, args)
-
-    output = None
-    verbose = False
-    for o, a in opts:
-        if   o in ("-n", "--node"):   host = a
-        elif o in ("-h", "--help"):   usage(); sys.exit()
-        elif o in ("-s", "--suite"):  suite =  a
-        elif o in ("-p", "--path"):   path =  a
-        elif o in ("-e", "--ecflow"): ecflow = True
-        elif o in ("-u", "--user"):
-            user = a
-        elif o in ("-p", "--port"):
-            port = a
-        else: print("#ERR: what?", o, a); assert False, "unhandled option"
-
-    import cli_proc
-
-    if suite is None: 
-        cli_proc.ip.SELECTION = user
-    elif '/' in suite:
-        sel = suite
-        if '/' == suite[0]: sel = sel[1:]
-        if '/' in sel: sel, family = sel.split('/', 1)
-        cli_proc.ip.SELECTION = sel
-    else: cli_proc.ip.SELECTION = suite
-
-    if ecflow and host not in ("ode", "map", "pikachu"):
-        ic.ecf.ECF_MODE = "ecflow"
-    else: 
-        import sms2ecf
-        sms2ecf.ECF_MODE = "sms"
-        ic.ecf.ECF_MODE = "sms"
-
-    print("#MSG: ecflow/sms: ", ic.ecf.ECF_MODE)
-    global wdir, rdir, fdef, jdir
-
-    ########### SETTINGS ################
-    udir = pwd.getpwnam(user).pw_dir
-    wdir = udir + "/course/cray"
-    rdir = "/sc1/tcwork/emos/logs"
-    fdef = wdir + "/cray.def"
-    jdir = "/tmp/%s/cray" % user
-    ddef = udir + "/course/cray"
-    fdef = ddef + "/cray.def"
-    idir = "/home/ma/emos/def/cray/include"
-    if user == "map" or host in ["map", ]:
-        wdir = "/home/ma/map/course/cray"
-    elif user == "emos" or host in ["ode", "od3", "eode"]:
-        jdir="/vol/lxop_emos_nc/output"
-        rdir="/vol/lxop_emos_nc/output"
-        udir="/vol/lxop_emos_nc/output"
-
-    print("##", host, suite)
-    argv = cli_proc.process(suites, selection=suite, host=host, proc=False)
-    try:    os.makedirs(wdir)
-    except: pass # one line on purpose
-    try:    os.makedirs(jdir)
-    except: pass
-
-    create_task()
-    create_smhi()
diff -pruN 5.12.4-1/Pyext/samples/def2def.py 5.13.0-1/Pyext/samples/def2def.py
--- 5.12.4-1/Pyext/samples/def2def.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/def2def.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,387 +0,0 @@
-#!/usr/bin/env python
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-import sys
-import getopt
-try: import ecflow
-except:
-        sys.path.append("/usr/local/apps/ecflow/current/lib/python2.7/site-packages/ecflow")
-        import ecflow 
-import ecflow  as ec
-import os
-import sys
-""" a simple program to convert an expanded definition file to 
-py script using ecf.py"""
-
-class Indent:
-    """This class manages indentation, for use with context manager
-    It is used to correctly indent the definition node tree hierarchy
-    """
-    _pos = 0
-    _step = 3
-    def __init__(self):
-        Indent._pos += Indent._step
-    def __del__(self):
-        Indent._pos -= Indent._step
-    @classmethod
-    def indent(cls, loc=''):
-        out = ''
-        for i in range(Indent._pos):
-            if loc is None: 
-                out += ' ' 
-            elif type(loc) == str: 
-                loc += ' '
-            else: 
-                loc.write(' ')
-        if type(loc) == str: 
-            return loc
-        return out
-
-def adds(line=0):
-    if line is None: 
-        return ""
-
-    return Indent.indent() + line + "\n"
-
-def add(line, echo=0):
-    if line is None: 
-        return ""
-    elif echo: 
-            return Indent.indent() + line 
-    else: 
-            return Indent.indent() + line + "\n"
-
-class DefFormat(object):
-    def __init__(self, defs): 
-        self.defs = defs
-
-    def process_attr(self, node, end=False):
-        # print node.get_abs_node_path()
-        res = ""
-        ind = Indent()
-        defstatus = node.get_defstatus()
-        if defstatus: 
-            if defstatus != ec.DState.queued:
-                res += add("Defstatus('%s')," % defstatus)
-
-        item = node.get_autocancel()
-        if item: 
-            line = "%s" % item
-            line = line.replace("autocancel ", "")
-            res += add("Autocancel('%s')," % line)
-
-        item = node.get_repeat()
-        if not item.empty(): 
-            line = "%s" % item
-            full = line.split()
-            kind = full[1]
-            name = full[2]
-            try:
-                beg  = full[3]
-                try: end  = full[4]
-                except: end = beg
-                if "#" in end: end = beg
-            except: beg = 1; end = 1
-            by = 1
-            if len(full) == 6: by = full[5]
-
-            if kind in ("integer", "date"):
-                res += add(
-                    "Repeat(kind='%s', name='%s', start=%s, end=%s, step=%s)," 
-                    % ( kind, name, beg, end, by))
-            elif kind in ("day", ):
-                res += add(
-                    "Repeat(kind='%s', name='%s', step=%s)," 
-                    % ( kind, name, by))
-            elif kind in ("string", "enumerated"):
-                line = "%s" % item
-                line = line.replace("repeat %s %s" % (kind, name), "")
-                line.replace('"', '')
-                res += add("Repeat(kind='%s', name='%s', start=%s)," % (
-                        kind, name, line.split()))
-             # FIXME string enum
-
-        item = node.get_late()
-        if item: 
-            line = "%s" % item
-            line = line.replace("late ", "")
-            res +=  add("Late('%s')," % line)
-
-        item = node.get_complete()
-        if item: res += add("Complete('%s')," % item)
-
-        item = node.get_trigger()
-        if item: 
-            res += add("Trigger('%s')," % item)
-
-        for item in node.meters: 
-            line = "%s" % item
-            dummy, name, beg, end, thr = line.split(" ")
-            res += add("Meter('%s', %s, %s, %s)," % (name, beg, end, thr))
-
-        for item in node.events: 
-            line = "%s" % item
-            line = line.replace("event ", "").strip()
-            res += add("Event('%s')," % line)
-
-        for item in node.labels: 
-            res += add("Label('%s', '%s')," % (item.name(), item.value()))
-
-        for item in node.limits: 
-            val = item.value()
-            if val == "0" or val == 0: 
-                val = "1"
-            res += add("Limit('%s', %d)," % (
-                    item.name(), int(val)))
-
-        for item in node.inlimits:
-            line = "%s" % item
-            line = line.replace("inlimit ", "")
-            res += add("InLimit('%s')," % line)
-
-        for item in node.times:  
-            line = "%s" % item
-            line = line.replace("time ", "")
-            res += add("Time('%s')," % line)  
-
-        for item in node.todays: 
-            line = "%s" % item
-            line = line.replace("today ", "")
-            res += add("Today('%s')," % line) 
-
-        for item in node.dates:  
-            line = "%s" % item
-            line = line.replace("date ", "")            
-            res += add("Date('%s')," % line)  
-
-        for item in node.days:   
-            line = "%s" % item
-            line = line.replace("day ", "")            
-            
-            res += add("Day('%s')," % item)   
-        for item in node.crons:  
-            line = "%s" % item
-            line = line.replace("cron ", "")            
-            res += add("Cron('%s')," % line)  
-
-        var = "Variables("
-        vind = Indent()            
-        num = 0
-        for item in node.variables: 
-            sep="'"
-            if sep in item.value(): sep="\""
-            var += ind.indent("\n") + item.name() + \
-                "= %s%s%s," % (sep, item.value(), sep)
-            num += 1
-        del vind        
-        if num: res += add(var + "),")
-
-        del ind
-        if len(res) == 0: 
-            return None
-        return res
-
-    def process(self, node=None, inc=0):
-        STREAM = 1
-        out = ""
-        if node is None:
-            num = 0
-            out += "# ecf.ECF_MODE = 'sms'"
-            out += "suites = []"
-            for suite in self.defs.suites:
-                if STREAM: out += "suite%d = Suite('%s').add(" % (num, suite.name())
-                else: out += "s = Suite('%s')"% (suite.name()) + "; suites.append(s);"
-                out += self.process(suite)
-                out += ")"
-                num += 1
-            else: out += "#WAR no suite to process"
-
-            if num > 1: 
-                if 0: raise BaseException("no more than one suite at a time")
-                out += "### WARNING: more than one suite defined"
-
-        elif isinstance(node, ec.Suite): 
-            if not STREAM: out += "s.add(\n"
-            add( self.process_attr(node),1 )
-            if STREAM: ind = Indent()
-            for kid in node.nodes: out += self.process(kid)
-            if STREAM: del ind
-
-        elif isinstance(node, ec.Family): 
-            many = ""; one = ""; post = "" # circumvent limitation to 255 items
-            if inc % 200 == 0: 
-                one += "("; post = "),"
-                if inc > 200: many = "),"
-            if STREAM: 
-                add( many + one + "Family('%s').add(" % node.name(), 1)
-                res = self.process_attr(node)
-            else:
-                out += ")\ncur = Family('%s')" % node.name()
-                out += "fam.add(cur); fam = cur; fam.add("
-                res = self.process_attr(node)
-
-            if STREAM: 
-                if res is not None: 
-                        out += Indent.indent(res) # add(res, 1)
-                ind = Indent()
-            num = 0
-            for kid in node.nodes: self.process(kid, num)            ; num += 1
-            if STREAM: 
-                del ind
-                add( Indent.indent(post + "), # endfamily %s" % node.name()), 1 )
-            out += "# %s " % num
-
-        elif isinstance(node, ec.Task): 
-            res = self.process_attr(node)
-            if res is None:  
-                add( "Task('%s')," % node.name(), 1)
-                # print Indent.indent("Task('%s')," % node.name())
-            else: add( "Task('%s').add(\n" % node.name() +
-                       "%s%s)," % (res, Indent.indent()), 1)
-
-        return out
-
-    def main(self):
-        return self.head() + self.process() + self.tail()
-
-    def head(self):
-        return """#!/usr/bin/env python
-# NOTICE: this file was originally created with def2def.py
-import sys
-# sys.path.append('../o/def')
-# sys.path.append('.')
-sys.path.append('/home/ma/emos/def/o/def')
-from ecf import *
-import ecf  as ecf
-# import inc_emos as ie
-"""
-
-    def tail(self):
-        return """
-
-if __name__ == '__main__':
-    defs = Defs()
-    defs.add(suite0); 
-    defs.auto_add_externs(True)
-    if 1: 
-      import cli_proc, ecf
-      cli_proc.process(ie.Seed(defs), compare=False)
-    else:
-       port = 1500 + int(get_uid()) # when started with ecflow_start.sh # ECMWF
-       node = "localhost"
-       path = '/' + suite0.name()
-       if 0: # test job creation
-         job_ctrl = ecflow.JobCreationCtrl()                    
-         defs.check_job_creation(job_ctrl)
-
-       print "replacing %s on %s@%s" % (path, node, port)
-       client = ecf.Client("localhost", port)
-       client.replace(path, defs)
-"""
-
-def usage():
-        print("""def2def.py
-  -f file    [filename]
-  -s string  [description of the suite]
-  -c client  [host@post:/path/to/node]
-  -h help
-
-""")
-
-def test(quiet=1):
-        import os
-        num = 0
-        if quiet: quiet = " > /dev/null "
-        else: quiet = ""
-        for cmd in (
-                        "./def2def.py    || : ", # usage
-                        "./def2def.py -h || : ", # usage
-                        "./def2def.py -s 'suite s; family f; task t'",
-                        "./def2def.py -s 'suite s\n family f\n task t'",
-                        "./def2def.py -p vsms2@32222/o ",
-                        "./def2def.py -f ../o.exp",
-                        "./def2def.py    ../o.exp"):
-                # print "#", cmd
-                # os.system(cmd + " > /dev/null && echo '#' OK%d" % num)
-                os.system(cmd + quiet
-                          + " && echo '#' OK%d " % num + cmd
-                          + " || echo '#' NOK%d " %  num + cmd)
-                num += 1
-
-def process(desc=None, path=None, fname=None):
-        if desc is not None: 
-                import tempfile
-                print("#desc: ", desc) # , "\n"
-                # import unicodedata
-                #unic = unicodedata.normalize('NFKD', desc).encode('ascii', 'ignore')
-                #print "#unic: ", unic # , "\n"
-                USER = os.getenv("USER")
-                try:
-                        with tempfile.NamedTemporaryFile(mode="w+t", dir="/tmp/%s" % USER) as temp:
-                                if type(desc) == list:
-                                        for line in desc:
-                                                temp.write(line)
-                                                temp.write("\n")
-                                elif type(desc) == str:
-                                        temp.write(desc.rstrip())
-                                temp.flush()
-                                # defs = ec.Defs(temp.name)
-                                # if DEBUG: print defs
-                                return process(fname= temp.name)
-                except RuntimeError as e:    
-                        out = "#WAR: failed: " + str(e)
-                        # print "temp, NOK"; sys.exit(1)
-                        print(out)
-                        return out
-                # return "%s" % defs
-        elif path is not None: 
-                import re
-                node, rem = path.split("@")
-                port, suite = rem.split('/')[0:2]
-                print(node, port, suite)
-                client = ec.Client(node, port)
-                client.ch_register(False, [ suite ])
-                client.sync_local()
-                defs = client.get_defs()
-        elif fname is not None: pass
-        elif fname is None and len(sys.argv) > 1:
-                fname = sys.argv[1]
-        else: usage(); sys.exit(2)
-
-        if fname:
-                defs = ec.Defs(fname)
-        defs.auto_add_externs(True)
-        if DEBUG: print(defs)
-        return DefFormat(defs).main()
-
-DEBUG = 0
-if __name__ == '__main__':
-        opts, args = getopt.getopt(sys.argv[1:], "gqhf:s:p:t",
-                                   ["debug", "help", "file", "string", "path", "test"])
-        fname = None
-        desc  = None
-        path  = None
-        QUIET = 0
-        DEBUG = 0
-        for o, a in opts:
-                if o in ("-g", "debug"): DEBUG = 1
-                if o in ("-h", "help"): usage(); sys.exit(2)
-                if o in ("-f", "file"): fname = a
-                if o in ("-s", "string"): desc = a
-                if o in ("-p", "path"): path = a
-                if o in ("-t", "test"): test(QUIET); sys.exit(0)
-                if o in ("-q", "quiet"): QUIET = 1
-
-        print(process(desc, path, fname))
-# ./def2def.py -q -t 
-# ./def2def.py -t 
diff -pruN 5.12.4-1/Pyext/samples/ecflow_1638.py 5.13.0-1/Pyext/samples/ecflow_1638.py
--- 5.12.4-1/Pyext/samples/ecflow_1638.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/ecflow_1638.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-from ecflow import *
-  
-print ("Simulator test ecflow_1638")
-
-# the following test fails in ecflow 5.3.1
-# Simulation start    at:: 1,5,2020 @ 00:00
-# Simulation finished at:: 3,5,2020 @ 00:00
-# ie Friday->Saturday(midnight) 2 days
-# Hence we expect  task t4; cron 23:00             to complete 2
-# Hence we expect  task t5; cron 10:00 20:00 01:00 to complete 22
-
-defs = Defs(
-        Suite("ecflow_1638",
-            Clock(1,5,2020),
-            Task("t2",Date("1.5.2010"),Date("1.5.2011"),Verify(State.complete,0)),
-            Task("t3",Time("23:00"),Verify(State.complete,1)),
-            Task("t4",Cron("23:00"),Verify(State.complete,2)),
-            Task("t5",Cron("10:00 20:00 01:00"),Verify(State.complete,22)),
-            )
-        )
-defs.ecflow_1639.add_end_clock(Clock(3,5,2020))
-print(defs)
-
-theResult = defs.simulate()
-assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
-
-    
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/samples/ecflow_urwid.py 5.13.0-1/Pyext/samples/ecflow_urwid.py
--- 5.12.4-1/Pyext/samples/ecflow_urwid.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/ecflow_urwid.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,682 +0,0 @@
-#!/usr/bin/python
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# file deepcode ignore PythonIdenticalBranches: <comment the reason here>
-
-"""Thanks https://github.com/pazz/urwidtrees
-"""
-
-
-
-import os
-import re
-import sys
-import time
-
-import urwid
-import ecflow
-mark = 'dirmark'
-
-UPDATE_INTERVAL = 180
-
-singles = {"queued": "Q",
-           "submitted": "S",
-           "active": "R",
-           "complete": "C",
-           "aborted": "A",
-           "suspended": "P",
-           "unknown": "U",
-           "RUNNING": "R",
-           "HALTED": "H",
-           "SHUTDOWN": "S",
-
-           "dirmark": "-",
-           # "unkown": "U",
-           }
-global STATUS_KIND
-STATUS_KIND = True
-
-
-def is_expanded(item):
-    return get_status(item, True) in (
-        "aborted", "active", "submitted", "RUNNING", "unknown",
-        "A", "R", "S", "U", "abo", "RUN", "unk",
-    )
-
-
-def decorate(node, parent=None, keys=None):
-    if type(node) not in (ecflow.Defs, ecflow.Alias,
-                          ecflow.Suite, ecflow.Family, ecflow.Task):
-        if 1:
-            raise Exception(type(node))
-        return ""
-    status = get_status(node)
-    ext = ' %c [%s]' % (kinds[type(node)], status)
-    num = 0
-
-    if type(node) in (ecflow.Suite, ecflow.Family, ecflow.Task, ):
-        if "%s" % node.get_defstatus() == status:
-            if status != "queued":
-                ext += " (defstatus)"
-
-    if type(node) == ecflow.Defs:
-        return ext
-    exp = node.get_repeat()
-    if exp:
-        ext += "\n%s" % exp
-
-    exp = node.get_trigger()
-    if exp:
-        ext += "\n%s" % exp
-
-    exp = node.get_complete()
-    if exp:
-        ext += "\n%s" % exp
-
-    exp = node.get_late()
-    if exp:
-        ext += "\n%s" % exp
-
-    exp = node.get_autocancel()
-    if exp:
-        ext += "\n%s" % exp
-
-    for item in node.events:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.meters:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.labels:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.limits:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.inlimits:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.times:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.dates:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.todays:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.crons:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.days:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.zombies:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    for item in node.variables:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-        else:
-            ext += " %s" % item
-        num += 1
-
-    gvar = ecflow.VariableList()
-    node.get_generated_variables(gvar)
-    for item in gvar:
-        if keys:
-            parent._children[num] = LeafNode(item)
-            keys.append("%s" % item)
-
-    if keys:
-        return num
-    return ext
-
-
-def get_name(item, full=False, parent=None, keys=None):
-    if type(item) in (ContainerNode, LeafNode):
-        item = item.get_value()
-    if type(item) in (dict, tuple, ):
-        return "#list"
-    if type(item) in (str, ):
-        if 1:
-            raise Exception(item)
-        return item
-    if type(item) in (ecflow.Client, ):
-        return "%s@%s" % (item.get_host(), item.get_port()) + \
-               " - %s " % time.time()
-
-    # ext = ' %c [%s]' % (kinds[type(item)], get_status(item))
-    ext = decorate(item)
-    if type(item) in (ecflow.Defs, ):
-        return "defs" + str(ext) + " - %s " % time.time()
-
-    if type(item) in (ecflow.Client, ):
-        return "%s@%s" % (item.get_host(), item.get_port()) + \
-               " - %s " % time.time()
-    if full:
-        return "%s" % item.name() + str(ext)
-    return item.name()
-
-
-def get_status(item, full=False):
-    if type(item) in (ecflow.Client, ):
-        item = item.get_defs()
-
-    if type(item) in (ecflow.Defs, ):
-        out = "%s" % item.get_server_state()
-    elif type(item) in (dict, tuple):
-        out = "unknown"
-    elif type(item) == str:
-        if item == dir_sep():
-            out = "unknown"
-        else:
-            raise Exception(item, type(item))
-    else:
-        out = "%s" % item.get_state()
-
-    if full:
-        return out
-    if STATUS_KIND == 1:
-        return singles[out]
-    if STATUS_KIND == 3:
-        return out[:3]
-    return out
-
-
-class FlagNodeW(urwid.TreeWidget):
-    unexpanded_icon = urwid.AttrMap(urwid.TreeWidget.unexpanded_icon, mark)
-    expanded_icon = urwid.AttrMap(urwid.TreeWidget.expanded_icon, mark)
-
-    def __init__(self, item):
-        super(FlagNodeW, self).__init__(item)
-        self._w = urwid.AttrWrap(self._w, None)
-        self.flagged = False
-        self.update_w()
-
-    def selectable(self):
-        return True
-
-    def keypress(self, size, key):
-        key = super(FlagNodeW, self).keypress(size, key)
-        if key:
-            key = self.unhandled_key(size, key)
-        return key
-
-    def unhandled_key(self, size, key):
-        if key == " ":
-            self.flagged = not self.flagged
-            self.update_w()
-        else:
-            return key
-
-    def update_w(self):
-        if self.flagged:
-            self._w.attr = 'flagged'
-            self._w.focus_attr = 'focus'
-        else:
-            self._w.attr = 'body'
-            self._w.focus_attr = 'focus'
-        self._w.attr = get_status(self.get_node().get_value(), True)
-
-
-class EmptyW(urwid.TreeWidget):
-
-    def get_display_text(self):
-        return ('flag', "(empty)")
-
-
-class ErrorW(urwid.TreeWidget):
-
-    def get_display_text(self):
-        return ('flag', "(error)")
-
-
-class NodeW(FlagNodeW):
-
-    def __init__(self, item):
-        super(NodeW, self).__init__(item)
-        node = item.get_value()
-        add_widget(node, self)
-
-    def get_display_text(self):
-        node = self.get_node().get_value()
-        return get_name(node, True)
-
-
-class ContainerNodeW(FlagNodeW):
-
-    def __init__(self, item):
-        super(ContainerNodeW, self).__init__(item)
-        node = item.get_value()
-        add_widget(node, self)
-        self.expanded = is_expanded(node)
-        self.update_expanded_icon()
-
-    def get_display_text(self):
-        node = self.get_node().get_value()
-        return get_name(node, True)
-
-
-class EmptyNode(urwid.TreeNode):
-
-    def load_widget(self):
-        return EmptyW(self)
-
-
-class ErrorNode(urwid.TreeNode):
-
-    def load_widget(self):
-        return ErrorW(self)
-
-
-class LeafNode(urwid.TreeNode):
-
-    def __init__(self, item, parent=None):
-        if type(item) == ecflow.Task:
-            path = item.get_abs_node_path()
-            depth = path.count(dir_sep())
-            key = os.path.basename(path)
-        else:
-            path = "%s" % item
-            depth = 0
-            key = "%s" % item
-        urwid.TreeNode.__init__(self, item, key=key,
-                                parent=parent, depth=depth)
-
-    def load_parent(self):
-        node = self.get_value()
-        if type(node) in (ecflow.Client, ecflow.Defs, ):
-            path = dir_sep()
-        else:
-            path = node.get_abs_node_path()
-        parentname, name = os.path.split(path)
-        if 1:
-            raise Exception
-        parent = ContainerNode(self.ci.find_abs_node_path(parentname))
-        parent.set_child_node(self.get_key().get_value(), self)
-        return parent
-
-    def load_widget(self):
-        return NodeW(self)
-
-    # def load_child_keys(self): return [None]
-
-
-class ContainerNode(urwid.ParentNode):
-
-    def __init__(self, item, parent=None):
-        if type(item) in (ecflow.Client, ecflow.Defs, ):
-            path = dir_sep()
-        else:
-            path = item.get_abs_node_path()
-        depth = path.count(dir_sep())
-        if path == dir_sep():
-            depth = 0
-            key = None
-        else:
-            key = os.path.basename(path)
-        urwid.ParentNode.__init__(
-            self, item, key=key, parent=parent, depth=depth)
-
-    def load_parent(self):
-        node = self.get_value()
-        if type(node) in (ecflow.Client, ecflow.Defs, ):
-            path = dir_sep()
-        else:
-            path = node.get_abs_node_path()
-        parentname, name = os.path.split(path)
-        if 1:
-            raise Exception
-        parent = ContainerNode(self.ci.find_abs_node_path(parentname))
-        parent.set_child_node(self.get_key().get_value(), self)
-        return parent
-
-    def load_child_keys(self):
-        keys = []
-        num = 0
-        node = self.get_value()
-        if type(node) in (ecflow.Client, ):
-            node = node.get_defs()
-
-        if type(node) in (ecflow.Defs, ):
-            for item in node.suites:
-                self._children[num] = ContainerNode(item)
-                keys.append(get_name(item))
-                num += 1
-
-        elif type(node) in (ecflow.Suite, ecflow.Family, ):
-            for item in node.nodes:
-                if type(item) in (ecflow.Family, ):
-                    self._children[num] = ContainerNode(item)
-                elif type(item) in (ecflow.Task, ):
-                    self._children[num] = LeafNode(item)
-                else:
-                    self._children[num] = LeafNode(item)
-                keys.append(get_name(item))
-                num += 1
-
-            if 0:
-                num += decorate(node, self, keys)
-
-        elif type(node) in (ecflow.Task, ):
-            pass
-
-        elif 1:
-            raise Exception(type(node))
-        else:
-            self._children[0] = EmptyNode(
-                self, parent=self, key=None, depth=num)
-        self.dir_count = num + 1
-        # print(keys)
-        return keys
-
-    def load_child_node(self, key):
-        # index = self.get_child_index(key)
-        node = self.get_value()
-        num = 0
-        if type(node) in (ecflow.Client, ):
-            node = node.get_defs()
-
-        if type(node) in (ecflow.Task, ):
-            return EmptyNode(None)
-
-        if type(node) in (ecflow.Suite, ecflow.Family):
-            num = 0
-            for item in node.nodes:
-                if num == key:
-                    node = item
-                    break
-                if item.name() == key:
-                    node = item
-                    break
-                num += 1
-
-        if key is None:
-            return EmptyNode(None)
-
-        if type(node) in (ecflow.Defs, ):
-            path = dir_sep()
-            for item in node.suites:
-                if num == key:
-                    node = item
-                    break
-                if get_name(item) == key:
-                    node = item
-                    break
-                num += 1
-            return ContainerNode(node, parent=self)
-
-        # path = os.path.join(get_name(node), key)
-        if type(node) in (ecflow.Suite, ecflow.Family, ):
-            return ContainerNode(node, parent=self)
-
-        return LeafNode(node, parent=self)
-
-    def load_widget(self):
-        return ContainerNodeW(self)
-
-
-class EcflowBrowser(object):
-    palette = [
-        ('body', 'black', 'light gray'),
-        ('flagged', 'black', 'dark green', ('bold', 'underline')),
-        ('focus', 'light gray', 'dark blue', 'standout'),
-        ('flagged focus', 'yellow', 'dark cyan',
-         ('bold', 'standout', 'underline')),
-        ('head', 'yellow', 'black', 'standout'),
-        ('foot', 'light gray', 'black'),
-        ('key', 'light cyan', 'black', 'underline'),
-        ('title', 'white', 'black', 'bold'),
-        ('dirmark', 'black', 'dark cyan', 'bold'),
-        ('flag', 'dark gray', 'light gray'),
-        ('error', 'dark red', 'light gray'),
-
-        ('queued', 'dark gray', 'light blue'),
-        ('submitted', 'dark gray', 'light cyan'),
-        ('active', 'dark gray', 'light green'),
-        ('complete', 'dark gray', 'yellow'),
-        ('aborted', 'dark gray', 'dark red'),
-        ('unknown', 'dark gray', 'light gray'),
-        ('suspended', 'dark gray', 'brown'),
-        ('RUNNING', 'dark gray', 'light green'),
-        ('HALTED', 'dark gray', 'dark cyan'),  # purple
-        ('SHUTDOWN', 'dark gray', 'light red'),  # pink'),
-    ]
-
-    footer_text = [
-        ('title', "Directory Browser"), "    ",
-        ('key', "UP"), ",", ('key', "DOWN"), ",",
-        ('key', "PAGE UP"), ",", ('key', "PAGE DOWN"),
-        "  ",
-        ('key', "SPACE"), "  ",
-        ('key', "+"), ",",
-        ('key', "-"), "  ",
-        ('key', "LEFT"), "  ",
-        ('key', "HOME"), "  ",
-        ('key', "END"), "  ",
-        ('key', "Q"),
-    ]
-
-    def __init__(self, server, suites):
-        host, port = server.split('@')
-        self.ci = ecflow.Client(host, int(port))
-        self.ci.ch_register(False, suites)
-        self.ci.sync_local()
-        # print(self.ci.get_defs())
-        self.start_time = time.time()
-
-        # cwd = os.getcwd()
-        cwd = self.ci.get_defs()
-        store_initial_cwd(dir_sep())
-        self.header = urwid.Text("")
-        self.listbox = urwid.TreeListBox(urwid.TreeWalker(ContainerNode(cwd)))
-        self.listbox.offset_rows = 1
-        self.footer = urwid.AttrWrap(urwid.Text(self.footer_text),
-                                     'foot')
-        self.view = urwid.Frame(
-            urwid.AttrWrap(self.listbox, 'body'),
-            header=urwid.AttrWrap(self.header, 'head'),
-            footer=self.footer)
-
-    def main(self):
-        """Run the program."""
-
-        self.loop = urwid.MainLoop(self.view, self.palette,
-                                   unhandled_input=self.unhandled_input)
-        self.loop.run()
-
-        # on exit, write the flagged filenames to the console
-        names = [escape_filename_sh(x) for x in get_flagged_names()]
-        print(" ".join(names))
-
-    def unhandled_input(self, k):
-        # update display of focus directory
-        if k in ('q', 'Q'):
-            raise urwid.ExitMainLoop()
-
-        if k in ('z', 'Z', ):
-            self.ci.sync_local()
-
-        global STATUS_KIND
-        if k in ('3', "3", 3):
-            STATUS_KIND = 3
-
-        elif k in ('1', "1", 1):
-            STATUS_KIND = 1
-
-        elif k in ('f', "F"):  # full
-            STATUS_KIND = 0
-
-
-def main(server, suites):
-    EcflowBrowser(server, suites).main()
-
-
-_widget_cache = {}
-
-
-def add_widget(path, widget):
-    _widget_cache[path] = widget
-
-
-def get_flagged_names():
-    lst = []
-    for w in list(_widget_cache.values()):
-        if w.flagged:
-            node = w.get_node().get_value()
-            lst.append(get_name(node))
-    return lst
-
-
-_initial_cwd = []
-
-
-def store_initial_cwd(name):
-    global _initial_cwd
-    _initial_cwd = name.split(dir_sep())
-
-
-def escape_filename_sh(name):
-    """Return a hopefully safe shell-escaped version of a filename."""
-
-    # check whether we have unprintable characters
-    for ch in name:
-        if ord(ch) < 32:
-            # found one so use the ansi-c escaping
-            return escape_filename_sh_ansic(name)
-
-    # all printable characters, so return a double-quoted version
-    name.replace('\\', '\\\\')
-    name.replace('"', '\\"')
-    name.replace('`', '\\`')
-    name.replace('$', '\\$')
-    return '"' + name + '"'
-
-
-def escape_filename_sh_ansic(name):
-    """Return an ansi-c shell-escaped version of a filename."""
-
-    out = []
-    # gather the escaped characters into a list
-    for ch in name:
-        if ord(ch) < 32:
-            out.append("\\x%02x" % ord(ch))
-        elif ch == '\\':
-            out.append('\\\\')
-        else:
-            out.append(ch)
-
-    # slap them back together in an ansi-c quote  $'...'
-    return "$'" + "".join(out) + "'"
-
-
-SPLIT_RE = re.compile(r'[a-zA-Z]+|\d+')
-
-
-def alphabetize(s):
-    L = []
-    import itertools
-    for isdigit, group in itertools.groupby(
-            SPLIT_RE.findall(s), key=lambda x: x.isdigit()):
-        if isdigit:
-            for n in group:
-                L.append(('', int(n)))
-        else:
-            L.append((''.join(group).lower(), 0))
-    return L
-
-
-def dir_sep():
-    return getattr(os.path, 'se[', '/')
-
-
-kinds = {ecflow.Defs: "D",
-         ecflow.Client: "C",
-         ecflow.Suite: "S",
-         ecflow.Family: "F",
-         ecflow.Task: "T",
-         ContainerNode: "X",
-         LeafNode: "L",
-         str: "S",
-         }
-
-
-if __name__ == '__main__':
-    if len(sys.argv) == 2:
-        node = sys.argv[1]
-    else:
-        raise Exception("ecflow_urwid.py localhost@2500/test")
-    server, suites = node.split('/')
-    main(server, [suites])
-
-"""
-python ecflow_urwid.py localhost@2500/test
-
-"""
diff -pruN 5.12.4-1/Pyext/samples/emos_example.py 5.13.0-1/Pyext/samples/emos_example.py
--- 5.12.4-1/Pyext/samples/emos_example.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/emos_example.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,483 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Checking Job Creation
-#for the record, Emos alternative syntax is,
-
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-print "suite creation"
-defs = Defs()
-defs.suite("test").add(
-    Variables(ECF_HOME= os.path.join(os.getenv("HOME"), "course")),
-    Task("t1"))
-print defs
-print "Checking job creation: .ecf -> .job0"  
-print defs.check_job_creation()
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# Load the file
-#Using "if __name__ == '__main__':" the script can be used both as a module (providing a function) or as a standalone script:
-
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-
-def generate():
-    # print "Creating suite definition"  
-    return Defs().add(
-        Suite("test").add(
-            Variables(ECF_HOME= os.path.join(os.getenv("HOME"),  "course")),
-            Task("t1")))
- 
-if __name__ == '__main__':
-    defs = generate()      
-    print defs
-    print "Checking job creation: .ecf -> .job0"  
-    print defs.check_job_creation()
-    print "Saving definition to file 'test.def'"
-    defs.save_as_defs("test.def")
-    try:
-        print "Load the in memory definition(defs) into the server"
-        Client("localhost@%s" % os.getenv("ECF_PORT")).load(defs)
-    except RuntimeError as e: print "Failed:", e
-        
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# families
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-print "Creating suite definition"  
-defs = Defs().add(Suite("test").add(
-    Variable("ECF_HOME", os.path.join(os.getenv("HOME"),  "course")),
-    Family("f1").add(
-      Task("t1"),
-      Task("t2"))))
-print defs
-print "Checking job creation: .ecf -> .job0"  
-print defs.check_job_creation()
-print "Saving definition to file 'test.def'"
-defs.save_as_defs("test.def")
-print "Client -> Server: delete, then load a new definition"  
-try:
-    ci = Client()
-    ci.replace("/test", "test.def") # replace the suite into the server
-    ci.begin_suite("test")    # start the suite
-except RuntimeError as e:
-    print "Failed:",   e
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# ecflow variables
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home = os.path.join(os.getenv("HOME"), "course")
- 
-def create_family_f1():
-    return Family("f1" ).add(
-        Task("t1").add(Variables(SLEEP= 20)),
-        Task("t2").add(Variables(SLEEP= 20)))
- 
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    create_family_f1() ))
- 
-print defs
-defs.save_as_defs("test.def")
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# variable inheritance
-# tab constraint is relaxed with Emos ecf.py
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home = os.path.join(os.getenv("HOME"), "course")
-def create_family_f1():
-    return Family("f1" ).add(
-        Variables(SLEEP= 20),
-        Task("t1"),
-        Task("t2"))
-print "Creating suite definition"
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-             ECF_HOME=    home),
-     create_family_f1() ))
-print defs
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# triggers#!/usr/bin/env python2.7
-import os
-from ecf import *
-home=  os.path.join(os.getenv("HOME"), "course")
-def create_family_f1():
-    return Family("f1" ).add(
-        Variable(SLEEP= 20),
-        Task("t1"),
-        Task("t2").add(Trigger("t1 eq complete")))
-print "Creating suite definition"
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    create_family_f1() ))
-print defs
-defs.save_as_defs("test.def")
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# add an event
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home = os.path.join(os.getenv("HOME"), "course")
-def create_family_f1():
-    return Family("f1").add(
-        Variables(SLEEP= 20),
-        Task("t1"),
-        Task("t2").add(
-            Trigger(["t1"]),
-            Event("a"),
-            Event("b")),
-     
-        Task("t3").add(Trigger("t2:a")),
-        Task("t4").add(Trigger("t2:b")),
-    )
-print "Creating suite definition"
-defs = Defs().add(
-    Suite("test").add(
-        Variables(ECF_INCLUDE= home,
-                  ECF_HOME=    home),
-        create_family_f1() ))
-print defs
-defs.save_as_defs("test.def")
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# add a complete
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home = os.path.join(os.getenv("HOME"),  "course")
-def create_family_f1():
-    return Family("f1").add(
-        Variable(SLEEP= 20),
-        Task("t1"),
-        Task("t2").add(Trigger("t1 eq complete"),
-                       Event("a"),
-                       Event("b")),
-        Task("t3").add(Trigger("t2:a")),
-        Task("t4").add(Trigger("t2 eq complete"), 
-                       Complete("t2:b")  ))
-       
-print "Creating suite definition"  
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    create_family_f1() ))
-print defs
-defs.save_as_defs("test.def")
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# add a meter
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home= os.path.join(os.getenv("HOME"), "course")
-def create_family_f1():
-    return Family("f1").add(
-        Variables(SLEEP= 20),
-        Task("t1").add(Meter("progress", 1, 100, 90)),
-     
-        Task("t2").add(Trigger("t1 eq complete"),
-                       Event("a"),
-                       Event("b")),
-     
-        Task("t3").add(Trigger("t2:a")),
-     
-        Task("t4").add(Trigger("t2 eq complete"),
-                       Complete("t2:b")),
-      
-        Task("t5").add(Trigger("t1:progress ge 30")),
-        Task("t6").add(Trigger("t1:progress ge 60")),
-        Task("t7").add(Trigger("t1:progress ge 90")))
-    
-print "Creating suite definition"  
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    create_family_f1() ))
-print defs
-defs.save_as_defs("test.def")
-
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# Time dependencies
-# #!/usr/bin/env python2.7
-import os
-
-home = os.path.join(os.getenv("HOME"),  "course")
- 
-def create_family_f2():
-    return Family("f2").add(
-        Variables(SLEEP= 20),
-        Task("t1").add(
-          Time("00:30 23:30 00:30")), # start(hh:mm) end(hh:mm) increment(hh:mm)
-        Task("t2").add(Day( "sunday" )),
-        Task("t3").add(
-            Date("1.*.*"),  # day month year, first of every month or every year
-            Time("12:00")), # hour, minutes at 12 o'clock
-    
-        Task("t4").add(Time("+00:02")), # hour, minutes, relative to suite start
-                                        # 2 minutes after family f2 start
-        Task("t5").add(Time("00:02"))   # hour, minutes suite site
-                                        # 2 minutes past midnight
-)           
-    
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    create_family_f1(),
-    create_family_f2(), ))
-print defs
-defs.save_as_defs("test.def")
-
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# indentation
-# Another approach is to use ecf.py module to benefit from object oriented polymorphism
-#!/usr/bin/env python2.7
-import os
-import sys
-sys.path.append('/home/ma/emos/def/o/def')
-from ecf import *
-print "Creating suite definition" 
-defs = Defs().add(# Stream like definition
-    Suite("test").add(
-        Variables({ # a dictionary to detect duplicated variables
-                "ECF_INCLUDE": os.getenv("HOME") + "/course",
-                "ECF_HOME":    os.getenv("HOME") + "/course",}),
-        Family("f1").add(
-            Variable("SLEEP", "20"),
-            Task("t1").add(Meter("progress", 1, 100, 90)),
-            Task("t2").add(
-                Trigger("t1 eq complete"),
-                Event("a"),
-                Event("b")),
-            Task("t3").add(Trigger("t2:a")),
-            Task("t4").add(Trigger("t2 eq complete"),
-                           Complete("t2:b")),
-            Task("t5").add(Trigger("t1:progress ge 30")),
-            Task("t6").add(Trigger("t1:progress ge 60")),
-            Task("t7").add(Trigger("t1:progress ge 90")),),
-        Family("f2").add(
-            Variable("SLEEP", "20"),
-            Task("t1").add(Time( "00:30 23:30 00:30" )),
-            Task("t2").add(Day( "sunday" )),
-            Task("t3").add(Date("1.*.*"),
-                           Time("12:00")),
-            Task("t4").add(Time("+00:02")),
-            Task("t5").add(Time("00:02")))))
-             
-out = file("test.def", "w")
-print >>out, defs
-
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-# label
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home = os.getenv("HOME") + "/course"
-print "Creating suite definition"  
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    Family("f3").add(
-        Task("t1").add(
-            Label("info","")))))
-print defs
-defs.save_as_defs("test.def")
-
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-# repeat
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home = os.path.join(os.getenv("HOME"),  "course")
-def create_family_f4():
-    return Family("f4").add(
-        Variables(SLEEP= 2),
-        Repeat("NAME", ["a", "b", "c", "d", "e", "f" ], kind="enum"),
-    
-        Family("f5").add(
-            Repeat( "VALUE", 1, 10, kind= "integer"),
-            Task("t1").add(
-                Repeat( "DATE", 20101230, 20110105, kind= "date"),
-                Label("info", ""))))
-     
-print "Creating suite definition"  
-defs = ecflow.Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    create_family_f4(), ))
-print defs
-defs.save_as_defs("test.def")
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# limits
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home= os.path.join(os.getenv("HOME"),  "course")
-def create_family_f5() :
-    return Family("f5").add(
-        Inlimit("l1"),
-        Variables(SLEEP= 20),
-        [ Task( "t" + str(i))     for i in range(1, 10)] # list comprehension
-    )
-     
-print "Creating suite definition"  
-defs = Defs().add(Suite("test").add(
-    Variables(ECF_INCLUDE= home,
-              ECF_HOME=    home),
-    Limit("l1", 2),
-    create_family_f5() ))
-print defs
-defs.save_as_defs("test.def")
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-#  Data acquiation solution
-#!/usr/bin/env python2.7
-import os
-from ecf import * 
-home = os.getenv("HOME") + "/course")  
-defs = Defs().add(Suite("data_aquisition").add(
-    Repeat(kind="day", step=1),
-    Variables(ECF_HOME= home,
-              ECF_INCLUDE= home,
-              ECF_FILES= home + "/data",
-              SLEEP= 2),
-    [ Family(city).add(
-        Task("archive").add(
-            [ Family(obs_type).add(
-                If( city in ("Exeter", "Toulouse", "Offenbach"),
-                    Time("00:00 23:00 01:00")),
-                If( city in ("Washington"),
-                    Time("00:00 23:00 03:00")),
-                If( city in ("Tokyo"),
-                    Time("12:00")),
-                If( city in ("Melbourne"),
-                    Day( "monday" )),
-                If( city in ("Montreal"),
-                    Date("1.*.*")),
-          
-                Task("get"),
-                Task("process").add(Trigger("get eq complete")),
-                Task("store").add(Trigger("get eq complete")))
-              for obs_type in ( "observations", "fields", "images" ) ] ))
-        for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) ]
-    ))
-print defs
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# operational suite solution:
-
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home = os.getenv("HOME") + "/course"
-cycle_triggers = None
-last_step = { "12": 240,
-              "00": 24, }
-def cycle_trigger(cycle):
-    if cycle == "12": return Trigger("./00==complete")
-    return None
-defs = Defs().add(Suite("operation_suite").add(
-     Repeat(kind="day", step=1),
-     Variables(ECF_HOME= home,
-               ECF_INCLUDE= home,
-               ECF_FILES= home + "/oper"),
-    [ Family(str(cycle)).add(
-        Variables(CYCLE=  cycle,
-                  LAST_STEP= last_step[cycle]),
-       
-        cycle_trigger(cycle),
-                  
-        Family("analysis").add(
-            Task("get_observations"),
-            Task("run_analysis").add(Trigger(["get_observations", ])),
-            Task("post_processing").add(Trigger(["run_analysis", ])),
-        ),
-  
-        Family("forecast").add(
-            Trigger("analysis == complete"),
-            Task("get_input_data"),
-            Task("run_forecast").add(
-                Trigger(["get_input_data", ]),
-                Meter("step", 0, last_step[cycle])),
-        ),
-        Family("archive").add(
-            Family("analysis").add(
-                Variables(TYPE= "analysis",
-                          STEP= 0),
-                Trigger(["../analysis/run_analysis", ]),
-                Task("save"),
-                [ Family("step_%02d" % i).add(
-                    Variables(TYPE= "forecast",
-                              STEP= i),
-                    Trigger("../../forecast/run_forecast:step ge %d" % i),
-                    Task("save"))
-                  for i in range(6, last_step+1, 6) ]
-            )
-        )
-    ) for cycle in ( 0 , 12 ) ] ))
-print defs
-
-!!!!!!! 
-Baudouin Raoult
-range(6, last_step, 6) will not return last_step.
-
->>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
-
-# back archiving solution
-#!/usr/bin/env python2.7
-import os
-from ecf import *
-home= os.getenv("HOME") + "/course"
-defs = Defs().add(Suite("back_archiving").add(
-    Repeat( kind= "day", step= 1),
-    Variables(ECF_HOME= home,
-              ECF_INCLUDE= home,
-              ECF_FILES= home + "/back",
-              SLEEP= 2),
-    Limit("access", 2),
-    [ Family(kind).add(
-        Repeat( "DATE", 19900101, 19950712, kind="date"),
-        Variables(KIND= kind),
-        Task("get_old").add(Inlimit("access")),
-        Task("convert").add(Trigger("get_old == complete")),
-        Task("save_new").add(Trigger("convert == complete")))
-      for kind in ( "analysis", "forecast", "climatology", "observations", "images" ) ]
-))
-print defs
diff -pruN 5.12.4-1/Pyext/samples/extract_version.py 5.13.0-1/Pyext/samples/extract_version.py
--- 5.12.4-1/Pyext/samples/extract_version.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/extract_version.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-import sys, os
-
-def get_installed_ecflow_version():
-    "This will extract ecFlow version from /usr/local/apps/ecflow/current."
-    "Will return a list of form `[2,0,24]`"
-    ecflow_dir_ext = os.readlink("/usr/local/apps/ecflow/current")
-    # print(ecflow_dir_ext)
-    version_list = ecflow_dir_ext.split(".")
-    assert len(version_list) == 3 ,"Expected 3 items,release,major,minor but found " + ecflow_dir_ext
-    print("Extracted ecflow version from /usr/local/apps/ecflow/current: " + ecflow_dir_ext)
-    return version_list;
-    
-def get_ecflow_version( work_space ):
-    "This will extract ecFlow version *list* from the source code."
-    "The version is defined in the file CMakeList.txt"
-    "expecting string of form:"
-    "project( ecflow LANGUAGES CXX VERSION 5.10.0 )"
-    file = work_space + "/CMakeLists.txt11"
-    ecflow_version = []
-    if os.path.exists(file):
-        cmake_file = open(file,'r')
-        try :
-            for line in cmake_file :
-                project = line.find('project(')
-                ecflow = line.find('ecflow')
-                cxx = line.find('CXX')
-                version_t = line.find('VERSION')
-                if project != -1 and ecflow != -1 and cxx != -1 and version_t != -1 :
-                    tokens = line.split()
-                    version_index = tokens.index("VERSION")
-                    version = tokens[version_index+1]
-                    if version[-1] == ')':
-                        version = version[:-1]
-                    ecflow_version = version.split(".")
-        finally:
-            cmake_file.close();
-        
-        print("Extracted ecflow version '" + str(ecflow_version) + "' from " + file)
-        return ecflow_version
-    else:
-        return get_installed_ecflow_version()
-    
-    
-print(get_ecflow_version("/Users/avibahra/git/ecflow"))
-    
diff -pruN 5.12.4-1/Pyext/samples/mirror.py 5.13.0-1/Pyext/samples/mirror.py
--- 5.12.4-1/Pyext/samples/mirror.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/mirror.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,1034 +0,0 @@
-#!/usr/bin/env python
-# ////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-# ////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# -m trace --count -C .
-"""an example for a simple python client to help ecFlow scheduling
- + unit test
- + task loading in the suite
-
-one script DO-IT-ALL:
-  - play suite + update suite holder aka def-file
-
-  - script as a wrapper for a task
-
-  - download content (passive client)
-
-  - upload statuses (active client)
-
-$manual
-
-  MIRRORING suite from server to server
-
-  test - suspend suite and rerun job if aborted... Thanks
-
-$end
-$comment
-  a comment in a comment
-$end
-
-TODO: check MICRO robust sync
-"""
-import argparse
-import os
-import pwd
-import sys
-import time
-import unittest
-from time import gmtime, strftime
-
-# ECFLOWP = "/usr/local/apps/ecflow/current"
-# ECFLOWC = ECFLOWP + "/bin/ecflow_client "
-# sys.path.append(ECFLOWP + "/lib/python2.7/site-packages/ecflow")
-ECFLOWC = "ecflow_client "
-child = None
-
-
-def getreq():
-    return Family("getreq").add(Task("collectreq"))
-
-
-def ymd():
-    return [Edit("YMD", "29090909"), Label("ymd", "29090909")]
-
-
-def excepthook(exctype, value, traceback):
-    if exctype == KeyboardInterrupt:
-        if child:
-            child.report("abort", "keyb")
-    else:
-        sys.__excepthook__(exctype, value, traceback)
-        if child:
-            child.report("abort", "gen")
-
-
-def fullname(item):
-    return ""
-
-
-sys.excepthook = excepthook
-from ecf import *  # mirror
-import ecf
-import ecflow
-
-
-# class Edit(ecf.Variables):    pass
-
-MICRO = "$$"  # keep ecFlow pleased with micro character balance
-DEBUG = 1
-DEBUG = 0
-USER = "emos"
-# USER = "map"
-
-sms_status = {
-    -1: "unknown",
-    0: "unknown",
-    1: "suspended",
-    2: "complete",
-    3: "queued",
-    4: "submitted",
-    5: "active",
-    6: "aborted",
-    7: "shutdown",
-    8: "halted",
-    9: "unknown",
-}
-sms_type = {
-    13: "definition",
-    12: "suite",
-    11: "family",
-    10: "task",
-    32: "alias",
-}
-
-
-############################
-def usage():
-    print(
-        sys.argv[0],
-        """
-      -h # help
-      -m <server@port> # mirror path fri
-      -t # unit test
-      -r # load the task definition in a suite, associated with -p option
-      -r # with -m, allow suite loading in destination
-      -u usage
-
-can also be used as a module: gen_task, gen_suite
-
-    """,
-    )
-    for num, val in enumerate(sys.argv):
-        print(num, val)
-    child.report("abort")
-    sys.exit(2)
-
-
-############################
-def get_uid():
-    return pwd.getpwnam(get_username()).pw_uid
-
-
-############################
-def gen_task(var=True, load_only=False, kind=None):
-    from ecf import Task, Label, Variables
-
-    pwd = os.getcwd()
-    name = sys.argv[0]
-    if "/" in name:
-        name = name.split("/")[-1]
-    if "." in name:
-        name = name.split(".")[0]
-    rec = "00:30"
-    cmd = "/home/ma/emos/bin/trimurti emos eurus $ECF_JOB$ $ECF_JOBOUT$"
-    cmd = "/usr/local/apps/python/2.7.12-01/bin/python $ECF_JOB$"
-    WDIR = pwd
-    ODIR = pwd
-
-    load = (
-        Label("info", "mirror suites..."),
-        Variables(
-            ECF_MICRO=MICRO[0],
-            ECF_HOME=ODIR,
-            ECF_EXTN=".py",
-            ECF_JOB_CMD=cmd,
-        ),
-    )
-    if load_only:
-        return load
-    return Task(name).add(Cron("04:00 20:00 " + rec), If(var, load))
-
-
-############################
-# def stop(msg, num, child=None):
-#     print(msg);
-#     if child:
-#         child.report(msg)
-#         if num == 0: child.report("complete")
-#     sys.stdout.flush()
-#     sys.stderr.flush()
-#     sys.exit(num)
-def timer(a, b):
-    if child is None:
-        return
-    child.report("timeout")
-    child.report("complete")
-
-
-import signal
-
-signal.signal(signal.SIGALRM, timer)
-signal.alarm(180)
-
-
-############################
-class Child(object):
-    """facilitate job behaviour with ecFlow server:
-    just instanciate and call complete when finished
-
-    obj = Child(); obs.report("complete")
-
-    this does nothing when script is called from command line
-    """
-
-    def __init__(self):
-        import signal
-
-        env = {
-            "ECF_HOST": "$ECF_HOST:$",
-            # check can be on a server, child on another
-            "ECF_PASS": "$ECF_PASS$",
-            "ECF_NAME": "$ECF_NAME$",
-            "ECF_PORT": "$ECF_PORT:0$",
-            "ECF_TRYNO": "$ECF_TRYNO$",
-        }
-        self.client = None
-        if MICRO[0] in env["ECF_PORT"]:
-            print("#MSG: cli mode")
-            return
-        print("#MSG: will communicate with server...")
-        print("#MSG: kill: ssh %s kill -15 %d" % (os.uname()[1], os.getpid()))
-        for sig in (
-            signal.SIGINT,
-            signal.SIGHUP,
-            signal.SIGQUIT,
-            signal.SIGILL,
-            signal.SIGTRAP,
-            signal.SIGIOT,
-            signal.SIGBUS,
-            signal.SIGFPE,
-            signal.SIGUSR1,
-            signal.SIGUSR2,
-            signal.SIGPIPE,
-            signal.SIGTERM,
-            signal.SIGXCPU,
-            signal.SIGPWR,
-        ):
-            signal.signal(sig, self.signal_handler)
-        self.set_client()
-
-    def set_client(self):
-        self.client = ecflow.Client()
-        if len(MICRO) == 2:
-            host = env["ECF_HOST"]
-            print(host)
-            self.client.set_host_port(host, int(env["ECF_PORT"]))
-            self.client.set_child_pid(os.getpid())
-            self.client.set_child_path(env["ECF_NAME"])
-            self.client.set_child_password(env["ECF_PASS"])
-            self.client.set_child_try_no(int(env["ECF_TRYNO"]))
-        else:
-            host = "$ECF_HOST:$"
-            print(host)
-            self.client.set_host_port(host, int("$ECF_PORT:0$"))
-            self.client.set_child_pid(os.getpid())
-            self.client.set_child_path("$ECF_NAME$")
-            self.client.set_child_password("$ECF_PASS$")
-            self.client.set_child_try_no(int("$ECF_TRYNO$"))
-        self.client.child_init()
-
-        self.client.child_label("info", "%s" % strftime("%Y-%m-%d %H:%M:%S", gmtime()))
-        self.client.set_child_timeout(20)
-        print(self.client)
-
-    def signal_handler(self, signum, frame):
-        """ catch signal """
-        print("Aborting: Signal handler called with signal ", signum)
-        self.report("abort", "Signal handler called with signal " + str(signum))
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        self.report("abort", "__exit__")
-
-    def report(self, msg, meter=None):
-        """ communicate with ecFlow server """
-        if not self.client:
-            print("#MSG: no child")
-            if msg in ("stop", "complete"):
-                sys.stdout.flush()
-                sys.stderr.flush()
-                print("#MSG: no child stop")
-                sys.exit(0)
-            else:
-                print(msg, meter)
-            return
-        elif msg in ("stop", "complete"):
-            self.client.child_complete()
-            self.client = None
-            sys.stdout.flush()
-            sys.stderr.flush()
-            print("#MSG: stop")
-            sys.exit(0)
-        elif msg in ("abort",):
-            self.client.child_abort()
-            self.client = None
-            raise Exception(msg)
-        elif meter:
-            self.client.child_meter(msg, meter)
-        else:
-            self.client.child_label("info", msg)
-
-
-############################
-destinations = {
-    "emos": "${DEST_HOST:=localhost}@${DEST_PORT=5001}",
-    "test": "${DEST_HOST:=localhost}@${DEST_PORT=5001}",
-    "mc": "localhost@5003",
-}
-
-
-def gen_suite(host=None, port=None, path=None):
-    import ecf
-    from ecf import (
-        Task,
-        Label,
-        Variables,
-        Suite,
-        Defs,
-        Family,
-        Trigger,
-        Defstatus,
-        Meter,
-        Event,
-    )
-
-    # destinations = dict()
-    defs = Defs()
-    sname = "mirror"
-    print(list(definitions.keys()), list(destinations.keys()))
-    defs.add_suite(
-        Suite(sname).add(
-            ecf.Defstatus("suspended"),
-            Limit("one", 2),
-            Inlimit("one"),
-            gen_task(load_only=True),
-            Variables(ALL_ECF=" "),
-            [
-                Family(name).add(
-                    Variables(DESTINATIONS=destinations[name]),
-                    Label("info", ""),
-                    gen_task(0, kind=name),
-                )
-                for name in list(definitions.keys())
-                # if name in destinations.keys()
-            ],
-        )
-    )
-    if DEBUG:
-        print(defs)
-    return defs
-
-
-definitions = {  # strings as path for all nodes below sync
-    # or suites, subset of the original, leaves are task...
-    # or else not sync'ed
-    # shall we add list of string/path ???
-    "emos": Suite("emos").add(
-        Defstatus("suspended"), Family("f1").add(Edit(YMD=20320101), Task("t1"))
-    ),
-    "test": Suite("test").add(
-        Defstatus("suspended"), Family("f1").add(Edit(YMD=20320101), Task("t1"))
-    ),
-    "mc": Suite("mc").add(
-        Defstatus("suspended"), Family("main").add(
-            Edit(YMD=20990101), 
-            Family("06bc").add(
-                Task("sweeper"), 
-                Family("fc0006d").add(Task("fc")),
-            ),
-    ), ),
-}
-
-############################
-
-
-class Mirror(object):
-
-    """    """
-
-    def _protect_oper(self, server):
-        if server == "xyz@123":
-            if 1:
-                child.report("abort", "protect")
-            elif (
-                "/o" in self.path
-                or self.path == "all"
-                or "/eda" in self.path
-                or "/mc" in self.path
-            ):
-                raise Exception("# wont do that...")
-
-    def _warmup(self):
-        self._set_register(self.path)
-        if not self.is_sms:
-            self.source.ch_register(False, self.register)
-            self.source.sync_local()
-
-    def _send(self, msg="", client=None, send=False):
-        """self.grouped is None: no buffering, immediate send
-        msg accumulate (send False by default)
-        msg is sent ("", client, send=True)
-        """
-        if self.grouped is None:
-            print("#MSG: send", self.grouped)
-            client.group(msg)
-            time.sleep(self.snap)
-            return
-
-        self.grouped += msg
-        if send and self.grouped != "":
-            print("#MSG: send", self.grouped)
-            client.group(self.grouped)
-            client.sync_local()
-            self.grouped = ""
-            time.sleep(self.snap)
-
-    def __init__(self, server="eurus@1630", path="/e_45r1", replay=False, is_sms=False):
-        self.is_sms = is_sms
-        self.replay = replay  # allow replay from skel definition
-        self.act = 1  # active ie force change allowed
-        self.snap = 1  # sleep interval
-        self.wait = 0  # refresh interval,continue as long as sub/act node exist
-        self.path = path
-        self.grouped = None  # would use atomic alter
-        self.grouped = ""  # command to send to the server ... grouped
-        self._set_register(path)
-
-        if server == "all":
-            self.servers = "$DESTINATIONS$".split(" ")
-        elif " " in server:
-            self.servers = server.split(" ")
-        elif "@" in server:
-            host, port = server.split("@")
-            self.servers = ("%s@%s" % (host, port),)
-        elif ":" in server:
-            host, port = server.split(":")
-            self.servers = ("%s:%s" % (host, port),)
-        if self.servers[-1] == "":
-            del self.servers[-1]
-        host = os.getenv("ECF_HOST", "localhost")
-        # if MICRO[0] in host: host = "localhost"
-        port = os.getenv("ECF_PORT", "3141")
-        if MICRO[0] in port:
-            port = 1500 + int(get_uid())
-        # when started with ecflow_start.sh
-        # aka reference/source  server name
-        self.sname = "%s:%s" % (host, port)
-
-        if "$SOURCE:$" != "" and MICRO[0] not in "$SOURCE:$":
-            self.sname = "$SOURCE:$"
-        if DEBUG:
-            print("#DBG: source is", self.sname)
-        self.set_source()
-
-    def set_source(self):
-        self.source = ecflow.Client(self.sname)
-        self._warmup()
-
-    def __exit__(self):
-        if type(self.source) == ecflow.Client:
-            try:
-                self.source.ch_drop()
-            except:
-                pass
-
-    def _set_register(self, path):
-        if "/" == path[0]:
-            suite = str(path.split("/")[1])
-            self.register = [
-                suite,
-            ]
-
-        elif path == "all":
-            self.register = list(skel.keys())
-
-        else:
-            child.report("abort", "register")
-
-    def _check(self, server, client, stop=0):
-        if client == self.source:
-            stop = 1
-
-        for suite in self.register:
-            top = client.get_defs().find_abs_node("/" + suite)
-
-            if top is None:
-                print(
-                    "#WAR: node not found",
-                    suite,
-                    server,
-                )
-                if stop:
-                    child.report("abort", "check")
-                elif self.act and server != self.sname:
-                    self._protect_oper(server)
-                    if self.replay:
-                        if type(definitions[suite]) == str:
-                            print("#WAR: not yet")
-                            child.report("abort", "str")
-                        print("replaying")
-
-                        defs = ecflow.Defs()
-                        defs.add_suite(definitions[suite])
-                        host = "localhost"
-                        client.load(defs)
-                        client.suspend("/" + suite)
-                        client.begin_suite(suite)
-                        client.sync_local()
-                    else:
-                        print("replay?")
-                else:
-                    pass
-
-            elif server != self.sname and not (
-                top.is_suspended()
-                or "%s" % top.get_state() == "unknown"  # normal backup server
-            ):  # test server
-                print("#ERR: top node shall be suspended - NOGO")
-                print("#ERR:", server, top.name(), top.get_state())
-                if 1:
-                    child.report("abort", "state")
-                print("#MSG: stop")
-                child.report("abort", "state")  # sys.exit(1)
-
-            else:
-                pass
-
-            if suite not in list(definitions.keys()):
-                raise Exception(list(definitions.keys()), suite)
-
-            if type(definitions[suite]) == str:
-                path = definitions[suite]
-
-            elif suite in self.path:
-                path = self.path
-
-            else:
-                return
-
-            node = client.get_defs().find_abs_node(path)
-            if node:
-                return
-            print("#WAR: node not found", path, server)
-            if stop:
-                child.report("abort", "stop")
-
-    def _update_var(self, var, nfrom, ndest, server, client, kind="edit"):
-        name = var.name()
-        vfrom = None
-        vdest = None
-        repeat = nfrom.get_repeat()
-        print("############# %s" % repeat, nfrom.get_abs_node_path())
-        if repeat and repeat.name() == name:
-            vfrom = repeat
-        else:
-            for vfrom in nfrom.variables:
-                if vfrom.name() == name:
-                    break
-
-        for vdest in ndest.variables:
-            if vdest.name() == name:
-                break
-        pnode = ndest.get_abs_node_path()
-        pnode = nfrom.get_abs_node_path()
-
-        if vfrom is None:
-            return
-
-        elif vfrom.name() != name:
-            return
-
-        if vdest is None:
-            return
-
-        vname = vdest.name()
-        vval = vdest.value()
-        if vname != name:
-            return
-
-        if vfrom.name() == vname and str(vfrom.value()) != str(vval) or FORCE:
-            if type(vfrom) == Repeat:
-                self.action(
-                    ndest.get_abs_node_path(),
-                    server,
-                    client,
-                    kind="repeat",
-                    value=str(vfrom.value()),
-                    msg="repeat requeue",
-                )
-            else:
-                self.action(
-                    pnode,
-                    server,
-                    client,
-                    kind=name,
-                    value=str(vfrom.value()),
-                    msg="value update",
-                )
-
-    def process(self, server=None, client=None, item=None, var=False):
-        if server is None:
-            self._check(self.sname, self.source, 1)
-
-            for server in self.servers:
-                server = server.replace("@", ":")
-                if DEBUG:
-                    print("#DBG: target is", server)
-                host, port = server.split(":")
-
-                if int(port) < 65536 and 0 == comm(
-                    ECFLOWC + "--ping --port %s --host %s" % (port, host), False
-                ):
-                    client = ecflow.Client(server)
-                    client.ch_register(False, self.register)
-                    client.sync_local()
-                    self._check(server, client)
-                    for suite in self.register:
-                        node = definitions[suite]
-                        if type(node) == str:
-                            node = self.source.get_defs().find_abs_node(node)
-                        # try: node.add(Label("memo", "This suite was generated by mirror.py"))
-                        # except: pass # used to sync, too late
-                        # update variables
-                        self.process(server, client, node, "repeat")
-                        # self.process(server, client, node) # update statuses
-                        # self.process(server, client, node, "edit") # update
-                        # variables
-                    client.ch_drop()
-
-                else:
-                    # child.report("abort","res")
-                    print("server is not responding")
-
-            if self.wait > 0:
-                print("#MSG: start again... snap ", self.wait)
-                time.sleep(self.wait)
-                self.wait = 0
-                self.source.sync_local()
-                self.process()
-            return
-
-        elif server == self.sname:
-            child.report("abort", "same name " + server + " " + self.sname)  # DONT
-
-        elif client is None:
-            child.report("abort", "no client")  # DONT
-
-        elif type(item) in (ecflow.Suite, ecf.Suite):
-
-            if 0:
-                pass
-            else:
-                # suite =
-                # client.get_defs().find_abs_node(item.get_abs_node_path())
-                suite = client.get_defs().find_abs_node(item.fullname())
-                # print(type(client), item.fullname(), type(suite))
-                if suite:
-                    if not suite.is_suspended():
-                        print("#ERR: top node shall be suspended - stop", suite, server)
-                        return
-                    for node in suite.nodes:
-                        self.process(server, client, node, var)
-            return
-
-        elif type(item) in (ecflow.Family, ecflow.Task):
-            pnode = item.get_abs_node_path()
-            nfrom = self.source.get_defs().find_abs_node(pnode)
-            if 0:
-                pass
-            else:
-                ndest = client.get_defs().find_abs_node(pnode)
-
-            if nfrom is None:
-                if var:
-                    return  # ignore
-                print(
-                    "#ERR: node not found, please update mirror.py skel",
-                    pnode,
-                    self.sname,
-                )
-                child.report("abort", "nfrom")
-
-            elif ndest is None:
-                if var:
-                    return  # ignore
-                print("#ERR: node not found, replay?", pnode, server)
-                return
-
-            else:
-                pass
-            if nfrom is not None:
-                status = "%s" % nfrom.get_state()
-            else:
-                raise Exception(pnode, self.source, "nfrom is not")
-
-            if 0:
-                pass
-            else:
-                dstate = "%s" % ndest.get_state()
-            is_task = type(item) == ecf.Task
-
-            for evs in nfrom.events:
-                for evd in ndest.events:
-                    # if evd.name_or_number() != evs.name_or_number(): continue
-                    if evd.name() == "" and evd.number() != evs.number():
-                        continue
-                    if evd.value() == evs.value():
-                        break
-                    print(
-                        "#event",
-                        evs.name(),
-                        evd.number(),
-                        evs.number(),
-                        evd.value(),
-                        evs.value(),
-                    )
-                    if evs.value():
-                        if evs.name() == "":
-                            self._send(
-                                "alter change event %d set %s;" % (evs.number(), pnode),
-                                client,
-                            )
-                            # client.alter(pnode, "change", "event", "%d" %
-                            # evs.number(), "set")
-                        else:
-                            self._send(
-                                "alter change event %s set %s;" % (evs.name(), pnode),
-                                client,
-                            )
-                        # else: client.alter(pnode, "change", "event",
-                        # evs.name(), "set")
-
-            for evs in nfrom.meters:
-                for evd in ndest.meters:
-                    if evd.name() != evs.name():
-                        continue
-                    if evd.value() == evs.value():
-                        break
-                    print("#meter", evd.value(), evs.value())
-                    try:
-                        value = evs.value()
-                        if value > 100:
-                            value = 100
-                        if value > 0:
-                            self._send(
-                                "alter change meter %s %s %s;"
-                                % (evs.name(), value, pnode),
-                                client,
-                            )
-                        # client.alter(pnode, "change", "meter", evs.name(),
-                        # "%s" % evs.value())
-                    except:
-                        pass
-
-            if status != dstate or FORCE:
-                print(
-                    "#WAR: diff ",
-                    pnode,
-                    status,
-                    dstate,
-                )
-                if status == "complete":
-                    self.action(
-                        pnode, server, client, status, is_task, msg="forced complete"
-                    )
-                    if not is_task:
-                        self._send("", client, send=True)
-                        return
-
-                elif status == "queued":
-                    # self._send("force queued %s;" % (pnode), client)
-                    self.action(
-                        pnode, server, client, status, is_task, msg="forced queued"
-                    )
-                elif status in (
-                    "submitted",
-                    "active",
-                    "unknown",
-                    "aborted",
-                ):
-                    print("#IGN: status is active/submit, ignored")
-                else:
-                    raise Exception(status)
-
-            if type(item) in (ecflow.Suite, ecflow.Family):
-                for node in item.nodes:
-                    self.process(server, client, node, var)
-
-            if var:
-                for edit in item.variables:
-                    self._update_var(edit, nfrom, ndest, server, client, var)
-
-            self._send("", client, send=True)
-        else:
-            raise Exception(type(item), item)
-
-    def action(
-        self, pnode, server, client, kind, is_task=False, value="20010101", msg=""
-    ):
-        if not self.act:
-            return
-
-        self._protect_oper(server)
-
-        print("#MSG:", msg)
-        if kind in (
-            "active",
-            "submitted",
-        ):
-            return
-        elif FORCE:
-            pass  # SMS ONLY
-
-        elif kind == "complete":
-            if is_task:
-                self._send("", client, True)
-                client.force_state(pnode, ecflow.State.complete)
-            else:
-                self._send("", client, True)
-                client.force_state_recursive(pnode, ecflow.State.complete)
-        elif kind == "queued":  # and is_task:
-            self._send("force queued %s;" % pnode, client)
-
-        elif kind == "repeat":
-            raise Exception
-
-        else:  # var
-            if DEBUG:
-                print("#DBG: update var", kind, value)
-            if kind in ("queued",):
-                pass
-            elif kind not in (
-                "YMD",
-                "JUL",
-                "DAY",
-                "SCHOST",
-                "STHOST",
-                "YYYY",
-                "MM",
-                "ECF_FILES",
-                "INIBEGINDATE",
-                "MIXTASK",
-            ):
-                raise Exception(kind)
-            if 0:
-                pass
-            else:
-                client.requeue(pnode)
-                self._send(
-                    "alter change variable %s %s %s;" % (kind, value, pnode),
-                    client,
-                    True,
-                )
-
-
-# ignore Family + queued while is might just be that we dont mirror all
-# fam/tasks and inheritance get it already complete in dest while still
-# queued in source
-
-
-############################
-def replay(path, defs=None):
-    import ecf
-
-    miss = "@undef@"
-    host = os.getenv("ECF_HOST", miss)
-    if host == miss:
-        print("ECF_HOST not defined")
-        exit(1)
-    port = os.getenv("ECF_PORT", 31415)
-    client = ecf.Client(host, port)
-    if defs is None:
-        defs = gen_suite(host, port, path)
-    if DEBUG:
-        print(defs)
-    # print(defs)
-    if (
-        "localhost" in host
-        and port in ("3141", 3141)
-        and ("/test" in path)
-        and "/mirror" not in path
-    ):
-        raise Exception("dont")
-
-    print("#MSG: replacing %s in " % path, host, port, defs)
-    client.replace(path, defs, 1, 1)
-    return client
-
-
-def comm(cmd, rem=True):
-    import subprocess
-
-    if rem and cmd in list(memo.keys()):
-        return memo[cmd]
-    (rc, res) = subprocess.getstatusoutput(cmd)
-    print("#COMM:", rc, res, cmd)
-    if rem:
-        memo[cmd] = rc
-    return rc
-
-
-############################
-class TestMirror(unittest.TestCase):
-    """ a test case """
-
-    def test_1(self, test_ok=1):
-        sname = "mirror"
-        replay("/" + sname, gen_suite())
-
-
-memo = dict()
-############################
-if __name__ == "__main__":
-    import argparse
-
-    parser = argparse.ArgumentParser(add_help=False)
-    parser.add_argument("-?", default=0, help="help")
-    parser.add_argument("-f", "--force", action="store_true", help="force")
-    parser.add_argument("-h", default=0, help="help")
-    parser.add_argument("-m", "--mirror", default="localhost@31415", help="mirror")
-    parser.add_argument("-p", "--path", default="/mirror/test", help="path")
-    parser.add_argument("-r", "--replay", action="store_true", help="replay")
-    parser.add_argument("-t", "--test", action="store_true", help="test")
-    parser.add_argument("-u", "--usage", action="store_true", help="test")
-
-    parsed = parser.parse_args()
-    global FORCE
-    FORCE = parsed.force
-    print(parsed.path, parsed.mirror, parsed.replay, parsed.force, parsed.test)
-    # raise Exception
-    child = Child()
-
-    if parsed.usage:
-        print(
-            """
-
-* mirrors (slow real-time) a source suite, from a source server, to a destination server
-* mirror suite can be hosted on the source, on the destination or another server
-* this script was used in ecflow course to demonstrate
-  * one script that can be used from the command line
-  * defines a suite
-  * play/replace a suite/node
-  * a script can be used as task wrapper/template to generate jobs
-  * an ecflow client (passive) to download status/value from source
-  * an ecflow client (active) to change status/value on destination
-
-* update mirror.py: destination variable with the triplet suite host port
-
-* update mirror.py: definition with the key(suite) and the minimum suite-tree to mirror
-
-* update mirror.py: replay add "if" for "protection" not to overwrite source suite by mistake
-
-* download a copy from the source suite
-  ecflow_client --port 3141 --host localhost --get > tmp.def
-
-* load the mirror suite on the source server
-  SUITE=test ECF_HOST=localhost ECF_PORT=3141 ./mirror.py -p /mirror/test -r # load
-
-* play (suspended) mirrored suite in destination
-  ECF_HOST=ecgate ECF_PORT=31415 ./mirror.py -m ecgate:31415 -p /test
-
-module load python3; module load ecflow/5.7.0
-ecflow_start.sh -p 5001 # source
-ecflow_start.sh -p 5003 # destination
-# ecflow_client --host vecf1 --port 44444 --get mc > mc.dump # an example suite
-ecflow_client --host localhost --port 5001 --replace /mc mc.dump # we take it as a source
-# definitions =  # contains "mc" definition
-# destinations = { # contains one destination for mc at least
- export  SUITE=mc ECF_HOST=localhost ECF_PORT=5001
- ./mirror.py -p /mirror/mc -r # load mirror on source server # might be destination or another server yet
-# ImportError: No module named ecf # ecf shall be in the path, at least it can found in ecflow distrib as 
-# ecflow/Pyext/samples/api/ecf.py
-# ('#MSG: replacing /mirror/test in ', 'localhost', '5001', #5.7.0 # loading OK
-# begin mirror - 
-# Script OK? mirror.py undef ECF_FILES directory?
-# Edit OK? $ is used as ECF_MICRO
-# cron OK?
-# set DESTINATIONS variable as expected
-
-ECF_HOST=localhost ECF_PORT=5003 python3 ./mirror.py -m localhost:5003 -p /mc # ok
-#COMM: 0 ping server(localhost:5003) succeeded in 00:00:00.001058  ~1 milliseconds ecflow_client --ping --port 5003 --host localhost # OK
-# replay?
-ECF_PORT=5003 python3 ./mirror.py -m localhost:5003 -p /mc -r # ok mc loaded on target
-# begin /mc in 5003 (it looks suspended
-# edit ECF_JOB_CMD "python3 $ECF_JOB$ > $ECF_JOBOUT$ &"
-
-# python3 /home/ma/map/mirror/mc/mirror.job1 # OK after ECF_PASS FREE running as zombie ommand line
-# ImportError: No module named 'ecf' # jobs lost in submit
-
-# mirror jobs submits and complete OKWITH ECF_JOB_CMD updated as 
-module load python3 && module load ecflow/5.7.0 && cd /home/ma/map && python3 $ECF_JOB$ > $ECF_JOBOUT$ 2>&1 &
-"""
-        )
-        sys.exit(2)
-
-    if not MICRO[0] in "$ECF_PORT$":
-        parsed.mirror = "$DESTINATIONS$"
-        parsed.path = "/$FAMILY1$"
-        print("#MSG: ssh %s kill -9 %d" % (os.uname()[1], os.getpid()))
-
-    if parsed.test:
-        sys.argv.pop()
-        unittest.main()
-
-    elif parsed.path and parsed.replay:
-        print("#MSG: path and replay", parsed.path, parsed.replay)
-        port = int(os.getenv("SMS_PROG", 0))
-        s = parsed.path.split("/")[1]
-        defs = None
-        if "mirror" not in parsed.path:
-            defs = Defs()
-            defs.add_suite(definitions[s])
-        replay(parsed.path, defs)
-
-    elif parsed.mirror and parsed.path:
-        print(parsed.mirror, "#", parsed.path, parsed.replay, type(Mirror))
-        mirror = Mirror(parsed.mirror, parsed.path, parsed.replay)
-        print("#MSG: step")
-        mirror.process()
-        print("#MSG: step")
-        child.report("complete")
-        print("#MSG: step")
-
-    else:
-        usage()
-    print("#MSG: step")
-    child.report("complete")
-"""
-  export ECF_HOST=localhost ECF_PORT=5001 SUITE=mc
-  ecflow_client --get /mc > tmp.def
-  ./mirror.py -p /mirror/mc -r # load
-
-  ECF_HOST=localhost ECF_PORT=31415 ./mirror.py -m localhost:31415 -p /mc
-
-/tmp/map/work/git/ecflow/Pyext/samples/mirror.py
-"""
diff -pruN 5.12.4-1/Pyext/samples/overview.py 5.13.0-1/Pyext/samples/overview.py
--- 5.12.4-1/Pyext/samples/overview.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/overview.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,458 +0,0 @@
-#!/usr/bin/env python
-# -*- coding= UTF-8 -*-
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-""" tkinter example with ecflow
-"""
-
-import tkinter as tki
-from tkinter import *
-import queue
-import sys
-import time
-import os
-import pwd
-from threading import Thread
-try: from scrolledlist import ScrolledList
-except: 
-    loc = "http://infohost.nmt.edu/tcc/help/lang/python/examples/scrolledlist"
-    raise Exception("wget %s/scrolledlist.py; # Thanks NMT")
-
-loc = "/usr/local/apps/ecflow/current/lib/python2.7/site-packages/ecflow"
-sys.path.append(loc)
-loc = "/usr/local/lib/python2.7/site-packages/ecflow"
-sys.path.append(loc)
-import ecflow as ec
-
-PROGRAM_NAME = "ecflowview-overview"
-BUTTON_FONT = ('times', 12)
-MONO_FONT = ('lucidatypewriter', 14, 'bold')
-DEBUG = 0
-COLORS = {"aborted": "red",
-          "active":  "green",
-          "submitted": "cyan",
-          "complete": "yellow",
-          "suspended": "orange",
-          "queued": "blue",
-          "unknwon": "grey"}
-running = [True]
-
-ONCE = False
-
-
-def show_check(one):
-    print(one)
-    sep = ','
-    if sep not in one: return
-    exp = one.split(sep)
-    if len(exp) != 4: return
-    host, qid = exp[2], exp[3]
-    check = os.getenv("CHECK_TASK", "check_task.py")
-    global ONCE
-    if check is not None:
-        print(check +  " -n %s -j %s" % (host, qid))
-    elif ONCE:
-        print("#WAR: export CHECK_TASK=$HOME/bin/check_task.py; overview.py $ECF_HOST@$ECF_PORT,")
-        ONCE = True
-
-
-class Label(object):
-    """ a class to encapsulate what was a global variable"""
-    inst = None
-
-    def __init__(self, item): Label.inst = item
-
-    @classmethod
-    def update(cls):
-        if Label.inst is None:
-            return
-        Label.inst.set(time.strftime("%a, %d %b %Y %H:%M:%S"))
-
-
-class MenuBar(tki.Frame):
-    """ guess"""
-
-    def __init__(self, parent):
-        tki.Frame.__init__(self, parent)
-        self.parent = parent
-        self.__helpButton = self.__createHelp()
-        self.__helpButton.grid(row=0, column=3)
-        self.__quitButton = tki.Button(self, text='Quit', font=BUTTON_FONT,
-                                       command=root.destroy)
-        self.__quitButton.grid(row=0, column=1)
-        self.__updateButton = tki.Button(self, text='Update', font=BUTTON_FONT,
-                                         command=parent.update)
-        self.__updateButton.grid(row=0, column=2)
-
-    def quit(self, event=None):
-        self.parent.quit()
-
-    def __createHelp(self):
-        mb = tki.Menubutton(self, font=BUTTON_FONT,
-                            relief=tki.RAISED, text='Help')
-        menu = tki.Menu(mb)
-        mb['menu'] = menu
-        url = "https://confluence.ecmwf.int/display/ECFLOW/Documentation"
-
-        def url1(): self.__url(url=url)
-
-        def url2(): self.__url(url="http://effbot.org/tkinterbook/")
-        menu.add_command(command=url1, label="confluence tutorial?")
-        menu.add_command(command=url2, label="tkinter?")
-        return mb
-
-    def __url(self, url=None):
-        if url is not None:
-            os.system("${BROWSER:=firefox} %s" % url)
-
-
-class TaskList(tki.Frame):
-    """ a class to host all tasks"""
-    # WIDTH = w / 30
-    # LINES = h / 10
-
-    def __init__(self, parent, kind):
-        tki.Frame.__init__(self, parent, 
-                           # side="bottom", 
-                           # fill="both", 
-                           # expand=True,
-                           # sticky="nsew",
-        )
-        self.WIDTH = 80
-        self.LINES = 80
-        self.__kind = kind
-        self.__callback = None
-        #self.__label = tki.Label(
-        #    self, font=BUTTON_FONT, background=COLORS[kind], text=kind)
-        #self.__label.grid(row=0, column=0, sticky=tki.W)
-        select = tki.Button(self, text=kind,
-                                 font=BUTTON_FONT,
-                                 background=COLORS[kind],
-                                 command=self.select)
-        select.grid(row=1, column=0, sticky=tki.W)
-
-        selectall = tki.Button(self, text="select all",
-                                    font=BUTTON_FONT,
-                                    # background=COLORS[kind],
-                                    command=self.select_all)
-        selectall.grid(row=2, column=0, sticky=tki.W)
-
-        self.__scrolledList = ScrolledList(
-            self, 
-            # sticky="nsew",
-            width=self.WIDTH, 
-            height=self.LINES,  # selectmode=tki.EXTENDED,
-            callback=self.__callback)
-        self.__scrolledList.grid(row=3, column=0)
-
-    def select_all(self):
-        res = set()
-        item = self.__scrolledList.listbox.get(0, tki.END)
-        for one in item:
-            print(one)
-
-    def select(self):
-        res = set()
-        selected = self.__scrolledList.listbox.curselection()
-        for i in selected:
-            item = self.__scrolledList.listbox.get(i)
-            res.add(item)
-            for one in res: 
-                show_check(one)
-                
-    def insert(self, path): self.__scrolledList.append(path)
-
-    def clear(self): self.__scrolledList.clear()
-
-
-class PaceKeeper():
-    """ get regular updates"""
-    PACE = 60
-
-    def __init__(self, item, queue):
-        self._item = item
-        Thread(target=self.process, args=(queue, running)).start()
-
-    def process(self, queue, running):
-        while running:
-            queue.put(self._item.update)
-            time.sleep(self.PACE)
-
-    def run(self): self.update()
-
-    def update(self, verbose=False):
-        while True:
-            self._item.update()
-            time.sleep(self.PACE)
-
-
-class Client(object):
-    """ a class to focus on client-ecFlow-server comm"""
-
-    def __init__(self, one="localhost@31415"):
-        # try: nick, hhh = one.split("-")
-        # except: hhh = one; nick = None
-        if "@" in one:
-            host, port = one.split("@")
-        # except: 
-        else: host = "localhost"; port = 31415
-        self.nick = one
-        # if nick is None: self.nick = "%s@%s" % (host, port)
-        print("# client creation", self.nick, host, port)
-        self.client = ec.Client(host, port)
-
-    def process(self, win):
-        # Label.update()
-        self.client.sync_local()
-        defs = self.client.get_defs()
-        if len(defs) == 0:
-            print("# %s-%: empty content" % (self.host, self.port))
-        # Label.update()
-        for suite in defs.suites:
-            self.process_nc(suite, win)
-
-    def process_nc(self, node, win):
-        for item in node.nodes:
-            if isinstance(item, ec.Task):
-                self.process_node(item, win)
-            else:
-                self.process_nc(item, win)
-
-    def process_node(self, item, wins):
-        for kind, win in list(wins.items()):
-            status = "%s" % item.get_state()
-            if status != kind:
-                continue
-            change = item.get_state_change_time()
-            line = "#%s:%s,%s" % (
-                self.nick, item.get_abs_node_path(), change)
-            try:
-                import check_task as ct
-                qid = str(ct.display_var(item, "qid"))
-                host = ct.display_var(item, "ECF_JOB_CMD")
-                line += ",%s,%s" % (host, qid)
-            except: pass
-            win.insert(line)
-
-try:
-    sys.path.append('/usr/local/apps/sms/lib/')
-    import cdp
-    NOCDP = 0
-except:
-    NOCDP = 1
-
-
-class ClientSMS(Client):
-    """ example of class derivation to connect another server-scheduler"""
-    init = 0
-
-    def __init__(self, host="localhost", port=31415, nick=None):
-        if NOCDP:
-            return
-        if not ClientSMS.init:
-            cdp.cdp_init([""], 0)
-            ClientSMS.init = 1
-        else:
-            pass
-        node = cdp.sms_node()
-        tree = cdp.sms_info_pointed(node)
-        cdp.sms_numbers(port, 0)
-        timeout = 60
-        passwd = "1"
-        user = get_username()
-
-        if DEBUG:
-            print("#MSG: login:", nick, host, port, user)
-        handle, rc = cdp.sms_client_login(host, user, passwd,
-                                          timeout, port, tree)
-        self.handle = handle
-        self.host = host
-        self.port = port
-        self.num = -1
-        self.nick = nick
-        if nick is None:
-            self.nick = "%s@%d" % (self.host, self.port)
-
-    def process_node(self, node, wins):
-        if node.type != cdp.NODE_TASK:
-            kid = node.kids
-            while kid:
-                self.process_node(kid, wins)
-                kid = kid.__next__
-        else:
-            for kind, win in list(wins.items()):
-                state = "%s" % ClientSMS.status(node)
-                if state != kind:
-                    continue
-                path = cdp.sms_node_full_name(node)
-                win.insert("%s:%s" % (self.nick, path))
-                if DEBUG:
-                    print(self.host, self.port, path, state)
-
-    def process(self, win):
-        rc = cdp.sms_client_news(self.handle, self.num)
-        if rc or self.num == -1:
-            Label.update()
-            state = cdp.sms_client_status2(self.handle, self.num)
-            cdp.sms_client_status(self.handle, state, self.num)
-
-            item = cdp.sms_status2node(state)
-            if not item:
-                return
-            self.process_node(item, win)
-            Label.update()
-            cdp.sms_node_free(item)
-
-    @classmethod
-    def status(cls, node):
-        s_status = {
-            -1: "unknown",
-            0: "unknown",
-            1: "suspended",
-            2: "complete",
-            3: "queued",
-            4: "submitted",
-            5: "active",
-            6: "aborted",
-            7: "shutdown",
-            8: "halted",
-            9: "unknown", }
-        return s_status[node.status]
-
-    def __exit__(self):
-        cdp.sms_client_logout(self.handle)
-        print("# logout from", self.nick)
-
-    def __delete__(self):
-        cdp.sms_client_logout(self.handle)
-        print("# logout from", self.nick)
-
-
-
-class Application(tki.Frame):
-    """ main """
-
-    def __init__(self, parent=None, client=None, queue=None):
-        if parent is None: parent = tki.Tk()
-        w, h = parent.winfo_screenwidth(), parent.winfo_screenheight()
-        tki.Frame.__init__(self, parent)
-        if client is None:
-            raise Exception("#ERR: please provide a client...\n./overview.py $ECF_HOST@$ECF_PORT")
-        elif type(client) in (set, tuple):
-            self.__clients = client
-        else:
-            self.__clients = [client]
-        self.__queue = queue
-        # width = 640;         height = 780
-        width = w;         height = h
-        self.canvas = tki.Canvas(width=width, height=height, bg='black')
-        self.grid()
-        self.createWidgets()
-        self.canvas.after(50, self.check_queue)
-
-        self.bind_all("<space>", self.update)
-        # self.bind_all("Control_q", self.quit)
-        # self.bind_all("Control_z", self.resize)
-        self.bind_all("<Control-q>", self.quit)
-        self.bind_all("<Control-z>", self.resize)
-
-    def resize(self, event=None): print("New size is: {}x{}".format(event.width, event.height))
-
-    def quit(self, event=None):
-        print("quit...")
-        self.destroy()
-        # global running; running = [ False, ]
-        # sys.exit(0)
-
-    def createWidgets(self):
-        global root
-        root = self
-        rowx = 1
-        var = tki.StringVar(self)
-        glob = Label(root)
-        # glob = Label(var)
-        self.__menuBar = MenuBar(root)
-        self.__menuBar.grid(row=0, column=0, sticky=tki.W)
-        self.label = tki.Label(root, textvariable=var) # Label.inst)
-        self.label.grid(row=0, column=2, sticky=tki.E)
-        self.__wins = dict()
-        rowx += 1
-        colx = 0
-        kinds = ("active", "aborted", "submitted")
-        for kind in kinds:
-            self.__wins[kind] = TaskList(root, kind)
-            self.__wins[kind].grid(row=rowx, column=colx,
-                                   sticky=tki.S + tki.E + tki.W)
-            colx += 1
-        self.update()
-
-    def check_queue(self):
-        try:
-            self.__queue.get(block=False)
-        except queue.Empty:
-            pass
-        else:
-            self.update()
-        self.canvas.after(50, self.check_queue)
-
-    def update(self, event=None):
-        self.label.update()
-        for kind, win in list(self.__wins.items()):
-            win.clear()
-        for client in self.__clients:
-            if type(client) == list:
-                for clt in client:
-                    clt.process(self.__wins)
-            else:
-                client.process(self.__wins)
-
-
-def get_username(): return pwd.getpwuid(os.getuid())[0]
-
-
-def get_uid(): return pwd.getpwnam(get_username()).pw_uid
-
-
-if __name__ == '__main__':
-    try:
-        port = 1500 + int(get_uid())
-    except:
-        port = 31415
-
-    if len(sys.argv) > 1:
-        clients = []
-        for num in range(1, len(sys.argv)):            
-            sep = ','
-            arg = sys.argv[num]
-            if sep in arg:
-                for one in arg.split(sep):
-                    client = Client(one)
-            else:
-                client = Client(arg)
-            clients.append(client)
-    else: 
-        one = "localhost%d" % port
-        print("# using", one)
-        clients = [Client(one), ]
-
-    queue = queue.Queue()
-    app = Application(client=clients, queue=queue)
-    app.master.title(PROGRAM_NAME)
-    app.columnconfigure(0, weight=1)
-    app.rowconfigure(0, weight=1)
-    PaceKeeper(app, queue)
-    app.mainloop()
-
-"""
-python ./overview.py localhost@31415,
-"""
diff -pruN 5.12.4-1/Pyext/samples/printdefs.py 5.13.0-1/Pyext/samples/printdefs.py
--- 5.12.4-1/Pyext/samples/printdefs.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/printdefs.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,180 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-import ecflow
-import argparse # for argument parsing  
-import sys   
-
-class Indentor:
-    """This class manages indentation, 
-    It is used to correctly indent the definition node tree hierarchy
-    """
-    _index = 0
-    def __init__(self):
-        Indentor._index += 1
-    def __del__(self):
-        Indentor._index -= 1
-    @classmethod
-    def indent(cls):
-        for i in range(Indentor._index):
-            print(' ', end=' ')
-     
-class DefsTraverser:
-    """Traverse the ecflow.Defs definition and writes to standard out.
-    
-    Ecflow has the following hierarchy::
-       Task   --> Submittable   -->Node
-       Family --> NodeContainer -->Node
-       Suite  --> NodeContainer -->Node
-    
-    This demonstrates that all nodes in the node tree and all attributes are accessible.
-    Additionally the state data is also accessible. This class will write state data as
-    comments. If the definition was returned from the server, it allows access to latest 
-    snapshot of the state data held in the server. 
-    """
-    def __init__(self,defs):
-        assert (isinstance(defs,ecflow.Defs)),"Expected ecflow.Defs as first argument"
-        self.__defs = defs
-        
-    def do_print(self):
-        for extern in self.__defs.externs:
-            self.__println("extern " + extern)
-        for suite in self.__defs.suites:
-            self.__print("suite ")
-            self.__print_node(suite)
-            clock = suite.get_clock()
-            if clock:
-                indent = Indentor()
-                self.__println(str(clock))
-                del indent
-            self.__print_nc(suite)
-            self.__println("endsuite")  
- 
-    def __print_nc(self,node_container):
-        indent = Indentor()
-        for node in node_container.nodes:
-            if isinstance(node, ecflow.Task):
-                self.__print("task ")
-                self.__print_node(node)
-                self.__print_alias(node)
-            else: 
-                self.__print("family ")
-                self.__print_node(node)
-                self.__print_nc(node)
-                self.__println("endfamily")
-        del indent
-
-    def __print_alias(self,task):
-       indent = Indentor()
-       for alias in task.nodes:
-           self.__print("alias ")
-           self.__print_node(alias)
-           self.__println("endalias")
-       del indent
-
-    def __print_node(self,node):
-        print(node.name() + " # state:" + str(node.get_state())) 
-        
-        indent = Indentor()
-        defStatus = node.get_defstatus()
-        if defStatus != ecflow.DState.queued: 
-            self.__println("defstatus " + str(defStatus))
-            
-        autocancel = node.get_autocancel()
-        if autocancel: self.__println(str(autocancel))
-        
-        repeat = node.get_repeat()
-        if not repeat.empty(): self.__println(str(repeat)  + " # value: " + str(repeat.value()))
-    
-        late = node.get_late()
-        if late: self.__println(str(late) + " # is_late: " + str(late.is_late()))
-
-        complete_expr = node.get_complete()
-        if complete_expr:
-            for part_expr in complete_expr.parts:
-                trig = "complete "
-                if part_expr.and_expr(): trig = trig + "-a "
-                if part_expr.or_expr():  trig = trig + "-o "
-                self.__print(trig)
-                print(part_expr.get_expression())
-        trigger_expr = node.get_trigger()
-        if trigger_expr:
-            for part_expr in trigger_expr.parts:
-                trig = "trigger "
-                if part_expr.and_expr(): trig = trig + "-a "
-                if part_expr.or_expr():  trig = trig + "-o "
-                self.__print(trig)
-                print(part_expr.get_expression()) 
-                
-        for var in node.variables:    self.__println("edit " + var.name() + " '" + var.value() + "'")
-        for meter in node.meters:     self.__println(str(meter) + " # value: " + str(meter.value()))
-        for event in node.events:     self.__println(str(event) + " # value: " + str(event.value()))
-        for label in node.labels:     self.__println(str(label) + " # value: " + label.new_value())
-        for limit in node.limits:     self.__println(str(limit) + " # value: " + str(limit.value()))
-        for inlimit in node.inlimits: self.__println(str(inlimit))
-        for the_time in node.times:   self.__println(str(the_time))
-        for today in node.todays:     self.__println(str(today))   
-        for date in node.dates:       self.__println(str(date))  
-        for day in node.days:         self.__println(str(day))   
-        for cron in node.crons:       self.__println(str(cron))    
-        for verify in node.verifies:  self.__println(str(verify))
-        for zombie in node.zombies:   self.__println(str(zombie))
-        for queue in node.queues:     self.__println(str(queue))
-        
-        del indent
-
-    def __print(self,the_string):
-        Indentor.indent()
-        print(the_string, end=' ')
-
-    def __println(self,the_string):
-        Indentor.indent()
-        print(the_string)
- 
-if __name__ == "__main__":
-    
-    DESC = """Will list all the nodes and attributes in the definition
-              Usage:
-                Example1: List all the states
-                   printdefs.py --host cca --port 4141  
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--host', default="localhost",   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default="3141",   
-                        help="The port on the host, defaults to 3141")
-    ARGS = PARSER.parse_args()
-    #print ARGS    
-    
-    # ===========================================================================
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    try:
-        CL.ping() 
-
-        # get the incremental changes, and merge with defs stored on the Client 
-        CL.sync_local()
-        
-        # check to see if definition exists in the server
-        defs = CL.get_defs()
-        if len(defs) == 0 :
-            print("No suites found, exiting...")
-            sys.exit(0) 
-            
-        # print defs;
-        defs_traverser = DefsTraverser(defs)
-        defs_traverser.do_print()
-
-    except RuntimeError as ex:
-        print("Error: " + str(ex))
-        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/Pyext/samples/pyflow_example.py 5.13.0-1/Pyext/samples/pyflow_example.py
--- 5.12.4-1/Pyext/samples/pyflow_example.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/pyflow_example.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-#pyflow Method
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-#pyflow is a pure python module on top of ecflow native API ;
-# it is proposed to facilitate suites definitions. 
-# It is not yet provided in default standard location. 
-# It can be used, adding this one line to the definition script.
-
-import sys; sys.path.append("/home/ma/emos/def/pyflow")
-
-# Enter the following python code into a file i.e. test.py :
-
-#!/usr/bin/env python2.7
-import os
-from pyflow import (Suite, Family, Task, Variable)
-   
-print("Creating suite definition")   
-with Suite("test" ) as suite: 
- ECF_HOME = os.path.join(os.getenv("HOME"),  "course") # python vriable
- Variable("ECF_HOME", ECF_HOME)  # suite variable
- Task("t1")
-print(suite.ecflow_definition()) 
-
-#Then run as a python script:
-
-
-#pyflow
-#Using pyflow, header files are generated and placed in the expected location (ECF_INCLUDE) when the suite is deployed:
-suite.deploy_suite()
diff -pruN 5.12.4-1/Pyext/samples/query/query.py 5.13.0-1/Pyext/samples/query/query.py
--- 5.12.4-1/Pyext/samples/query/query.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/query/query.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,50 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-import ecflow
-import argparse # for argument parsing  
-import sys  
-import os
-    
-if __name__ == "__main__":
-    DESC = """query node state
-              Usage:
-                   query.py --host cca --port 4141 --path /ecflow/regenerate
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--host', default=os.getenv("ECF_HOST","localhost"),   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default=os.getenv("ECF_PORT","3141"),   
-                        help="The port on the host, defaults to 3141")
-    PARSER.add_argument('--path', default="/",   
-                        help="The path to the node. i.e /suite/family/task")
-    ARGS = PARSER.parse_args()
-    
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    try:
-        CL.sync_local()
-        defs = CL.get_defs()        
-        if len(defs) == 0 :
-            print("No suites found, exiting...")
-            sys.exit(0) 
-        if ARGS.path == "/":
-            print(defs.get_state())
-        else:
-            node = defs.find_abs_node(ARGS.path)
-            if node is None:  
-                print("No node found at path " + ARGS.path)
-            else:
-                print(node.get_state())
-    except RuntimeError as ex:
-        print("Error: " + str(ex))
-        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/Pyext/samples/resume.py 5.13.0-1/Pyext/samples/resume.py
--- 5.12.4-1/Pyext/samples/resume.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/resume.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,81 +0,0 @@
-#!/usr/bin/env python2.7
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-import ecflow
-import argparse # for argument parsing     
-import sys
-
-if __name__ == "__main__":
-    
-    DESC = """Will resume any suspended 'node' who name matches input
-              Usage:
-                Example1: resume all suspended node whose name matches 'fred' for suite grib_api
-                   resume.py --host cca --port 4141 --suite grib_api --name fred
-            """    
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--host', default="localhost",   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default="3141",   
-                        help="The port on the host, defaults to 3141")
-    PARSER.add_argument('--suite',   
-                        help="The name of the suite")
-    PARSER.add_argument('--name', default="install",   
-                        help="The name of the node")
-    ARGS = PARSER.parse_args()
-    print(ARGS)    
-     
-    # ===========================================================================
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    try:
-        CL.ping() 
-
-        # get the incremental changes, and merge with defs stored on the Client 
-        CL.sync_local()
-        
-        # check to see if definition exists in the server
-        defs = CL.get_defs()
-        if len(defs) == 0 :
-            print("No suites found, exiting...")
-            sys.exit(0) 
-         
-        paths_list = []
-        node_vec = defs.get_all_nodes()
-        for node in node_vec:
-            if node.name() != ARGS.name: continue
-            if node.get_dstate() != ecflow.DState.suspended: continue
-
-            path = node.get_abs_node_path()
-            paths = path.split('/')
-            if paths[1] == ARGS.suite:
-                paths_list.append(path) 
-                
-        if len(paths_list) > 0:
-            CL.resume(paths_list)
-
-#        # requires ecflow >= 4.0.8
-#         suite = defs.find_suite(ARGS.suite)
-#         if suite is not None:
-#             paths_list = []
-#             node_vec = suite.get_all_nodes()
-#             for node in node_vec:
-#                 if node.name() == ARGS.name and node.get_dstate() == DState.SUSPENDED:
-#                     paths_list.append(node.get_abs_node_path())
-# 
-#             print paths_list
-#             if len(paths_list) > 0:
-#                  CL.resume(paths_list)
-        
-    except RuntimeError as ex:
-        print("Error: " + str(ex))
-        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/Pyext/samples/run_batches_with_delay.py 5.13.0-1/Pyext/samples/run_batches_with_delay.py
--- 5.12.4-1/Pyext/samples/run_batches_with_delay.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/run_batches_with_delay.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,116 +0,0 @@
-#!/usr/bin/env python3.6
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import ecflow
-import os       # for getenv
-import sys
-import shutil   # used to remove directory tree
-import argparse # for argument parsing     
-
-def sync_local(ci):
-    ci.sync_local()
-    return ci.get_defs() 
-
-def get_tasks_to_run(defs,paths):
-    print("Collating tasks to run in batch")
-    node_path_list = []
-    for path in paths:
-        node = defs.find_abs_node(path)
-        if not node:
-            print("Could not find node",path,"in the definition")
-            continue
-        if isinstance(node,ecflow.Task):
-            node_path_list.append(node.get_abs_node_path())
-        elif isinstance(node,ecflow.NodeContainer):
-            node_vec = node.get_all_nodes()
-            for n in node_vec:
-                if isinstance(n,ecflow.Task):
-                    node_path_list.append(n.get_abs_node_path())
-             
-    uniqueList = []
-    for path in node_path_list:
-        if path not in uniqueList:
-            uniqueList.append(path)
-            print(" found task",path)
-           
-    return uniqueList 
-    
-def chunks(list_to_break, chunk_size):
-    for i in range(0, len(list_to_break), chunk_size):
-        yield list_to_break[i:i + chunk_size]
-        
-def run_chunk(ci,list_of_task_paths):
-    defs = sync_local(ci)
-    CL.suspend(list_of_task_paths);
-
-
-if __name__ == "__main__":
-    
-    DESC = """ 
-            example:
-                python3 Pyext/samples/run_batches_with_delay.py -h polonius -p 4141 -b 4 -s 4 -n "/ecflow/cron /limit_basic"
-                The list of paths can be obtained from the GUI, using:
-                sh $WK/Pyext/samples/run_batches_with_delay.sh -h %ECF_HOST% -p %ECF_PORT% -b 10 -s 2 -n '<full_name>'
-            """    
-            
-    print("####################################################################")
-    print("Running ecflow version " + ecflow.Client().version()  + " debug build(" + str(ecflow.debug_build()) +")")
-    if 'PYTHONPATH' in os.environ:
-        print("PYTHONPATH: " + str(os.environ['PYTHONPATH'].split(os.pathsep)))
-    print("sys.path:   " + str(sys.path))
-    print("####################################################################")
- 
-    default_port = "3141"
-    if "ECF_PORT" in os.environ:
-         default_port = os.environ["ECF_PORT"]
- 
-    default_host = "localhost"
-    if "ECF_HOST" in os.environ:
-        default_host  = os.environ["ECF_HOST"]
-
-    PARSER = argparse.ArgumentParser(description=DESC,  
-                                     formatter_class=argparse.RawDescriptionHelpFormatter)
-    PARSER.add_argument('--host', default=default_host,   
-                        help="The name of the host machine, defaults to 'localhost'")
-    PARSER.add_argument('--port', default=default_port,   
-                        help="The port on the host, defaults to 3141")
-    PARSER.add_argument('--batch_size', default=10, type=int,
-                        help="The number of jobs to submit in batch")
-    PARSER.add_argument('--sleep_between_batch', default=5, type=int,  
-                        help="The number of seconds to sleep between the next batch")
-    PARSER.add_argument('--paths',
-                        help="This list of node path to execute. These could be suites/families.")
-    ARGS = PARSER.parse_args()
-    print(ARGS )  
-    
-    paths = ARGS.paths.split()
-    print(paths)
-    
-    # ===========================================================================
-    CL = ecflow.Client(ARGS.host, ARGS.port)
-    try:
-        print("check server " + ARGS.host + ":" + ARGS.port + " is running")
-        CL.ping() 
-        print("Server is running.")
-         
-        defs = sync_local(CL)
-        node_path_list = get_tasks_to_run(defs,paths)
-        
-        list_of_chunks = (list(chunks(node_path_list,ARGS.batch_size)))
-        for chunk in list_of_chunks:
-            print(chunk)
-            run_chunk(CL,chunk)
-        
-    except RuntimeError as ex:
-        print("Error: " + str(ex))
diff -pruN 5.12.4-1/Pyext/samples/run_batches_with_delay.sh 5.13.0-1/Pyext/samples/run_batches_with_delay.sh
--- 5.12.4-1/Pyext/samples/run_batches_with_delay.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/samples/run_batches_with_delay.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,60 +0,0 @@
-#!/bin/sh
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# Example of running a shell command from the GUI.
-# Use the following in ecflowUI:
-# sh $WK/Pyext/samples/run_batches_with_delay.sh -h %ECF_HOST% -p %ECF_PORT% -b 10 -s 2 -n '<full_name>'
-#    - sh at the front is required
-#    - the tick quotes on <full_name> are required
-#
-
-echo "test.sh $*"
-#exit 0
-
-function usage() {
-   echo "Usage: -h <host> -p <port> -b <batch_size> -s <sleep_between_batch> -n <node paths>"
-   echo "       -h        ECF_HOST"
-   echo "       -p        ECF_PORT"
-   echo "       -b        batch size. the number of job to be submitted in parallel"
-   echo "       -s        number of seconds to sleep between each batch"
-   echo "       -n        list of node paths."
-}
-
-host=
-port=
-batch_size=
-sleep_between_batch=
-
-while getopts ":h:p:b:s:n:" opt
-   do
-     case "${opt}" in
-        h ) host=$OPTARG;;
-        p ) port=$OPTARG;;
-        b ) batch_size=$OPTARG;;
-	    s ) sleep_between_batch=$OPTARG;;
-        n ) node_paths+=("$OPTARG");;
-     esac
-done
-
-echo "host:$host"
-echo "port:$port"
-echo "batch_size=$batch_size"
-echo "sleep_between_batch=$sleep_between_batch"
-echo "paths='${node_paths[@]}'"
- 
-for path in $node_paths; do
-   echo $path
-done   
-
-python3 /var/tmp/ma0/workspace/ecflow/Pyext/samples/run_batches_with_delay.py --host $host --port $port --batch_size $batch_size --sleep_between_batch $sleep_between_batch --paths "$node_paths"
diff -pruN 5.12.4-1/Pyext/script.py 5.13.0-1/Pyext/script.py
--- 5.12.4-1/Pyext/script.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/script.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-#
-#
-print 'Hello World !'
-number = 42
diff -pruN 5.12.4-1/Pyext/setup.py 5.13.0-1/Pyext/setup.py
--- 5.12.4-1/Pyext/setup.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/setup.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,108 +0,0 @@
-#!/usr/bin/env python
-from distutils.core import setup, Extension
-import os
-import sys
-import glob
-
-# ========================================================================
-# Usage:
-#   cd $WK; cd ecbuild/release/; sh -x ../../cmake.sh release; make ; make install
-#   calling 'sh -x ../../cmake.sh release' will generate setup.py from setup.py.in
-# Issues:
-#   Cannot test cmake install, since it will always install to 
-#     /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
-#
-# To test install manually, we can:
-#   python3 setup.py --help-commands # help
-#
-#   cd $WK/Pyext
-#   rm -rf build/                     # for a clean build
-#   python setup.py build_ext         # build C/C++ extensions (compile/link to build directory)
-#   python setup.py install --home=~
-#
-# See: http://docs.python.org/2/distutils/apiref.html?highlight=extension#distutils.core.Extension
-#
-# ==========================================================================
-# Permissions: The permission of configured file are wrong: 2 choices
-# o Make sure origin file, has the right permissions
-# o Copy file to different directory, and change the permissions
-#   since file(COPY) does rename files
-#   configure_file(setup.py.in /tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/CMakeFiles/setup.py)
-#       now copy the temporary into the final destination, setting the permissions
-#   file(COPY /tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/CMakeFiles/setup.py
-#     DESTINATION /tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox
-#     FILE_PERMISSIONS OWNER_READ OWNER_WRITE OWNER_EXECUTE GROUP_READ
-#     GROUP_EXECUTE WORLD_READ WORLD_EXECUTE)
-# ============================================================================
-        
-#=============================================================================
-# define the directories to search for include files
-# to get this to work, you will need to include the path
-# to your boost installation and  ecflow includes
-boost_root=os.getenv("BOOST_ROOT") 
-include_dirs = [ "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../cereal/include",
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../ACore/src", 
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../ANattr/src", 
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../ANode/parser/src",
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../ANode/src",
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../Base/src",
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../Base/src/cts",
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../Base/src/stc",
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../CSim/src", 
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/../Client/src",
-                 "/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/src",
-                 boost_root,
-               ]
-
-# define the library directories to include any extra libraries that may be needed.
-# Give preference to release libs   
-boost_lib_dir = boost_root + "/stage/lib/"
-library_dirs = ['/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/ACore',
-                '/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/ANattr/',
-                '/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/ANode/',
-                '/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/Base/', 
-                '/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/CSim/', 
-                '/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow-build-sandbox/Client/', 
-                boost_lib_dir  
-               ]
-
-# define the libraries to link with this includes the boost lib
-libraries = [ 'core' , 'nodeattr', 'node', 'base', 'libsimu', 'libclient',
-              'boost_system',
-              'boost_filesystem',
-              'boost_program_options',
-              'boost_date_time', 
-              'boost_python36' ]
-
-# Using gcc-4.8 with boost 1.53 linux requires these flags
-extra_compile_args = ['-ftemplate-depth-512','-Wno-unused-variable','-Wno-deprecated-declarations','-Wno-unused-local-typedefs','-Wno-maybe-uninitialized' ]
-extra_link_args = []
-
-# create the extension and add it to the python distribution
-# o glob.glob(os.path.join('src', '*.cpp'))
-#   This expand the list of cpp files that need to be compiled
-#
-# The configuation below installs to:
-#   o /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
-#     when, "python setup.py install" is used:
-#   lib/python2.7/site-packages/ecflow/ecflow.so
-#                                     __init__.py               
-setup( name='ecflow', 
-       version='5.12.4', 
-       author      = 'ECMWF',
-       description = """ecflow Python interface""",
-       packages = [ 'ecflow' ],
-       url = 'https://confluence.ecmwf.int/display/ECFLOW/ecflow+home',
-       license = 'Apache',
-       package_dir={'ecflow': '/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/ecflow'},
-       ext_modules=[ Extension( 
-                              'ecflow.ecflow', 
-                              glob.glob(os.path.join('/tmp/ecflow-packaging-stage.IcxVbtmu3s/ecflow/Pyext/src', '*.cpp')), 
-                              include_dirs=include_dirs, 
-                              library_dirs=library_dirs, 
-                              libraries=libraries,
-                              extra_compile_args=extra_compile_args,
-                              extra_link_args=extra_link_args
-                              )
-                    ],
-   )
diff -pruN 5.12.4-1/Pyext/setup.py.in 5.13.0-1/Pyext/setup.py.in
--- 5.12.4-1/Pyext/setup.py.in	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/setup.py.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,108 +0,0 @@
-#!/usr/bin/env python
-from distutils.core import setup, Extension
-import os
-import sys
-import glob
-
-# ========================================================================
-# Usage:
-#   cd $WK; cd ecbuild/release/; sh -x ../../cmake.sh release; make ; make install
-#   calling 'sh -x ../../cmake.sh release' will generate setup.py from setup.py.in
-# Issues:
-#   Cannot test cmake install, since it will always install to 
-#     /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
-#
-# To test install manually, we can:
-#   python3 setup.py --help-commands # help
-#
-#   cd $WK/Pyext
-#   rm -rf build/                     # for a clean build
-#   python setup.py build_ext         # build C/C++ extensions (compile/link to build directory)
-#   python setup.py install --home=~
-#
-# See: http://docs.python.org/2/distutils/apiref.html?highlight=extension#distutils.core.Extension
-#
-# ==========================================================================
-# Permissions: The permission of configured file are wrong: 2 choices
-# o Make sure origin file, has the right permissions
-# o Copy file to different directory, and change the permissions
-#   since file(COPY) does rename files
-#   configure_file(setup.py.in ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/setup.py)
-#       now copy the temporary into the final destination, setting the permissions
-#   file(COPY ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/setup.py
-#     DESTINATION ${CMAKE_BINARY_DIR}
-#     FILE_PERMISSIONS OWNER_READ OWNER_WRITE OWNER_EXECUTE GROUP_READ
-#     GROUP_EXECUTE WORLD_READ WORLD_EXECUTE)
-# ============================================================================
-        
-#=============================================================================
-# define the directories to search for include files
-# to get this to work, you will need to include the path
-# to your boost installation and  ecflow includes
-boost_root=os.getenv("BOOST_ROOT") 
-include_dirs = [ "@CMAKE_CURRENT_SOURCE_DIR@/../cereal/include",
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../ACore/src", 
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../ANattr/src", 
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../ANode/parser/src",
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../ANode/src",
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../Base/src",
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../Base/src/cts",
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../Base/src/stc",
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../CSim/src", 
-                 "@CMAKE_CURRENT_SOURCE_DIR@/../Client/src",
-                 "@CMAKE_CURRENT_SOURCE_DIR@/src",
-                 boost_root,
-               ]
-
-# define the library directories to include any extra libraries that may be needed.
-# Give preference to release libs   
-boost_lib_dir = boost_root + "/stage/lib/"
-library_dirs = ['@CMAKE_BINARY_DIR@/ACore',
-                '@CMAKE_BINARY_DIR@/ANattr/',
-                '@CMAKE_BINARY_DIR@/ANode/',
-                '@CMAKE_BINARY_DIR@/Base/', 
-                '@CMAKE_BINARY_DIR@/CSim/', 
-                '@CMAKE_BINARY_DIR@/Client/', 
-                boost_lib_dir  
-               ]
-
-# define the libraries to link with this includes the boost lib
-libraries = [ 'core' , 'nodeattr', 'node', 'base', 'libsimu', 'libclient',
-              'boost_system',
-              'boost_filesystem',
-              'boost_program_options',
-              'boost_date_time', 
-              'boost_python36' ]
-
-# Using gcc-4.8 with boost 1.53 linux requires these flags
-extra_compile_args = ['-ftemplate-depth-512','-Wno-unused-variable','-Wno-deprecated-declarations','-Wno-unused-local-typedefs','-Wno-maybe-uninitialized' ]
-extra_link_args = []
-
-# create the extension and add it to the python distribution
-# o glob.glob(os.path.join('src', '*.cpp'))
-#   This expand the list of cpp files that need to be compiled
-#
-# The configuation below installs to:
-#   o /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
-#     when, "python setup.py install" is used:
-#   lib/python2.7/site-packages/ecflow/ecflow.so
-#                                     __init__.py               
-setup( name='ecflow', 
-       version='@ecflow_VERSION@', 
-       author      = 'ECMWF',
-       description = """ecflow Python interface""",
-       packages = [ 'ecflow' ],
-       url = 'https://confluence.ecmwf.int/display/ECFLOW/ecflow+home',
-       license = 'Apache',
-       package_dir={'ecflow': '@CMAKE_CURRENT_SOURCE_DIR@/ecflow'},
-       ext_modules=[ Extension( 
-                              'ecflow.ecflow', 
-                              glob.glob(os.path.join('@CMAKE_CURRENT_SOURCE_DIR@/src', '*.cpp')), 
-                              include_dirs=include_dirs, 
-                              library_dirs=library_dirs, 
-                              libraries=libraries,
-                              extra_compile_args=extra_compile_args,
-                              extra_link_args=extra_link_args
-                              )
-                    ],
-   )
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/BoostPythonUtil.cpp 5.13.0-1/Pyext/src/ecflow/python/BoostPythonUtil.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/BoostPythonUtil.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/BoostPythonUtil.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,86 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/BoostPythonUtil.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/core/Converter.hpp"
-
-void BoostPythonUtil::list_to_int_vec(const boost::python::list& list, std::vector<int>& int_vec) {
-    auto the_list_size = len(list);
-    int_vec.reserve(the_list_size);
-    for (ssize_t i = 0; i < the_list_size; ++i) {
-        int_vec.push_back(boost::python::extract<int>(list[i]));
-    }
-}
-
-void BoostPythonUtil::list_to_str_vec(const boost::python::list& list, std::vector<std::string>& vec) {
-    auto the_list_size = len(list);
-    vec.reserve(the_list_size);
-    for (ssize_t i = 0; i < the_list_size; ++i) {
-        vec.push_back(boost::python::extract<std::string>(list[i]));
-    }
-}
-
-void BoostPythonUtil::list_to_str_vec(const boost::python::list& list, std::vector<Variable>& vec) {
-    auto the_list_size = len(list);
-    vec.reserve(the_list_size);
-    for (ssize_t i = 0; i < the_list_size; ++i) {
-        vec.push_back(boost::python::extract<Variable>(list[i]));
-    }
-}
-
-void BoostPythonUtil::dict_to_str_vec(const boost::python::dict& dict,
-                                      std::vector<std::pair<std::string, std::string>>& str_pair_vec) {
-    boost::python::list keys = dict.keys();
-    const auto no_of_keys    = len(keys);
-    str_pair_vec.reserve(no_of_keys);
-
-    for (ssize_t i = 0; i < no_of_keys; ++i) {
-
-        std::string second;
-        std::string first = boost::python::extract<std::string>(keys[i]);
-        if (boost::python::extract<std::string>(dict[keys[i]]).check()) {
-            second = boost::python::extract<std::string>(dict[keys[i]]);
-        }
-        else if (boost::python::extract<int>(dict[keys[i]]).check()) {
-            int the_int = boost::python::extract<int>(dict[keys[i]]);
-            second      = ecf::convert_to<std::string>(the_int);
-        }
-        else
-            throw std::runtime_error("BoostPythonUtil::dict_to_str_vec: type not convertible to string or integer");
-        str_pair_vec.emplace_back(first, second);
-    }
-}
-
-void BoostPythonUtil::dict_to_str_vec(const boost::python::dict& dict, std::vector<Variable>& vec) {
-    boost::python::list keys = dict.keys();
-    const auto no_of_keys    = len(keys);
-    vec.reserve(no_of_keys);
-
-    for (ssize_t i = 0; i < no_of_keys; ++i) {
-
-        std::string second;
-        std::string first = boost::python::extract<std::string>(keys[i]);
-        if (boost::python::extract<std::string>(dict[keys[i]]).check()) {
-            second = boost::python::extract<std::string>(dict[keys[i]]);
-        }
-        else if (boost::python::extract<int>(dict[keys[i]]).check()) {
-            int the_int = boost::python::extract<int>(dict[keys[i]]);
-            second      = ecf::convert_to<std::string>(the_int);
-        }
-        else
-            throw std::runtime_error("BoostPythonUtil::dict_to_str_vec: type not convertible to string or integer");
-
-        vec.emplace_back(first, second);
-    }
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/BoostPythonUtil.hpp 5.13.0-1/Pyext/src/ecflow/python/BoostPythonUtil.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/BoostPythonUtil.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/BoostPythonUtil.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_BoostPythonUtil_HPP
-#define ecflow_python_BoostPythonUtil_HPP
-
-#include <vector>
-
-#include <boost/python.hpp> // IWYU pragma: keep
-
-class Variable;
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-
-class BoostPythonUtil {
-public:
-    BoostPythonUtil()                                  = delete;
-    BoostPythonUtil(const BoostPythonUtil&)            = delete;
-    BoostPythonUtil& operator=(const BoostPythonUtil&) = delete;
-
-    /// Convert python list to a vector of integers. raises a type error if integer extraction fails
-    static void list_to_int_vec(const boost::python::list& list, std::vector<int>& int_vec);
-    static void list_to_str_vec(const boost::python::list& list, std::vector<std::string>& int_vec);
-    static void list_to_str_vec(const boost::python::list& list, std::vector<Variable>& vec);
-    static void dict_to_str_vec(const boost::python::dict& dict,
-                                std::vector<std::pair<std::string, std::string>>& str_pair);
-    static void dict_to_str_vec(const boost::python::dict& dict, std::vector<Variable>& vec);
-};
-
-template <typename T>
-const T copyObject(const T& v) {
-    return v;
-}
-
-#endif /* ecflow_python_BoostPythonUtil_HPP */
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ClientDoc.cpp 5.13.0-1/Pyext/src/ecflow/python/ClientDoc.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ClientDoc.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ClientDoc.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1586 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/ClientDoc.hpp"
-
-const char* ClientDoc::class_client() {
-    return "Class client provides an interface to communicate with the `ecflow_server`_.:\n\n"
-           ".. code-block:: shell\n\n"
-           "   Client(\n"
-           "      string host, # The server name. Cannot be empty.\n"
-           "      string port  # The port on the server, must be unique to the server\n"
-           "   )\n\n"
-           "   Client(\n"
-           "      string host, # The server name. Cannot be empty.\n"
-           "      int port     # The port on the server, must be unique to the server\n"
-           "   )\n\n"
-           "   Client(\n"
-           "      string host_port, # Expects <host>:<port> || <host>@<port>\n"
-           "   )\n\n"
-           "The client reads in the following environment variables.\n"
-           "For child commands,(i.e these are commands called in the .ecf/jobs files), these variables are used.\n"
-           "For the python interface these environment variable are not really applicable but documented for "
-           "completeness:\n\n"
-           "* ECF_NAME <string> : Full path name to the task\n"
-           "* ECF_PASS <string> : The jobs password, allocated by server, then used by server to authenticate client "
-           "request\n"
-           "* ECF_TRYNO <int>   : The number of times the job has run. Used in file name generation. Set to 1 by "
-           "begin() and re-queue commands.\n"
-           "* ECF_TIMEOUT <int> : Max time in seconds for client to deliver message to main server\n"
-           "* ECF_HOSTFILE <string> : File that lists alternate hosts to try, if connection to main host fails\n"
-           "* ECF_DENIED <any> : Provides a way for child to exit with an error, if server denies connection. Avoids "
-           "24hr wait. Note: when you have hundreds of tasks, using this approach requires a lot of manual "
-           "intervention to determine job status\n"
-           "* NO_ECF <any> : If set exit's immediately with success. Used to test jobs without communicating with "
-           "server\n\n"
-           "The following environment variables are used by the python interface and child commands\n\n"
-           "* ECF_HOST  <string>   : The host name of the main server. defaults to 'localhost'\n"
-           "* ECF_PORT  <int>      : The TCP/IP port to call on the server. Must be unique to a server\n\n"
-           "The ECF_HOST and ECF_PORT can be overridden by using the Constructor or set_host_port() member function.\n"
-           "For optimal usage it is best to reuse the same Client rather than recreating for each client server "
-           "interaction\n"
-           "By default the Client interface will throw exceptions for error's.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client('localhost:3150')   # for errors will throw RuntimeError\n"
-           "       ci.terminate_server()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n\n";
-}
-
-const char* ClientDoc::set_host_port() {
-    return "Explicitly set the host and port to be used by the client, overriding the default host name (localhost) "
-           "and port (3141) and the environment variables: ECF_HOST and ECF_PORT.\n\n"
-           ".. code-block:: shell\n\n"
-           "   set_host_port(\n"
-           "      string host, # The server name. Cannot be empty.\n"
-           "      string port  # The port on the server, must be unique to the server\n"
-           "   )\n\n"
-           "   set_host_port(\n"
-           "      string host, # The server name. Cannot be empty.\n"
-           "      int port     # The port on the server, must be unique to the server\n"
-           "   )\n\n"
-           "   set_host_port(\n"
-           "      string host_port, # Expects <host>:<port> or <host>@<port>\n"
-           "   )\n\n"
-           "Exceptions:\n\n"
-           "- Raise a RuntimeError if the host or port is empty\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()\n"
-           "       ci.set_host_port('localhost','3150')\n"
-           "       ci.set_host_port('avi',3150)\n"
-           "       ci.set_host_port('avi:3150')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n\n";
-}
-
-const char* ClientDoc::set_retry_connection_period() {
-    return "Set the sleep period between connection attempts\n\n"
-           "Whenever there is a connection failure we wait a number of seconds before trying again.\n"
-           "i.e. to get round glitches in the network.\n"
-           "For the ping command this is hard wired as 1 second.\n"
-           "This wait between connection attempts can be configured here.\n"
-           "i.e This could be reduced to increase responsiveness.\n"
-           "Default: In debug this period is 1 second and in release mode 10 seconds.\n\n"
-           ".. code-block:: shell\n\n"
-           "   set_retry_connection_period(\n"
-           "      int period # must be an integer >= 0\n"
-           "   )\n\n"
-           "Exceptions:\n\n"
-           "- None\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   ci = Client()\n"
-           "   ci.set_connection_attempts(3)     # make 3 attempts for server connection\n"
-           "   ci.set_retry_connection_period(1) # wait 1 second between each attempt\n";
-}
-
-const char* ClientDoc::set_connection_attempts() {
-    return "Set the number of times to connect to `ecflow_server`_, in case of connection failures\n\n"
-           "The period between connection attempts is handled by Client.set_retry_connection_period().\n"
-           "If the network is unreliable the connection attempts can be be increased, likewise\n"
-           "when the network is stable this number could be reduced to one.\n"
-           "This can increase responsiveness and reduce latency.\n"
-           "Default value is set as 2.\n"
-           "Setting a value less than one is ignored, will default to 1 in this case::\n\n"
-           "   set_connection_attempts(\n"
-           "      int attempts # must be an integer >= 1\n"
-           "   )\n"
-           "\nExceptions:\n\n"
-           "- None\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   ci = Client()\n"
-           "   ci.set_connection_attempts(3)     # make 3 attempts for server connection\n"
-           "   ci.set_retry_connection_period(1) # wait 1 second between each attempt\n";
-}
-
-const char* ClientDoc::get_defs() {
-    return "Returns the `suite definition`_ stored on the Client.\n\n"
-           "Use :py:class:`ecflow.Client.sync_local()` to retrieve the definition from the server first.\n"
-           "The definition is *retained* in memory until the next call to sync_local().\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()         # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.sync_local()       # get the definition from the server and store on 'ci'\n"
-           "       print(ci.get_defs())  # print out definition stored in the client\n"
-           "       print(ci.get_defs())  # print again, this shows that defs is retained on ci\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::edit_script_edit() {
-    return "get script for Edit\n";
-}
-
-const char* ClientDoc::edit_script_preprocess() {
-    return "get script for Edit Preprocess\n";
-}
-
-const char* ClientDoc::edit_script_submit() {
-    return "submit script from Edit/Preprocess \n"
-           "to run as alias or not:\n\n"
-           ".. code-block:: python\n\n"
-           " ci = Client()\n"
-           " ci.edit_script_submit(path_to_task,\n"
-           "	                   used_variables, # array name=value\n"
-           "	                   file_contents,  # strings array\n"
-           "	                   alias, # bool False,\n"
-           "	                   run  # bool true\n"
-           "                      )\n";
-}
-
-const char* ClientDoc::get_log() {
-    return "Request the `ecflow_server`_ to return the log file contents as a string\n\n"
-           "Use with caution as the returned string could be several megabytes.\n"
-           "Only enabled in the debug build of ECF.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()          # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       print(ci.get_log(100)  # get the 100 last lines from server log file\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::new_log() {
-    return "Request the `ecflow_server`_ to use the path provided, as the new log file\n\n"
-           "The old log file is released.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()               # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.new_log('/path/log.log') # use '/path/log,log' as the new log file\n"
-           "                                   # To keep track of log file Can change ECF_LOG\n"
-           "       ci.alter('\','change','variable','ECF_LOG','/new/path.log')\n"
-           "       ci.new_log()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::clear_log() {
-    return "Request the `ecflow_server`_ to clear log file.\n\n"
-           "Log file will be empty after this call.\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.clear_log()   # log file is now empty\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::flush_log() {
-    return "Request the `ecflow_server`_ to flush and then close log file\n\n"
-           "It is best that the server is `shutdown`_ first, as log file will be reopened\n"
-           "whenever a command wishes to log any changes.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.flush_log()   # Log can now opened by external program\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::log_msg() {
-    return "";
-}
-
-const char* ClientDoc::restart_server() {
-    return "Restart the `ecflow_server`_\n\n"
-           "Start job scheduling, communication with jobs, and respond to all requests.\n"
-           "See `server states`_\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.restart_server()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-const char* ClientDoc::halt_server() {
-    return "Halt the `ecflow_server`_\n\n"
-           "Stop server communication with jobs, and new job scheduling, and stops check pointing.\n"
-           "See `server states`_\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.halt_server()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-const char* ClientDoc::shutdown_server() {
-    return "Shut down the `ecflow_server`_\n\n"
-           "Stop server from scheduling new jobs.\n"
-           "See `server states`_\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.shutdown_server()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::terminate_server() {
-    return "Terminate the `ecflow_server`_\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.terminate_server()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::wait_for_server_reply() {
-    return "Wait for a response from the `ecflow_server`_::\n\n"
-           "   void wait_for_server_reply(\n"
-           "      int time_out     : (default = 60) \n"
-           "   )\n\n"
-           "This is used to check if server has started. Typically for tests.\n"
-           "Returns true if server(ping) replies before time out, otherwise false\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "   if ci.wait_for_server_reply(30):\n"
-           "      print('Server is alive')\n"
-           "   else:\n"
-           "      print('Timed out after 30 second wait for server response.?')\n";
-}
-
-const char* ClientDoc::load_defs() {
-    return "Load a `suite definition`_ or checkpoint file given by the file_path argument into the "
-           "`ecflow_server`_\n::\n\n"
-           "   void load(\n"
-           "      string file_path     : path name to the definition file\n"
-           "      [(bool)force=False]  : If true overwrite suite of same name\n"
-           "      [(bool)print=False]  : print parsed defs to standard out\n"
-           "   )\n\n"
-           "By default throws a RuntimeError exception for errors.\n"
-           "If force is not used and `suite`_ of the same name already exists in the server,\n"
-           "then a error is thrown\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   defs_file = 'Hello.def' \n"
-           "   defs = Defs()\n"
-           "   suite = def.add_suite('s1')\n"
-           "   family = suite.add_family('f1')\n"
-           "   for i in [ '_1', '_2', '_3' ]:\n"
-           "      family.add_task( 't' + i )\n"
-           "   defs.save_as_defs(defs_file)  # write out in memory defs into the file 'Hello.def'\n"
-           "   ...\n"
-           "   try:\n"
-           "       ci = Client()       # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.load(defs_file)  # open and parse defs or checkpoint file, and load into server.\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::load() {
-    return "Load a in memory `suite definition`_ into the `ecflow_server`_\n::\n\n"
-           "   void load(\n"
-           "      Defs defs           : A in memory definition\n"
-           "      [(bool)force=False] : for true overwrite suite of same name\n"
-           "   )\n\n"
-           "If force is not used and `suite`_ already exists in the server, then a error is thrown.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   defs = Defs()\n"
-           "   suite = defs.add_suite('s1')\n"
-           "   family = suite.add_family('f1')\n"
-           "   for i in [ '_1', '_2', '_3' ]: \n"
-           "       family.add_task( Task( 't' + i) )\n"
-           "   ...\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.load(defs)    # Load in memory defs, into the server\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::get_server_defs() {
-    return "Get all suite Node tree's from the `ecflow_server`_.\n\n"
-           "The definition is *retained* in memory until the next call to get_server_defs().\n"
-           "This is important since get_server_defs() could return several megabytes of data.\n"
-           "Hence we only want to call it once, and then access it locally with get_defs().\n"
-           "If you need to access the server definition in a loop use :py:class:`ecflow.Client.sync_local` instead\n"
-           "since this is capable of returning incremental changes, and thus considerably\n"
-           "reducing the network load.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()         # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.get_server_defs()  # get the definition from the server and store on 'ci'\n"
-           "       print(ci.get_defs())  # print out definition stored in the client\n"
-           "       print(ci.get_defs())  # print again, this shows that defs is retained on ci\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::sync() {
-    return "Requests that `ecflow_server`_ returns the full definition or incremental change made and applies them to "
-           "the client Defs\n\n"
-           "When there is a very large definition, calling :py:class:`ecflow.Client.get_server_defs` each time can be "
-           "*very* expensive\n"
-           "both in terms of memory, speed, and network bandwidth. The alternative is to call\n"
-           "this function, which will get the incremental changes, and apply them local client `suite definition`_\n"
-           "effectively synchronising the client and server Defs.\n"
-           "If the period of time between two sync() calls is too long, then the full server definition\n"
-           "is returned and assigned to the client Defs.\n"
-           "We can determine if the changes were applied by calling in_sync() after the call to sync_local()::\n\n"
-           "   void sync_local();                     # The very first call, will get the full Defs.\n"
-           "\n\n"
-           "Exceptions:\n\n"
-           "- raise a RuntimeError if the delta change cannot be applied.\n"
-           "- this could happen if the client Defs bears no resemblance to server Defs\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                       # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.sync_local()                     # Very first call gets the full Defs\n"
-           "       client_defs = ci.get_defs()         # End user access to the returned Defs\n"
-           "       ... after a period of time\n"
-           "       ci.sync_local()                     # Subsequent calls to sync_local() users the local Defs to sync "
-           "incrementally\n"
-           "       if ci.in_sync():                    # returns true server changed and changes applied to client\n"
-           "          print('Client is now in sync with server')\n"
-           "       client_defs = ci.get_defs()         # End user access to the returned Defs\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n"
-           "\n"
-           "Calling sync_local() is considerably faster than calling get_server_defs() for large Definitions";
-}
-
-const char* ClientDoc::in_sync() {
-    return "Returns true if the definition on the client is in sync with the `ecflow_server`_\n\n"
-           ".. Warning:: Calling in_sync() is **only** valid after a call to sync_local().\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "      ci = Client()                       # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "      ci.sync_local()                     # very first call gets the full Defs\n"
-           "      client_defs = ci.get_defs()         # End user access to the returned Defs\n"
-           "      ... after a period of time\n"
-           "      ci.sync_local()                     # Subsequent calls to sync_local() users the local Defs to sync "
-           "incrementally\n"
-           "      if ci.in_sync():                    # returns true  changed and changes applied to client\n"
-           "         print('Client is now in sync with server')\n"
-           "      client_defs = ci.get_defs()         # End user access to the returned Defs\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::news() {
-    return "Query the `ecflow_server`_ to detect any changes.\n\n"
-           "This returns a simple bool, if there has been changes, the user should call "
-           ":py:class:`ecflow.Client.sync_local`.\n"
-           "This will bring the client in sync with changes in the server. If sync_local() is not called\n"
-           "then calling news_local() will always return true.\n"
-           "news_local() uses the definition stored on the client::\n\n"
-           "   bool news_local()\n"
-           "\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                  # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       if ci.news_local():            # has the server changed\n"
-           "          print('Server Changed')     # server changed bring client in sync with server\n"
-           "          ci.sync_local()             # get the full definition from the server if first time\n"
-           "                                      # otherwise apply incremental changes to Client definition,\n"
-           "                                      # bringing it in sync with the server definition\n"
-           "          print(ci.get_defs())        # print the synchronised definition. Should be same as server\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::changed_node_paths() {
-    return "After a call to sync_local() we can access the list of nodes that changed\n\n"
-           "The returned list consists of node paths. *IF* the list is empty assume that\n"
-           "whole definition changed. This should be expected after the first call to sync_local()\n"
-           "since that always retrieves the full definition from the server::\n\n"
-           "   void changed_node_paths()\n"
-           "\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                          # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       if ci.news_local():                    # has the server changed\n"
-           "          print('Server Changed')             # server changed bring client in sync with server\n"
-           "          ci.sync_local()                     # get the full definition from the server if first time\n"
-           "                                              # otherwise apply incremental changes to Client definition,\n"
-           "                                              # bringing it in sync with the server definition\n"
-           "          defs = ci.get_defs()                # get the updated/synchronised definition\n"
-           "          for path in ci.changed_node_paths:\n"
-           "              if path == '/':                 # path '/' represent change to server node/defs\n"
-           "                 print('defs changed')        # defs state change or user variables changed\n"
-           "              else:\n"
-           "                 node = defs.find_abs_node(path)\n"
-           "\n"
-           "         # if changed_node_paths is empty, then assume entire definition changed\n"
-           "         print(defs)                         # print the synchronised definition. Should be same as "
-           "server\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::checkpt() {
-    return "Request the `ecflow_server`_ `check point`_\\ s the definition held in the server immediately\n\n"
-           "This effectively saves the definition held in the server to disk,\n"
-           "in a platform independent manner. This is the default when no arguments are specified.\n"
-           "The saved file will include node state, passwords, etc.\n"
-           "The default file name is <host>.<port>.ecf.check and is saved in ECF_HOME directory.\n"
-           "The `check point`_ file name can be overridden via ECF_CHECK server environment variable.\n"
-           "The back up `check point`_ file name can be overridden via ECF_CHECKOLD server environment variable::\n\n"
-           "   void checkpt(\n"
-           "     [(CheckPt::Mode)mode=CheckPt.UNDEFINED]\n"
-           "                         : Must be one of [ NEVER, ON_TIME, ALWAYS, UNDEFINED ]\n"
-           "                           NEVER  :  Never check point the definition in the server\n"
-           "                           ON_TIME:  Turn on automatic check pointing at interval stored on server\n"
-           "                                     or with interval specified as the second argument\n"
-           "                           ALWAYS:   Check point at any change in node tree, *NOT* recommended for large "
-           "definitions\n"
-           "                           UNDEFINED:The default, which allows for immediate check pointing, or alarm "
-           "setting\n"
-           "     [(int)interval=120] : This specifies the interval in seconds when server should automatically check "
-           "pt.\n"
-           "                           This will only take effect if mode is on_time/CHECK_ON_TIME\n"
-           "                           Should ideally be a value greater than 60 seconds, default is 120 seconds\n"
-           "     [(int)alarm=30]     : Specifies check pt save alarm time. If saving the check pt takes longer than\n"
-           "                           the alarm time, then the late flag is set on the server.\n"
-           "                           This flag will need to be cleared manually.\n"
-           "   )\n\n"
-           ".. Note:: When the time taken to save the check pt is excessive, it can interfere with job scheduling.\n"
-           "          It may be an indication of the following:\n\n"
-           "          * slow disk\n"
-           "          * file system full\n"
-           "          * The definition is very large and needs to split\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                      # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.checkpt()                       # Save the definition held in the server to disk\n"
-           "       ci.checkpt(CheckPt.NEVER)          # Switch off check pointing\n"
-           "       ci.checkpt(CheckPt.ON_TIME)        # Start automatic check pointing at the interval stored in the "
-           "server\n"
-           "       ci.checkpt(CheckPt.ON_TIME,180)    # Start automatic check pointing every 180 seconds\n"
-           "       ci.checkpt(CheckPt.ALWAYS)         # Check point at any state change in node tree. *not* "
-           "recommended for large defs\n"
-           "       ci.checkpt(CheckPt.UNDEFINED,0,35) # Change check point save time alarm to 35 seconds\n"
-           "                                          # With these arguments mode and interval remain unchanged\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::restore_from_checkpt() {
-    return "Request the `ecflow_server`_ loads the `check point`_ file from disk\n\n"
-           "The server will first try to open file at ECF_HOME/ECF_CHECK if that fails it will\n"
-           "then try path ECF_HOME/ECF_CHECKOLD.\n"
-           "An error is returned if the server has not been `halted`_ or contains a `suite definition`_\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()             # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.halt_server()          # server must be halted, otherwise restore_from_checkpt will throw\n"
-           "       ci.restore_from_checkpt() # restore the definition from the check point file\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::reload_wl_file() {
-    return "Request that the `ecflow_server`_ reload the white list file.\n\n"
-           "The white list file if present, can be used to control who has read/write\n"
-           "access to the `ecflow_server`_::\n\n"
-           "   void reload_wl_file()\n\n"
-           "Usage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.reload_wl_file()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::run() {
-    return "Immediately run the jobs associated with the input `node`_.\n\n"
-           "Ignore `trigger`_\\ s, `limit`_\\ s, `suspended`_, `time`_ or `date`_ dependencies,\n"
-           "just run the `task`_.\n"
-           "When a job completes, it may be automatically re-queued if it has\n"
-           "multiple time `dependencies`_. In the specific case where a `task`_ has a SINGLE\n"
-           "time dependency and we want to avoid re running the `task`_ then\n"
-           "a flag is set so that it is not automatically re-queued when set to `complete`_.\n"
-           "The flag is applied up the `node`_ hierarchy until we reach a node with a `repeat`_\n"
-           "or `cron`_ attribute. This behaviour allow `repeat`_ values to be incremented interactively.\n"
-           "A `repeat`_ attribute is incremented when all the child nodes are `complete`_\n"
-           "in this case the child nodes are automatically re-queued\n::\n\n"
-           "   void run(\n"
-           "      string absolute_node_path : Path name to node. If the path is suite/family will recursively\n"
-           "                                  run all child tasks\n"
-           "      [(bool)force=False]       : If true, run even if there are nodes that are active or submitted.\n"
-           "   )\n"
-           "   void run(\n"
-           "      list  paths               : List of paths. If the path is suite/family will recursively run all "
-           "child tasks\n"
-           "      [(bool)force=False]       : If true, run even if there are nodes that are active or submitted.\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                          # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.run('/s1')                          # run all tasks under suite /s1\n"
-           "\n"
-           "       ci.run(['/s1/f1/t1','/s2/f1/t2'])      # run all tasks specified\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n"
-           "\nEffect:\n\n"
-           "   Lets see the effect of run command on the following defs:\n\n"
-           ".. code-block:: shell\n\n"
-           "   suite s1\n"
-           "      task t1; time 10:00             # will complete straight away\n"
-           "      task t2; time 10:00 13:00 01:00 # will re-queue 3 times and complete on fourth run\n\n"
-           "In the last case (task t2) after each run the next time slot is incremented.\n"
-           "This can be seen by calling the Why command.";
-}
-
-const char* ClientDoc::requeue() {
-
-    return "Re queues the specified `node`_ (s)\n::\n\n"
-           "   void requeue(\n"
-           "      list paths     : A list of paths. Node paths must begin with a leading '/' character\n"
-           "      [(str)option=''] : option = ('' | 'abort' | 'force')\n"
-           "          ''   : empty string, the default, re-queue the node\n"
-           "          abort: means re-queue only aborted tasks below node\n"
-           "          force: means re-queueing even if there are nodes that are active or submitted\n"
-           "   )\n"
-           "   void requeue(\n"
-           "      string absolute_node_path : Path name to node\n"
-           "      [(string)option='']       : option = ('' | 'abort' | 'force')\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.requeue('/s1','abort')       # re-queue aborted tasks below suite /s1\n"
-           "\n"
-           "       path_list = ['/s1/f1/t1','/s2/f1/t2']\n"
-           "       ci.requeue(path_list)\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::free_trigger_dep() {
-    return "Free `trigger`_ `dependencies`_ for a `node`_\n::\n\n"
-           "   void free_trigger_dep(\n"
-           "      string absolute_node_path : Path name to node\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()         # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.free_trigger_dep('/s1/f1/task')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::free_date_dep() {
-    return "Free `date`_ `dependencies`_ for a `node`_\n::\n\n"
-           "   void free_date_dep(\n"
-           "      string absolute_node_path : Path name to node\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.free_date_dep('/s1/task')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::free_time_dep() {
-    return "Free all time `dependencies`_. i.e `time`_, `day`_, `today`_, `cron`_\n::\n\n"
-           "   void free_time_dep(\n"
-           "      string absolute_node_path : Path name to node\n"
-           "   )\n\n"
-           "After freeing the time related dependencies (i.e time,today,cron)\n"
-           "the next time slot will be missed.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.free_time_dep('/s1/task')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::free_all_dep() {
-    return "Free all `trigger`_, `date`_ and all time(`day`_, `today`_, `cron`_,etc) `dependencies`_\n::\n\n"
-           "   void free_all_dep(\n"
-           "      string absolute_node_path : Path name to node\n"
-           "   )\n\n"
-           "After freeing the time related dependencies (i.e time,today,cron)\n"
-           "the next time slot will be missed.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.free_all_dep('/s1/task')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::ping() {
-    return "Checks if the `ecflow_server`_ is running\n::\n\n"
-           "   void ping()\n\n"
-           "The default behaviour is to check on host 'localhost' and port 3141\n"
-           "It should be noted that any Client function will fail if the server is\n"
-           "is not running. Hence ping() is not strictly required. However its main\n"
-           "distinction from other Client function is that it is quite fast.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client('localhost','3150')\n"
-           "       ci.ping()\n"
-           "       print('------- Server already running------')\n"
-           "       do_something_with_server(ci)\n"
-           "   except RuntimeError, e:\n"
-           "       print('------- Server *NOT* running------' + str(e))\n";
-}
-
-const char* ClientDoc::stats() {
-    return "Returns the `ecflow_server`_ statistics as a string\n\n"
-           ".. warning::\n\n"
-           "    When called without arguments, this function will print the statistics to :code:`stdout`,"
-           " before returning the information as a string.\n"
-           "    To avoid printing the output, set the boolean flag :code:`to_stdout` to :code:`False`.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()  # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       stats = ci.stats()      # prints to stdout\n"
-           "       stats = ci.stats(True)  # prints to stdout\n"
-           "       stats = ci.stats(False) # does not print to stdout\n"
-           "       print(stats)\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::stats_reset() {
-    return "Resets the statistical data in the server\n::\n\n"
-           "   void stats_reset()\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()  # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.stats_reset()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::suites() {
-    return "Returns a list strings representing the `suite`_ names\n::\n\n"
-           "   list(string) suites()\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()  # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       suites = ci.suites()\n"
-           "       print(suites)\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::ch_register() {
-    return "Register interest in a set of `suite`_\\ s.\n\n"
-           "If a definition has lots of suites, but the client is only interested in a small subset.\n"
-           "Then using this command can reduce network bandwidth and synchronisation will be quicker.\n"
-           "This command will create a client handle. This handle is held locally on the :py:class:`ecflow.Client`, "
-           "and\n"
-           "can be used implicitly by ch_drop(),ch_add(),ch_remove() and ch_auto_add().\n"
-           "Registering a client handle affects the news() and sync() commands::\n\n"
-           "   void ch_register(\n"
-           "      bool auto_add_new_suites : true means add new suites to my list, when they are created\n"
-           "      list suite_names         : should be a list of suite names, names not in the definition are ignored\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()\n"
-           "       suite_names = [ 's1', 's2', 's3' ]\n"
-           "       ci.ch_register(True,suite_names)    # register interest in suites s1,s2,s3 and any new suites\n"
-           "       ci.ch_register(False,suite_names)   # register interest in suites s1,s2,s3 only\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n\n"
-           "The client 'ci' will hold locally the client handle. Since we have made multiple calls to register\n"
-           "a handle, the variable 'ci' will hold the handle for the last call only.\n"
-           "The handle associated with the suite can be manually retrieved:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()\n"
-           "       ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
-           "       client_handle = ci.ch_handle()        # get the handle associated with last call to ch_register\n"
-           "       ....                                  # after a period of time\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n"
-           "   finally:\n"
-           "       ci.ch_drop( client_handle )           # de-register the handle\n\n"
-           "To automatically drop the handle(preferred) use with:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       with Client() as ci:\n"
-           "          ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
-           "          client_handle = ci.ch_handle()        # get the handle associated with last call to ch_register\n"
-           "       ....                                     # will automatically drop last handle\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::ch_suites() {
-    return "Writes to standard out the list of registered handles and the suites they reference.\n\n"
-           "When dealing with large definitions, where a user is only interested in a small subset\n"
-           "of suites, registering them, improves download performance from the server.\n"
-           "Registered suites have an associated handle.\n";
-}
-
-const char* ClientDoc::ch_drop() {
-    return "Drop/de-register the client handle.\n\n"
-           "When dealing with large definitions, where a user is only interested in a small subset\n"
-           "of suites, registering them, improves download performance from the server.\n"
-           "Registered suites have an associated handle.\n"
-           "Client must ensure un-used handle are dropped otherwise they will stay, in the `ecflow_server`_\n::\n\n"
-           "   void ch_drop(\n"
-           "      int client_handle : The handle must be an integer that is > 0\n"
-           "   )\n"
-           "   void ch_drop()       : Uses the local handle stored on the client, from last call to ch_register()\n\n"
-           "Exception:\n\n"
-           "- RunTimeError thrown if handle has not been previously registered\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "	try:\n"
-           "      ci = Client()                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "      ci.ch_register(False,['s1','s2'])\n"
-           "      while( 1 ):\n"
-           "         # get incremental changes to suites s1 & s2, uses data stored on ci/defs\n"
-           "         ci.sync_local()                # will only retrieve data for suites s1 & s2\n"
-           "         update(ci.get_defs())\n"
-           "	finally:\n"
-           "      ci.ch_drop()\n\n"
-           "To automatically drop the handle(Preferred) use with\n:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       with Client() as ci:\n"
-           "          ci.ch_register(False,['s1','s2'])\n"
-           "          while( 1 ):\n"
-           "              # get incremental changes to suites s1 & s2, uses data stored on ci/defs\n"
-           "              ci.sync_local()                # will only retrieve data for suites s1 & s2\n"
-           "              update(ci.get_defs())\n"
-           "       ....                                  # will automatically drop last handle\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::ch_drop_user() {
-    return "Drop/de-register all handles associated with user.\n\n"
-           "When dealing with large definitions, where a user is only interested in a small subset\n"
-           "of suites, registering them, improves download performance from the server.\n"
-           "Registered suites have an associated handle.\n"
-           "Client must ensure un-used handle are dropped otherwise they will stay, in the `ecflow_server`_\n::\n\n"
-           "   void ch_drop_user(\n"
-           "        string user   # If empty string will drop current user\n"
-           "   )\n\n"
-           "Exception:\n\n"
-           "- RunTimeError thrown if handle has not been previously registered\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  try:\n"
-           "      ci = Client()                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "      ci.ch_register(False,['s1','s2'])\n"
-           "      while( 1 ):\n"
-           "         # get incremental changes to suites s1 & s2, uses data stored on ci/defs\n"
-           "         update(ci.get_defs())\n"
-           "  finally:\n"
-           "      ci.ch_drop_user('') # drop all handles associated with current user\n\n";
-}
-
-const char* ClientDoc::ch_add() {
-    return "Add a set of suites, to an existing registered handle\n\n"
-           "When dealing with large definitions, where a user is only interested in a small subset\n"
-           "of suites, registering them, improves download performance from the server.\n"
-           "Registered suites have an associated handle.\n"
-           "::\n\n"
-           "  integer ch_add(\n"
-           "     integer handle   : the handle obtained after ch_register\n"
-           "     list suite_names : list of strings representing suite names\n"
-           "  )\n"
-           "  integer ch_add(\n"
-           "     list suite_names : list of strings representing suite names\n"
-           "  )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       with Client() as ci:       # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "          ci.ch_register(True,[]) # register interest in any new suites\n"
-           "          ci.ch_add(['s1','s2'])  # add suites s1,s2 to the last added handle\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n\n";
-}
-
-const char* ClientDoc::ch_remove() {
-    return "Remove a set of suites, from an existing handle\n\n"
-           "When dealing with large definitions, where a user is only interested in a small subset\n"
-           "of suites, registering them, improves download performance from the server.\n"
-           "Registered suites have an associated handle.\n"
-           "::\n\n"
-           "  integer ch_remove(\n"
-           "     integer handle   : the handle obtained after ch_register\n"
-           "     list suite_names : list of strings representing suite names\n"
-           "  )\n"
-           "  integer ch_remove(\n"
-           "     list suite_names : list of strings representing suite names\n"
-           "  )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       with Client() as ci:                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "          ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
-           "          ci.ch_remove( ['s1'] )                # remove suites s1 from the last added handle\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n\n";
-}
-
-const char* ClientDoc::ch_auto_add() {
-    return "Change an existing handle so that new suites can be added automatically\n\n"
-           "When dealing with large definitions, where a user is only interested in a small subset\n"
-           "of suites, registering them, improves download performance from the server.\n"
-           "Registered suites have an associated handle.\n"
-           "::\n\n"
-           "   void ch_auto_add(\n"
-           "      integer handle,         : the handle obtained after ch_register\n"
-           "      bool auto_add_new_suite : automatically add new suites, this handle when they are created\n"
-           "   )\n"
-           "   void ch_auto_add(\n"
-           "      bool auto_add_new_suite : automatically add new suites using handle on the client\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       with Client() as ci:                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "          ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
-           "          ci.ch_auto_add( False )               # disable adding newly created suites to my handle\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n\n";
-}
-
-const char* ClientDoc::get_file() {
-    return "The File command is used to request the various file types associated with a `node`_.\n\n"
-           "By default, the output is composed of the last 10000 lines of the file. The number of lines can be "
-           "customised via the :code:`max_lines` parameter.\n\n"
-           "The content can be retrieved as a sequence of 'bytes'. This allows to download a file that contains "
-           "invalid Unicode sequence, without causing an :code:`UnicodeDecodeError` to be raised.\n"
-           "::\n\n"
-           "   string get_file(\n"
-           "      string absolute_node_path    : Path name to node\n"
-           "      [(string)file_type='script'] : file_type = [ script<default> | job | jobout | manual | kill | stat "
-           "]\n"
-           "      [(string)max_lines='10000'] : The number of lines in the file to return\n"
-           "      [(bool)as_bytes=False] : A flag indicating if the output should be 'bytes'; by default the output is "
-           "of type 'str'\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()        # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       for file in [ 'script', 'job', 'jobout', 'manual', 'kill', 'stat' ]:\n"
-           "           print(ci.get_file('/suite/f1/t1',file))  # print the contents of the file\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::plug() {
-    return "Plug command is used to move `node`_\\ s\n\n"
-           "The destination node can be on another `ecflow_server`_.\n"
-           "In which case the destination path should be of the form '//<host>:<port>/suite/family/task\n::\n\n"
-           "   void plug(\n"
-           "      string source_absolute_node_path       : Path name to source node\n"
-           "      string destination_absolute_node_path  : Path name to destination node. Note if only\n"
-           "                                               '//host:port' is specified the whole suite can be moved\n"
-           "   )\n\n"
-           "By default throws a RuntimeError exception for errors.\n\n"
-           "Exceptions can be raised because:\n\n"
-           "- Source `node`_ is in a `active`_ or `submitted`_ state.\n"
-           "- Another user already has an lock.\n"
-           "- source/destination paths do not exist on the corresponding servers\n"
-           "- If the destination node path is empty, i.e. only host:port is specified,\n"
-           "  then the source `node`_ must correspond to a `suite`_.\n"
-           "- If the source node is added as a child, then its name must be unique\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.plug('/suite','host3:3141')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::query() {
-    return "Query the status of event, meter, state, variable, limit, limit_max or trigger expression without "
-           "blocking\n\n"
-           " - state     return [unknown | complete | queued |             aborted | submitted | active] to standard "
-           "out\n"
-           " - dstate    return [unknown | complete | queued | suspended | aborted | submitted | active] to standard "
-           "out\n"
-           " - event     return 'set' | 'clear' to standard out\n"
-           " - meter     return value of the meter to standard out\n"
-           " - limit     return value of the limit to standard out\n"
-           " - limit_max return max value of the limit to standard out\n"
-           " - variable  return value to standard out\n"
-           " - trigger   returns 'true' if the expression is true, otherwise 'false'\n\n:\n\n"
-           ".. code-block:: shell\n\n"
-           "  string query(\n"
-           "     string query_type        # [ event | meter | variable | trigger | limit | limit_max ]\n"
-           "     string path_to_attribute # path to the attribute\n"
-           "     string attribute         # name of the attribute or trigger expression\n"
-           "  )\n\n"
-           "By default throws a exception for errors.\n\n"
-           "Exceptions can be raised if the path to the attribute does not exist and because:\n\n"
-           "- No event of the given name exists on the specified node\n"
-           "- No meter of the given name exists on the specified node\n"
-           "- No limit of the given name exists on the specified node\n"
-           "- No variable of the given name (repeat or generated variable) exists on the\n"
-           "  specified node or any of its parent\n"
-           "- trigger expression does not parse, or if references to node/attributes are not defined\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       res = ci.query('event','/path/to/node','event_name') # returns 'SET' | 'CLEAR'\n"
-           "       res = ci.query('meter','/path/to/node','meter_name') # returns meter value as a string\n"
-           "       res = ci.query('limit','/path/to/node','limit_name') # returns limit value as a string\n"
-           "       res = ci.query('limit_max','/path/to/node','limit_name') # returns max limit value as a string\n"
-           "       res = ci.query('variable','/path/to/node,'var')      # returns variable value as a string\n"
-           "       res = ci.query('trigger','/path/to/node','/joe90 == complete') # return 'true' | 'false' as a "
-           "string\n"
-           "       res = ci.query('state','/path/to/node') # return node state as a string\n"
-           "       res = ci.query('dstate','/path/to/node') # return node state as a string,can include suspended\n"
-           "   except RuntimeError, e:\n"
-           "       print str(e)\n";
-}
-
-const char* ClientDoc::alter() {
-    return "Alter command is used to change the attributes of a node\n::\n\n"
-           "   void alter(\n"
-           "      (list | string ) paths(s) : A single or list of paths. Path name to the node whose attributes are to "
-           "be changed\n"
-           "      string alter_type         : This must be one of [ 'add' | 'change' | 'delete' | 'set_flag' | "
-           "'clear_flag' ]\n"
-           "      string attr_type          : This varies according to the 'alter_type'. valid strings are:\n"
-           "         add    : [ variable,time,today,date,day,label,zombie,late]\n"
-           "         delete : [ "
-           "variable,time,today,date,day,label,cron,event,meter,trigger,complete,repeat,limit,inlimit,limit_path,"
-           "zombie,late]\n"
-           "         change : [ "
-           "variable,clock-type,clock-gain,event,meter,label,trigger,complete,repeat,limit-max,limit-value,late,time,"
-           "today]\n"
-           "         set_flag and clear_flag:\n"
-           "                  [ force_aborted | user_edit | task_aborted | edit_failed | ecfcmd_failed | "
-           "statuscmd_failed | killcmd_failed |\n"
-           "                    no_script | killed | status | late | message | complete | queue_limit | task_waiting | "
-           "locked | zombie ]\n"
-           "      string name               : used to locate the attribute, when multiple attributes of the same "
-           "type,\n"
-           "                                  optional for some.i.e. when changing, attributes like "
-           "variable,meter,event,label,limits\n"
-           "      string value              : Only used when 'changing' a attribute. provides a new value\n"
-           "   )\n\n"
-           "Exceptions can be raised because:\n\n"
-           "- absolute_node_path does not exist.\n"
-           "- parsing fails\n"
-           "\n"
-           "The following describes the parameters in more detail:\n\n"
-           ".. code-block:: shell\n\n"
-           " add variable variable_name variable_value\n"
-           " add time   format    # when format is +hh:mm | hh:mm | hh:mm(start) hh:mm(finish) hh:mm(increment)\n"
-           " add today  format    # when format is +hh:mm | hh:mm | hh:mm(start) hh:mm(finish) hh:mm(increment)\n"
-           " add date   format    # when format dd.mm.yyyy, can use '*' to indicate any day,month, or year\n"
-           " add day    format    # when format is one of [ sunday,monday,tuesday,wednesday,friday,saturday ]\n"
-           " add zombie format    # when format is one of "
-           "<zombie-type>:<child>:<server-action>|<client-action>:<zombie-lifetime>\n"
-           "                      #  <zombie-type> := [ user | ecf | path ]\n"
-           "                      #  <child> := [ init, event, meter, label, wait, abort, complete ]\n"
-           "                      #  <server-action> := [ adopt | delete ]\n"
-           "                      #  <client-action> := [ fob | fail | block(default) ]\n"
-           "                      #  <zombie-lifetime>:= lifetime of zombie in the server\n"
-           "                      # example\n"
-           "                      # add zombie :label:fob:0   # fob all child label request, & remove zombie as soon "
-           "as possible\n"
-           "\n"
-           " delete variable name # if name is empty will delete -all- variables on the node\n"
-           " delete time name     # To delete a specific time, enter the time in same format as show above,\n"
-           "                      # or as specified in the defs file\n"
-           "                      # an empty name will delete all time attributes on the node\n"
-           " delete today name    # To delete a specific today attribute, enter in same format as show above,\n"
-           "                      # or as specified in the defs file.\n"
-           "                      # an empty name will delete all today attributes on the node\n"
-           " delete date name     # To delete a specific date attribute, enter in same format as show above,\n"
-           "                      # or as specified in the defs file\n"
-           "                      # an empty name will delete all date attributes on the node\n"
-           " delete day name      # To delete a specific day attribute, enter in same format as show above,\n"
-           "                      # or as specified in the defs file\n"
-           "                      # an empty name will delete all day attributes on the node\n"
-           " delete cron name     # To delete a specific cron attribute, enter in same as specified in the defs file\n"
-           "                      # an empty name will delete all cron attributes on the node\n"
-           " delete event name    # To delete a specific event, enter name or number\n"
-           "                      # an empty name will delete all events on the node\n"
-           " delete meter name    # To delete a specific meter , enter the meter name\n"
-           "                      # an empty name will delete all meter on the node \n"
-           " delete label name    # To delete a specific label , enter the label name\n"
-           "                      # an empty name will delete all labels on the node\n"
-           " delete limit name    # To delete a specific limit , enter the limit name\n"
-           "                      # an empty name will delete all limits on the node\n"
-           " delete inlimit name  # To delete a specific inlimit , enter the inlimit name\n"
-           "                      # an empty name will delete all inlimits on the node\n"
-           " delete limit_path limit_name limit_path # To delete a specific limit path\n"
-           " delete trigger       # A node can only have one trigger expression, hence the name is not required\n"
-           " delete complete      # A node can only have one complete expression, hence the name is not required\n"
-           " delete repeat        # A node can only have one repeat, hence the name is not required\n"
-           "\n"
-           " change variable name value    # Find the specified variable, and set the new value.\n"
-           " change clock_type name        # The name must be one of 'hybrid' or 'real'.\n"
-           " change clock_gain name        # The gain must be convertible to an integer.\n"
-           " change clock_sync name        # Sync suite calendar with the computer.\n"
-           " change event name(optional )  # if no name specified the event is set, otherwise name must be 'set' or "
-           "'clear'\n"
-           " change meter name value       # The meter value must be convertible to an integer, and between meter "
-           "min-max range.\n"
-           " change label name value       # sets the label\n"
-           " change trigger name           # The name must be expression. returns an error if the expression does not "
-           "parse\n"
-           " change complete name          # The name must be expression. returns an error if the expression does not "
-           "parse\n"
-           " change limit_max name value   # Sets the max value of the limit. The value must be convertible to an "
-           "integer\n"
-           " change limit_value name value # Sets the consumed tokens to value.The value must be convertible to an "
-           "integer\n"
-           " change repeat value           # If the repeat is a date, then the value must be a valid YMD ( ie. "
-           "yyyymmdd)\n"
-           "                               # and be convertible to an integer, additionally the value must be in "
-           "range\n"
-           "                               # of the repeat start and end dates. Like wise for repeat integer. For "
-           "repeat\n"
-           "                               # string and enum,  the name must either be an integer, that is a valid "
-           "index or\n"
-           "                               # if it is a string, it must correspond to one of enum's or strings list\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  try:\n"
-           "     ci = Client()     # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "     ci.alter('/suite/task','change','trigger','b2 == complete')\n"
-           "  except RuntimeError, e:\n"
-           "     print(str(e))\n";
-}
-
-const char* ClientDoc::force_state() {
-
-    return "Force a node(s) to a given state\n\n"
-           "When a `task`_ is set to `complete`_, it may be automatically re-queued if it has\n"
-           "multiple time `dependencies`_. In the specific case where a task has a single\n"
-           "time dependency and we want to interactively set it to `complete`_\n"
-           "a flag is set so that it is not automatically re-queued when set to complete.\n"
-           "The flag is applied up the node hierarchy until reach a node with a `repeat`_\n"
-           "or `cron`_ attribute. This behaviour allow `repeat`_ values to be incremented interactively.\n"
-           "A `repeat`_ attribute is incremented when all the child nodes are `complete`_\n"
-           "in this case the child nodes are automatically re-queued\n::\n\n"
-           "   void force_state(\n"
-           "      string absolute_node_path: Path name to node. The path must begin with a leading '/'\n"
-           "      State::State state       : [ unknown | complete | queued | submitted | active | aborted ]\n"
-           "   )\n"
-           "   void force_state(\n"
-           "      list paths         : A list of absolute node paths. The paths must begin with a leading '/'\n"
-           "      State::State state : [ unknown | complete | queued | submitted | active | aborted ]\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       # force a single node to complete\n"
-           "       ci.force_state('/s1/f1',State.complete)\n"
-           "\n"
-           "       # force a list of nodes to complete\n"
-           "       paths = [ '/s1/t1', '/s1/t2', '/s1/f1/t1' ]\n"
-           "       ci.force_state(paths,State.complete)\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n"
-           "\nEffect:\n\n"
-           "Lets see the effect of forcing complete on the following defs\n\n"
-           ".. code-block:: shell\n\n"
-           "   suite s1\n"
-           "      task t1; time 10:00             # will complete straight away\n"
-           "      task t2; time 10:00 13:00 01:00 # will re-queue 3 times and complete on fourth \n\n"
-           "In the last case (task t2) after each force complete, the next time slot is incremented.\n"
-           "This can be seen by calling the Why command.";
-}
-
-const char* ClientDoc::force_state_recursive() {
-
-    return "Force node(s) to a given state recursively\n::\n\n"
-           "   void force_state_recursive(\n"
-           "      string absolute_node_path: Path name to node.The paths must begin with a leading '/'\n"
-           "      State::State state       : [ unknown | complete | queued | submitted | active | aborted ]\n"
-           "   )\n"
-           "   void force_state_recursive(\n"
-           "      list  paths         : A list of absolute node paths.The paths must begin with a leading '/'\n"
-           "      State::State state  : [ unknown | complete | queued | submitted | active | aborted ]\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  try:\n"
-           "      ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "      ci.force_state_recursive('/s1/f1',State.complete)\n"
-           "\n"
-           "      # recursively force a list of nodes to complete\n"
-           "      paths = [ '/s1', '/s2', '/s1/f1/t1' ]\n"
-           "      ci.force_state_recursive(paths,State.complete)\n"
-           "  except RuntimeError, e:\n"
-           "      print(str(e))\n";
-}
-
-const char* ClientDoc::force_event() {
-
-    return "Set or clear a `event`_\n::\n\n"
-           "   void force_event(\n"
-           "      string absolute_node_path:event: Path name to node: < event name | number>\n"
-           "                                       The paths must begin with a leading '/'\n"
-           "      string signal                  : [ set | clear ]\n"
-           "   )\n"
-           "   void force_event(\n"
-           "      list paths    : A list of absolute node paths. Each path must include a event name\n"
-           "                      The paths must begin with a leading '/'\n"
-           "      string signal : [ set | clear ]\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.force_event('/s1/f1:event_name','set')\n"
-           "\n"
-           "       # Set or clear a event for a list of events\n"
-           "       paths = [ '/s1/t1:ev1', '/s2/t2:ev2' ]\n"
-           "       ci.force_event(paths,'clear')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::replace() {
-    return "Replaces a `node`_ in a `suite definition`_ with the given path. The definition is in the "
-           "`ecflow_server`_\n::\n\n"
-           "   void replace(\n"
-           "      string absolute_node_path: Path name to node in the client defs.\n"
-           "                                 This is also the node we want to replace in the server.\n"
-           "      string client_defs_file  : File path to defs files, that provides the definition of the new node\n"
-           "      [(bool)parent=False]     : create parent families or suite as needed,\n"
-           "                                 when absolute_node_path does not exist in the server\n"
-           "      [(bool)force=False]      : check for zombies, if force = true, bypass checks\n"
-           "   )\n"
-           "\n"
-           "   void replace(\n"
-           "      string absolute_node_path: Path name to node in the client defs.\n"
-           "                                 This is also the node we want to replace in the server.\n"
-           "      Defs client_defs         : In memory client definition that provides the definition of the new node\n"
-           "      [(bool)parent=False]     : create parent families or suite as needed,\n"
-           "                                 when absolute_node_path does not exist in the server\n"
-           "      [(bool)force=False]      : check for zombies, force = true, bypass checks\n"
-           "   )\n"
-           "\n"
-           "Exceptions can be raised because:\n\n"
-           "- The absolute_node_path does not exist in the provided definition\n"
-           "- The provided client definition must be free of errors\n"
-           "- If the third argument is not provided, then the absolute_node_path must exist in the server defs\n"
-           "- replace will fail, if child task nodes are in `active`_ / `submitted`_ state\n\n"
-           "After replace is done, we check trigger expressions. These are reported to standard output.\n"
-           "It is up to the user to correct invalid trigger expressions, otherwise the tasks will *not* run.\n"
-           "Please note, you can use check() to check trigger expression and limits in the server.\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.replace('/s1/f1','/tmp/defs.def')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n"
-           "\n"
-           "   try:\n"
-           "       ci.replace('/s1',client_defs) # replace suite 's1' in the server, with 's1' in the client_defs\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::kill() {
-    return "Kills the job associated with the `node`_\n::\n\n"
-           "   void kill(\n"
-           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
-           "   )\n"
-           "   void kill(\n"
-           "      string absolute_node_path: Path name to node to kill.\n"
-           "   )\n"
-           "\n"
-           "If a `family`_ or `suite`_ is selected, will kill hierarchically.\n"
-           "Kill uses the ECF_KILL_CMD variable. After `variable substitution`_ it is invoked as a command.\n"
-           "The ECF_KILL_CMD variable should be written in such a way that the output is written to %ECF_JOB%.kill, "
-           "i.e:\n\n"
-           ".. code-block:: shell\n\n"
-           "   kill -15 %ECF_RID% > %ECF_JOB%.kill 2>&1\n"
-           "   /home/ma/emos/bin/ecfkill %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1\n\n"
-           "\n"
-           "Exceptions can be raised because:\n\n"
-           "- The absolute_node_path does not exist in the server\n"
-           "- ECF_KILL_CMD variable is not defined\n"
-           "- `variable substitution`_ fails\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.kill('/s1/f1')\n"
-           "       time.sleep(2)\n"
-           "       print(ci.file('/s1/t1','kill')) # request kill output\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::status() {
-    return "Shows the status of a job associated with a `task`_\n::\n\n"
-           "   void status(\n"
-           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
-           "   )\n"
-           "   void status(\n"
-           "      string absolute_node_path\n"
-           "   )\n\n"
-           "If a `family`_ or `suite`_ is selected, will invoke status command hierarchically.\n"
-           "Status uses the ECF_STATUS_CMD variable. After `variable substitution`_ it is invoked as a command.\n"
-           "The command should be written in such a way that the output is written to %ECF_JOB%.stat, i.e:\n\n"
-           ".. code-block:: shell\n\n"
-           "   /home/ma/emos/bin/ecfstatus  %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.stat 2>&1\n\n"
-           "Exceptions can be raised because:\n\n"
-           "- The absolute_node_path does not exist in the server\n"
-           "- ECF_STATUS_CMD variable is not defined\n"
-           "- `variable substitution`_ fails\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.status('/s1/t1')\n"
-           "       time.sleep(2)\n"
-           "       print(ci.file('/s1/t1','stats')) # request status output\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::order() {
-    return "Re-orders the `node`_\\ s in the `suite definition`_ held by the `ecflow_server`_\n\n"
-           "It should be noted that in the absence of `dependencies`_,\n"
-           "the order in which `task`_\\ s are `submitted`_, depends on the order in the definition.\n"
-           "This changes the order and hence affects the submission order\n::\n\n"
-           "   void order(\n"
-           "      string absolute_node_path: Path name to node.\n"
-           "      string order_type        : Must be one of [ top | bottom | alpha | order | up | down ]\n"
-           "   )\n"
-           "   o top     raises the node within its parent, so that it is first\n"
-           "   o bottom  lowers the node within its parent, so that it is last\n"
-           "   o alpha   Arranges for all the peers of selected note to be sorted alphabetically\n"
-           "   o order   Arranges for all the peers of selected note to be sorted in reverse alphabet\n"
-           "   o up      Moves the selected node up one place amongst its peers\n"
-           "   o down    Moves the selected node down one place amongst its peers\n\n"
-           "Exceptions can be raised because:\n\n"
-           "- The absolute_node_path does not exist in the server\n"
-           "- The order_type is not the right type\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.order('/s1/f1','top')\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::group() {
-    return "Allows a series of commands to be executed in the `ecflow_server`_\n::\n\n"
-           "   void group(\n"
-           "       string cmds : a list of ';' separated commands \n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()               # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.group('get; show')\n"
-           "       ci.group('get; show state') # show node states and trigger abstract syntax trees\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::begin_suite() {
-    return "Begin playing the chosen `suite`_\\ s in the `ecflow_server`_\n\n"
-           ".. Note:: using the force option may cause `zombie`_\\ s if suite has running jobs\n\n"
-           "::\n\n"
-           "   void begin_suite\n"
-           "      string suite_name     : begin playing the given suite\n"
-           "      [(bool)force=False]   : bypass the checks for submitted and active jobs\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                  # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.begin_suite('/suite1')      # begin playing suite '/suite1'\n"
-           "       ci.begin_suite('/suite1',True) # begin playing suite '/suite1' bypass any checks"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::begin_all() {
-    return "Begin playing all the `suite`_\\ s in the `ecflow_server`_\n\n"
-           ".. Note:: using the force option may cause `zombie`_\\ s if suite has running jobs\n\n"
-           "::\n\n"
-           "   void begin_all_suites(\n"
-           "      [(bool)force=False] : bypass the checks for submitted and active jobs\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()             # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.begin_all_suites()     # begin playing all the suites\n"
-           "       ci.begin_all_suites(True) # begin playing all the suites, by passing checks\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::suspend() {
-    return "Suspend `job creation` / generation for the given `node`_\n::\n\n"
-           "   void suspend(\n"
-           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
-           "   )\n"
-           "   void suspend(\n"
-           "      string absolute_node_path: Path name to node to suspend.\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.suspend('/s1/f1/task1')\n"
-           "       paths = ['/s1/f1/t1','/s2/f1/t2']\n"
-           "       ci.suspend(paths)\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::resume() {
-    return "Resume `job creation` / generation for the given `node`_\n::\n\n"
-           "   void resume(\n"
-           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
-           "   )\n"
-           "   void resume(\n"
-           "      string absolute_node_path: Path name to node to resume.\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.resume('/s1/f1/task1')\n"
-           "       paths = ['/s1/f1/t1','/s2/f1/t2']\n"
-           "       ci.resume(paths)\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::job_gen() {
-    return "Job submission for chosen Node *based* on `dependencies`_\n\n"
-           "The `ecflow_server`_ traverses the `node`_ tree every 60 seconds, and if the dependencies are free\n"
-           "does `job creation` and submission. Sometimes the user may free time/date dependencies\n"
-           "to avoid waiting for the server poll, this commands allows early job generation\n::\n\n"
-           "   void job_generation(\n"
-           "      string absolute_node_path: Path name for job generation to start from\n"
-           "   )\n"
-           "   If empty string specified generates for full definition.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.job_generation('/s1')  # generate jobs for suite '/s1 \n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::delete_node() {
-    return "Delete the `node`_ (s) specified.\n\n"
-           "If a node is `submitted`_ or `active`_, then a Exception will be raised.\n"
-           "To force the deletion at the expense of `zombie`_ creation, then set\n"
-           "the force parameter to true\n::\n\n"
-           "   void delete(\n"
-           "      list paths          : List of paths.\n"
-           "      [(bool)force=False] : If true delete even if in 'active' or 'submitted' states\n"
-           "                            Which risks creating zombies.\n"
-           "   )\n"
-           "   void delete(\n"
-           "      string absolute_node_path: Path name of node to delete.\n"
-           "      [(bool)force=False]       : If true delete even if in 'active' or 'submitted' states\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.delete('/s1/f1/task1')\n"
-           "\n"
-           "       paths = ['/s1/f1/t1','/s2/f1/t2']\n"
-           "       ci.delete(paths)                  # delete all tasks specified in the paths\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::delete_all() {
-    return "Delete all the `node`_\\ s held in the `ecflow_server`_.\n\n"
-           "The `suite definition`_ in the server will be empty, after this call. **Use with care**\n"
-           "If a node is `submitted`_ or `active`_, then a Exception will be raised.\n"
-           "To force the deletion at the expense of `zombie`_ creation, then set\n"
-           "the force parameter to true\n::\n\n"
-           "   void delete_all(\n"
-           "      [(bool)force=False] : If true delete even if in 'active' or 'submitted' states\n"
-           "                            Which risks creating zombies.\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.delete_all()\n"
-           "       ci.get_server_defs()\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e));    # expect failure since all nodes deleted";
-}
-
-const char* ClientDoc::check() {
-    return "Check `trigger`_ and `complete expression`_\\ s and `limit`_\\ s\n\n"
-           "The `ecflow_server`_ does not store `extern`_\\ s. Hence all unresolved references\n"
-           "are reported as errors.\n"
-           "Returns a non empty string for any errors or warning\n::\n\n"
-           "   string check(\n"
-           "      list paths # List of paths.\n"
-           "   )\n"
-           "   string check(\n"
-           "      string absolute_node_path\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       print(ci.check('/suite1'))\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* ClientDoc::archive() {
-    return "Archives suite or family nodes. Saves the suite/family nodes to disk, and then removes then from the "
-           "definition\n"
-           "This saves memory in the server, when dealing with huge definitions that are not needed.\n"
-           "If the node is re-queued or begun, it is automatically restored\n"
-           "Use --restore to reload the archived nodes manually\n"
-           "The nodes are saved to ECF_HOME/ECF_NAME.check\n"
-           "Usage::\n\n"
-           "   string archive(\n"
-           "      list paths # List of paths.\n"
-           "   )\n"
-           "   string archive(\n"
-           "      string absolute_node_path\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       print ci.archive('/suite1')\n"
-           "   except RuntimeError, e:\n"
-           "       print str(e)\n";
-}
-const char* ClientDoc::restore() {
-    return "Restore archived nodes.\n"
-           "Usage::\n\n"
-           "   string restore(\n"
-           "      list paths # List of paths.\n"
-           "   )\n"
-           "   string restore(\n"
-           "      string absolute_node_path\n"
-           "   )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       print ci.restore('/suite1')\n"
-           "   except RuntimeError, e:\n"
-           "       print str(e)\n";
-}
-
-const char* ClientDoc::set_child_path() {
-    return "Set the path to the task, obtained from server using %ECF_NAME%\n\n"
-           "By default the environment variable ECF_NAME is read for the task path\n"
-           "This can be overridden for the python child api";
-}
-const char* ClientDoc::set_child_password() {
-    return "Set the password, needed for authentication, provided by the server using %ECF_PASS%\n\n"
-           "By default the environment variable ECF_PASS is read for the jobs password\n"
-           "This can be overridden for the python child api";
-}
-
-const char* ClientDoc::set_child_pid() {
-    return "Set the process id of this job\n\n"
-           "By default the environment variable ECF_RID is read for the jobs process or remote id\n"
-           "This can be overridden for the python child api";
-}
-
-const char* ClientDoc::set_child_try_no() {
-    return "Set the try no, i.e the number of times this job has run, obtained from the server, using %ECF_TRYNO%\n\n"
-           "By default the environment variable ECF_TRYNO is read to record number of times job has been run\n"
-           "This can be overridden for the python child api";
-}
-
-const char* ClientDoc::set_child_timeout() {
-    return "Set timeout if child cannot connect to server, default is 24 hours. The input is required to be in "
-           "seconds\n\n"
-           "By default the environment variable  ECF_TIMEOUT is read to control how long child command should attempt "
-           "to connect to the server\n"
-           "This can be overridden for the python child api";
-}
-
-const char* ClientDoc::set_child_init_add_vars() {
-    return "Set the list of variables to be added when a task becomes active\n"
-           "Needs a dictionary of name/value pairs, or a list of ecflow Variables";
-}
-
-const char* ClientDoc::set_child_complete_del_vars() {
-    return "Set the list of variables to be deleted when a task becomes complete\n"
-           "Needs a list of strings, representing the variable names.";
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ClientDoc.hpp 5.13.0-1/Pyext/src/ecflow/python/ClientDoc.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/ClientDoc.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ClientDoc.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,101 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_ClientDoc_HPP
-#define ecflow_python_ClientDoc_HPP
-
-// ===========================================================================
-// IMPORTANT: These appear as python doc strings.
-//            Additionally they are auto documented using sphinx-poco
-//            Hence the doc strings use reStructuredText markup.
-// ===========================================================================
-class ClientDoc {
-public:
-    ClientDoc()                            = delete;
-    ClientDoc(const ClientDoc&)            = delete;
-    ClientDoc& operator=(const ClientDoc&) = delete;
-
-    static const char* class_client();
-    static const char* set_host_port();
-    static const char* set_retry_connection_period();
-    static const char* set_connection_attempts();
-    static const char* get_defs();
-    static const char* edit_script_edit();
-    static const char* edit_script_preprocess();
-    static const char* edit_script_submit();
-    static const char* get_log();
-    static const char* new_log();
-    static const char* clear_log();
-    static const char* flush_log();
-    static const char* log_msg();
-    static const char* restart_server();
-    static const char* halt_server();
-    static const char* shutdown_server();
-    static const char* terminate_server();
-    static const char* wait_for_server_reply();
-    static const char* load_defs();
-    static const char* load();
-    static const char* get_server_defs();
-    static const char* sync();
-    static const char* in_sync();
-    static const char* news();
-    static const char* changed_node_paths();
-    static const char* checkpt();
-    static const char* restore_from_checkpt();
-    static const char* reload_wl_file();
-    static const char* run();
-    static const char* requeue();
-    static const char* free_date_dep();
-    static const char* free_trigger_dep();
-    static const char* free_time_dep();
-    static const char* free_all_dep();
-    static const char* ping();
-    static const char* stats();
-    static const char* stats_reset();
-    static const char* suites();
-    static const char* ch_register();
-    static const char* ch_suites();
-    static const char* ch_drop();
-    static const char* ch_drop_user();
-    static const char* ch_add();
-    static const char* ch_remove();
-    static const char* ch_auto_add();
-    static const char* get_file();
-    static const char* plug();
-    static const char* query();
-    static const char* alter();
-    static const char* force_state();
-    static const char* force_state_recursive();
-    static const char* force_event();
-    static const char* replace();
-    static const char* kill();
-    static const char* check();
-    static const char* status();
-    static const char* order();
-    static const char* group();
-    static const char* begin_suite();
-    static const char* begin_all();
-    static const char* suspend();
-    static const char* resume();
-    static const char* job_gen();
-    static const char* delete_node();
-    static const char* delete_all();
-    static const char* archive();
-    static const char* restore();
-    static const char* set_child_path();
-    static const char* set_child_password();
-    static const char* set_child_pid();
-    static const char* set_child_try_no();
-    static const char* set_child_timeout();
-    static const char* set_child_init_add_vars();
-    static const char* set_child_complete_del_vars();
-};
-
-#endif /* ecflow_python_ClientDoc_HPP */
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/DefsDoc.cpp 5.13.0-1/Pyext/src/ecflow/python/DefsDoc.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/DefsDoc.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/DefsDoc.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1022 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/DefsDoc.hpp"
-
-const char* DefsDoc::add() {
-    return "add(..) provides a way to append Nodes and attributes\n\n"
-           "This is best illustrated with an example:\n\n"
-           ".. code-block:: python\n\n"
-           " defs = Defs().add(\n"
-           "     Suite('s1').add(\n"
-           "         Clock(1, 1, 2010, False),\n"
-           "         Autocancel(1, 10, True),\n"
-           "         Task('t1').add(\n"
-           "             Edit({'a':'12', 'b':'bb'}, c='v',d='b'),\n"
-           "             Edit(g='d'),\n"
-           "             Edit(h=1),\n"
-           "             Event(1),\n"
-           "             Event(11,'event'),\n"
-           "             Meter('meter',0,10,10),\n"
-           "             Label('label','c'),\n"
-           "             Trigger('1==1'),\n"
-           "             Complete('1==1'),\n"
-           "             Limit('limit',10),Limit('limit2',10),\n"
-           "             InLimit('limitName','/limit',2),\n"
-           "             Defstatus(DState.complete),\n"
-           "             Today(0,30),Today('00:59'),Today('00:00 11:30 00:01'),\n"
-           "             Time(0,30),Time('00:59'),Time('00:00 11:30 00:01'),\n"
-           "             Day('sunday'),Day(Days.monday),\n"
-           "             Date(1,1,0),Date(28,2,1960),\n"
-           "             Autocancel(3)\n"
-           "             ),\n"
-           "         [ Family('f{}'.format(i)) for i in range(1,6)]))\n\n"
-           "We can also use '+=' with a list here are a few examples:\n\n"
-           ".. code-block:: python\n\n"
-           " defs = Defs();\n"
-           " defs += [ Suite('s2'),Edit({ 'x1':'y', 'aa1':'bb'}, a='v',b='b') ]\n\n"
-           ".. code-block:: python\n\n"
-           " defs += [ Suite('s{}'.format(i)) for i in range(1,6) ]\n\n"
-           ".. code-block:: python\n\n"
-           " defs = Defs()\n"
-           " defs += [ Suite('suite').add(\n"
-           "              Task('x'),\n"
-           "              Family('f').add( [ Task('t{}'.format(i)) for i in range(1,6)] ),\n"
-           "              Task('y'),\n"
-           "              [ Family('f{}'.format(i)) for i in range(1,6) ],\n"
-           "              Edit(a='b'),\n"
-           "              [ Task('t{}'.format(i)) for i in range(1,6) ],\n"
-           "              )]\n\n"
-           "It is also possible to use '+'\n\n"
-           ".. code-block:: python\n\n"
-           " defs = Defs() + Suite('s1')\n"
-           " defs.s1 += Autocancel(1, 10, True)\n"
-           " defs.s1 += Task('t1') + Edit({ 'e':1, 'f':'bb'}) +\\ \n"
-           "            Event(1) + Event(11,'event') + Meter('meter',0,10,10) + Label('label','c') + Trigger('1==1') "
-           "+\\ \n"
-           "            Complete('1==1') + Limit('limit',10) + Limit('limit2',10) + InLimit('limitName','/limit',2) "
-           "+\\ \n"
-           "            Defstatus(DState.complete) + Today(0,30) + Today('00:59') + Today('00:00 11:30 00:01') +\\ \n"
-           "            Time(0,30) + Time('00:59') + Time('00:00 11:30 00:01') + Day('sunday') + Day(Days.monday) +\\ "
-           "\n"
-           "            Date(1,1,0) + Date(28,2,1960) + Autocancel(3)\n\n"
-           ".. warning:: We can only use '+' when the left most object is a node, i.e Task('t1') in this case";
-}
-
-const char* DefsDoc::abs_node_path_doc() {
-    return "returns a string which holds the path to the node\n\n";
-}
-
-const char* DefsDoc::part_expression_doc() {
-    return "PartExpression holds part of a `trigger`_ or `complete expression`_.\n\n"
-           "Expressions can contain references to `event`_\\s, `meter`_\\ s, user variables,\n"
-           "`repeat`_ variables and generated variables. The part expression allows us\n"
-           "to split a large trigger or complete expression into smaller ones\n"
-           "\nConstructor::\n\n"
-           "  PartExpression(exp )\n"
-           "      string   exp: This represents the *first* expression\n\n"
-           "  PartExpression(exp, bool and_expr)\n"
-           "      string   exp: This represents the expression\n"
-           "      bool and_exp: If true the expression is to be anded, with a previously added expression\n"
-           "                    If false the expression is to be 'ored', with a previously added expression\n"
-           "\nUsage:\n"
-           "To add simple expression this class can be by-passed, i.e. can use:\n\n"
-           ".. code-block:: python\n\n"
-           "  task = Task('t1')\n"
-           "  task.add_trigger( 't2 == active' )\n"
-           "  task.add_complete( 't2 == complete' )\n\n"
-           "To add large triggers and complete expression:\n\n"
-           ".. code-block:: python\n\n"
-           "  exp1 = PartExpression('t1 == complete')\n  # a simple expression can be added as a string\n"
-           "  ....\n"
-           "  task2.add_part_trigger( PartExpression('t1 == complete or t4 == complete') ) \n"
-           "  task2.add_part_trigger( PartExpression('t5 == active',True) )    # anded with first expression\n"
-           "  task2.add_part_trigger( PartExpression('t7 == active',False) )   # or'ed with last expression added\n\n"
-           "The trigger for task2 is equivalent to\n"
-           "'t1 == complete or t4 == complete and t5 == active or t7 == active'";
-}
-
-const char* DefsDoc::expression_doc() {
-    return "Expression holds `trigger`_ or `complete expression`_. Also see :py:class:`ecflow.Trigger`\n\n"
-           "Expressions can contain references to events, meters, user variables,repeat variables and generated "
-           "variables.\n"
-           "Expressions hold a list of part expressions. This allows us to split a large trigger or complete\n"
-           "expression into smaller ones.\n"
-           "\nConstructor::\n\n"
-           "   Expression( expression )\n"
-           "      string expression  : This typically represents the complete expression\n"
-           "                           however part expression can still be added\n"
-           "   Expression( part )\n"
-           "      PartExpression part: The first part expression should have no 'and/or' set\n"
-           "\nUsage:\n"
-           "To add simple expression this class can be by passed, i.e. can use:\n\n"
-           ".. code-block:: python\n\n"
-           "  task = Task('t1')\n"
-           "  task.add_trigger( 't2 == active' )\n"
-           "  task.add_complete( 't2 == complete' )\n"
-           "\n"
-           "  task = Task('t2')\n"
-           "  task.add_trigger( 't1 == active' )\n"
-           "  task.add_part_trigger( 't3 == active', True)\n\n"
-           "To store and add large expressions use a Expression with PartExpression:\n\n"
-           ".. code-block:: python\n\n"
-           "  big_expr = Expression( PartExpression('t1 == complete or t4 == complete') )\n"
-           "  big_expr.add( PartExpression('t5 == active',True) )\n"
-           "  big_expr.add( PartExpression('t7 == active',False) )\n"
-           "  task.add_trigger( big_expr)\n\n"
-           "In the example above the trigger for task is equivalent to\n"
-           "'t1 == complete or t4 == complete and t5 == active or t7 == active'\n\n"
-           ".. code-block:: python\n\n"
-           "  big_expr2 = Expression('t0 == complete'))\n"
-           "  big_expr2.add( PartExpression('t1 == complete or t4 == complete',True) )\n"
-           "  big_expr2.add( PartExpression('t5 == active',False) )\n"
-           "  task2.add_trigger( big_expr2)\n\n"
-           "Here the trigger for task2 is equivalent to\n"
-           "'t0 == complete and t1 == complete or t4 == complete or t5 == active'";
-}
-
-const char* DefsDoc::add_trigger_doc() {
-    return "Add a `trigger`_ or `complete expression`_.Also see :py:class:`ecflow.Trigger`\n\n"
-           "This defines a dependency for a `node`_.\n"
-           "There can only be one `trigger`_ or `complete expression`_ dependency per node.\n"
-           "A `node`_ with a trigger can only be activated when the trigger has expired.\n"
-           "A trigger holds a node as long as the expression returns false.\n"
-           "\nException:\n\n"
-           "- Will throw RuntimeError if multiple trigger or complete expression are added\n"
-           "- Will throw RuntimeError if first expression is added as 'AND' or 'OR' expression\n"
-           "  Like wise second and subsequent expression must have 'AND' or 'OR' booleans set\n"
-           "\nUsage:\n\n"
-           "Note we cannot make multiple add_trigger(..) calls on the same `task`_!\n"
-           "to add a simple trigger:\n\n"
-           ".. code-block:: python\n\n"
-           "  task1.add_trigger( 't2 == active' )\n"
-           "  task2.add_trigger( 't1 == complete or t4 == complete' )\n"
-           "  task3.add_trigger( 't5 == active' )\n"
-           "\n"
-           "Long expression can be broken up using add_part_trigger:\n\n"
-           ".. code-block:: python\n\n"
-           "  task2.add_part_trigger( 't1 == complete or t4 == complete')\n"
-           "  task2.add_part_trigger( 't5 == active',True)  # True means  AND\n"
-           "  task2.add_part_trigger( 't7 == active',False) # False means OR\n\n"
-           "The trigger for task2 is equivalent to:\n"
-           "'t1 == complete or t4 == complete and t5 == active or t7 == active'";
-}
-
-const char* DefsDoc::trigger() {
-    return "Add a `trigger`_ or `complete expression`_.\n\n"
-           "This defines a dependency for a `node`_.\n"
-           "There can only be one `trigger`_ or `complete expression`_ dependency per node.\n"
-           "A `node`_ with a trigger can only be activated when the trigger has expired.\n"
-           "Triggers can reference nodes, events, meters, variables, repeats, limits and late flag\n"
-           "A trigger holds a node as long as the expression returns false.\n"
-           "\nException:\n\n"
-           "- Will throw RuntimeError if first expression is added as 'AND' or 'OR' expression\n"
-           "  Like wise second and subsequent expression must have 'AND' or 'OR' booleans set\n"
-           "\nUsage:\n\n"
-           "Multiple trigger will automatically be *anded* together, If *or* is required please\n"
-           "use bool 'False' as the last argument i.e. :\n\n"
-           ".. code-block:: python\n\n"
-           "  task1.add( Trigger('t2 == active' ),\n"
-           "             Trigger('t1 == complete or t4 == complete' ),\n"
-           "             Trigger('t5 == active',False))\n"
-           "\n"
-           "The trigger for task1 is equivalent to :\n\n"
-           ".. code-block:: python\n\n"
-           "  t2 == active and t1 == complete or t4 == complete or t5 == active\n\n"
-           "Since a large number of triggers are of the form `<node> == complete` there are\n"
-           "are short cuts, these involves a use of a list :\n\n"
-           ".. code-block:: python\n\n"
-           "  task1.add( Trigger( ['t2','t3'] )) #  This is same as t2 == complete and t3 == complete\n\n"
-           "You can also use a node :\n\n"
-           ".. code-block:: python\n\n"
-           "  task1.add( Trigger( ['t2',taskx] ))\n\n"
-           "If the node 'taskx' has a parent, we use the full hierarchy, hence we will get a trigger\n"
-           "of the form :\n\n"
-           ".. code-block:: python\n\n"
-           "  t2 ==complete and /suite/family/taskx == complete\n\n"
-           "If however node taskx has not yet been added to its parent, we use a relative name in the trigger :\n\n"
-           ".. code-block:: python\n\n"
-           "  t2 ==complete and taskx == complete\n";
-}
-
-const char* DefsDoc::add_variable_doc() {
-    return "Adds a name value `variable`_. Also see :py:class:`ecflow.Edit`\n\n"
-           "This defines a variable for use in `variable substitution`_ in a `ecf script`_ file.\n"
-           "There can be any number of variables. The variables are names inside a pair of\n"
-           "'%' characters in an `ecf script`_. The name are case sensitive.\n"
-           "Special character in the value, must be placed inside single quotes if misinterpretation\n"
-           "is to be avoided.\n"
-           "The value of the variable replaces the variable name in the `ecf script`_ at `job creation` time.\n"
-           "The variable names for any given node must be unique. If duplicates are added then the\n"
-           "the last value added is kept.\n"
-           "\nException:\n\n"
-           "- Writes warning to standard output, if a duplicate variable name is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  task.add_variable( Variable('ECF_HOME','/tmp/'))\n"
-           "  task.add_variable( 'TMPDIR','/tmp/')\n"
-           "  task.add_variable( 'COUNT',2)\n"
-           "  a_dict = { 'name':'value', 'name2':'value2', 'name3':'value3' }\n"
-           "  task.add_variable(a_dict)\n";
-}
-
-const char* DefsDoc::add_label_doc() {
-    return "Adds a `label`_ to a `node`_. See :py:class:`ecflow.Label`\n\n"
-           "Labels can be updated from the jobs files, via `child command`_\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if a duplicate label name is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  task.add_label( Label('TEA','/me/'))\n"
-           "  task.add_label( 'Joe','/me/')\n\n"
-           "The corresponding child command in the .ecf script file might be:\n\n"
-           ".. code-block:: shell\n\n"
-           "  ecflow_client --label=TEA time\n"
-           "  ecflow_client --label=Joe ninety\n";
-}
-
-const char* DefsDoc::add_limit_doc() {
-    return "Adds a `limit`_ to a `node`_ for simple load management. See :py:class:`ecflow.Limit`\n\n"
-           "Multiple limits can be added, however the limit name must be unique.\n"
-           "For a node to be in a limit, a `inlimit`_ must be used.\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if a duplicate limit name is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  family.add_limit( Limit('load',12) )\n"
-           "  family.add_limit( 'load',12 )\n";
-}
-
-const char* DefsDoc::add_inlimit_doc() {
-    return "Adds a `inlimit`_ to a `node`_. See :py:class:`ecflow.InLimit`\n\n"
-           "InLimit reference a `limit`_/:py:class:`ecflow.Limit`. Duplicate InLimits are not allowed\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if a duplicate is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  task2.add_inlimit( InLimit('limitName','/s1/f1',2) )\n"
-           "  task2.add_inlimit( 'limitName','/s1/f1',2 )\n";
-}
-
-const char* DefsDoc::suite_doc() {
-    return "A `suite`_ is a collection of Families,Tasks,Variables, `repeat`_ and `clock`_ definitions\n\n"
-           "Suite is the only node that can be started using the begin API.\n"
-           "There are several ways of adding a suite, see example below and :py:class:`ecflow.Defs.add_suite`\n"
-           "\nConstructor::\n\n"
-           "  Suite(name, Nodes | attributes)\n"
-           "      string name : The Suite name. name must consist of alpha numeric characters or\n"
-           "                    underscore or dot. The first character cannot be a dot, as this\n"
-           "                    will interfere with trigger expressions. Case is significant\n"
-           "      Nodes | Attributes:(optional)\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if the name is not valid\n"
-           "- Throws a RuntimeError if duplicate suite names added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  defs = Defs()                  # create a empty definition. Root of all Suites\n"
-           "  suite = Suite('suite_1')       # create a stand alone suite\n"
-           "  defs.add_suite(suite)          # add suite to definition\n"
-           "  suite2 = defs.add_suite('s2')  # create a suite and add it to the defs\n\n"
-           "  defs = Defs(\n"
-           "           Suite('s1',\n"
-           "              Family('f1',\n"
-           "                 Task('t1'))))   # create in in-place\n";
-}
-
-const char* DefsDoc::family_doc() {
-    return "Create a `family`_ `node`_.A Family node lives inside a `suite`_ or another `family`_\n\n"
-           "A family is used to collect `task`_\\ s together or to group other families.\n"
-           "Typically you place tasks that are related to each other inside the same family\n"
-           "analogous to the way you create directories to contain related files.\n"
-           "There are two ways of adding a family, see example below.\n"
-           "\nConstructor::\n\n"
-           "  Family(name, Nodes | Attributes)\n"
-           "      string name : The Family name. name must consist of alpha numeric characters or\n"
-           "                    underscore or dot. The first character cannot be dot, as this\n"
-           "                    will interfere with trigger expressions. Case is significant\n"
-           "      Nodes | Attributes: (optional)\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if the name is not valid\n"
-           "- Throws a RuntimeError if a duplicate family is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  suite = Suite('suite_1')       # create a suite\n"
-           "  family = Family('family_1')    # create a family\n"
-           "  suite.add_family(family)       # add created family to a suite\n"
-           "  f2 = suite.add_family('f2')    # create a family f2 and add to suite\n\n"
-           "  # create in place\n"
-           "  defs = Defs(\n"
-           "           Suite('s1',\n"
-           "              Family('f1',\n"
-           "                 Task('t1',\n"
-           "                     Edit(SLEEP='10')))))\n";
-}
-
-const char* DefsDoc::task_doc() {
-    return "Creates a `task`_ `node`_. Task is a child of a :py:class:`ecflow.Suite` or :py:class:`ecflow.Family` "
-           "node.\n\n"
-           "Multiple Tasks can be added, however the task names must be unique for a given parent.\n"
-           "Note case is significant. Only Tasks can be submitted. A job inside a Task `ecf script`_ (i.e .ecf file)\n"
-           "should generally be re-entrant since a Task may be automatically submitted more than once if it aborts.\n"
-           "There are several ways of adding a task, see examples below\n"
-           "\nConstructor::\n\n"
-           "  Task(name, Attributes)\n"
-           "     string name : The Task name.Name must consist of alpha numeric characters or\n"
-           "                   underscore or dot. First character cannot be a dot.\n"
-           "                   Case is significant\n"
-           "     attributes: optional, i.e like Meter, Event, Trigger etc\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if the name is not valid\n"
-           "- Throws a RuntimeError if a duplicate Task is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  task = Task('t1')            # create a stand alone task\n"
-           "  family.add_task(task)        # add to the family\n"
-           "  t2 = family.add_task('t2')   # create a task t2 and add to the family\n\n"
-           "  # Create Task in place\n"
-           "  defs = Defs(\n"
-           "           Suite('s1',\n"
-           "              Family('f1',\n"
-           "                 Task('t1',\n"
-           "                    Trigger('1==1'),\n"
-           "                    Edit(SLEEP='10'))))) # add Trigger and Variables in place\n";
-}
-
-const char* DefsDoc::alias_doc() {
-    return "Aliases can be created by the GUI or via edit_script command.\n\n"
-           "Aliases provide a mechanism to edit/test task scripts without effecting the suite.\n"
-           "The Aliases parent is always a Task. Multiple Alias can be added\n";
-}
-
-const char* DefsDoc::add_suite_doc() {
-    return "Add a `suite`_ `node`_. See :py:class:`ecflow.Suite`\n\n"
-           "If a new suite is added which matches the name of an existing suite, then an exception is thrown.\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError is the suite name is not valid\n"
-           "- Throws RuntimeError if duplicate suite is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  defs = Defs()                # create a empty defs\n"
-           "  suite = Suite('suite')       # create a stand alone Suite \n"
-           "  defs.add_suite(suite)        # add suite to defs\n"
-           "  s2 = defs.add_suite('s2')    # create a suite and add to defs\n\n"
-           "  # Alternatively we can create Suite in place\n"
-           "  defs = Defs(\n"
-           "           Suite('s1',\n"
-           "              Family('f1',\n"
-           "                 Task('t1'))),\n"
-           "           Suite('s2',\n"
-           "              Family('f1',\n"
-           "                 Task('t1'))))\n";
-}
-
-const char* DefsDoc::add_extern_doc() {
-    return "`extern`_ refer to nodes that have not yet been defined typically due to cross suite `dependencies`_\n\n"
-           "`trigger`_ and `complete expression`_\\ s may refer to paths, and variables in other suites, that have not "
-           "been\n"
-           "loaded yet. The references to node paths and variable must exist, or exist as externs\n"
-           "Externs can be added manually or automatically.\n\n"
-           "Manual Method:\n\n"
-           ".. code-block:: python\n\n"
-           "  void add_extern(string nodePath )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  defs = Defs('file.def')\n"
-           "  ....\n"
-           "  defs.add_extern('/temp/bill:event_name')\n"
-           "  defs.add_extern('/temp/bill:meter_name')\n"
-           "  defs.add_extern('/temp/bill:repeat_name')\n"
-           "  defs.add_extern('/temp/bill:edit_name')\n"
-           "  defs.add_extern('/temp/bill')\n"
-           "\n"
-           "Automatic Method:\n"
-           "  This will scan all trigger and complete expressions, looking for paths and variables\n"
-           "  that have not been defined. The added benefit of this approach is that duplicates will not\n"
-           "  be added. It is the user's responsibility to check that extern's are eventually defined\n"
-           "  otherwise trigger expression will not evaluate correctly\n\n"
-           ".. code-block:: python\n\n"
-           "  void auto_add_externs(bool remove_existing_externs_first )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  defs = Defs('file.def')\n"
-           "  ...\n"
-           "  defs.auto_add_externs(True)   # remove existing extern first.\n";
-}
-
-const char* DefsDoc::node_doc() {
-    return "A Node class is the abstract base class for Suite, Family and Task\n\n"
-           "Every Node instance has a name, and a path relative to a suite";
-}
-
-const char* DefsDoc::node_container_doc() {
-    return "NodeContainer is the abstract base class for a Suite and Family\n\n"
-           "A NodeContainer can have Families and Tasks as children";
-}
-
-const char* DefsDoc::submittable_doc() {
-    return "Submittable is the abstract base class for a Task and Alias\n\n"
-           "It provides a process id, password and try number";
-}
-
-const char* DefsDoc::add_family_doc() {
-    return "Add a `family`_. See :py:class:`ecflow.Family`.\n\n"
-           "Multiple families can be added. However family names must be unique.\n"
-           "for a given parent. Families can be hierarchical.\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if a duplicate is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  suite = Suite('suite')          # create a suite\n"
-           "  f1 = Family('f1')               # create a family\n"
-           "  suite.add_family(f1)            # add family to suite\n"
-           "  f2 = suite.add_family('f2')     # create a family and add to suite\n";
-}
-
-const char* DefsDoc::add_task_doc() {
-    return "Add a `task`_. See :py:class:`ecflow.Task`\n\n"
-           "Multiple Tasks can be added. However Task names must be unique,\n"
-           "for a given parent. Task can be added to Familiy's or Suites.\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if a duplicate is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  f1 = Family('f1')      # create a family\n"
-           "  t1 = Task('t1')          # create a task\n"
-           "  f1.add_task(t1)          # add task to family\n"
-           "  t2 = f1.add_task('t2') # create task 't2' and add to family";
-}
-
-const char* DefsDoc::add_definition_doc() {
-    return "The Defs class holds the `suite definition`_ structure.\n\n"
-           "It contains all the :py:class:`ecflow.Suite` and hence acts like the root for suite node tree hierarchy.\n"
-           "The definition can be kept as python code, alternatively it can be saved as a flat\n"
-           "ASCII definition file.\n"
-           "If a definition is read in from disk, it will by default, check the `trigger`_ expressions.\n"
-           "If however the definition is created in python, then checking should be done explicitly:\n\n"
-           "   Defs(string)\n"
-           "      string - The Defs class take one argument which represents the file name\n"
-           "   Defs(Suite | Edit )\n"
-           "      :py:class:`ecflow.Suite`- One or more suites\n\n"
-           "      :py:class:`ecflow.Edit` - specifies user defined server variables\n"
-           "\nExample:\n\n"
-           ".. code-block:: python\n\n"
-           " # Build definition using Constructor approach, This allows indentation, to show the structure\n"
-           " # This is a made up example to demonstrate suite construction:\n"
-           " defs = Defs(\n"
-           "     Edit(SLEEP=10,FRED='bill'),  # user defined server variables\n"
-           "     Suite('s1'\n"
-           "         Clock(1, 1, 2010, False),\n"
-           "         Autocancel(1, 10, True),\n"
-           "         Task('t1'\n"
-           "             Edit({'a':'12', 'b':'bb'}, c='v',d='b'),\n"
-           "             Edit(g='d'),\n"
-           "             Edit(h=1),\n"
-           "             Event(1),\n"
-           "             Event(11,'event'),\n"
-           "             Meter('meter',0,10,10),\n"
-           "             Label('label','c'),\n"
-           "             Trigger('1==1'),\n"
-           "             Complete('1==1'),\n"
-           "             Limit('limit',10),Limit('limit2',10),\n"
-           "             InLimit('limitName','/limit',2),\n"
-           "             Defstatus(DState.complete),\n"
-           "             Today(0,30),Today('00:59'),Today('00:00 11:30 00:01'),\n"
-           "             Time(0,30),Time('00:59'),Time('00:00 11:30 00:01'),\n"
-           "             Day('sunday'),Day(Days.monday),\n"
-           "             Date(1,1,0),Date(28,2,1960),\n"
-           "             Autocancel(3)\n"
-           "             ),\n"
-           "         [ Family('f{}'.format(i)) for i in range(1,6)]))\n\n"
-           "  defs.save_as_defs('filename.def')  # save defs into file\n\n"
-           "  defs = Defs()                      # create an empty defs\n"
-           "  suite = defs.add_suite('s1')\n"
-           "  family = suite.add_family('f1')\n"
-           "  for i in [ '_1', '_2', '_3' ]: family.add_task( 't' + i )\n"
-           "  defs.save_as_defs('filename.def')  # save defs into file\n"
-           "\n"
-           "Create a Defs from an existing file on disk:\n\n"
-           ".. code-block:: python\n\n"
-           "  defs = Defs('filename.def')   #  Will open and parse the file and create the Definition\n"
-           "  print(defs)\n";
-}
-
-const char* DefsDoc::add_event_doc() {
-    return "Add a `event`_. See :py:class:`ecflow.Event`\n"
-           "Events can be referenced in `trigger`_ and `complete expression`_\\ s\n\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if a duplicate is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1',\n"
-           "            Event(12),\n"
-           "            Event(11,'eventx'))             # Create events on Task creation\n\n"
-           "  t1.add_event( Event(10) )                 # Create with function on Task\n"
-           "  t1.add_event( Event(11,'Eventname') )\n"
-           "  t1.add_event( 12 )\n"
-           "  t1.add_event( 13, 'name')\n\n"
-           "To reference event 'flag' in a trigger:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1.add_event('flag')\n"
-           "  t2 = Task('t2',\n"
-           "            Trigger('t1:flag == set'))";
-}
-
-const char* DefsDoc::add_meter_doc() {
-    return "Add a `meter`_. See :py:class:`ecflow.Meter`\n"
-           "Meters can be referenced in `trigger`_ and `complete expression`_\\ s\n\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if a duplicate is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1',\n"
-           "            Meter('met',0,50))                   # create Meter on Task creation\n"
-           "  t1.add_meter( Meter('metername',0,100,50) )  # create Meter using function\n"
-           "  t1.add_meter( 'meter',0,200)\n\n"
-           "To reference in a trigger:\n\n"
-           ".. code-block:: python\n\n"
-           "  t2 = Task('t2')\n"
-           "  t2.add_trigger('t1:meter >= 10')\n";
-}
-
-const char* DefsDoc::add_date_doc() {
-    return "Add a `date`_ time dependency. See :py:class:`ecflow.Date`\n\n"
-           "A value of zero for day,month,year means every day, every month, every year\n"
-           "\nException:\n\n"
-           "- Throws RuntimeError if an invalid date is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1',\n"
-           "            Date('1.*.*'),\n"
-           "            Date(1,1,2010)))    # Create Date in place\n\n"
-           "  t1.add_date( Date(1,1,2010) ) # day,month,year\n"
-           "  t1.add_date( 2,1,2010)        # day,month,year\n"
-           "  t1.add_date( 1,0,0)           # day,month,year, the first of each month for every year\n";
-}
-
-const char* DefsDoc::add_day_doc() {
-    return "Add a `day`_ time dependency. See :py:class:`ecflow.Day`\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1',\n"
-           "            Day('sunday'))  # Create Day on Task creation\n\n"
-           "  t1.add_day( Day(Days.sunday) )\n"
-           "  t1.add_day( Days.monday)\n"
-           "  t1.add_day( 'tuesday' )\n";
-}
-
-const char* DefsDoc::add_today_doc() {
-    return "Add a `today`_ time dependency. See :py:class:`ecflow.Today`\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1',\n"
-           "            Today('+00:30 20:00 01:00')) # Create Today in Task constructor\n\n"
-           "  t1.add_today( '00:30' )\n"
-           "  t1.add_today( '+00:30' )\n"
-           "  t1.add_today( '+00:30 20:00 01:00' )\n"
-           "  t1.add_today( Today( 0,10 ))      # hour,min,relative =false\n"
-           "  t1.add_today( Today( 0,12,True )) # hour,min,relative\n"
-           "  t1.add_today( Today(TimeSlot(20,20),False))\n"
-           "  t1.add_today( 0,1 ))              # hour,min,relative=false\n"
-           "  t1.add_today( 0,3,False ))        # hour,min,relative=false\n"
-           "  start = TimeSlot(0,0)\n"
-           "  finish = TimeSlot(23,0)\n"
-           "  incr = TimeSlot(0,30)\n"
-           "  ts = TimeSeries( start, finish, incr, True)\n"
-           "  task2.add_today( Today(ts) )\n";
-}
-
-const char* DefsDoc::add_time_doc() {
-    return "Add a `time`_ dependency. See :py:class:`ecflow.Time`\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1', Time('+00:30 20:00 01:00')) # Create Time in Task constructor\n"
-           "  t1.add_time( '00:30' )\n"
-           "  t1.add_time( '+00:30' )\n"
-           "  t1.add_time( '+00:30 20:00 01:00' )\n"
-           "  t1.add_time( Time( 0,10 ))      # hour,min,relative =false\n"
-           "  t1.add_time( Time( 0,12,True )) # hour,min,relative\n"
-           "  t1.add_time( Time(TimeSlot(20,20),False))\n"
-           "  t1.add_time( 0,1 ))              # hour,min,relative=false\n"
-           "  t1.add_time( 0,3,False ))        # hour,min,relative=false\n"
-           "  start = TimeSlot(0,0)\n"
-           "  finish = TimeSlot(23,0)\n"
-           "  incr = TimeSlot(0,30)\n"
-           "  ts = TimeSeries( start, finish, incr, True)\n"
-           "  task2.add_time( Time(ts) )\n";
-}
-
-const char* DefsDoc::add_cron_doc() {
-    return "Add a `cron`_ time dependency. See :py:class:`ecflow.Cron`\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  start = TimeSlot(0,0)\n"
-           "  finish = TimeSlot(23,0)\n"
-           "  incr = TimeSlot(0,30)\n"
-           "  time_series = TimeSeries( start, finish, incr, True)\n"
-           "  cron = Cron()\n"
-           "  cron.set_week_days( [0,1,2,3,4,5,6] )\n"
-           "  cron.set_days_of_month( [1,2,3,4,5,6] )\n"
-           "  cron.set_months( [1,2,3,4,5,6] )\n"
-           "  cron.set_time_series( time_series )\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_cron( cron )\n\n"
-           "  # we can also create a Cron in the Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            Cron('+00:00 23:00 "
-           "00:30',days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6],months=[1,2,3,4,5,6]))\n";
-}
-
-const char* DefsDoc::add_late_doc() {
-    return "Add a `late`_ attribute. See :py:class:`ecflow.Late`\n\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one late is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  late = Late()\n"
-           "  late.submitted( 20,10 )     # hour,minute\n"
-           "  late.active(    20,10 )     # hour,minute\n"
-           "  late.complete(  20,10,True) # hour,minute,relative\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_late( late )\n\n"
-           "  # we can also create a Late in the Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            Late(submitted='20:10',active='20:10',complete='+20:10'))\n";
-}
-
-const char* DefsDoc::add_autocancel_doc() {
-    return "Add a `autocancel` attribute. See :py:class:`ecflow.Autocancel`\n\n"
-           "This will delete the node on completion. The deletion may be delayed by\n"
-           "an amount of time in hours and minutes or expressed as days\n"
-           "Node deletion is not immediate. The nodes are checked once a minute\n"
-           "and expired auto cancel nodes are deleted\n"
-           "A node may only have one auto cancel attribute\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one auto cancel is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_autocancel( Autocancel(20,10,False) )  # hour,min, relative\n"
-           "  t2 = Task('t2')\n"
-           "  t2.add_autocancel( 3 )                        # 3 days \n"
-           "  t3 = Task('t3')\n"
-           "  t3.add_autocancel( 20,10,True )               # hour,minutes,relative\n"
-           "  t4 = Task('t4')\n"
-           "  t4.add_autocancel( TimeSlot(20,10),True )     # hour,minutes,relative\n\n"
-           "  # we can also create a Autocancel in the Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            Autocancel(20,10,False))\n";
-}
-
-const char* DefsDoc::add_autoarchive_doc() {
-    return "Add a `autoarchive` attribute. See :py:class:`ecflow.Autoarchive`\n\n"
-           "Provides a way to automatically archive a suite/family which has completed.(i.e remove children)\n"
-           "This is required when dealing with super large suite/families, they can be archived off, and then restored "
-           "later.\n"
-           "The node can be recovered using 'autorestore',begin,re-queue and manually via ecflow_client --restore.\n"
-           "The archived node is written to disk, as ECF_HOME/<host>.<port>.ECF_NAME.check,\n"
-           "where '/' is replaced with ':' in ECF_NAME.\n"
-           "The removal may be delayed by an amount of time in hours and minutes or expressed as days\n"
-           "Node removal is not immediate. The nodes are checked once a minute\n"
-           "A Node may only have one autoarchive attribute\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one auto archive is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_autoarchive( Autoarchive(20,10,False) )  # hour,min, relative\n"
-           "  t2 = Task('t2')\n"
-           "  t2.add_autoarchive( 3 )                        # 3 days \n"
-           "  t3 = Task('t3')\n"
-           "  t3.add_autoarchive( 20,10,True )               # hour,minutes,relative\n"
-           "  t4 = Task('t4')\n"
-           "  t4.add_autoarchive( TimeSlot(20,10),True )     # hour,minutes,relative\n\n"
-           "  # we can also create a Autoarchive in the Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            Autoarchive(20,10,False))\n";
-}
-
-const char* DefsDoc::add_autorestore_doc() {
-    return "Add a `autorestore` attribute. See :py:class:`ecflow.Autorestore`\n\n"
-           "Auto-restore is used to automatically restore a previously auto-archived node.\n"
-           "The restore will fail if:\n\n"
-           " - The node has not been archived\n"
-           " - The node has children.\n"
-           " - The file ECF_HOME/<host>.<port>.ECF_NAME.check does not exist\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one autorestore is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_autorestore( ['/s1/f1'] )   \n"
-           "  t2 = Task('t2')\n"
-           "  t2.add_autorestore( Autorestore(['/s2/f1','/s1/f2']) )  \n"
-           "  # we can also create a Autorestore in the Task constructor like any other attribute\n"
-           "  t2 = Task('t2', Autorestore(['/s2/f1','/s1/f2'] ))\n";
-}
-
-const char* DefsDoc::add_verify_doc() {
-    return "Add a Verify attribute.\n\n"
-           "Used in python simulation used to assert that a particular state was reached."
-           "  t2 = Task('t2',\n"
-           "             Verify(State.complete, 6)) # verify task completes 6 times during simulation\n";
-}
-
-const char* DefsDoc::add_repeat_date_doc() {
-    return "Add a RepeatDate attribute. See :py:class:`ecflow.RepeatDate`\n\n"
-           "A node can only have one repeat\n"
-           "Reference to a RepeatDate in a trigger will use date arithmetic in a sub expression. i.e.\n"
-           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer\n\n"
-           "   trigger /suite/family:YMD + 1 > 20190101\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one repeat is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_repeat( RepeatDate('YMD',20100111,20100115) )\n\n"
-           "  # we can also create a repeat in Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            RepeatDate('YMD',20100111,20100115))\n";
-}
-
-const char* DefsDoc::add_repeat_datetime_doc() {
-    return "Add a RepeatDateTime attribute. See :py:class:`ecflow.RepeatDateTime`\n\n"
-           "A node can only have one repeat.\n"
-           "When a RepeatDateTime is used in a trigger expression, the arithmetic value of the Repeat decays to second.\n"
-           "For example, the expression `/suite/family:DATETIME + 1` is evaluated as the number of seconds represented "
-           "by `/suite/family:DT` (since the reference epoch, i.e. 19700101T000000) plus 1."
-           "The result is an integer.\n\n"
-           "   trigger /suite/family:DT + 1 > 123456\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one repeat is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_repeat(RepeatDateTime('DT', '20100111T120000', '20100115T000000', '12:00:00'))\n\n"
-           "  # we can also create a repeat in Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            RepeatDateTime('DT', '20100101T000000', '20100115T000000', '1:00:00'))\n";
-}
-
-const char* DefsDoc::add_repeat_date_list_doc() {
-    return "Add a RepeatDateList attribute. See :py:class:`ecflow.RepeatDateList`\n\n"
-           "A node can only have one repeat\n"
-           "Reference to a RepeatDateList in a trigger will use date arithmetic. i.e.\n"
-           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer:\n\n"
-           ".. code-block:: python\n\n"
-           "  trigger /suite/family:YMD + 1 > 20190101\n\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one repeat is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_repeat( RepeatDateList('YMD',[20100111,20100115]) )\n\n"
-           "  # we can also create a repeat in Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            RepeatDateList('YMD',[20100111,20100115]))\n";
-}
-
-const char* DefsDoc::add_repeat_integer_doc() {
-    return "Add a RepeatInteger attribute. See :py:class:`ecflow.RepeatInteger`\n\n"
-           "A node can only have one `repeat`_\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one repeat is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_repeat( RepeatInteger('testInteger',0,100,2) )\n\n"
-           "  # we can also create a repeat in Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            RepeatInteger('testInteger',0,100,2))\n";
-}
-
-const char* DefsDoc::add_repeat_string_doc() {
-    return "Add a RepeatString attribute. See :py:class:`ecflow.RepeatString`\n\n"
-           "A node can only have one `repeat`_\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one repeat is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_repeat( RepeatString('test_string',['a', 'b', 'c' ] ) )\n\n"
-           "  # we can also create a repeat in Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            RepeatString('test_string',['a', 'b', 'c' ] ) )\n";
-}
-
-const char* DefsDoc::add_repeat_enumerated_doc() {
-    return "Add a RepeatEnumerated attribute. See :py:class:`ecflow.RepeatEnumerated`\n\n"
-           "A node can only have one `repeat`_\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one repeat is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1')\n"
-           "  t1.add_repeat( RepeatEnumerated('test_string', ['red', 'green', 'blue' ] ) )\n\n"
-           "  # we can also create a repeat in Task constructor like any other attribute\n"
-           "  t2 = Task('t2',\n"
-           "            RepeatEnumerated('test_string', ['red', 'green', 'blue' ] ) )\n";
-}
-
-const char* DefsDoc::add_repeat_day_doc() {
-    return "Add a RepeatDay attribute. See :py:class:`ecflow.RepeatDay`\n\n"
-           "A node can only have one `repeat`_\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if more than one repeat is added\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t2 = Task('t2',\n"
-           "            RepeatDay(1))\n";
-}
-
-const char* DefsDoc::add_defstatus_doc() {
-    return "Set the default status( `defstatus`_ ) of node at begin or re queue. See :py:class:`ecflow.Defstatus`\n\n"
-           "A `defstatus`_ is useful in preventing suites from running automatically\n"
-           "once begun, or in setting Task's complete so they can be run selectively\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  t1 = Task('t1') + Defstatus('complete')\n"
-           "  t2 = Task('t2').add_defstatus( DState.suspended )\n\n"
-           "  # we can also create a Defstatus in the Task constructor like any other attribute\n"
-           "  t2 = Task('t3',\n"
-           "            Defstatus('complete'))\n";
-}
-
-const char* DefsDoc::jobgenctrl_doc() {
-    return "The class JobCreationCtrl is used in `job creation` checking\n\n"
-           "Constructor::\n\n"
-           "   JobCreationCtrl()\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   defs = Defs('my.def')                     # specify the definition we want to check, load into memory\n"
-           "   job_ctrl = JobCreationCtrl()\n"
-           "   job_ctrl.set_node_path('/suite/to_check') # will hierarchically check job creation under this node\n"
-           "   defs.check_job_creation(job_ctrl)         # job files generated to ECF_JOB\n"
-           "   print(job_ctrl.get_error_msg())            # report any errors in job generation\n"
-           "\n"
-           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
-           "   job_ctrl.set_dir_for_job_creation(tmp)    # generate jobs file under this directory\n"
-           "   defs.check_job_creation(job_ctrl)\n"
-           "   print(job_ctrl.get_error_msg())\n"
-           "\n"
-           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
-           "   job_ctrl.generate_temp_dir()              # automatically generate directory for job file\n"
-           "   defs.check_job_creation(job_ctrl)\n"
-           "   print(job_ctrl.get_error_msg())\n";
-}
-
-const char* DefsDoc::check_job_creation_doc() {
-    return "Check `job creation` .\n\n"
-           "Will check the following:\n\n"
-           "- `ecf script`_ files and includes files can be located\n"
-           "- recursive includes\n"
-           "- manual and comments `pre-processing`_\n"
-           "- `variable substitution`_\n\n"
-           "Some `task`_\\ s are dummy tasks have no associated `ecf script`_ file.\n"
-           "To disable error message for these tasks please add a variable called ECF_DUMMY_TASK to them.\n"
-           "Checking is done in conjunction with the class :py:class:`ecflow.JobCreationCtrl`.\n"
-           "If no node path is set on class JobCreationCtrl then all tasks are checked.\n"
-           "In the case where we want to check all tasks, use the convenience function that take no arguments.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   defs = Defs('my.def')                     # specify the defs we want to check, load into memory\n"
-           "   ...\n"
-           "   print(defs.check_job_creation())          # Check job generation for all tasks\n"
-           "   ...\n\n"
-           "   # throw on error and Output the tasks as they are being checked\n"
-           "   defs.check_job_creation(throw_on_error=TrueTrue,verbose=True)\n\n"
-           "   job_ctrl = JobCreationCtrl()\n"
-           "   job_ctrl.set_verbose(True)                # Output the tasks as they are being checked\n"
-           "   defs.check_job_creation(job_ctrl)         # Check job generation for all tasks, same as above\n"
-           "   print(job_ctrl.get_error_msg())\n"
-           "   ...\n"
-           "   job_ctrl = JobCreationCtrl()\n"
-           "   job_ctrl.set_node_path('/suite/to_check') # will hierarchically check job creation under this node\n"
-           "   defs.check_job_creation(job_ctrl)         # job files generated to ECF_JOB\n"
-           "   print(job_ctrl.get_error_msg())\n"
-           "   ...\n"
-           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
-           "   job_ctrl.set_dir_for_job_creation(tmp)    # generate jobs file under this directory\n"
-           "   defs.check_job_creation(job_ctrl)\n"
-           "   print(job_ctrl.get_error_msg())\n"
-           "   ...\n"
-           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
-           "   job_ctrl.generate_temp_dir()              # automatically generate directory for job file\n"
-           "   defs.check_job_creation(job_ctrl)\n"
-           "   print(job_ctrl.get_error_msg())\n";
-}
-
-const char* DefsDoc::generate_scripts_doc() {
-    return "Automatically generate template `ecf script`_\\ s for this definition\n"
-           "Will automatically add `child command`_\\ s for `event`_\\ s, `meter`_\\ s and `label`_\\ s.\n"
-           "This allows the definition to be refined with out worrying about the scripts.\n"
-           "However it should be noted that, this will create a lot of *duplicated* script contents\n"
-           "i.e in the absence of `event`_\\ s, `meter`_\\ s and `label`_\\ s, most of generated `ecf script`_ files "
-           "will\n"
-           "be the same. Hence should only be used an aid to debugging the definition.\n"
-           "It uses the contents of the definition to parameterise what gets\n"
-           "generated, and the location of the files. Will throw Exceptions for errors.\n"
-           "\nRequires:\n\n"
-           "- ECF_HOME: specified and accessible for all Tasks, otherwise RuntimeError is raised\n"
-           "- ECF_INCLUDE: specifies location for head.h and tail.h includes, will use angle brackets,\n"
-           "               i.e %include <head.h>, if the head.h and tail.h already exist they are used otherwise\n"
-           "               they are generated\n"
-           "\nOptional:\n\n"
-           "- ECF_FILES: If specified, then scripts are generated under this directory otherwise ECF_HOME is used.\n"
-           "             The missing directories are automatically created.\n"
-           "- ECF_CLIENT_EXE_PATH: if specified child command will use this, otherwise will use ecflow_client\n"
-           "                       and assume this accessible on the path.\n"
-           "- ECF_DUMMY_TASK: Will not generated scripts for this task.\n"
-           "- SLEEP: Uses this variable to delay time between calls to child commands, if not specified uses delay of "
-           "one second\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   defs = ecflow.Defs()\n"
-           "   suite = defs.add_suite('s1')\n"
-           "   suite.add_variable('ECF_HOME','/user/var/home')\n"
-           "   suite.add_variable('ECF_INCLUDE','/user/var/home/includes')\n"
-           "   for i in range(1,7) :\n"
-           "      fam = suite.add_family('f' + str(i))\n"
-           "      for t in ( 'a', 'b', 'c', 'd', 'e' ) :\n"
-           "        fam.add_task(t);\n"
-           "   defs.generate_scripts()   # generate '.ecf' and head.h/tail.h if required\n";
-}
-
-const char* DefsDoc::check() {
-    return "Check `trigger`_ and `complete expression`_\\ s and `limit`_\\ s\n\n"
-           "* Client Side: The client side can specify externs. Hence all node path references\n"
-           "  in `trigger`_ expressions, and `inlimit`_ references to `limit`_\\ s, that are\n"
-           "  unresolved and which do *not* appear in `extern`_\\ s are reported as errors\n"
-           "* Server Side: The server does not store externs. Hence all unresolved references\n"
-           "  are reported as errors\n\n"
-           "Returns a non empty string for any errors or warning\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   # Client side\n"
-           "   defs = Defs('my.def')        # Load my.def from disk\n"
-           "   ....\n"
-           "   print(defs.check()) # do the check\n"
-           "\n"
-           "   # Server Side\n"
-           "   try:\n"
-           "       ci = Client()             # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       print(ci.check('/suite'))\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
-
-const char* DefsDoc::simulate() {
-    return "Simulates a suite definition, allowing you predict/verify the behaviour of your suite in few seconds\n\n"
-           "The simulator will analyse the definition, and simulate the ecflow server.\n"
-           "Allowing time dependencies that span several months, to be simulated in a few seconds.\n"
-           "Ecflow allows the use of verify attributes. This example show how we can verify the number of times\n"
-           "a task should run, given a start(optional) and end time(optional):\n\n"
-           ".. code-block:: shell\n\n"
-           "  suite cron3              # use real clock otherwise clock starts when the simulations starts.\n"
-           "     clock real  1.1.2006  # define a start date for deterministic behaviour\n"
-           "     endclock   13.1.2006  # When to finish. end clock is *only* used for the simulator\n"
-           "     family cronFamily\n"
-           "        task t\n"
-           "           cron -d 10,11,12   10:00 11:00 01:00  # run on 10,11,12 of the month at 10am and 11am\n"
-           "           verify complete:6                     # task should complete 6 times between 1.1.2006 -> "
-           "13.1.2006\n"
-           "     endfamily\n"
-           "  endsuite\n\n"
-           "Please note, for deterministic behaviour, the start and end clock should be specified.\n"
-           "However if no 'endclock' is specified the simulation will assume the following defaults.\n\n"
-           "- No time dependencies: 24 hours\n"
-           "- time || today       : 24 hours\n"
-           "- day                 : 1 week\n"
-           "- date                : 1 month\n"
-           "- cron                : 1 year\n"
-           "- repeat              : 1 year\n\n"
-           "If there no time dependencies with an minute resolution, then the simulator will by default\n"
-           "use 1 hour resolution. This needs to be taken into account when specifying the verify attribute\n"
-           "If the simulation does not complete it creates  defs.flat and  defs.depth files.\n"
-           "This provides clues as to the state of the definition at the end of the simulation\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   defs = Defs('my.def')        # specify the defs we want to simulate\n"
-           "   ....\n"
-           "   theResults = defs.simulate()\n"
-           "   print(theResults)\n";
-}
-
-const char* DefsDoc::get_server_state() {
-    return "Returns the `ecflow_server`_ state: See `server states`_\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   try:\n"
-           "       ci = Client()           # use default host(ECF_HOST) & port(ECF_PORT)\n"
-           "       ci.shutdown_server()\n"
-           "       ci.sync_local()\n"
-           "       assert ci.get_defs().get_server_state() == SState.SHUTDOWN, 'Expected server to be shutdown'\n"
-           "   except RuntimeError, e:\n"
-           "       print(str(e))\n";
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/DefsDoc.hpp 5.13.0-1/Pyext/src/ecflow/python/DefsDoc.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/DefsDoc.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/DefsDoc.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,77 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_DefsDoc_HPP
-#define ecflow_python_DefsDoc_HPP
-
-#include <boost/core/noncopyable.hpp>
-
-// ===========================================================================
-// IMPORTANT: These appear as python doc strings.
-//            Additionally they are auto documented using sphinx-poco
-//            Hence the doc strings use reStructuredText markup.
-// ===========================================================================
-class DefsDoc {
-public:
-    DefsDoc()                          = delete;
-    DefsDoc(const DefsDoc&)            = delete;
-    DefsDoc& operator=(const DefsDoc&) = delete;
-
-    static const char* add();
-    static const char* abs_node_path_doc();
-    static const char* part_expression_doc();
-    static const char* expression_doc();
-    static const char* add_trigger_doc();
-    static const char* trigger();
-    static const char* add_variable_doc();
-    static const char* add_label_doc();
-    static const char* add_limit_doc();
-    static const char* add_inlimit_doc();
-    static const char* node_doc();
-    static const char* node_container_doc();
-    static const char* submittable_doc();
-    static const char* task_doc();
-    static const char* alias_doc();
-    static const char* family_doc();
-    static const char* add_suite_doc();
-    static const char* add_extern_doc();
-    static const char* add_family_doc();
-    static const char* add_task_doc();
-    static const char* suite_doc();
-    static const char* add_definition_doc();
-    static const char* add_event_doc();
-    static const char* add_meter_doc();
-    static const char* add_date_doc();
-    static const char* add_day_doc();
-    static const char* add_today_doc();
-    static const char* add_time_doc();
-    static const char* add_cron_doc();
-    static const char* add_late_doc();
-    static const char* add_autocancel_doc();
-    static const char* add_autoarchive_doc();
-    static const char* add_autorestore_doc();
-    static const char* add_verify_doc();
-    static const char* add_repeat_date_doc();
-    static const char* add_repeat_datetime_doc();
-    static const char* add_repeat_date_list_doc();
-    static const char* add_repeat_integer_doc();
-    static const char* add_repeat_string_doc();
-    static const char* add_repeat_enumerated_doc();
-    static const char* add_repeat_day_doc();
-    static const char* add_defstatus_doc();
-    static const char* jobgenctrl_doc();
-    static const char* check_job_creation_doc();
-    static const char* generate_scripts_doc();
-    static const char* check();
-    static const char* simulate();
-    static const char* get_server_state();
-};
-
-#endif /* ecflow_python_DefsDoc_HPP */
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/EcfExt.cpp 5.13.0-1/Pyext/src/ecflow/python/EcfExt.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/EcfExt.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/EcfExt.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/python.hpp>
-#include <boost/python/docstring_options.hpp>
-
-using namespace boost::python;
-
-void export_Core();
-void export_NodeAttr();
-void export_Node();
-void export_Task();
-void export_SuiteAndFamily();
-void export_Defs();
-void export_Client();
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-BOOST_PYTHON_MODULE(ecflow) {
-    boost::python::docstring_options doc_options(
-        true, // show the docstrings from here
-        true, // show Python signatures.
-        false // Don't mention the C++ method signatures in the generated docstrings
-    );
-    scope().attr("__doc__") = "The ecflow module provides the python bindings/api for creating definition structure "
-                              "and communicating with the server.";
-
-    export_Core();
-    export_NodeAttr();
-    export_Node();
-    export_Task();
-    export_SuiteAndFamily();
-    export_Defs();
-    export_Client();
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/Edit.cpp 5.13.0-1/Pyext/src/ecflow/python/Edit.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/Edit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/Edit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/Edit.hpp"
-
-#include <stdexcept>
-
-#include <boost/python.hpp>
-
-#include "ecflow/python/BoostPythonUtil.hpp"
-
-using namespace boost::python;
-using namespace std;
-namespace bp = boost::python;
-
-Edit::Edit(const boost::python::dict& dict) {
-    BoostPythonUtil::dict_to_str_vec(dict, vec_);
-}
-Edit::Edit(const boost::python::dict& dict, const boost::python::dict& dict2) {
-    BoostPythonUtil::dict_to_str_vec(dict, vec_);
-    BoostPythonUtil::dict_to_str_vec(dict2, vec_);
-}
-
-object Edit::init(boost::python::tuple args, dict kw) {
-    // cout << "Edit::init args: " << len(args) << " kwargs " << len(kw) << "\n";
-    //  args[0] is Edit(i.e self)
-    for (int i = 1; i < len(args); ++i) {
-        if (boost::python::extract<dict>(args[i]).check()) {
-            dict d = boost::python::extract<dict>(args[i]);
-            return args[0].attr("__init__")(d, kw); // calls -> .def(init<dict,dict>() -> Edit(dict,dict)
-        }
-        else
-            throw std::runtime_error("Edit::Edit: only accepts dictionary and key word arguments");
-    }
-    bp::tuple rest(args.slice(1, _));
-    return args[0].attr("__init__")(kw); // calls -> .def(init<dict>() -> Edit(const boost::python::dict& dict)
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/Edit.hpp 5.13.0-1/Pyext/src/ecflow/python/Edit.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/Edit.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/Edit.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_Edit_HPP
-#define ecflow_python_Edit_HPP
-
-#include <vector>
-
-#include <boost/python.hpp>
-
-#include "ecflow/attribute/Variable.hpp"
-
-class Edit {
-public:
-    explicit Edit(const boost::python::dict& dict);
-    Edit(const boost::python::dict& dict, const boost::python::dict& dict2);
-    const std::vector<Variable>& variables() const { return vec_; }
-    static std::string to_string() { return "edit"; }
-    static boost::python::object init(boost::python::tuple args, boost::python::dict kw);
-
-private:
-    std::vector<Variable> vec_;
-};
-
-#endif /* ecflow_python_Edit_HPP */
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ExportClient.cpp 5.13.0-1/Pyext/src/ecflow/python/ExportClient.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ExportClient.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ExportClient.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,769 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <algorithm> // for std::transform
-
-#include <boost/python.hpp>
-
-#include "ecflow/base/WhyCmd.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/client/UrlCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/NState.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/ClientDoc.hpp"
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/Openssl.hpp"
-#endif
-
-using namespace boost::python;
-using namespace std;
-namespace bp = boost::python;
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-
-void set_host_port(ClientInvoker* self, const std::string& host, int port) {
-    self->set_host_port(host, ecf::convert_to<std::string>(port));
-}
-
-std::string version(ClientInvoker* self) {
-    return ecf::Version::raw();
-}
-std::string server_version(ClientInvoker* self) {
-    self->server_version();
-    return self->get_string();
-}
-
-const std::string& query(ClientInvoker* self,
-                         const std::string& query_type,
-                         const std::string& path_to_attribute,
-                         const std::string& attribute) {
-    self->query(query_type, path_to_attribute, attribute);
-    return self->get_string();
-}
-const std::string& query1(ClientInvoker* self, const std::string& query_type, const std::string& path_to_attribute) {
-    self->query(query_type, path_to_attribute, "");
-    return self->get_string();
-}
-
-// const std::string& get_log(ClientInvoker* self) { self->getLog(); return self->get_string();}
-
-const std::string& get_log(ClientInvoker* self, int lastLines) {
-    self->getLog(lastLines);
-    return self->get_string();
-}
-
-const std::string& edit_script_edit(ClientInvoker* self, const std::string& absNodePath) {
-    self->edit_script_edit(absNodePath);
-    return self->get_string();
-}
-
-const std::string& edit_script_preprocess(ClientInvoker* self, const std::string& absNodePath) {
-    self->edit_script_preprocess(absNodePath);
-    return self->get_string();
-}
-
-int edit_script_submit(ClientInvoker* self,
-                       const std::string& absNodePath,
-                       const bp::list& name_values,
-                       const bp::list& lines,
-                       bool alias = false,
-                       bool run   = true) {
-    std::vector<std::string> file_contents;
-    BoostPythonUtil::list_to_str_vec(lines, file_contents);
-
-    std::vector<std::string> namv;
-    BoostPythonUtil::list_to_str_vec(name_values, namv);
-    NameValueVec used_variables;
-    char sep = '=';
-    for (size_t i = 0; i < namv.size(); ++i) {
-        string::size_type pos = namv[i].find(sep);
-        used_variables.push_back(std::make_pair(namv[i].substr(0, pos - 1), namv[i].substr(pos + 1, namv[i].length())));
-    }
-    return self->edit_script_submit(absNodePath, used_variables, file_contents, alias, run);
-}
-
-namespace /* __ANONYMOUS__ */ {
-
-boost::python::object convert_to_pyobject(const std::string& s, bool as_bytes) {
-    boost::python::object result;
-    if (as_bytes) {
-        result = boost::python::object(boost::python::handle<>(PyBytes_FromObject(
-            PyMemoryView_FromMemory(const_cast<char*>(s.data()), static_cast<ssize_t>(s.size()), PyBUF_READ))));
-    }
-    else {
-        result = boost::python::object(
-            boost::python::handle<>(PyUnicode_FromStringAndSize(s.data(), static_cast<ssize_t>(s.size()))));
-    }
-    return result;
-}
-
-} // namespace
-
-boost::python::object get_file(ClientInvoker* self,
-                               const std::string& absNodePath,
-                               const std::string& file_type = "script",
-                               const std::string& max_lines = "10000",
-                               bool as_bytes                = false) {
-    self->file(absNodePath, file_type, max_lines);
-    const std::string& s = self->get_string();
-
-    return convert_to_pyobject(s, as_bytes);
-}
-
-/// Set the CLI to enable output to standard out
-class CliSetter {
-public:
-    explicit CliSetter(ClientInvoker* self) : _self(self) { self->set_cli(true); }
-    ~CliSetter() { _self->set_cli(false); }
-
-private:
-    ClientInvoker* _self;
-};
-
-const std::string& stats(ClientInvoker* self, bool to_stdout = true) {
-    self->stats();
-    if (to_stdout) {
-        std::cout << self->server_reply().get_string() << std::endl;
-    }
-    return self->server_reply().get_string();
-}
-BOOST_PYTHON_FUNCTION_OVERLOADS(stats_overloads, stats, 1, 2)
-
-void stats_reset(ClientInvoker* self) {
-    self->stats_reset();
-}
-bp::list suites(ClientInvoker* self) {
-    self->suites();
-    const std::vector<std::string>& the_suites = self->server_reply().get_string_vec();
-    bp::list list;
-    size_t the_size = the_suites.size();
-    for (size_t i = 0; i < the_size; i++)
-        list.append(the_suites[i]);
-    return list;
-}
-
-bool news_local(ClientInvoker* self) {
-    self->news_local();
-    return self->get_news();
-}
-
-void free_trigger_dep(ClientInvoker* self, const std::string& path) {
-    self->freeDep(path, true /*trigger*/, false /*all*/, false /*date*/, false /*time*/);
-}
-void free_date_dep(ClientInvoker* self, const std::string& path) {
-    self->freeDep(path, false /*trigger*/, false /*all*/, true /*date*/, false /*time*/);
-}
-void free_time_dep(ClientInvoker* self, const std::string& path) {
-    self->freeDep(path, false /*trigger*/, false /*all*/, false /*date*/, true /*time*/);
-}
-void free_all_dep(ClientInvoker* self, const std::string& path) {
-    self->freeDep(path, false /*trigger*/, true /*all*/, false /*date*/, false /*time*/);
-}
-void free_trigger_dep1(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->freeDep(paths, true /*trigger*/, false /*all*/, false /*date*/, false /*time*/);
-}
-void free_date_dep1(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->freeDep(paths, false /*trigger*/, false /*all*/, true /*date*/, false /*time*/);
-}
-void free_time_dep1(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->freeDep(paths, false /*trigger*/, false /*all*/, false /*date*/, true /*time*/);
-}
-void free_all_dep1(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->freeDep(paths, false /*trigger*/, true /*all*/, false /*date*/, false /*time*/);
-}
-
-void force_state(ClientInvoker* self, const std::string& path, NState::State state) {
-    self->force(path, NState::toString(state), false);
-}
-void force_states(ClientInvoker* self, const bp::list& list, NState::State state) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->force(paths, NState::toString(state), false);
-}
-void force_state_recursive(ClientInvoker* self, const std::string& path, NState::State state) {
-    self->force(path, NState::toString(state), true);
-}
-void force_states_recursive(ClientInvoker* self, const bp::list& list, NState::State state) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->force(paths, NState::toString(state), true);
-}
-void force_event(ClientInvoker* self, const std::string& path, const std::string& set_or_clear) {
-    self->force(path, set_or_clear);
-}
-void force_events(ClientInvoker* self, const bp::list& list, const std::string& set_or_clear) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->force(paths, set_or_clear);
-}
-
-void run(ClientInvoker* self, const std::string& path, bool force) {
-    self->run(path, force);
-}
-void runs(ClientInvoker* self, const bp::list& list, bool force) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->run(paths, force);
-}
-void requeue(ClientInvoker* self, std::string path, const std::string& option) {
-    self->requeue(path, option);
-}
-void requeues(ClientInvoker* self, const bp::list& list, const std::string& option) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->requeue(paths, option);
-}
-void suspend(ClientInvoker* self, const std::string& path) {
-    self->suspend(path);
-}
-void suspends(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->suspend(paths);
-}
-void resume(ClientInvoker* self, const std::string& path) {
-    self->resume(path);
-}
-void resumes(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->resume(paths);
-}
-void archive(ClientInvoker* self, const std::string& path) {
-    self->archive(path);
-}
-void archives(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->archive(paths);
-}
-void restore(ClientInvoker* self, const std::string& path) {
-    self->restore(path);
-}
-void restores(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->restore(paths);
-}
-void the_status(ClientInvoker* self, const std::string& path) {
-    self->status(path);
-}
-void statuss(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->status(paths);
-}
-void do_kill(ClientInvoker* self, const std::string& path) {
-    self->kill(path);
-}
-void do_kills(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->kill(paths);
-}
-const std::string& check(ClientInvoker* self, const std::string& node_path) {
-    self->check(node_path);
-    return self->get_string();
-}
-const std::string& checks(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->check(paths);
-    return self->get_string();
-}
-
-void delete_node(ClientInvoker* self, const bp::list& list, bool force) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->delete_nodes(paths, force);
-}
-
-void ch_suites(ClientInvoker* self) {
-    CliSetter cli(self);
-    self->ch_suites();
-}
-void ch_register(ClientInvoker* self, bool auto_add_new_suites, const bp::list& list) {
-    std::vector<std::string> suites;
-    BoostPythonUtil::list_to_str_vec(list, suites);
-    self->ch_register(auto_add_new_suites, suites);
-}
-
-void ch_add(ClientInvoker* self, int client_handle, const bp::list& list) {
-    std::vector<std::string> suites;
-    BoostPythonUtil::list_to_str_vec(list, suites);
-    self->ch_add(client_handle, suites);
-}
-void ch1_add(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> suites;
-    BoostPythonUtil::list_to_str_vec(list, suites);
-    self->ch1_add(suites);
-}
-
-void ch_remove(ClientInvoker* self, int client_handle, const bp::list& list) {
-    std::vector<std::string> suites;
-    BoostPythonUtil::list_to_str_vec(list, suites);
-    self->ch_remove(client_handle, suites);
-}
-void ch1_remove(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> suites;
-    BoostPythonUtil::list_to_str_vec(list, suites);
-    self->ch1_remove(suites);
-}
-
-/// Need to provide override since the boolean argument is optional.
-/// This saves on client python code, on having to specify the optional arg
-void replace_1(ClientInvoker* self, const std::string& absNodePath, defs_ptr client_defs) {
-    self->replace_1(absNodePath, client_defs);
-}
-void replace_2(ClientInvoker* self, const std::string& absNodePath, const std::string& path_to_client_defs) {
-    self->replace(absNodePath, path_to_client_defs);
-}
-
-void order(ClientInvoker* self, const std::string& absNodePath, const std::string& the_order) {
-    self->order(absNodePath, the_order);
-}
-
-void alters(ClientInvoker* self,
-            const bp::list& list,
-            const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-            const std::string& attrType,
-            const std::string& name  = "",
-            const std::string& value = "") {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->check(paths);
-    self->alter(paths, alterType, attrType, name, value);
-}
-void alter(ClientInvoker* self,
-           const std::string& path,
-           const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
-           const std::string& attrType,
-           const std::string& name  = "",
-           const std::string& value = "") {
-    self->alter(path, alterType, attrType, name, value);
-}
-
-void alter_sorts(ClientInvoker* self, const bp::list& list, const std::string& attribute_name, bool recursive = true) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->check(paths);
-    self->alter_sort(paths, attribute_name, recursive);
-}
-void alter_sort(ClientInvoker* self,
-                const std::string& path,
-                const std::string& attribute_name,
-                bool recursive = true) {
-    self->alter_sort(std::vector<std::string>(1, path), attribute_name, recursive);
-}
-
-void set_child_pid(ClientInvoker* self, int pid) {
-    self->set_child_pid(ecf::convert_to<std::string>(pid));
-}
-
-void set_child_init_add_vars(ClientInvoker* self, const bp::dict& dict) {
-    std::vector<std::pair<std::string, std::string>> vars;
-    BoostPythonUtil::dict_to_str_vec(dict, vars);
-
-    std::vector<Variable> vec;
-    std::transform(vars.begin(),
-                   vars.end(),
-                   std::back_inserter(vec),
-                   [](const std::pair<std::string, std::string>& var) { return Variable(var.first, var.second); });
-
-    self->set_child_init_add_vars(vec);
-}
-
-void set_child_init_add_vars2(ClientInvoker* self, const bp::list& dict) {
-    std::vector<Variable> vec;
-    BoostPythonUtil::list_to_str_vec(dict, vec);
-    self->set_child_init_add_vars(vec);
-}
-
-void set_child_complete_del_vars(ClientInvoker* self, const bp::list& dict) {
-    std::vector<std::string> vars;
-    BoostPythonUtil::list_to_str_vec(dict, vars);
-    self->set_child_complete_del_vars(vars);
-}
-
-// Context mgr. The expression is evaluated and should result in an object called a ``context manager''
-// with expression [as variable]:
-//    with-block
-//
-// . The context manager must have __enter__() and __exit__() methods.
-// . The context manager's __enter__() method is called.
-//   The value returned is assigned to VAR.
-//   If no 'as VAR' clause is present, the value is simply discarded.
-// . The code in BLOCK is executed.
-// . If BLOCK raises an exception, the __exit__(type, value, traceback)
-//   is called with the exception details, the same values returned by sys.exc_info().
-//   The method's return value controls whether the exception is re-raised:
-//    any false value re-raises the exception, and True will result in suppressing it.
-//    You'll only rarely want to suppress the exception, because if you do the author
-//    of the code containing the 'with' statement will never realize anything went wrong.
-// .  If BLOCK didn't raise an exception, the __exit__() method is still called, but type, value, and traceback are all
-// None.
-//
-std::shared_ptr<ClientInvoker> client_enter(std::shared_ptr<ClientInvoker> self) {
-    return self;
-}
-bool client_exit(std::shared_ptr<ClientInvoker> self,
-                 const bp::object& type,
-                 const bp::object& value,
-                 const bp::object& traceback) {
-    self->ch1_drop();
-    return false;
-}
-
-const std::vector<Zombie>& zombieGet(ClientInvoker* self, int pid) {
-    self->zombieGet();
-    return self->server_reply().zombies();
-}
-
-void zombieFobCli(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->zombieFobCliPaths(paths);
-}
-void zombieFailCli(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->zombieFailCliPaths(paths);
-}
-void zombieAdoptCli(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->zombieAdoptCliPaths(paths);
-}
-void zombieBlockCli(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->zombieBlockCliPaths(paths);
-}
-void zombieRemoveCli(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->zombieRemoveCliPaths(paths);
-}
-void zombieKillCli(ClientInvoker* self, const bp::list& list) {
-    std::vector<std::string> paths;
-    BoostPythonUtil::list_to_str_vec(list, paths);
-    self->zombieKillCliPaths(paths);
-}
-
-void export_Client() {
-    // Need std::shared_ptr<ClientInvoker>, to add support for with( __enter__,__exit__)
-    class_<ClientInvoker, std::shared_ptr<ClientInvoker>, boost::noncopyable>("Client", ClientDoc::class_client())
-        .def(init<std::string>() /* host:port      */)
-        .def(init<std::string, std::string>() /* host, port      */)
-        .def(init<std::string, int>() /* host, port(int) */)
-        .def("__enter__", &client_enter) // allow with statement
-        .def("__exit__", &client_exit)   // allow with statement, remove last handle
-        .def("version", &version, "Returns the current client version")
-        .def("set_user_name",
-             &ClientInvoker::set_user_name,
-             "set user name. A password must be provided in the file <host>.<port>.ecf.custom_passwd")
-        .def("server_version",
-             &server_version,
-             "Returns the server version, can throw for old servers, that did not implement this request.")
-        .def("set_host_port", &ClientInvoker::set_host_port, ClientDoc::set_host_port())
-        .def("set_host_port", &ClientInvoker::set_hostport)
-        .def("set_host_port", &set_host_port)
-        .def("get_host",
-             &ClientInvoker::host,
-             return_value_policy<copy_const_reference>(),
-             "Return the host, assume set_host_port() has been set, otherwise return localhost")
-        .def("get_port",
-             &ClientInvoker::port,
-             return_value_policy<copy_const_reference>(),
-             "Return the port, assume set_host_port() has been set. otherwise returns 3141")
-        .def("set_retry_connection_period",
-             &ClientInvoker::set_retry_connection_period,
-             ClientDoc::set_retry_connection_period())
-        .def("set_connection_attempts", &ClientInvoker::set_connection_attempts, ClientDoc::set_connection_attempts())
-        .def("set_auto_sync",
-             &ClientInvoker::set_auto_sync,
-             "If true automatically sync with local definition after each call.")
-        .def("is_auto_sync_enabled", &ClientInvoker::is_auto_sync_enabled, "Returns true if automatic syncing enabled")
-        .def("get_defs", &ClientInvoker::defs, ClientDoc::get_defs())
-        .def("reset", &ClientInvoker::reset, "reset client definition, and handle number")
-        .def("in_sync", &ClientInvoker::in_sync, ClientDoc::in_sync())
-        .def("get_log", &get_log, return_value_policy<copy_const_reference>(), ClientDoc::get_log())
-        .def("edit_script_edit",
-             &edit_script_edit,
-             return_value_policy<copy_const_reference>(),
-             ClientDoc::edit_script_edit())
-        .def("edit_script_preprocess",
-             &edit_script_preprocess,
-             return_value_policy<copy_const_reference>(),
-             ClientDoc::edit_script_preprocess())
-        .def("edit_script_submit", &edit_script_submit, ClientDoc::edit_script_submit())
-        .def("new_log", &ClientInvoker::new_log, (bp::arg("path") = ""), ClientDoc::new_log())
-        .def("clear_log", &ClientInvoker::clearLog, ClientDoc::clear_log())
-        .def("flush_log", &ClientInvoker::flushLog, ClientDoc::flush_log())
-        .def("log_msg", &ClientInvoker::logMsg, ClientDoc::log_msg())
-        .def("restart_server", &ClientInvoker::restartServer, ClientDoc::restart_server())
-        .def("halt_server", &ClientInvoker::haltServer, ClientDoc::halt_server())
-        .def("shutdown_server", &ClientInvoker::shutdownServer, ClientDoc::shutdown_server())
-        .def("terminate_server", &ClientInvoker::terminateServer, ClientDoc::terminate_server())
-        .def("wait_for_server_reply",
-             &ClientInvoker::wait_for_server_reply,
-             (bp::arg("time_out") = 60),
-             ClientDoc::wait_for_server_reply())
-        .def("load",
-             &ClientInvoker::loadDefs,
-             (bp::arg("path_to_defs"),
-              bp::arg("force")      = false,
-              bp::arg("check_only") = false,
-              bp::arg("print")      = false,
-              bp::arg("stats")      = false),
-             ClientDoc::load_defs())
-        .def("load", &ClientInvoker::load, (bp::arg("defs"), bp::arg("force") = false), ClientDoc::load())
-        .def("get_server_defs", &ClientInvoker::getDefs, ClientDoc::get_server_defs())
-        .def("sync_local", &ClientInvoker::sync_local, (bp::arg("sync_suite_clock") = false), ClientDoc::sync())
-        .def("news_local", &news_local, ClientDoc::news())
-        .add_property("changed_node_paths",
-                      bp::range(&ClientInvoker::changed_node_paths_begin, &ClientInvoker::changed_node_paths_end),
-                      ClientDoc::changed_node_paths())
-        .def("suites", &suites, ClientDoc::suites())
-        .def("ch_register", &ch_register, ClientDoc::ch_register())
-        .def("ch_suites", &ch_suites, ClientDoc::ch_suites())
-        .def("ch_handle", &ClientInvoker::client_handle, ClientDoc::ch_register())
-        .def("ch_drop", &ClientInvoker::ch_drop, ClientDoc::ch_drop())
-        .def("ch_drop", &ClientInvoker::ch1_drop)
-        .def("ch_drop_user", &ClientInvoker::ch_drop_user, ClientDoc::ch_drop_user())
-        .def("ch_add", &ch_add, ClientDoc::ch_add())
-        .def("ch_add", &ch1_add)
-        .def("ch_remove", &ch_remove, ClientDoc::ch_remove())
-        .def("ch_remove", &ch1_remove)
-        .def("ch_auto_add", &ClientInvoker::ch_auto_add, ClientDoc::ch_auto_add())
-        .def("ch_auto_add", &ClientInvoker::ch1_auto_add)
-        .def("checkpt",
-             &ClientInvoker::checkPtDefs,
-             (bp::arg("mode")                     = ecf::CheckPt::UNDEFINED,
-              bp::arg("check_pt_interval")        = 0,
-              bp::arg("check_pt_save_alarm_time") = 0),
-             ClientDoc::checkpt())
-        .def("restore_from_checkpt", &ClientInvoker::restoreDefsFromCheckPt, ClientDoc::restore_from_checkpt())
-        .def("reload_wl_file", &ClientInvoker::reloadwsfile, ClientDoc::reload_wl_file())
-        .def("reload_passwd_file", &ClientInvoker::reloadpasswdfile, "reload the passwd file. <host>.<port>.ecf.passwd")
-        .def("reload_custom_passwd_file",
-             &ClientInvoker::reloadcustompasswdfile,
-             "reload the custom passwd file. <host>.<port>.ecf.custom_passwd. For users using ECF_USER or --user or "
-             "set_user_name()")
-        .def("requeue", &requeue, (bp::arg("abs_node_path"), bp::arg("option") = ""), ClientDoc::requeue())
-        .def("requeue", &requeues, (bp::arg("paths"), bp::arg("option") = ""))
-        .def("free_trigger_dep", &free_trigger_dep, ClientDoc::free_trigger_dep())
-        .def("free_trigger_dep", &free_trigger_dep1)
-        .def("free_date_dep", &free_date_dep, ClientDoc::free_date_dep())
-        .def("free_date_dep", &free_date_dep1)
-        .def("free_time_dep", &free_time_dep, ClientDoc::free_time_dep())
-        .def("free_time_dep", &free_time_dep1)
-        .def("free_all_dep", &free_all_dep, ClientDoc::free_all_dep())
-        .def("free_all_dep", &free_all_dep1)
-        .def("ping", &ClientInvoker::pingServer, ClientDoc::ping())
-        .def("stats", &stats, stats_overloads(args("to_stdout"), ClientDoc::stats())[return_value_policy<copy_const_reference>()])
-        .def("stats_reset", &stats_reset, ClientDoc::stats_reset())
-        .def("get_file",
-             &get_file,
-             (bp::arg("task"), bp::arg("type") = "script", bp::arg("max_lines") = "10000", bp::arg("as_bytes") = false),
-             ClientDoc::get_file())
-        .def("plug", &ClientInvoker::plug, ClientDoc::plug())
-        .def("query", &query, return_value_policy<copy_const_reference>(), ClientDoc::query())
-        .def("query", &query1, return_value_policy<copy_const_reference>(), ClientDoc::query())
-        .def("alter",
-             &alters,
-             (bp::arg("paths"),
-              bp::arg("alter_type"),
-              bp::arg("attribute_type"),
-              bp::arg("name")  = "",
-              bp::arg("value") = ""),
-             ClientDoc::alter())
-        .def("alter",
-             &alter,
-             (bp::arg("abs_node_path"),
-              bp::arg("alter_type"),
-              bp::arg("attribute_type"),
-              bp::arg("name")  = "",
-              bp::arg("value") = ""))
-        .def("sort_attributes",
-             &alter_sort,
-             (bp::arg("abs_node_path"), bp::arg("attribute_name"), bp::arg("recursive") = true))
-        .def(
-            "sort_attributes", &alter_sorts, (bp::arg("paths"), bp::arg("attribute_name"), bp::arg("recursive") = true))
-        .def("force_event", &force_event, ClientDoc::force_event())
-        .def("force_event", &force_events)
-        .def("force_state", &force_state, ClientDoc::force_state())
-        .def("force_state", &force_states)
-        .def("force_state_recursive", &force_state_recursive, ClientDoc::force_state_recursive())
-        .def("force_state_recursive", &force_states_recursive)
-        .def("replace", &ClientInvoker::replace, ClientDoc::replace())
-        .def("replace", &ClientInvoker::replace_1)
-        .def("replace", &replace_1)
-        .def("replace", &replace_2)
-        .def("order", &order, ClientDoc::order())
-        .def("group", &ClientInvoker::group, ClientDoc::group())
-        .def("begin_suite",
-             &ClientInvoker::begin,
-             (bp::arg("suite_name"), bp::arg("force") = false),
-             ClientDoc::begin_suite())
-        .def("begin_all_suites", &ClientInvoker::begin_all_suites, (bp::arg("force") = false), ClientDoc::begin_all())
-        .def("job_generation", &ClientInvoker::job_gen, ClientDoc::job_gen())
-        .def("run", &run, ClientDoc::run())
-        .def("run", &runs)
-        .def("check", &check, return_value_policy<copy_const_reference>(), ClientDoc::check())
-        .def("check", &checks, return_value_policy<copy_const_reference>())
-        .def("kill", &do_kill, ClientDoc::kill())
-        .def("kill", &do_kills)
-        .def("status", &the_status, ClientDoc::status())
-        .def("status", &statuss)
-        .def("suspend", &suspend, ClientDoc::suspend())
-        .def("suspend", &suspends)
-        .def("resume", &resume, ClientDoc::resume())
-        .def("resume", &resumes)
-        .def("archive", &archive, ClientDoc::archive())
-        .def("archive", &archives)
-        .def("restore", &restore, ClientDoc::restore())
-        .def("restore", &restores)
-        .def("delete",
-             &ClientInvoker::delete_node,
-             (bp::arg("abs_node_path"), bp::arg("force") = false),
-             ClientDoc::delete_node())
-        .def("delete", &delete_node, (bp::arg("paths"), bp::arg("force") = false))
-        .def("delete_all", &ClientInvoker::delete_all, (bp::arg("force") = false), ClientDoc::delete_all())
-        .def("debug_server_on",
-             &ClientInvoker::debug_server_on,
-             "Enable server debug, Will dump to standard out on server host.")
-        .def("debug_server_off", &ClientInvoker::debug_server_off, "Disable server debug")
-
-        .def("debug", &ClientInvoker::debug, "enable/disable client api debug")
-
-#ifdef ECF_OPENSSL
-        .def("enable_ssl", &ClientInvoker::enable_ssl, ecf::Openssl::ssl_info())
-        .def("disable_ssl", &ClientInvoker::disable_ssl, ecf::Openssl::ssl_info())
-#endif
-        .def("zombie_get", &zombieGet, return_value_policy<copy_const_reference>())
-        .def("zombie_fob", &ClientInvoker::zombieFobCli)
-        .def("zombie_fail", &ClientInvoker::zombieFailCli)
-        .def("zombie_adopt", &ClientInvoker::zombieAdoptCli)
-        .def("zombie_block", &ClientInvoker::zombieBlockCli)
-        .def("zombie_remove", &ClientInvoker::zombieRemoveCli)
-        .def("zombie_kill", &ClientInvoker::zombieKillCli)
-        .def("zombie_fob", &zombieFobCli)
-        .def("zombie_fail", &zombieFailCli)
-        .def("zombie_adopt", &zombieAdoptCli)
-        .def("zombie_block", &zombieBlockCli)
-        .def("zombie_remove", &zombieRemoveCli)
-        .def("zombie_kill", &zombieKillCli)
-
-        .def("set_child_path", &ClientInvoker::set_child_path, ClientDoc::set_child_path())
-        .def("set_child_password", &ClientInvoker::set_child_password, ClientDoc::set_child_password())
-        .def("set_child_pid", &ClientInvoker::set_child_pid, ClientDoc::set_child_pid())
-        .def("set_child_pid", &set_child_pid, ClientDoc::set_child_pid())
-        .def("set_child_try_no", &ClientInvoker::set_child_try_no, ClientDoc::set_child_try_no())
-        .def("set_child_timeout", &ClientInvoker::set_child_timeout, ClientDoc::set_child_timeout())
-        .def("set_child_init_add_vars", &set_child_init_add_vars, ClientDoc::set_child_init_add_vars())
-        .def("set_child_init_add_vars", &set_child_init_add_vars2, ClientDoc::set_child_init_add_vars())
-        .def("set_child_complete_del_vars", &set_child_complete_del_vars, ClientDoc::set_child_complete_del_vars())
-
-        .def("set_zombie_child_timeout",
-             &ClientInvoker::set_zombie_child_timeout,
-             "Set timeout for zombie child commands,that cannot connect to server, default is 24 hours. The input is "
-             "required to be in seconds")
-        .def("child_init", &ClientInvoker::child_init, "Child command,notify server job has started")
-        .def("child_abort",
-             &ClientInvoker::child_abort,
-             (bp::arg("reason") = ""),
-             "Child command,notify server job has aborted, can provide an optional reason")
-        .def("child_event",
-             &ClientInvoker::child_event,
-             (bp::arg("event_name"), bp::arg("value") = true),
-             "Child command,notify server event occurred, requires the event name")
-        .def("child_meter",
-             &ClientInvoker::child_meter,
-             "Child command,notify server meter changed, requires meter name and value")
-        .def("child_label",
-             &ClientInvoker::child_label,
-             "Child command,notify server label changed, requires label name, and new value")
-        .def("child_wait", &ClientInvoker::child_wait, "Child command,wait for expression to come true")
-        .def("child_queue",
-             &ClientInvoker::child_queue,
-             (bp::arg("queue_name"), bp::arg("action"), bp::arg("step") = "", bp::arg("path_to_node_with_queue") = ""),
-             "Child command,active:return current step as string, then increment index, requires queue name, and "
-             "optionally path to node with the queue")
-        .def("child_complete", &ClientInvoker::child_complete, "Child command,notify server job has complete");
-
-    class_<WhyCmd, boost::noncopyable>("WhyCmd",
-                                       "The why command reports, the reason why a node is not running.\n\n"
-                                       "It needs the  definition structure and the path to node\n"
-                                       "\nConstructor::\n\n"
-                                       "   WhyCmd(defs, node_path)\n"
-                                       "      defs_ptr  defs   : pointer to a definition structure\n"
-                                       "      string node_path : The node path\n\n"
-                                       "\nExceptions:\n\n"
-                                       "- raises RuntimeError if the definition is empty\n"
-                                       "- raises RuntimeError if the node path is empty\n"
-                                       "- raises RuntimeError if the node path cannot be found in the definition\n"
-                                       "\nUsage::\n\n"
-                                       "   try:\n"
-                                       "      ci = Client()\n"
-                                       "      ci.sync_local()\n"
-                                       "      ask = WhyCmd(ci.get_defs(),'/suite/family')\n"
-                                       "      print(ask.why())\n"
-                                       "   except RuntimeError, e:\n"
-                                       "       print(str(e))\n\n",
-                                       init<defs_ptr, std::string>())
-        .def("why", &WhyCmd::why, "returns a '/n' separated string, with reasons why node is not running");
-
-    class_<UrlCmd, boost::noncopyable>(
-        "UrlCmd",
-        "Executes a command ECF_URL_CMD to display a url.\n\n"
-        "It needs the definition structure and the path to node.\n"
-        "\nConstructor::\n\n"
-        "   UrlCmd(defs, node_path)\n"
-        "      defs_ptr  defs   : pointer to a definition structure\n"
-        "      string node_path : The node path.\n\n"
-        "\nExceptions\n\n"
-        "- raises RuntimeError if the definition is empty\n"
-        "- raises RuntimeError if the node path is empty\n"
-        "- raises RuntimeError if the node path cannot be found in the definition\n"
-        "- raises RuntimeError if ECF_URL_CMD not defined or if variable substitution fails\n"
-        "\nUsage:\n"
-        "Lets assume that the server has the following definition::\n\n"
-        "   suite s\n"
-        "      edit ECF_URL_CMD  \"${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%\"\n"
-        "      edit ECF_URL_BASE \"http://www.ecmwf.int\"\n"
-        "      family f\n"
-        "         task t1\n"
-        "            edit ECF_URL \"publications/manuals/ecflow\"\n"
-        "         task t2\n"
-        "            edit ECF_URL index.html\n\n"
-        "::\n\n"
-        "   try:\n"
-        "      ci = Client()\n"
-        "      ci.sync_local()\n"
-        "      url = UrlCmd(ci.get_defs(),'/suite/family/task')\n"
-        "      print(url.execute())\n"
-        "   except RuntimeError, e:\n"
-        "       print(str(e))\n\n",
-        init<defs_ptr, std::string>())
-        .def("execute", &UrlCmd::execute, "Displays url in the chosen browser");
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ExportCore.cpp 5.13.0-1/Pyext/src/ecflow/python/ExportCore.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ExportCore.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ExportCore.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,282 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/python.hpp>
-#include <boost/python/raw_function.hpp>
-
-#include "ecflow/core/CheckPt.hpp"
-#include "ecflow/core/DState.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/SState.hpp"
-#include "ecflow/core/TimeSeries.hpp"
-#include "ecflow/core/TimeSlot.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/Edit.hpp"
-#include "ecflow/python/NodeAttrDoc.hpp"
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-template <class K, class T>
-struct pair_to_tuple
-{
-    typedef pair_to_tuple<K, T> converter;
-    typedef std::pair<K, T> ctype;
-
-    static PyObject* convert(ctype const& v) {
-        using namespace boost::python;
-        return incref(make_tuple(v.first, v.second).ptr());
-    }
-    static void register_to_python() { boost::python::to_python_converter<ctype, converter>(); }
-};
-
-using namespace boost::python;
-using namespace std;
-using namespace ecf;
-
-bool debug_build() {
-#ifdef NDEBUG
-    return false;
-#else
-    return true;
-#endif
-}
-
-void export_Core() {
-    // For use in test only
-    def("debug_build", debug_build);
-
-    // see: https://github.com/boostorg/python/blob/master/test/raw_ctor.cpp
-    // Uses a raw constructor approach to support pass arbitrary number arguments on the python side.
-    // using no_init postpones defining __init__ function until after raw_function for proper overload resolution order,
-    // since later defs get higher priority.
-    class_<Edit>("Edit", NodeAttrDoc::variable_doc(), no_init)
-        .def("__init__", raw_function(&Edit::init, 0)) // raw_constructor -> will call -> def(init<dict>() )
-        .def(init<dict>())                             //
-        .def(init<dict, dict>())                       //
-        .def("__str__", &Edit::to_string)              // __str__
-        ;
-
-    class_<File, boost::noncopyable>("File", "Utility class, Used in test only.", no_init)
-        .def("find_server", &File::find_ecf_server_path, "Provides pathname to the server")
-        .staticmethod("find_server")
-        .def("find_client", &File::find_ecf_client_path, "Provides pathname to the client")
-        .staticmethod("find_client")
-        .def("source_dir", &File::root_source_dir, "Path name to ecflow source directory")
-        .staticmethod("source_dir")
-        .def("build_dir", &File::root_build_dir, "Path name to ecflow build directory")
-        .staticmethod("build_dir");
-
-    enum_<PrintStyle::Type_t>(
-        "Style",
-        "Style is used to control printing output for the definition\n\n"
-        "- DEFS:  This style outputs the definition file in a format that is parse-able.\n"
-        "         and can be re-loaded back into the server.\n"
-        "         Externs are automatically added.\n"
-        "         This excludes the edit history.\n"
-        "- STATE: The output includes additional state information for debug\n"
-        "         This excludes the edit history\n"
-        "- MIGRATE: Output includes structure and state, allow migration to future ecflow versions\n"
-        "         This includes edit history. If file is reloaded no checking is done\n\n"
-        "The following shows a summary of the features associated with each choice\n"
-        "\n"
-        "   ===================== ==== ===== =======\n"
-        "   Functionality         DEFS STATE MIGRATE\n"
-        "   ===================== ==== ===== =======\n"
-        "   Auto generate externs  Yes  Yes   No\n"
-        "   Checking on reload     Yes  Yes   No\n"
-        "   Edit History           No   No    Yes\n"
-        "   Show trigger AST       No   Yes   No\n"
-        "   ===================== ==== ===== =======\n")
-        .value("NOTHING", PrintStyle::NOTHING)
-        .value("DEFS", PrintStyle::DEFS)
-        .value("STATE", PrintStyle::STATE)
-        .value("MIGRATE", PrintStyle::MIGRATE);
-
-    class_<PrintStyle, boost::noncopyable>("PrintStyle",
-                                           "Singleton used to control the print Style. See :py:class:`ecflow.Style`\n\n"
-                                           "\nUsage::\n\n"
-                                           "   old_style = PrintStyle.get_style()\n"
-                                           "   PrintStyle.set_style(PrintStyle.STATE)\n"
-                                           "   ...\n"
-                                           "   print(defs)                     # show the node state\n"
-                                           "   PrintStyle.set_style(old_style) # reset previous style\n",
-                                           no_init)
-        .def("get_style", &PrintStyle::getStyle, "Returns the style, static method")
-        .staticmethod("get_style")
-        .def("set_style", &PrintStyle::setStyle, "Set the style, static method")
-        .staticmethod("set_style");
-
-    enum_<CheckPt::Mode>(
-        "CheckPt",
-        "CheckPt is enum that is used to control check pointing in the `ecflow_server`_\n\n"
-        "- NEVER  : Switches of check pointing\n"
-        "- ON_TIME: `check point`_ file is saved periodically, specified by checkPtInterval. This is the default.\n"
-        "- ALWAYS : `check point`_ file is saved after any state change, *not* recommended for large definitions\n"
-        "- UNDEFINED : None of the the above, used to provide default argument\n")
-        .value("NEVER", CheckPt::NEVER)
-        .value("ON_TIME", CheckPt::ON_TIME)
-        .value("ALWAYS", CheckPt::ALWAYS)
-        .value("UNDEFINED", CheckPt::UNDEFINED);
-
-    class_<Ecf, boost::noncopyable>("Ecf", "Singleton used to control ecf debugging\n\n", no_init)
-        .def("debug_equality", &Ecf::debug_equality, "Returns true if debugging of equality is enabled")
-        .staticmethod("debug_equality")
-        .def("set_debug_equality", &Ecf::set_debug_equality, "Set debugging for equality")
-        .staticmethod("set_debug_equality")
-        .def("debug_level",
-             &Ecf::debug_level,
-             "Returns integer showing debug level. debug_level > 0 will disable some warning messages")
-        .staticmethod("debug_level")
-        .def("set_debug_level",
-             &Ecf::set_debug_level,
-             "Set debug level. debug_level > 0 will disable some warning messages")
-        .staticmethod("set_debug_level");
-
-    enum_<NState::State>(
-        "State",
-        "Each `node`_ can have a status, which reflects the life cycle of a node.\n\n"
-        "It varies as follows:\n\n"
-        "- When the definition file is loaded into the `ecflow_server`_ the `task`_ status is `unknown`_\n"
-        "- After begin command the `task`_ s are either `queued`_, `complete`_, `aborted`_ or `suspended`_ ,\n"
-        "  a suspended task means that the task is really `queued`_ but it must be resumed by\n"
-        "  the user first before it can be `submitted`_. See :py:class:`ecflow.DState`\n"
-        "- Once the `dependencies`_ are resolved a task is submitted and placed into the `submitted`_ state,\n"
-        "  however if the submission fails, the task is placed in a `aborted`_ state.\n"
-        "- On a successful submission the task is placed into the `active`_ state\n"
-        "- Before a job ends, it may send other message to the server such as:\n"
-        "  Set an `event`_, Change a `meter`_, Change a `label`_, send a message to log file\n\n"
-        "Jobs end by becoming either `complete`_ or `aborted`_")
-        .value("unknown", NState::UNKNOWN)
-        .value("complete", NState::COMPLETE)
-        .value("queued", NState::QUEUED)
-        .value("aborted", NState::ABORTED)
-        .value("submitted", NState::SUBMITTED)
-        .value("active", NState::ACTIVE);
-
-    enum_<DState::State>("DState",
-                         "A DState is like a ecflow.State, except for the addition of SUSPENDED\n\n"
-                         "Suspended stops job generation, and hence is an attribute of a Node.\n"
-                         "DState can be used for setting the default state of node when it is\n"
-                         "begun or re queued. DState is used for defining `defstatus`_.\n"
-                         "See :py:class:`ecflow.Node.add_defstatus` and :py:class:`ecflow.Defstatus`\n"
-                         "The default state of a `node`_ is `queued`_.\n"
-                         "\nUsage::\n\n"
-                         "   task = ecflow.Task('t1')\n"
-                         "   task.add_defstatus(ecflow.DState.complete)"
-                         "   task = ecflow.Task('t2')\n"
-                         "   task += Defstatus('complete')\n"
-                         "   task = Task('t3',\n"
-                         "               Defstatus('complete')) # create in place\n")
-        .value("unknown", DState::UNKNOWN)
-        .value("complete", DState::COMPLETE)
-        .value("queued", DState::QUEUED)
-        .value("aborted", DState::ABORTED)
-        .value("submitted", DState::SUBMITTED)
-        .value("suspended", DState::SUSPENDED)
-        .value("active", DState::ACTIVE);
-
-    class_<Defstatus>("Defstatus",
-                      "A `node`_ can be set with a default status other the `queued`_\n\n"
-                      "The default state of a `node`_ is `queued`_.\n"
-                      "This defines the state to take at 'begin' or 're-queue' time\n"
-                      "See :py:class:`ecflow.Node.add_defstatus` and :py:class:`ecflow.DState`\n",
-                      init<DState::State>())
-        .def(init<std::string>()) // constructor
-        .def("state", &Defstatus::state)
-        .def("__str__", &Defstatus::to_string) // __str__
-        ;
-
-    enum_<SState::State>("SState",
-                         "A SState holds the `ecflow_server`_ state\n\n"
-                         "See `server states`_")
-        .value("HALTED", SState::HALTED)
-        .value("SHUTDOWN", SState::SHUTDOWN)
-        .value("RUNNING", SState::RUNNING);
-
-    class_<TimeSlot>("TimeSlot",
-                     "Represents a time slot.\n\n"
-                     "It is typically used as an argument to a :py:class:`TimeSeries` or\n"
-                     "other time dependent attributes of a node.\n"
-                     "\n"
-                     "\nConstructor::\n\n"
-                     "   TimeSlot(hour,min)\n"
-                     "      int hour:   represent an hour:\n"
-                     "      int minute: represents a minute:\n"
-                     "\nUsage::\n\n"
-                     "   ts = TimeSlot(10,11)\n",
-                     init<int, int>())
-        .def("__str__", &TimeSlot::toString)   // __str__
-        .def("__copy__", copyObject<TimeSlot>) // __copy__ uses copy constructor
-        .def(self == self)                     // __eq__
-        .def("hour", &TimeSlot::hour)          // return int
-        .def("minute", &TimeSlot::minute)      // return int
-        .def("empty", &TimeSlot::isNULL)       // return bool
-        ;
-
-    // single slot, | start, finish, incr,  bool relative to suite start
-    class_<TimeSeries>(
-        "TimeSeries",
-        "A TimeSeries can hold a single time slot or a series.\n\n"
-        "Time series can be created relative to the `suite`_ start or start of a repeating node.\n"
-        "A Time series can be used as argument to the :py:class:`ecflow.Time`, :py:class:`ecflow.Today` and "
-        ":py:class:`ecflow.Cron` attributes of a node.\n"
-        "If a time the job takes to complete is longer than the interval, a 'slot' is missed\n"
-        "e.g time 10:00 20:00 01:00, if the 10.00 run takes more than an hour the 11.00 is missed\n\n"
-        "\nConstructor::\n\n"
-        "   TimeSeries(single,relative_to_suite_start)\n"
-        "      TimeSlot single :  A single point in a 24 clock \n"
-        "      optional bool relative_to_suite_start : depend on suite begin time or\n"
-        "                                              start of repeating node. Default is false\n"
-        "\n"
-        "   TimeSeries(hour,minute,relative_to_suite_start)\n"
-        "      int hour   :  hour in 24 clock \n"
-        "      int minute :  minute < 59 \n"
-        "      bool relative_to_suite_start<optional> : depend on suite begin time or\n"
-        "                                              start of repeating node. Default is false\n"
-        "\n"
-        "   TimeSeries(start,finish,increment,relative_to_suite_start)\n"
-        "      start TimeSlot :     The start time  \n"
-        "      finish TimeSlot :    The finish time, when used in a series. This must greater than the start.\n"
-        "      increment TimeSlot : The increment. This must be less that difference between start and finish\n"
-        "      bool relative_to_suite_start<optional> : The time is relative suite start, or start of repeating node.\n"
-        "                                               The default is false\n"
-        "\nExceptions:\n\n"
-        "- Raises IndexError when an invalid time series is specified\n"
-        "\nUsage::\n\n"
-        "   time_series = TimeSeries(TimeSlot(10,11),False)\n",
-        init<TimeSlot, boost::python::optional<bool>>())
-        .def(init<int, int, boost::python::optional<bool>>())
-        .def(init<TimeSlot, TimeSlot, TimeSlot, boost::python::optional<bool>>())
-        .def(self == self)                       // __eq__
-        .def("__str__", &TimeSeries::toString)   // __str__
-        .def("__copy__", copyObject<TimeSeries>) // __copy__ uses copy constructor
-        .def("has_increment",
-             &TimeSeries::hasIncrement,
-             "distinguish between a single time slot and a series. returns true for a series") // false if single time
-                                                                                               // slot
-        .def("start",
-             &TimeSeries::start,
-             return_value_policy<copy_const_reference>(),
-             "returns the start time") // returns a time slot
-        .def("finish",
-             &TimeSeries::finish,
-             return_value_policy<copy_const_reference>(),
-             "returns the finish time if time series specified, else returns a NULL time slot") // returns a time slot
-        .def("incr",
-             &TimeSeries::incr,
-             return_value_policy<copy_const_reference>(),
-             " returns the increment time if time series specified, else returns a NULL time slot") // returns a time
-                                                                                                    // slot
-        .def("relative", &TimeSeries::relative, "returns a boolean where true means that the time series is relative");
-
-    using namespace boost::python;
-    pair_to_tuple<std::string, std::string>::register_to_python();
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ExportDefs.cpp 5.13.0-1/Pyext/src/ecflow/python/ExportDefs.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ExportDefs.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ExportDefs.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,369 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include <boost/python.hpp>
-#include <boost/python/raw_function.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/JobCreationCtrl.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/DefsDoc.hpp"
-#include "ecflow/python/Edit.hpp"
-#include "ecflow/python/GlossaryDoc.hpp"
-#include "ecflow/simulator/Simulator.hpp"
-
-using namespace ecf;
-using namespace boost::python;
-using namespace std;
-namespace bp = boost::python;
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-
-void save_as_defs(const Defs& theDefs, const std::string& filename, PrintStyle::Type_t the_style_enum) {
-    PrintStyle style(the_style_enum);
-    std::stringstream ss;
-    ss << theDefs;
-
-    std::string file_creation_error_msg;
-    if (!File::create(filename, ss.str(), file_creation_error_msg)) {
-        std::string error = "save_as_defs failed: ";
-        error += file_creation_error_msg;
-        throw std::runtime_error(error);
-    }
-}
-
-void save_as_defs_1(const Defs& theDefs, const std::string& filename) {
-    save_as_defs(theDefs, filename, PrintStyle::DEFS);
-}
-
-static defs_ptr create_defs(const std::string& file_name) {
-    defs_ptr defs = Defs::create();
-
-    std::string errorMsg, warningMsg;
-    if (!defs->restore(file_name, errorMsg, warningMsg)) {
-        throw std::runtime_error(errorMsg);
-    }
-    if (!warningMsg.empty())
-        std::cerr << warningMsg;
-    return defs;
-}
-
-std::string check_defs(defs_ptr defs) {
-    std::string error_msg;
-    std::string warning_msg;
-    if (defs.get() && !defs->check(error_msg, warning_msg)) {
-        error_msg += "\n";
-        error_msg += warning_msg;
-        return error_msg;
-    }
-    return warning_msg;
-}
-
-void restore_from_checkpt(defs_ptr defs, const std::string& file_name) {
-    defs->restore(file_name);
-}
-
-std::string simulate(defs_ptr defs) {
-    if (defs.get()) {
-        // name output file after name of the first suite
-        std::string defs_filename = "pyext.def";
-        if (!defs->suiteVec().empty()) {
-            defs_filename = (*defs->suiteVec().begin())->name() + ".def";
-        }
-
-        Simulator simulator;
-        std::string errorMsg;
-        if (!simulator.run(*defs, defs_filename, errorMsg)) {
-            return errorMsg;
-        }
-    }
-    return string();
-}
-
-SState::State get_server_state(defs_ptr self) {
-    return self->server().get_state();
-}
-
-/// Since we don't pass in a child pos, the nodes are added to the end
-suite_ptr add_suite(defs_ptr self, suite_ptr s) {
-    self->addSuite(s);
-    return s;
-}
-
-std::vector<task_ptr> get_all_tasks(defs_ptr self) {
-    std::vector<task_ptr> tasks;
-    self->get_all_tasks(tasks);
-    return tasks;
-}
-std::vector<node_ptr> get_all_nodes(defs_ptr self) {
-    std::vector<node_ptr> nodes;
-    self->get_all_nodes(nodes);
-    return nodes;
-}
-
-// Context management, Only used to provide indentation
-defs_ptr defs_enter(defs_ptr self) {
-    return self;
-}
-bool defs_exit(defs_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
-    return false;
-}
-
-std::string check_job_creation(defs_ptr defs, bool throw_on_error, bool verbose) {
-    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
-    if (verbose)
-        jobCtrl->set_verbose(verbose);
-    defs->check_job_creation(jobCtrl);
-    if (!jobCtrl->get_error_msg().empty() && throw_on_error) {
-        throw std::runtime_error(jobCtrl->get_error_msg());
-    }
-    return jobCtrl->get_error_msg();
-}
-
-// Add  server user variables
-defs_ptr add_variable(defs_ptr self, const std::string& name, const std::string& value) {
-    self->set_server().add_or_update_user_variables(name, value);
-    return self;
-}
-defs_ptr add_variable_int(defs_ptr self, const std::string& name, int value) {
-    self->set_server().add_or_update_user_variables(name, ecf::convert_to<std::string>(value));
-    return self;
-}
-defs_ptr add_variable_var(defs_ptr self, const Variable& var) {
-    self->set_server().add_or_update_user_variables(var.name(), var.theValue());
-    return self;
-}
-defs_ptr add_variable_dict(defs_ptr self, const bp::dict& dict) {
-    std::vector<std::pair<std::string, std::string>> vec;
-    BoostPythonUtil::dict_to_str_vec(dict, vec);
-    std::vector<std::pair<std::string, std::string>>::iterator i;
-    auto vec_end = vec.end();
-    for (i = vec.begin(); i != vec_end; ++i) {
-        self->set_server().add_or_update_user_variables((*i).first, (*i).second);
-    }
-    return self;
-}
-void delete_variable(defs_ptr self, const std::string& name) {
-    self->set_server().delete_user_variable(name);
-}
-
-void sort_attributes(defs_ptr self, ecf::Attr::Type attr) {
-    self->sort_attributes(attr);
-}
-void sort_attributes1(defs_ptr self, ecf::Attr::Type attr, bool recurse) {
-    self->sort_attributes(attr, recurse);
-}
-void sort_attributes2(defs_ptr self, ecf::Attr::Type attr, bool recurse, const bp::list& list) {
-    std::vector<std::string> no_sort;
-    BoostPythonUtil::list_to_str_vec(list, no_sort);
-    self->sort_attributes(attr, recurse, no_sort);
-}
-
-void sort_attributes3(defs_ptr self, const std::string& attribute_name, bool recursive, const bp::list& list) {
-    std::string attribute = attribute_name;
-    boost::algorithm::to_lower(attribute);
-    ecf::Attr::Type attr = Attr::to_attr(attribute_name);
-    if (attr == ecf::Attr::UNKNOWN) {
-        std::stringstream ss;
-        ss << "sort_attributes: the attribute " << attribute_name << " is not valid";
-        throw std::runtime_error(ss.str());
-    }
-    std::vector<std::string> no_sort;
-    BoostPythonUtil::list_to_str_vec(list, no_sort);
-    self->sort_attributes(attr, recursive, no_sort);
-}
-
-// Support sized and Container protocol
-size_t defs_len(defs_ptr self) {
-    return self->suiteVec().size();
-}
-bool defs_container(defs_ptr self, const std::string& name) {
-    return (self->findSuite(name)) ? true : false;
-}
-
-static object do_add(defs_ptr self, const bp::object& arg) {
-    // std::cout << "defs::do_add \n";
-    if (arg.ptr() == object().ptr())
-        return object(self); // *IGNORE* None
-    else if (extract<suite_ptr>(arg).check())
-        self->addSuite(extract<suite_ptr>(arg));
-    else if (extract<dict>(arg).check())
-        add_variable_dict(self, extract<dict>(arg));
-    else if (extract<Edit>(arg).check()) {
-        Edit edit                        = extract<Edit>(arg);
-        const std::vector<Variable>& vec = edit.variables();
-        for (const auto& i : vec)
-            self->set_server().add_or_update_user_variables(i.name(), i.theValue());
-    }
-    else if (extract<bp::list>(arg).check()) {
-        bp::list the_list = extract<bp::list>(arg);
-        int the_list_size = len(the_list);
-        for (int i = 0; i < the_list_size; ++i)
-            (void)do_add(self, the_list[i]); // recursive
-    }
-    else if (extract<Variable>(arg).check()) {
-        Variable var = extract<Variable>(arg);
-        self->set_server().add_or_update_user_variables(var.name(), var.theValue());
-    }
-    else
-        throw std::runtime_error("ExportDefs::add : Unknown type");
-    return object(self);
-}
-
-static object add(bp::tuple args, dict kwargs) {
-    int the_list_size = len(args);
-    defs_ptr self     = extract<defs_ptr>(args[0]); // self
-    if (!self)
-        throw std::runtime_error("ExportDefs::add() : first argument is not a Defs");
-
-    for (int i = 1; i < the_list_size; ++i)
-        (void)do_add(self, args[i]);
-    (void)add_variable_dict(self, kwargs);
-
-    return object(self); // return defs as python object, relies class_<Defs>... for type registration
-}
-
-static object defs_iadd(defs_ptr self, const bp::list& list) {
-    // std::cout << "defs_iadd  list " << self->name() << "\n";
-    int the_list_size = len(list);
-    for (int i = 0; i < the_list_size; ++i)
-        (void)do_add(self, list[i]);
-    return object(self); // return node_ptr as python object, relies class_<Node>... for type registration
-}
-
-static object defs_getattr(defs_ptr self, const std::string& attr) {
-    // cout << "  defs_getattr  self.name() : " << self->name() << "  attr " << attr << "\n";
-    suite_ptr child = self->findSuite(attr);
-    if (child)
-        return object(child);
-
-    Variable var = self->server().findVariable(attr);
-    if (!var.empty())
-        return object(var);
-
-    std::stringstream ss;
-    ss << "ExportDefs::defs_getattr : function of name '" << attr << "' does not exist *OR* suite or defs variable";
-    throw std::runtime_error(ss.str());
-    return object();
-}
-
-object defs_raw_constructor(bp::tuple args, dict kw) {
-    // cout << "defs_raw_constructor  len(args):" << len(args) << endl;
-    // args[0] is Defs(i.e self)
-    bp::list the_list;
-    std::string name;
-    for (int i = 1; i < len(args); ++i) {
-        if (extract<string>(args[i]).check())
-            name = extract<string>(args[i]);
-        else
-            the_list.append(args[i]);
-    }
-    if (!name.empty() && len(the_list) > 0)
-        throw std::runtime_error("defs_raw_constructor: Can't mix string with other arguments. String argument "
-                                 "specifies a path(loads a definition from disk)");
-    return args[0].attr("__init__")(the_list, kw); // calls -> init(list attr, dict kw)
-}
-
-defs_ptr defs_init(bp::list the_list, bp::dict kw) {
-    // cout << " defs_init: the_list: " << len(the_list) << " dict: " << len(kw) << endl;
-    defs_ptr defs = Defs::create();
-    (void)add_variable_dict(defs, kw);
-    (void)defs_iadd(defs, the_list);
-    return defs;
-}
-
-void export_Defs() {
-    class_<Defs, defs_ptr>("Defs", DefsDoc::add_definition_doc(), init<>("Create a empty Defs"))
-        .def("__init__", raw_function(&defs_raw_constructor, 0)) // will call -> task_init
-        .def("__init__", make_constructor(&defs_init))
-        .def("__init__", make_constructor(&create_defs), DefsDoc::add_definition_doc())
-        .def(self == self)                    // __eq__
-        .def("__copy__", copyObject<Defs>)    // __copy__ uses copy constructor
-        .def("__str__", &Defs::toString)      // __str__
-        .def("__enter__", &defs_enter)        // allow with statement, hence indentation support
-        .def("__exit__", &defs_exit)          // allow with statement, hence indentation support
-        .def("__len__", &defs_len)            // Sized protocol
-        .def("__contains__", &defs_container) // Container protocol
-        .def("__iter__", bp::range(&Defs::suite_begin, &Defs::suite_end)) // iterable protocol
-        .def("__getattr__", &defs_getattr) /* Any attempt to resolve a property, method, or field name that doesn't
-                                              actually exist on the object itself will be passed to __getattr__*/
-        .def("__iadd__", &defs_iadd) // defs += [ Suite('s1'), Edit(var='value'), Variable('a','b') [ Suite('t2') ] ]
-        .def("__iadd__", &do_add)    // defs += Suite("s1")
-        .def("__add__", &do_add)
-        .def("add", raw_function(add, 1), DefsDoc::add())
-        .def("add_suite", &add_suite, DefsDoc::add_suite_doc())
-        .def("add_suite", &Defs::add_suite, GlossaryDoc::list())
-        .def("add_extern", &Defs::add_extern, DefsDoc::add_extern_doc())
-        .def("auto_add_externs", &Defs::auto_add_externs, DefsDoc::add_extern_doc())
-        .def("add_variable", &add_variable, DefsDoc::add_variable_doc())
-        .def("add_variable", &add_variable_int)
-        .def("add_variable", &add_variable_var)
-        .def("add_variable", &add_variable_dict)
-        .def("sort_attributes", &sort_attributes)
-        .def("sort_attributes", &sort_attributes1)
-        .def("sort_attributes", &sort_attributes2)
-        .def("sort_attributes",
-             &sort_attributes3,
-             (bp::arg("attribute_type"), bp::arg("recursive") = true, bp::arg("no_sort") = bp::list()))
-        .def("sort_attributes", &Defs::sort_attributes, (bp::arg("attribute_type"), bp::arg("recursive") = true))
-        .def("delete_variable", &delete_variable, "An empty string will delete all user variables")
-        .def("find_suite", &Defs::findSuite, "Given a name, find the corresponding `suite`_")
-        .def("find_abs_node", &Defs::findAbsNode, "Given a path, find the the `node`_")
-        .def("find_node_path",
-             &Defs::find_node_path,
-             "Given a type(suite,family,task) and a name, return path of the first match, otherwise return an empty "
-             "string")
-        .def("find_node", &Defs::find_node, "Given a type(suite,family,task) and a path to a node, return the node.")
-        .def("get_all_nodes", &get_all_nodes, "Returns all the `node`_\\ s in the definition")
-        .def("get_all_tasks", &get_all_tasks, "Returns all the `task`_ nodes")
-        .def("has_time_dependencies",
-             &Defs::hasTimeDependencies,
-             "returns True if the `suite definition`_ has any time `dependencies`_")
-        .def("save_as_checkpt",
-             &Defs::save_as_checkpt,
-             "Save the in memory `suite definition`_ as a `check point`_ file. This includes all node state.")
-        .def("restore_from_checkpt",
-             &restore_from_checkpt,
-             "Restore the `suite definition`_ from a `check point`_ file stored on disk")
-        .def("save_as_defs",
-             &save_as_defs,
-             "Save the in memory `suite definition`_ into a file. The file name must be passed as an argument\n\n")
-        .def("save_as_defs",
-             &save_as_defs_1,
-             "Save the in memory `suite definition`_ into a file. The file name must be passed as an argument\n\n")
-        .def("check", &check_defs, DefsDoc::check())
-        .def("simulate", &simulate, DefsDoc::simulate())
-        .def("check_job_creation",
-             &check_job_creation,
-             (bp::arg("throw_on_error") = false, bp::arg("verbose") = false),
-             DefsDoc::check_job_creation_doc())
-        .def("check_job_creation", &Defs::check_job_creation)
-        .def("generate_scripts", &Defs::generate_scripts, DefsDoc::generate_scripts_doc())
-        .def("get_state", &Defs::state)
-        .def("get_server_state", &get_server_state, DefsDoc::get_server_state())
-        .add_property("suites", bp::range(&Defs::suite_begin, &Defs::suite_end), "Returns a list of `suite`_\\ s")
-        .add_property("externs", bp::range(&Defs::extern_begin, &Defs::extern_end), "Returns a list of `extern`_\\ s")
-        .add_property("user_variables",
-                      bp::range(&Defs::user_variables_begin, &Defs::user_variables_end),
-                      "Returns a list of user defined `variable`_\\ s")
-        .add_property("server_variables",
-                      bp::range(&Defs::server_variables_begin, &Defs::server_variables_end),
-                      "Returns a list of server `variable`_\\ s");
-
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<defs_ptr>(); // needed for mac and boost 1.6
-#endif
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ExportNode.cpp 5.13.0-1/Pyext/src/ecflow/python/ExportNode.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ExportNode.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ExportNode.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,765 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include <boost/python.hpp>
-#include <boost/python/raw_function.hpp>
-#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/MiscAttrs.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/node/NodeContainer.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/DefsDoc.hpp"
-#include "ecflow/python/NodeAttrDoc.hpp"
-#include "ecflow/python/NodeUtil.hpp"
-
-using namespace ecf;
-using namespace boost::python;
-using namespace std;
-namespace bp = boost::python;
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-
-Defs* get_defs(node_ptr self) {
-    return self->defs();
-}
-
-node_ptr add_variable(node_ptr self, const std::string& name, const std::string& value) {
-    self->add_variable(name, value);
-    return self;
-}
-node_ptr add_variable_int(node_ptr self, const std::string& name, int value) {
-    self->add_variable_int(name, value);
-    return self;
-}
-node_ptr add_variable_var(node_ptr self, const Variable& var) {
-    self->addVariable(var);
-    return self;
-}
-
-node_ptr add_event(node_ptr self, const Event& e) {
-    self->addEvent(e);
-    return self;
-}
-node_ptr add_event_1(node_ptr self, int number) {
-    self->addEvent(Event(number));
-    return self;
-}
-node_ptr add_event_2(node_ptr self, int number, const std::string& name) {
-    self->addEvent(Event(number, name));
-    return self;
-}
-node_ptr add_event_3(node_ptr self, const std::string& name) {
-    self->addEvent(Event(name));
-    return self;
-}
-
-node_ptr add_meter(node_ptr self, const Meter& m) {
-    self->addMeter(m);
-    return self;
-}
-node_ptr add_meter_1(node_ptr self, const std::string& meter_name, int min, int max, int color_change) {
-    self->addMeter(Meter(meter_name, min, max, color_change));
-    return self;
-}
-node_ptr add_meter_2(node_ptr self, const std::string& meter_name, int min, int max) {
-    self->addMeter(Meter(meter_name, min, max));
-    return self;
-}
-
-node_ptr add_queue(node_ptr self, const QueueAttr& m) {
-    self->add_queue(m);
-    return self;
-}
-node_ptr add_queue1(node_ptr self, const std::string& name, const bp::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    QueueAttr queue_attr(name, vec);
-    self->add_queue(queue_attr);
-    return self;
-}
-
-node_ptr add_generic(node_ptr self, const GenericAttr& m) {
-    self->add_generic(m);
-    return self;
-}
-node_ptr add_generic1(node_ptr self, const std::string& name, const bp::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    GenericAttr attr(name, vec);
-    self->add_generic(attr);
-    return self;
-}
-
-node_ptr add_label(node_ptr self, const std::string& name, const std::string& value) {
-    self->addLabel(Label(name, value));
-    return self;
-}
-node_ptr add_label_1(node_ptr self, const Label& label) {
-    self->addLabel(label);
-    return self;
-}
-node_ptr add_limit(node_ptr self, const std::string& name, int limit) {
-    self->addLimit(Limit(name, limit));
-    return self;
-}
-node_ptr add_limit_1(node_ptr self, const Limit& limit) {
-    self->addLimit(limit);
-    return self;
-}
-node_ptr add_in_limit(node_ptr self,
-                      const std::string& name,
-                      const std::string& pathToNode,
-                      int tokens,
-                      bool limit_this_node_only) {
-    self->addInLimit(InLimit(name, pathToNode, tokens, limit_this_node_only));
-    return self;
-}
-node_ptr add_in_limit_1(node_ptr self, const InLimit& inlimit) {
-    self->addInLimit(inlimit);
-    return self;
-}
-node_ptr add_time(node_ptr self, int hour, int minute) {
-    self->addTime(ecf::TimeAttr(hour, minute));
-    return self;
-}
-node_ptr add_time_1(node_ptr self, int hour, int minute, bool relative) {
-    self->addTime(ecf::TimeAttr(hour, minute, relative));
-    return self;
-}
-node_ptr add_time_2(node_ptr self, const std::string& ts) {
-    self->addTime(ecf::TimeAttr(TimeSeries::create(ts)));
-    return self;
-}
-node_ptr add_time_3(node_ptr self, const ecf::TimeAttr& ts) {
-    self->addTime(ts);
-    return self;
-}
-node_ptr add_today(node_ptr self, int hour, int minute) {
-    self->addToday(ecf::TodayAttr(hour, minute));
-    return self;
-}
-node_ptr add_today_1(node_ptr self, int hour, int minute, bool relative) {
-    self->addToday(ecf::TodayAttr(hour, minute, relative));
-    return self;
-}
-node_ptr add_today_2(node_ptr self, const std::string& ts) {
-    self->addToday(ecf::TodayAttr(TimeSeries::create(ts)));
-    return self;
-}
-node_ptr add_today_3(node_ptr self, const ecf::TodayAttr& ts) {
-    self->addToday(ts);
-    return self;
-}
-node_ptr add_date(node_ptr self, int day, int month, int year) {
-    self->addDate(DateAttr(day, month, year));
-    return self;
-}
-node_ptr add_date_1(node_ptr self, const DateAttr& d) {
-    self->addDate(d);
-    return self;
-}
-node_ptr add_day(node_ptr self, DayAttr::Day_t day) {
-    self->addDay(DayAttr(day));
-    return self;
-}
-node_ptr add_day_1(node_ptr self, const std::string& day) {
-    self->addDay(DayAttr(DayAttr::getDay(day)));
-    return self;
-}
-node_ptr add_day_2(node_ptr self, const DayAttr& day) {
-    self->addDay(day);
-    return self;
-}
-
-node_ptr add_autocancel(node_ptr self, int days) {
-    self->addAutoCancel(ecf::AutoCancelAttr(days));
-    return self;
-}
-node_ptr add_autocancel_1(node_ptr self, int hour, int min, bool relative) {
-    self->addAutoCancel(ecf::AutoCancelAttr(hour, min, relative));
-    return self;
-}
-node_ptr add_autocancel_2(node_ptr self, const TimeSlot& ts, bool relative) {
-    self->addAutoCancel(ecf::AutoCancelAttr(ts, relative));
-    return self;
-}
-node_ptr add_autocancel_3(node_ptr self, const ecf::AutoCancelAttr& attr) {
-    self->addAutoCancel(attr);
-    return self;
-}
-node_ptr add_autoarchive(node_ptr self, int days, bool idle) {
-    self->add_autoarchive(ecf::AutoArchiveAttr(days, idle));
-    return self;
-}
-node_ptr add_autoarchive_1(node_ptr self, int hour, int min, bool relative, bool idle) {
-    self->add_autoarchive(ecf::AutoArchiveAttr(hour, min, relative, idle));
-    return self;
-}
-node_ptr add_autoarchive_2(node_ptr self, const TimeSlot& ts, bool relative, bool idle) {
-    self->add_autoarchive(ecf::AutoArchiveAttr(ts, relative, idle));
-    return self;
-}
-node_ptr add_autoarchive_3(node_ptr self, const ecf::AutoArchiveAttr& attr) {
-    self->add_autoarchive(attr);
-    return self;
-}
-
-node_ptr add_zombie(node_ptr self, const ZombieAttr& attr) {
-    self->addZombie(attr);
-    return self;
-}
-
-node_ptr add_autorestore(node_ptr self, const ecf::AutoRestoreAttr& attr) {
-    self->add_autorestore(attr);
-    return self;
-}
-node_ptr add_autorestore1(node_ptr self, const bp::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    self->add_autorestore(ecf::AutoRestoreAttr(vec));
-    return self;
-}
-
-node_ptr add_cron(node_ptr self, const ecf::CronAttr& attr) {
-    self->addCron(attr);
-    return self;
-}
-node_ptr add_late(node_ptr self, const ecf::LateAttr& attr) {
-    self->addLate(attr);
-    return self;
-}
-std::string get_state_change_time(node_ptr self, const std::string& format) {
-    if (format == "iso_extended")
-        return to_iso_extended_string(self->state_change_time());
-    else if (format == "iso")
-        return to_iso_string(self->state_change_time());
-    return to_simple_string(self->state_change_time());
-}
-
-node_ptr add_repeat_date(node_ptr self, const RepeatDate& d) {
-    self->addRepeat(d);
-    return self;
-}
-node_ptr add_repeat_datetime(node_ptr self, const RepeatDateTime& d) {
-    self->addRepeat(d);
-    return self;
-}
-node_ptr add_repeat_date_list(node_ptr self, const RepeatDateList& d) {
-    self->addRepeat(d);
-    return self;
-}
-node_ptr add_repeat_integer(node_ptr self, const RepeatInteger& d) {
-    self->addRepeat(d);
-    return self;
-}
-node_ptr add_repeat_string(node_ptr self, const RepeatString& d) {
-    self->addRepeat(d);
-    return self;
-}
-node_ptr add_repeat_enum(node_ptr self, const RepeatEnumerated& d) {
-    self->addRepeat(d);
-    return self;
-}
-node_ptr add_repeat_day(node_ptr self, const RepeatDay& d) {
-    self->addRepeat(d);
-    return self;
-}
-
-void sort_attributes(node_ptr self, ecf::Attr::Type attr) {
-    self->sort_attributes(attr);
-}
-void sort_attributes1(node_ptr self, ecf::Attr::Type attr, bool recursive) {
-    self->sort_attributes(attr, recursive);
-}
-void sort_attributes2(node_ptr self, ecf::Attr::Type attr, bool recursive, const bp::list& list) {
-    std::vector<std::string> no_sort;
-    BoostPythonUtil::list_to_str_vec(list, no_sort);
-    self->sort_attributes(attr, recursive, no_sort);
-}
-
-void sort_attributes3(node_ptr self, const std::string& attribute_name, bool recursive, const bp::list& list) {
-    std::string attribute = attribute_name;
-    boost::algorithm::to_lower(attribute);
-    ecf::Attr::Type attr = Attr::to_attr(attribute_name);
-    if (attr == ecf::Attr::UNKNOWN) {
-        std::stringstream ss;
-        ss << "sort_attributes: the attribute " << attribute_name << " is not valid";
-        throw std::runtime_error(ss.str());
-    }
-    std::vector<std::string> no_sort;
-    BoostPythonUtil::list_to_str_vec(list, no_sort);
-    self->sort_attributes(attr, recursive, no_sort);
-}
-
-std::vector<node_ptr> get_all_nodes(node_ptr self) {
-    std::vector<node_ptr> nodes;
-    self->get_all_nodes(nodes);
-    return nodes;
-}
-
-node_ptr add_trigger(node_ptr self, const std::string& expr) {
-    self->add_trigger(expr);
-    return self;
-}
-node_ptr add_trigger_expr(node_ptr self, const Expression& expr) {
-    self->add_trigger_expr(expr);
-    return self;
-}
-node_ptr add_complete(node_ptr self, const std::string& expr) {
-    self->add_complete(expr);
-    return self;
-}
-node_ptr add_complete_expr(node_ptr self, const Expression& expr) {
-    self->add_complete_expr(expr);
-    return self;
-}
-node_ptr add_part_trigger(node_ptr self, const PartExpression& expr) {
-    self->add_part_trigger(PartExpression(expr));
-    return self;
-}
-node_ptr add_part_trigger_1(node_ptr self, const std::string& expression) {
-    self->add_part_trigger(PartExpression(expression));
-    return self;
-}
-node_ptr add_part_trigger_2(node_ptr self, const std::string& expression, bool and_expr) {
-    self->add_part_trigger(PartExpression(expression, and_expr));
-    return self;
-}
-node_ptr add_part_complete(node_ptr self, const PartExpression& expr) {
-    self->add_part_complete(PartExpression(expr));
-    return self;
-}
-node_ptr add_part_complete_1(node_ptr self, const std::string& expression) {
-    self->add_part_complete(PartExpression(expression));
-    return self;
-}
-node_ptr add_part_complete_2(node_ptr self, const std::string& expression, bool and_expr) {
-    self->add_part_complete(PartExpression(expression, and_expr));
-    return self;
-}
-bool evaluate_trigger(node_ptr self) {
-    Ast* t = self->triggerAst();
-    if (t)
-        return t->evaluate();
-    return false;
-}
-bool evaluate_complete(node_ptr self) {
-    Ast* t = self->completeAst();
-    if (t)
-        return t->evaluate();
-    return false;
-}
-
-node_ptr add_defstatus(node_ptr self, DState::State s) {
-    self->addDefStatus(s);
-    return self;
-}
-node_ptr add_defstatus1(node_ptr self, const Defstatus& ds) {
-    self->addDefStatus(ds.state());
-    return self;
-}
-
-/////////////////////////////////////////////////////////////////////////////////////////
-
-static object do_rshift(node_ptr self, const bp::object& arg) {
-    // std::cout << "do_rshift\n";
-    (void)NodeUtil::do_add(self, arg);
-
-    if (extract<node_ptr>(arg).check()) {
-        NodeContainer* nc = self->isNodeContainer();
-        if (!nc)
-            throw std::runtime_error("ExportNode::do_rshift() : Can only add a child to Suite or Family");
-        node_ptr child = extract<node_ptr>(arg);
-
-        std::vector<node_ptr> children;
-        nc->immediateChildren(children);
-        node_ptr previous_child;
-        for (auto& i : children) {
-            if (previous_child && i == child) {
-                // if existing trigger, add new trigger as AND
-                if (child->get_trigger())
-                    child->add_part_trigger(
-                        PartExpression(previous_child->name() + " == complete", PartExpression::AND));
-                else
-                    child->add_trigger_expr(Expression(previous_child->name() + " == complete"));
-            }
-            if (i->defStatus() != DState::COMPLETE)
-                previous_child = i;
-        }
-    }
-    return object(self);
-}
-static object do_lshift(node_ptr self, const bp::object& arg) {
-    // std::cout << "do_lshift : " << self->name() << "\n"; cout << flush;
-    (void)NodeUtil::do_add(self, arg);
-
-    if (extract<node_ptr>(arg).check()) {
-
-        NodeContainer* nc = self->isNodeContainer();
-        if (!nc)
-            throw std::runtime_error("ExportNode::do_lshift() : Can only add a child to Suite or Family");
-        node_ptr child = extract<node_ptr>(arg);
-
-        std::vector<node_ptr> children;
-        nc->immediateChildren(children);
-        node_ptr previous_child;
-        for (size_t i = 0; i < children.size(); i++) {
-            if (i == 0)
-                continue;
-            if (children[i - 1]->defStatus() != DState::COMPLETE)
-                previous_child = children[i - 1];
-
-            if (previous_child && previous_child != child && children[i] == child) {
-                // if existing trigger, add new trigger as AND
-                if (previous_child->get_trigger())
-                    previous_child->add_part_trigger(
-                        PartExpression(child->name() + " == complete", PartExpression::AND));
-                else
-                    previous_child->add_trigger_expr(Expression(child->name() + " == complete"));
-            }
-        }
-    }
-    return object(self);
-}
-
-static object add(bp::tuple args, bp::dict kwargs) {
-    int the_list_size = len(args);
-    node_ptr self     = extract<node_ptr>(args[0]); // self
-    if (!self)
-        throw std::runtime_error("ExportNode::add() : first argument is not a node");
-
-    for (int i = 1; i < the_list_size; ++i)
-        (void)NodeUtil::do_add(self, args[i]);
-
-    // key word arguments are use for adding variable only
-    (void)NodeUtil::add_variable_dict(self, kwargs);
-
-    return object(self); // return node_ptr as python object, relies class_<Node>... for type registration
-}
-
-static object node_getattr(node_ptr self, const std::string& attr) {
-    // cout << " node_getattr  self.name() : " << self->name() << "  attr " << attr << "\n";
-    size_t pos     = 0;
-    node_ptr child = self->findImmediateChild(attr, pos);
-    if (child) {
-        return object(child);
-    }
-
-    const Variable& var = self->findVariable(attr);
-    if (!var.empty())
-        return object(var);
-
-    const Variable& gvar = self->findGenVariable(attr);
-    if (!gvar.empty())
-        return object(gvar);
-
-    const Event& event = self->findEventByNameOrNumber(attr);
-    if (!event.empty())
-        return object(event);
-
-    const Meter& meter = self->findMeter(attr);
-    if (!meter.empty())
-        return object(meter);
-
-    limit_ptr limit = self->find_limit(attr);
-    if (limit.get())
-        return object(limit);
-
-    std::stringstream ss;
-    ss << "ExportNode::node_getattr: function of name '" << attr
-       << "' does not exist *OR* child node,variable,meter,event or limit on node " << self->absNodePath();
-    throw std::runtime_error(ss.str());
-    return object();
-}
-
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////
-struct null_deleter
-{
-    void operator()(void const*) const {}
-};
-void do_replace_on_server(node_ptr self, ClientInvoker& theClient, bool suspend_node_first, bool force_replace) {
-    // cout << "ExportNode: do_replace_on_server " << self->absNodePath() << "\n";
-    // cout << " suspend_node_first " << suspend_node_first << "\n";
-    // cout << " force_replace  " << force_replace  << "\n";
-
-    // Need to make a defs_ptr from a Defs*  to avoid double delete use null_deletor
-    defs_ptr defs                   = defs_ptr(self->defs(), null_deleter());
-    bool create_parents_as_required = true;
-    if (suspend_node_first)
-        theClient.suspend(self->absNodePath());
-    theClient.replace_1(self->absNodePath(), defs, create_parents_as_required, force_replace); // this can throw
-}
-void replace_on_server(node_ptr self, bool suspend_node_first, bool force_replace) {
-    ClientInvoker theClient; // assume HOST and PORT found from environment
-    do_replace_on_server(self, theClient, suspend_node_first, force_replace);
-}
-void replace_on_server1(node_ptr self,
-                        const std::string& host,
-                        const std::string& port,
-                        bool suspend_node_first,
-                        bool force_replace) {
-    ClientInvoker theClient(host, port);
-    do_replace_on_server(self, theClient, suspend_node_first, force_replace);
-}
-void replace_on_server2(node_ptr self, const std::string& host_port, bool suspend_node_first, bool force_replace) {
-    ClientInvoker theClient(host_port);
-    do_replace_on_server(self, theClient, suspend_node_first, force_replace);
-}
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
-void export_Node() {
-    // Turn off proxies by passing true as the NoProxy template parameter.
-    // shared_ptrs don't need proxies because calls on one a copy of the
-    // shared_ptr will affect all of them (duh!).
-    class_<std::vector<node_ptr>>("NodeVec", "Hold a list of Nodes (i.e `suite`_, `family`_ or `task`_\\ s)")
-        .def(vector_indexing_suite<std::vector<node_ptr>, true>());
-
-    class_<Node, boost::noncopyable, node_ptr>("Node", DefsDoc::node_doc(), no_init)
-        .def("name", &Node::name, return_value_policy<copy_const_reference>())
-        .def("add", raw_function(add, 1), DefsDoc::add())  // a.add(b) & a.add([b])
-        .def(self < self)                                  // __lt__
-        .def("__add__", &NodeUtil::do_add, DefsDoc::add()) // a + b
-        .def("__rshift__",
-             &do_rshift) // nc >> a >> b >> c     a + (b.add(Trigger('a==complete')) + (c.add(Trigger('b==complete')))
-        .def("__lshift__",
-             &do_lshift) // nc << a << b << c     (a.add(Trigger('b==complete')) + (b.add(Trigger('c==complete'))) + c
-        .def("__iadd__", &NodeUtil::do_add)    // a += b
-        .def("__iadd__", &NodeUtil::node_iadd) // a += [ b ]
-        .def("__getattr__", &node_getattr)     /* Any attempt to resolve a property, method, or field name that doesn't
-                                                  actually exist on the object itself will be passed to __getattr__*/
-        .def("remove", &Node::remove, "Remove the node from its parent. and returns it")
-        .def("add_trigger", &add_trigger, DefsDoc::add_trigger_doc())
-        .def("add_trigger", &add_trigger_expr)
-        .def("add_complete", &add_complete, DefsDoc::add_trigger_doc())
-        .def("add_complete", &add_complete_expr)
-        .def("add_part_trigger", &add_part_trigger, DefsDoc::add_trigger_doc())
-        .def("add_part_trigger", &add_part_trigger_1)
-        .def("add_part_trigger", &add_part_trigger_2)
-        .def("add_part_complete", &add_part_complete, DefsDoc::add_trigger_doc())
-        .def("add_part_complete", &add_part_complete_1)
-        .def("add_part_complete", &add_part_complete_2)
-        .def("evaluate_trigger", &evaluate_trigger, "evaluate trigger expression")
-        .def("evaluate_complete", &evaluate_complete, "evaluate complete expression")
-        .def("add_variable", &add_variable, DefsDoc::add_variable_doc())
-        .def("add_variable", &add_variable_int)
-        .def("add_variable", &add_variable_var)
-        .def("add_variable", &NodeUtil::add_variable_dict)
-        .def("add_label", &add_label, DefsDoc::add_label_doc())
-        .def("add_label", &add_label_1)
-        .def("add_limit", &add_limit, DefsDoc::add_limit_doc())
-        .def("add_limit", &add_limit_1)
-        .def("add_inlimit",
-             &add_in_limit,
-             (bp::arg("limit_name"),
-              bp::arg("path_to_node_containing_limit") = "",
-              bp::arg("tokens")                        = 1,
-              bp::arg("limit_this_node_only")          = false),
-             DefsDoc::add_inlimit_doc())
-        .def("add_inlimit", &add_in_limit_1)
-        .def("add_event", &add_event, DefsDoc::add_event_doc())
-        .def("add_event", &add_event_1)
-        .def("add_event", &add_event_2)
-        .def("add_event", &add_event_3)
-        .def("add_meter", &add_meter, DefsDoc::add_meter_doc())
-        .def("add_meter", &add_meter_1)
-        .def("add_meter", &add_meter_2)
-        .def("add_queue", &add_queue)
-        .def("add_queue", &add_queue1)
-        .def("add_generic", &add_generic)
-        .def("add_generic", &add_generic1)
-        .def("add_date", &add_date, DefsDoc::add_date_doc())
-        .def("add_date", &add_date_1)
-        .def("add_day", &add_day, DefsDoc::add_day_doc())
-        .def("add_day", &add_day_1)
-        .def("add_day", &add_day_2)
-        .def("add_today", &add_today, DefsDoc::add_today_doc())
-        .def("add_today", &add_today_1)
-        .def("add_today", &add_today_2)
-        .def("add_today", &add_today_3)
-        .def("add_time", &add_time, DefsDoc::add_time_doc())
-        .def("add_time", &add_time_1)
-        .def("add_time", &add_time_2)
-        .def("add_time", &add_time_3)
-        .def("add_cron", &add_cron, DefsDoc::add_cron_doc())
-        .def("add_late", &add_late, DefsDoc::add_late_doc())
-        .def("add_autocancel", &add_autocancel, DefsDoc::add_autocancel_doc())
-        .def("add_autocancel", &add_autocancel_1)
-        .def("add_autocancel", &add_autocancel_2)
-        .def("add_autocancel", &add_autocancel_3)
-        .def("add_autoarchive",
-             &add_autoarchive,
-             (bp::arg("days"), bp::arg("idle") = false),
-             DefsDoc::add_autoarchive_doc())
-        .def("add_autoarchive",
-             &add_autoarchive_1,
-             (bp::arg("hour"), bp::arg("min"), bp::arg("relative"), bp::arg("idle") = false))
-        .def("add_autoarchive", &add_autoarchive_2, (bp::arg("TimeSlot"), bp::arg("relative"), bp::arg("idle") = false))
-        .def("add_autoarchive", &add_autoarchive_3)
-        .def("add_autorestore", &add_autorestore, DefsDoc::add_autorestore_doc())
-        .def("add_autorestore", &add_autorestore1)
-        .def("add_verify", &Node::addVerify, DefsDoc::add_verify_doc())
-        .def("add_repeat", &add_repeat_date, DefsDoc::add_repeat_date_doc())
-        .def("add_repeat", &add_repeat_datetime, DefsDoc::add_repeat_datetime_doc())
-        .def("add_repeat", &add_repeat_date_list, DefsDoc::add_repeat_date_list_doc())
-        .def("add_repeat", &add_repeat_integer, DefsDoc::add_repeat_integer_doc())
-        .def("add_repeat", &add_repeat_string, DefsDoc::add_repeat_string_doc())
-        .def("add_repeat", &add_repeat_enum, DefsDoc::add_repeat_enumerated_doc())
-        .def("add_repeat", &add_repeat_day, DefsDoc::add_repeat_day_doc())
-        .def("add_defstatus", &add_defstatus, DefsDoc::add_defstatus_doc())
-        .def("add_defstatus", &add_defstatus1, DefsDoc::add_defstatus_doc())
-        .def("add_zombie", &add_zombie, NodeAttrDoc::zombie_doc())
-        .def("delete_variable", &Node::deleteVariable)
-        .def("delete_event", &Node::deleteEvent)
-        .def("delete_meter", &Node::deleteMeter)
-        .def("delete_label", &Node::deleteLabel)
-        .def("delete_queue", &Node::delete_queue)
-        .def("delete_generic", &Node::delete_generic)
-        .def("delete_trigger", &Node::deleteTrigger)
-        .def("delete_complete", &Node::deleteComplete)
-        .def("delete_repeat", &Node::deleteRepeat)
-        .def("delete_limit", &Node::deleteLimit)
-        .def("delete_inlimit", &Node::deleteInlimit)
-        .def("delete_time", &Node::deleteTime)
-        .def("delete_time", &Node::delete_time)
-        .def("delete_today", &Node::deleteToday)
-        .def("delete_today", &Node::delete_today)
-        .def("delete_date", &Node::deleteDate)
-        .def("delete_date", &Node::delete_date)
-        .def("delete_day", &Node::deleteDay)
-        .def("delete_day", &Node::delete_day)
-        .def("delete_cron", &Node::deleteCron)
-        .def("delete_cron", &Node::delete_cron)
-        .def("delete_zombie", &Node::deleteZombie)
-        .def("delete_zombie", &Node::delete_zombie)
-        .def("change_trigger", &Node::changeTrigger)
-        .def("change_complete", &Node::changeComplete)
-        .def("sort_attributes", &sort_attributes)
-        .def("sort_attributes", &sort_attributes1)
-        .def("sort_attributes", &sort_attributes2)
-        .def("sort_attributes",
-             &sort_attributes3,
-             (bp::arg("attribute_type"), bp::arg("recursive") = true, bp::arg("no_sort") = bp::list()))
-        .def("sort_attributes", &Node::sort_attributes, (bp::arg("attribute_type"), bp::arg("recursive") = true))
-        .def("get_abs_node_path", &Node::absNodePath, DefsDoc::abs_node_path_doc())
-        .def("has_time_dependencies", &Node::hasTimeDependencies)
-        .def("update_generated_variables", &Node::update_generated_variables)
-        .def("get_generated_variables",
-             &Node::gen_variables,
-             "returns a list of generated variables. Use ecflow.VariableList as return argument")
-        .def("is_suspended", &Node::isSuspended, "Returns true if the `node`_ is in a `suspended`_ state")
-        .def("find_variable",
-             &Node::findVariable,
-             return_value_policy<copy_const_reference>(),
-             "Find user variable on the node only.  Returns a object")
-        .def("find_gen_variable",
-             &Node::findGenVariable,
-             return_value_policy<copy_const_reference>(),
-             "Find generated variable on the node only.  Returns a object")
-        .def("find_parent_variable",
-             &Node::find_parent_variable,
-             return_value_policy<copy_const_reference>(),
-             "Find user variable variable up the parent hierarchy.  Returns a object")
-        .def("find_parent_variable_sub_value",
-             &Node::find_parent_variable_sub_value,
-             "Find user variable *up* node tree, then variable substitute the value, otherwise return empty string")
-        .def("find_meter",
-             &Node::findMeter,
-             return_value_policy<copy_const_reference>(),
-             "Find the `meter`_ on the node only. Returns a object")
-        .def("find_event",
-             &Node::findEventByNameOrNumber,
-             return_value_policy<copy_const_reference>(),
-             "Find the `event`_ on the node only. Returns a object")
-        .def("find_label",
-             &Node::find_label,
-             return_value_policy<copy_const_reference>(),
-             "Find the `label`_ on the node only. Returns a object")
-        .def("find_queue",
-             &Node::find_queue,
-             return_value_policy<copy_const_reference>(),
-             "Find the queue on the node only. Returns a queue object")
-        .def("find_generic",
-             &Node::find_generic,
-             return_value_policy<copy_const_reference>(),
-             "Find the `generic`_ on the node only. Returns a Generic object")
-        .def("find_limit", &Node::find_limit, "Find the `limit`_ on the node only. returns a limit ptr")
-        .def("find_node_up_the_tree", &Node::find_node_up_the_tree, "Search immediate node, then up the node hierarchy")
-        .def("get_state", &Node::state, "Returns the state of the node. This excludes the suspended state")
-        .def("get_state_change_time",
-             &get_state_change_time,
-             (bp::arg("format") = "iso_extended"),
-             "Returns the time of the last state change as a string. Default format is iso_extended, (iso_extended, "
-             "iso, simple)")
-        .def("get_dstate", &Node::dstate, "Returns the state of node. This will include suspended state")
-        .def("get_defstatus", &Node::defStatus)
-        .def("get_repeat", &Node::repeat, return_value_policy<copy_const_reference>())
-        .def("get_late", &Node::get_late, return_internal_reference<>())
-        .def("get_autocancel", &Node::get_autocancel, return_internal_reference<>())
-        .def("get_autoarchive", &Node::get_autoarchive, return_internal_reference<>())
-        .def("get_autorestore", &Node::get_autorestore, return_internal_reference<>())
-        .def("get_trigger", &Node::get_trigger, return_internal_reference<>())
-        .def("get_complete", &Node::get_complete, return_internal_reference<>())
-        .def("get_defs", get_defs, return_internal_reference<>())
-        .def("get_parent", &Node::parent, return_internal_reference<>())
-        .def("get_all_nodes", &get_all_nodes, "Returns all the child nodes")
-        .def("get_flag",
-             &Node::get_flag,
-             return_value_policy<copy_const_reference>(),
-             "Return additional state associated with a node.")
-        .def("replace_on_server",
-             &replace_on_server,
-             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
-             "replace node on the server.")
-        .def("replace_on_server",
-             &replace_on_server1,
-             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
-             "replace node on the server.")
-        .def("replace_on_server",
-             &replace_on_server2,
-             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
-             "replace node on the server.")
-        .def("replace_on_server",
-             &do_replace_on_server,
-             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
-             "replace node on the server.")
-        .add_property("meters", bp::range(&Node::meter_begin, &Node::meter_end), "Returns a list of `meter`_\\ s")
-        .add_property("events", bp::range(&Node::event_begin, &Node::event_end), "Returns a list of `event`_\\ s")
-        .add_property("variables",
-                      bp::range(&Node::variable_begin, &Node::variable_end),
-                      "Returns a list of user defined `variable`_\\ s")
-        .add_property("labels", bp::range(&Node::label_begin, &Node::label_end), "Returns a list of `label`_\\ s")
-        .add_property("limits", bp::range(&Node::limit_begin, &Node::limit_end), "Returns a list of `limit`_\\ s")
-        .add_property(
-            "inlimits", bp::range(&Node::inlimit_begin, &Node::inlimit_end), "Returns a list of `inlimit`_\\ s")
-        .add_property("verifies", bp::range(&Node::verify_begin, &Node::verify_end), "Returns a list of Verify's")
-        .add_property("times", bp::range(&Node::time_begin, &Node::time_end), "Returns a list of `time`_\\ s")
-        .add_property("todays", bp::range(&Node::today_begin, &Node::today_end), "Returns a list of `today`_\\ s")
-        .add_property("dates", bp::range(&Node::date_begin, &Node::date_end), "Returns a list of `date`_\\ s")
-        .add_property("days", bp::range(&Node::day_begin, &Node::day_end), "Returns a list of `day`_\\ s")
-        .add_property("crons", bp::range(&Node::cron_begin, &Node::cron_end), "Returns a list of `cron`_\\ s")
-        .add_property("zombies", bp::range(&Node::zombie_begin, &Node::zombie_end), "Returns a list of `zombie`_\\ s")
-        .add_property("queues", bp::range(&Node::queue_begin, &Node::queue_end), "Returns a list of `queue`_\\ s")
-        .add_property(
-            "generics", bp::range(&Node::generic_begin, &Node::generic_end), "Returns a list of `generic`_\\ s");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<node_ptr>(); // needed for mac and boost 1.6
-#endif
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ExportNodeAttr.cpp 5.13.0-1/Pyext/src/ecflow/python/ExportNodeAttr.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ExportNodeAttr.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ExportNodeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,993 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <stdexcept>
-
-#include <boost/python.hpp>
-#include <boost/python/raw_function.hpp>
-#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/ClockAttr.hpp"
-#include "ecflow/attribute/CronAttr.hpp"
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/attribute/GenericAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/attribute/RepeatAttr.hpp"
-#include "ecflow/attribute/TimeAttr.hpp"
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/attribute/Zombie.hpp"
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/node/Attr.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Expression.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/InLimit.hpp"
-#include "ecflow/node/JobCreationCtrl.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/DefsDoc.hpp"
-#include "ecflow/python/NodeAttrDoc.hpp"
-#include "ecflow/python/Trigger.hpp"
-
-using namespace ecf;
-using namespace boost::python;
-using namespace std;
-namespace bp = boost::python;
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-///////////////////////////////////////////////////////////////////////////////////////////////////
-object late_raw_constructor(bp::tuple args, bp::dict kw) {
-    // cout << "late_raw_constructor len(args):" << len(args) << endl;
-    //  args[0] is Late(i.e self)
-    if (len(args) > 1)
-        throw std::runtime_error("late_raw_constructor: Late only expects keyword arguments, ie. "
-                                 "Late(submitted='00:20',active='15:00',complete='+30:00')");
-    return args[0].attr("__init__")(kw); // calls -> late_init(dict kw)
-}
-
-static void extract_late_keyword_arguments(std::shared_ptr<LateAttr> late, bp::dict& dict) {
-    boost::python::list keys = dict.keys();
-    const int no_of_keys     = len(keys);
-    for (int i = 0; i < no_of_keys; ++i) {
-        if (extract<string>(keys[i]).check()) {
-            std::string first = extract<std::string>(keys[i]);
-            if (extract<string>(dict[keys[i]]).check()) {
-                std::string second = extract<string>(dict[keys[i]]);
-                int hour           = 0;
-                int min            = 0;
-                bool relative      = TimeSeries::getTime(second, hour, min);
-                if (first == "submitted")
-                    late->add_submitted(hour, min);
-                else if (first == "active")
-                    late->add_active(hour, min);
-                else if (first == "complete")
-                    late->add_complete(hour, min, relative);
-                else
-                    throw std::runtime_error(
-                        "extract_late_keyword_arguments: keyword arguments, expected [submitted | active | complete]");
-            }
-            else
-                throw std::runtime_error("extract_late_keyword_arguments: expected keyword arguments to be a string, "
-                                         "ie Late(submitted='00:20',active='15:00',complete='+30:00')");
-        }
-    }
-}
-
-static std::shared_ptr<LateAttr> late_init(bp::dict& dict) {
-    std::shared_ptr<LateAttr> late = std::make_shared<LateAttr>();
-    extract_late_keyword_arguments(late, dict);
-    return late;
-}
-
-static std::shared_ptr<LateAttr> late_create() {
-    return std::make_shared<LateAttr>();
-}
-
-///////////////////////////////////////////////////////////////////////////////////////////////////
-object cron_raw_constructor(bp::tuple args, bp::dict kw) {
-    // cout << "cron_raw_constructor len(args):" << len(args) << endl;
-    //  args[0] is Cron(i.e self) args[1] is string name
-    for (int i = 1; i < len(args); ++i) {
-        if (extract<string>(args[i]).check()) {
-            std::string time_series = extract<string>(args[i]);
-            if (time_series.empty())
-                throw std::runtime_error("cron_raw_constructor: Empty string, please pass a valid time, i.e '12:30'");
-            return args[0].attr("__init__")(time_series, kw); // calls -> init(const std::string& ts, dict kw)
-        }
-        if (extract<TimeSeries>(args[i]).check()) {
-            TimeSeries time_series = extract<TimeSeries>(args[i]);
-            return args[0].attr("__init__")(time_series, kw); // calls -> init(const TimeSeries& ts, dict kw)
-        }
-        else
-            throw std::runtime_error("cron_raw_constructor: expects string | TimeSeries and keyword arguments");
-    }
-    throw std::runtime_error("cron_raw_constructor: expects string | TimeSeries and keyword arguments !!");
-    return object();
-}
-
-static void extract_cron_keyword_arguments(std::shared_ptr<CronAttr> cron, bp::dict& dict) {
-    boost::python::list keys = dict.keys();
-    const int no_of_keys     = len(keys);
-    for (int i = 0; i < no_of_keys; ++i) {
-
-        if (extract<string>(keys[i]).check()) {
-            std::string first = extract<std::string>(keys[i]);
-            if (extract<bp::list>(dict[keys[i]]).check()) {
-
-                bp::list second = extract<bp::list>(dict[keys[i]]);
-                std::vector<int> int_vec;
-                BoostPythonUtil::list_to_int_vec(second, int_vec);
-
-                //  expected keywords are: days_of_week,last_week_days_ofThe_month, days_of_month, months
-                if (first == "days_of_week")
-                    cron->addWeekDays(int_vec);
-                else if (first == "days_of_month")
-                    cron->addDaysOfMonth(int_vec);
-                else if (first == "months")
-                    cron->addMonths(int_vec);
-                else if (first == "last_week_days_of_the_month")
-                    cron->add_last_week_days_of_month(int_vec);
-                else
-                    throw std::runtime_error(
-                        "extract_cron_keyword_arguments: keyword arguments, expected [days_of_week | "
-                        "last_week_days_of_the_month | days_of_month | months | last_day_of_the_month");
-            }
-            else if (extract<bool>(dict[keys[i]]).check()) {
-                if (first == "last_day_of_the_month")
-                    cron->add_last_day_of_month();
-                else
-                    throw std::runtime_error(
-                        "extract_cron_keyword_arguments: keyword arguments, expected [days_of_week | "
-                        "last_week_days_of_the_month | days_of_month | months | last_day_of_the_month]");
-            }
-            else
-                throw std::runtime_error("extract_cron_keyword_arguments: keyword arguments to be a list");
-        }
-    }
-}
-
-static std::shared_ptr<CronAttr> cron_init(const std::string& ts, bp::dict& dict) {
-    std::shared_ptr<CronAttr> cron = std::make_shared<CronAttr>(ts);
-    extract_cron_keyword_arguments(cron, dict);
-    return cron;
-}
-
-static std::shared_ptr<CronAttr> cron_init1(const TimeSeries& ts, bp::dict& dict) {
-    std::shared_ptr<CronAttr> cron = std::make_shared<CronAttr>(ts);
-    extract_cron_keyword_arguments(cron, dict);
-    return cron;
-}
-
-static std::shared_ptr<CronAttr> cron_create() {
-    return std::make_shared<CronAttr>();
-}
-static std::shared_ptr<CronAttr> cron_create2(const TimeSeries& ts) {
-    return std::make_shared<CronAttr>(ts);
-}
-///////////////////////////////////////////////////////////////////////////////////////////////////
-
-void add_time_series_3(CronAttr* self, const std::string& ts) {
-    self->addTimeSeries(TimeSeries::create(ts));
-}
-
-void set_week_days(CronAttr* cron, const bp::list& list) {
-    std::vector<int> int_vec;
-    BoostPythonUtil::list_to_int_vec(list, int_vec);
-    cron->addWeekDays(int_vec);
-}
-void set_last_week_days_of_month(CronAttr* cron, const bp::list& list) {
-    std::vector<int> int_vec;
-    BoostPythonUtil::list_to_int_vec(list, int_vec);
-    cron->add_last_week_days_of_month(int_vec);
-}
-
-void set_days_of_month(CronAttr* cron, const bp::list& list) {
-    std::vector<int> int_vec;
-    BoostPythonUtil::list_to_int_vec(list, int_vec);
-    cron->addDaysOfMonth(int_vec);
-}
-void set_last_day_of_the_month(CronAttr* cron) {
-    cron->add_last_day_of_month();
-}
-
-void set_months(CronAttr* cron, const bp::list& list) {
-    std::vector<int> int_vec;
-    BoostPythonUtil::list_to_int_vec(list, int_vec);
-    cron->addMonths(int_vec);
-}
-
-// Create as shared because: we want to pass a Python list as part of the constructor,
-// *AND* the only way make_constructor works is with a pointer.
-// The Node::add function seem to cope with this, some boost python magic,must do a conversion
-// from shared_ptr to pass by reference
-static std::shared_ptr<RepeatEnumerated> create_RepeatEnumerated(const std::string& name, const bp::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    return std::make_shared<RepeatEnumerated>(name, vec);
-}
-static std::shared_ptr<RepeatDateList> create_RepeatDateList(const std::string& name, const bp::list& list) {
-    std::vector<int> vec;
-    BoostPythonUtil::list_to_int_vec(list, vec);
-    return std::make_shared<RepeatDateList>(name, vec);
-}
-static std::shared_ptr<RepeatString> create_RepeatString(const std::string& name, const bp::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    return std::make_shared<RepeatString>(name, vec);
-}
-static std::shared_ptr<AutoRestoreAttr> create_AutoRestoreAttr(const boost::python::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    return std::make_shared<AutoRestoreAttr>(vec);
-}
-
-static std::shared_ptr<QueueAttr> create_queue(const std::string& name, const boost::python::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    return std::make_shared<QueueAttr>(name, vec);
-}
-
-static std::shared_ptr<GenericAttr> create_generic(const std::string& name, const boost::python::list& list) {
-    std::vector<std::string> vec;
-    BoostPythonUtil::list_to_str_vec(list, vec);
-    return std::make_shared<GenericAttr>(name, vec);
-}
-
-static std::shared_ptr<ZombieAttr>
-create_ZombieAttr(Child::ZombieType zt, const bp::list& list, User::Action uc, int life_time_in_server) {
-    std::vector<Child::CmdType> vec;
-    int the_list_size = len(list);
-    vec.reserve(the_list_size);
-    for (int i = 0; i < the_list_size; ++i) {
-        vec.push_back(extract<Child::CmdType>(list[i]));
-    }
-    return std::make_shared<ZombieAttr>(zt, vec, uc, life_time_in_server);
-}
-
-static std::shared_ptr<ZombieAttr> create_ZombieAttr1(Child::ZombieType zt, const bp::list& list, User::Action uc) {
-    std::vector<Child::CmdType> vec;
-    int the_list_size = len(list);
-    vec.reserve(the_list_size);
-    for (int i = 0; i < the_list_size; ++i) {
-        vec.push_back(extract<Child::CmdType>(list[i]));
-    }
-    return std::make_shared<ZombieAttr>(zt, vec, uc);
-}
-
-static bp::list wrap_set_of_strings(Limit* limit) {
-    bp::list list;
-    const std::set<std::string>& paths = limit->paths();
-    for (std::string path : paths) {
-        list.append(path);
-    }
-    return list;
-}
-
-static job_creation_ctrl_ptr makeJobCreationCtrl() {
-    return std::make_shared<JobCreationCtrl>();
-}
-
-void export_NodeAttr() {
-    // Trigger & Complete thin wrapper over Expression, allows us to call: Task("a").add(Trigger("a=1"),Complete("b=1"))
-    class_<Trigger, std::shared_ptr<Trigger>>("Trigger", DefsDoc::trigger(), init<std::string>())
-        .def(init<PartExpression>())
-        .def(init<bp::list>())
-        .def(init<std::string, bool>())
-        .def(self == self)                    // __eq__
-        .def("__str__", &Trigger::expression) // __str__
-        .def("get_expression", &Trigger::expression, "returns the trigger expression as a string");
-
-    class_<Complete, std::shared_ptr<Complete>>("Complete", DefsDoc::trigger(), init<std::string>())
-        .def(init<PartExpression>())
-        .def(init<bp::list>())
-        .def(init<std::string, bool>())
-        .def(self == self)                     // __eq__
-        .def("__str__", &Complete::expression) // __str__
-        .def("get_expression", &Complete::expression, "returns the complete expression as a string");
-
-    // mimic PartExpression(const std::string& expression  )
-    // mimic PartExpression(const std::string& expression, bool andExpr /* true means AND , false means OR */ )
-    // Use to adding large trigger and complete expressions
-    class_<PartExpression>("PartExpression", DefsDoc::part_expression_doc(), init<std::string>())
-        .def(init<std::string, bool>())
-        .def(self == self) // __eq__
-        .def("get_expression",
-             &PartExpression::expression,
-             return_value_policy<copy_const_reference>(),
-             "returns the part expression as a string")
-        .def("and_expr", &PartExpression::andExpr)
-        .def("or_expr", &PartExpression::orExpr);
-
-    class_<Expression, std::shared_ptr<Expression>>("Expression", DefsDoc::expression_doc(), init<std::string>())
-        .def(init<PartExpression>())
-        .def(self == self)                       // __eq__
-        .def("__str__", &Expression::expression) // __str__
-        .def("get_expression", &Expression::expression, "returns the complete expression as a string")
-        .def("add",
-             &Expression::add,
-             "Add a part expression, the second and subsequent part expressions must have 'and/or' set")
-        .add_property(
-            "parts", bp::range(&Expression::part_begin, &Expression::part_end), "Returns a list of PartExpression's");
-
-    enum_<Flag::Type>("FlagType",
-                      "Flags store state associated with a node\n\n"
-                      "- FORCE_ABORT   - Node* do not run when try_no > ECF_TRIES, and task aborted by user\n"
-                      "- USER_EDIT     - task\n"
-                      "- TASK_ABORTED  - task*\n"
-                      "- EDIT_FAILED   - task*\n"
-                      "- JOBCMD_FAILED - task*\n"
-                      "- KILLCMD_FAILED   - task*\n"
-                      "- STATUSCMD_FAILED - task*\n"
-                      "- NO_SCRIPT     - task*\n"
-                      "- KILLED        - task* do not run when try_no > ECF_TRIES, and task killed by user\n"
-                      "- STATUS        - task* indicates that the status command has been run\n"
-                      "- LATE          - Node attribute, Task is late, or Defs checkpt takes to long\n"
-                      "- MESSAGE       - Node\n"
-                      "- BYRULE        - Node*, set if node is set to complete by complete trigger expression\n"
-                      "- QUEUELIMIT    - Node\n"
-                      "- WAIT          - task* \n"
-                      "- LOCKED        - Server\n"
-                      "- ZOMBIE        - task*\n"
-                      "- NO_REQUE      - task\n"
-                      "- ARCHIVED      - Suite/Family\n"
-                      "- RESTORED      - Family/Family\n"
-                      "- THRESHOLD     - task\n"
-                      "- SIGTERM       - Defs, records that server received a SIGTERM signal\n"
-                      "- LOG_ERROR     - Error in opening or writing to log file\n"
-                      "- CHECKPT_ERROR - Error in opening or writing to checkpt file \n"
-                      "- NOT_SET\n")
-        .value("force_abort", Flag::FORCE_ABORT)
-        .value("user_edit", Flag::USER_EDIT)
-        .value("task_aborted", Flag::TASK_ABORTED)
-        .value("edit_failed", Flag::EDIT_FAILED)
-        .value("jobcmd_failed", Flag::JOBCMD_FAILED)
-        .value("killcmd_failed", Flag::KILLCMD_FAILED)
-        .value("statuscmd_failed", Flag::STATUSCMD_FAILED)
-        .value("no_script", Flag::NO_SCRIPT)
-        .value("killed", Flag::KILLED)
-        .value("status", Flag::STATUS)
-        .value("late", Flag::LATE)
-        .value("message", Flag::MESSAGE)
-        .value("byrule", Flag::BYRULE)
-        .value("queuelimit", Flag::QUEUELIMIT)
-        .value("wait", Flag::WAIT)
-        .value("locked", Flag::LOCKED)
-        .value("zombie", Flag::ZOMBIE)
-        .value("no_reque", Flag::NO_REQUE_IF_SINGLE_TIME_DEP)
-        .value("archived", Flag::ARCHIVED)
-        .value("restored", Flag::RESTORED)
-        .value("threshold", Flag::THRESHOLD)
-        .value("sigterm", Flag::ECF_SIGTERM)
-        .value("not_set", Flag::NOT_SET)
-        .value("log_error", Flag::LOG_ERROR)
-        .value("checkpt_error", Flag::CHECKPT_ERROR);
-
-    class_<Flag>("Flag", "Represents additional state associated with a Node.\n\n", init<>())
-        .def("__str__", &Flag::to_string) // __str__
-        .def(self == self)                // __eq__
-        .def("is_set", &Flag::is_set, "Queries if a given flag is set")
-        .def("set", &Flag::set, "Sets the given flag. Used in test only")
-        .def("clear", &Flag::clear, "Clear the given flag. Used in test only")
-        .def("reset", &Flag::reset, "Clears all flags. Used in test only")
-        .def("list", &Flag::list, "Returns the list of all flag types. returns FlagTypeVec. Used in test only")
-        .staticmethod("list")
-        .def("type_to_string", &Flag::enum_to_string, "Convert type to a string. Used in test only")
-        .staticmethod("type_to_string");
-
-    class_<std::vector<Flag::Type>>("FlagTypeVec", "Hold a list of flag types")
-        .def(vector_indexing_suite<std::vector<Flag::Type>, true>());
-
-    class_<JobCreationCtrl, boost::noncopyable, job_creation_ctrl_ptr>("JobCreationCtrl", DefsDoc::jobgenctrl_doc())
-        .def("__init__", make_constructor(makeJobCreationCtrl), DefsDoc::jobgenctrl_doc())
-        .def("set_node_path",
-             &JobCreationCtrl::set_node_path,
-             "The node we want to check job creation for. If no node specified check all tasks")
-        .def("set_dir_for_job_creation",
-             &JobCreationCtrl::set_dir_for_job_creation,
-             "Specify directory, for job creation")
-        .def("set_verbose", &JobCreationCtrl::set_verbose, "Output each task as its being checked.")
-        .def("get_dir_for_job_creation",
-             &JobCreationCtrl::dir_for_job_creation,
-             return_value_policy<copy_const_reference>(),
-             "Returns the directory set for job creation")
-        .def(
-            "generate_temp_dir",
-            &JobCreationCtrl::generate_temp_dir,
-            "Automatically generated temporary directory for job creation. Directory written to stdout for information")
-        .def("get_error_msg",
-             &JobCreationCtrl::get_error_msg,
-             return_value_policy<copy_const_reference>(),
-             "Returns an error message generated during checking of job creation");
-
-    enum_<Child::ZombieType>("ZombieType", NodeAttrDoc::zombie_type_doc())
-        .value("ecf", Child::ECF)
-        .value("ecf_pid", Child::ECF_PID)
-        .value("ecf_pid_passwd", Child::ECF_PID_PASSWD)
-        .value("ecf_passwd", Child::ECF_PASSWD)
-        .value("user", Child::USER)
-        .value("path", Child::PATH);
-
-    enum_<User::Action>("ZombieUserActionType", NodeAttrDoc::zombie_user_action_type_doc())
-        .value("fob", User::FOB)
-        .value("fail", User::FAIL)
-        .value("remove", User::REMOVE)
-        .value("adopt", User::ADOPT)
-        .value("block", User::BLOCK)
-        .value("kill", User::KILL);
-
-    enum_<Child::CmdType>("ChildCmdType", NodeAttrDoc::child_cmd_type_doc())
-        .value("init", Child::INIT)
-        .value("event", Child::EVENT)
-        .value("meter", Child::METER)
-        .value("label", Child::LABEL)
-        .value("wait", Child::WAIT)
-        .value("queue", Child::QUEUE)
-        .value("abort", Child::ABORT)
-        .value("complete", Child::COMPLETE);
-
-    enum_<Attr::Type>("AttrType",
-                      "Sortable attribute type, currently [event | meter | label | limit | variable | all ]")
-        .value("event", Attr::EVENT)
-        .value("meter", Attr::METER)
-        .value("label", Attr::LABEL)
-        .value("limit", Attr::LIMIT)
-        .value("variable", Attr::VARIABLE)
-        .value("all", Attr::ALL);
-
-    // 	ZombieAttr(ecf::Child::ZombieType t, const std::vector<ecf::Child::CmdType>& c, ecf::User::Action a, int
-    // zombie_lifetime);
-    class_<ZombieAttr>("ZombieAttr", NodeAttrDoc::zombie_doc())
-        .def("__init__", make_constructor(&create_ZombieAttr))
-        .def("__init__", make_constructor(&create_ZombieAttr1))
-        .def("__str__", &ZombieAttr::toString)   // __str__
-        .def("__copy__", copyObject<ZombieAttr>) // __copy__ uses copy constructor
-        .def(self == self)                       // __eq__
-        .def("empty", &ZombieAttr::empty, "Return true if the attribute is empty")
-        .def("zombie_type", &ZombieAttr::zombie_type, "Returns the `zombie type`_")
-        .def("user_action", &ZombieAttr::action, "The automated action to invoke, when zombies arise")
-        .def("zombie_lifetime",
-             &ZombieAttr::zombie_lifetime,
-             "Returns the lifetime in seconds of `zombie`_ in the server")
-        .add_property("child_cmds",
-                      bp::range(&ZombieAttr::child_begin, &ZombieAttr::child_end),
-                      "The list of child commands. If empty action applies to all child cmds");
-
-    class_<std::vector<Zombie>>("ZombieVec", "Hold a list of zombies")
-        .def(vector_indexing_suite<std::vector<Zombie>, true>());
-
-    class_<Zombie>("Zombie", "Represent a zombie process stored by the server")
-        .def("__str__", &Zombie::to_string)  // __str__
-        .def("__copy__", copyObject<Zombie>) // __copy__ uses copy constructor
-        .def(self == self)                   // __eq__
-        .def("empty", &Zombie::empty)
-        .def("manual_user_action", &Zombie::manual_user_action)
-        .def("fob", &Zombie::fob)
-        .def("fail", &Zombie::fail)
-        .def("adopt", &Zombie::adopt)
-        .def("block", &Zombie::block)
-        .def("remove", &Zombie::remove)
-        .def("kill", &Zombie::kill)
-        .def("type", &Zombie::type)
-        .def("type_str", &Zombie::type_str)
-        .def("last_child_cmd", &Zombie::last_child_cmd)
-        .def("attr", &Zombie::attr, return_value_policy<copy_const_reference>())
-        .def("calls", &Zombie::calls)
-        .def("jobs_password", &Zombie::jobs_password, return_value_policy<copy_const_reference>())
-        .def("path_to_task", &Zombie::path_to_task, return_value_policy<copy_const_reference>())
-        .def("process_or_remote_id", &Zombie::process_or_remote_id, return_value_policy<copy_const_reference>())
-        .def("user_cmd", &Zombie::user_cmd, return_value_policy<copy_const_reference>())
-        .def("try_no", &Zombie::try_no)
-        .def("duration", &Zombie::duration)
-        .def("user_action", &Zombie::user_action)
-        .def("user_action_str", &Zombie::user_action_str)
-        .def("host", &Zombie::host, return_value_policy<copy_const_reference>())
-        .def("allowed_age", &Zombie::allowed_age);
-
-    class_<Variable>("Variable", NodeAttrDoc::variable_doc(), init<std::string, std::string>())
-        .def("__str__", &Variable::toString)   // __str__
-        .def("__copy__", copyObject<Variable>) // __copy__ uses copy constructor
-        .def(self < self)                      // __lt__
-        .def(self == self)                     // __eq__
-        .def("name", &Variable::name, return_value_policy<copy_const_reference>(), "Return the variable name as string")
-        .def("value",
-             &Variable::theValue,
-             return_value_policy<copy_const_reference>(),
-             "Return the variable value as a string")
-        .def("empty",
-             &Variable::empty,
-             "Return true if the variable is empty. Used when returning a Null variable, from a find");
-    // .add_property("value", make_function(&Variable::theValue ,return_value_policy<copy_const_reference>()),
-    //                       &Variable::set_value,  "get/set the value as a property")
-    // The following works v = Variable('name','fred')
-    //   print v.value
-    // But it will then break v.value()
-
-    // We need to return pass a list of Variable as arguments, to retrieve the generated variables
-    class_<std::vector<Variable>>("VariableList", "Hold a list of Variables")
-        .def(vector_indexing_suite<std::vector<Variable>>());
-
-    class_<Label>("Label", NodeAttrDoc::label_doc(), init<std::string, std::string>())
-        .def(self == self)                  // __eq__
-        .def("__str__", &Label::toString)   // __str__
-        .def("__copy__", copyObject<Label>) // __copy__ uses copy constructor
-        .def(self < self)                   // __lt__
-        .def("name", &Label::name, return_value_policy<copy_const_reference>(), "Return the `label`_ name as string")
-        .def("value",
-             &Label::value,
-             return_value_policy<copy_const_reference>(),
-             "Return the original `label`_ value as string")
-        .def("new_value",
-             &Label::new_value,
-             return_value_policy<copy_const_reference>(),
-             "Return the new label value as string")
-        .def(
-            "empty", &Label::empty, "Return true if the Label is empty. Used when returning a NULL Label, from a find");
-
-    // This will not work, because paths_begin
-    //.add_property("node_paths", bp::range(&Limit::paths_begin,&Limit::paths_begin),"List of nodes(paths) that have
-    // consumed a limit")
-
-    class_<Limit, std::shared_ptr<Limit>>("Limit", NodeAttrDoc::limit_doc(), init<std::string, int>())
-        .def(self == self)                  // __eq__
-        .def("__str__", &Limit::toString)   // __str__
-        .def("__copy__", copyObject<Limit>) // __copy__ uses copy constructor
-        .def(self < self)                   // __lt__
-        .def("name", &Limit::name, return_value_policy<copy_const_reference>(), "Return the `limit`_ name as string")
-        .def("value", &Limit::value, "The `limit`_ token value as an integer")
-        .def("limit", &Limit::theLimit, "The max value of the `limit`_ as an integer")
-        .def("increment", &Limit::increment, "used for test only")
-        .def("decrement", &Limit::decrement, "used for test only")
-        .def("node_paths", &wrap_set_of_strings, "List of nodes(paths) that have consumed a limit");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<std::shared_ptr<Limit>>(); // needed for mac and boost 1.6
-#endif
-
-    class_<InLimit>("InLimit", NodeAttrDoc::inlimit_doc())
-        .def(init<std::string>())
-        .def(init<std::string, std::string>())
-        .def(init<std::string, std::string, int>())
-        .def(init<std::string, std::string, int, bool>())
-        .def(init<std::string, std::string, int, bool, bool>())
-        .def(self == self)                    // __eq__
-        .def("__str__", &InLimit::toString)   // __str__
-        .def("__copy__", copyObject<InLimit>) // __copy__ uses copy constructor
-        .def(self < self)                     // __lt__
-        .def(
-            "name", &InLimit::name, return_value_policy<copy_const_reference>(), "Return the `inlimit`_ name as string")
-        .def("path_to_node",
-             &InLimit::pathToNode,
-             return_value_policy<copy_const_reference>(),
-             "Path to the node that holds the limit, can be empty")
-        .def("limit_this_node_only",
-             &InLimit::limit_this_node_only,
-             "Only this node is limited. i.e. typically Family or Suite")
-        .def("limit_submission", &InLimit::limit_submission, "Limit submission only")
-        .def("tokens", &InLimit::tokens, "The number of token to consume from the Limit");
-
-    class_<Event>("Event", NodeAttrDoc::event_doc(), init<int, bp::optional<std::string>>())
-        .def(init<int, std::string, bool>()) // here bool is the initial value, by default is false/clear. The value
-                                             // taken by begin/re-queue
-        .def(init<std::string, bool>()) // here bool is the initial value, by default is false/clear. The value taken by
-                                        // begin/re-queue
-        .def(init<std::string>())
-        .def(self == self)                  // __eq__
-        .def("__str__", &Event::toString)   // __str__
-        .def("__copy__", copyObject<Event>) // __copy__ uses copy constructor
-        .def(self < self)                   // __lt__
-        .def("name",
-             &Event::name,
-             return_value_policy<copy_const_reference>(),
-             "Return the Events name as string. If number supplied name may be empty.")
-        .def("number", &Event::number, "Return events number as a integer. If not specified return max integer value")
-        .def("name_or_number", &Event::name_or_number, "Returns name or number as string")
-        .def("value", &Event::value, "Return events current value")
-        .def("initial_value",
-             &Event::initial_value,
-             "Return events initial value, This is value taken for begin/re-queue")
-        .def(
-            "empty", &Event::empty, "Return true if the Event is empty. Used when returning a NULL Event, from a find");
-
-    class_<Meter>("Meter", NodeAttrDoc::meter_doc(), init<std::string, int, int, bp::optional<int>>())
-        .def(self == self)                  // __eq__
-        .def("__str__", &Meter::toString)   // __str__
-        .def("__copy__", copyObject<Meter>) // __copy__ uses copy constructor
-        .def(self < self)                   // __lt__
-        .def("name", &Meter::name, return_value_policy<copy_const_reference>(), "Return the Meters name as string")
-        .def("min", &Meter::min, "Return the Meters minimum value")
-        .def("max", &Meter::max, "Return the Meters maximum value")
-        .def("value", &Meter::value, "Return meters current value")
-        .def("color_change", &Meter::colorChange, "returns the color change")
-        .def(
-            "empty", &Meter::empty, "Return true if the Meter is empty. Used when returning a NULL Meter, from a find");
-
-    class_<QueueAttr>("Queue", NodeAttrDoc::queue_doc())
-        .def("__init__", make_constructor(&create_queue))
-        .def(self == self)                      // __eq__
-        .def("__str__", &QueueAttr::toString)   // __str__
-        .def("__copy__", copyObject<QueueAttr>) // __copy__ uses copy constructor
-        .def(self < self)                       // __lt__
-        .def("name", &QueueAttr::name, return_value_policy<copy_const_reference>(), "Return the queue name as string")
-        .def("value", &QueueAttr::value, "Return the queue current value as string")
-        .def("index", &QueueAttr::index, "Return the queue current index as a integer")
-        .def("empty",
-             &QueueAttr::empty,
-             "Return true if the Queue is empty. Used when returning a NULL Queue, from a find");
-
-    class_<GenericAttr>(
-        "Generic", "A generic attribute, used to add new attributes for the future, without requiring a API change")
-        .def("__init__", make_constructor(&create_generic))
-        .def(self == self)                        // __eq__
-        .def("__str__", &GenericAttr::to_string)  // __str__
-        .def("__copy__", copyObject<GenericAttr>) // __copy__ uses copy constructor
-        .def(self < self)                         // __lt__
-        .def("name",
-             &GenericAttr::name,
-             return_value_policy<copy_const_reference>(),
-             "Return the generic name as string")
-        .def("empty",
-             &GenericAttr::empty,
-             "Return true if the Generic is empty. Used when returning a NULL Generic, from a find")
-        .add_property("values",
-                      boost::python::range(&GenericAttr::values_begin, &GenericAttr::values_end),
-                      "The list of values for the generic");
-
-    class_<DateAttr>("Date", NodeAttrDoc::date_doc(), init<int, int, int>()) // day,month,year
-        .def(init<std::string>())
-        .def(self == self)                     // __eq__
-        .def("__str__", &DateAttr::toString)   // __str__
-        .def("__copy__", copyObject<DateAttr>) // __copy__ uses copy constructor
-        .def(self < self)                      // __lt__
-        .def("day", &DateAttr::day, "Return the day. The range is 0-31, 0 means its wild-carded")
-        .def("month", &DateAttr::month, "Return the month. The range is 0-12, 0 means its wild-carded")
-        .def("year", &DateAttr::year, "Return the year, 0 means its wild-carded");
-
-    enum_<DayAttr::Day_t>("Days", NodeAttrDoc::days_enum_doc())
-        .value("sunday", DayAttr::SUNDAY)
-        .value("monday", DayAttr::MONDAY)
-        .value("tuesday", DayAttr::TUESDAY)
-        .value("wednesday", DayAttr::WEDNESDAY)
-        .value("thursday", DayAttr::THURSDAY)
-        .value("friday", DayAttr::FRIDAY)
-        .value("saturday", DayAttr::SATURDAY);
-
-    class_<DayAttr>("Day", NodeAttrDoc::day_doc(), init<DayAttr::Day_t>())
-        .def(init<std::string>())             // constructor
-        .def(self == self)                    // __eq__
-        .def("__str__", &DayAttr::toString)   // __str__
-        .def("__copy__", copyObject<DayAttr>) // __copy__ uses copy constructor
-        .def(self < self)                     // __lt__
-        .def("day", &DayAttr::day, "Return the day as enumerator");
-
-    class_<TimeAttr>("Time", NodeAttrDoc::time_doc(), init<TimeSlot, bp::optional<bool>>())
-        .def(init<int, int, bp::optional<bool>>()) // hour, minute, relative
-        .def(init<TimeSeries>())
-        .def(init<TimeSlot, TimeSlot, TimeSlot, bool>())
-        .def(init<std::string>())
-        .def(self == self)                     // __eq__
-        .def("__str__", &TimeAttr::toString)   // __str__
-        .def("__copy__", copyObject<TimeAttr>) // __copy__ uses copy constructor
-        .def("time_series",
-             &TimeAttr::time_series,
-             return_value_policy<copy_const_reference>(),
-             "Return the Time attributes time series");
-
-    class_<TodayAttr>("Today", NodeAttrDoc::today_doc(), init<TimeSlot, bp::optional<bool>>())
-        .def(init<int, int, bp::optional<bool>>()) // hour, minute, relative
-        .def(init<TimeSeries>())
-        .def(init<TimeSlot, TimeSlot, TimeSlot, bool>())
-        .def(init<std::string>())
-        .def(self == self)                      // __eq__
-        .def("__str__", &TodayAttr::toString)   // __str__
-        .def("__copy__", copyObject<TodayAttr>) // __copy__ uses copy constructor
-        .def("time_series",
-             &TodayAttr::time_series,
-             return_value_policy<copy_const_reference>(),
-             "Return the Todays time series");
-
-    class_<LateAttr, std::shared_ptr<LateAttr>>("Late", NodeAttrDoc::late_doc())
-        .def("__init__", raw_function(&late_raw_constructor, 1)) // will call -> late_init
-        .def("__init__", make_constructor(&late_init))
-        .def("__init__", make_constructor(&late_create))
-        .def(
-            "submitted",
-            &LateAttr::addSubmitted,
-            "submitted(TimeSlot):The time node can stay `submitted`_. Submitted is always relative. If the node stays\n"
-            "submitted longer than the time specified, the `late`_ flag is set\n")
-        .def(
-            "submitted",
-            &LateAttr::add_submitted,
-            "submitted(hour,minute) The time node can stay submitted. Submitted is always relative. If the node stays\n"
-            "submitted longer than the time specified, the late flag is set\n")
-        .def("active",
-             &LateAttr::add_active,
-             "active(hour,minute): The time the node must become `active`_. If the node is still `queued`_ or "
-             "`submitted`_\n"
-             "by the time specified, the late flag is set")
-        .def(
-            "active",
-            &LateAttr::addActive,
-            "active(TimeSlot):The time the node must become `active`_. If the node is still `queued`_ or `submitted`_\n"
-            "by the time specified, the late flag is set")
-        .def("complete",
-             &LateAttr::add_complete,
-             "complete(hour,minute):The time the node must become `complete`_. If relative, time is taken from the "
-             "time\n"
-             "the node became `active`_, otherwise node must be `complete`_ by the time given")
-        .def("complete",
-             &LateAttr::addComplete,
-             "complete(TimeSlot): The time the node must become `complete`_. If relative, time is taken from the time\n"
-             "the node became `active`_, otherwise node must be `complete`_ by the time given")
-        .def(self == self)                     // __eq__
-        .def("__str__", &LateAttr::toString)   // __str__
-        .def("__copy__", copyObject<LateAttr>) // __copy__ uses copy constructor
-        .def("submitted",
-             &LateAttr::submitted,
-             return_value_policy<copy_const_reference>(),
-             "Return the submitted time as a TimeSlot")
-        .def("active",
-             &LateAttr::active,
-             return_value_policy<copy_const_reference>(),
-             "Return the active time as a TimeSlot")
-        .def("complete",
-             &LateAttr::complete,
-             return_value_policy<copy_const_reference>(),
-             "Return the complete time as a TimeSlot")
-        .def("complete_is_relative",
-             &LateAttr::complete_is_relative,
-             "Returns a boolean where true means that complete is relative")
-        .def("is_late", &LateAttr::isLate, "Return True if late");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<std::shared_ptr<LateAttr>>(); // needed for mac and boost 1.6
-#endif
-
-    class_<AutoCancelAttr, std::shared_ptr<AutoCancelAttr>>(
-        "Autocancel", NodeAttrDoc::autocancel_doc(), init<int, int, bool>() // hour, minute, relative
-        )
-        .def(init<int>()) // days
-        .def(init<TimeSlot, bool>())
-        .def(self == self)                           // __eq__
-        .def("__str__", &AutoCancelAttr::toString)   // __str__
-        .def("__copy__", copyObject<AutoCancelAttr>) // __copy__ uses copy constructor
-        .def(self < self)                            // __lt__
-        .def("time",
-             &AutoCancelAttr::time,
-             return_value_policy<copy_const_reference>(),
-             "returns cancel time as a TimeSlot")
-        .def("relative", &AutoCancelAttr::relative, "Returns a boolean where true means the time is relative")
-        .def("days", &AutoCancelAttr::days, "Returns a boolean true if time was specified in days");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<std::shared_ptr<AutoCancelAttr>>(); // needed for mac and boost 1.6
-#endif
-
-    class_<AutoArchiveAttr, std::shared_ptr<AutoArchiveAttr>>(
-        "Autoarchive",
-        NodeAttrDoc::autoarchive_doc(),
-        init<int, int, bool, bool>() // hour, minute,relative,idle(true means queued,aborted,complete, false means
-                                     // completed only)
-        )
-        .def(init<int, bool>())                       // days, idle
-        .def(init<TimeSlot, bool, bool>())            // TimeSlot,relative,idle
-        .def(self == self)                            // __eq__
-        .def("__str__", &AutoArchiveAttr::toString)   // __str__
-        .def("__copy__", copyObject<AutoArchiveAttr>) // __copy__ uses copy constructor
-        .def(self < self)                             // __lt__
-        .def("time",
-             &AutoArchiveAttr::time,
-             return_value_policy<copy_const_reference>(),
-             "returns archive time as a TimeSlot")
-        .def("relative", &AutoArchiveAttr::relative, "Returns a boolean where true means the time is relative")
-        .def("days", &AutoArchiveAttr::days, "Returns a boolean true if time was specified in days")
-        .def("idle",
-             &AutoArchiveAttr::idle,
-             "Returns a boolean true if archiving when idle, i.e queued,aborted,complete and time elapsed");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    boost::python::register_ptr_to_python<std::shared_ptr<AutoArchiveAttr>>(); // needed for mac and boost 1.6
-#endif
-
-    class_<AutoRestoreAttr, std::shared_ptr<AutoRestoreAttr>>("Autorestore", NodeAttrDoc::autorestore_doc())
-        .def("__init__", make_constructor(&create_AutoRestoreAttr))
-        .def(self == self)                            // __eq__
-        .def("__str__", &AutoRestoreAttr::toString)   // __str__
-        .def("__copy__", copyObject<AutoRestoreAttr>) // __copy__ uses copy constructor
-        .def("nodes_to_restore",
-             &AutoRestoreAttr::nodes_to_restore,
-             return_value_policy<copy_const_reference>(),
-             "returns a list of nodes to be restored");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    boost::python::register_ptr_to_python<std::shared_ptr<AutoRestoreAttr>>(); // needed for mac and boost 1.6
-#endif
-
-    class_<RepeatDate>("RepeatDate",
-                       NodeAttrDoc::repeat_date_doc(),
-                       init<std::string, int, int, bp::optional<int>>()) // name, start, end , delta
-        .def(self == self)                                               // __eq__
-        .def("__str__", &RepeatDate::toString)                           // __str__
-        .def("__copy__", copyObject<RepeatDate>)                         // __copy__ uses copy constructor
-        .def("name", &RepeatDate::name, return_value_policy<copy_const_reference>(), "Return the name of the repeat.")
-        .def("start", &RepeatDate::start, "Return the start date as an integer in yyyymmdd format")
-        .def("end", &RepeatDate::end, "Return the end date as an integer in yyyymmdd format")
-        .def("step",
-             &RepeatDate::step,
-             "Return the step increment. This is used to update the repeat, until end date is reached");
-
-    class_<RepeatDateTime>("RepeatDateTime",
-                           NodeAttrDoc::repeat_datetime_doc(),
-                           init<std::string, std::string, std::string, bp::optional<std::string>>()) // name, start, end , delta
-        .def(self == self)                                                             // __eq__
-        .def("__str__", &RepeatDateTime::toString)                                     // __str__
-        .def("__copy__", copyObject<RepeatDateTime>)                                   // __copy__ uses copy constructor
-        .def("name",
-             &RepeatDateTime::name,
-             return_value_policy<copy_const_reference>(),
-             "Return the name of the repeat.")
-        .def(
-            "start", &RepeatDateTime::start, "Return the start date as an integer (i.e. seconds since 19700101T000000)")
-        .def("end", &RepeatDateTime::end, "Return the end date as an integer (i.e. seconds since 19700101T000000)")
-        .def("step",
-             &RepeatDateTime::step,
-             "Return the step increment (in seconds). This is used to update the repeat, until end instant is reached");
-
-    class_<RepeatDateList>("RepeatDateList", NodeAttrDoc::repeat_date_list_doc())
-        .def("__init__", make_constructor(&create_RepeatDateList))
-        .def(self == self)                           // __eq__
-        .def("__str__", &RepeatDateList::toString)   // __str__
-        .def("__copy__", copyObject<RepeatDateList>) // __copy__ uses copy constructor
-        .def("name",
-             &RepeatDateList::name,
-             return_value_policy<copy_const_reference>(),
-             "Return the name of the repeat.")
-        .def("start", &RepeatDateList::start, "Return the start date as an integer in yyyymmdd format")
-        .def("end", &RepeatDateList::end, "Return the end date as an integer in yyyymmdd format");
-
-    class_<RepeatInteger>("RepeatInteger",
-                          NodeAttrDoc::repeat_integer_doc(),
-                          init<std::string, int, int, bp::optional<int>>()) // name, start, end , delta = 1
-        .def(self == self)                                                  // __eq__
-        .def("__str__", &RepeatInteger::toString)                           // __str__
-        .def("__copy__", copyObject<RepeatInteger>)                         // __copy__ uses copy constructor
-        .def(
-            "name", &RepeatInteger::name, return_value_policy<copy_const_reference>(), "Return the name of the repeat.")
-        .def("start", &RepeatInteger::start)
-        .def("end", &RepeatInteger::end)
-        .def("step", &RepeatInteger::step);
-
-    // Create as shared because: we want to pass a Python list as part of the constructor,
-    // and the only way make_constructor works is with a pointer.
-    class_<RepeatEnumerated, std::shared_ptr<RepeatEnumerated>>("RepeatEnumerated",
-                                                                NodeAttrDoc::repeat_enumerated_doc())
-        .def("__init__", make_constructor(&create_RepeatEnumerated))
-        .def(self == self)                             // __eq__
-        .def("__str__", &RepeatEnumerated::toString)   // __str__
-        .def("__copy__", copyObject<RepeatEnumerated>) // __copy__ uses copy constructor
-        .def("name",
-             &RepeatEnumerated::name,
-             return_value_policy<copy_const_reference>(),
-             "Return the name of the `repeat`_.")
-        .def("start", &RepeatEnumerated::start)
-        .def("end", &RepeatEnumerated::end)
-        .def("step", &RepeatEnumerated::step);
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<std::shared_ptr<RepeatEnumerated>>(); // needed for mac and boost 1.6
-#endif
-
-    class_<RepeatString, std::shared_ptr<RepeatString>>("RepeatString", NodeAttrDoc::repeat_string_doc())
-        .def("__init__", make_constructor(&create_RepeatString))
-        .def(self == self)                         // __eq__
-        .def("__str__", &RepeatString::toString)   // __str__
-        .def("__copy__", copyObject<RepeatString>) // __copy__ uses copy constructor
-        .def("name",
-             &RepeatString::name,
-             return_value_policy<copy_const_reference>(),
-             "Return the name of the `repeat`_.")
-        .def("start", &RepeatString::start)
-        .def("end", &RepeatString::end)
-        .def("step", &RepeatString::step);
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<std::shared_ptr<RepeatString>>(); // needed for mac and boost 1.6
-#endif
-
-    class_<RepeatDay>("RepeatDay", NodeAttrDoc::repeat_day_doc(), init<bp::optional<int>>())
-        .def(self == self)                      // __eq__
-        .def("__str__", &RepeatDay::toString)   // __str__
-        .def("__copy__", copyObject<RepeatDay>) // __copy__ uses copy constructor
-        ;
-
-    class_<Repeat>("Repeat", NodeAttrDoc::repeat_doc(), init<int>())
-        .def(self == self)                   // __eq__
-        .def("__str__", &Repeat::toString)   // __str__
-        .def("__copy__", copyObject<Repeat>) // __copy__ uses copy constructor
-        .def("empty", &Repeat::empty, "Return true if the repeat is empty.")
-        .def("name",
-             &Repeat::name,
-             return_value_policy<copy_const_reference>(),
-             "The `repeat`_ name, can be referenced in `trigger`_ expressions")
-        .def("start", &Repeat::start, "The start value of the repeat, as an integer")
-        .def("end", &Repeat::end, "The last value of the repeat, as an integer")
-        .def("step", &Repeat::step, "The increment for the repeat, as an integer")
-        .def("value", &Repeat::last_valid_value, "The current value of the repeat as an integer");
-
-    void (CronAttr::*add_time_series)(const TimeSeries&) = &CronAttr::addTimeSeries;
-    void (CronAttr::*add_time_series_2)(const TimeSlot& s, const TimeSlot& f, const TimeSlot& i) =
-        &CronAttr::addTimeSeries;
-    class_<CronAttr, std::shared_ptr<CronAttr>>("Cron", NodeAttrDoc::cron_doc())
-        .def("__init__", raw_function(&cron_raw_constructor, 1)) // will call -> cron_init or cron_init1
-        .def("__init__", make_constructor(&cron_init))
-        .def("__init__", make_constructor(&cron_init1))
-        .def("__init__", make_constructor(&cron_create2))
-        .def("__init__", make_constructor(&cron_create))
-        .def(self == self)                     // __eq__
-        .def("__str__", &CronAttr::toString)   // __str__
-        .def("__copy__", copyObject<CronAttr>) // __copy__ uses copy constructor
-        .def("set_week_days",
-             &set_week_days,
-             "Specifies days of week. Expects a list of integers, with integer range 0==Sun to 6==Sat")
-        .def("set_last_week_days_of_the_month",
-             &set_last_week_days_of_month,
-             "Specifies last week days of the month. Expects a list of integers, with integer range 0==Sun to 6==Sat")
-        .def("set_days_of_month",
-             &set_days_of_month,
-             "Specifies days of the month. Expects a list of integers with integer range 1-31")
-        .def("set_last_day_of_the_month", &set_last_day_of_the_month, "Set cron for the last day of the month")
-        .def("set_months", &set_months, "Specifies months. Expects a list of integers, with integer range 1-12")
-        .def("set_time_series",
-             &CronAttr::add_time_series,
-             (bp::arg("hour"), bp::arg("minute"), bp::arg("relative") = false),
-             "time_series(hour(int),minute(int),relative to suite start(bool=false)), Add a time slot")
-        .def("set_time_series", add_time_series, "Add a time series. This will never complete")
-        .def("set_time_series", add_time_series_2, "Add a time series. This will never complete")
-        .def("set_time_series", &add_time_series_3, "Add a time series. This will never complete")
-        .def("time", &CronAttr::time, return_value_policy<copy_const_reference>(), "return cron time as a TimeSeries")
-        .def("last_day_of_the_month", &CronAttr::last_day_of_the_month, "Return true if last day of month is enabled")
-        .add_property("week_days",
-                      bp::range(&CronAttr::week_days_begin, &CronAttr::week_days_end),
-                      "returns a integer list of week days")
-        .add_property("last_week_days_of_the_month",
-                      bp::range(&CronAttr::last_week_days_of_month_begin, &CronAttr::last_week_days_end_of_month_end),
-                      "returns a integer list of last week days of the month")
-        .add_property("days_of_month",
-                      bp::range(&CronAttr::days_of_month_begin, &CronAttr::days_of_month_end),
-                      "returns a integer list of days of the month")
-        .add_property("months",
-                      bp::range(&CronAttr::months_begin, &CronAttr::months_end),
-                      "returns a integer list of months of the year");
-
-    class_<VerifyAttr>("Verify", init<NState::State, int>()) // state, expected
-        .def(self == self)                                   // __eq__
-        .def("__str__", &VerifyAttr::toString)               // __str__
-        .def("__copy__", copyObject<VerifyAttr>)             // __copy__ uses copy constructor
-        ;
-
-    class_<ClockAttr, std::shared_ptr<ClockAttr>>(
-        "Clock", NodeAttrDoc::clock_doc(), init<int, int, int, bp::optional<bool>>()) // day, month, year, hybrid
-        .def(init<int, int, int, bool>())
-        .def(init<bool>())
-        .def(self == self)                      // __eq__
-        .def("__str__", &ClockAttr::toString)   // __str__
-        .def("__copy__", copyObject<ClockAttr>) // __copy__ uses copy constructor
-        .def("set_gain_in_seconds", &ClockAttr::set_gain_in_seconds, "Set the gain in seconds")
-        .def("set_gain", &ClockAttr::set_gain, "Set the gain in hours and minutes")
-        .def("day", &ClockAttr::day, "Returns the day as an integer, range 1-31")
-        .def("month", &ClockAttr::month, "Returns the month as an integer, range 1-12")
-        .def("year", &ClockAttr::year, "Returns the year as an integer, > 1400")
-        .def("gain", &ClockAttr::gain, "Returns the gain as an long. This represents seconds")
-        .def("positive_gain",
-             &ClockAttr::positive_gain,
-             "Returns a boolean, where true means that the gain is positive");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<std::shared_ptr<ClockAttr>>(); // needed for mac and boost 1.6
-#endif
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ExportSuiteAndFamily.cpp 5.13.0-1/Pyext/src/ecflow/python/ExportSuiteAndFamily.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ExportSuiteAndFamily.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ExportSuiteAndFamily.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,153 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/python.hpp>
-#include <boost/python/raw_function.hpp>
-#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
-
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/DefsDoc.hpp"
-#include "ecflow/python/NodeUtil.hpp"
-
-using namespace ecf;
-using namespace boost::python;
-using namespace std;
-namespace bp = boost::python;
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-
-/// Since we don't pass in a child pos, the nodes are added to the end
-family_ptr add_family(NodeContainer* self, family_ptr f) {
-    self->addFamily(f);
-    return f;
-}
-task_ptr add_task(NodeContainer* self, task_ptr t) {
-    self->addTask(t);
-    return t;
-}
-
-suite_ptr add_clock(suite_ptr self, const ClockAttr& clk) {
-    self->addClock(clk);
-    return self;
-}
-suite_ptr add_end_clock(suite_ptr self, const ClockAttr& clk) {
-    self->add_end_clock(clk);
-    return self;
-}
-
-// Sized and Container protocol
-size_t family_len(family_ptr self) {
-    return self->nodeVec().size();
-}
-size_t suite_len(suite_ptr self) {
-    return self->nodeVec().size();
-}
-bool family_container(family_ptr self, const std::string& name) {
-    size_t pos;
-    return (self->findImmediateChild(name, pos)) ? true : false;
-}
-bool suite_container(suite_ptr self, const std::string& name) {
-    size_t pos;
-    return (self->findImmediateChild(name, pos)) ? true : false;
-}
-
-// Context management, Only used to provide indentation
-suite_ptr suite_enter(suite_ptr self) {
-    return self;
-}
-bool suite_exit(suite_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
-    return false;
-}
-family_ptr family_enter(family_ptr self) {
-    return self;
-}
-bool family_exit(family_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
-    return false;
-}
-
-family_ptr family_init(const std::string& name, bp::list the_list, bp::dict kw) {
-    // cout << "family_init : " << name << " the_list: " << len(the_list) << " dict: " << len(kw) << endl;
-    family_ptr node = Family::create(name);
-    (void)NodeUtil::add_variable_dict(node, kw);
-    (void)NodeUtil::node_iadd(node, the_list);
-    return node;
-}
-
-suite_ptr suite_init(const std::string& name, bp::list the_list, bp::dict kw) {
-    // cout << "suite_init : " << name << " the_list: " << len(the_list) << " dict: " << len(kw) << endl;
-    suite_ptr node = Suite::create(name);
-    (void)NodeUtil::add_variable_dict(node, kw);
-    (void)NodeUtil::node_iadd(node, the_list);
-    return node;
-}
-
-void export_SuiteAndFamily() {
-    // Turn off proxies by passing true as the NoProxy template parameter.
-    // shared_ptrs don't need proxies because calls on one a copy of the
-    // shared_ptr will affect all of them (duh!).
-    class_<std::vector<family_ptr>>("FamilyVec", "Hold a list of `family`_ nodes")
-        .def(vector_indexing_suite<std::vector<family_ptr>, true>());
-
-    class_<std::vector<suite_ptr>>("SuiteVec", "Hold a list of `suite`_ nodes's")
-        .def(vector_indexing_suite<std::vector<suite_ptr>, true>());
-
-    // choose the correct overload
-    class_<NodeContainer, bases<Node>, boost::noncopyable>("NodeContainer", DefsDoc::node_container_doc(), no_init)
-        .def("__iter__", bp::range(&NodeContainer::node_begin, &NodeContainer::node_end))
-        .def("add_family", &NodeContainer::add_family, DefsDoc::add_family_doc())
-        .def("add_family", add_family)
-        .def("add_task", &NodeContainer::add_task, DefsDoc::add_task_doc())
-        .def("add_task", add_task)
-        .def("find_node", &NodeContainer::find_by_name, "Find immediate child node given a name")
-        .def("find_task", &NodeContainer::findTask, "Find a task given a name")
-        .def("find_family", &NodeContainer::findFamily, "Find a family given a name")
-        .add_property(
-            "nodes", bp::range(&NodeContainer::node_begin, &NodeContainer::node_end), "Returns a list of Node's");
-
-    class_<Family, bases<NodeContainer>, family_ptr>("Family", DefsDoc::family_doc())
-        .def("__init__", raw_function(&NodeUtil::node_raw_constructor, 1)) // will call -> family_init
-        .def("__init__", make_constructor(&family_init), DefsDoc::family_doc())
-        .def("__init__", make_constructor(&Family::create_me), DefsDoc::family_doc())
-        .def(self == self)                      // __eq__
-        .def("__str__", &Family::to_string)     // __str__
-        .def("__copy__", copyObject<Family>)    // __copy__ uses copy constructor
-        .def("__enter__", &family_enter)        // allow with statement, hence indentation support
-        .def("__exit__", &family_exit)          // allow with statement, hence indentation support
-        .def("__len__", &family_len)            // Implement sized protocol for immediate children
-        .def("__contains__", &family_container) // Implement container protocol for immediate children
-        ;
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<family_ptr>(); // needed for mac and boost 1.6
-#endif
-
-    class_<Suite, bases<NodeContainer>, suite_ptr>("Suite", DefsDoc::suite_doc())
-        .def("__init__", raw_function(&NodeUtil::node_raw_constructor, 1)) // will call -> suite_init
-        .def("__init__", make_constructor(&suite_init), DefsDoc::suite_doc())
-        .def("__init__", make_constructor(&Suite::create_me), DefsDoc::suite_doc())
-        .def(self == self)                     // __eq__
-        .def("__str__", &Suite::to_string)     // __str__
-        .def("__copy__", copyObject<Suite>)    // __copy__ uses copy constructor
-        .def("__enter__", &suite_enter)        // allow with statement, hence indentation support
-        .def("__exit__", &suite_exit)          // allow with statement, hence indentation support
-        .def("__len__", &suite_len)            // Implement sized protocol for immediate children
-        .def("__contains__", &suite_container) // Implement container protocol for immediate children
-        .def("add_clock", &add_clock)
-        .def("get_clock", &Suite::clockAttr, "Returns the `suite`_ `clock`_")
-        .def("add_end_clock", &add_end_clock, "End clock, used to mark end of simulation")
-        .def("get_end_clock", &Suite::clock_end_attr, "Return the suite's end clock. Can be NULL")
-        .def("begun", &Suite::begun, "Returns true if the `suite`_ has begun, false otherwise");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<suite_ptr>(); // needed for mac and boost 1.6
-#endif
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/ExportTask.cpp 5.13.0-1/Pyext/src/ecflow/python/ExportTask.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/ExportTask.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/ExportTask.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,98 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/python.hpp>
-#include <boost/python/raw_function.hpp>
-#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
-
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/DefsDoc.hpp"
-#include "ecflow/python/NodeUtil.hpp"
-
-using namespace ecf;
-using namespace boost::python;
-using namespace std;
-namespace bp = boost::python;
-
-// Sized protocol
-bool task_len(task_ptr self) {
-    return self->aliases().size();
-}
-
-task_ptr task_enter(task_ptr self) {
-    return self;
-}
-bool task_exit(task_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
-    return false;
-}
-
-task_ptr task_init(const std::string& name, bp::list the_list, bp::dict kw) {
-    // cout << "task_init: " << name << " the_list: " << len(the_list) << " dict: " << len(kw) << endl;
-    task_ptr node = Task::create(name);
-    (void)NodeUtil::add_variable_dict(node, kw);
-    (void)NodeUtil::node_iadd(node, the_list);
-    return node;
-}
-
-// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
-
-void export_Task() {
-    // Turn off proxies by passing true as the NoProxy template parameter.
-    // shared_ptrs don't need proxies because calls on one a copy of the
-    // shared_ptr will affect all of them (duh!).
-    class_<std::vector<task_ptr>>("TaskVec", "Hold a list of `task`_ nodes")
-        .def(vector_indexing_suite<std::vector<task_ptr>, true>());
-
-    class_<Submittable, bases<Node>, boost::noncopyable>("Submittable", DefsDoc::submittable_doc(), no_init)
-        .def("get_jobs_password",
-             &Submittable::jobsPassword,
-             return_value_policy<copy_const_reference>(),
-             "The password. This generated by server")
-        .def("get_process_or_remote_id",
-             &Submittable::process_or_remote_id,
-             return_value_policy<copy_const_reference>(),
-             "The process or remote id of the running job")
-        .def("get_try_no", &Submittable::tryNo, "The current try number as a string.")
-        .def("get_int_try_no", &Submittable::try_no, "The current try number as integer.")
-        .def("get_aborted_reason",
-             &Submittable::abortedReason,
-             return_value_policy<copy_const_reference>(),
-             "If node was aborted and a reason was provided, return the string");
-
-    class_<Task, bases<Submittable>, task_ptr>("Task", DefsDoc::task_doc())
-        .def("__init__", raw_function(&NodeUtil::node_raw_constructor, 1)) // will call -> task_init
-        .def("__init__", make_constructor(&task_init), DefsDoc::task_doc())
-        .def("__init__",
-             make_constructor(&Task::create_me),
-             DefsDoc::task_doc())          // create_me take a single string argument
-        .def(self == self)                 // __eq__
-        .def("__enter__", &task_enter)     // allow with statement, hence indentation support
-        .def("__exit__", &task_exit)       // allow with statement, hence indentation support
-        .def("__str__", &Task::to_string)  // __str__
-        .def("__copy__", copyObject<Task>) // __copy__ uses copy constructor
-        .def("__len__", &task_len)         // Implement sized protocol for immediate children
-        .def("__iter__", bp::range(&Task::alias_begin, &Task::alias_end)) // implement iter protocol
-        .add_property("aliases", bp::range(&Task::alias_begin, &Task::alias_end), "Returns a list of aliases")
-        .add_property("nodes", bp::range(&Task::alias_begin, &Task::alias_end), "Returns a list of aliases");
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<task_ptr>(); // needed for mac and boost 1.6
-#endif
-
-    class_<Alias, bases<Submittable>, alias_ptr>("Alias", DefsDoc::alias_doc(), no_init)
-        .def(self == self)                  // __eq__
-        .def("__str__", &Alias::to_string)  // __str__
-        .def("__copy__", copyObject<Alias>) // __copy__ uses copy constructor
-        ;
-#if ECF_ENABLE_PYTHON_PTR_REGISTER
-    bp::register_ptr_to_python<alias_ptr>(); // needed for mac and boost 1.6
-#endif
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/GlossaryDoc.cpp 5.13.0-1/Pyext/src/ecflow/python/GlossaryDoc.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/GlossaryDoc.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/GlossaryDoc.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/GlossaryDoc.hpp"
-
-const char* GlossaryDoc::list() {
-    return "Create a empty Defs\n\n"
-        // ".. _active: glossary_\n"
-        // ".. _aborted: glossary_\n"
-        // ".. _autocancel: glossary_\n"
-        // ".. _complete expression: glossary_\n"
-        // ".. _check point: glossary_\n"
-        // ".. _child command: glossary_\n"
-        // ".. _clock: glossary_\n"
-        // ".. _complete: glossary_\n"
-        // ".. _cron: glossary_\n"
-        // ".. _date: glossary_\n"
-        // ".. _day: glossary_\n"
-        // ".. _defstatus: glossary_\n"
-        // ".. _dependencies: glossary_\n"
-        // ".. _ecflow_server: glossary_\n"
-        // ".. _ecf script: glossary_\n"
-        // ".. _event: glossary_\n"
-        // ".. _extern: glossary_\n"
-        // ".. _family: glossary_\n"
-        // ".. _halted: glossary_\n"
-        // ".. _inlimit: glossary_\n"
-        // ".. _job creation: glossary_\n"
-        // ".. _job file: glossary_\n"
-        // ".. _label: glossary_\n"
-        // ".. _late: glossary_\n"
-        // ".. _limit: glossary_\n"
-        // ".. _meter: glossary_\n"
-        // ".. _node: glossary_\n"
-        // ".. _pre-processing: glossary_\n"
-        // ".. _repeat: glossary_\n"
-        // ".. _server states: glossary_\n"
-        // ".. _suite definition: glossary_\n"
-        // ".. _submitted: glossary_\n"
-        // ".. _suite: glossary_\n"
-        // ".. _shutdown: glossary_\n"
-        // ".. _suspended: glossary_\n"
-        // ".. _task: glossary_\n"
-        // ".. _time: glossary_\n"
-        // ".. _today: glossary_\n"
-        // ".. _trigger: glossary_\n"
-        // ".. _queued: glossary_\n"
-        // ".. _unknown: glossary_\n"
-        // ".. _variable inheritance: glossary_\n"
-        // ".. _variable substitution: glossary_\n"
-        // ".. _variable: glossary_\n"
-        // ".. _zombie: glossary_\n"
-        // ".. _zombie type: glossary_\n"
-        // ".. _glossary: https://confluence.ecmwf.int/display/ECFLOW/Glossary\n"
-        ;
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/GlossaryDoc.hpp 5.13.0-1/Pyext/src/ecflow/python/GlossaryDoc.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/GlossaryDoc.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/GlossaryDoc.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_GlossaryDoc_HPP
-#define ecflow_python_GlossaryDoc_HPP
-
-#include <boost/core/noncopyable.hpp>
-
-// ===========================================================================
-// IMPORTANT: These appear as python doc strings.
-//            Additionally they are auto documented using sphinx-poco
-//            Hence the doc strings use reStructuredText markup.
-// ===========================================================================
-class GlossaryDoc {
-public:
-    GlossaryDoc()                              = delete;
-    GlossaryDoc(const GlossaryDoc&)            = delete;
-    GlossaryDoc& operator=(const GlossaryDoc&) = delete;
-
-    static const char* list();
-};
-
-#endif /* ecflow_python_GlossaryDoc_HPP */
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/NodeAttrDoc.cpp 5.13.0-1/Pyext/src/ecflow/python/NodeAttrDoc.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/NodeAttrDoc.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/NodeAttrDoc.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,707 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/NodeAttrDoc.hpp"
-
-const char* NodeAttrDoc::variable_doc() {
-    return "Defines a `variable`_ on a `node`_ for use in `ecf script`_.\n\n"
-           "A Node can have a number of variables.\n"
-           "These variables can be added at any node level: Defs, `suite`_, `family`_ or `task`_.\n"
-           "The variables are names inside a pair of '%' characters in an `ecf script`_.\n"
-           "The content of a variable replaces the variable name in the `ecf script`_ at\n"
-           "job submission time. When a variable is needed at submission time, it is first\n"
-           "sought in the task itself. If it is not found, it is sought from the tasks parent\n"
-           "and so on, up through the node levels until found. See `variable inheritance`_\n"
-           "A undefined variable in a `ecf script`_, causes the `task`_ to be `aborted`_,\n"
-           "without the job being submitted.\n"
-           "\nConstructor::\n\n"
-           "   Variable(name,value)\n"
-           "      string name: the name of the variable\n"
-           "      string value: The value of the variable\n\n"
-           "   Edit(dict,kwarg) # alternative that allows multiple variables\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   ...\n"
-           "   var = Variable('ECF_JOB_CMD','/bin/sh %ECF_JOB% &')\n"
-           "   task.add_variable(var)\n"
-           "   task.add_variable('JOE','90')\n\n"
-           "The following use example of using Edit, which allow multiple variables to added at the same time :\n\n"
-           ".. code-block:: python\n\n"
-           "   t = Task('t1',\n"
-           "             Edit({ 'a':'y', 'b':'bb'}, c='v',d='b'),\n"
-           "             Edit({ 'e':1100, 'f':'bb'}),\n"
-           "             Edit(g='d'),\n"
-           "             Edit(h='1'))\n\n"
-           ".. code-block:: python\n\n"
-           "  defs = Defs(\n"
-           "            Suite('s1'),\n"
-           "            Edit(SLEEP='1')) # Add user variable to definition\n"
-           "  defs.s1 += [ Task('a') ]\n"
-           "  defs.s1.a += [ Edit({ 'x1':'y', 'aa1':'bb'}, a='v',b='b'),\n"
-           "                 Edit({ 'var':10, 'aa':'bb'}),\n"
-           "                 Edit(d='d') ]\n";
-}
-
-const char* NodeAttrDoc::zombie_doc() {
-    return "The `zombie`_ attribute defines how a `zombie`_ should be handled in an automated fashion\n\n"
-           "Very careful consideration should be taken before this attribute is added\n"
-           "as it may hide a genuine problem.\n"
-           "It can be added to any `node`_. But is best defined at the `suite`_ or `family`_ level.\n"
-           "If there is no zombie attribute the default behaviour is to block the init,complete,abort `child "
-           "command`_.\n"
-           "and *fob* the event,label,and meter `child command`_\n"
-           "This attribute allows the server to make a automated response.\n"
-           "Please see: :py:class:`ecflow.ZombieType`, :py:class:`ecflow.ChildCmdType`, "
-           ":py:class:`ecflow.ZombieUserActionType`\n"
-           "\nConstructor::\n\n"
-           "   ZombieAttr(ZombieType,ChildCmdTypes, ZombieUserActionType, lifetime)\n"
-           "      ZombieType            : Must be one of ZombieType.ecf, ZombieType.path, ZombieType.user\n"
-           "      ChildCmdType          : A list(ChildCmdType) of Child commands. Can be left empty in\n"
-           "                              which case the action affect all child commands\n"
-           "      ZombieUserActionType  : One of [ fob, fail, block, remove, adopt ]\n"
-           "      int lifetime<optional>: Defines the life time in seconds of the zombie in the server.\n"
-           "                              On expiration, zombie is removed automatically\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   # Add a zombie attribute so that child commands(i.e ecflow_client --init)\n"
-           "   # will fail the job if it is a zombie process.\n"
-           "   s1 = Suite('s1')\n"
-           "   child_list = [ ChildCmdType.init, ChildCmdType.complete, ChildCmdType.abort ]\n"
-           "   s1.add_zombie( ZombieAttr(ZombieType.ecf, child_list, ZombieUserActionType.fob))\n\n"
-           "   # create the zombie as part of the node constructor\n"
-           "   s1 = Suite('s1',\n"
-           "              ZombieAttr(ZombieType.ecf, child_list, ZombieUserActionType.fail))\n";
-}
-
-const char* NodeAttrDoc::zombie_type_doc() {
-    return "`zombie`_\\ s are running jobs that fail authentication when communicating with the `ecflow_server`_.\n\n"
-           "See class `zombie type`_ and :py:class:`ecflow.ZombieAttr` for further information.\n";
-}
-
-const char* NodeAttrDoc::zombie_user_action_type_doc() {
-    return "ZombieUserActionType is used define an automated response. See class :py:class:`ZombieAttr`\n\n"
-           "This can be either on the client side or on the server side\n"
-           "\nclient side:\n\n"
-           "- fob:    The `child command`_ always succeeds, i.e allows job to complete without blocking\n"
-           "- fail:   The `child command`_ is asked to fail.\n"
-           "- block:  The `child command`_ is asked to block.\n"
-           "  This is the default action for init,complete and abort child commands\n"
-           "\nserver side:\n\n"
-           "- adopt:  Allows the password supplied with the `child command`_\\ s, to be adopted by the server\n"
-           "- kill:   Kills the zombie process associated with the `child command`_ using ECF_KILL_CMD.\n"
-           "  path zombies will need to be killed manually. If kill is specified for path zombies\n"
-           "  they will be fobed, i.e allowed to complete without blocking the job.\n"
-           "- remove: `ecflow_server`_ removes the `zombie`_ from the zombie list.\n"
-           "  The child continues blocking. If the process is still running, the\n"
-           "  `zombie`_ may well re-appear\n\n"
-           "Note: Only adopt will allow the `child command`_ to continue and change the `node`_ tree\n";
-}
-
-const char* NodeAttrDoc::child_cmd_type_doc() {
-    return "ChildCmdType represents the different `child command`_\\ s.\n"
-           "This type is used as a parameter to the class :py:class:`ecflow.ZombieAttr`\n\n"
-           "Child commands are called within a `job file`_::\n\n"
-           "  ChildCmdType::init     corresponds to : ecflow_client --init=<process_id>\n"
-           "  ChildCmdType::event    corresponds to : ecflow_client --event=<event_name | number>\n"
-           "  ChildCmdType::meter    corresponds to : ecflow_client --meter=<meter_name>, <meter_value>\n"
-           "  ChildCmdType::label    corresponds to : ecflow_client --label=<label_name>. <label_value>\n"
-           "  ChildCmdType::wait     corresponds to : ecflow_client --wait=<expression>\n"
-           "  ChildCmdType::abort    corresponds to : ecflow_client --abort=<reason>\n"
-           "  ChildCmdType::complete corresponds to : ecflow_client --complete\n";
-}
-
-const char* NodeAttrDoc::label_doc() {
-    return "A `label`_ has a name and value and provides a way of displaying information in a GUI.\n\n"
-           "The value can be anything(ASCII) as it cannot be used in triggers.\n"
-           "The value of the label is set to be the default value given in the definition\n"
-           "when the `suite`_ is begun. This is useful in repeated suites: A task sets the label\n"
-           "to be something.\n\n"
-           "Labels can be set at any level: Suite,Family,Task.\n"
-           "There are two ways of updating the label\n\n"
-           "- A `child command`_ can be used to automatically update the label on a `task`_\n"
-           "- Using the alter command, the labels on `suite`_ `family`_ and `task`_ can be changed manually\n"
-           "\nConstructor::\n\n"
-           "   Label(name,value)\n"
-           "      string name:  The name of the label\n"
-           "      string value: The value of the label\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   t1 = Task('t1',\n"
-           "             Label('name','value'),  # create Labels in-place\n"
-           "             Label('a','b'))\n"
-           "   t1.add_label('l1','value')\n"
-           "   t1.add_label(Label('l2','value2'))\n"
-           "   for label in t1.labels:\n"
-           "      print(label)\n";
-}
-
-const char* NodeAttrDoc::limit_doc() {
-    return "`limit`_ provides a simple load management\n\n"
-           "i.e. by limiting the number of `task`_\\ s submitted by a server.\n"
-           "Limits are typically defined at the `suite`_ level, or defined in a\n"
-           "separate suite, so that they can be used by multiple suites.\n"
-           "Once a limit is defined in a `suite definition`_, you must also assign families/tasks to use\n"
-           "this limit. See  `inlimit`_ and :py:class:`ecflow.InLimit`\n"
-           "\nConstructor::\n\n"
-           "   Limit(name,value)\n"
-           "      string name: the name of the limit\n"
-           "      int   value: The value of the limit\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   limit = Limit('fast', 10)\n"
-           "    ...\n"
-           "   suite = Suite('s1',\n"
-           "                 Limit('slow',10))  # create Limit in Node constructor\n"
-           "   suite.add_limit(limit)           # add existing limit using function\n";
-}
-
-const char* NodeAttrDoc::inlimit_doc() {
-    return "`inlimit`_ is used in conjunction with `limit`_ to provide simple load management:\n\n"
-           ".. code-block:: shell\n\n"
-           "   suite x\n"
-           "      limit fast 1\n"
-           "      family f\n"
-           "         inlimit /x:fast\n"
-           "         task t1\n"
-           "         task t2\n\n"
-           "Here 'fast' is the name of :py:class:`ecflow.Limit` and the number defines the maximum number of tasks\n"
-           "that can run simultaneously using this limit. That is why you do not need a `trigger`_\n"
-           "between tasks 't1' and 't2'. There is no need to change the tasks. The jobs are\n"
-           "created in the order they are defined\n"
-           "\nConstructor::\n\n"
-           "   InLimit(name, optional<path = ''>, optional<token = 1>, optional<limit_this_node_only = false>)\n"
-           "      string name           : The name of the referenced Limit\n"
-           "      string path<optional> : The path to the Limit, if this is left out, then Limit of 'name' must be "
-           "specified\n"
-           "                              some where up the parent hierarchy\n"
-           "      int value<optional>   : The usage of the Limit. Each job submission will consume 'value' tokens\n"
-           "                              from the Limit. defaults to 1 if no value specified.\n"
-           "      bool limit_this_node_only<optional> : Only limits this node and *NOT* its children\n"
-           "                                            Can be used load balance families\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   inlimit = InLimit('fast','/x/f', 2)\n"
-           "    ...\n"
-           "   family = Family('f1',\n"
-           "                   InLimit('mars','/x/f', 2)) # create InLimit in Node constructor\n"
-           "   family.add_inlimit(inlimit)                # add existing inlimit using function\n";
-}
-
-const char* NodeAttrDoc::event_doc() {
-    return "`event`_\\ s are used as signal mechanism.\n\n"
-           "Typically they would be used to signal partial completion of a `task`_\n"
-           "and to be able to `trigger`_ another job, which is waiting for this partial completion.\n"
-           "Only tasks can have events that are automatically set via a `child command`_\\ s, see below.\n"
-           "Events are cleared automatically when a `node`_ is re-queued or begun.\n"
-           "Suites and Families can have events, but these events must be set via the Alter command\n"
-           "Multiple events can be added to a task.\n"
-           "An Event has a number and a optional name. Events are typically used\n"
-           "in `trigger`_ and `complete expression`_ , to control job creation.\n"
-           "Event are fired within a script/`job file`_, i.e.:\n\n"
-           ".. code-block:: shell\n\n"
-           "   ecflow_client --init=$$\n"
-           "   ecflow_client --event=foo\n"
-           "   ecflow_client --complete\n\n"
-           "Hence the defining of an event for a `task`_, should be followed with the addition of ecflow_client "
-           "--event\n"
-           "`child command`_ in the corresponding `ecf script`_ file.\n"
-           "\nConstructor::\n\n"
-           "   Event(number, optional<name = ''>)\n"
-           "      int number            : The number must be >= 0\n"
-           "      string name<optional> : If name is given, can only refer to Event by its name\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   event = Event(2,'event_name')\n"
-           "   task.add_event(event)\n"
-           "   task1.add_event('2')          # create an event '2' and add to the task\n"
-           "   task2.add_event('name')       # create an event 'name' and add to task\n\n"
-           "   # Events can be created in the Task constructor, like any other attribute\n"
-           "   t = Task('t3',\n"
-           "            Event(2,'event_name'))\n";
-}
-
-const char* NodeAttrDoc::meter_doc() {
-    return "`meter`_\\ s can be used to indicate proportional completion of `task`_\n\n"
-           "They are able to `trigger`_ another job, which is waiting on this proportion.\n"
-           "Can also be used to indicate progress of a job. Meters can be used in\n"
-           "`trigger`_ and `complete expression`_.\n"
-           "\nConstructor::\n\n"
-           "   Meter(name,min,max,<optional>color_change)\n"
-           "      string name                : The meter name\n"
-           "      int min                    : The minimum and initial meter value\n"
-           "      int max                    : The maximum meter value. Must be greater than min value.\n"
-           "      int color_change<optional> : default = max, Must be between min-max, used in the GUI\n"
-           "\nExceptions:\n\n"
-           "- raises IndexError when an invalid Meter is specified\n"
-           "\nUsage:\n\n"
-           "Using a meter requires:\n\n"
-           "- Defining a meter on a `task`_:\n\n"
-           ".. code-block:: python\n\n"
-           "     meter = Meter('progress',0,100,100)\n"
-           "     task.add_meter(meter)\n\n"
-           "- Updating the corresponding `ecf script`_ file with the meter `child command`_:\n\n"
-           ".. code-block:: shell\n\n"
-           "     ecflow_client --init=$$\n"
-           "     for i in 10 20 30 40 50 60 80 100; do\n"
-           "         ecflow_client --meter=progress $i\n"
-           "         sleep 2 # or do some work\n"
-           "     done\n"
-           "     ecflow_client --complete\n\n"
-           "- Optionally addition in a `trigger`_ or `complete expression`_ for job control:\n\n"
-           "  .. code-block:: shell\n\n"
-           "     trigger task:progress ge 60\n\n"
-           "  trigger and complete expression should *avoid* using equality i.e.:\n\n"
-           "  .. code-block:: shell\n\n"
-           "     trigger task:progress == 60\n\n"
-           "  Due to network issues the meter event's may **not** arrive in sequential order\n"
-           "  hence the `ecflow_server`_ will ignore meter value's, which are less than the current value\n"
-           "  as a result triggers's which use meter equality may never evaluate\n";
-}
-
-const char* NodeAttrDoc::queue_doc() {
-    return "Queue allows specification of queue on Task, Family and Suite nodes\n\n";
-}
-
-const char* NodeAttrDoc::date_doc() {
-    return "Used to define a `date`_ dependency.\n\n"
-           "There can be multiple Date dependencies for a `node`_.\n"
-           "Any of the 3 attributes, i.e. day, month, year can be wild carded using a zero\n"
-           "If a hybrid `clock`_ is defined on a suite, any node held by a date dependency\n"
-           "will be set to `complete`_ at the beginning of the `suite`_, without the\n"
-           "task ever being dispatched otherwise, the suite would never complete.\n"
-           "\nConstructor::\n\n"
-           "  Date(string)\n"
-           "     string : * means wild card\n"
-           "  Date(day,month,year)\n"
-           "     int day   : represents the day, zero means wild card. day >= 0 & day < 31\n"
-           "     int month : represents the month, zero means wild card. month >= 0 & month < 12\n"
-           "     int year  : represents the year, zero means wild card. year >= 0\n"
-           "\nExceptions:\n\n"
-           "- raises IndexError when an invalid date is specified\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "  date = Date(11,12,2010)  # represent 11th of December 2010\n"
-           "  date = Date(1,0,0);      # means the first day of every month of every year\n"
-           "  t = Task('t1',\n"
-           "            Date('1.*.*'));  # Create Date in place.\n";
-}
-
-const char* NodeAttrDoc::day_doc() {
-    return "Defines a `day`_ dependency.\n\n"
-           "There can be multiple day dependencies. If a hybrid `clock`_ is defined\n"
-           "on a suite, any node held by a day dependency will be set to `complete`_ at the\n"
-           "beginning of the `suite`_, without the task ever being dispatched otherwise\n"
-           "the suite would never complete.\n"
-           "\nConstructor::\n\n"
-           "   Day(string)\n"
-           "      string: 'sunday','monday',etc\n"
-           "   Day(Days)\n"
-           "      Days day: Is an enumerator with represent the days of the week\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   day1 = Day(Days.sunday)\n"
-           "   t = Task('t1',\n"
-           "           Day('tuesday'))\n";
-}
-
-const char* NodeAttrDoc::days_enum_doc() {
-    return "This enum is used as argument to a :py:class:`ecflow.Day` class.\n\n"
-           "It represents the days of the week\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   day1 = Day(Days.sunday)\n"
-           "   day2 = Day(Days.monday)\n"
-           "   t = Task('t1',\n"
-           "           day1,\n"
-           "           day2,\n"
-           "           Day(Days.tuesday))\n";
-}
-
-const char* NodeAttrDoc::time_doc() {
-    return "Is used to define a `time`_ dependency\n\n"
-           "This can then control job submission.\n"
-           "There can be multiple time dependencies for a node, however overlapping times may\n"
-           "cause unexpected results. The time dependency can be made relative to the beginning\n"
-           "of the suite or in repeated families relative to the beginning of the repeated family.\n"
-           "\nConstructor::\n\n"
-           "   Time(string)\n"
-           "     string: i.e '00:30' || '00:30 20:00 00:30'"
-           "   Time(hour,minute,relative<optional> = false)\n"
-           "      int hour:               hour in 24 clock\n"
-           "      int minute:             minute <= 59\n"
-           "      bool relative<optional>: default = False, Relative to suite start or repeated node.\n\n"
-           "   Time(single,relative<optional> = false)\n"
-           "      TimeSlot single:         A single time\n"
-           "      bool relative:           Relative to suite start or repeated node. Default is false\n\n"
-           "   Time(start,finish,increment,relative<optional> = false)\n"
-           "      TimeSlot start:          The start time\n"
-           "      TimeSlot finish:         The finish/end time\n"
-           "      TimeSlot increment:      The increment\n"
-           "      bool relative<optional>: default = False, relative to suite start or repeated node\n\n"
-           "   Time(time_series)\n"
-           "      TimeSeries time_series:Similar to constructor above\n"
-           "\nExceptions:\n\n"
-           "- raises IndexError when an invalid Time is specified\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   time1 = Time( 10,10 )                                                   #  time 10:10 \n"
-           "   time2 = Time( TimeSlot(10,10), true)                                    #  time +10:10 \n"
-           "   time2 = Time( TimeSlot(10,10), TimeSlot(20,10),TimeSlot(0,10), false )  #  time 10:10 20:10 00:10 \n\n"
-           "   t = Task('t1',\n"
-           "            time1,time2,time3,\n"
-           "            Time('10:30 20:10 00:10')) # Create time in place\n";
-}
-
-const char* NodeAttrDoc::today_doc() {
-    return "`today`_ is a time dependency that does not wrap to tomorrow.\n\n"
-           "If the `suite`_\\ s begin time is past the time given for the Today,\n"
-           "then the node is free to run.\n"
-           "\nConstructor::\n\n"
-           "   Today(hour,minute,relative<optional> = false)\n"
-           "      int hour               : hour in 24 clock\n"
-           "      int minute             : minute <= 59\n"
-           "      bool relative<optional>: Default = false,Relative to suite start or repeated node.\n\n"
-           "   Today(single,relative<optional> = false)\n"
-           "      TimeSlot single        : A single time\n"
-           "      bool relative          : Relative to suite start or repeated node. Default is false\n\n"
-           "   Today(start,finish,increment,relative<optional> = false)\n"
-           "      TimeSlot start         : The start time\n"
-           "      TimeSlot finish        : The finish/end time. This must be greater than the start time.\n"
-           "      TimeSlot increment     : The increment\n"
-           "      bool relative<optional>: Default = false, Relative to suite start or repeated node.\n\n"
-           "   Today(time_series)\n"
-           "      TimeSeries time_series: Similar to constructor above\n"
-           "\nExceptions:\n\n"
-           "- raises IndexError when an invalid Today is specified\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   today1 = Today( 10,10 )                                                   #  today 10:10 \n"
-           "   today2 = Today( TimeSlot(10,10) )                                         #  today 10:10 \n"
-           "   today3 = Today( TimeSlot(10,10), true)                                    #  today +10:10 \n"
-           "   today4 = Today( TimeSlot(10,10), TimeSlot(20,10),TimeSlot(0,10), false )  #  time 10:10 20:10 00:10 \n"
-           "   t = Task('t1',\n"
-           "            today1,today2,today3,today4,\n"
-           "            Today('10:30 20:10 00:10')) # Create today in place\n";
-}
-
-const char* NodeAttrDoc::late_doc() {
-    return "Sets the `late`_ flag.\n\n"
-           "When a Node is classified as being late, the only action `ecflow_server`_ can take\n"
-           "is to set a flag. The GUI will display this alongside the `node`_ name as a icon.\n"
-           "Only one Late attribute can be specified on a Node.\n"
-           "\nConstructor::\n\n"
-           "   Late()\n"
-           "   Late(kwargs)\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   # This is interpreted as: The node can stay `submitted`_ for a maximum of 15 minutes\n"
-           "   # and it must become `active`_ by 20:00 and the run time must not exceed 2 hours\n"
-           "   late = Late()\n"
-           "   late.submitted( 0,15 )\n"
-           "   late.active(   20,0 )\n"
-           "   late.complete(  2,0, true )\n\n"
-           "   late = Late(submitted='00:15',active='20:00',complete='+02:00')\n"
-           "   t = Task('t1',\n"
-           "            Late(submitted='00:15',active='20:00'))\n";
-}
-
-const char* NodeAttrDoc::autocancel_doc() {
-    return "Provides a way to automatically delete/remove a node which has completed\n\n"
-           "See `autocancel`_\n"
-           "\nConstructor::\n\n"
-           "   Autocancel(TimeSlot,relative)\n"
-           "      TimeSlot single: A time\n"
-           "      bool relative:   Relative to completion. False means delete the node at the real time specified.\n\n"
-           "   Autocancel(hour,minute,relative)\n"
-           "      int hour:        hour in 24 hrs\n"
-           "      int minute:      minute <= 59\n"
-           "      bool relative:   Relative to completion. False means delete the node at the real time specified.\n\n"
-           "   Autocancel(days)\n"
-           "      int days:        Delete the node 'days' after completion\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   attr = Autocancel( 1,30, true )              # delete node 1 hour and 30 minutes after completion\n"
-           "   attr = Autocancel( TimeSlot(0,10), true )    # delete node 10 minutes after completion\n"
-           "   attr = Autocancel( TimeSlot(10,10), false )  # delete node at 10:10 after completion\n"
-           "   attr = Autocancel( 3  )                      # delete node 3 days after completion\n\n"
-           "   t1 = Task('t1',\n"
-           "              Autocancel(2,0,true))             # delete task 2 hours after completion\n";
-}
-
-const char* NodeAttrDoc::autoarchive_doc() {
-    return "Provides a way to automatically archive a suite/family which has completed or is *idle*\n\n"
-           "This is required when dealing with super large suite/families, they can be archived off, and then restored "
-           "later.\n"
-           "This reduces the time to checkpoint and network band width.\n"
-           "The archived node is written to disk, as ECF_HOME/<host>.<port>.ECF_NAME.check,\n"
-           "where '/' is replaced with ':' in ECF_NAME.\n"
-           "The node can be recovered using 'autorestore', begin,re-queue and manually via ecflow_client --restore.\n"
-           "The archiving is never immediate. The nodes are checked one a minute, and expired autoarchive nodes are "
-           "archived.\n"
-           "If the node is suspended or any of its parent are suspended,or previously restored then archive does not "
-           "happen.\n"
-           "\nConstructor::\n\n"
-           "   Autoarchive(TimeSlot,relative,idle)\n"
-           "      TimeSlot     : A time\n"
-           "      bool relative: Relative to node state, False means archive the node at the real time specified.\n\n"
-           "      bool idle:     True includes queued,aborted and complete, False means archive after completion "
-           "only\n\n"
-           "   Autoarchive(hour,minute,relative)\n"
-           "      int hour:      hour in 24 hrs\n"
-           "      int minute:    minute <= 59\n"
-           "      bool relative: Relative to node state. False means archive the node at the real time specified.\n\n"
-           "      bool idle:     True includes queued,aborted and complete, False means archive after completion "
-           "only\n\n"
-           "   AutoArchive(days,idle)\n"
-           "      int days:      archive the node after 'days' elapsed \n"
-           "      bool idle:     True archive if node queued,aborted and complete, False means archive after "
-           "completion only\n\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   attr = Autoarchive( 1,30, true )              # archive node 1 hour and 30 minutes after completion\n"
-           "   attr = Autoarchive( TimeSlot(0,10), true )    # archive node 10 minutes after completion\n"
-           "   attr = Autoarchive( TimeSlot(10,10), false )  # archive node at 10:10 after completion\n"
-           "   attr = Autoarchive( 3  )                      # archive node 3 days after completion\n"
-           "   attr = Autoarchive( 3,true  )                 # archive node 3 days after complete,queued or aborted, "
-           "i.e node is idle\n";
-}
-
-const char* NodeAttrDoc::autorestore_doc() {
-    return "Provides a way to automatically restore a previously archived node\n\n"
-           "This is required when dealing with super large suite/families, they can be archived off, and then restored "
-           "later.\n"
-           "This reduces the time to checkpoint the definition and network band width.\n"
-           "The archived node is written to disk, as ECF_HOME/<host>.<port>.ECF_NAME.check,\n"
-           "where '/' is replaced with ':' in ECF_NAME.\n"
-           "The node can be recovered using 'autorestore', begin,re-queue and manually via ecflow_client --restore.\n"
-           "The archiving is never immediate. The nodes are checked one a minute, and expired autoarchive nodes are "
-           "archived.\n"
-           "If the node is suspended or any of its parent are suspended then then the archive does not happen.\n"
-           "\nConstructor::\n\n"
-           "   Autorestore( list of paths )\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   attr = Autorestore( ['/s1/f1'] )           # restore archived node at /s1/f1\n"
-           "   attr = Autorestore( ['/s1/f1','/s1/f2'] )  # restore archived node at /s1/f1 and /s1/f2\n";
-}
-
-const char* NodeAttrDoc::repeat_doc() {
-    return "Represents one of RepeatString,RepeatEnumerated,RepeatInteger,RepeatDate,RepeatDay\n\n";
-}
-
-const char* NodeAttrDoc::repeat_date_doc() {
-    return "Allows a `node`_ to be repeated using a yyyymmdd format\n\n"
-           "A node can only have one `repeat`_.\n"
-           "The repeat name can be referenced in `trigger`_ expressions.\n"
-           "The trigger expression referencing a RepeatDate will use date arithmetic\n"
-           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer\n\n"
-           "   trigger /suite/family:YMD + 1 > 20190101\n"
-           "\nConstructor::\n\n"
-           "   RepeatDate(variable,start,end,delta)\n"
-           "      string variable:     The name of the repeat. The current date can referenced in\n"
-           "                           in trigger expressions using the variable name\n"
-           "      int start:           Start date, must have format: yyyymmdd\n"
-           "      int end:             End date, must have format: yyyymmdd\n"
-           "      int delta<optional>: default = 1, Always in days. The increment used to update the date\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if start/end are not valid dates\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   rep = RepeatDate('YMD', 20050130, 20050203 )\n"
-           "   rep = RepeatDate('YMD', 20050130, 20050203, 2)\n"
-           "   t = Task('t1',\n"
-           "            RepeatDate('YMD', 20050130, 20050203 ))\n";
-}
-
-const char* NodeAttrDoc::repeat_datetime_doc() {
-    return "Allows a `node`_ to be repeated based on date+time instants (using yyyymmddTHHMMSS format).\n\n"
-           "A node can only have one `repeat`_.\n"
-           "The repeat name can be referenced in `trigger`_ expressions.\n"
-           "The trigger expression referencing a RepeatDate will use date arithmetic\n"
-           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer\n\n"
-           "   trigger /suite/family:YMD + 1 > 20190101\n"
-           "\nConstructor::\n\n"
-           "   RepeatDateTime(variable, start, end[, step])\n"
-           "      string variable:     The name of the repeat. The Repeat can referenced in\n"
-           "                           in trigger expressions using the variable name\n"
-           "      int start:           Start date+time instant, formatted as yyyymmddTHHMMSS\n"
-           "      int end:             End date+time instant, formatted as yyyymmddTHHMMSS\n"
-           "      int step:            The increment duration used to update the instant when iterating\n"
-           "                           Formatted as HH:MM.SS, if not provided default delta is '24:00:00'.\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if start/end are not valid date+time instants\n"
-           "- Throws a RuntimeError if delta is not a valid duration\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   rep = RepeatDateTime('DATETIME', '20050130T000000', '20050203T000000')\n"
-           "   rep = RepeatDateTime('DATETIME', '20050130T000000', '20050203T000000', '48:00:00')\n"
-           "   t = Task('t1',\n"
-           "            RepeatDateTime('DATETIME', '20050130T000000', '20050203T120000', '1:00:00'))\n";
-}
-
-const char* NodeAttrDoc::repeat_date_list_doc() {
-    return "Allows a `node`_ to be repeated using arbitrary list of yyyymmdd integers\n\n"
-           "A node can only have one `repeat`_.\n"
-           "The repeat name can be referenced in `trigger`_ expressions.\n"
-           "The trigger expression referencing a RepeatDateList will use date arithmetic\n"
-           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer:\n\n"
-           ".. code-block:: shell\n\n"
-           "   trigger /suite/family:YMD + 1 > 20190101\n"
-           "\nConstructor::\n\n"
-           "   RepeatDateList(variable,list)\n"
-           "      string variable:     The name of the repeat. The current date can referenced in\n"
-           "                           in trigger expressions using the variable name\n"
-           "      list list_of_int:    Arbitrary list of integers following a yyyymmdd format\n"
-           "\nException:\n\n"
-           "- Throws a RuntimeError if list of integers are not valid dates\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   rep = RepeatDateList('YMD', [20050130, 20050203] )\n"
-           "   t = Task('t1',\n"
-           "            RepeatDateList('YMD',[20050130, 20050203] ))\n";
-}
-
-const char* NodeAttrDoc::repeat_integer_doc() {
-    return "Allows a `node`_ to be repeated using a integer range.\n\n"
-           "A node can only have one `repeat`_.\n"
-           "The repeat can be referenced in `trigger`_ expressions.\n"
-           "\nConstructor::\n\n"
-           "   RepeatInteger(variable,start,end,step)\n"
-           "      string variable:     The name of the repeat. The current integer value can be\n"
-           "                           referenced in trigger expressions using the variable name\n"
-           "      int start:           Start integer value\n"
-           "      int end:             End end integer value\n"
-           "      int step<optional>:  Default = 1, The step amount\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   t = Task('t1',\n"
-           "            RepeatInteger('HOUR', 6, 24, 6 ))\n";
-}
-
-const char* NodeAttrDoc::repeat_enumerated_doc() {
-    return "Allows a node to be repeated using a enumerated list.\n\n"
-           "A `node`_ can only have one `repeat`_.\n"
-           "The repeat can be referenced in `trigger`_ expressions.\n"
-           "\nConstructor::\n\n"
-           "   RepeatEnumerated(variable,list)\n"
-           "      string variable:     The name of the repeat. The current enumeration index can be\n"
-           "                           referenced in trigger expressions using the variable name\n"
-           "      vector list:         The list of enumerations\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   t = Task('t1',\n"
-           "            RepeatEnumerated('COLOR', [ 'red', 'green', 'blue' ] ))\n";
-}
-
-const char* NodeAttrDoc::repeat_string_doc() {
-    return "Allows a `node`_ to be repeated using a string list.\n\n"
-           "A `node`_ can only have one `repeat`_.\n"
-           "The repeat can be referenced in `trigger`_ expressions.\n"
-           "\nConstructor::\n\n"
-           "   RepeatString(variable,list)\n"
-           "      string variable:     The name of the repeat. The current index of the string list can be\n"
-           "                           referenced in trigger expressions using the variable name\n"
-           "      vector list:         The list of enumerations\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   t = Task('t1',\n"
-           "            RepeatString('COLOR', [ 'red', 'green', 'blue' ] ))\n";
-}
-
-const char* NodeAttrDoc::repeat_day_doc() {
-    return "A repeat that is infinite.\n\n"
-           "A node can only have one `repeat`_.\n"
-           "\nConstructor::\n\n"
-           "   RepeatDay(step)\n"
-           "      int step:     The step.\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   t = Task('t1',\n"
-           "             RepeatDay( 1 ))\n";
-}
-
-const char* NodeAttrDoc::cron_doc() {
-    return "A `cron`_ defines a repeating time dependency for a node.\n\n"
-           "\nConstructor::\n\n"
-           "   Cron()\n"
-           "   Cron(string time_series,\n"
-           "        days_of_week=list of ints,   # 0-6, Sunday-Saturday\n"
-           "        days_of_month=list of ints,  # 1-31\n"
-           "        months=list of ints)         # 1-12\n"
-           "   Cron(TimeSeries time_series,\n"
-           "        days_of_week=list of ints,\n"
-           "        days_of_month=list of ints,\n"
-           "        months=list of ints)\n"
-           "\nExceptions:\n\n"
-           "- raises IndexError || RuntimeError when an invalid cron is specified\n"
-           "\nUsage (see the `cron definition<text_based_def_cron>`_ for more examples):\n\n"
-           ".. code-block:: python\n\n"
-           "    # Run every day at 2pm\n"
-           "    cron = Cron('14:00')\n\n"
-           "    # Run every 30 minutes between 0:00 and 20:00, the first 6 days of the month from January until July\n"
-           "    cron = Cron('+00:00 20:00 00:30', days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6])\n\n"
-           "    # Run relative to suite start time or task requeue time\n"
-           "    cron = Cron('+01:30',days_of_week=[0,1,2,3,4,5,6])\n\n"
-
-           "    # Run relative to suite start time or task requeue time\n"
-           "    cron = Cron('+00:15 23:00 00:30', days_of_week=[0,1,2],days_of_month=[4,5,6], months=[1,2,3])\n\n"
-
-           "    # Define Cron based on start/end/increment\n"
-           "    start = TimeSlot(0 , 0)\n"
-           "    finish = TimeSlot(23, 0)\n"
-           "    incr = TimeSlot(0, 30)\n"
-           "    ts = TimeSeries(start, finish, incr, True)  # True means relative to suite start\n"
-           "    cron = Cron(ts, days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2])\n\n"
-           "    # Use Cron methods to set weekdays, days of month and month parameters\n"
-           "    cron = Cron()\n"
-           "    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])\n"
-           "    cron.set_days_of_month([1, 2, 3, 4, 5, 6 ])\n"
-           "    cron.set_months([1, 2, 3, 4, 5, 6])\n"
-           "    cron.set_time_series(ts)\n\n"
-           "    # Use Cron methods to set time series\n"
-           "    cron = Cron()\n"
-           "    cron.set_time_series(1, 30, True)  # same as cron +01:30\n\n"
-           "    # Use Cron methods to set time series over all days of the week\n"
-           "    cron = Cron()\n"
-           "    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])\n"
-           "    cron.set_time_series('00:30 01:30 00:01')\n\n"
-           "    # Use Cron methods to set relative time series over all days of the week\n"
-           "    cron = Cron()\n"
-           "    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])\n"
-           "    cron.set_time_series('+00:30')\n";
-}
-
-const char* NodeAttrDoc::clock_doc() {
-    return "Specifies the `clock`_ type used by the `suite`_.\n\n"
-           "Only suites can have a `clock`_.\n"
-           "A gain can be specified to offset from the given date.\n"
-           "\nConstructor::\n\n"
-           "   Clock(day,month,year,hybrid)\n"
-           "      int day              : Specifies the day of the month  1-31\n"
-           "      int month            : Specifies the month 1-12\n"
-           "      int year             : Specifies the year > 1400\n"
-           "      bool hybrid<optional>: Default = False, true means hybrid, false means real\n"
-           "                             by default the clock is not real\n\n"
-           "      Time will be set to midnight, use set_gain() to alter\n"
-           "\n"
-           "   Clock(hybrid)\n"
-           "      bool hybrid: true means hybrid, false means real\n"
-           "                   by default the clock is real\n"
-           "      Time will be set real time of the computer\n"
-           "\n"
-           "\nExceptions:\n\n"
-           "- raises IndexError when an invalid Clock is specified\n"
-           "\nUsage:\n\n"
-           ".. code-block:: python\n\n"
-           "   suite = Suite('s1')\n"
-           "   clock = Clock(1,1,2012,False)\n"
-           "   clock.set_gain(1,10,True)\n"
-           "   suite.add_clock(clock)\n";
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/NodeAttrDoc.hpp 5.13.0-1/Pyext/src/ecflow/python/NodeAttrDoc.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/NodeAttrDoc.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/NodeAttrDoc.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_NodeAttrDoc_HPP
-#define ecflow_python_NodeAttrDoc_HPP
-
-#include <boost/core/noncopyable.hpp>
-
-// ===========================================================================
-// IMPORTANT: These appear as python doc strings.
-//            Additionally they are auto documented using sphinx-poco
-//            Hence the doc strings use reStructuredText markup
-// ===========================================================================
-class NodeAttrDoc {
-public:
-    NodeAttrDoc()                              = delete;
-    NodeAttrDoc(const NodeAttrDoc&)            = delete;
-    NodeAttrDoc& operator=(const NodeAttrDoc&) = delete;
-
-    static const char* variable_doc();
-    static const char* zombie_doc();
-    static const char* zombie_type_doc();
-    static const char* zombie_user_action_type_doc();
-    static const char* child_cmd_type_doc();
-    static const char* label_doc();
-    static const char* limit_doc();
-    static const char* inlimit_doc();
-    static const char* event_doc();
-    static const char* meter_doc();
-    static const char* queue_doc();
-    static const char* date_doc();
-    static const char* day_doc();
-    static const char* days_enum_doc();
-    static const char* time_doc();
-    static const char* today_doc();
-    static const char* late_doc();
-    static const char* autocancel_doc();
-    static const char* autoarchive_doc();
-    static const char* autorestore_doc();
-    static const char* repeat_doc();
-    static const char* repeat_date_doc();
-    static const char* repeat_datetime_doc();
-    static const char* repeat_date_list_doc();
-    static const char* repeat_integer_doc();
-    static const char* repeat_enumerated_doc();
-    static const char* repeat_string_doc();
-    static const char* repeat_day_doc();
-    static const char* cron_doc();
-    static const char* clock_doc();
-};
-
-#endif /* ecflow_python_NodeAttrDoc_HPP */
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/NodeUtil.cpp 5.13.0-1/Pyext/src/ecflow/python/NodeUtil.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/NodeUtil.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/NodeUtil.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,175 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/NodeUtil.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/attribute/AutoArchiveAttr.hpp"
-#include "ecflow/attribute/AutoCancelAttr.hpp"
-#include "ecflow/attribute/ClockAttr.hpp"
-#include "ecflow/attribute/CronAttr.hpp"
-#include "ecflow/attribute/DateAttr.hpp"
-#include "ecflow/attribute/DayAttr.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/attribute/RepeatAttr.hpp"
-#include "ecflow/attribute/TimeAttr.hpp"
-#include "ecflow/attribute/TodayAttr.hpp"
-#include "ecflow/attribute/Variable.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/attribute/ZombieAttr.hpp"
-#include "ecflow/node/Attr.hpp"
-#include "ecflow/node/AutoRestoreAttr.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Flag.hpp"
-#include "ecflow/node/InLimit.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-#include "ecflow/python/BoostPythonUtil.hpp"
-#include "ecflow/python/Edit.hpp"
-#include "ecflow/python/Trigger.hpp"
-
-using namespace boost::python;
-using namespace std;
-using namespace ecf;
-namespace bp = boost::python;
-
-object NodeUtil::node_raw_constructor(bp::tuple args, bp::dict kw) {
-    // cout << "node_raw_constructor len(args):" << len(args) << endl;
-    // args[0] is Task(i.e self) args[1] is string name
-    bp::list the_list;
-    std::string name;
-    for (int i = 1; i < len(args); ++i) {
-        if (extract<string>(args[i]).check())
-            name = extract<string>(args[i]);
-        else
-            the_list.append(args[i]);
-    }
-    if (name.empty())
-        throw std::runtime_error("node_raw_constructor: first argument must be a string");
-    return args[0].attr("__init__")(name, the_list, kw); // calls -> init(const std::string& name, list attr, dict kw)
-}
-
-node_ptr NodeUtil::add_variable_dict(node_ptr self, const bp::dict& dict) {
-    std::vector<Variable> vec;
-    BoostPythonUtil::dict_to_str_vec(dict, vec);
-    for (const auto& i : vec)
-        self->addVariable(i);
-    return self;
-}
-
-object NodeUtil::node_iadd(node_ptr self, const bp::list& list) {
-    // std::cout << "node_iadd list " << self->name() << "\n";
-    int the_list_size = len(list);
-    for (int i = 0; i < the_list_size; ++i)
-        (void)do_add(self, list[i]);
-    return object(self); // return node_ptr as python object, relies class_<Node>... for type registration
-}
-
-object NodeUtil::do_add(node_ptr self, const bp::object& arg) {
-    // std::cout << "do_add " << self->name() << "\n";
-    if (arg.ptr() == object().ptr())
-        return object(self); // *IGNORE* None
-    if (extract<Edit>(arg).check()) {
-        Edit edit                        = extract<Edit>(arg);
-        const std::vector<Variable>& vec = edit.variables();
-        for (const auto& i : vec)
-            self->addVariable(i);
-    }
-    else if (extract<node_ptr>(arg).check()) {
-        // std::cout << "  do_add node_ptr\n";
-        NodeContainer* nc = self->isNodeContainer();
-        if (!nc)
-            throw std::runtime_error("ExportNode::add() : Can only add a child to Suite or Family");
-        node_ptr child = extract<node_ptr>(arg);
-        nc->addChild(child);
-    }
-    else if (extract<Event>(arg).check())
-        self->addEvent(extract<Event>(arg));
-    else if (extract<Meter>(arg).check())
-        self->addMeter(extract<Meter>(arg));
-    else if (extract<Label>(arg).check())
-        self->addLabel(extract<Label>(arg));
-    else if (extract<Trigger>(arg).check()) {
-        Trigger t = extract<Trigger>(arg);
-        self->py_add_trigger_expr(t.expr());
-    }
-    else if (extract<Complete>(arg).check()) {
-        Complete t = extract<Complete>(arg);
-        self->py_add_complete_expr(t.expr());
-    }
-    else if (extract<Limit>(arg).check())
-        self->addLimit(extract<Limit>(arg));
-    else if (extract<InLimit>(arg).check())
-        self->addInLimit(extract<InLimit>(arg));
-    else if (extract<DayAttr>(arg).check())
-        self->addDay(extract<DayAttr>(arg));
-    else if (extract<DateAttr>(arg).check())
-        self->addDate(extract<DateAttr>(arg));
-    else if (extract<TodayAttr>(arg).check())
-        self->addToday(extract<TodayAttr>(arg));
-    else if (extract<TimeAttr>(arg).check())
-        self->addTime(extract<TimeAttr>(arg));
-    else if (extract<CronAttr>(arg).check())
-        self->addCron(extract<CronAttr>(arg));
-    else if (extract<LateAttr>(arg).check())
-        self->addLate(extract<LateAttr>(arg));
-    else if (extract<ZombieAttr>(arg).check())
-        self->addZombie(extract<ZombieAttr>(arg));
-    else if (extract<RepeatDate>(arg).check())
-        self->addRepeat(Repeat(extract<RepeatDate>(arg)));
-    else if (extract<RepeatDateTime>(arg).check())
-        self->addRepeat(Repeat(extract<RepeatDateTime>(arg)));
-    else if (extract<RepeatDateList>(arg).check())
-        self->addRepeat(Repeat(extract<RepeatDateList>(arg)));
-    else if (extract<RepeatInteger>(arg).check())
-        self->addRepeat(Repeat(extract<RepeatInteger>(arg)));
-    else if (extract<RepeatEnumerated>(arg).check())
-        self->addRepeat(Repeat(extract<RepeatEnumerated>(arg)));
-    else if (extract<RepeatString>(arg).check())
-        self->addRepeat(Repeat(extract<RepeatString>(arg)));
-    else if (extract<RepeatDay>(arg).check())
-        self->addRepeat(Repeat(extract<RepeatDay>(arg)));
-    else if (extract<AutoCancelAttr>(arg).check())
-        self->addAutoCancel(extract<AutoCancelAttr>(arg));
-    else if (extract<Defstatus>(arg).check()) {
-        Defstatus t = extract<Defstatus>(arg);
-        self->addDefStatus(t.state());
-    }
-    else if (extract<AutoArchiveAttr>(arg).check())
-        self->add_autoarchive(extract<AutoArchiveAttr>(arg));
-    else if (extract<AutoRestoreAttr>(arg).check())
-        self->add_autorestore(extract<AutoRestoreAttr>(arg));
-    else if (extract<VerifyAttr>(arg).check())
-        self->addVerify(extract<VerifyAttr>(arg));
-    else if (extract<bp::list>(arg).check()) {
-        // std::cout << "  do_add list\n";
-        bp::list the_list = extract<bp::list>(arg);
-        int the_list_size = len(the_list);
-        for (int i = 0; i < the_list_size; ++i)
-            (void)do_add(self, the_list[i]); // recursive
-    }
-    else if (extract<ClockAttr>(arg).check()) {
-        if (!self->isSuite())
-            throw std::runtime_error("ExportNode::add() : Can only add a clock to a suite");
-        self->isSuite()->addClock(extract<ClockAttr>(arg));
-    }
-    else if (extract<Variable>(arg).check())
-        self->addVariable(extract<Variable>(arg));
-    else if (extract<dict>(arg).check()) {
-        dict d = extract<dict>(arg);
-        add_variable_dict(self, d);
-    }
-    else
-        throw std::runtime_error("ExportNode::add : Unknown type ");
-    return object(self);
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/NodeUtil.hpp 5.13.0-1/Pyext/src/ecflow/python/NodeUtil.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/NodeUtil.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/NodeUtil.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_NodeUtil_HPP
-#define ecflow_python_NodeUtil_HPP
-
-#include <boost/python.hpp>
-
-#include "ecflow/node/NodeFwd.hpp"
-
-class NodeUtil {
-public:
-    NodeUtil()                           = delete;
-    NodeUtil(const NodeUtil&)            = delete;
-    NodeUtil& operator=(const NodeUtil&) = delete;
-
-    /// any nodes and attributes to be added
-    static boost::python::object do_add(node_ptr self, const boost::python::object& arg);
-
-    /// add ecflow variables from a python dictionary of strings
-    static node_ptr add_variable_dict(node_ptr self, const boost::python::dict& dict);
-
-    /// Add all the object in python list, to the node
-    static boost::python::object node_iadd(node_ptr self, const boost::python::list& list);
-
-    /// raw constructor,assumes first argument is a string.
-    /// Assumes Task,Family,Suite has defined a constructor  init(const std::string& name, list attrs, dict kw)
-    static boost::python::object node_raw_constructor(boost::python::tuple args, boost::python::dict kw);
-};
-
-#endif /* ecflow_python_NodeUtil_HPP */
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/Trigger.cpp 5.13.0-1/Pyext/src/ecflow/python/Trigger.cpp
--- 5.12.4-1/Pyext/src/ecflow/python/Trigger.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/Trigger.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/python/Trigger.hpp"
-
-#include <stdexcept>
-
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Node.hpp"
-
-using namespace boost::python;
-using namespace std;
-using namespace ecf;
-namespace bp = boost::python;
-
-static void construct_expr(std::vector<PartExpression>& vec, const bp::list& list) {
-    int the_list_size = len(list);
-    for (int i = 0; i < the_list_size; ++i) {
-        std::string part_expr;
-        if (extract<std::string>(list[i]).check()) {
-            part_expr = extract<std::string>(list[i]);
-            if (Str::valid_name(part_expr)) {
-                part_expr += " == complete";
-            }
-        }
-        else if (extract<node_ptr>(list[i]).check()) {
-            node_ptr node = extract<node_ptr>(list[i]);
-            if (node->parent())
-                part_expr = node->absNodePath();
-            else
-                part_expr = node->name();
-            part_expr += " == complete";
-        }
-        else
-            throw std::runtime_error("Trigger: Expects string, or list(strings or nodes)");
-
-        if (vec.empty())
-            vec.emplace_back(part_expr);
-        else
-            vec.emplace_back(part_expr, true /*AND*/);
-    }
-}
-
-Trigger::Trigger(const bp::list& list) {
-    construct_expr(vec_, list);
-}
-Complete::Complete(const bp::list& list) {
-    construct_expr(vec_, list);
-}
diff -pruN 5.12.4-1/Pyext/src/ecflow/python/Trigger.hpp 5.13.0-1/Pyext/src/ecflow/python/Trigger.hpp
--- 5.12.4-1/Pyext/src/ecflow/python/Trigger.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/src/ecflow/python/Trigger.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_python_Trigger_HPP
-#define ecflow_python_Trigger_HPP
-
-#include <boost/python.hpp>
-
-#include "ecflow/node/Expression.hpp"
-
-////////////////////////////////////////////////////////////////////////////////////////
-// Trigger & Complete thin wrapper over Expression, allows us to call:
-//  Task("a").add(Trigger("a == 1"),Complete("b == 1"))
-///////////////////////////////////////////////////////////////////////////////////
-
-class Trigger {
-public:
-    explicit Trigger(const std::string& expression) { add(PartExpression(expression)); }
-    Trigger(const std::string& expression, bool and_type) { add(PartExpression(expression, and_type)); }
-    explicit Trigger(const PartExpression& pe) { add(pe); }
-    Trigger(const Trigger& rhs) = default;
-    explicit Trigger(const boost::python::list& list);
-
-    bool operator==(const Trigger& rhs) const { return vec_ == rhs.vec_; }
-    bool operator!=(const Trigger& rhs) const { return !operator==(rhs); }
-    std::string expression() const { return Expression::compose_expression(vec_); }
-
-    const std::vector<PartExpression>& expr() const { return vec_; }
-
-private:
-    void add(const PartExpression& t) { vec_.push_back(t); }
-    std::vector<PartExpression> vec_;
-    Trigger& operator=(Trigger const& f) = delete; // prevent assignment
-};
-
-class Complete {
-public:
-    explicit Complete(const std::string& expression) { add(PartExpression(expression)); }
-    Complete(const std::string& expression, bool and_type) { add(PartExpression(expression, and_type)); }
-    explicit Complete(const PartExpression& pe) { add(pe); }
-    Complete(const Complete& rhs) = default;
-    explicit Complete(const boost::python::list& list);
-
-    bool operator==(const Complete& rhs) const { return vec_ == rhs.vec_; }
-    bool operator!=(const Complete& rhs) const { return !operator==(rhs); }
-    std::string expression() const { return Expression::compose_expression(vec_); }
-
-    const std::vector<PartExpression>& expr() const { return vec_; }
-
-private:
-    void add(const PartExpression& t) { vec_.push_back(t); }
-    std::vector<PartExpression> vec_;
-    Complete& operator=(Complete const& f) = delete; // prevent assignment
-};
-
-#endif /* ecflow_python_Trigger_HPP */
diff -pruN 5.12.4-1/Pyext/test/CleanupOnlineTutorial.py 5.13.0-1/Pyext/test/CleanupOnlineTutorial.py
--- 5.12.4-1/Pyext/test/CleanupOnlineTutorial.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/CleanupOnlineTutorial.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,28 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import os
-
-# clean up any file after running the online tutorial examples
-# Place in separate exception, otherwise not all files will be removed
-try: os.remove("test.def")
-except: pass
-
-try: os.remove("TestSuite.def")
-except: pass
-
-try: os.remove("SuiteBuilder.def")
-except: pass
-
-try: os.remove("server.defs")   
-except: pass
diff -pruN 5.12.4-1/Pyext/test/data/.gitignore 5.13.0-1/Pyext/test/data/.gitignore
--- 5.12.4-1/Pyext/test/data/.gitignore	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/data/.gitignore	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-/CUSTOMER
diff -pruN 5.12.4-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf 5.13.0-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf
--- 5.12.4-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,72 +0,0 @@
-%manual
-	OPERATORS: This is an example of using a manual
-	
-	This is used to also test variable subsitution of 
-	generated variables
-	SUITE     = %SUITE%
-	DATE      = %DATE%
-	DAY       = %DAY%
-	DD        = %DD%
-	DOW       = %DOW%
-	DOY       = %DOY%
-	MM        = %MM%
-	MONTH     = %MONTH%
-	YYYY      = %YYYY%
-	ECF_DATE   = %ECF_DATE%
-	ECF_TIME   = %ECF_TIME%
-	ECF_CLOCK  = %ECF_CLOCK%
-
-	FAMILY    = %FAMILY%
-	FAMILY1   = %FAMILY1%
-
-	TASK      = %TASK%
-	ECF_RID    = %ECF_RID:<not defined yet, since empty string in task>%
-	ECF_TRYNO  = %ECF_TRYNO%
-	ECF_NAME   = %ECF_NAME%
-	ECF_PASS   = %ECF_PASS%
-	ECF_SCRIPT = %ECF_SCRIPT%
-	ECF_JOB    = %ECF_JOB%
-	ECF_JOBOUT = %ECF_JOBOUT%
-    
-    Other ECF_ variables
-	ECF_KILL_CMD  = %ECF_KILL_CMD:<not defined yet>%
-	ECF_JOB_CMD   = %ECF_JOB_CMD%
-	ECF_HOME      = %ECF_HOME%
-	ECF_TRIES     = %ECF_TRIES:<Error>%
-	SMFILES      = %SMFILES:<not defined yet>%
-	ECF_INCLUDE   = %ECF_INCLUDE:<not defined yet>%
-	ECF_FETCH     = %ECF_FETCH:<not defined yet>%
-	ECF_OUT       = %ECF_OUT:<not defined yet>%
-	ECF_MICRO     = %ECF_MICRO%
-%end
-
-#============================================================
-# Using angle brackets should use ECF_INCLUDE
-#=========================================================
-%include <head.h>
-
-
-echo do some work
-# SLEEPTIME is defined thedefs.def file. Test variable substituition
-sleep %SLEEPTIME%
-echo end of job
-
-# test smsevent. smsmeter replaced with path to client exe
-smsevent  eventname
-smsmeter  metername 10
-
-%include <tail.h>
-
-
-%manual
-	Rest of the manual page is placed here, closer to the code
-%end
-%comment
-  Comment start
-%end
-%comment
-  Comment end
-%end
-%nopp
-  ignore everything in here
-%end
diff -pruN 5.12.4-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf 5.13.0-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf
--- 5.12.4-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
- 
-%include <head.h>
-
-echo do some work
-# SLEEPTIME is defined thedefs.def file. Test variable substituition
-sleep 10
-echo end of job
-
-%include <tail.h>
diff -pruN 5.12.4-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf 5.13.0-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf
--- 5.12.4-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf	1970-01-01 00:00:00.000000000 +0000
@@ -1,34 +0,0 @@
- 
-%include <head.h>
-
-
-echo do some work
-sleep 10
-echo end of job
-
-#=====================================================
-# change the ecfmicro character
-%ecfmicro &
-
-&manual
-	START Rest of the manual page is placed here, closer to the code
-&end
-&comment
-  Comment start
-  &SUITE&
-&end
-&comment
-  Comment end
-&end
-&nopp
-  ignore everything in here
-&end
-&manual
-	END of the manual
-&end
-#=====================================================
-# change the ecfmicro character back
-&ecfmicro %
-
-
-%include <tail.h>
diff -pruN 5.12.4-1/Pyext/test/data/includes/head.h 5.13.0-1/Pyext/test/data/includes/head.h
--- 5.12.4-1/Pyext/test/data/includes/head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/data/includes/head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,56 +0,0 @@
-#!/bin/ksh
-
-set -e # stop the shell on first error
-set -u # fail when using an undefined variable
-set -x # echo script lines as they are executed
-set -o pipefail # fail if last(rightmost) command exits with a non-zero status
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-## In applying this licence, ECMWF does not waive the privileges and immunities
-## granted to it by virtue of its status as an intergovernmental organisation
-## nor does it submit to any jurisdiction.
-
-# Defines the variables that are needed for any communication with ecflow server
-
-export ECF_PORT=%ECF_PORT%    # ECF port number on the server
-export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-export ECF_RID=$$             # Let All child commands pass process id to server
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%   # if server is SSL make sure client is
-fi
-
-# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
-os_name=$(uname -s)
-if [[ $os_name = Linux ]] ; then
-   host %ECF_HOST%
-fi
-
-echo "About to run ecflow_client --version"
-%ECF_CLIENT_EXE_PATH:ecflow_client% --version
-
-echo "About to run ecflow_client --init"
-%ECF_CLIENT_EXE_PATH:ecflow_client% --init=$$
-
-# Define a error hanlder
-
-ERROR() {
-   echo "ERROR() called"
-	set +e                                       # Clear -e flag, so we don't fail
-	wait                                         # wait for background process to stop
-	%ECF_CLIENT_EXE_PATH:ecflow_client% --abort  # Notify ECF_ that something went wrong
-	trap 0                                       # Remove the trap
-	exit 0                                       # End the script
-}
-
-# Trap any calls to exit and errors caught by the -e flag
-
-trap ERROR 0
-
-# Trap any signal that may cause the script to fail
-
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/Pyext/test/data/includes/tail.h 5.13.0-1/Pyext/test/data/includes/tail.h
--- 5.12.4-1/Pyext/test/data/includes/tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/data/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-wait                                            # wait for background process to stop
-%ECF_CLIENT_EXE_PATH:ecflow_client% --complete  # Notify ECF of a normal end
-trap 0                                          # Remove all traps
-exit 0                                          # End the shell
diff -pruN 5.12.4-1/Pyext/test/data/python_includes/head.py 5.13.0-1/Pyext/test/data/python_includes/head.py
--- 5.12.4-1/Pyext/test/data/python_includes/head.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/data/python_includes/head.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,94 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import datetime,time
-import os, signal, platform
-import ecflow
-
-print("cwd: " + os.getcwd())
-print("PYTHONPATH=====================================================")
-try:
-    print(os.environ['PYTHONPATH'].split(os.pathsep))
-except KeyError:
-    print("Could not get PYTHONPATH")
-
-print("LD_LIBRARY_PATH=====================================================")
-try:
-    print(os.environ['LD_LIBRARY_PATH'].split(os.pathsep))
-except KeyError:
-    print("Could not get LD_LIBRARY_PATH")
-    
-    
-class Client(object):
-    """Encapsulate communication with the ecflow server. This will automatically call
-       the child command init()/complete(), for job start/finish. It will also
-       handle exceptions and signals, by calling the abort child command.
-       *ONLY* one instance of this class, should be used. Otherwise zombies will be created.
-    """
-    def __init__(self,init_add_vars = False):
-        print ("Creating Client")
-        self.ci = ecflow.Client()
-        self.ci.set_host_port("%ECF_HOST%","%ECF_PORT%")
-        self.ci.set_child_pid(os.getpid())
-        self.ci.set_child_path("%ECF_NAME%")
-        self.ci.set_child_password("%ECF_PASS%")
-        self.ci.set_child_try_no(%ECF_TRYNO%)
-        if init_add_vars:
-            self.ci.set_child_init_add_vars({"name1":"1", "name2":"2"})
-            self.ci.set_child_init_add_vars([ecflow.Variable("name3","3"), ecflow.Variable("name4","4")])
-            self.ci.set_child_complete_del_vars(["name","name1","name2","name3","name4"])
-    
-        print("   Only wait 20 seconds, if the server cannot be contacted (note default is 24 hours) before failing")
-        self.ci.set_child_timeout(20)
-        self.ci.set_zombie_child_timeout(10)
-     
-        # Abort the task for the following signals
-        signal.signal(signal.SIGINT,  self.signal_handler)
-        signal.signal(signal.SIGHUP,  self.signal_handler)
-        signal.signal(signal.SIGQUIT, self.signal_handler)
-        signal.signal(signal.SIGILL,  self.signal_handler)
-        signal.signal(signal.SIGTRAP, self.signal_handler)
-        signal.signal(signal.SIGIOT,  self.signal_handler)
-        signal.signal(signal.SIGBUS,  self.signal_handler)
-        signal.signal(signal.SIGFPE,  self.signal_handler)
-        signal.signal(signal.SIGUSR1, self.signal_handler)
-        signal.signal(signal.SIGUSR2, self.signal_handler)
-        signal.signal(signal.SIGPIPE, self.signal_handler)
-        signal.signal(signal.SIGTERM, self.signal_handler)
-        signal.signal(signal.SIGXCPU, self.signal_handler) 
-        if platform.system() != "Darwin":
-            signal.signal(signal.SIGPWR,  self.signal_handler)
-     
-    def at_time(self):
-%ecfmicro #
-        return datetime.datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')
-#ecfmicro %
-
-    def signal_handler(self,signum, frame):
-        print('   Aborting: Signal handler called with signal ', signum)
-        self.ci.child_abort("Signal handler called with signal " + str(signum));
-     
-    def __enter__(self):
-        print('Calling init at: ' + self.at_time())
-        self.ci.child_init()
-        return self.ci
-     
-    def __exit__(self,ex_type,value,tb):
-        print ("   Client:__exit__: ex_type:" + str(ex_type) + " value:" + str(value) + "\n   traceback:" + str(tb))
-        if ex_type is not None:
-            print('Calling abort ' + self.at_time())
-            self.ci.child_abort("Aborted with exception type " + str(ex_type) + ":" + str(value))
-            return False
-        print('Calling complete at: ' + self.at_time())
-        self.ci.child_complete()
-        return False 
diff -pruN 5.12.4-1/Pyext/test/ecflow_test_util.py 5.13.0-1/Pyext/test/ecflow_test_util.py
--- 5.12.4-1/Pyext/test/ecflow_test_util.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/ecflow_test_util.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,255 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-# Utility code used in the tests.
-#
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-from socket import gethostname 
-import os,sys,fnmatch
-import time
-import fcntl
-import datetime,time
-import shutil   # used to remove directory tree
-import platform # for python version info
-
-from ecflow import Client, debug_build, File
-
-def all_files(root, patterns='*', single_level=False, yield_folders=False):
-    """Expand patterns from semi-colon separated string to list"""
-    patterns = patterns.split(';')
-    for path, subdirs, files in os.walk(root):
-        if yield_folders:
-            files.extend(subdirs)
-        files.sort()
-        for name in files:
-            for pattern in patterns:
-                if fnmatch.fnmatch(name,pattern):
-                    yield os.path.join(path, name)
-                    break
-        if single_level:
-            break    
-        
-# Enable to stop data being deleted, and stop server from being terminated
-def debugging() : return False
-
-def ecf_home(port): 
-    # debug_build() is defined for ecflow. Used in test to distinguish debug/release ecflow
-    # Vary ECF_HOME based on debug/release/port/python version, allowing multiple invocations of these tests
-    ecf_home_base = "/test/data/ecf_home_py" + str(sys.version_info[0])
-    if debug_build():
-        return os.getcwd() + ecf_home_base + "_debug_" + str(port)
-    return os.getcwd() + ecf_home_base + "_release_" + str(port)
-
-def get_parent_dir(file_path):
-    return os.path.dirname(file_path)
-
-def log_file_path(port): return "./" + gethostname() + "." + port + ".ecf.log"
-def checkpt_file_path(port): return "./" + gethostname() + "." + port + ".ecf.check"
-def backup_checkpt_file_path(port): return "./" + gethostname() + "." + port + ".ecf.check.b"
-def white_list_file_path(port): return "./" + gethostname() + "." + port + ".ecf.lists"
-
-def print_test_start(test_name):
-    print("#######################################################################################")
-    print(test_name)  
-    print("ecflow version(" + Client().version() + ") debug build(" + str(debug_build()) +")  python(" + platform.python_version() + ")")
-    print("PYTHONPATH                : " + str(os.environ['PYTHONPATH'].split(os.pathsep)))
-    #print("sys.path                  : " + str(sys.path))
-    print("Current working directory : " + str(os.getcwd()))
-    print("Python version            : " + str(sys.version_info[0]) + "." + str(sys.version_info[1]))
-    print("#######################################################################################")
-    
-def clean_up_server(port):
-    print("   clean_up " + port)
-    try: os.remove(log_file_path(port))
-    except: pass
-    try: os.remove(checkpt_file_path(port))
-    except: pass
-    try: os.remove(backup_checkpt_file_path(port))
-    except: pass
-    try: os.remove(white_list_file_path(port))  
-    except: pass
-    
-def clean_up_data(port):
-    print("   Attempting to Removing ECF_HOME " + ecf_home(port))
-    try: 
-        shutil.rmtree(ecf_home(port),True)   # True means ignore errors 
-        print("   Remove OK") 
-    except: 
-        print("   Remove Failed") 
-        pass
-        
-# =======================================================================================
-class EcfPortLock(object):
-    """allow debug and release version of python tests to run at the same
-    time, buy generating a unique port each time"""
-    def __init__(self):
-        print("   EcfPortLock:__init__")
-        pass
-    
-    def at_time(self):
-        return datetime.datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')
-    
-    def find_free_port(self,seed_port):
-        print("   EcfPortLock:find_free_port starting with " + str(seed_port) + " at time " + self.at_time())
-        port = seed_port
-        while 1:
-            # port must be free for at least 15 seconds
-            if self._timed_free_port(port,15) == True:
-                print("   *FOUND* free server port " + str(port) + " : " + self.at_time())
-                if self.do_lock(port):
-                    break
-            else:
-                print("   *Server* port " + str(port) + " busy( by  ping), trying next port " + self.at_time())
-            port = port + 1
-            
-        return str(port)  
-    
-    def _timed_free_port(self,port,wait_time = 10):
-        count = 0
-        while count < wait_time:
-            if self._free_port(port) == True:
-                count = count + 1
-                time.sleep(1)
-            else:
-                return False
-        return self._free_port(port)
-            
-    def _free_port(self,port):
-        try:
-            ci = Client()
-            ci.set_host_port("localhost",str(port))
-            ci.ping() 
-            return False
-        except RuntimeError as e:
-            return True
-            
-    def do_lock(self,port):
-        file = self._lock_file(port)
-        if os.path.exists(file):
-            print("   *LOCKED* lock file exists " + file + " trying next port : " + self.at_time() )
-            return False
-        try:
-            fp = open(file, 'w') 
-            try:
-                self.lock_time = self.at_time()
-                fcntl.lockf(fp, fcntl.LOCK_EX | fcntl.LOCK_NB)
-                self.lock_file_fp = fp
-                print("   *LOCKED* file " + file + " : " + self.lock_time )
-                return True;
-            except IOError:
-                print("   Could *NOT* lock file " + file + " trying next port : " + self.at_time())
-                return False
-        except IOError as e:
-            print("   Could not open file " + file + " for write trying next port : " + self.at_time())
-            return False
-        
-    def remove(self,port):
-        file = self._lock_file(port)
-        print("   Remove lock file : " + file + " : lock_time: " + self.lock_time + " release_time: " + self.at_time() )
-        self.lock_file_fp.close()
-        os.remove(file)
-    
-    def _lock_file(self,port):
-        if "ECF_PORT_LOCK_DIR" in os.environ:
-            lock_file = os.environ["ECF_PORT_LOCK_DIR"] + "/" + str(port) + ".lock"
-            #print("     EcfPortLock::_lock_file ECF_PORT_LOCK_DIR: " + lock_file)
-            return lock_file
-        if os.path.exists(File.source_dir()):
-            lock_file = File.source_dir() + "/" + str(port) + ".lock"
-            #print("     EcfPortLock::_lock_file File::source_dir(): " + lock_file)
-            return lock_file
-        lock_file = os.getcwd() + "/" + str(port) + ".lock"
-        #print("     EcfPortLock::_lock_file os.getcwd(): " + lock_file)
-        return lock_file
-        
-# ===============================================================================
-
-class Server(object):
-    """TestServer: allow debug and release version of python tests to run at the same
-    time, by generating a unique port each time"""
-    def __init__(self):
-        print("Server:__init__: Starting server")    
-        if not debugging():
-            seed_port = int(os.getenv('ECF_FREE_PORT', '3153'))
-            if sys.version_info[0] == 3: # python3 can run at same time
-                seed_port = int(os.getenv('ECF_FREE_PORT', '3154'))  
-            if debug_build(): seed_port = seed_port + 1 
-            self.lock_file = EcfPortLock()
-            self.the_port = self.lock_file.find_free_port(seed_port)   
-        else:
-            self.the_port = "3152"
-            
-        # Only worth doing this test, if the server is running
-        # ON HPUX, having only one connection attempt, sometimes fails
-        #ci.set_connection_attempts(1)     # improve responsiveness only make 1 attempt to connect to server
-        #ci.set_retry_connection_period(0) # Only applicable when make more than one attempt. Added to check api.
-        self.ci = Client("localhost", self.the_port)
-
-    def at_time(self):
-        return datetime.datetime.fromtimestamp(time.time()).strftime('%Y-%m-%d %H:%M:%S')
-
-    def __enter__(self):
-        try:
-            print("Server:__enter__: About to ping localhost: " + self.the_port +  " : " + self.at_time())       
-            self.ci.ping() 
-            print("   ------- Server all ready running on port " + self.the_port + " *UNEXPECTED* -- : " + self.at_time() )
-            sys.exit(1)
-        except RuntimeError as e:
-            while 1:
-                # Only worth doing this test, if the server is running
-                # ON HPUX, having only one connection attempt, sometimes fails
-                #ci.set_connection_attempts(1)     # improve responsiveness only make 1 attempt to connect to server
-                #ci.set_retry_connection_period(0) # Only applicable when make more than one attempt. Added to check api.
-                self.ci = Client("localhost", self.the_port)
-
-                print("   ------- Server *NOT* running on port " + self.the_port + " as *EXPECTED* ------ ") 
-                print("   ------- Start the server on port " + self.the_port + " ---------")  
-                if not debugging():
-                    clean_up_server(str(self.the_port))   
-                    clean_up_data(str(self.the_port))    
-        
-                server_exe = File.find_server();
-                assert len(server_exe) != 0, "Could not locate the server executable"
-            
-                server_exe += " --port=" + self.the_port + " --ecfinterval=4 &"
-                print("   TestClient.py: Starting server " + server_exe)
-                os.system(server_exe) 
-            
-                print("   Allow time for server to start " + self.at_time())
-                if self.ci.wait_for_server_reply() :
-                    print("   Server has started " +  self.at_time())
-                    break
-                else:
-                    print("   Server failed to start after 60 second, trying next port !!!!!! " + self.at_time())
-                    self.the_port = self.lock_file.find_free_port( int(self.the_port) + 1 )   
-             
-        print("   Run the tests, leaving Server:__enter__:") 
-
-        # return the Client, that can call to the server
-        return self.ci
-    
-    def __exit__(self,exctype,value,tb):
-        print("Server:__exit__: Kill the server, clean up log file, check pt files and lock files, ECF_HOME " + self.at_time())
-        print("   exctype:",exctype)
-        print("   value:",value)
-        print("   tb:",tb)
-        print("   Terminate server "+ self.at_time() )
-        self.ci.terminate_server()  
-        print("   Terminate server OK " + self.at_time() )
-        self.lock_file.remove(self.the_port)
-        
-        # Do not clean up data, if an assert was raised. This allow debug
-        if exctype is None:
-            if not debugging():
-                clean_up_server(str(self.the_port))
-                clean_up_data(str(self.the_port))
-        return False
diff -pruN 5.12.4-1/Pyext/test/py_s_TestClientApi.py 5.13.0-1/Pyext/test/py_s_TestClientApi.py
--- 5.12.4-1/Pyext/test/py_s_TestClientApi.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_s_TestClientApi.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,2143 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-#  code for testing client code in python
-import time
-import os
-import pwd
-import select
-from datetime import datetime
-import shutil   # used to remove directory tree
-
-# ecflow_test_util, see File ecflow_test_util.py
-import ecflow_test_util as Test
-from ecflow import Defs, Suite, Family, Task, Edit, Meter, Clock, DState,  Style, State, RepeatDate, RepeatDateTime, \
-                   PrintStyle, File, Client, SState, CheckPt, Cron, Late, debug_build, Flag, FlagType
-
-def ecf_includes() :  return os.getcwd() + "/test/data/includes"
-
-def debugging() : return False  # Use to enable auto flush and disable log file tests
-
-def create_defs(name=""):
-    defs = Defs()
-    suite_name = name
-    if len(suite_name) == 0: suite_name = "s1"
-    suite = defs.add_suite(suite_name);
-    
-    ecfhome = Test.ecf_home(the_port);
-    suite.add_variable("ECF_HOME", ecfhome);
-    suite.add_variable("ECF_CLIENT_EXE_PATH", File.find_client());
-    suite.add_variable("SLEEP", "1");  # not strictly required since default is 1 second
-    suite.add_variable("ECF_INCLUDE", ecf_includes());
-
-    family = suite.add_family("f1")
-    family.add_task("t1")
-    family.add_task("t2")
-    return defs;
-    
-def test_host_port(ci,host,port):
-    try :
-        ci.set_host_port(host,port)
-        return True
-    except RuntimeError:
-        return False 
-
-def test_host_port_(ci,host_port):
-    try :
-        ci.set_host_port(host_port)
-        return True
-    except RuntimeError:
-        return False 
-    
-def test_client_host_port(host,port):
-    try :
-        Client(host,port)
-        return True
-    except RuntimeError:
-        return False 
-
-def test_client_host_port_(host_port):
-    try :
-        Client(host_port)
-        return True
-    except RuntimeError:
-        return False 
-    
-def sync_local(ci):
-    if ci.is_auto_sync_enabled():
-        return
-    ci.sync_local()
-        
-def test_set_host_port():
-    print("test_set_host_port")
-    ci = Client();
-    print(" Client.get_host() = " + ci.get_host())
-    print(" Client.get_port() = " + ci.get_port())
-    assert test_host_port(ci,"host","3141") ,  "Expected no errors"
-    assert test_host_port(ci,"host",4444) ,    "Expected no errors"
-    assert test_host_port_(ci,"host:4444") ,    "Expected no errors"
-    assert test_host_port_(ci,"host@4444") ,    "Expected no errors"
-    assert test_host_port(ci,"","") == False , "Expected errors"
-    assert test_host_port(ci,"host","") == False , "Expected errors"
-    assert test_host_port(ci,"host","host") == False , "Expected errors"
-    assert test_host_port_(ci,"host:host") == False , "Expected errors"
-    assert test_host_port_(ci,"3141:host") == False , "Expected errors"
-    assert test_host_port_(ci,"3141@host") == False , "Expected errors"
-    assert test_host_port_(ci,"3141@") == False , "Expected errors"
-    
-    assert test_client_host_port("host","3141") ,  "Expected no errors"
-    assert test_client_host_port("host",4444) ,    "Expected no errors"
-    assert test_client_host_port_("host:4444") ,    "Expected no errors"
-    assert test_client_host_port("","") == False , "Expected errors"
-    assert test_client_host_port("host","") == False , "Expected errors"
-    assert test_client_host_port("host","host") == False , "Expected errors"
-    assert test_client_host_port_("host:host") == False , "Expected errors"
-    assert test_client_host_port_("3141:host") == False , "Expected errors"
-
-def print_test(ci,test_name):
-    print(test_name)
-    if ci.is_auto_sync_enabled():
-        ci.log_msg(test_name + " ============= AUTO SYNC ENABLED ================================ ")
-    else:
-        ci.log_msg(test_name + " ================================================================ ")
-
-def test_version(ci):
-    print_test(ci,"test_version")
-    client_version = ci.version();
-    server_version = ci.server_version();
-    print("  client_version: ",client_version)
-    print("  server_version: ",server_version)
-    assert client_version == server_version, "Expected client version(" + client_version +") and server version(" +  server_version + ") to match\n";
-    
-def test_client_get_server_defs(ci):
-    print_test(ci,"test_client_get_server_defs")
-    ci.delete_all() # start fresh
-    ci.load(create_defs())  
-    ci.get_server_defs() 
-    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())
-
-    ci.delete_all() # start fresh
-    ci.load(create_defs()) 
-    sync_local(ci) 
-    
-    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())
-
-
-def test_client_new_log(ci, port):
-    print_test(ci,"test_client_new_log")
-    log_path = Test.log_file_path(port)
-    if not os.path.exists(log_path):
-        print(log_path  + " : log does not exist ?")    
-    
-    new_log_file_name = "./test_client_new_log_" + str(os.getpid()) + ".log"
-    try : os.remove(new_log_file_name) # delete file if it exists
-    except: pass
-    
-    ci.new_log(new_log_file_name) 
-    ci.flush_log() # close log file and force write to disk
-    assert os.path.exists(new_log_file_name),new_log_file_name + " : New log does not exist"
-    try: os.remove(new_log_file_name)
-    except: pass
-    
-    # reset new log to original
-    ci.new_log(log_path) 
-    ci.ping()
-    ci.flush_log() # close log file and force write to disk    
-    log_file = open(log_path)
-    try:     log_text = log_file.read();     # assume log file not to big
-    finally: log_file.close();
-    assert log_text.find("--ping") != -1, "Expected to find --ping in log file"
- 
-    if not os.path.exists(log_path):
-        print(log_path  + " : log does not exist ?")
-
-def test_client_clear_log(ci, port):
-    if debugging() : return   #  dont run this test when debugging as log file is lost
-    print_test(ci,"test_client_clear_log")
-    log_path = Test.log_file_path(port)
-    # populate log
-    ci.ping();
-    ci.ping();
-    ci.flush_log() # close log file and force write to disk    
-    log_file = open(log_path)
-    try:     log_text = log_file.read();     # assume log file not to big
-    finally: log_file.close();
-    assert log_text.find("--ping") != -1, "Expected to find --ping in log file"
-    
-    ci.clear_log()    
-    if not os.path.exists(log_path):
-        print(log_path  + " : log does not exist ?")
-
-    log_file = open(log_path)
-    try:     log_text = log_file.read();     # assume log file not to big
-    finally: log_file.close();
-    assert len(log_text) == 0, "Expected log file to be empty but found " + log_text
-
-    if not os.path.exists(log_path):
-        print(log_path  + " : log does not exist ?")
-
-
-def test_client_log_msg(ci, port):
-    if debugging() : return   #  dont run this test when debugging  
-
-    print_test(ci,"test_client_log_msg")
-    log_path = Test.log_file_path(port)
-    if not os.path.exists(log_path):
-        print(log_path  + " : log does not exist ?")
-
-    # Send a message to the log file, then make sure it was written
-    ci.log_msg("Humpty dumpty sat on a wall!")
-    ci.flush_log(); # flush and close log file, so we can open it
-    log_file = open(log_path)
-    try:     log_text = log_file.read();     # assume log file not to big
-    finally: log_file.close();
-    assert log_text.find("Humpty dumpty sat on a wall!") != -1, "Expected to find Humpty dumpty in the log file"                
-
-    if not os.path.exists(log_path):
-        print(log_path  + " : log does not exist ?")
-
-def test_client_restart_server(ci):
-    print_test(ci,"test_client_restart_server")
-    ci.restart_server()
-    sync_local(ci)
-    assert ci.get_defs().get_server_state() == SState.RUNNING, "Expected server to be running"
-    
-    paths = list(ci.changed_node_paths)
-    assert len(paths) == 1, "expected changed node to be the root node: " + paths
-    assert paths[0] == "/", "Expected root path but found " + str(paths[0])
-
-
-def test_client_halt_server(ci):
-    print_test(ci,"test_client_halt_server")
-    ci.halt_server()
-    sync_local(ci)
-    assert ci.get_defs().get_server_state() == SState.HALTED, "Expected server to be halted"
-    
-    paths = list(ci.changed_node_paths)
-    assert len(paths) == 1, "expected changed node to be the root node"
-    assert paths[0] == "/", "Expected root path but found " + str(paths[0])
-    ci.restart_server()   
-
-def test_client_shutdown_server(ci):
-    print_test(ci,"test_client_shutdown_server")
-    ci.shutdown_server()
-    sync_local(ci)
-    assert ci.get_defs().get_server_state() == SState.SHUTDOWN, "Expected server to be shutdown"
-    
-    paths = list(ci.changed_node_paths)
-    assert len(paths) == 1, "expected changed node to be the root node"
-    assert paths[0] == "/", "Expected root path but found " + str(paths[0])
-
-
-def test_client_load_in_memory_defs(ci):
-    print_test(ci,"test_client_load_in_memory_defs")
-    ci.delete_all() # start fresh
-    ci.load(create_defs())  
-    sync_local(ci) 
-    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())              
-
-
-def test_client_load_from_disk(ci):            
-    print_test(ci,"test_client_load_from_disk")
-    ci.delete_all() # start fresh
-    defs = create_defs();
-    defs_file = "test_client_load_from_disk_" + str(os.getpid()) + ".def"
-    defs.save_as_defs(defs_file)     
-    assert os.path.exists(defs_file), "Expected file " + defs_file + " to exist after defs.save_as_defs()"
-    ci.load(defs_file) # open and parse defs file, and load into server.\n"
-        
-    sync_local(ci) 
-    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())
-    os.remove(defs_file)
-
-
-def test_client_checkpt(ci, port):
-    print_test(ci,"test_client_checkpt")
-    # start fresh
-    ci.delete_all() 
-    try:    
-        os.remove(Test.checkpt_file_path(port))
-        os.remove(Test.backup_checkpt_file_path(port))
-    except: pass
-    
-    ci.load(create_defs())  
-    ci.checkpt()
-    assert os.path.exists(Test.checkpt_file_path(port)), "Expected check pt file to exist after ci.checkpt()"
-    assert os.path.exists(Test.backup_checkpt_file_path(port)) == False, "Expected back up check pt file to *NOT* exist"
-    
-    ci.checkpt()   # second check pt should cause backup check pt to be written
-    assert os.path.exists(Test.backup_checkpt_file_path(port)), "Expected back up check pt file to exist after second ci.checkpt()"
-
-    ci.checkpt(CheckPt.NEVER)         # switch of check pointing
-    ci.checkpt(CheckPt.ALWAYS)        # always check point, at any state change
-    ci.checkpt(CheckPt.ON_TIME)       # Check point periodically, by interval set in server
-    ci.checkpt(CheckPt.ON_TIME, 200)  # Check point periodically, by interval set in server
-    ci.checkpt(CheckPt.UNDEFINED, 0, 35)  # Change check point save time alarm
-
-    os.remove(Test.checkpt_file_path(port))
-    os.remove(Test.backup_checkpt_file_path(port))
-
-
-def test_client_restore_from_checkpt(ci, port):          
-    print_test(ci,"test_client_restore_from_checkpt")
-    # start fresh
-    ci.delete_all() 
-    try:    
-        os.remove(Test.checkpt_file_path(port))
-        os.remove(Test.backup_checkpt_file_path(port))
-    except: pass
-    
-    ci.load(create_defs())  
-    ci.checkpt()
-    ci.delete_all() 
-    
-    sync_local(ci) 
-    assert ci.get_defs().find_suite("s1") is None, "Expected all suites to be delete:\n"
-    
-    ci.halt_server()  # server must be halted, otherwise restore_from_checkpt will throw
-    ci.restore_from_checkpt()
-    
-    sync_local(ci) 
-    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite s1 after restore from checkpt:\n" + str(ci.get_defs())
-
-    os.remove(Test.checkpt_file_path(port))
-    ci.restart_server()   
-
-
-def get_username(): return pwd.getpwuid(os.getuid())[ 0 ]
-
-def test_client_reload_wl_file(ci, port):
-    print_test(ci,"test_client_reload_wl_file")
-    
-    expected = False
-    try:    ci.reload_wl_file();            
-    except: expected = True
-    assert expected, "Expected reload to fail when no white list specified"
-    
-    # create a white list file
-    wl_file = open(Test.white_list_file_path(port), 'w')
-    wl_file.write("#\n")
-    wl_file.write("4.4.14   #   comment\n\n")
-    wl_file.write("# These user have read and write access to the server\n")
-    wl_file.write(get_username() + "\n")  # add current user otherwise remaining test's, wont have access from server anymore
-    wl_file.write("axel  # admin\n")
-    wl_file.write("john  # admin\n\n")
-    wl_file.write("# Read only users\n")
-    wl_file.write("-fred   # needs read access only\n")
-    wl_file.write("-joe90  # needs read access only\n")
-    wl_file.close();
-    
-    ci.reload_wl_file();  
-    os.remove(Test.white_list_file_path(port))          
-
-
-def test_client_run(ci):            
-    print_test(ci,"test_client_run")
-    ci.delete_all()     
-    defs = create_defs("test_client_run")  
-    suite = defs.find_suite("test_client_run")
-    suite.add_defstatus(DState.suspended)
-
-    defs.generate_scripts();
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
-    
-    ci.restart_server()
-    ci.load(defs)           
-    ci.begin_all_suites()
-    ci.run("/test_client_run", False)
-    
-    count = 0
-    while 1:
-        count += 1
-        ci.sync_local() # get the changes, synced with local defs
-        suite = ci.get_defs().find_suite("test_client_run")
-        assert suite is not None, "Expected to find suite test_client_run:\n" + str(ci.get_defs())
-        print(f"Suite state: {suite.get_state()}, {count}, at {datetime.now()}")
-        if suite.get_state() == State.complete:
-            break;
-        assert suite.get_state() != State.aborted, "Expected suite to complete, but found it was aborted"
-        time.sleep(3)
-        if count > 20:
-            assert False, "test_client_run aborted after " + str(count) + " loops:\n" + str(ci.get_defs())
-        
-    ci.log_msg("Looped " + str(count) + " times")
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_run"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)  
-
-
-def test_client_run_with_multiple_paths(ci):            
-    print_test(ci,"test_client_run_with_multiple_paths")
-    ci.delete_all()     
-    defs = create_defs("test_client_run_with_multiple_paths")  
-    suite = defs.find_suite("test_client_run_with_multiple_paths")
-    suite.add_defstatus(DState.suspended)
-
-    defs.generate_scripts();
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
-    
-    ci.restart_server()
-    ci.load(defs)           
-    ci.begin_all_suites()
-    path_list = [ "/test_client_run_with_multiple_paths/f1/t1", "/test_client_run_with_multiple_paths/f1/t2"]
-    ci.run( path_list, False)
-
-    count = 0
-    while 1:
-        count += 1
-        ci.sync_local() # get the changes, synced with local defs
-        suite = ci.get_defs().find_suite("test_client_run_with_multiple_paths")
-        assert suite is not None, "Expected to find suite test_client_run_with_multiple_paths:\n" + str(ci.get_defs())
-        if suite.get_state() == State.complete:
-            break;
-        time.sleep(3)
-        if count > 20:
-            assert False, "test_client_run_with_multiple_paths aborted after " + str(count) + " loops:\n" + str(ci.get_defs())
-        
-    ci.log_msg("Looped " + str(count) + " times")
-    
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_run_with_multiple_paths"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)     
-
-    
-def test_client_requeue(ci):
-    print_test(ci,"test_client_requeue")
-    ci.delete_all()     
-    defs = create_defs("test_client_requeue")  
-    suite = defs.find_suite("test_client_requeue")
-    suite.add_defstatus(DState.suspended)
-     
-    defs.generate_scripts()
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
- 
-    ci.restart_server()
-    ci.load(defs)           
-    ci.begin_all_suites()
-    
-    ci.force_state_recursive("/test_client_requeue",State.unknown)
-    sync_local(ci)
-    suite = ci.get_defs().find_suite("test_client_requeue")
-    assert suite.get_state() == State.unknown, "Expected to find suite with state unknown"
-
-    ci.requeue("/test_client_requeue")
-    sync_local(ci);
-    suite = ci.get_defs().find_suite("test_client_requeue")
-    assert suite.get_state() == State.queued, "Expected to find suite with state queued"
-
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_requeue"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)     
-
-def test_client_requeue_with_multiple_paths(ci):
-    print_test(ci,"test_client_requeue_with_multiple_paths")
-    ci.delete_all()     
-    defs = create_defs("test_client_requeue_with_multiple_paths")  
-    suite = defs.find_suite("test_client_requeue_with_multiple_paths")
-    suite.add_defstatus(DState.suspended)
-     
-    defs.generate_scripts()
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
- 
-    ci.restart_server()
-    ci.load(defs)           
-    ci.begin_all_suites()
-    
-    ci.force_state_recursive("/test_client_requeue_with_multiple_paths",State.unknown)
-    sync_local(ci);
-    task1 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t1")
-    task2 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t2")
-    assert task1.get_state() == State.unknown, "Expected to find t1 with state unknown"
-    assert task2.get_state() == State.unknown, "Expected to find t2 with state unknown"
-
-    path_list = [ "/test_client_requeue_with_multiple_paths/f1/t1", "/test_client_requeue_with_multiple_paths/f1/t2" ]
-    ci.requeue( path_list)
-    sync_local(ci);
-    task1 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t1")
-    task2 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t2")
-    assert task1.get_state() == State.queued, "Expected to find task t1 with state queued"
-    assert task2.get_state() == State.queued, "Expected to find task t2 with state queued"
-
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_requeue_with_multiple_paths"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)     
-
-
-def test_client_free_dep(ci):
-    print_test(ci,"test_client_free_dep")
-    ci.delete_all()  
-       
-    # add a real clock, since we are adding date dependencies
-    # Note: adding a future time dependency on a task, will cause it to requeue, when complete
-    # Hence even when we free these dependency they get requeued.
-    # So we use todays date.
-    ltime = time.localtime();
-    day = ltime.tm_mday
-    month = ltime.tm_mon
-    year = ltime.tm_year
-    
-    defs = Defs()
-    suite = defs.add_suite("test_client_free_dep");
-    suite.add_clock(Clock(False)) # true means hybrid, False means real
-    ecfhome = Test.ecf_home(the_port);
-    suite.add_variable("ECF_HOME", ecfhome);
-    suite.add_variable("ECF_CLIENT_EXE_PATH", File.find_client());
-    suite.add_variable("SLEEPTIME", "1");
-    suite.add_variable("ECF_INCLUDE", ecf_includes());
-    family = suite.add_family("f1")
-    family.add_task("t1").add_time("00:01")
-    family.add_task("t2").add_date(day,month,year)
-    family.add_task("t3").add_trigger("1 == 0")
-    t4 = family.add_task("t4")
-    t4.add_time("00:01")
-    t4.add_date(day,month,year)
-    t4.add_trigger("1 == 0")
-
-    defs.generate_scripts();
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
- 
-    ci.restart_server()
-    ci.load(defs)           
-    ci.begin_all_suites()
-    
-    t1_path = "/test_client_free_dep/f1/t1"
-    t2_path = "/test_client_free_dep/f1/t2"
-    t3_path = "/test_client_free_dep/f1/t3"
-    t4_path = "/test_client_free_dep/f1/t4"
-    while 1:
-        ci.sync_local()
-        t1 = ci.get_defs().find_abs_node(t1_path)
-        t2 = ci.get_defs().find_abs_node(t2_path)
-        t3 = ci.get_defs().find_abs_node(t3_path)
-        t4 = ci.get_defs().find_abs_node(t4_path)
- 
-        if t1.get_state() == State.queued: ci.free_time_dep(t1_path)
-        if t2.get_state() == State.queued: ci.free_date_dep(t2_path)
-        if t3.get_state() == State.queued: ci.free_trigger_dep(t3_path)
-        if t4.get_state() == State.queued: ci.free_all_dep(t4_path)
-
-        suite = ci.get_defs().find_suite("test_client_free_dep")
-        if suite.get_state() == State.complete:
-            break;
-        time.sleep(3)       
-            
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_free_dep"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)
-
-
-class CustomStdOut:
-    def __enter__(self):
-        # create a pipe to store some content temporarily
-        self.read_pipe, self.write_pipe = os.pipe()
-        # save the original ouput fd
-        self.stdout = os.dup(1)
-        # redirect stdout into the write pipe
-        fd = os.dup2(self.write_pipe, 1)
-        return self
-
-    def __exit__(self, exc_type, exc_value, exc_traceback):
-        # restore the original output fd
-        os.dup2(self.stdout, 1)
-
-    def _more_data(self):
-        # check if there is more data in the read pipe
-        r, _, _ = select.select([self.read_pipe], [], [], 0)
-        return bool(r)
-
-    def value(self):
-        out = ''
-        while self._more_data():
-            out += os.read(self.read_pipe, 1024).decode('utf-8')
-        return out
-
-
-def test_client_stats(ci):
-    print_test(ci,"test_client_stats")
-    with CustomStdOut() as out:
-        stats = ci.stats()
-        assert "statistics" in stats, "Expected 'statistics' in the response"
-        assert "statistics" in out.value(), "Expected 'statistics' in the captured output"
-
-
-def test_client_stats_with_stdout(ci):
-    print_test(ci,"test_client_stats_with_stdout")
-    with CustomStdOut() as out:
-        stats = ci.stats(True)
-        assert "statistics" in stats, "Expected 'statistics' in the response"
-        assert "statistics" in out.value(), "Expected 'statistics' in the captured output"
-
-
-def test_client_stats_without_stdout(ci):
-    print_test(ci,"test_client_stats_without_stdout")
-    with CustomStdOut() as out:
-        stats = ci.stats(False)
-        assert "statistics" in stats, "Expected 'statistics' in the response"
-        assert not out.value() , "No captured output expected"
-
-
-def test_client_stats_reset(ci):
-    print_test(ci,"test_client_stats_reset")
-    ci.stats_reset()   
-    stats = ci.stats()
-    assert "statistics" in stats, "Expected 'statistics' in the response"
-
-
-def test_client_debug_server_on_off(ci):
-    print_test(ci,"test_client_debug_server_on_off")
-    ci.debug_server_on()  # writes to standard out
-    ci.debug_server_off()  
-
-
-def test_client_check(ci):
-    print_test(ci,"test_client_check")
-    ci.delete_all()     
-    
-    defs = Defs()
-    defs.add_extern("/a/b/c/d")
-    defs.add_extern("/a/b/c/d/e:event")
-    defs.add_extern("/a/b/c/d/e:meter")
-    defs.add_extern("/made/up/redundant/extren")
-    defs.add_extern("/made/up/redundant/extren")
-    defs.add_extern("/limits:c1a")
-    defs.add_extern("/limits:c1a")
-    defs.add_extern("fred")
-    defs.add_extern("limits:hpcd")
-    defs.add_extern("/suiteName:sg1")
-    defs.add_extern("/obs/limits:hpcd")
-    suite = defs.add_suite("extern")
-    family_f1 = suite.add_family("f1")
-    family_f1.add_task("p").add_trigger("/a/b/c/d == complete")      # extern path
-    family_f1.add_task("q").add_trigger("/a/b/c/d/e:event == set")   # extern event path
-    family_f1.add_task("r").add_trigger("/a/b/c/d/e:meter le 30")    # extern meter path
-
-    suite.add_inlimit("c1a","/limits")
-    suite.add_inlimit("fred")
-    
-    family_anon = suite.add_family("anon")
-    family_anon.add_inlimit("hpcd","limits")
-    family_anon.add_task("t1").add_inlimit("sg1","/suiteName")
-    family_anon.add_task("t2").add_inlimit("hpcd","/obs/limits")
-    family_anon.add_task("t3").add_inlimit("c1a","/limits")
- 
-    # CLIENT side check
-    client_check = defs.check()
-    assert len(client_check) == 0, "Expected clean defs check due to externs but found:\n" + client_check + "\n" + str(defs)
-
-    # SERVER side check
-    ci.load(defs)
-    server_check = ci.check("") # empty string means check the whole defs, otherwise a node path can be specified.
-    # print(server_check)
-    assert len(server_check) > 0, "Expected defs to fail, since no externs in server "
-    
-def test_client_suites(ci):
-    print_test(ci,"test_client_suites")
-    ci.delete_all() 
-    assert len(ci.suites()) == 0 ,"expected 0 suite "
-
-    defs = create_defs("test_client_suites")
-    ci.load(defs)  
-    assert len(ci.suites()) == 1 ,"expected 1 suite "
-    
-    ci.delete_all() 
-    defs.add_suite("s2")
-    ci.load(defs)  
-    assert len(ci.suites()) == 2 ,"expected 2 suite "
-    
-def test_client_ch_suites(ci):
-    print_test(ci,"test_client_ch_suites")
-    try: ci.ch_drop_user("")  # drop all handle associated with current user
-    except: pass              # Drop throws if no handle registered
-    ci.delete_all()     
-    
-    defs = Defs()
-    for i in range(1,7): defs.add_suite("s" + str(i))
-    ci.load(defs)
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 after load, but found " + str(len(list((ci.get_defs().suites))))
-
-    suite_names = [ 's1', 's2', 's3' ]
-    ci.ch_register(True,suite_names)    # register interest in suites s1,s2,s3 and any new suites
-    print("ch_handle after register : " , ci.ch_handle())
-    ci.ch_suites()  # writes to standard out, list of suites and handles
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 3,"Expected 3 registered suites but found " + str(len(list((ci.get_defs().suites))))
-
-    ci.ch_register(False,[ "s1"])       # register interest in suites s1. ci remembers the last client handle
-    ci.ch_suites()  # writes to standard out, list of suites and handles
-    sync_local(ci)
-    ci.ch_suites()  # writes to standard out, list of suites and handles
-    assert len(list(ci.get_defs().suites)) == 1,"Expected 1 registered suites but found " + str(len(list((ci.get_defs().suites))))
-    
-
-def test_client_ch_register(ci):
-    print_test(ci,"test_client_ch_register")
-    try: ci.ch_drop_user("")  # drop all handle associated with current user
-    except: pass              # Drop throws if no handle registered
-    ci.delete_all()  
-    
-    defs = Defs()
-    for i in range(1,7): defs.add_suite("s" + str(i))
-    ci.load(defs)
-    
-    suite_names = [ 's1', 's2', 's3' ]
-    ci.ch_register(True, suite_names)    # register interest in suites s1,s2,s3 and any new suites
-    ci.ch_register(False,suite_names)    # register interest in suites s1,s2,s3 only
-
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 3,"Expected 3 registered suites but found " + str(len(list((ci.get_defs().suites))))
-  
-            
-def test_client_ch_drop(ci):
-    print_test(ci,"test_client_ch_drop")
-    try: ci.ch_drop_user("")  # drop all handle associated with current user
-    except: pass              # Drop throws if no handle registered
-    ci.delete_all()   
-    
-    defs = Defs()
-    for i in range(1,7): defs.add_suite("s" + str(i))
-    ci.load(defs)
-    
-    try:
-        # register interest in suites s1,s2,s3 and any new suites
-        suite_names = [ 's1', 's2', 's3' ]
-        ci.ch_register(True, suite_names)    
-    finally:  
-        ci.ch_drop()  # drop using handle stored in ci., from last register
-
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
-         
-          
-def test_client_ch_drop_user(ci):
-    print_test(ci,"test_client_ch_drop_user")
-    ci.delete_all()   
-    try: ci.ch_drop_user("")  # drop all handle associated with current user
-    except: pass              # Drop throws if no handle registered
-    
-    defs = Defs()
-    for i in range(1,7): defs.add_suite("s" + str(i))
-    ci.load(defs)
-    
-    try:
-        # register interest in suites s1,s2,s3 and any new suites
-        suite_names = [ 's1', 's2', 's3' ]
-        ci.ch_register(True, suite_names)
-        sync_local(ci)
-        assert len(list(ci.get_defs().suites)) == 3,"Expected 3 suites but found " + str(len(list((ci.get_defs().suites))))
-    except RuntimeError as e:
-        print(str(e))
-    
-    ci.ch_drop_user("")  # drop all handle associated with current user
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
-            
-            
-def test_client_ch_add(ci):
-    print_test(ci,"test_client_ch_add")
-    ci.delete_all()  
-    try: ci.ch_drop_user("")  # drop all handle associated with current user
-    except: pass              # Drop throws if no handle registered
-    
-    defs = Defs()
-    for i in range(1,7): defs.add_suite("s" + str(i))
-    ci.load(defs)
-    
-    try:
-        suite_names = []
-        ci.ch_register(True,suite_names)        # register interest in any new suites
-        suite_names = [ 's1', 's2' ]
-        ci.ch_add(suite_names)                  # add suites s1,s2 to the last added handle
-        sync_local(ci)
-        assert len(list(ci.get_defs().suites)) == 2,"Expected 2 suites but found " + str(len(list((ci.get_defs().suites))))
-
-        suite_names = [ 's3', 's4' ]
-        ci.ch_add( ci.ch_handle(),suite_names)  # add suites s3,s4 using last handle
-        sync_local(ci)
-        assert len(list(ci.get_defs().suites)) == 4,"Expected 4 suites but found " + str(len(list((ci.get_defs().suites))))
-        
-    except RuntimeError as e:
-        print(str(e))
-        
-    ci.ch_drop_user("")  # drop all handle associated with current user
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
-
-            
-def test_client_ch_auto_add(ci):
-    print_test(ci,"test_client_ch_auto_add")
-    ci.delete_all()  
-    try: ci.ch_drop_user("")  # drop all handle associated with current user
-    except: pass              # Drop throws if no handle registered
-    
-    defs = Defs()
-    for i in range(1,7): defs.add_suite("s" + str(i))
-    ci.load(defs)
-    
-    try:
-        suite_names = [ 's1', 's2' , 's3']
-        ci.ch_register(True,suite_names)        # register interest in suites s1,s2,s3 and any new suites
-        ci.ch_auto_add( False )                 # disable adding newly created suites to last registered handle\n"
-        ci.ch_auto_add( True )                  # enable adding newly created suites to last registered handle\n"
-        ci.ch_auto_add( ci.ch_handle(), False ) # disable adding newly created suites to handle\n"
-        sync_local(ci)
-        assert len(list(ci.get_defs().suites)) == 3,"Expected 3 suites but found " + str(len(list((ci.get_defs().suites))))
-    except RuntimeError as e:
-        print(str(e))
-        
-    ci.ch_drop_user("")  # drop all handle associated with current user
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
-        
-           
-def test_client_ch_remove(ci):
-    print_test(ci,"test_client_ch_remove")
-    ci.delete_all()  
-    try: ci.ch_drop_user("")  # drop all handle associated with current user
-    except: pass              # Drop throws if no handle registered
-    
-    defs = Defs()
-    for i in range(1,7): defs.add_suite("s" + str(i))
-    ci.load(defs)
-    
-    try:
-        suite_names = [ 's1', 's2' , 's3']
-        ci.ch_register(True,suite_names)     # register interest in suites s1,s2,s3 and any new suites
-        sync_local(ci)
-        assert len(list(ci.get_defs().suites)) == 3,"Expected 3 suites but found " + str(len(list((ci.get_defs().suites))))
-
-        suite_names = [ 's1' ]
-        ci.ch_remove( suite_names )          # remove suites s1 from the last added handle\n"
-        sync_local(ci)
-        assert len(list(ci.get_defs().suites)) == 2,"Expected 2 suites but found " + str(len(list((ci.get_defs().suites))))
-        
-        suite_names = [ 's2' ]
-        ci.ch_remove( ci.ch_handle(), suite_names )  # remove suites s2 from the last added handle\n"
-        sync_local(ci)
-        assert len(list(ci.get_defs().suites)) == 1,"Expected 1 suites but found " + str(len(list((ci.get_defs().suites))))
-
-    except RuntimeError as e:
-        print(str(e))
-        
-    ci.ch_drop_user("")  # drop all handle associated with current user
-    sync_local(ci)
-    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
-           
-           
-def test_client_get_file(ci):
-    print_test(ci, "test_client_get_file")
-    ci.delete_all()     
-    defs = create_defs("test_client_get_file")  
-    
-    # Also test where user has specified his OWN ECF_JOBOUT (rare)
-    t2 = defs.find_abs_node("/test_client_get_file/f1/t2")
-    t2_jobout = Test.ecf_home(the_port) + "/test_client_get_file/t2.xx"
-    t2.add_variable("ECF_JOBOUT", t2_jobout)
-    
-    defs.generate_scripts()
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
- 
-    ci.restart_server()
-    ci.load(defs)           
-    ci.begin_all_suites()
-    
-    while 1:
-        if ci.news_local():
-            ci.sync_local()  # get the changes, synced with local defs
-            suite = ci.get_defs().find_suite("test_client_get_file")
-            assert suite is not None, "Expected to find suite"
-            if suite.get_state() == State.complete:
-                break
-        time.sleep(1)
-
-    try:
-        for task in ['/test_client_get_file/f1/t1', '/test_client_get_file/f1/t2']:
-
-            result_string = ci.get_file(task)
-            assert isinstance(result_string, str), \
-                f"Expected ci.get_file({task}) to return 'str'"
-            assert len(result_string) > 0, \
-                f"Expected ci.get_file({task}) to return something"
-
-            result_string = ci.get_file(task, as_bytes=False)
-            assert isinstance(result_string, str), \
-                f"Expected ci.get_file({task}, as_bytes=False) to return 'str'"
-            assert len(result_string) > 0, \
-                f"Expected ci.get_file({task}, as_bytes=False) to return something"
-
-            result_bytes = ci.get_file(task, as_bytes=True)
-            assert isinstance(result_bytes, bytes), \
-                f"Expected ci.get_file({task}, as_bytes=True) to return 'bytes'"
-            assert len(result_bytes) > 0, \
-                f"Expected ci.get_file({task}, as_bytes=True) to return something"
-
-            assert len(result_string) == len(result_bytes), \
-                f"Expected 'str' result and 'bytes' result to have the same length"
-
-            result_string = ci.get_file(task, max_lines='10')
-            assert isinstance(result_string, str), \
-                f"Expected ci.get_file({task}, max_lines='10') to return 'str'"
-            assert len(result_string) > 0, \
-                f"Expected ci.get_file({task}, max_lines='10') to return something"
-
-            result_string = ci.get_file(task, max_lines='10', as_bytes=False)
-            assert isinstance(result_string, str), \
-                f"Expected ci.get_file({task}, max_lines='10', as_bytes=False) to return 'str'"
-            assert len(result_string) > 0, \
-                f"Expected ci.get_file({task}, max_lines='10', as_bytes=False) to return something"
-
-            result_bytes = ci.get_file(task, max_lines='10', as_bytes=True)
-            assert isinstance(result_bytes, bytes), \
-                f"Expected ci.get_file({task}, max_lines='10', as_bytes=True) to return 'bytes'"
-            assert len(result_bytes) > 0, \
-                f"Expected ci.get_file({task}, max_lines='10', as_bytes=True) to return something"
-
-            assert len(result_string) == len(result_bytes), \
-                f"Expected 'str' result and 'bytes' result to have the same length"
-
-            for file_type in ['script', 'job', 'jobout', 'manual']:
-
-                result_string = ci.get_file(task, file_type)
-                assert isinstance(result_string, str), \
-                    f"Expected ci.get_file({task}, {file_type}) to return 'str'"
-                assert len(result_string) > 0, \
-                    f"Expected ci.get_file({task}, {file_type}) to return something"
-
-                result_string = ci.get_file(task, file_type, as_bytes=False)
-                assert isinstance(result_string, str), \
-                    f"Expected ci.get_file({task}, {file_type}, as_bytes=False) to return 'str'"
-                assert len(result_string) > 0, \
-                    f"Expected ci.get_file({task}, {file_type}, as_bytes=False) to return something"
-
-                result_bytes = ci.get_file(task, file_type, as_bytes=True)
-                assert isinstance(result_bytes, bytes), \
-                    f"Expected ci.get_file({task}, {file_type}, as_bytes=True) to return 'bytes'"
-                assert len(result_bytes) > 0, \
-                    f"Expected ci.get_file({task}, {file_type}, as_bytes=True) to return something"
-
-                assert len(result_string) == len(result_bytes), \
-                    f"Expected 'str' result and 'bytes' result to have the same length"
-
-                result_string = ci.get_file(task, file_type, '10')
-                assert isinstance(result_string, str), \
-                    f"Expected ci.get_file({task}, {file_type}, '10') to return 'str'"
-                assert len(result_string) > 0, \
-                    f"Expected ci.get_file({task}, {file_type}, '10') to return something"
-
-                result_string = ci.get_file(task, file_type, '10', as_bytes=False)
-                assert isinstance(result_string, str), \
-                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=False) to return 'str'"
-                assert len(result_string) > 0, \
-                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=False) to return something"
-
-                result_bytes = ci.get_file(task, file_type, '10', as_bytes=True)
-                assert isinstance(result_bytes, bytes), \
-                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=True) to return 'bytes'"
-                assert len(result_bytes) > 0, \
-                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=True) to return something"
-
-                assert len(result_string) == len(result_bytes), \
-                    f"Expected 'str' result and 'bytes' result to have the same length"
-
-        assert os.path.exists(t2_jobout), f"User specified ECF_JOBOUT file not created {t2_jobout}"
- 
-    except RuntimeError as e:
-        print(str(e))
-
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_get_file"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)  
-
-    
-def test_client_plug(ci):
-    pass
-           
-def test_client_alter_sort(ci):
-    print_test(ci,"test_client_alter_sort")
-    ci.delete_all()   
-    
-    defs = create_defs("test_client_alter_sort")
-    t1 = "/test_client_alter_sort/f1/t1"
-    task_t1 = defs.find_abs_node(t1)
-    task_t1.add_variable("z","value").add_variable("y","value").add_variable("x","value")
-    task_t1.add_event("z").add_event("y").add_event("x")
-    task_t1.add_meter("z",0,100,100).add_meter("y",0,100,100).add_meter("x",0,100,100)
-    task_t1.add_label("z","name").add_label("y","name").add_label("x","name")
-    task_t1.add_limit("z",10).add_limit("y",10).add_limit("x",10)
-    
-    ci.load(defs)   
-    
-    ci.sort_attributes(t1,"variable")
-    ci.sort_attributes(t1,"event")
-    ci.sort_attributes(t1,"meter")
-    ci.sort_attributes(t1,"label")
-    ci.sort_attributes(t1,"limit")
-
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.variables)) == 3 ,"Expected 3 variable :\n" + str(ci.get_defs())
-    assert len(list(task_t1.events)) == 3 ,"Expected 3 events :\n" + str(ci.get_defs())
-    assert len(list(task_t1.meters)) == 3 ,"Expected 3 meters :\n" + str(ci.get_defs())
-    assert len(list(task_t1.labels)) == 3 ,"Expected 3 labels :\n" + str(ci.get_defs())
-    assert len(list(task_t1.limits)) == 3 ,"Expected 3 limits :\n" + str(ci.get_defs())
-    expected = ['x','y','z']; vactual = []; eactual = []; mactual = []; lactual = []; liactual = [];
-    for v in task_t1.variables: vactual.append(v.name())
-    for v in task_t1.events: eactual.append(v.name())
-    for v in task_t1.meters: mactual.append(v.name())
-    for v in task_t1.labels: lactual.append(v.name())
-    for v in task_t1.limits: liactual.append(v.name())
-    assert expected == vactual, "variable Attributes not sorted, expected:" + str(expected) + " but found:" + str(vactual)
-    assert expected == eactual, "event Attributes not sorted, expected:" + str(expected) + " but found:" + str(eactual)
-    assert expected == mactual, "meter Attributes not sorted, expected:" + str(expected) + " but found:" + str(mactual)
-    assert expected == lactual, "label Attributes not sorted, expected:" + str(expected) + " but found:" + str(lactual)
-    assert expected == liactual,"limit Attributes not sorted, expected:" + str(expected) + " but found:" + str(liactual)
-
-def test_client_alter_sort_defs(ci):
-    print_test(ci,"test_client_alter_sort_defs")
-    ci.delete_all()   
-    
-    defs = create_defs("test_client_alter_sort_defs")
-    t1 = "/test_client_alter_sort_defs/f1/t1"
-    task_t1 = defs.find_abs_node(t1)
-    task_t1.add_variable("z","value").add_variable("y","value").add_variable("x","value")
-    task_t1.add_event("z").add_event("y").add_event("x")
-    task_t1.add_meter("z",0,100,100).add_meter("y",0,100,100).add_meter("x",0,100,100)
-    task_t1.add_label("z","name").add_label("y","name").add_label("x","name")
-    task_t1.add_limit("z",10).add_limit("y",10).add_limit("x",10)
-    
-    ci.load(defs)   
-    
-    ci.sort_attributes("/","variable",True)
-    ci.sort_attributes("/","event",True)
-    ci.sort_attributes("/","meter",True)
-    ci.sort_attributes("/","label",True)
-    ci.sort_attributes("/","limit",True)
-
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.variables)) == 3 ,"Expected 3 variable :\n" + str(ci.get_defs())
-    assert len(list(task_t1.events)) == 3 ,"Expected 3 events :\n" + str(ci.get_defs())
-    assert len(list(task_t1.meters)) == 3 ,"Expected 3 meters :\n" + str(ci.get_defs())
-    assert len(list(task_t1.labels)) == 3 ,"Expected 3 labels :\n" + str(ci.get_defs())
-    assert len(list(task_t1.limits)) == 3 ,"Expected 3 limits :\n" + str(ci.get_defs())
-    expected = ['x','y','z']; vactual = []; eactual = []; mactual = []; lactual = []; liactual = [];
-    for v in task_t1.variables: vactual.append(v.name())
-    for v in task_t1.events: eactual.append(v.name())
-    for v in task_t1.meters: mactual.append(v.name())
-    for v in task_t1.labels: lactual.append(v.name())
-    for v in task_t1.limits: liactual.append(v.name())
-    assert expected == vactual, "variable Attributes not sorted, expected:" + str(expected) + " but found:" + str(vactual)
-    assert expected == eactual, "event Attributes not sorted, expected:" + str(expected) + " but found:" + str(eactual)
-    assert expected == mactual, "meter Attributes not sorted, expected:" + str(expected) + " but found:" + str(mactual)
-    assert expected == lactual, "label Attributes not sorted, expected:" + str(expected) + " but found:" + str(lactual)
-    assert expected == liactual,"limit Attributes not sorted, expected:" + str(expected) + " but found:" + str(liactual)
- 
-           
-def test_client_alter_add(ci):
-    print_test(ci,"test_client_alter_add")
-    ci.delete_all()     
-    ci.load(create_defs("test_client_alter_add"))   
-
-    t1 = "/test_client_alter_add/f1/t1"
-    ci.alter(t1,"add","variable","var","var_name")
-    ci.alter(t1,"add","variable","var2","--")
-    ci.alter(t1,"add","variable","var3","--fred")
-    ci.alter(t1,"add","variable","var4"," --fred ")
-    ci.alter(t1,"add","variable","var5","--fred --jake")
-    ci.alter(t1,"add","variable","var6"," --fred --jake ")
-    ci.alter(t1,"add","variable","var7","")
-    ci.alter(t1,"add","time","+00:30")
-    ci.alter(t1,"add","time","01:30")
-    ci.alter(t1,"add","time","01:30 20:00 00:30")
-    ci.alter(t1,"add","today","+00:30")
-    ci.alter(t1,"add","today","01:30")
-    ci.alter(t1,"add","today","01:30 20:00 00:30")
-    ci.alter(t1,"add","date","01.01.2001")
-    ci.alter(t1,"add","date","*.01.2001")
-    ci.alter(t1,"add","date","*.*.2001")
-    ci.alter(t1,"add","date","*.*.*")
-    ci.alter(t1,"add","day","sunday")
-    ci.alter(t1,"add","day","monday")
-    ci.alter(t1,"add","day","tuesday")
-    ci.alter(t1,"add","day","wednesday")
-    ci.alter(t1,"add","day","thursday")
-    ci.alter(t1,"add","day","friday")
-    ci.alter(t1,"add","day","saturday")
-    ci.alter(t1,"add","late","late -s +00:15 -a 20:00 -c +02:00")
-    ci.alter(t1,"add","label","label_name","label_value")
-    ci.alter(t1,"add","label","label_name2","/a/label/with/path/values")
-
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.variables)) == 7 ,"Expected 7 variable :\n" + str(ci.get_defs())
-    assert len(list(task_t1.times)) == 3 ,"Expected 3 time :\n" + str(ci.get_defs())
-    assert len(list(task_t1.todays)) == 3 ,"Expected 3 today's :\n" + str(ci.get_defs())
-    assert len(list(task_t1.dates)) == 4 ,"Expected 4 dates :\n" + str(ci.get_defs())
-    assert len(list(task_t1.days)) == 7 ,"Expected 7 days :\n" + str(ci.get_defs())
-    assert len(list(task_t1.labels)) == 2 ,"Expected 2 labels :\n" + str(ci.get_defs())
-    assert str(task_t1.get_late()) == "late -s +00:15 -a 20:00 -c +02:00", "Expected late 'late -s +00:15 -a 20:00 -c +02:00'" + str(ci.get_defs())
-           
-
-def test_client_alter_delete(ci):
-    print_test(ci,"test_client_alter_delete")
-    ci.delete_all() 
-    defs = create_defs("test_client_alter_delete")  
-    suite_with_limits = defs.add_suite("suite_with_limits")
-    suite_with_limits.add_limit("limitX",10)
-    suite_with_limits_X = defs.add_suite("suite_with_limits_X")
-    suite_with_limits_X.add_limit("limitX",10)
- 
-    t1 = "/test_client_alter_delete/f1/t1"
-    task_t1 = defs.find_abs_node(t1)
-    task_t1.add_variable("var","value")
-    task_t1.add_variable("var1","value")
-    task_t1.add_time("00:30")
-    task_t1.add_time("00:31")
-    task_t1.add_today("00:30")
-    task_t1.add_today("00:31")
-    task_t1.add_date(1,1,2001)
-    task_t1.add_date(1,1,2002)
-    task_t1.add_day("sunday")
-    task_t1.add_day("monday")
-    cron = Cron()
-    cron.set_week_days( [0,1,2,3,4,5,6] )
-    cron.set_time_series( "+00:30" )
-    task_t1.add_cron(cron)
-    task_t1.add_cron(cron)
-    task_t1.add_event("event")
-    task_t1.add_event("event1")
-    task_t1.add_meter("meter",0,100,100)
-    task_t1.add_meter("meter1",0,100,100)
-    task_t1.add_label("label","name")
-    task_t1.add_label("label1","name")
-    task_t1.add_limit("limit",10)
-    task_t1.add_limit("limit1",10)
-    task_t1.add_inlimit( "limit",t1,2)
-    task_t1.add_inlimit( "limit1",t1,2)
-    task_t1.add_inlimit( "limitX","/suite_with_limits",2)
-    task_t1.add_inlimit( "limitX","/suite_with_limits_X",2)
-    task_t1.add_trigger( "t2 == active" )
-    task_t1.add_complete( "t2 == complete" )
-    
-    assert task_t1.get_late() is None, "expected no late" 
-    late = Late()
-    late.submitted(20, 10)
-    late.active(20, 10)
-    late.complete(20, 10, True)
-    task_t1.add_late(late)
-    assert task_t1.get_late() is not None, "expected late" 
-    
-            
-    t2 = "/test_client_alter_delete/f1/t2"
-    task_t2 = defs.find_abs_node(t2)
-    task_t2.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
-    
-    #print(defs)
-    ci.load(defs)   
-
-    ci.alter(t1,"delete","variable","var")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.variables)) == 1 ,"Expected 1 variable :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","variable")  # delete all veriables
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.variables)) == 0 ,"Expected 0 variable :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","time","00:30")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.times)) == 1 ,"Expected 1 time :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","time")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.times)) == 0 ,"Expected 0 time :\n" + str(ci.get_defs())
-    
-    ci.alter(t1,"delete","today","00:30")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.todays)) == 1 ,"Expected 1 today :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","today")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.todays)) == 0 ,"Expected 0 today :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","date","01.01.2001")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.dates)) == 1 ,"Expected 1 date :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","date")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.dates)) == 0 ,"Expected 0 date :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","day","sunday")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.days)) == 1 ,"Expected 1 day :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","day")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.days)) == 0 ,"Expected 0 day :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","event","event")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.events)) == 1 ,"Expected 1 event :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","event")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.events)) == 0 ,"Expected 0 event :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","meter","meter")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.meters)) == 1 ,"Expected 1 meter :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","meter")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.meters)) == 0 ,"Expected 0 meter :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","label","label")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.labels)) == 1 ,"Expected 1 label :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","label")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.labels)) == 0 ,"Expected 0 label :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","inlimit","limit")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.inlimits)) == 3 ,"Expected 3 inlimit :\n" + str(ci.get_defs())
-    
-    ci.alter(t1,"delete","inlimit","/suite_with_limits:limitX")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.inlimits)) == 2 ,"Expected 2 inlimit :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","inlimit","/suite_with_limits_X:limitX")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.inlimits)) == 1 ,"Expected 1 inlimit :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","inlimit")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.inlimits)) == 0 ,"Expected 0 inlimit :\n" + str(ci.get_defs())
-
-
-    ci.alter(t1,"delete","limit","limit")
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.limits)) == 1 ,"Expected 1 limit :\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","limit")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.limits)) == 0 ,"Expected 0 limit :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","cron")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.crons)) == 0 ,"Expected 0 crons :\n" + str(ci.get_defs())
-
-    ci.alter(t1,"delete","late")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert task_t1.get_late() is None, "expected no late after delete" 
-
-
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert task_t1.get_trigger() is not None, "Expected trigger:\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","trigger")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert task_t1.get_trigger() is None, "Expected trigger to be deleted:\n" + str(ci.get_defs())
-
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert task_t1.get_complete() is not None, "Expected complete:\n" + str(ci.get_defs())
-    ci.alter(t1,"delete","complete")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert task_t1.get_complete() is None, "Expected complete to be deleted:\n" + str(ci.get_defs())
-
-    ci.alter(t2,"delete","repeat")   
-    sync_local(ci)
-    task_t2 = ci.get_defs().find_abs_node(t2)
-    repeat = task_t2.get_repeat()
-    assert repeat.empty(), "Expected repeat to be deleted:\n" + str(ci.get_defs())
-
-
-def test_client_alter_change(ci):
-    print_test(ci,"test_client_alter_change")
-    ci.delete_all() 
-    defs =create_defs("test_client_alter_change")   
-    t1 = "/test_client_alter_change/f1/t1"
-    repeat_date_path = "/test_client_alter_change/f1/repeat_date"
-    repeat_datetime_path = "/test_client_alter_change/f1/repeat_datetime"
-    
-    task_t1 = defs.find_abs_node(t1)
-    task_t1.add_variable("var","value")
-    task_t1.add_variable("var1","value")
-    task_t1.add_event("event")
-    task_t1.add_event("event1")
-    task_t1.add_meter("meter",0,100,100)
-    task_t1.add_meter("meter1",0,100,100)
-    task_t1.add_label("label","name")
-    task_t1.add_label("label1","name1")
-    task_t1.add_limit("limit",10)
-    task_t1.add_limit("limit1",10)
-    task_t1.add_inlimit( "limit",t1,2)
-    task_t1.add_inlimit( "limit1",t1,2)
-    task_t1.add_trigger( "t2 == active" )
-    task_t1.add_complete( "t2 == complete" )
-    task_t1.add_time("00:31")
-    task_t1.add_today("00:30")
-
-    late = Late()
-    late.submitted(20, 10)
-    late.active(20, 10)
-    late.complete(20, 10, True)
-    task_t1.add_late(late)
-
-            
-    f1 = defs.find_abs_node("/test_client_alter_change/f1")
-    # Add a new Repeat (based on date)
-    repeat_date = f1.add_task("repeat_date")
-    repeat_date.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
-    # Add a new Repeat (based on date+time)
-    repeat_datetime = f1.add_task("repeat_datetime")
-    repeat_datetime.add_repeat(RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00"))
-           
-    ci.load(defs)   
-
-    ci.alter(t1,"change","time","00:31","10:10")   
-    ci.alter(t1,"change","today","00:30","10:10")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    assert len(list(task_t1.times)) == 1 ,"Expected 1 time :\n" + str(ci.get_defs())
-    assert len(list(task_t1.todays)) == 1 ,"Expected 1 time :\n" + str(ci.get_defs())
-    for t in task_t1.times:
-        assert str(t) == "time 10:10"," expected 'time 10:10' but found:\n" + str(t)
-    for t in task_t1.todays:
-        assert str(t) == "today 10:10"," expected 'today 10:10' but found:\n" + str(t)
-
-
-    ci.alter(t1,"change","late","-s +10:00")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    variable = task_t1.get_late()
-    assert str(task_t1.get_late()) == "late -s +10:00", "Expected alter of late to be 'late -s +10:00' but found " + str(task_t1.get_late())
-
-
-    ci.alter(t1,"change","variable","var","changed_var")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    variable = task_t1.find_variable("var")
-    assert variable.value() == "changed_var", "Expected alter of variable to be 'change_var' but found " + variable.value()
-    res = ci.query('variable',task_t1.get_abs_node_path(),"var")
-    assert res == 'changed_var',"Expected alter of variable to be 'change_var' but found " + res
-
-
-    ci.alter(t1,"change","variable","var","--")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    variable = task_t1.find_variable("var")
-    assert variable.value() == "--", "Expected alter of variable to be '--' but found " + variable.value()
-    res = ci.query('variable',task_t1.get_abs_node_path(),"var")
-    assert res == '--',"Expected alter of variable to be '--' but found " + res
-    
-    ci.alter(t1,"change","variable","var","--fred")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    variable = task_t1.find_variable("var")
-    assert variable.value() == "--fred", "Expected alter of variable to be '--fred' but found " + variable.value()
-    
-    ci.alter(t1,"change","variable","var","--fred --bill")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    variable = task_t1.find_variable("var")
-    assert variable.value() == "--fred --bill", "Expected alter of variable to be '--fred --bill' but found " + variable.value()
-
-    ci.alter(t1,"change","meter","meter","10")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    meter = task_t1.find_meter("meter")
-    assert meter.value() == 10, "Expected alter of meter to be 10 but found " + str(meter.value())
-    res = ci.query('meter',task_t1.get_abs_node_path(),"meter")
-    assert res == '10',"Expected alter of meter to be 10 but found " + res
-
-    ci.alter(t1,"change","event","event","set")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    event = task_t1.find_event("event")
-    assert event.value() == True, "Expected alter of event to be set but found " + str(event.value())
-    res = ci.query('event',task_t1.get_abs_node_path(),"event")
-    assert res == 'set',"Expected alter of event to be 'set' but found " + res
-
-    ci.alter(t1,"change","trigger","t2 == aborted")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    trigger = task_t1.get_trigger()
-    assert trigger.get_expression() == "t2 == aborted", "Expected alter of trigger to be 't2 == aborted' but found " + trigger.get_expression()
-    res = ci.query('trigger',task_t1.get_abs_node_path(),"t2 == aborted")
-    assert res == 'false',"Expected evaluation of trigger to fail, but found: " + res
-
-    ci.alter(t1,"change","trigger","/test_client_alter_change/f1/t2 == complete")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    trigger = task_t1.get_trigger()
-    assert trigger.get_expression() == "/test_client_alter_change/f1/t2 == complete", "Expected alter of trigger to be '/test_client_alter_change/f1/t2 == complete' but found " + trigger.get_expression()
-
-    ci.alter(t1,"change","complete","t2 == aborted")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    complete = task_t1.get_complete()
-    assert complete.get_expression() == "t2 == aborted", "Expected alter of complete to be 't2 == aborted' but found " + complete.get_expression()
-
-    ci.alter(t1,"change","complete","/test_client_alter_change/f1/t2 == active")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    complete = task_t1.get_complete()
-    assert complete.get_expression() == "/test_client_alter_change/f1/t2 == active", "Expected alter of complete to be '/test_client_alter_change/f1/t2 == active' but found " + complete.get_expression()
-
-    ci.alter(t1,"change","limit_max","limit", "2")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    limit = task_t1.find_limit("limit")
-    assert limit is not None, "Expected to find limit"
-    assert limit.limit() == 2, "Expected alter of limit_max to be 2 but found " + str(limit.limit())
-
-    ci.alter(t1,"change","limit_value","limit", "2")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    limit = task_t1.find_limit("limit")
-    assert limit is not None, "Expected to find limit"
-    assert limit.value() == 2, "Expected alter of limit_value to be 2 but found " + str(limit.value())
-
-    
-    ci.alter(t1,"change","label","label","new-value")   
-    sync_local(ci)
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    label = task_t1.find_label("label")
-    assert label.new_value() == "new-value", "Expected alter of label to be 'new-value' but found " + label.new_value()
-
-    ci.alter(repeat_date_path,"change","repeat","20100113")
-    sync_local(ci)
-    task = ci.get_defs().find_abs_node(repeat_date_path)
-    repeat = task.get_repeat()
-    assert repeat.value() == 20100113, "Expected alter of repeat to be 20100113 but found " + str(repeat.value())
-    res = ci.query('variable',task.get_abs_node_path(),repeat.name())
-    assert res == "20100113", "Expected alter of repeat to be 20100113 but found " + res
-
-    ci.alter(repeat_datetime_path, "change", "repeat", "20100113T000000")
-    sync_local(ci)
-    task = ci.get_defs().find_abs_node(repeat_datetime_path)
-    repeat = task.get_repeat()
-    assert repeat.value() == 1263340800, "Expected alter of repeat to be 1263340800 (i.e. seconds between 19700101T000000 and 20100113T000000) but found " + str(repeat.value())
-    res = ci.query('variable', task.get_abs_node_path(), repeat.name())
-    assert res == "20100113T000000", "Expected alter of repeat to be 20100113T000000 but found " + res
-
-def test_client_alter_flag(ci):
-    print_test(ci,"test_client_alter_flag")
-    ci.delete_all() 
-    defs =create_defs("test_client_alter_flag")   
-    t1 = "/test_client_alter_flag/f1/t1"
-     
-    task_t1 = defs.find_abs_node(t1)
-           
-    ci.load(defs)   
-
-    flag = Flag()
-    flag_list = flag.list() # flag_list is of type FlagTypeVec
-    for flg in flag_list: 
-        ci.alter(t1,"set_flag",flag.type_to_string(flg) )   
-        sync_local(ci)
-        task_t1 = ci.get_defs().find_abs_node(t1)
-        task_flag = task_t1.get_flag()
-        assert task_flag.is_set( flg ),"expected flag %r to be set" % task_flag.type_to_string(flg)
-
-        # alter itself causes the flag message to be set, and preserved
-        if flg == FlagType.message: continue 
-        
-        ci.alter(t1,"clear_flag",flag.type_to_string(flg) )   
-        sync_local(ci)
-        task_t1 = ci.get_defs().find_abs_node(t1)
-        task_flag = task_t1.get_flag()
-        assert not task_flag.is_set( flg ),"expected flag %r NOT to be set" % task_flag.type_to_string(flg)
-
-
-    # ISSUES:
-    # o Currently we can only change clock attr if we have one.
-    # o Even when we have a clock attr, it only makes sense to apply clock attr changes
-    #   before begin(), i.e how do we apply change in gain after begin ??
-    
-    #" change clock-type name        # The name must be one of 'hybrid' or 'real'.\n"
-    #       " change clock-gain name        # The gain must be convertible to an integer.\n"
-    #        " change label name value       # sets the label\n"
-    #        " change repeat value           # If the repeat is a date, then the value must be a valid YMD ( ie. yyyymmdd)\n"
-    #        "                               # and be convertible to an integer, additionally the value must be in range\n"
-    #        "                               # of the repeat start and end dates. Like wise for repeat integer. For repeat\n"
-    #         "                               # string and enum,  the name must either be an integer, that is a valid index or\n"
-    #         "                               # if it is a string, it must correspond to one of enum's or strings list\n"
-
-
-def test_client_force(ci):
-    print_test(ci,"test_client_force")
-    ci.delete_all()     
-    defs = create_defs("test_client_force") 
-     
-    path_list = [ "/test_client_force/f1/t1", "/test_client_force/f1/t2" ]       
-    t1 = path_list[0]      
-    for path in path_list:
-        task = defs.find_abs_node(path)
-        assert task is not None, "Expected to find task at path " + path
-        task.add_event("event")
-
-    ci.load(defs)   
-    
-    state_list = [ State.unknown, State.active, State.complete, State.queued, State.submitted, State.aborted ]
-    for state in state_list:
-        ci.force_state(t1,state) 
-        sync_local(ci)
-        task = ci.get_defs().find_abs_node(t1)
-        assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())      
-    for state in state_list:
-        ci.force_state( path_list,state) 
-        sync_local(ci)
-        for path in path_list:
-            task = ci.get_defs().find_abs_node(path)
-            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())     
- 
-    for state in state_list:
-        ci.force_state_recursive("/test_client_force",state) 
-        sync_local(ci)
-        task = ci.get_defs().find_abs_node(t1)
-        assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())
-    suite_paths = [ "/test_client_force"]
-    for state in state_list:
-        ci.force_state_recursive( suite_paths,state) 
-        sync_local(ci)
-        task = ci.get_defs().find_abs_node(t1)
-        assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())           
-    
-    event_states = [ "set", "clear" ]
-    for ev_state in event_states:
-        for path in path_list:
-            ci.force_event(path + ":event" , ev_state)
-            sync_local(ci)
-            task = ci.get_defs().find_abs_node(path)
-            event_fnd = False
-            for event in task.events:
-                event_fnd = True
-                if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
-                else:                   assert event.value() == False ," Expected event value to be clear"
-            assert event_fnd == True," Expected event to be found"
-
-    event_path_list = [ "/test_client_force/f1/t1:event", "/test_client_force/f1/t2:event" ]       
-    event_states = [ "set", "clear" ]
-    for ev_state in event_states:
-        ci.force_event( event_path_list , ev_state)
-        sync_local(ci)
-        for path in path_list:
-            task = ci.get_defs().find_abs_node(path)
-            event_fnd = False
-            for event in task.events:
-                event_fnd = True
-                if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
-                else:                   assert event.value() == False ," Expected event value to be clear"
-            assert event_fnd == True," Expected event to be found"
-
-      
-
-def test_client_replace(ci,on_disk):
-    print_test(ci,"test_client_replace client_defs on disk = " + str(on_disk))
-    # Create and load the following defs
-    # s1
-    #   f1
-    #     t1
-    #     t2
-    ci.delete_all()     
-    ci.load(create_defs("s1"))  
-    
-    #===============================================================================
-    # Example of using replace to ADD a *NEW* node hierarchy to an existing suite
-    # we should end up with:
-    # s1
-    #   f1
-    #     t1
-    #     t2
-    #   f2
-    #     t1
-    #     t2
-    test_client_replace_def_file = "test_client_replace_" + str(os.getpid()) + ".def"
-    client_def = create_defs("s1")
-    client_def.find_suite("s1").add_family("f2").add_task("t1")
-    if on_disk:
-        client_def.save_as_defs(test_client_replace_def_file)
-        client_def = test_client_replace_def_file
-    
-    ci.replace("/s1/f2",client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
-    ci.get_server_defs()
-    assert len(list(ci.get_defs().suites)) == 1 ,"Expected 1 suites:\n" + str(ci.get_defs())
-    assert ci.get_defs().find_abs_node("/s1/f2/t1") is not None, "Expected to find task /s1/f2/t1\n" + str(ci.get_defs())
-
-
-    # Example of using replace to *REMOVE* node hierarchy to an existing suite, could have used delete
-    assert ci.get_defs().find_abs_node("/s1/f1/t1") is not None, "Expected to find task /s1/f1/t1\n" + str(ci.get_defs())
-    assert ci.get_defs().find_abs_node("/s1/f2/t1") is not None, "Expected to find task /s1/f2/t1\n" + str(ci.get_defs())
-    client_def = Defs()
-    client_def.add_suite("s1")    # should only have the suite
-    if on_disk:
-        client_def.save_as_defs(test_client_replace_def_file)
-        client_def = test_client_replace_def_file
-
-    ci.replace("/s1",client_def)   
-    ci.get_server_defs()
-    assert len(list(ci.get_defs().suites)) == 1 ,"Expected 1 suites:\n" + str(ci.get_defs())
-    assert ci.get_defs().find_abs_node("/s1/f1/t1") is None, "Expected NOT to find task /s1/f1/t1\n" + str(ci.get_defs())
-    assert ci.get_defs().find_abs_node("/s1/f2/t1") is None, "Expected NOT to find task /s1/f2/t1\n" + str(ci.get_defs())
-
-
-    #===============================================================================
-    # Example of using replace to add a *NEW* suite
-    client_def = Defs();
-    client_def.add_suite("s2")
-    if on_disk:
-        client_def.save_as_defs(test_client_replace_def_file)
-        client_def = test_client_replace_def_file
-
-    ci.replace("/s2",client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
-    ci.get_server_defs()
-    assert len(list(ci.get_defs().suites)) == 2 ," Expected two suites:\n" + str(ci.get_defs())
-           
-    # replace added suite s2 with a new s2 which has a task, 
-    # s2 must exist on the client defs
-    client_def = Defs();
-    client_def.add_suite("s2").add_task("t1")
-    if on_disk:
-        client_def.save_as_defs(test_client_replace_def_file)
-        client_def = test_client_replace_def_file
-
-    ci.replace("/s2",client_def) 
-        
-    ci.get_server_defs()
-    assert len(list(ci.get_defs().suites)) == 2 ," Expected two suites:\n" + str(ci.get_defs())
-    assert ci.get_defs().find_abs_node("/s2/t1") is not None, "Expected to find task /s2/t1\n" + str(ci.get_defs())
-    if on_disk:
-        os.remove(test_client_replace_def_file)
-
-
-def test_node_replace(ci):
-    print_test(ci,"test_node_replace")
-    PrintStyle.set_style( Style.MIGRATE ) # show node state 
-    ci.delete_all()     
-    defs = Defs() + (Suite("s1") + Family('f1').add(Task('t1'),Task('t2')))
-    ci.load(defs)  
- 
-    # We should have 4 nodes
-    sync_local(ci)
-    ci_defs = ci.get_defs()
-    node_vec = ci_defs.get_all_nodes()
-    assert len(list(node_vec)) == 4,"Expected two 4 nodes: \n" + str(ci.get_defs())
-             
-    # replace each node, add variable first, then check, it was added
-    for node in node_vec:
-        node += Edit(var="XX", var2="xx")
-        node.replace_on_server(ci) # default is to suspend server node first, so replaced node is also suspended
-                
-        sync_local(ci)
-        replace_node = ci.get_defs().find_abs_node(node.get_abs_node_path())
-        assert len(list(replace_node.variables)) == 2,"Expected two 2 variable: \n" + str(replace_node)+ "\n" + str(ci.get_defs())
-        assert replace_node.get_dstate() == DState.suspended,"Expected node to be suspended:\n" + str(replace_node) + "\n" + str(ci.get_defs())
-
-    # resume nodes, test that when False passed in we do not suspend the replaced node
-    for node in node_vec:
-        ci.resume(node.get_abs_node_path())
-        sync_local(ci)
-        replace_node = ci.get_defs().find_abs_node(node.get_abs_node_path())
-        assert replace_node.get_dstate() != DState.suspended,"Expected node not to suspended:\n" +  str(replace_node)
-        
-        replace_node += Meter("meter",0,100)
-        
-        # cant use node i.e this is only client side, and is still suspended
-        # When we replace is server the client defs is sent to server. hence node would be suspended
-        replace_node.replace_on_server(ci,suspend_node_first=False)
-        sync_local(ci)
-
-        replace_node = ci.get_defs().find_abs_node(node.get_abs_node_path())
-        assert len(list(replace_node.meters)) == 1,"Expected 1 meter: \n" + str(replace_node)
-        assert len(list(replace_node.variables)) == 2,"Expected two 2 variable: \n" + str(replace_node)
-        assert replace_node.get_dstate() != DState.suspended,"Expected node not to suspended:\n" +  str(replace_node)
-
-    # replace the suite
-    defs = Defs() + Suite("s1")
-    host_port = ci.get_host() + ':' + ci.get_port()
-    defs.s1.replace_on_server(host_port)
-  
-    ci.get_server_defs()
-    assert len(list(ci.get_defs().s1)) == 0,"Expected 0 family: \n" + str(ci.get_defs())
-    assert ci.get_defs().s1.get_dstate() == DState.suspended,"Expected node to be suspended:\n" +  str(ci.get_defs())
-
-
-def test_client_kill(ci):
-    pass
-        
-def test_client_status(ci):
-    pass
-           
-def test_client_order(ci):
-    pass
-           
-def test_client_group(ci):
-    pass
-           
-def test_client_suspend(ci):
-    print_test(ci,"test_client_suspend")
-    ci.delete_all()     
-    defs = create_defs("test_client_suspend")  
-    suite = defs.find_suite("test_client_suspend")
-    suite.add_variable("ECF_DUMMY_TASK","")
-        
-    ci.load(defs)  
-    ci.begin_all_suites()  
-    
-    ci.suspend("/test_client_suspend")  
-           
-    sync_local(ci);
-    suite = ci.get_defs().find_suite("test_client_suspend")
-    assert suite.is_suspended(), "Expected to find suite suspended"
-    
-    assert ci.query('dstate',suite.get_abs_node_path()) == "suspended", "Expected to find suite dstate suspended but found: " + res
-    assert ci.query('state',suite.get_abs_node_path()) == "queued", "Expected to find suite state queued but found: " + res
-
-
-def test_client_suspend_multiple_paths(ci):
-    print_test(ci,"test_client_suspend_multiple_paths")
-    ci.delete_all()     
-    defs = create_defs("test_client_suspend_multiple_paths")  
-    suite = defs.find_suite("test_client_suspend_multiple_paths")
-    suite.add_variable("ECF_DUMMY_TASK","")
-    
-    ci.load(defs)  
-    ci.begin_all_suites()  
-    
-    path_list = [ "/test_client_suspend_multiple_paths/f1/t1", "/test_client_suspend_multiple_paths/f1/t2" ]
-    ci.suspend( path_list )  
-           
-    sync_local(ci);
-    task_t1 = ci.get_defs().find_abs_node("/test_client_suspend_multiple_paths/f1/t1")
-    task_t2 = ci.get_defs().find_abs_node("/test_client_suspend_multiple_paths/f1/t2")
-    assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
-    assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
-            
-def test_client_resume(ci):
-    print_test(ci,"test_client_resume")
-    ci.delete_all()     
-    defs = create_defs("test_client_resume")  
-    suite = defs.find_suite("test_client_resume")
-    suite.add_variable("ECF_DUMMY_TASK","")
-        
-    ci.load(defs)  
-    ci.begin_all_suites()  
-    
-    ci.suspend("/test_client_resume")  
-    sync_local(ci);
-    suite = ci.get_defs().find_suite("test_client_resume")
-    assert suite.is_suspended(), "Expected to find suite suspended"
-    
-    ci.resume("/test_client_resume")  
-    sync_local(ci);
-    suite = ci.get_defs().find_suite("test_client_resume")
-    assert suite.is_suspended() == False, "Expected to find suite resumed"
-
-def test_client_resume_multiple_paths(ci):
-    print_test(ci,"test_client_resume_multiple_paths")
-    ci.delete_all()     
-    defs = create_defs("test_client_resume_multiple_paths")  
-    suite = defs.find_suite("test_client_resume_multiple_paths")
-    suite.add_variable("ECF_DUMMY_TASK","")
-        
-    ci.load(defs)  
-    ci.begin_all_suites()  
-    
-    path_list = [ "/test_client_resume_multiple_paths/f1/t1", "/test_client_resume_multiple_paths/f1/t2" ]
-    ci.suspend( path_list )  
-  
-    sync_local(ci);
-    task_t1 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t1")
-    task_t2 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t2")
-    assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
-    assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
-
-    ci.resume( path_list )  
-    sync_local(ci);
-    task_t1 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t1")
-    task_t2 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t2")
-    assert task_t1.is_suspended() == False, "Expected to find task t1 to be resumed"
-    assert task_t2.is_suspended() == False, "Expected to find task t2 to be resumed"
- 
-          
-def test_client_delete_node(ci): 
-    print_test(ci,"test_client_delete_node")
-    ci.delete_all() 
-    defs = create_defs("test_client_delete_node")
-    
-    task_vec = defs.get_all_tasks();
-    assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
-
-    ci.load(defs)  
-    sync_local(ci);
-    for task in task_vec:
-        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
-        assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(ci.get_defs()) 
-
-    for task in task_vec:
-        ci.delete(task.get_abs_node_path())
-
-    sync_local(ci);
-    for task in task_vec:
-        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
-        assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(ci.get_defs())   
-    
-def test_client_delete_node_multiple_paths(ci): 
-    print_test(ci,"test_client_delete_node_multiple_paths")
-    ci.delete_all() 
-    defs = create_defs("test_client_delete_node_multiple_paths")
-    
-    task_vec = defs.get_all_tasks();
-    assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
-
-    paths = []
-    for task in task_vec:
-        paths.append(task.get_abs_node_path()) 
- 
-    ci.load(defs)  
-    
-    sync_local(ci);
-    for task in task_vec:
-        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
-        assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(ci.get_defs()) 
-
-    ci.delete(paths)
-
-    sync_local(ci);
-    for task in task_vec:
-        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
-        assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(ci.get_defs())   
-    
-def test_client_archive_and_restore(ci):
-    suite_name = "test_client_archive_and_restore"
-    print_test(ci,suite_name)
-    ci.delete_all()     
-    defs = create_defs(suite_name)  
-    suite = defs.find_suite(suite_name)
-    suite_path = suite.get_abs_node_path();
-     
-    ci.restart_server()
-    ci.load(defs)  
-     
-    sync_local(ci) # get the changes, synced with local defs
-    node_vec = ci.get_defs().get_all_nodes()
-    assert len(node_vec) == 4, "Expected 4 nodes, but found " + str(len(node_vec))
- 
-    ci.archive(suite_path)
-    sync_local(ci) # get the changes, synced with local defs
-    node_vec = ci.get_defs().get_all_nodes()
-    assert len(node_vec) == 1, "Expected 1 nodes, but found " + str(len(node_vec))
-    the_suite = ci.get_defs().find_suite(suite_name)
-    assert the_suite is not None, "Expected to find suite"
-    assert the_suite.get_flag().is_set(FlagType.archived), " expected archive flag to be set"
- 
-    ci.restore(suite_path)
-    sync_local(ci) # get the changes, synced with local defs
-    node_vec = ci.get_defs().get_all_nodes()
-    assert len(node_vec) == 4, "Expected 4 nodes, but found " + str(len(node_vec))
-    the_restored_suite = ci.get_defs().find_suite(suite_name)
-    assert the_restored_suite is not None, "Expected to find suite"
-    assert the_restored_suite.get_flag().is_set(FlagType.restored), " expected restored flag to be set"
-    assert not the_restored_suite.get_flag().is_set(FlagType.archived), "expected archive flag to be cleared"
-    
-
-def test_client_check_defstatus(ci):            
-    print_test(ci,"test_client_check_defstatus")
-    ci.delete_all()     
-    defs = create_defs("test_client_check_defstatus")  
-    
-    # stop defs form running when begin is called.
-    suite = defs.find_suite("test_client_check_defstatus")
-    suite.add_defstatus(DState.suspended)
-
-    t1 = "/test_client_check_defstatus/f1/t1"
-    t2 = "/test_client_check_defstatus/f1/t2"
-    task_t1 = defs.find_abs_node(t1)
-    task_t1.add_defstatus(DState.suspended)
-    
-    defs.generate_scripts();
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
-    
-    ci.restart_server()
-    ci.load(defs)           
-    ci.begin_all_suites()
-     
-    sync_local(ci) # get the changes, synced with local defs
-    #print(ci.get_defs())
-    task_t1 = ci.get_defs().find_abs_node(t1)
-    task_t2 = ci.get_defs().find_abs_node(t2)
-    assert task_t1 is not None,"Could not find t1"
-    assert task_t2 is not None,"Could not find t2"
-  
-    assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
-    assert task_t2.get_state() == State.queued, "Expected state queued " + str(task_t2.get_state())
-
-    assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_state())
-    assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_state())
-   
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_check_defstatus"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)     
-    
-def test_ECFLOW_189(ci):
-    # Bug, when a node is resumed it ignored holding dependencies higher up the tree.
-    # i.e Previously when we resumed a node, it ignored trigger/time/node state, dependencies higher up the tree
-    print_test(ci,"test_ECFLOW_189")
-    ci.delete_all()     
-    defs = create_defs("test_ECFLOW_189")  
-    defs.generate_scripts();
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
-    
-    ci.restart_server()
-    ci.load(defs)   
-    
-    ci.suspend("/test_ECFLOW_189")
-    ci.suspend("/test_ECFLOW_189/f1/t1")
-    ci.suspend("/test_ECFLOW_189/f1/t2")
-        
-    ci.begin_all_suites()
-    
-    sync_local(ci) # get the changes, synced with local defs
-    #print(ci.get_defs())
-    task_t1 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t1")
-    task_t2 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t2")
-    assert task_t1 is not None,"Could not find /test_ECFLOW_189/f1/t1"
-    assert task_t2 is not None,"Could not find /test_ECFLOW_189/f1/t2"
-  
-    assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
-    assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
-    assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_dstate())
-    assert task_t2.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t2.get_dstate())
-
-    # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
-    ci.resume("/test_ECFLOW_189/f1/t1")
-    ci.resume("/test_ECFLOW_189/f1/t2")
-     
-    time.sleep(3)
-    sync_local(ci) # get the changes, synced with local defs
-    #print(ci.get_defs())
-    task_t1 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t1")
-    task_t2 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t2")
-    assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
-    assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
-    assert task_t1.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t1.get_dstate())
-    assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_dstate())
-
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_ECFLOW_189"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)    
-
-
-def test_ECFLOW_1761(ci):
-    print_test(ci,"test_ECFLOW_1761")
-    print("# get log: last 10 lines")
-    ci.get_log(10)
-    
-    ci_defs = ci.get_defs()
-    task = ci_defs.get_all_nodes()[0]  # take first task
-    
-    #print(ci.edit_script_edit(task.get_abs_node_path())
-
-    #print(ci.edit_script_preprocess(task.get_abs_node_path()))
-
-    #ci.edit_script_submit(
-    #    task.get_abs_node_path(),
-    #        [],  # name-value variables list
-    #        [],  # lines (script)
-    #        False, # True,  $ alias
-    #        False)  # run
-
-
-def test_ECFLOW_199(ci):
-    # Test ClientInvoker::changed_node_paths
-    print_test(ci,"test_ECFLOW_199")
-    ci.delete_all()     
-    defs = create_defs("test_ECFLOW_199")  
-    defs.generate_scripts();
-    msg = defs.check_job_creation(verbose=True)
-    assert len(msg) == 0, msg
-    
-    ci.restart_server()
-    ci.load(defs)   
-    
-    ci.suspend("/test_ECFLOW_199")
-    ci.suspend("/test_ECFLOW_199/f1/t1")
-    ci.suspend("/test_ECFLOW_199/f1/t2")
-        
-    ci.begin_all_suites()
-    
-    sync_local(ci) # get the changes, synced with local defs
-    #print(ci.get_defs())
-    assert len(list(ci.changed_node_paths)) == 0, "Expected first call to sync_local, to have no changed paths but found " + str(len(list(ci.changed_node_paths)))
-    
-    # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
-    # Note: ECFLOW-1512, we may get additional paths.( i.e. suite path) due to changes in suite calendar
-    ci.resume("/test_ECFLOW_199/f1/t1")
-    sync_local(ci)
-    found_path = False
-    for path in ci.changed_node_paths:
-        print("   changed node path " + path);
-        if path == "/test_ECFLOW_199/f1/t1":
-            found_path = True
-    assert found_path, "Expected '/test_ECFLOW_199/f1/t1' in list of changed paths"
-
-    ci.resume("/test_ECFLOW_199/f1/t2")
-    sync_local(ci)
-    found_path = False
-    for path in ci.changed_node_paths:
-        print("   changed node path " + path);
-        if path == "/test_ECFLOW_199/f1/t2":
-            found_path = True
-    assert found_path, "Expected '/test_ECFLOW_199/f1/t2' in list of changed paths"
-
-
-    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_ECFLOW_199"
-    shutil.rmtree(dir_to_remove, ignore_errors=True)  
-
-def test_client_ch_with_drops_handles(the_port,top_ci):
-    print_test(ci,"test_client_ch_with_drops_handles")
-    try:
-        print("  test using with but without register, handle should be zero, ie do nothing")
-        with Client("localhost",the_port) as local_ci:
-            #print("Handle:",local_ci.ch_handle())
-            assert local_ci.ch_handle() == 0,"Expected handle to be zero"
-            local_ci.ch_suites()
-        print("  Test Client with register, should drop handle ")
-        with Client("localhost",the_port) as local_ci:
-            local_ci.ch_register(True, [ 's1','s2'])
-            #print("Handle:",local_ci .ch_handle())
-            local_ci.ch_suites()
-            #raise RuntimeError("xxx") # check exeption is still caught
-    except RuntimeError as e:
-        print("Exception",e)
-    print("after with:")
-    # really need a way to get hold of the suites, via python api.
-    top_ci.ch_suites() # should be empty
- 
-def do_tests(ci,the_port):
-    test_version(ci)
-    PrintStyle.set_style( Style.STATE ) # show node state 
-            
-    test_client_get_server_defs(ci)             
-    test_client_new_log(ci, the_port)             
-    test_client_clear_log(ci, the_port)             
-    test_client_log_msg(ci, the_port)             
-           
-    test_client_restart_server(ci)             
-    test_client_halt_server(ci)             
-    test_client_shutdown_server(ci)   
-       
-    test_client_load_in_memory_defs(ci)             
-    test_client_load_from_disk(ci)             
-    test_client_checkpt(ci, the_port)             
-    test_client_restore_from_checkpt(ci, the_port)             
-            
-    test_client_reload_wl_file(ci, the_port)             
-    
-    test_client_run(ci)  
-    test_client_run_with_multiple_paths(ci)     
-    test_client_requeue(ci)             
-    test_client_requeue_with_multiple_paths(ci)             
-    test_client_free_dep(ci)              
-   
-    test_client_suites(ci)
-    test_client_ch_with_drops_handles(the_port,ci)
-    test_client_ch_suites(ci)  
-    test_client_ch_register(ci)             
-    test_client_ch_drop(ci)             
-    test_client_ch_drop_user(ci)             
-    test_client_ch_add(ci)             
-    test_client_ch_auto_add(ci)             
-    test_client_ch_remove(ci)             
-              
-    test_client_get_file(ci)             
-    #test_client_plug(ci)             
-    test_client_alter_sort(ci) 
-    test_client_alter_sort_defs(ci) 
-    test_client_alter_add(ci) 
-    test_client_alter_delete(ci) 
-    test_client_alter_change(ci) 
-    test_client_alter_flag(ci) 
-
-    test_client_force(ci)             
-    test_client_replace(ci,False)             
-    test_client_replace(ci,True)             
-    test_node_replace(ci)             
-   
-    #test_client_kill(ci)             
-    #test_client_status(ci)             
-    #test_client_order(ci)             
-    #test_client_group(ci)             
-    test_client_suspend(ci)             
-    test_client_suspend_multiple_paths(ci)             
-    test_client_resume(ci)             
-    test_client_resume_multiple_paths(ci)             
-    test_client_delete_node(ci)             
-    test_client_delete_node_multiple_paths(ci)             
-    test_client_archive_and_restore(ci)             
- 
-    test_client_check(ci)  
-    test_client_check_defstatus(ci)  
-    
-    test_client_stats(ci)
-    test_client_stats_with_stdout(ci)
-    test_client_stats_without_stdout(ci)
-    test_client_stats_reset(ci)             
-    test_client_debug_server_on_off(ci)    
-          
-    test_ECFLOW_189(ci)         
-    test_ECFLOW_199(ci)         
-    test_ECFLOW_1761(ci)
-
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))   
-
-    # server independent tests
-    test_set_host_port();
-    
-    with Test.Server() as ci:
-        server_version = ci.server_version();
-        print("Running ecflow server version " + server_version)
-        print("Running ecflow client version " + ci.version())
-        assert ci.version() == server_version, " Client version not same as server version"
-        
-        global the_port
-        the_port = ci.get_port()
-        
-        # test with sync_local
-        do_tests(ci,the_port)  
-        
-        # test with auto sync
-        ci.set_auto_sync(True)
-        do_tests(ci,the_port)  
-
-        print("All Tests pass ======================================================================")    
diff -pruN 5.12.4-1/Pyext/test/py_s_TestPythonChildApi.py 5.13.0-1/Pyext/test/py_s_TestPythonChildApi.py
--- 5.12.4-1/Pyext/test/py_s_TestPythonChildApi.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_s_TestPythonChildApi.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,196 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-#  code for testing client code in python
-import time
-import os
-import pwd
-import sys  # determine python version
-from datetime import datetime
-import shutil   # used to remove directory tree
-
-from ecflow import Defs, Clock, DState, Event, Style, State, PrintStyle, File, Client, SState, File, debug_build
-import ecflow_test_util as Test
-
-
-def ecf_includes() : return File.source_dir() + "/Pyext" + "/test/data/python_includes"
-
-def create_defs(name,the_port):
-    defs = Defs()
-    suite_name = name
-    if len(suite_name) == 0: suite_name = "s1"
-    suite = defs.add_suite(suite_name);
-    
-    ecfhome = Test.ecf_home(the_port);
-    suite.add_variable("ECF_HOME", ecfhome);
-    suite.add_variable("ECF_INCLUDE", ecf_includes());
-    
-    prefix_job_cmd = ""
-    if 'PYTHONPATH' in os.environ:
-        prefix_job_cmd = "export PYTHONPATH=" + os.environ['PYTHONPATH'] +";" 
-    if 'LD_LIBRARY_PATH' in os.environ:
-        prefix_job_cmd += "export LD_LIBRARY_PATH=" + os.environ['LD_LIBRARY_PATH'] +";"
-   
-    # sys.version_info is a tuple containing (major,minor,micro,releaselevel,serial)
-    # releaselevel = alpha beta candidate final
-    if (sys.version_info > (3, 0)):
-        suite.add_variable("ECF_JOB_CMD",prefix_job_cmd + "python3 %ECF_JOB% 1> %ECF_JOBOUT% 2>&1")
-    else:
-        suite.add_variable("ECF_JOB_CMD",prefix_job_cmd + "python %ECF_JOB% 1> %ECF_JOBOUT% 2>&1")
-
-    family = suite.add_family("f1")
-    t1 = family.add_task("t1")
-    t1.add_event("event_fred")
-    t1.add(Event("event_set",True)) # ECFLOW-1526
-    t1.add_meter("meter", 0, 100)
-    t1.add_label("label_name", "value")
-    t1.add_queue("q1",["1","2","3"])
-
-    family.add_task("t2")  # test wait
-    family.add_task("t3").add_trigger("t1:q1 >= 3 and t1:event_fred and t1:event_set == clear") # wait on queue q1 and events
-    family.add_task("t4").add_trigger("t1:name1 == 1 and t1:name2 == 2 and t1:name3 == 3 and t1:name4 == 4") # test ECFLOW-1573
- 
-    defs.auto_add_externs(True) # because variable name1,name2,name3,name4  are not added until t1 is active.(i.e. runtime)
-    return defs;
-    
-def wait_for_suite_to_complete(ci,suite_name):
-    count = 0
-    while 1:
-        count += 1
-        ci.sync_local() # get the changes, synced with local defs
-        suite = ci.get_defs().find_suite(suite_name)
-        assert suite is not None, " Expected to find suite " + suite_name + ":\n" + str(ci.get_defs())
-        if suite.get_state() == State.complete:
-            break;
-        if suite.get_state() == State.aborted:
-            print(ci.get_defs());
-            assert False," Suite aborted \n"  
-        time.sleep(2)
-        if count > 20:
-            assert False, suite_name + " aborted after " + str(count) + " loops, printing defs:\n" + str(ci.get_defs())
-        
-    ci.log_msg("Looped " + str(count) + " times")
-    
-def test_python_child_api(ci):   
-    suite_name = "test_python_child_api"         
-    print("\n" + suite_name + " " + ci.get_host() + ":" + str(ci.get_port()))
-    print(" ECF_HOME(" + Test.ecf_home(ci.get_port()) + ")")
-    print(" ECF_INCLUDES(" + ecf_includes() + ")")
-    ci.delete_all(True)     
-    defs = create_defs(suite_name,ci.get_port())  
-    suite = defs.find_suite(suite_name)
-    suite.add_defstatus(DState.suspended)
-
-    # create the ecf file /test_python_child_api/f1/t1
-    ecf_home = Test.ecf_home(ci.get_port())
-    test_home = ecf_home + "/" + suite_name
-    dir = test_home + "/f1"
-    
-    # on cray creating recursive directories can fail, try again. yuk
-    try:
-        if not os.path.exists(dir): os.makedirs(dir)
-    except:
-        try:
-            if not os.path.exists(dir): os.makedirs(dir)
-        except:
-            # try breaking down
-            if not os.path.exists(ecf_home): os.makedirs(ecf_home)
-            new_dir = ecf_home + "/test_python_child_api"
-            if not os.path.exists(new_dir): os.makedirs(new_dir)
-            new_dir = ecf_home + "/test_python_child_api/f1"
-            if not os.path.exists(new_dir): os.makedirs(new_dir)
-    if not os.path.exists(dir): os.makedirs(dir)
-
-    # record the log file with the test
-    ci.new_log(test_home + "/" + suite_name + ".log")
-
-    server_version = ci.server_version()
-    file = dir + "/t1.ecf"
-    contents = "%include <head.py>\n\n"
-    contents += "with Client(True) as ci:\n" # Here True means add variables durint init and remove them on complete ECFLOW-1573
-    contents += "    print('   doing some work: t1.ecf')\n"
-    contents += "    if ci.version() != '" + server_version + "':\n"
-    contents += "        assert False, 'Client and server versions different'\n"
-    contents += "    ci.child_event('event_fred')      # set the event\n"
-    contents += "    ci.child_event('event_set',False) # clear the event ECFLOW-1526\n"
-    contents += "    ci.child_meter('meter',100)\n"
-    contents += "    ci.child_label('label_name','100')\n"
-    contents += "    step = ci.child_queue('q1','active')\n"
-    contents += "    assert step == '1','expected first step to be 1'\n"
-    contents += "    step = ci.child_queue('q1','complete',step)\n"
-    contents += "    step = ci.child_queue('q1','active')\n"
-    contents += "    assert step == '2','expected second step to be 2'\n"
-    contents += "    step = ci.child_queue('q1','complete',step)\n"
-    contents += "    step = ci.child_queue('q1','active')\n"
-    contents += "    assert step == '3','expected third step to be 3'\n"
-    contents += "    step = ci.child_queue('q1','complete',step)\n"
-    contents += "    step = ci.child_queue('q1','active')\n"
-    contents += "    assert step == '<NULL>','expected <NULL? for end of queue'\n"
-    contents += "    print('   Finished event,meter,label and queue child commands')\n"
-    open(file,'w').write(contents)
-    print(" Created file " + file)
-      
-    # create the ecf file /test_python_child_api/f1/t2
-    file = dir + "/t2.ecf"
-    contents = "%include <head.py>\n\n"
-    contents += "with Client() as ci:\n"
-    contents += "    print('   Waiting for /test_python_child_api/f1/t1 == complete')\n"
-    contents += "    ci.child_wait('/test_python_child_api/f1/t1 == complete')\n"
-    contents += "    print('   Finished waiting')\n"
-    open(file,'w').write(contents)
-    print(" Created file " + file)
-    
-    # create the ecf file /test_python_child_api/f1/t3
-    file = dir + "/t3.ecf"
-    contents = "%include <head.py>\n\n"
-    contents += "with Client() as ci:\n"
-    contents += "    print('   Running t3.ecf')\n"
-    open(file,'w').write(contents)
-    print(" Created file " + file)
-    
-    # create the ecf file /test_python_child_api/f1/t4
-    file = dir + "/t4.ecf"
-    contents = "%include <head.py>\n\n"
-    contents += "with Client() as ci:\n"
-    contents += "    print('   Running t4.ecf')\n"
-    open(file,'w').write(contents)
-    print(" Created file " + file)
-            
-    ci.restart_server()
-    ci.load(defs)          
-    ci.begin_all_suites()
-    print(" Running the test, wait for suite to complete ...")  
-    ci.run("/test_python_child_api", False)
-
-    wait_for_suite_to_complete(ci,suite_name);
-    
-    defs.save_as_defs(os.path.join(ecf_home,suite_name, suite_name + ".def"))
-
-    if not Test.debugging():
-        print(" Test OK: removing directory ",test_home)
-        shutil.rmtree(test_home,ignore_errors=True)      
-
-#///////////////////////////////////////////////////////////////////////////////////////        
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
-
-    with Test.Server() as ci:
-    
-        server_version = ci.server_version();
-        print("Running ecflow server version " + server_version)
-        print("Running ecflow client version " + ci.version() )
-        assert ci.version() == server_version, "Client version not same as server version"
-
-        PrintStyle.set_style( Style.STATE ) # show node state 
-        test_python_child_api(ci)  
-        print("\nAll Tests pass ======================================================================")    
diff -pruN 5.12.4-1/Pyext/test/py_u_TestAddDelete.py 5.13.0-1/Pyext/test/py_u_TestAddDelete.py
--- 5.12.4-1/Pyext/test/py_u_TestAddDelete.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestAddDelete.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,764 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# code for testing addition and deletion 
-#
-import sys
-import os
-import copy
-import unittest # for assertItemsEqual
-import ecflow
-import ecflow_test_util as Test
-
-if __name__ == "__main__":
-    
-    Test.print_test_start(os.path.basename(__file__))
- 
-    #===========================================================================
-    # Defs: add, delete and sort *USER* variables, use set(a).intersection(b) to compare lists
-    #===========================================================================
-    defs = ecflow.Defs()
-    defs.add_variable("ZFRED", "/tmp/")
-    defs.add_variable("YECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
-    defs.add_variable("XECF_URL_BASE", "http://www.ecmwf.int")
-    defs.add_variable("AECF_URL", "publications/manuals/sms")
-    assert len(list(defs.user_variables)) == 4, "Expected *user* 4 variable"    
-    
-    # sort
-    expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED']
-    actual = []
-    defs.sort_attributes("variable");
-    for v in defs.user_variables: actual.append(v.name())
-    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-
-    expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
-    actual = []
-    defs.add_variable("ZZ", "x")
-    defs.sort_attributes(ecflow.AttrType.variable);
-    for v in defs.user_variables: actual.append(v.name())
-    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-
-    expected = ['AA', 'AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
-    actual = []
-    defs.add_variable("AA", "x")
-    defs.sort_attributes("all");
-    for v in defs.user_variables: actual.append(v.name())
-    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-
-    expected = ['AA', 'AECF_URL', 'BB','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
-    actual = []
-    defs.add_variable("BB", "x")
-    defs.sort_attributes(ecflow.AttrType.all );
-    for v in defs.user_variables: actual.append(v.name())
-    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-
-    
-    
-    defs.delete_variable("ZFRED");assert len(list(defs.user_variables)) == 6, "Expected 6 variables since we just delete ZFRED"
-    defs.delete_variable("");     assert len(list(defs.user_variables)) == 0, "Expected 0 variables since we should have deleted all"
-    
-    a_dict = { "name":"value", "name2":"value2", "name3":"value3", "name4":"value4" }
-    defs.add_variable(a_dict)
-    assert len(list(defs.user_variables)) == 4, "Expected 4 variable"    
-    defs.delete_variable("");         assert len(list(defs.user_variables)) == 0, "Expected 0 variable since we should have deleted all"
-
-    # add a empty dictionary
-    a_dict = {}
-    defs.add_variable(a_dict)
-    assert len(list(defs.user_variables)) == 0, "Expected zero variables"    
-    
-    a_dict = { "name":0, "name2":1, "name3":2, "name4":3 }
-    defs.add_variable(a_dict)
-    assert len(list(defs.user_variables)) == 4, "Expected 4 variable"    
-    defs.delete_variable("");         assert len(list(defs.user_variables)) == 0, "Expected 0 variable since we should have deleted all"
-
-    #===========================================================================
-    # Suite: add,delete and sort variables
-    #===========================================================================
-    suite = ecflow.Suite("s1")
-    suite.add_variable(ecflow.Variable("ECF_HOME", "/tmp/"))
-    suite.add_variable("ZZZZZZ", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
-    suite.add_variable("YYYYY", "http://www.ecmwf.int")
-    suite.add_variable("aaaa", "publications/manuals/sms")
-    assert len(list(suite.variables)) == 4, "Expected 4 variable"    
-    
-    # sort
-    expected = ['aaaa','ECF_HOME','YYYYY','ZZZZZZ']
-    actual = []
-    suite.sort_attributes("variable");
-    suite.sort_attributes(ecflow.AttrType.variable);
-    for v in suite.variables: actual.append(v.name())
-    assert set(expected).intersection(actual), "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-
-    suite.delete_variable("ECF_HOME"); assert len(list(suite.variables)) == 3, "Expected 3 variable since we just delete ECF_HOME"
-    suite.delete_variable("");         assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
-    
-    a_dict = { "name":"value", "name2":"value2", "name3":"value3", "name4":"value4" }
-    suite.add_variable(a_dict)
-    assert len(list(suite.variables)) == 4, "Expected 4 variable"    
-    suite.delete_variable("");         assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
-
-    a_dict = { "name":1, "name2":2, "name3":3, "name4":4 }
-    suite.add_variable(a_dict)
-    assert len(list(suite.variables)) == 4, "Expected 4 variable"    
-    suite.delete_variable("");         assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
-
-    # add a empty dictionary
-    a_dict = { }
-    suite.add_variable(a_dict)
-    assert len(list(suite.variables)) == 0, "Expected zero variables"    
-
-    # adding dictionary items that are not strings,or ints in value ,should result in a type error
-    expected_type_error = False
-    try:
-        a_bad_dict = { "name":"fred", "name2":14, "name3": list( 1,2,3), "name4":12 }
-        suite.add_variable(a_bad_dict)
-    except TypeError:
-        expected_type_error = True
-        
-    assert expected_type_error, "Expected Type error"
-    assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
-    
-    suite.add_variable("ECF_URL_CMD", "test duplicates") 
-    suite.add_variable("ECF_URL_CMD", "Expected warning")  # expect a warning message to standard out
-
-
-    #===========================================================================
-    # add,delete and sort limits
-    #===========================================================================
-    suite.add_limit(ecflow.Limit("zlimitName1", 10))
-    suite.add_limit(ecflow.Limit("ylimitName2", 10))
-    suite.add_limit("xlimitName3", 10)
-    suite.add_limit("alimitName4", 10)
-    assert len(list(suite.limits)) == 4, "Expected 4 Limits"
-    
-    # sort
-    expected = ['alimitName4','xlimitName3','ylimitName2','zlimitName1']
-    actual = []
-    suite.sort_attributes(ecflow.AttrType.limit);
-    suite.sort_attributes("limit");
-    for v in suite.limits: actual.append(v.name())
-    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-
-    suite.delete_limit("zlimitName1"); assert len(list(suite.limits)) == 3, "Expected 3 limits since we just deleted one limitName1" 
-    suite.delete_limit("");            assert len(list(suite.limits)) == 0, "Expected 0 limits since we just deleted all of them"
-
-    # The following will fail, since the iterators are essentially read only, 
-    # This is because we are using C++ vector iterators, hence we can't delete the vectors items, whilst traversing 
-    #    for limit in suite.limits: suite.delete_limit(limit.name())
-    # We can get round this by copy the limits first
-    suite.add_limit(ecflow.Limit("limitName1", 10))
-    suite.add_limit(ecflow.Limit("limitName2", 10))
-    suite.add_limit("limitName3", 10)
-    suite.add_limit("limitName4", 10)
-    limit_names = []
-    for limit in suite.limits:
-        limit_names.append(limit.name())
-    for limit in limit_names:
-        suite.delete_limit(limit)
-    assert len(list(suite.limits)) == 0, "Expected 0 Limits,since we just deleted all of them, via iteration"
-
-    #===========================================================================
-    # Test Limit and node paths, ECFLOW-518
-    #===========================================================================
-    the_limit = ecflow.Limit("limitName1", 10)
-    assert the_limit.name() == "limitName1", "name not as expected"
-    assert the_limit.value() == 0 ,"Expected limit value of 0"
-    assert the_limit.limit() == 10 ,"Expected limit of 10"
-    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
-    
-    the_limit.increment(1,"/path1") ;  assert the_limit.value() == 1 ,"Expected limit value of 1"
-    the_limit.increment(1,"/path2") ;  assert the_limit.value() == 2 ,"Expected limit value of 2"
-    the_limit.increment(1,"/path3") ;  assert the_limit.value() == 3 ,"Expected limit value of 3"
-    the_limit.increment(1,"/path4") ;  assert the_limit.value() == 4 ,"Expected limit value of 4"
-    for path in the_limit.node_paths(): print(path)
-    assert len(list(the_limit.node_paths())) == 4 ,"expected 4 path"
-    the_limit.decrement(1,"/path1") ; assert the_limit.value() == 3 ,"Expected limit value of 3"
-    the_limit.decrement(1,"/path2") ; assert the_limit.value() == 2 ,"Expected limit value of 2"
-    the_limit.decrement(1,"/path3") ; assert the_limit.value() == 1 ,"Expected limit value of 1"
-    the_limit.decrement(1,"/path4") ; assert the_limit.value() == 0 ,"Expected limit value of 0"
-    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
-
-    the_limit.increment(1,"/path1") # add same path, should only consume one token
-    the_limit.increment(1,"/path1")
-    the_limit.increment(1,"/path1")
-    the_limit.increment(1,"/path1")
-    assert len(list(the_limit.node_paths())) == 1 ,"expected 1 path"
-    assert the_limit.value() == 1 ,"Expected limit value of 1"
-
-    #===========================================================================
-    # add and delete inlimits
-    #===========================================================================
-    suite.add_inlimit(ecflow.InLimit("limitName1", "/s1/f1", 2))
-    suite.add_inlimit(ecflow.InLimit("limitName2", "/s1/f1", 2, True))
-    suite.add_inlimit("limitName3", "/s1/f1", 2)
-    suite.add_inlimit("limitName4", "/s1/f1", 2)
-    suite.add_inlimit("limitNameA", "/s1/f1", 2)
-    suite.add_inlimit("limitNameA", "/s1/f1/a", 2)
-    suite.add_inlimit("limitNameA", "/s1/f1/b", 2)
-    assert len(list(suite.inlimits)) == 7, "Expected 7 inLimits"
-    suite.delete_inlimit("limitName1"); assert len(list(suite.inlimits)) == 6, "Expected 6 inlimits since we just deleted one limitName1" 
-    suite.delete_inlimit("/s1/f1:limitNameA"); assert len(list(suite.inlimits)) == 5, "Expected 5 inlimits since we just deleted one limitName1" 
-    suite.delete_inlimit("/s1/f1/a:limitNameA"); assert len(list(suite.inlimits)) == 4, "Expected 4 inlimits since we just deleted one limitName1" 
-    suite.delete_inlimit("/s1/f1/b:limitNameA"); assert len(list(suite.inlimits)) == 3, "Expected 3 inlimits since we just deleted one limitName1" 
-    suite.delete_inlimit("");           assert len(list(suite.inlimits)) == 0, "Expected 0 inlimits since we just deleted all of them"
-
-    #===============================================================================
-    # add and delete triggers and complete
-    #===============================================================================
-    task = ecflow.Task("task")
-    task.add_trigger("t2 == active")
-    task.add_complete("t2 == complete")
-    assert task.get_complete(), "Expected complete"
-    assert task.get_trigger(), "Expected trigger"
-    assert task.get_trigger().get_expression() == "t2 == active","add trigger failed"
-    assert task.get_complete().get_expression() == "t2 == complete","add complete failed"
-    task.delete_trigger();  assert not task.get_trigger(), "Expected no trigger"
-    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
-    
-    task.add_part_trigger(ecflow.PartExpression("t1 == complete"))
-    task.add_part_trigger(ecflow.PartExpression("t2 == active", True))  #  for long and/or expressions, subsequent expr must be and/or
-    task.add_part_complete(ecflow.PartExpression("t3 == complete"))
-    task.add_part_complete(ecflow.PartExpression("t4 == active", False))  #  for long and/or expressions, subsequent expr must be and/or
-    task.delete_trigger();  assert not task.get_trigger(), "Expected no trigger"
-    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
-
-    task.add_part_trigger("t1 == complete")
-    task.add_part_trigger("t2 == active", True)  #  for long and/or expressions, subsequent expr must be and/or
-    task.add_part_complete("t3 == complete")
-    task.add_part_complete("t4 == active", False)  #  for long and/or expressions, subsequent expr must be and/or
-    task.delete_trigger();  assert not task.get_trigger(), "Expected no trigger"
-    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
-    
-    #===========================================================================
-    # Add triggers using expressions
-    #===========================================================================
-    expr = ecflow.Expression("t1 == complete")
-    task = ecflow.Task("task")
-    task.add_trigger(expr)
-    assert task.get_trigger().get_expression() == "t1 == complete","add trigger failed : " + task.get_trigger().get_expression()
-
-    expr = ecflow.Expression("t1 == complete")
-    expr.add(ecflow.PartExpression("t2 == complete", True))
-    expr.add(ecflow.PartExpression("t3 == complete", True))
-    task = ecflow.Task("task")
-    task.add_trigger(expr)
-    assert task.get_trigger().get_expression() == "t1 == complete AND t2 == complete AND t3 == complete","add trigger failed : " + task.get_trigger().get_expression()
-
-    #===========================================================================
-    # add,delete,find events
-    #===========================================================================
-    task.add_event(ecflow.Event(1)); 
-    task.add_event(2)                              
-    task.add_event(ecflow.Event(10, "Eventname"))  
-    task.add_event(10, "Eventname2")               
-    task.add_event("fred")                         
-    
-    # sort
-    expected = ['1','2','Eventname','Eventname2','fred']
-    actual = []
-    task.sort_attributes("event");
-    task.sort_attributes(ecflow.AttrType.event);
-    for v in task.events: actual.append(v.name_or_number())
-    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-     
-    # test find
-    event = task.find_event("EVENT")
-    assert(event.empty()),"Expected to not to find event"
-    assert(event.name() == ""),"Expected to not to find event, number is maximum int"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task.find_event("1"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.number() == 1), "Expected to find event 1"
-    assert(event.name() == ""), "Expected name to be empty"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task.find_event("2"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.number() == 2), "Expected to find event 1"
-    assert(event.name() == ""), "Expected name to be empty"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task.find_event("10"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.number() == 10), "Expected to find event 10"
-    assert(event.name() == "Eventname"), "Expected name to be empty"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task.find_event("fred"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.name() == "fred"), "Expected name to be empty, when name defind an not number, number is max_int"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    for e in task.events:     print(str(e)," # value: ",str(e.value()))
-    a_dict = {}
-    for e in task.events:
-        if e.name() != "": a_dict[e.name()] = e.value()
-        else:              a_dict[e.number()] = e.value()
-    print(a_dict)
-
-    assert len(list(task.events)) == 5, "Expected 5 Events"
-    task.delete_event("1");         assert len(list(task.events)) == 4, "Expected 4 Events"
-    task.delete_event("Eventname"); assert len(list(task.events)) == 3, "Expected 3 Events"
-    task.delete_event("");          assert len(list(task.events)) == 0, "Expected 0 Events"
-
-
-    #===========================================================================
-    # add and delete meter
-    #===========================================================================
-    task.add_meter(ecflow.Meter("zzzz", 0, 100, 50))
-    task.add_meter(ecflow.Meter("yyyy", 0, 100))
-    task.add_meter("bbbb", 0, 100, 50)
-    task.add_meter("aaaa", 0, 100)
-    assert len(list(task.meters)) == 4, "Expected 4 Meters"
-    
-    # sort
-    expected = ['aaaa','bbbb','yyyy','zzzz']
-    actual = []
-    task.sort_attributes(ecflow.AttrType.meter);
-    task.sort_attributes("meter");
-    for v in task.meters: actual.append(v.name())
-    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
- 
-    task.delete_meter("zzzz"); assert len(list(task.meters)) == 3, "Expected 3 Meters"
-    task.delete_meter("yyyy"); assert len(list(task.meters)) == 2, "Expected 2 Meters"
-    task.delete_meter("");     assert len(list(task.meters)) == 0, "Expected 0 Meters"
-
-    #===========================================================================
-    # add and delete queue
-    #===========================================================================
-    queue_items = [ "001", "002"]
-    task.add_queue(ecflow.Queue("queue",queue_items))
-    task.add_queue("queue1",queue_items)
-    task.add_queue("queue2",queue_items)
-    task.add_queue("queue3",queue_items)
-    assert len(list(task.queues)) == 4, "Expected 4 Queues"
-    task.delete_queue("queue3"); assert len(list(task.queues)) == 3, "Expected 3 Queues"
-    task.delete_queue("queue2"); assert len(list(task.queues)) == 2, "Expected 2 Queues"
-    task.delete_queue("");       assert len(list(task.queues)) == 0, "Expected 0 Queues"
-
-    #===========================================================================
-    # add and delete, find generic. These are arbitary attributes for future func.
-    #===========================================================================
-    generic_items = [ "001", "002"]
-    task.add_generic(ecflow.Generic("gen",generic_items ))
-    task.add_generic("gen1",generic_items )
-    task.add_generic("gen2",generic_items )
-    task.add_generic("gen3",generic_items )
-    assert len(list(task.generics)) == 4, "Expected 4 Generics"
-    gen = task.find_generic("gen3")
-    assert not gen.empty()," find failed"
-    assert gen.name() == "gen3", "expected for find gen3"
-    
-    task.delete_generic("gen1"); assert len(list(task.generics)) == 3, "Expected 3 Generics"
-    task.delete_generic("gen2"); assert len(list(task.generics)) == 2, "Expected 2 Generics"
-    task.delete_generic("");     assert len(list(task.generics)) == 0, "Expected 0 Generics"
-
-    #===========================================================================
-    # add and delete label
-    #===========================================================================
-    task.add_label(ecflow.Label("labela", "value"))
-    task.add_label(ecflow.Label("labelb", "value"))
-    task.add_label("labelc", "value")
-    task.add_label("labeld", "value")
-    assert len(list(task.labels)) == 4, "Expected 4 labels"
-    
-    # sort
-    expected = ['labela','labelb','labelc','labeld']
-    actual = []
-    task.sort_attributes("label");
-    task.sort_attributes(ecflow.AttrType.label);
-    for v in task.labels: actual.append(v.name())
-    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-    
-    task.delete_label("labela"); assert len(list(task.labels)) == 3, "Expected 3 Labels"
-    task.delete_label("labelb"); assert len(list(task.labels)) == 2, "Expected 2 Labels"
-    task.delete_label("");       assert len(list(task.labels)) == 0, "Expected 0 Labels"
-
-    #===========================================================================
-    # add delete Repeat
-    #===========================================================================
-    task.add_repeat(ecflow.RepeatInteger("integer", 0, 100, 2))
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    task.add_repeat(ecflow.RepeatEnumerated("enum", ["red", "green", "blue" ]))
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task.add_repeat(ecflow.RepeatDate("date", 20100111, 20100115, 2))
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task.add_repeat(ecflow.RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00"))
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task.add_repeat(ecflow.RepeatDateList("date",[20100111, 20100115]))
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-     
-    task.add_repeat(ecflow.RepeatString("string", ["a", "b", "c" ]))
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task.add_repeat(ecflow.RepeatDay(1))
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    
-    #===========================================================================
-    # create a time series, used for adding time and today
-    #===========================================================================
-    start = ecflow.TimeSlot(0, 0)
-    finish = ecflow.TimeSlot(23, 0)
-    incr = ecflow.TimeSlot(0, 30)
-    time_series = ecflow.TimeSeries(start, finish, incr, True)
-
-    # Add and delete today
-    # NOTE: **********************************************************************
-    # Do *NOT* delete attributes using iterator traversal
-    # The iterators *are* bound to the c++ iterators hence if we delete
-    # over the traversal, we can corrupt the vector, leading to undefined behavour.  
-    # Hence we **cannot** delete more than once over a traversal
-    # Soln 1: take a copy
-    # *****************************************************************************
-    # task.add_today( Today( 0,10 ))
-    # task.add_today( Today( 0,59, True ))
-    # task.add_today( Today(TimeSlot(20,10)) )
-    # task.add_today( Today(TimeSlot(20,20),False)) 
-    # for today in task.todays: 
-    #    task.delete_today(today) # will corrupt C++ vector
-  
-    task.add_today("00:30")
-    task.add_today("+00:30")
-    task.add_today("+00:30 20:00 01:00")
-    task.add_today(ecflow.Today(time_series))
-    task.add_today(ecflow.Today("+00:30"))
-    task.add_today(ecflow.Today("+00:30 20:00 01:00"))
-    task.add_today(ecflow.Today(0, 10))
-    task.add_today(0, 59, True)
-    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 10)))
-    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 20), False)) 
-    assert len(list(task.todays)) == 10, "Expected 8 todays"
-    vec_copy = []
-    for today in task.todays: vec_copy.append(today)
-    for today in vec_copy: task.delete_today(today)
-    assert len(list(task.todays)) == 0, "Expected 0 todays"
-        
-    #===========================================================================
-    # add and delete time
-    #===========================================================================
-    task.add_time("00:30")
-    task.add_time("+00:30")
-    task.add_time("+00:30 20:00 01:00")
-    task.add_time(ecflow.Time(time_series))
-    task.add_time(ecflow.Time(0, 10))
-    task.add_time(ecflow.Time("+00:30"))
-    task.add_time(ecflow.Time("+00:30 20:00 01:00"))
-    task.add_time(0, 59, True)
-    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 10)))
-    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 20), False)) 
-    assert len(list(task.times)) == 10, "Expected 8 times"
-    vec_copy = []
-    for time in task.times: vec_copy.append(time)
-    for time in vec_copy: task.delete_time(time)
-    assert len(list(task.todays)) == 0, "Expected 0 todays"
-
-    #===========================================================================
-    # add and delete date
-    #===========================================================================
-    for i in [ 1, 2, 4, 8, 16 ] :
-        task.add_date(i, 0, 0)
-    task.add_date(ecflow.Date(1, 1, 2010))
-    task.add_date(1, 1, 2010)       # duplicate
-    task.add_date(ecflow.Date(2, 1, 2010))
-    task.add_date(ecflow.Date(3, 1, 2010))
-    task.add_date(ecflow.Date(4, 1, 2010)) 
-    assert len(list(task.dates)) == 10, "Expected 10 dates but found " + str(len(list(task.dates)))
-    vec_copy = []
-    for attr in task.dates: vec_copy.append(attr)
-    for attr in vec_copy: task.delete_date(attr)
-    assert len(list(task.dates)) == 0, "Expected 0 dates"
-
-    #===========================================================================
-    # add and delete day
-    #===========================================================================
-    task.add_day(ecflow.Day(ecflow.Days.sunday))
-    task.add_day(ecflow.Days.monday)
-    task.add_day(ecflow.Days.tuesday)  # duplicate ?
-    task.add_day(ecflow.Day("tuesday"))   
-    task.add_day("sunday")     
-    assert len(list(task.days)) == 5, "Expected 5 days"
-    vec_copy = []
-    for attr in task.days: vec_copy.append(attr)
-    for attr in vec_copy: task.delete_day(attr)
-    assert len(list(task.days)) == 0, "Expected 0 days"
-    
-    #===========================================================================
-    # add and delete crons
-    #===========================================================================
-    cron = ecflow.Cron()
-    start = ecflow.TimeSlot(23 , 0)
-    ts = ecflow.TimeSeries(start,True)  # True means relative to suite start
-    cron.set_time_series(ts)
-    
-    cron = ecflow.Cron()
-    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])
-    cron.set_days_of_month([1, 2, 3, 4, 5, 6 ])
-    cron.set_months([1, 2, 3, 4, 5, 6])
-    start = ecflow.TimeSlot(0 , 0)
-    finish = ecflow.TimeSlot(23, 0)
-    incr = ecflow.TimeSlot(0, 30)
-    ts = ecflow.TimeSeries(start, finish, incr, True)  # True means relative to suite start
-    cron.set_time_series(ts)
-
-    cron0 = ecflow.Cron()
-    cron0.set_week_days([0, 1, 2, 3, 4, 5 ])
-    cron0.set_time_series(1, 30) # default relative = false, added in release 4.0.7
-
-    cron1 = ecflow.Cron()
-    cron1.set_week_days([0, 1, 2, 3, 4, 5, 6 ])
-    cron1.set_time_series(1, 30, True)
-    
-    cron2 = ecflow.Cron()
-    cron2.set_week_days([0, 1, 2, 3, 4, 5, 6])
-    cron2.set_time_series("00:30 01:30 00:01")
-    
-    cron3 = ecflow.Cron()
-    cron3.set_week_days([0, 1, 2, 3, 4, 5, 6])
-    cron3.set_time_series("+00:30")
-
-    task.add_cron(cron)
-    task.add_cron(cron1)
-    task.add_cron(cron2)
-    task.add_cron(cron3)
-    assert len(list(task.crons)) == 4, "Expected 4 crons"
-    vec_copy = []
-    for attr in task.crons: vec_copy.append(attr)
-    for attr in vec_copy: task.delete_cron(attr)
-    assert len(list(task.crons)) == 0, "Expected 0 crons"  
-    
-    #===========================================================================
-    # add autocancel
-    #===========================================================================
-    print("test add autoCancel")
-    t1 = ecflow.Task("t1")
-    assert t1.get_autocancel() is None, " Expected no autocancel"
-    t1.add_autocancel(3)                       # 3 days
-    assert t1.get_autocancel() is not None, " Expected autocancel"
-    print(str(t1.get_autocancel()))
-
-    t3 = ecflow.Task("t3")
-    t3.add_autocancel(20, 10, True)              # hour,minutes,relative
-    print(str(t3.get_autocancel()))
-    
-    t4 = ecflow.Task("t4")
-    t4.add_autocancel(ecflow.TimeSlot(10, 10), True)    # hour,minutes,relative
-    print(str(t4.get_autocancel()))
-
-    t5 = ecflow.Task("t5")
-    t5.add_autocancel(ecflow.Autocancel(1, 10, True))   # hour,minutes,relative
-    print(str(t5.get_autocancel()))
-    
-    #===========================================================================
-    # add autoarchive
-    #===========================================================================
-    print("test add autoarchive")
-    f1 = ecflow.Family("f1")
-    assert f1.get_autoarchive() is None, " Expected no autoarchive"
-    f1.add_autoarchive(3)                       # 3 days
-    assert f1.get_autoarchive() is not None, " Expected autoarchive"
-    print(str(f1.get_autoarchive()))
- 
-    f2 = ecflow.Family("f2")
-    assert f2.get_autoarchive() is None, " Expected no autoarchive"
-    f2.add_autoarchive(3,True)                       # 3 days
-    assert f2.get_autoarchive() is not None, " Expected autoarchive"
-    print(str(f2.get_autoarchive()))
-
-    f3 = ecflow.Family("f3")
-    f3.add_autoarchive(20, 10, True)              # hour,minutes,relative
-    print(str(f3.get_autoarchive()))
-    
-    f3_1 = ecflow.Family("f3_1")
-    f3_1.add_autoarchive(20, 10, True,True)          # hour,minutes,relative,idle
-    print(str(f3_1.get_autoarchive()))
-
-    f4 = ecflow.Family("f4")
-    f4.add_autoarchive(ecflow.TimeSlot(10, 10), True)    # hour,minutes,relative
-    print(str(f4.get_autoarchive()))
-
-    f4_1 = ecflow.Family("f4_1")
-    f4_1.add_autoarchive(ecflow.TimeSlot(10, 10), True,True)    # hour,minutes,relative,idle
-    print(str(f4_1.get_autoarchive()))
-
-    f4_2 = ecflow.Family("f4_2")
-    assert f4_2.get_autoarchive() is None, " Expected no autoarchive"
-    f4_2.add_autoarchive(ecflow.Autoarchive(10,True))    # Days,idle
-    assert f4_2.get_autoarchive() is not None, " Expected autoarchive"
-    print(str(f4_2.get_autoarchive()))
-
-    #===========================================================================
-    # autocancel
-    #===========================================================================
-    f5 = ecflow.Family("f5")
-    f5.add_autocancel(ecflow.Autocancel(1, 10, True))   # hour,minutes,relative
-    print(str(f5.get_autocancel()))
-    
-    #===========================================================================
-    # add autorestore
-    #===========================================================================
-    print("test add autorestore")
-    t1 = ecflow.Task("f1")
-    assert t1.get_autorestore() is None, " Expected no autorestore"
-    t1.add_autorestore(["/s1/f2"])                       
-    assert t1.get_autorestore() is not None, " Expected autorestore"
-    print(str(t1.get_autorestore()))
-
-    f5 = ecflow.Family("f5")
-    assert f5.get_autorestore() is None, " Expected no autorestore"
-    f5.add_autorestore(["/s1/f2","/s2","/s3"])                       
-    assert f5.get_autorestore() is not None, " Expected autorestore"
-    print(str(f5.get_autoarchive()))
-    
-    f6 = ecflow.Family("f6")
-    assert f6.get_autorestore() is None, " Expected no autorestore"
-    f6.add_autorestore(ecflow.Autorestore(["/s1/f2","/s2","/s3"]))                       
-    assert f6.get_autorestore() is not None, " Expected autorestore"
-    print(str(f6.get_autoarchive()))
-    
-    #===========================================================================
-    # add late
-    #===========================================================================
-    late = ecflow.Late()
-    late.submitted(ecflow.TimeSlot(20, 10))
-    late.active(ecflow.TimeSlot(20, 10))
-    late.complete(ecflow.TimeSlot(20, 10), True)
-    task.add_late(late)
-    
-    late = ecflow.Late()
-    late.submitted(20, 10)
-    late.active(20, 10)
-    late.complete(20, 10, True)
-    t1.add_late(late)
-    
-    
-    #===========================================================================
-    # add defstatus, last one set takes effect
-    #===========================================================================
-    task.add_defstatus(ecflow.DState.complete)
-    assert task.get_defstatus() == ecflow.DState.complete
-    task.add_defstatus(ecflow.DState.queued)
-    assert task.get_defstatus() == ecflow.DState.queued
-    task.add_defstatus(ecflow.DState.aborted)
-    assert task.get_defstatus() == ecflow.DState.aborted
-    task.add_defstatus(ecflow.DState.submitted)
-    assert task.get_defstatus() == ecflow.DState.submitted
-    task.add_defstatus(ecflow.Defstatus(ecflow.DState.suspended ));
-    assert task.get_defstatus() == ecflow.DState.suspended
-    task.add_defstatus(ecflow.Defstatus("active"))  
-    assert task.get_defstatus() == ecflow.DState.active
-
-    # the state should be unknown until the suite is begun
-    assert task.get_state() == ecflow.State.unknown
-    assert task.get_dstate() == ecflow.DState.unknown
- 
-    #===========================================================================
-    # add clock
-    #===========================================================================
-    clock = ecflow.Clock(1, 1, 2010, False)     # day,month, year, hybrid
-    clock.set_gain(1, 10, True)                 # True means positive gain
-    suite = ecflow.Suite("suite")
-    suite.add_clock(clock)
-    
-    clock = ecflow.Clock(1, 1, 2011, True)       # day,month, year, hybrid
-    clock.set_gain_in_seconds(12, True)
-    s1 = ecflow.Suite("s1")
-    s1.add_clock(clock)
-    
-    print("#===========================================================================")
-    print("# get clock")
-    print("#===========================================================================")
-    s0 = ecflow.Suite("s0")
-    assert s0.get_clock() is None, "Expected no clock"
-    
-    s0.add_clock(ecflow.Clock(1, 1, 2010, False))
-    assert s0.get_clock() is not None, "Expected clock"
-
-    #===========================================================================
-    # end clock, used in simulator only, not persisted
-    #===========================================================================
-    clock = ecflow.Clock(1, 1, 2010, False)     # day,month, year, hybrid
-    clock.set_gain(1, 10, True)                 # True means positive gain
-    suite = ecflow.Suite("suite")
-    suite.add_end_clock(clock)
-    
-    clock = ecflow.Clock(1, 1, 2011, True)       # day,month, year, hybrid
-    clock.set_gain_in_seconds(12, True)
-    s1 = ecflow.Suite("s1")
-    s1.add_end_clock(clock)
-    
-    print("#===========================================================================")
-    print("# get end clock")
-    print("#===========================================================================")
-    s0 = ecflow.Suite("s0")
-    assert s0.get_end_clock() is None, "Expected no end clock"
-    
-    s0.add_end_clock(ecflow.Clock(1, 1, 2010, False))
-    assert s0.get_end_clock() is not None, "Expected end clock"
-    #===========================================================================
-    # Add zombie. Note we can *NOT* add two zombie attributes of the same ZombieType
-    #===========================================================================
-    zombie_life_time_in_server = 800
-    child_list = [ ecflow.ChildCmdType.init, ecflow.ChildCmdType.event, ecflow.ChildCmdType.meter, ecflow.ChildCmdType.label, ecflow.ChildCmdType.wait, ecflow.ChildCmdType.abort, ecflow.ChildCmdType.complete ]
-    zombie_type_list = [ ecflow.ZombieType.ecf, ecflow.ZombieType.ecf_pid, ecflow.ZombieType.ecf_pid_passwd, ecflow.ZombieType.ecf_passwd, ecflow.ZombieType.user, ecflow.ZombieType.path ]
-    for zombie_type in zombie_type_list:
-        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block, zombie_life_time_in_server)
-        s1.add_zombie(zombie_attr)
-    assert len(list(s1.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(s1.zombies)))
-    
-    # delete all the zombies
-    s1.delete_zombie("")
-    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
-    
-    # add with zombie_life_time_in_server not set, this is optional
-    for zombie_type in zombie_type_list:
-        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block)
-        s1.add_zombie(zombie_attr)
-    assert len(list(s1.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(s1.zombies)))
-
-    s1.delete_zombie("")
-    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
-
-    # repeat the the test with empty child list. Empty child list means apply to all child commands
-    child_list = []
-    for zombie_type in zombie_type_list:
-        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block, zombie_life_time_in_server)
-        s1.add_zombie(zombie_attr)
-        
-        # test delete of specific zombie attribute
-        assert len(list(s1.zombies)) == 1, "Expected 1 zombie attributes but found " + str(len(list(s1.zombies)))
-        s1.delete_zombie(zombie_type)
-        assert len(list(s1.zombies)) == 0, "Expected 0 zombie attributes but found " + str(len(list(s1.zombies)))
-
-
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestAddDeleteError.py 5.13.0-1/Pyext/test/py_u_TestAddDeleteError.py
--- 5.12.4-1/Pyext/test/py_u_TestAddDeleteError.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestAddDeleteError.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import os
-from ecflow import Defs, Suite, Variable, Limit, InLimit, Task, PartExpression, \
-                   Event, Meter, Label, RepeatInteger, RepeatEnumerated, RepeatDate,RepeatDateList,RepeatString, \
-                   TimeSlot, TimeSeries, Today, Time, Date, Day, Days, Cron, Autocancel, Late, \
-                   DState, Clock, ChildCmdType, ZombieType, ZombieAttr, ZombieUserActionType, Client, debug_build
-import ecflow_test_util as Test
-    
-if __name__ == "__main__":
-    
-    Test.print_test_start(os.path.basename(__file__))
-    
-    #
-    # Test for: See  ECFLOW-106 Times/Dates attributes attached to suite node
-    #
-    defs = Defs()
-    suite = defs.add_suite("s1") 
-    
-    #
-    # Suite should not be allowed time based dependencies
-    # Check Today
-    expected_error = False
-    try:
-        suite.add_today("00:30")
-    except RuntimeError: 
-        expected_error = True
-    assert expected_error, "Suite should not allow any time based dependencies"
-
-    expected_error = False
-    try:
-        suite.add_today(0,30)
-    except RuntimeError: 
-        expected_error = True
-    assert expected_error, "Suite should not allow any time based dependencies"
-    
-    #
-    # Check Time
-    expected_error = False
-    try:
-        suite.add_time("+00:30")
-    except RuntimeError: 
-        expected_error = True
-    assert expected_error, "Suite should not allow any time based dependencies"
-
-    expected_error = False
-    try:
-        suite.add_time(0,30)
-    except RuntimeError: 
-        expected_error = True
-    assert expected_error, "Suite should not allow any time based dependencies"
-
-    # 
-    # Check Date::See  ECFLOW-106 Times/Dates attributes attached to suite node
-    expected_error = False
-    try:
-        suite.add_date( 1,1,2010)
-    except RuntimeError: 
-        expected_error = True
-    assert expected_error, "Suite should not allow any time based dependencies"
- 
-    # 
-    # Check Day:: See  ECFLOW-106 Times/Dates attributes attached to suite node
-    expected_error = False
-    try:
-        suite.add_day("sunday")
-    except RuntimeError: 
-        expected_error = True
-    assert expected_error, "Suite should not allow any time based dependencies"
-
-    # 
-    #Adding a RepeatDateList with a empty list should be an error
-    expected_error = False
-    task = Task("t")
-    try:
-        task.add_repeat(RepeatDateList("date",[]))
-    except RuntimeError: 
-        expected_error = True
-    assert expected_error, "RepeatDateList adding an empty date list should be an error"
-
-    print("All Tests pass")
-    
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_TestAddDeleteFunc.py 5.13.0-1/Pyext/test/py_u_TestAddDeleteFunc.py
--- 5.12.4-1/Pyext/test/py_u_TestAddDeleteFunc.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestAddDeleteFunc.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,331 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import os
-from ecflow import Defs, Suite, Variable, Limit, InLimit, Task, PartExpression, \
-                   Event, Meter, Label, Queue, RepeatInteger, RepeatEnumerated, RepeatDate, RepeatDateTime, \
-                   RepeatDateList, RepeatString, TimeSlot, TimeSeries, Today, Time, Date, Day, Days, Cron, Autocancel, \
-                   Late, DState, Clock, ChildCmdType, ZombieType, ZombieAttr, ZombieUserActionType, Client, debug_build
-import ecflow_test_util as Test
-
-if __name__ == "__main__":
-
-    Test.print_test_start(os.path.basename(__file__))
-    
-    #
-    # Add Nodes functional way
-    #
-    defs = Defs()
-    defs.add_suite("s1").add_task("t1").add_variable("var","v")
-    defs.add_suite("s2").add_family("f1").add_task("t1").add_variable("var","v")
-    defs.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
-    assert len(defs) == 3,"Expected 3 suites"    
-
-
-    # add and delete variables
-    a_dict = { "name":"value", "name2":"value2", "name3":"value3", "name4":"value4" }
-    suite = Suite("s1")
-    suite.add_variable(Variable("ECF_HOME","'/tmp/'")) \
-         .add_variable("Fred", 1)\
-         .add_variable("ECF_URL_BASE",'http://www.ecmwf.int')\
-         .add_variable("ECF_URL",'"publications/manuals/sms"')\
-         .add_variable(a_dict)
-    print(suite)
-    assert len(list(suite.variables)) == 8,"Expected 8 variable"    
-    suite.delete_variable("");         assert len(list(suite.variables)) == 0,"Expected 0 variable since we should have deleted all"
-    
-    
-    # add and delete limits
-    the_limit = Limit("limitName1", 10)
-    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
-    suite.add_limit(  Limit("limitName1", 10) )\
-        .add_limit(  Limit("limitName2", 10) )\
-        .add_limit(  "limitName3", 10 )\
-        .add_limit(  "limitName4", 10 )
-    assert len(list(suite.limits)) == 4,"Expected 4 Limits"
-    suite.delete_limit("");           assert len(list(suite.limits)) == 0,"Expected 0 limits since we just deleted all of them"
-
-
-    # add and delete in-limits
-    suite.add_inlimit( InLimit("limitName1","/s1/f1",2,True) )\
-        .add_inlimit( InLimit("limitName2","/s1/f1",2))\
-        .add_inlimit( "limitName3","/s1/f1",2,True)\
-        .add_inlimit( "limitName4","/s1/f1",2)
-    assert len(list(suite.inlimits)) == 4,"Expected 4 inLimits"
-    suite.delete_inlimit("limitName1"); assert len(list(suite.inlimits)) == 3,"Expected 3 inlimits since we just deleted one limitName1" 
-    suite.delete_inlimit("");           assert len(list(suite.inlimits)) == 0,"Expected 0 inlimits since we just deleted all of them"
-
-
-    # add and delete triggers and complete
-    task = Task("task")
-    task.add_trigger( "t2 == active" ).add_complete( "t2 == complete" )
-    assert task.get_complete(), "Expected complete"
-    assert task.get_trigger(),  "Expected trigger"
-    task.delete_trigger();  assert not task.get_trigger(),  "Expected no trigger"
-    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
-    
-    task.add_part_trigger(  PartExpression("t1 == complete") )\
-        .add_part_complete( PartExpression("t3 == complete") ) \
-        .add_part_complete( PartExpression("t4 == active",False) )   
-    task.delete_trigger();  assert not task.get_trigger(),  "Expected no trigger"
-    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
-
-    task.add_part_trigger(  "t1 == complete" ) \
-        .add_part_complete( "t3 == complete" ) \
-        .add_part_complete( "t4 == active",False)  #  for long and/or expressions, subsequent expr must be and/or
-    task.delete_trigger();  assert not task.get_trigger(),  "Expected no trigger"
-    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
-    
-    
-    # add and delete events
-    task.add_event( Event(1) ).add_event( 2 ).add_event( Event(10, "Eventname") ).add_event( 10, "Eventname2" ).add_event( "fred" )
-    assert len(list(task.events)) == 5,"Expected 5 Events"
-    task.delete_event("");          assert len(list(task.events)) == 0,"Expected 0 Events"
-
-
-    # add and delete meter
-    task.add_meter( Meter("metername1", 0, 100, 50) )\
-        .add_meter( Meter("metername2", 0, 100) )\
-        .add_meter( "metername3", 0, 100, 50 )\
-        .add_meter( "metername4", 0, 100 )
-    assert len(list(task.meters)) == 4,"Expected 4 Meters"
-    task.delete_meter("");           assert len(list(task.meters)) == 0,"Expected 0 Meters"
-
-    # add and delete queue
-    queue_items = [ "001", "002"]
-    task.add_queue( Queue("q1", queue_items) )\
-        .add_queue( Queue("q2", queue_items) )\
-        .add_queue( "q3", queue_items )\
-        .add_queue( "q4", queue_items)
-    assert len(list(task.queues)) == 4,"Expected 4 Queues"
-    task.delete_queue("");           assert len(list(task.queues)) == 0,"Expected 0 Queues"
-
-    # add and delete label
-    task.add_label( Label("label_name1", "value") )\
-        .add_label( Label("label_name2", "value") )\
-        .add_label( "label_name3", "value" )\
-        .add_label( "label_name4", "value" )
-    assert len(list(task.labels)) == 4,"Expected 4 labels"
-    task.delete_label("");            assert len(list(task.labels)) == 0,"Expected 0 Labels"
-
-    # add delete Repeat
-    task.add_repeat( RepeatInteger("integer", 0, 100, 2) ).add_variable("fred","j")
-    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    task.add_repeat( RepeatEnumerated("enum", ["red", "green", "blue" ]) ).add_variable("Q","j")
-    print(task)
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task.add_repeat( RepeatDate("date", 20100111, 20100115,2) ).add_variable("W","j")
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task.add_repeat(RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00")).add_variable("W", "j")
-    task.delete_repeat()
-    repeat = task.get_repeat();
-    assert repeat.empty(), "Expected no repeat"
-
-    task.add_repeat( RepeatDateList("date",[20100111, 20100115]) ).add_variable("W","j")
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    task.add_repeat( RepeatString("string", ["a", "b", "c" ] ) ).add_variable("E","j")
-    task.delete_repeat()      
-    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    
-    # create a time series, used for adding time and today
-    start = TimeSlot(0, 0)
-    finish = TimeSlot(23, 0)
-    incr = TimeSlot(0, 30)
-    time_series = TimeSeries( start, finish, incr, True)
-
-    # Add and delete today
-    # NOTE: **********************************************************************
-    # Do *NOT* delete attributes using iterator traversal
-    # The iterators *are* bound to the c++ iterators hence if we delete
-    # over the traversal, we can corrupt the vector, leading to undefined behaviour.  
-    # Hence we **cannot** delete more than once over a traversal
-    # Soln 1: take a copy
-    # *****************************************************************************
-    # task.add_today( Today( 0,10 ))
-    # task.add_today( Today( 0,59, True ))
-    # task.add_today( Today(TimeSlot(20,10)) )
-    # task.add_today( Today(TimeSlot(20,20),False)) 
-    # for today in task.todays: 
-    #    task.delete_today(today) # will corrupt C++ vector
-  
-    task.add_today( "00:30" ).add_today( "+00:30" ).add_today( "+00:30 20:00 01:00" )\
-        .add_today( Today( time_series) )\
-        .add_today( Today( 0,10 )).add_today( 0, 59, True )\
-        .add_today( Today(TimeSlot(20,10)) )\
-        .add_today( Today(TimeSlot(20,20),False)) 
-    assert len(list(task.todays)) == 8,"Expected 8 todays"
-    vec_copy = []
-    for today in task.todays: vec_copy.append(today)
-    for today in vec_copy: task.delete_today(today)
-    assert len(list(task.todays)) == 0,"Expected 0 todays"
-        
-             
-    # add and delete time
-    task.add_time( "00:30" ).add_time( "+00:30" ).add_time( "+00:30 20:00 01:00" )\
-        .add_time( Time(time_series ))\
-        .add_time( Time( 0,10 ))\
-        .add_time( 0, 59, True)\
-        .add_time( Time(TimeSlot(20,10)) )\
-        .add_time( Time(TimeSlot(20,20),False)) 
-    assert len(list(task.times)) == 8,"Expected 8 times"
-    vec_copy = []
-    for time in task.times: vec_copy.append(time)
-    for time in vec_copy: task.delete_time(time)
-    assert len(list(task.todays)) == 0,"Expected 0 todays"
-
-
-    # add and delete date
-    for i in [ 1, 2, 4, 8, 16 ] :
-        task.add_date( i, 0, 0)
-    task.add_date( Date(1, 1, 2010))\
-        .add_date( Date(2, 1, 2010))\
-        .add_date( Date(3, 1, 2010))\
-        .add_date( Date(4, 1, 2010))\
-        .add_date( 1, 1, 2010)
-    assert len(list(task.dates)) == 10,"Expected 10 dates but found " + str(len(list(task.dates)))
-    vec_copy = []
-    for attr in task.dates: vec_copy.append(attr)
-    for attr in vec_copy: task.delete_date(attr)
-    assert len(list(task.dates)) == 0,"Expected 0 dates"
-
-    # add and delete day
-    task.add_day( Day(Days.sunday))\
-        .add_day( Days.monday)\
-        .add_day( Days.tuesday)\
-        .add_day( "sunday")     
-    assert len(list(task.days)) == 4,"Expected 4 days"
-    vec_copy = []
-    for attr in task.days: vec_copy.append(attr)
-    for attr in vec_copy: task.delete_day(attr)
-    assert len(list(task.days)) == 0,"Expected 0 days"
-    
-    # add and delete crons
-    cron = Cron()
-    cron.set_week_days( [0, 1, 2, 3, 4, 5, 6]  )
-    cron.set_days_of_month( [1, 2, 3, 4, 5, 6 ] )
-    cron.set_months(  [1, 2, 3, 4, 5, 6]  )
-    start = TimeSlot(0 ,0)
-    finish = TimeSlot(23, 0)
-    incr = TimeSlot(0, 30)
-    ts = TimeSeries( start, finish, incr, True)  # True means relative to suite start
-    cron.set_time_series( ts )
-
-    cron1 = Cron()
-    cron1.set_week_days( [0, 1, 2, 3, 4, 5, 6 ] )
-    cron1.set_time_series( 1, 30,  True )
-    
-    cron2 = Cron()
-    cron2.set_week_days( [0, 1, 2, 3, 4, 5, 6] )
-    cron2.set_time_series( "00:30 01:30 00:01" )
-    
-    cron3 = Cron()
-    cron3.set_week_days( [0, 1, 2, 3, 4, 5, 6] )
-    cron3.set_time_series( "+00:30" )
-
-    task.add_cron( cron ) \
-        .add_cron( cron1 ) \
-        .add_cron( cron2 ) \
-        .add_cron( cron3 )
-    assert len(list(task.crons)) == 4,"Expected 4 crons"
-    vec_copy = []
-    for attr in task.crons: vec_copy.append(attr)
-    for attr in vec_copy: task.delete_cron(attr)
-    assert len(list(task.crons)) == 0,"Expected 0 crons"  
-    
-    
-    # add autocancel
-    t1 = Task("t1")
-    t1.add_autocancel( 3 ).add_variable("A","j")                       
-    t3 = Task("t3")
-    t3.add_autocancel( 20, 10, True ).add_variable("B","j") 
-    t4 = Task("t4")
-    t4.add_autocancel( TimeSlot(10, 10), True ).add_variable("C","j") 
-    t5 = Task("t5")
-    t5.add_autocancel( Autocancel(1, 10, True) ).add_variable("D","j") 
-    
-    
-    # add late
-    late = Late()
-    late.submitted( TimeSlot(20, 10) )
-    late.active(    TimeSlot(20, 10))
-    late.complete(  TimeSlot(20, 10), True)
-    task.add_late(late ).add_variable("FRED33","j") 
-        
-    
-    # add defstatus, last one set takes effect
-    task.add_defstatus( DState.complete )\
-        .add_defstatus( DState.queued )\
-        .add_defstatus( DState.aborted )\
-        .add_defstatus( DState.submitted )\
-        .add_defstatus( DState.suspended )\
-        .add_defstatus( DState.active )
-    
-    #
-    # add clock
-    #
-    clock = Clock(1, 1, 2010, False)     # day,month, year, hybrid
-    clock.set_gain(1, 10, True)         # True means positive gain
-    suite =  Suite("suite")
-    suite.add_clock(clock).add_variable("fred1","j") 
-    
-    end_clock = Clock(1, 1, 2017, False)     # day,month, year, hybrid
-    suite.add_end_clock(end_clock).add_variable("fred2","j") 
-    
-    clock = Clock(1, 1, 2011, True)       # day,month, year, hybrid
-    clock.set_gain_in_seconds(12, True)
-    s1 =  Suite("s1")
-    s1.add_clock(clock).add_variable("fred3","j") 
-    s1.add_end_clock(end_clock).add_variable("fred4","j") 
-    
-    #
-    # Add zombie. Note we can *NOT* add two zombie attributes of the same ZombieType
-    #
-    zombie_life_time_in_server = 800
-    child_list = [ ChildCmdType.init, ChildCmdType.event, ChildCmdType.meter, ChildCmdType.label, ChildCmdType.wait, ChildCmdType.abort, ChildCmdType.complete ]
-    zombie_type_list = [ ZombieType.ecf, ZombieType.user, ZombieType.path ]
-    count = 1;
-    for zombie_type in zombie_type_list:
-        zombie_attr = ZombieAttr(zombie_type, child_list, ZombieUserActionType.block, zombie_life_time_in_server)
-        s1.add_zombie(zombie_attr).add_variable("afred" + str(count),"j") 
-        count += 1
-    assert len(list(s1.zombies)) == 3,"Expected 3 zombie attributes but found " + str(len(list(s1.zombies)))
-    
-    # delete all the zombies
-    s1.delete_zombie("")
-    assert len(list(s1.zombies)) == 0,"Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
-
-    # repeat the the test with empty child list. Empty child list means apply to all child commands
-    # + don't specify zombie_life_time_in_server as this is optional
-    child_list = [ ]
-    zombie_type_list = [ ZombieType.ecf, ZombieType.user, ZombieType.path ]
-    for zombie_type in zombie_type_list:
-        zombie_attr = ZombieAttr(zombie_type, child_list, ZombieUserActionType.block)
-        s1.add_zombie(zombie_attr).add_variable("bfred" + str(count),"j") 
-        
-        # test delete of specific zombie attribute
-        assert len(list(s1.zombies)) == 1,"Expected 1 zombie attributes but found " + str(len(list(s1.zombies)))
-        s1.delete_zombie(zombie_type)
-        assert len(list(s1.zombies)) == 0,"Expected 0 zombie attributes but found " + str(len(list(s1.zombies)))
-        count += 1;
-
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestAddNodeFunc.py 5.13.0-1/Pyext/test/py_u_TestAddNodeFunc.py
--- 5.12.4-1/Pyext/test/py_u_TestAddNodeFunc.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestAddNodeFunc.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-from ecflow import Defs, Client, debug_build
-import ecflow_test_util as Test
-import os
-
-def create_defs_sequentially():
-    local_defs = Defs()
-    suite = local_defs.add_suite("s1")
-    suite.add_variable("Var","value")
-    suite.add_meter( "metername3", 0, 100, 50 )
-    suite.add_event( 2 )
-    suite.add_event( 3 )
-    f1 = suite.add_family("f1")
-    f1 = f1.add_family("f1")
-    t1 = f1.add_task("t1")
-    t1.add_variable("fred","jones")
-    
-    f2 = suite.add_family("f2")
-    f1 = f2.add_family("f1")
-    t1 = f1.add_task("t1")
-    t1.add_variable("fred","jones")
-
-    f3 = suite.add_family("f3")
-    t1 = f3.add_task("t1")
-    t1.add_variable("fred",    "jones")
-    
-    suite.add_task("t1").add_variable("fred","jones")
-    return local_defs
-
-def create_defs_functionally():
-    f_defs = Defs()
-    suite = f_defs.add_suite("s1")
-    suite.add_variable("Var","value").add_family("f1").add_family("f1").add_task("t1").add_variable("fred","jones")
-    suite.add_family("f2").add_family("f1").add_task("t1").add_variable("fred","jones")
-    suite.add_meter( "metername3", 0, 100, 50 ).add_family("f3").add_task("t1").add_variable("fred","jones")
-    suite.add_event( 2 ).add_event( 3 ).add_task("t1").add_variable("fred","jones")
-    return f_defs
-    
-    
-if __name__ == "__main__":
-        
-    Test.print_test_start(os.path.basename(__file__))
-
-    #
-    # Add Nodes functional way
-    #
-    defs = Defs()
-    defs.add_suite("s1").add_task("t1").add_variable("var","v")
-    defs.add_suite("s2").add_family("f1").add_task("t1").add_variable("var","v")
-    defs.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
-    assert len(defs) == 3,"Expected 3 suites"    
-  
-    # These test show that although add_variable() returns a node_ptr, its really a suite
-    # hence calling add_family/add_task still works.
-    assert create_defs_sequentially() == create_defs_functionally(),"Functional suite not as expected "
-  
-    print("All Tests pass")
-    
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_TestAutoAddExtern.py 5.13.0-1/Pyext/test/py_u_TestAutoAddExtern.py
--- 5.12.4-1/Pyext/test/py_u_TestAutoAddExtern.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestAutoAddExtern.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,49 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-#  code for testing pointers and hierarchy in python
-
-import os
-from ecflow import Suite, Family, Task, Defs, Client, debug_build
-import ecflow_test_util as Test
-
-def check_then_auto_add_extern(defs):
-    error_msg = defs.check() 
-    print(error_msg)
-    assert len(error_msg) !=0,"Expect error in checks\n" + str(defs)
-    
-    defs.auto_add_externs(True)
-    error_msg = defs.check()
-    assert len(error_msg) == 0,"Expect check to pass after auto add extern\n" + error_msg + "\n" + str(defs)
-    
-if __name__ == "__main__":   
-    Test.print_test_start(os.path.basename(__file__))
-
-    defs = Defs()
-    error_msg = defs.check();  assert len(error_msg) == 0,"Expect empty defs to pass check"
-    suite = defs.add_suite("ext");
-
-    f1 = suite.add_family("f1")
-    f1.add_task("t").add_trigger("/a/b/c/d == complete");     check_then_auto_add_extern(defs)
-    f1.add_task("t1").add_trigger("/a/b/c/d/e:event == set"); check_then_auto_add_extern(defs)
-    f1.add_task("t2").add_trigger("/a/b/c/d/x:event");        check_then_auto_add_extern(defs)     
-    f1.add_task("t3").add_trigger("/a/b/c/d/y:meter le 30");  check_then_auto_add_extern(defs)  
-    f1.add_task("t4").add_trigger("/a/b/c/d/z<flag>late");    check_then_auto_add_extern(defs)   
-    
-    f2 = suite.add_family("f2")
-    f2.add_inlimit("hpcd","limits");                           check_then_auto_add_extern(defs)
-    f2.add_task("t").add_inlimit("sg1","/suiteName");          check_then_auto_add_extern(defs)
-    f2.add_task("t1").add_inlimit("hpcd","/obs/limits");       check_then_auto_add_extern(defs) 
-    f2.add_task("t2").add_inlimit("c1a","/limits");            check_then_auto_add_extern(defs)     
-    print (defs)
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestCopy.py 5.13.0-1/Pyext/test/py_u_TestCopy.py
--- 5.12.4-1/Pyext/test/py_u_TestCopy.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestCopy.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,515 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# code for testing copy
-#
-import ecflow
-import sys
-import os
-import copy
-import ecflow_test_util as Test
-
-if __name__ == "__main__":
-    
-    Test.print_test_start(os.path.basename(__file__))
-
-    defs = ecflow.Defs()
-    defs.add_suite("a").add_family("f1").add_task("t1").add_variable("a","b").add_event(1).add_meter("meter", 0, 100).add_label("label", "v").add_time("+00:30 20:00 01:00")
-    print(defs)
-    
-    defs_copy = copy.copy(defs)
-    print(defs_copy)
-    assert defs_copy == defs,"defs should be equal after copy"
-    
- 
-    #===========================================================================
-    # Defs: add and delete *USER* variables
-    #===========================================================================
-    defs = ecflow.Defs()
-    defs.add_variable("FRED", "/tmp/")
-    defs.add_variable("ECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
-    defs.add_variable("ECF_URL_BASE", "http://www.ecmwf.int")
-    defs.add_variable("ECF_URL", "publications/manuals/sms")
-    assert len(list(defs.user_variables)) == 4, "Expected *user* 4 variable"    
-    defs_copy = copy.copy(defs)
-    assert len(list(defs_copy.user_variables)) == 4, "Expected *user* 4 variable"    
-
-    defs.delete_variable("FRED");     assert len(list(defs.user_variables)) == 3, "Expected 3 variables since we just delete FRED"
-    defs.delete_variable("");         assert len(list(defs.user_variables)) == 0, "Expected 0 variables since we should have deleted all"
-    assert len(list(defs_copy.user_variables)) == 4, "Expected *user* 4 variable"    
-
-    #===========================================================================
-    # Suite: add and delete variables
-    #===========================================================================
-    suite = ecflow.Suite("s1")
-    suite.add_variable(ecflow.Variable("ECF_HOME", "/tmp/"))
-    suite.add_variable("ECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
-    suite.add_variable("ECF_URL_BASE", "http://www.ecmwf.int")
-    suite.add_variable("ECF_URL", "publications/manuals/sms")
-    assert len(list(suite.variables)) == 4, "Expected 4 variable"   
-    suite_copy = copy.copy(suite)
-    assert len(list(suite_copy.variables)) == 4, "Expected 4 variables in copy"   
-
-    #===========================================================================
-    # add and delete limits
-    #===========================================================================
-    suite.add_limit(ecflow.Limit("limitName1", 10))
-    suite.add_limit(ecflow.Limit("limitName2", 10))
-    suite.add_limit("limitName3", 10)
-    suite.add_limit("limitName4", 10)
-    assert len(list(suite.limits)) == 4, "Expected 4 Limits"
-    
-    suite_copy = copy.copy(suite)
-    assert len(list(suite_copy.limits)) == 4, "Expected 4 Limits in copy"
-    suite_copy.delete_limit("limitName1"); assert len(list(suite_copy.limits)) == 3, "Expected 3 limits since we just deleted one limitName1" 
-    suite_copy.delete_limit("");           assert len(list(suite_copy.limits)) == 0, "Expected 0 limits since we just deleted all of them"
-
-    #===========================================================================
-    # Test Limit and node paths 
-    #===========================================================================
-    the_limit = ecflow.Limit("limitName1", 10)
-    assert the_limit.name() == "limitName1", "name not as expected"
-    assert the_limit.value() == 0 ,"Expected limit value of 0"
-    assert the_limit.limit() == 10 ,"Expected limit of 10"
-    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
-    
-    the_limit.increment(1,"/path1") ;  assert the_limit.value() == 1 ,"Expected limit value of 1"
-    the_limit.increment(1,"/path2") ;  assert the_limit.value() == 2 ,"Expected limit value of 2"
-    the_limit.increment(1,"/path3") ;  assert the_limit.value() == 3 ,"Expected limit value of 3"
-    the_limit.increment(1,"/path4") ;  assert the_limit.value() == 4 ,"Expected limit value of 4"
-    for path in the_limit.node_paths(): print(path)
-    assert len(list(the_limit.node_paths())) == 4 ,"expected 4 path"
-    
-    limit_copy = copy.copy(the_limit)
-    assert len(list(limit_copy.node_paths())) == 4 ,"expected 4 path in copy"
-
-    limit_copy.decrement(1,"/path1") ; assert limit_copy.value() == 3 ,"Expected limit value of 3"
-    limit_copy.decrement(1,"/path2") ; assert limit_copy.value() == 2 ,"Expected limit value of 2"
-    limit_copy.decrement(1,"/path3") ; assert limit_copy.value() == 1 ,"Expected limit value of 1"
-    limit_copy.decrement(1,"/path4") ; assert limit_copy.value() == 0 ,"Expected limit value of 0"
-    assert len(list(limit_copy.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
-
-    limit_copy.increment(1,"/path1") # add same path, should only consume one token
-    limit_copy.increment(1,"/path1")
-    limit_copy.increment(1,"/path1")
-    limit_copy.increment(1,"/path1")
-    assert len(list(limit_copy.node_paths())) == 1 ,"expected 1 path"
-    assert limit_copy.value() == 1 ,"Expected limit value of 1"
-
-    #===========================================================================
-    # add and delete inlimits
-    #===========================================================================
-    suite.add_inlimit(ecflow.InLimit("limitName1", "/s1/f1", 2))
-    suite.add_inlimit(ecflow.InLimit("limitName2", "/s1/f1", 2, True))
-    suite.add_inlimit("limitName3", "/s1/f1", 2)
-    suite.add_inlimit("limitName4", "/s1/f1", 2, True)
-    assert len(list(suite.inlimits)) == 4, "Expected 4 inLimits"
-    
-    suite_copy = copy.copy(suite)
-    assert len(list(suite_copy.inlimits)) == 4, "Expected 4 inLimits"
-    suite_copy.delete_inlimit("limitName1"); assert len(list(suite_copy.inlimits)) == 3, "Expected 3 inlimits since we just deleted one limitName1" 
-    suite_copy.delete_inlimit("");           assert len(list(suite_copy.inlimits)) == 0, "Expected 0 inlimits since we just deleted all of them"
-
-    #===============================================================================
-    # add and delete triggers and complete
-    #===============================================================================
-    task = ecflow.Task("task")
-    task.add_trigger("t2 == active")
-    task.add_complete("t2 == complete")
-    
-    task_copy = copy.copy(task)
-    assert task_copy.get_complete(), "Expected complete"
-    assert task_copy.get_trigger(), "Expected trigger"
-    task_copy.delete_trigger();  assert not task_copy.get_trigger(), "Expected no trigger"
-    task_copy.delete_complete(); assert not task_copy.get_complete(), "Expected no complete"
-    
-    #===========================================================================
-    # Add triggers using expressions
-    #===========================================================================
-    expr = ecflow.Expression("t1 == complete")
-    task = ecflow.Task("task")
-    task.add_trigger(expr)
-    
-    task_copy = copy.copy(task)
-    assert task_copy.get_trigger(), "Expected trigger"
-
-    expr = ecflow.Expression("t1 == complete")
-    expr.add(ecflow.PartExpression("t1 == complete", True))
-    expr.add(ecflow.PartExpression("t2 == complete", True))
-    task = ecflow.Task("task")
-    task.add_trigger(expr)
-
-    task_copy = copy.copy(task)
-    assert task_copy.get_trigger(), "Expected trigger"
-
-     
-    #===========================================================================
-    # add,delete,find events
-    #===========================================================================
-    task.add_event(ecflow.Event(1)); 
-    task.add_event(2)                              
-    task.add_event(ecflow.Event(10, "Eventname"))  
-    task.add_event(10, "Eventname2")               
-    task.add_event("fred")                         
-    
-    # test find
-    task_copy = copy.copy(task)
-    event = task_copy.find_event("EVENT")
-    assert(event.empty()),"Expected to not find event"
-    assert(event.name() == ""),"Expected to not to find event, number is maximum int"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task_copy.find_event("1"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.number() == 1), "Expected to find event 1"
-    assert(event.name() == ""), "Expected name to be empty"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task_copy.find_event("2"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.number() == 2), "Expected to find event 1"
-    assert(event.name() == ""), "Expected name to be empty"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task_copy.find_event("10"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.number() == 10), "Expected to find event 10"
-    assert(event.name() == "Eventname"), "Expected name to be empty"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    event = task_copy.find_event("fred"); 
-    assert(not event.empty()),"Expected to find event"
-    assert(event.name() == "fred"), "Expected name to be empty, when name defind an not number, number is max_int"
-    assert(event.value() == 0),"Expected to not to find event"
-
-    for e in task_copy.events:     print(str(e)," # value: ",str(e.value()))
-    a_dict = {}
-    for e in task_copy.events:
-        if e.name() != "": a_dict[e.name()] = e.value()
-        else:              a_dict[e.number()] = e.value()
-    print(a_dict)
-
-    assert len(list(task_copy.events)) == 5, "Expected 5 Events"
-    task_copy.delete_event("1");         assert len(list(task_copy.events)) == 4, "Expected 4 Events"
-    task_copy.delete_event("Eventname"); assert len(list(task_copy.events)) == 3, "Expected 3 Events"
-    task_copy.delete_event("");          assert len(list(task_copy.events)) == 0, "Expected 0 Events"
-
-
-    #===========================================================================
-    # add and delete meter
-    #===========================================================================
-    task.add_meter(ecflow.Meter("metername1", 0, 100, 50))
-    task.add_meter(ecflow.Meter("metername2", 0, 100))
-    task.add_meter("metername3", 0, 100, 50)
-    task.add_meter("metername4", 0, 100)
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.meters)) == 4, "Expected 4 Meters"
-    task_copy.delete_meter("metername1"); assert len(list(task_copy.meters)) == 3, "Expected 3 Meters"
-    task_copy.delete_meter("metername4"); assert len(list(task_copy.meters)) == 2, "Expected 2 Meters"
-    task_copy.delete_meter("");           assert len(list(task_copy.meters)) == 0, "Expected 0 Meters"
-
-    #===========================================================================
-    # add and delete queue
-    #===========================================================================
-    queue_items = [ "a", "b"]
-    task.add_queue(ecflow.Queue("q1", queue_items ))
-    task.add_queue(ecflow.Queue("q2", queue_items))
-    task.add_queue("q3", [ "a", "b"])
-    task.add_queue("q4",  [ "a", "b"])
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.queues)) == 4, "Expected 4 queues"
-    task_copy.delete_queue("q1"); assert len(list(task_copy.queues)) == 3, "Expected 3 queues"
-    task_copy.delete_queue("q2"); assert len(list(task_copy.queues)) == 2, "Expected 2 queues"
-    task_copy.delete_queue("");   assert len(list(task_copy.queues)) == 0, "Expected 0 queues"
-
-    #===========================================================================
-    # copy generic
-    #===========================================================================
-    generic_items = [ "a", "b"]
-    task.add_generic(ecflow.Generic("q1",generic_items ))
-    task.add_generic(ecflow.Generic("q2",generic_items))
-    task.add_generic("q3", [ "a", "b"])
-    task.add_generic("q4",  [ "a", "b"])
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.generics)) == 4, "Expected 4  Generics after copy"
-    task_copy.delete_generic("q1"); assert len(list(task_copy.generics)) == 3, "Expected 3 Generics"
-    task_copy.delete_generic("q2"); assert len(list(task_copy.generics)) == 2, "Expected 2 Generics"
-    task_copy.delete_generic("");   assert len(list(task_copy.generics)) == 0, "Expected 0 Generics"
-
-    #===========================================================================
-    # add and delete label
-    #===========================================================================
-    task.add_label(ecflow.Label("label_name1", "value"))
-    task.add_label(ecflow.Label("label_name2", "value"))
-    task.add_label("label_name3", "value")
-    task.add_label("label_name4", "value")
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.labels)) == 4, "Expected 4 labels"
-    task_copy.delete_label("label_name1"); assert len(list(task_copy.labels)) == 3, "Expected 3 Labels"
-    task_copy.delete_label("label_name4"); assert len(list(task_copy.labels)) == 2, "Expected 2 Labels"
-    task_copy.delete_label("");            assert len(list(task_copy.labels)) == 0, "Expected 0 Labels"
-
-
-    #===========================================================================
-    # add delete Repeat
-    #===========================================================================
-    task = ecflow.Task("task")
-    task.add_repeat(ecflow.RepeatInteger("integer", 0, 100, 2))
-    task_copy = copy.copy(task)
-    repeat = task_copy.get_repeat(); assert not repeat.empty(), "Expected repeat"
-    task_copy.delete_repeat()      
-    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    task = ecflow.Task("task")
-    task.add_repeat(ecflow.RepeatEnumerated("enum", ["red", "green", "blue" ]))
-    task_copy = copy.copy(task)
-    task_copy.delete_repeat()      
-    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task = ecflow.Task("task")
-    task.add_repeat(ecflow.RepeatDate("date", 20100111, 20100115, 2))
-    task_copy = copy.copy(task)
-    task_copy.delete_repeat()      
-    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task = ecflow.Task("task")
-    task.add_repeat(ecflow.RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00"))
-    task_copy = copy.copy(task)
-    task_copy.delete_repeat()
-    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
-
-    task = ecflow.Task("task")
-    task.add_repeat(ecflow.RepeatDateList("date", [20100111, 20100115]))
-    task_copy = copy.copy(task)
-    task_copy.delete_repeat()      
-    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    task = ecflow.Task("task")
-    task.add_repeat(ecflow.RepeatString("string", ["a", "b", "c" ]))
-    task_copy = copy.copy(task)
-    task_copy.delete_repeat()      
-    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
-    
-    
-    #===========================================================================
-    # create a time series, used for adding time and today
-    #===========================================================================
-    start = ecflow.TimeSlot(0, 0)
-    finish = ecflow.TimeSlot(23, 0)
-    incr = ecflow.TimeSlot(0, 30)
-    time_series = ecflow.TimeSeries(start, finish, incr, True)
-
-    # Add and delete today
-    # NOTE: **********************************************************************
-    # Do *NOT* delete attributes using iterator traversal
-    # The iterators *are* bound to the c++ iterators hence if we delete
-    # over the traversal, we can corrupt the vector, leading to undefined behavour.  
-    # Hence we **cannot** delete more than once over a traversal
-    # Soln 1: take a copy
-    # *****************************************************************************
-    # task.add_today( Today( 0,10 ))
-    # task.add_today( Today( 0,59, True ))
-    # task.add_today( Today(TimeSlot(20,10)) )
-    # task.add_today( Today(TimeSlot(20,20),False)) 
-    # for today in task.todays: 
-    #    task.delete_today(today) # will corrupt C++ vector
-  
-    task.add_today("00:30")
-    task.add_today("+00:30")
-    task.add_today("+00:30 20:00 01:00")
-    task.add_today(ecflow.Today(time_series))
-    task.add_today(ecflow.Today(0, 10))
-    task.add_today(0, 59, True)
-    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 10)))
-    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 20), False)) 
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.todays)) == 8, "Expected 8 todays"
-    vec_copy = []
-    for today in task_copy.todays: vec_copy.append(today)
-    for today in vec_copy: task_copy.delete_today(today)
-    assert len(list(task_copy.todays)) == 0, "Expected 0 todays"
-        
-    #===========================================================================
-    # add and delete time
-    #===========================================================================
-    task.add_time("00:30")
-    task.add_time("+00:30")
-    task.add_time("+00:30 20:00 01:00")
-    task.add_time(ecflow.Time(time_series))
-    task.add_time(ecflow.Time(0, 10))
-    task.add_time(0, 59, True)
-    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 10)))
-    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 20), False)) 
-
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.times)) == 8, "Expected 8 times"
-    vec_copy = []
-    for time in task_copy.times: vec_copy.append(time)
-    for time in vec_copy: task_copy.delete_time(time)
-    assert len(list(task_copy.times)) == 0, "Expected 0 todays"
-
-    #===========================================================================
-    # add and delete date
-    #===========================================================================
-    for i in [ 1, 2, 4, 8, 16 ] :
-        task.add_date(i, 0, 0)
-    task.add_date(ecflow.Date(1, 1, 2010))
-    task.add_date(1, 1, 2010)       # duplicate
-    task.add_date(ecflow.Date(2, 1, 2010))
-    task.add_date(ecflow.Date(3, 1, 2010))
-    task.add_date(ecflow.Date(4, 1, 2010)) 
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.dates)) == 10, "Expected 10 dates but found " + str(len(list(task_copy.dates)))
-    vec_copy = []
-    for attr in task_copy.dates: vec_copy.append(attr)
-    for attr in vec_copy: task_copy.delete_date(attr)
-    assert len(list(task_copy.dates)) == 0, "Expected 0 dates"
-
-    #===========================================================================
-    # add and delete day
-    #===========================================================================
-    task.add_day(ecflow.Day(ecflow.Days.sunday))
-    task.add_day(ecflow.Days.monday)
-    task.add_day(ecflow.Days.tuesday)  # duplicate ?
-    task.add_day("sunday")     
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.days)) == 4, "Expected 4 days"
-    vec_copy = []
-    for attr in task_copy.days: vec_copy.append(attr)
-    for attr in vec_copy: task_copy.delete_day(attr)
-    assert len(list(task_copy.days)) == 0, "Expected 0 days"
-    
-    #===========================================================================
-    # add and delete crons
-    #===========================================================================
-    cron = ecflow.Cron()
-    start = ecflow.TimeSlot(23 , 0)
-    ts = ecflow.TimeSeries(start,True)  # True means relative to suite start
-    cron.set_time_series(ts)
-    
-    cron = ecflow.Cron()
-    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])
-    cron.set_days_of_month([1, 2, 3, 4, 5, 6 ])
-    cron.set_months([1, 2, 3, 4, 5, 6])
-    start = ecflow.TimeSlot(0 , 0)
-    finish = ecflow.TimeSlot(23, 0)
-    incr = ecflow.TimeSlot(0, 30)
-    ts = ecflow.TimeSeries(start, finish, incr, True)  # True means relative to suite start
-    cron.set_time_series(ts)
-
-    cron0 = ecflow.Cron()
-    cron0.set_week_days([0, 1, 2, 3, 4, 5 ])
-    cron0.set_time_series(1, 30) # default relative = false, added in release 4.0.7
-
-    cron1 = ecflow.Cron()
-    cron1.set_week_days([0, 1, 2, 3, 4, 5, 6 ])
-    cron1.set_time_series(1, 30, True)
-    
-    cron2 = ecflow.Cron()
-    cron2.set_week_days([0, 1, 2, 3, 4, 5, 6])
-    cron2.set_time_series("00:30 01:30 00:01")
-    
-    cron3 = ecflow.Cron()
-    cron3.set_week_days([0, 1, 2, 3, 4, 5, 6])
-    cron3.set_time_series("+00:30")
-
-    task = ecflow.Task("task")
-    task.add_cron(cron)
-    task.add_cron(cron1)
-    task.add_cron(cron2)
-    task.add_cron(cron3)
-    
-    task_copy = copy.copy(task)
-    assert len(list(task_copy.crons)) == 4, "Expected 4 crons"
-    vec_copy = []
-    for attr in task_copy.crons: vec_copy.append(attr)
-    for attr in vec_copy: task_copy.delete_cron(attr)
-    assert len(list(task_copy.crons)) == 0, "Expected 0 crons"  
-    
-    #===========================================================================
-    # add autocancel
-    #===========================================================================
-    print("test add autoCancel")
-    t1 = ecflow.Task("t1")
-    assert t1.get_autocancel() is None, " Expected no autocancel"
-    t1.add_autocancel(3)  # 3 days
-    
-    task_copy = copy.copy(t1)
-    assert task_copy.get_autocancel() is not None, " Expected autocancel"
-    print(str(task_copy.get_autocancel()))
-
-    #===========================================================================
-    # add late  
-    #===========================================================================
-    late = ecflow.Late()
-    late.submitted(ecflow.TimeSlot(20, 10))
-    late.active(ecflow.TimeSlot(20, 10))
-    late.complete(ecflow.TimeSlot(20, 10), True)
-    task.add_late(late)
-    task_copy = copy.copy(task)
-    assert task_copy.get_late() is not None, " Expected late"
-    
-    #===========================================================================
-    # add defstatus, last one set takes effect
-    #===========================================================================
-    task.add_defstatus(ecflow.DState.complete)
-    task_copy = copy.copy(task)
-    assert task_copy.get_defstatus() == ecflow.DState.complete
-
-    #===========================================================================
-    # add clock
-    #===========================================================================
-    clock = ecflow.Clock(1, 1, 2010, False)     # day,month, year, hybrid
-    clock.set_gain(1, 10, True)                 # True means positive gain
-    suite = ecflow.Suite("suite")
-    assert suite.get_clock() is None, "Expected no clock"
-    suite.add_clock(clock)
-    
-    suite_copy = copy.copy(suite)
-    assert suite_copy.get_clock() is not None, "expected clock"
-    
-    #===========================================================================
-    # Add zombie. Note we can *NOT* add two zombie attributes of the same ZombieType
-    #===========================================================================
-    s1 = ecflow.Task("s1")
-    zombie_life_time_in_server = 800
-    child_list = [ ecflow.ChildCmdType.init, ecflow.ChildCmdType.event, ecflow.ChildCmdType.meter, ecflow.ChildCmdType.label, ecflow.ChildCmdType.wait, ecflow.ChildCmdType.abort, ecflow.ChildCmdType.complete ]
-    zombie_type_list = [ ecflow.ZombieType.ecf, ecflow.ZombieType.ecf_pid, ecflow.ZombieType.ecf_pid_passwd, ecflow.ZombieType.ecf_passwd, ecflow.ZombieType.user, ecflow.ZombieType.path ]
-    for zombie_type in zombie_type_list:
-        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block, zombie_life_time_in_server)
-        s1.add_zombie(zombie_attr)
-    task_copy = copy.copy(s1)
-    assert len(list(task_copy.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(task_copy.zombies)))
-    
-    # delete all the zombies
-    s1.delete_zombie("")
-    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
-    
-    # add with zombie_life_time_in_server not set, this is optional
-    for zombie_type in zombie_type_list:
-        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block)
-        s1.add_zombie(zombie_attr)
-    task_copy = copy.copy(s1)
-    assert len(list(task_copy.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(task_copy.zombies)))
-
-    s1.delete_zombie("")
-    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
-
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestDefs.py 5.13.0-1/Pyext/test/py_u_TestDefs.py
--- 5.12.4-1/Pyext/test/py_u_TestDefs.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestDefs.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,241 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-#  code for testing creation of defs file in python
-import os
-import ecflow
-
-print(ecflow.__doc__)
-print(ecflow.Defs.__doc__)
-    
-from ecflow import Suite, Family, Task, Defs, Clock, DState, PartExpression, Variable, Limit, InLimit, \
-                   Date, Day, Event, Meter, Label, Autocancel, Days, TimeSlot, TimeSeries, Style, State, \
-                   RepeatString, RepeatDate, RepeatDateTime, RepeatInteger, RepeatDay, RepeatEnumerated, \
-                   Verify, PrintStyle, Time, Today, Late, Cron, Client, debug_build,Ecf
-import ecflow_test_util as Test
-
-if __name__ == "__main__":
-    
-    Test.print_test_start(os.path.basename(__file__))
-
-    suite = Suite("s1")
-    assert (isinstance(suite, ecflow.Suite)), "Expected suite"
-    assert (not isinstance(suite, ecflow.Family)), "Expected suite"
-    assert (not isinstance(suite, ecflow.Task)), "Expected suite"
- 
-    family = Family("f1")
-    assert (isinstance(family, ecflow.Family)), "Expected Family"
-    assert (not isinstance(family, ecflow.Suite)), "Expected Family"
-    assert (not isinstance(family, ecflow.Task)), "Expected Family"
-    suite.add_family(family)
-
-    task = Task("f1")
-    assert (isinstance(task, ecflow.Task)), "Expected Task"
-    assert (not isinstance(task, ecflow.Suite)), "Expected Task"
-    assert (not isinstance(task, ecflow.Family)), "Expected Task"
-    family.add_task(task)
-
-    
-    defs = Defs()
-    defs2 = Defs()
-    assert defs == defs2, "Empty defs should be equal"
- 
-    assert defs.get_state() == ecflow.State.unknown, "Expected default state to be unknown"
-    defs.add_suite(suite);  # add existing suite to defs
- 
-    suite = defs.add_suite("s2");
-    suite.add_variable(Variable("ECF_HOME","/tmp/"))
-    suite.add_variable("ECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
-    suite.add_variable("ECF_URL_BASE","http://www.ecmwf.int")
-    suite.add_variable("ECF_URL","publications/manuals/sms")
-    suite.add_limit( Limit("limitName", 10) )
-    suite.add_limit( "limitName_2", 10 )
-    assert suite.begun() == False, "Suite should not have begun"
-
-    clock = Clock(1,1,2010,False);
-    clock.set_gain(1,10,True);
-    suite.add_clock(clock);
-
-    assert defs != defs2, "Defs should no longer compare as they are different"
-    
-    defs.add_extern("/path/to/task");
-    defs.add_extern("/fred/bill:event_name");
-    
-    family = suite.add_family("f1")
-    family.add_defstatus( DState.active );
-
-    task = family.add_task("t1")
-    task.add_trigger( "t2 == active" )
-    task.add_complete( "t2 == complete" )
-    task.add_autocancel( Autocancel(3) );
-
-    task2 = family.add_task("t2")
-    task2.add_defstatus(  DState.complete );
-    task2.add_part_trigger(  PartExpression("t1 == complete") )
-    task2.add_part_trigger(  PartExpression("t1 == active",True) )  #  for long and/or expressions, subsequent expr must be and/or
-    task2.add_part_complete( PartExpression("t1 == complete") )
-    task2.add_part_complete( PartExpression("t1 == active",False) )  #  for long and/or expressions, subsequent expr must be and/or
-    task2.add_label(      Label("labelname", "label1") )
-    task2.add_label(      "labelname2", "label1")
-    task2.add_inlimit(    InLimit("limitName","/s1/f1",2) )
-    task2.add_inlimit(    InLimit("limitName1","/s1/f1",2,True) )
-    task2.add_inlimit(    "limitName2" )
-    task2.add_inlimit(    "limitName3","path" )
-    task2.add_inlimit(    "limitName4","path",1 )
-    task2.add_inlimit(    "limitName5","path",1,True )
-    task2.add_event(      10 )
-    task2.add_event(      Event(10,"Eventname") )
-    task2.add_meter(      Meter("metername",0,100,50) )
-    task2.add_meter(      "metername2",0,100,50 )
-    task2.add_date(       Date(1,1,2010) )
-    task2.add_date(       1,2,2010 )
-    task2.add_day(        Day(Days.sunday) )
-    task2.add_day(        Days.monday )
-    task2.add_autocancel( Autocancel(TimeSlot(20,10),True) )
-
-    task2.add_today(      0,10 )
-    task2.add_today(      Today( 0,59, True ))
-    task2.add_today(      Today(TimeSlot(20,10)) )
-    task2.add_today(      Today(TimeSlot(20,20),False)) 
-    start = TimeSlot(0,0)
-    finish = TimeSlot(23,0)
-    incr = TimeSlot(0,30)
-    ts = TimeSeries( start, finish, incr, True);
-    task2.add_today(      Today(ts) )
-
-    task2.add_time(       20,10 )
-    task2.add_time(       Time(20,12,True) )
-    task2.add_time(       Time(TimeSlot(20,12))) 
-    task2.add_time(       Time(TimeSlot(20,20),True)) 
-    task2.add_time(       Time(ts) )
-    
-    late = Late()
-    late.submitted( 20,10 )
-    late.active(TimeSlot(20,10))
-    late.complete(TimeSlot(20,10),True)
-    task2.add_late(  late )
-        
-    cron = Cron()
-    cron.set_week_days( [0,1,2,3,4,5,6] )
-    cron.set_days_of_month(  [1,2,3,4,5,6] )
-    cron.set_months( [1,2,3,4,5,6] )
-    cron.set_time_series( ts )
-    task2.add_cron( cron );
-    
-    task3 = family.add_task("t3")
-    task3.add_repeat( RepeatDate("testDate",20100111,20100115,2) )
-    task3.add_defstatus( DState.queued );
-    task3.add_verify( Verify(State.complete, 1) )
-    task3.add_autocancel( Autocancel(20,10,False) )
-    task3.add_label( Label("label_name","label_value") )
-
-    task3_1 = family.add_task("t3_1")
-    task3_1.add_repeat( RepeatDate("testDate",20100111,20100115) )
-
-    task3_2 = family.add_task("t3_2")
-    task3_2.add_repeat(RepeatDateTime("testDateTime", "20100111T000000", "20100115T000000"))
-
-
-    task4 = family.add_task("t4")
-    task4.add_repeat( RepeatInteger("testInteger",0,100,2) )
-    task4.add_defstatus( DState.aborted );
-    
-    task4_1 = family.add_task("t4_1")
-    task4_1.add_repeat( RepeatInteger("testInteger",0,100) )
- 
-    
-    task5 = family.add_task("t5")
-    task5.add_repeat( RepeatEnumerated("testInteger", ["red", "green", "blue" ] ) )
-    task5.add_defstatus( DState.submitted );
-        
-    task6 = family.add_task("t6")
-    task6.add_repeat( RepeatString("test_string",  ["a", "b", "c" ] ) )
-    task6.add_defstatus( DState.suspended );
-    
-    task7 = family.add_task("t7")
-    task7.add_repeat( RepeatDay(2) )
-    task7.add_defstatus( DState.active );
-    
-    task8 = family.add_task("t8")
-    task8.add_repeat( RepeatDay() )
-    print("task8.get_try_no()    :string:",task8.get_try_no())
-    print("task8.get_int_try_no():int   :",task8.get_int_try_no())
-    
-    the_defs = task8.get_defs()
- 
-          
-    # Test find      
-    assert defs.find_suite("s1") is not None, "Expected to find suite of name s1"
-    assert defs.find_suite("sffff1") is None, "Should not be able to find suite of name sfffff1"
-        
-    # save the defs file as a check point file and restore it again
-    checkpt_file = "py_u_TestDefs.check"
-    defs_file = "py_u_TestDefs.def"
-    if debug_build() :
-        checkpt_file = "py_u_TestDefs_debug.check"
-        defs_file = "py_u_TestDefs_debug.def"
-    defs.save_as_checkpt(checkpt_file);
-    
-    restored_checkpt_defs = Defs()
-    restored_checkpt_defs.restore_from_checkpt(checkpt_file)
-    
-    print("Save and restore as Defs ******************************************************")
-    defs.save_as_defs(defs_file)           # default is to save as DEFS
-    restored_from_defs = Defs( defs_file ) # restore the defs
-
-    defs.save_as_defs(defs_file,Style.DEFS)
-    restored_from_defs = Defs( defs_file ) # restore the defs
-            
-    print("Save and restore using STATE ******************************************************")
-    defs.save_as_defs(defs_file,Style.STATE)
-    restored_from_defs = Defs( defs_file ) # restore the defs
-
-    print("Save and restore using MIGRATE ******************************************************")
-    defs.save_as_defs(defs_file,Style.MIGRATE)
-    restored_from_defs = Defs( defs_file ) # restore the defs
-    assert restored_checkpt_defs == restored_from_defs ,"File should be the same"
-
-        
-    print("Print in DEFS style ******************************************************")
-    PrintStyle.set_style(Style.DEFS)
-    the_string = str(restored_from_defs)
-    assert the_string.find("defs_state") == -1, "Print in DEFS style failed"
-    print(the_string)
-    
-    print("Print in STATE style *****************************************************")
-    PrintStyle.set_style(Style.STATE)
-    the_string = str(restored_from_defs)
-    assert the_string.find("defs_state STATE") != -1, "Print in STATE style failed"
-    print(the_string)
-    
-    print("Print in MIGRATE style *****************************************************")
-    PrintStyle.set_style(Style.MIGRATE)
-    the_string = str(restored_from_defs)
-    assert the_string.find("defs_state MIGRATE") != -1, "Print in MIGRATE style failed"
-    print(the_string)
-     
-    # Comment this out if you want to see what the file looked like
-    os.remove(checkpt_file)
-    os.remove(defs_file)
-    
-    # Test job creation failure
-    msg = defs.check_job_creation()
-    assert len(msg) != 0 ,"Expected job creation to fail"
-    
-    expected_exeption = False;
-    try:
-        defs.check_job_creation(throw_on_error=True) 
-    except RuntimeError as e:
-        expected_exeption = True
-    assert expected_exeption,"expected exception"  
- 
-    print("All tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestDefsCheck.py 5.13.0-1/Pyext/test/py_u_TestDefsCheck.py
--- 5.12.4-1/Pyext/test/py_u_TestDefsCheck.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestDefsCheck.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,71 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-#  Test the error and waning checks defined in the defs work
-import os
-from ecflow import  Defs, Limit, InLimit, Client, debug_build
-import ecflow_test_util as Test
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
-     
-    defs = Defs()
-    suite = defs.add_suite("s1");
-    suite.add_task("t1").add_trigger("t2 == active)")   
-    theCheckValue = defs.check();
-    print("Message: '" + theCheckValue + "'")
-    assert len(theCheckValue) != 0,  "Expected Error: triggers fail parse, miss-matched brackets in expression."
- 
-    # The number of tokens specified on the in-limit must be less than or equal to those specified on the LIMIT
-    defs = Defs()
-    suite = defs.add_suite("s1");
-    suite.add_limit( Limit("disk", 50) );
-    family = suite.add_family("anon");
-    family.add_inlimit( InLimit("disk","/s1",100) )
-    family.add_task( "t1" );
-    theCheckValue = defs.check();
-    print("Message: '" + theCheckValue + "'")
-    assert len(theCheckValue) != 0,  "Expected Error: since inlimit value('100') is greater than the LIMIT value('50')"  
-
-
-    # When a path is specified on the in-limit we search for the limit on that path, otherwise the extern's
-    defs = Defs()
-    suite = defs.add_suite("s1");
-    family = suite.add_family("anon");
-    family.add_inlimit( InLimit("disk","/s1",100) )
-    family.add_task( "t1" );
-    theCheckValue = defs.check();
-    print("Message: '" + theCheckValue + "'")
-    assert len(theCheckValue) != 0,  "Expected warning: since inlimit PATH(/s1:disk) reference a limit('disk') that does not exist"  
-    
-    # Add as extern and repeat the check
-    defs.add_extern("/s1:disk")
-    assert len(defs.check()) == 0,  "Expected no warnings, since extern specified: "  + defs.check()
-
-
-    # When no path is specified on the in-limit, we search for the limit up the node tree, otherwise the extern's
-    defs = Defs()
-    suite = defs.add_suite("s1");
-    family = suite.add_family("anon");
-    family.add_inlimit( InLimit("disk","",100) )
-    family.add_task( "t1" );
-    theCheckValue = defs.check();
-    print("Message: '" + theCheckValue + "'")
-    assert len(theCheckValue) != 0,  "Expected warning: since inlimit SHOULD reference a limit('disk') somewhere UP parent hierarchy"  
-    
-    # Add as extern and repeat the check
-    defs.add_extern("disk")
-    assert len(defs.check()) == 0,  "Expected no warnings, since extern specified"  
-    
-    print("All Tests pass")
-    
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_TestDerivable.py 5.13.0-1/Pyext/test/py_u_TestDerivable.py
--- 5.12.4-1/Pyext/test/py_u_TestDerivable.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestDerivable.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-#  code for testing derivation works
-import os
-import sys
-import ecflow
-import ecflow_test_util as Test
-
-class MyDefs(ecflow.Defs): pass
-class MySuite(ecflow.Suite): pass
-class MyFamily(ecflow.Family): pass
-class MyTask(ecflow.Task): pass
-class MyClient(ecflow.Client): pass
-
-if sys.version_info[0] > 2:
-    class MySuite2(ecflow.Suite):
-        def __init__(self, name):
-            super().__init__(name)
-    
-    class MyFamily2(ecflow.Family):
-        def __init__(self, name):
-            super().__init__(name)
-    
-    class MyTask2(ecflow.Task):
-        def __init__(self, name):
-            super().__init__(name)
-
-    n = MySuite2('s')
-    print(n)
-
-    n = MyFamily2('f')
-    print(n)
-
-    n = MyTask2('t')
-    print(n)
-
-else:
-    print("Python2 ignoring derivation test")
-
-
-if __name__ == "__main__":
-    
-    Test.print_test_start(os.path.basename(__file__))
-    print("All tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestEcf.py 5.13.0-1/Pyext/test/py_u_TestEcf.py
--- 5.12.4-1/Pyext/test/py_u_TestEcf.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestEcf.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,38 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-#  code for testing creation of defs file in python
-import os
-import ecflow
-      
-from ecflow import Ecf, Client, debug_build
-
-if __name__ == "__main__":
-    print("####################################################################")
-    print("Running TestEcf, ecflow version " + Client().version() + " debug build(" + str(debug_build()) +")")
-    print("####################################################################")
-    
-    default_debug_level = Ecf.debug_level()
-    assert default_debug_level == 0, "Expected default debug level to be 0"
-    Ecf.set_debug_level(10)
-    assert  Ecf.debug_level() == 10, "Expected debug level to be 10"
-    Ecf.set_debug_level(0)
-    assert  Ecf.debug_level() == 0, "Expected debug level to be 0"
-
-
-    assert  Ecf.debug_equality() == False, "Expected  default for Ecf.debug_equality() == False "
-    Ecf.set_debug_equality(True)
-    assert  Ecf.debug_equality() == True, "Expected  debug_equality() == True "
-    Ecf.set_debug_equality(False)
-    assert  Ecf.debug_equality() == False, "Expected  Ecf.debug_equality() == False "
-
-    print("All tests pass")
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_TestError.py 5.13.0-1/Pyext/test/py_u_TestError.py
--- 5.12.4-1/Pyext/test/py_u_TestError.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestError.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,608 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-#  code for testing errors in creation of defs file in python
-
-import os
-from ecflow import Day, Date, Meter, Event, Queue, Clock, Variable, Label, Limit, InLimit, \
-                   RepeatDate, RepeatDateTime, RepeatEnumerated, RepeatInteger, RepeatString, \
-                   Task, Family, Suite, Defs, Client, debug_build, Trigger
-import ecflow_test_util as Test
-
-def check_day(day):
-    try:    
-        Day(day)
-        return True
-    except RuntimeError: 
-        return False
-
-def check_date(day,month,year):
-    try:    
-        Date(day,month,year)
-        return True
-    except IndexError: 
-        return False
-    
-def check_date_str(str_date):
-    try:    
-        Date( str_date)
-        return True
-    except IndexError: 
-        return False
-    except  RuntimeError: 
-        return False
-
-def check_meter(name,min_meter_value,max_meter_value,color_change):
-    try:    
-        Meter(name,min_meter_value,max_meter_value,color_change)
-        return True
-    except IndexError: 
-        return False
-    except RuntimeError: 
-        return False
-
-def check_queue(name,queue_items):
-    try:    
-        Queue(name, queue_items)
-        return True
-    except IndexError: 
-        return False
-    except RuntimeError: 
-        return False
-    
-def check_event_number_and_name(number,name):
-    try:    
-        Event(number,name)
-        return True
-    except: 
-        return False
-    
-def check_event(number):
-    try:    
-        Event(number)
-        return True
-    except RuntimeError: 
-        return False
-        
-def check_clock(day_of_month,month,year):
-    try:    
-        Clock(day_of_month,month,year)
-        return True
-    except IndexError: 
-        return False
-
-def check_variable(name,value):
-    try:    
-        Variable(name,value)
-        return True
-    except RuntimeError: 
-        return False
-    
-def check_label(name,value):
-    try:    
-        Label(name,value)
-        return True
-    except RuntimeError: 
-        return False
-    
-def check_limit(name,int_token):
-    try:    
-        Limit(name,int_token)
-        return True
-    except RuntimeError: 
-        return False
-    except TypeError: 
-        return False
-    
-def check_inlimit(name,path_to_node,int_token):
-    try:    
-        InLimit(name,path_to_node,int_token)
-        return True
-    except RuntimeError: 
-        return False
-    except TypeError: 
-        return False
-        
-def check_repeat_date(name, start, end, step):
-    try:    
-        RepeatDate(name,start,end,step)
-        return True
-    except RuntimeError: 
-        return False
-
-def check_repeat_datetime(name, start, end, step):
-    try:
-        RepeatDateTime(name,start,end,step)
-        return True
-    except RuntimeError:
-        return False
-
-def check_repeat_integer(name, start, end, step):
-    try:    
-        RepeatInteger(name,start,end,step)
-        return True
-    except RuntimeError: 
-        return False
-    except TypeError: 
-        return False
-
-def check_repeat_enumerated(name, list_of_strings):
-    try:    
-        RepeatEnumerated(name,list_of_strings)
-        return True
-    except RuntimeError: 
-        return False
-    except TypeError: 
-        return False
- 
-def check_repeat_string(name, list_of_strings):
-    try:    
-        RepeatString(name,list_of_strings)
-        return True
-    except RuntimeError: 
-        return False
-    except TypeError: 
-        return False
-        
-def check_node_name(name):
-    try:
-        Task(name)
-        Family(name)
-        Suite(name)
-        return True;
-    except RuntimeError: 
-        return False
-  
-def check_defs(path_to_defs):
-    try:    
-        Defs(path_to_defs)
-        return True
-    except RuntimeError: 
-        return False
-          
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
- 
-    # Names with leading '.' should not be allowed. Will interfere with triggers
-    # Empty names not allowed
-    # Spaces not allowed
-    invalid_names = [ ".", "", " ","   ",  "fred doc", "1 "]
-    
-    # Allow names with leading underscore
-    valid_names = [ "_", "__", "_._", "1.2", "fred.doc", "_.1"]
-    
-    assert check_day("monday"),            "Expected valid day"
-    assert check_day("tuesday"),           "Expected valid day"
-    assert check_day("wednesday"),         "Expected valid day"
-    assert check_day("thursday"),          "Expected valid day"
-    assert check_day("friday"),            "Expected valid day"
-    assert check_day("saturday"),          "Expected valid day"
-    assert check_day("sunday"),            "Expected valid day"
-    assert check_day("")        == False,  "Expected exeception"
-    assert check_day("sunday1") == False,  "Expected exeception"
-    assert check_day("2")       == False,  "Expected exeception"
-
-    assert check_date(0,1,2010),            "Expected valid date"
-    assert check_date(10,0,2010),           "Expected valid date"
-    assert check_date(10,1,0),              "Expected valid date"
-    assert check_date(0,0,0),               "Expected valid date"
-    assert check_date(40,1,2010) == False,  "Expected exception since day > 31"
-    assert check_date(-10,1,2010) == False, "Expected exception since day >= 0"
-    assert check_date(1,14,2010) == False,  "Expected exception since month > 12"
-    assert check_date(1,-1,2010) == False,  "Expected exception since month >= 0"
-    assert check_date(1,1,-2) == False,     "Expected exception since year >= 0"
-
-    assert check_date_str("*.1.2010"),            "Expected valid date"
-    assert check_date_str("10.*.2010"),           "Expected valid date"
-    assert check_date_str("10.1.*"),              "Expected valid date"
-    assert check_date_str("*.*.*"),               "Expected valid date"
-    assert check_date_str("40.1.2010") == False,  "Expected exception since day > 31"
-    assert check_date_str("-10.1.2010") == False, "Expected exception since day >= 0"
-    assert check_date_str("1.14.2010") == False,  "Expected exception since month > 12"
-    assert check_date_str("1.-1.2010") == False,  "Expected exception since month >= 0"
-    assert check_date_str("1.1.-2") == False,     "Expected exception since year >= 0"
-
-    # clock do not support wild carding hence we cant use 0 like in Date
-    assert check_clock(12,1,2010),           "Expected valid date"
-    assert check_clock(10,1,2010),           "Expected valid date"
-    assert check_clock(10,1,1400),           "Expected valid date"
-    assert check_clock(31,12,2010),          "Expected valid date"
-    assert check_clock(40,1,2010) == False,  "Expected exception since day > 31"
-    assert check_clock(-10,1,2010) == False, "Expected exception since day >= 0"
-    assert check_clock(1,14,2010) == False,  "Expected exception since month > 12"
-    assert check_clock(1,-1,2010) == False,  "Expected exception since month >= 0"
-    assert check_clock(1,1,-2) == False,     "Expected exception since year >= 0"
-
-    assert check_meter("m",0,100,100),             "Expected valid Meter"
-    assert check_meter("m",0,100,0),               "Expected valid Meter"
-    assert check_meter("m",200,100,100) == False,  "Expected exception since min > max"
-    assert check_meter("m",0,100,-20) == False,    "Expected exception since color_change should between min-max"
-    assert check_meter("m",0,100,200) == False,    "Expected exception since color_change should between min-max"
-    assert check_meter("",0,100,100) == False,     "Expected exception since no name specified"
-    assert check_meter(" ",0,100,100) == False,    "Expected Exception cannot have spaces for a name"
-
-    assert check_queue("m",["a"]),                 "Expected valid Queue"
-    assert check_queue("m",["a","b"]),             "Expected valid Queue"
-    assert check_queue("",["a","b"]) == False,     "Expected exception queue name is empty"
-    assert check_queue(" ",["a","b"]) == False,    "Expected Exception cannot have spaces for a name"
-    assert check_queue(".",["a","b"]) == False,    "Expected Exception cannot start name with a ."
-    assert check_queue("m",[]) == False,           "Expected Exception queue items list is empty"
- 
-    assert check_event(1),                            "Expected valid Event"
-    assert check_event(2),                            "Expected valid Event"
-    assert check_event_number_and_name(2,"fred"),     "Expected valid Event"
-    assert check_event_number_and_name(2,2) == False, "Expected failure since the name is not a string"
-
-    assert check_repeat_date("m",20000101,20001201,200),          "Expected valid repeat"
-    assert check_repeat_date("m",20001201,20000101,200) == False, "Expected exception since end YMD > start YMD"
-    assert check_repeat_date("m",200001011,20001201,200)== False, "Expected Exception since start is invalid."
-    assert check_repeat_date("m",20000101,200012013,200)== False, "Expected Exception since send is invalid."
-    assert check_repeat_date("m",00000000,00000000,200)== False,  "Expected Exception since start/end are not valid dates is invalid."
-    assert check_repeat_date("",20000101,20001201,200)==False,    "Expected Exception since no name specified"
-    assert check_repeat_date(" ",20000101,20001201,200)==False,   "Expected Exception cannot have spaces for a name"
-    assert check_repeat_datetime("m", "20000101T000000", "20001201T000000", "4800:00:00"), "Expected valid repeat"
-    assert check_repeat_datetime("m", "20001201T000000", "20000101T000000", "4800:00:00") == False, "Expected exception since end YMD > start YMD"
-    assert check_repeat_datetime("m", "200001011T000000", "20001201T000000", "4800:00:00") == False, "Expected Exception since start is invalid."
-    assert check_repeat_datetime("m", "20000101T000000", "200012013T000000", "4800:00:00") == False, "Expected Exception since send is invalid."
-    assert check_repeat_datetime("m", "00000000T000000", "00000000T000000", "4800:00:00") == False, "Expected Exception since start/end are not valid dates is invalid."
-    assert check_repeat_datetime("", "20000101T000000", "20001201T000000", "4800:00:00") == False, "Expected Exception since no name specified"
-    assert check_repeat_datetime(" ", "20000101T000000", "20001201T000000", "4800:00:00") == False, "Expected Exception cannot have spaces for a name"
-    assert check_repeat_integer("name",0, 10, 2 ),                "Expected valid repeat"
-    assert check_repeat_integer("",0, 10, 2 )==False,             "Expected Exception since no name specified"
-    assert check_repeat_integer(" ",0, 10, 2 )==False,            "Expected Exception cannot have spaces for a name"
-    assert check_repeat_string("name",[ "a" ]),                   "Expected valid repeat"
-    assert check_repeat_string("",["a"] )==False,                 "Expected Exception since no name specified"
-    assert check_repeat_string(" ",["a"] )==False,                "Expected Exception cannot have spaces for a name"
-    assert check_repeat_string("name",[ 1,2 ])==False,            "Expected Exception since a list of strings was expected"
-    assert check_repeat_string("name",[])==False,                 "Expected Exception since list of strings is empty"
-    assert check_repeat_enumerated("name",[ "a" ]),               "Expected valid repeat"
-    assert check_repeat_enumerated("",["a"] )==False,             "Expected Exception since no name specified"
-    assert check_repeat_enumerated(" ",["a"] )==False,            "Expected Exception since no name specified"
-    assert check_repeat_enumerated("name",[ 1,2 ])==False,        "Expected Exception since a list of strings was expected"
-    assert check_repeat_enumerated("name",[])==False,             "Expected Exception since list is empty"
-
-
-    assert check_variable("name","value"),        "Expected valid Variable"
-    assert check_variable("name",""),             "Expected valid Variable"
-    assert check_variable("name"," "),            "Expected valid Variable"
-    assert check_variable("name","12"),           "Expected valid Variable"
-    assert check_variable("","12")==False,        "Expected Exception name must be specified"
-    assert check_variable(" ","12")==False,       "Expected Exception cannot have spaces for a name"
-
-    assert check_label("name","value"),        "Expected valid label"
-    assert check_label("name",""),             "Expected valid label"
-    assert check_label("name"," "),            "Expected valid label"
-    assert check_label("name","12"),           "Expected valid label"
-    assert check_label("","12")==False,        "Expected exception name must be specified"
-    assert check_label(" ","12")==False,       "Expected Exception cannot have spaces for a name"
-
-    assert check_limit("name",1),              "Expected valid limit"
-    assert check_limit("name",20000),          "Expected valid limit"
-    assert check_limit("name","ten")==False,   "Expected exception, token must be a integer"
-    assert check_limit("name","2")==False,     "Expected exception, token must be a integer"
-    assert check_limit("","2")==False,         "Expected exception, no name specified"
-    assert check_limit(" ","2")==False,        "Expected exception, cannot have spaces for a name"
-
-    assert check_inlimit("limit_name","/path/to/limit",1),      "Expected valid in limit"
-    assert check_inlimit("limit_name","/path/to/limit",999999), "Expected valid in limit"
-    assert check_inlimit("limit_name","",1),                    "Expected valid in limit"
-    assert check_inlimit("","",1)==False,                       "Expected exception, no limit name specified"
-    assert check_inlimit(" ","",1)==False,                      "Expected exception, cannot have spaces for a name"
- 
-
-    # ========================================================================
-    print("Check node names")
-    for i in range(25):
-        assert check_node_name(str(i)),             "Integer names should be allowed"
-     
-    for name in valid_names:
-        assert check_node_name(name),  "Expected valid name " + name
-    
-    for name in invalid_names:
-        assert check_node_name(name)==False,  "Expected exception for invalid name " + name
-
-   
-    assert check_defs("a_made_up_path_that_doesnt_not_exit.def") == False, "Expected exception, Defs file does not exist"
-
-    # =================================================================================
-    print("test save_as_defs")
-    defs = Defs()                      # create a empty definition
-    s1 = defs.add_suite("s1")          # create a suite "s1" and add to defs
-    defs.save_as_defs("testerror.def") # create a defs on disk
-    assert check_defs("testerror.def"), "Expected defs file to exist"
-    os.remove("testerror.def")
-
-    # =================================================================================
-    print("Check duplicate suites not allowed")
-    test_passed = False
-    try :
-        defs = Defs()               # create a empty definition
-        s1 = defs.add_suite("s1")   # create a suite "s1" and add to defs
-        s2 = defs.add_suite("s1")   # Exception thrown trying to add suite name "s1" again
-    except RuntimeError as e : 
-        test_passed = True
-        pass 
-    assert test_passed,"duplicate suite test failed"   
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_today("00:30")
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding today at the suite level should fail"   
-    print("check adding today at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_time("00:30")
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding time at the suite level should fail"    
-    print("check adding time at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_date(1,1,2016)
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding date at the suite level should fail"    
-    print("check adding date at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_day("monday")
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding day at the suite level should fail"    
-    print("check adding day at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_trigger("1 == 0")
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding a trigger at suite level should fail"    
-    print("check adding trigger at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_part_trigger("1 == 0")
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding a part trigger at suite level should fail"    
-    print("check adding part trigger at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_complete("1 == 0")
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding a complete trigger at suite level should fail"    
-    print("check adding complete trigger at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    test_passed = False
-    try:
-        defs = Defs()
-        defs.add_suite("1").add_part_complete("1 == 0")
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Adding a part complete trigger at suite level should fail"    
-    print("check adding part complete trigger at the suite level: RuntimeError: ")
-
-    # =================================================================================
-    print("check adding trigger referencing parent should fail ECFLOW-1436")
-    defs = Defs()
-    defs += Suite("obs") + Family("anon", Task("t1", Trigger("anon == complete")))
-    assert len(defs.check()) > 0,"Adding a trigger referencing a parent without .. should fail"    
-
-
-    # =================================================================================
-    print("check duplicate family not allowed")
-    test_passed = False
-    try:
-        suite = Suite("1")
-        fam1 = Family("1")
-        fam2 = Family("1")
-        suite.add_family(fam1)
-        suite.add_family(fam2)
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"duplicate Family test failed"   
-  
-    # =================================================================================
-    print("duplicate task not allowed")
-    test_passed = False
-    try:
-        suite = Suite("1")
-        ta = Task("a")
-        tb = Task("a")
-        suite.add_task(ta)
-        suite.add_task(tb)
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"duplicate Task test failed"   
-
-    # =================================================================================
-    print("Task and family of same name should not be allowed")
-    test_passed = False
-    try:
-        suite = Suite("1")
-        ta = Task("a")
-        tb = Family("a")
-        suite.add_task(ta)
-        suite.add_family(tb)
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"Task and family of same name should not be allowed"   
-
-    # =================================================================================
-    print("check duplicate meter not allowed")
-    test_passed = False
-    try:
-        defs = Defs()
-        suite = defs.add_suite("1")
-        ta = suite.add_task("a")
-        ta.add_meter("meter",0,100);
-        ta.add_meter("meter",0,100);
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"duplicate meter test failed"   
-
-    # =================================================================================
-    print("check duplicate queue not allowed")
-    test_passed = False
-    try:
-        defs = Defs()
-        suite = defs.add_suite("1")
-        suite.add_queue("q",["a"]);
-        suite.add_queue("q",["a","b"]);
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"duplicate queue test failed"   
-
-    # =================================================================================
-    print("check duplicate event not allowed")
-    test_passed = False
-    try:
-        defs = Defs()
-        suite = defs.add_suite("1")
-        ta = suite.add_task("a")
-        ta.add_event(1);
-        ta.add_event("1");
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"duplicate event test failed"   
-    
-    test_passed = False
-    try:
-        defs = Defs()
-        suite = defs.add_suite("1")
-        ta = suite.add_task("a")
-        ta.add_event("name");
-        ta.add_event("name");
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"duplicate event test failed"   
-    
-    test_passed = False
-    try:
-        defs = Defs()
-        suite = defs.add_suite("1")
-        ta = suite.add_task("a")
-        ta.add_event(1,"name");
-        ta.add_event(1,"name");
-    except RuntimeError as e : 
-        test_passed = True
-        pass
-    assert test_passed,"duplicate event test failed"   
-    
-    
-    # =================================================================================
-    print("check cannot add same node to different containers")
-    defs1 = Defs();
-    suite = defs1.add_suite("s1")
-    family =  suite.add_family("f1")
-    task  = family.add_task("t1")
-    
-    test_passed = False
-    try :
-        defs2 = Defs();
-        defs2.add_suite(suite)
-    except RuntimeError as e : 
-        test_passed = True
-        pass    
-    assert test_passed,"Can't add same suite to two different defs"   
-
-    test_passed = False
-    try :
-        defs3 = Defs();
-        suite = defs3.add_suite(suite)
-        suite.add_family(family)
-    except RuntimeError as e : 
-        test_passed = True
-        pass    
-    assert test_passed,"Can't add same family to two different suites"   
-
-    test_passed = False
-    try :
-        defs4 = Defs();
-        suite = defs4.add_suite("s1")
-        suite.add_task(task)
-    except RuntimeError as e : 
-        test_passed = True
-        pass    
-    assert test_passed,"Can't add same task to two different containers"   
-
-    test_passed = False
-    try :
-        defs4 = Defs();
-        suite = defs4.add_suite("s1")
-        suite.add_autocancel(3)
-        suite.add_autocancel(4)
-    except RuntimeError as e : 
-        test_passed = True
-        pass    
-    assert test_passed,"Can't add two autocancel on same node" 
-    
-    test_passed = False
-    try :
-        defs4 = Defs();
-        suite = defs4.add_suite("s1")
-        suite.add_autoarchive(3)
-        suite.add_autocancel(4)
-    except RuntimeError as e : 
-        test_passed = True
-        pass    
-    assert test_passed,"Can't add autocancel and autoarchive on same node"  
-    
-    test_passed = False
-    try :
-        defs4 = Defs();
-        suite = defs4.add_suite("s1")
-        suite.add_autorestore(["/s1"])
-        suite.add_autorestore(["/s1"])
-    except RuntimeError as e : 
-        test_passed = True
-        pass    
-    assert test_passed,"Can't add two autorestore on same node"  
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestFind.py 5.13.0-1/Pyext/test/py_u_TestFind.py
--- 5.12.4-1/Pyext/test/py_u_TestFind.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestFind.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,162 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-#  code for testing pointers and hierarchy in python
-
-from ecflow import Suite, Family, Task, Defs, Client, debug_build, Edit
-import ecflow_test_util as Test
-import os
-
-def create_defs(name=""):
-    suite_name = name
-    if len(suite_name) == 0: suite_name = "s1"
-    defs =  Defs(Edit(FRED_2="XX",DEFS_VAR="0"),
-                Suite(suite_name, Edit(SUITE_VAR="1",FRED_1="%FRED_2%"),
-                    Family("f1",Edit(FRED_0="%FRED_1%"),
-                          Task("f1_t1", Edit(TASK_VAR="3",FRED="%FRED_0%")),
-                          Task("f1_t2", Edit(TASK_VAR="3",FRED="%FRED_0%"))
-                    ),
-                    Family("f2",Edit(FRED_0="%FRED_1%"),
-                          Task("f2_t1", Edit(TASK_VAR="3",FRED="%FRED_0%")),
-                          Task("f2_t2", Edit(TASK_VAR="3",FRED="%FRED_0%"))
-                    )
-                )
-            )
-    return defs;
-
-def test_ecflow_1213(defs):
-    s1 = defs.find_node_path("suite","s1")
-    assert s1 == "/s1"," expected to find suite s1"
-
-    f1 = defs.find_node_path("family","f1")
-    assert f1 == "/s1/f1"," expected to find family f1"
-  
-    f2 = defs.find_node_path("family","f2")
-    assert f2 == "/s1/f2"," expected to find family f2"
-
-    f1_t1 = defs.find_node_path("task","f1_t1")
-    f1_t2 = defs.find_node_path("task","f1_t2")
-    assert f1_t1 == "/s1/f1/f1_t1"," expected to find task f1_t1"
-    assert f1_t2 == "/s1/f1/f1_t2"," expected to find task f1_t2"
-    
-    f2_t1 = defs.find_node_path("task","f2_t1") 
-    f2_t2 = defs.find_node_path("task","f2_t2")
-    assert f2_t1 == "/s1/f2/f2_t1"," expected to find task f2_t1"
-    assert f2_t2 == "/s1/f2/f2_t2"," expected to find task f2_t2"
-    
-    # find_node
-    s1 = defs.find_node("suite","/s1")
-    assert s1 is not None and isinstance(s1, Suite), "expected find find suite s1"
-    
-    f1 = defs.find_node("family","/s1/f1")
-    assert f1 is not None and isinstance(f1, Family)," expected to find family f1"
-  
-    f2 = defs.find_node("family","/s1/f2")
-    assert f2 is not None and isinstance(f2, Family)," expected to find family f2"
-
-    f1_t1 = defs.find_node("task","/s1/f1/f1_t1")
-    f1_t2 = defs.find_node("task","/s1/f1/f1_t2")
-    assert f1_t1 is not None and isinstance(f1_t1, Task)," expected to find task f1_t1"
-    assert f1_t2 is not None and isinstance(f1_t2, Task)," expected to find task f1_t2"
-    
-    f2_t1 = defs.find_node("task","/s1/f2/f2_t1")
-    f2_t2 = defs.find_node("task","/s1/f2/f2_t2")
-    assert f2_t1 is not None and isinstance(f2_t1, Task)," expected to find task f2_t1"
-    assert f2_t2 is not None and isinstance(f2_t1, Task)," expected to find task f2_t2"
-
-
-if __name__ == "__main__":   
-    
-    Test.print_test_start(os.path.basename(__file__))
- 
-    defs = create_defs()
-    
-    test_ecflow_1213(defs)
-    
-    s1 = defs.find_suite("s1")
-    assert s1 is not None, "expected find find suite s1"
-    assert "s1" in defs, "expected find find suite s1"
-
-    sx = defs.find_suite("sx")
-    assert sx is None, "expected not to find suite sx"
-    
-    f1 = s1.find_family("f1")
-    assert f1 is not None, "expected find find family f1"
-    f1 = s1.find_node("f1")
-    assert f1 is not None, "expected find find family f1"
-
-    fx = s1.find_family("fx")
-    assert fx is None, "expected not to find family fx"
-    fx = s1.find_node("fx")
-    assert fx is None, "expected not to find family fx"
-
-    f2 = s1.find_family("f2")
-    assert f2 is not None, "expected find find family f2"
-    f2 = s1.find_node("f2")
-    assert f2 is not None, "expected find find family f2"
-    
-    f2_t1 = f2.find_task("f2_t1")
-    assert f2_t1 is not None, "Expected to find task"
-
-    f2_t2 = f2.find_task("f2_t2")
-    assert f2_t2 is not None, "Expected to find task"
-    f2_t2 = f2.find_node("f2_t2")
-    assert f2_t2 is not None, "Expected to find task"
-
-    f2_tx = f2.find_task("f2_tx")
-    assert f2_tx is None, "Expected not to find task"
-    f2_tx = f2.find_node("f2_tx")
-    assert f2_tx is None, "Expected not to find task"
-
-    tasks = defs.get_all_tasks()
-    assert len(tasks) == 4, "Expected four tasks, but found " + str(len(tasks))
-    for task in tasks:
-        # test find variable
-        var = task.find_parent_variable("TASK_VAR")
-        assert not var.empty()
-        assert var.value() == "3"
-        
-        var = task.find_parent_variable_sub_value("FRED")
-        assert var == "XX"
-
-        var = task.find_parent_variable_sub_value("ZZZZ")
-        assert var == ""
-
-        var = task.find_variable("TASK_VAR")
-        assert not var.empty()
-        assert var.value() == "3"
-        
-        var = task.find_parent_variable("SUITE_VAR");
-        assert not var.empty()
-        assert var.value() == "1"
-         
-        var = task.find_parent_variable("DEFS_VAR")
-        assert not var.empty()
-        assert var.value() == "0"
-
-        var = task.find_parent_variable("MADE_UP_VAR")
-        assert var.empty()
-
-        if task.name() == "f1_t1":
-            node = task.find_node_up_the_tree("f1")
-            assert node is not None
-            assert node.get_abs_node_path() == "/s1/f1"
-            
-            node = task.find_node_up_the_tree("s1")
-            assert node is not None
-            assert node.get_abs_node_path() == "/s1"
-
-            node = task.find_node_up_the_tree("freddd")
-            assert node is None
-            
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestFlag.py 5.13.0-1/Pyext/test/py_u_TestFlag.py
--- 5.12.4-1/Pyext/test/py_u_TestFlag.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestFlag.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,96 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import ecflow
-import sys
-import os
-import ecflow_test_util as Test
-
-if __name__ == "__main__":
-
-    Test.print_test_start(os.path.basename(__file__))
- 
-    flag = ecflow.Flag()
-    assert str(flag) == "", "expected empty string, for an empty flag"
-         
-    flag_list =  flag.list() # flag_list is of type FlagTypeVec
-    my_flag_list = [ ecflow.FlagType.force_abort,
-                     ecflow.FlagType.user_edit,
-                     ecflow.FlagType.task_aborted,
-                     ecflow.FlagType.edit_failed,
-                     ecflow.FlagType.jobcmd_failed,
-                     ecflow.FlagType.killcmd_failed,
-                     ecflow.FlagType.statuscmd_failed,
-                     ecflow.FlagType.no_script,
-                     ecflow.FlagType.killed,
-                     ecflow.FlagType.status,
-                     ecflow.FlagType.late,
-                     ecflow.FlagType.message,
-                     ecflow.FlagType.byrule,
-                     ecflow.FlagType.queuelimit,
-                     ecflow.FlagType.wait ,
-                     ecflow.FlagType.locked ,
-                     ecflow.FlagType.zombie ,
-                     ecflow.FlagType.no_reque,
-                     ecflow.FlagType.archived,
-                     ecflow.FlagType.restored,
-                     ecflow.FlagType.threshold,
-                     ecflow.FlagType.sigterm, 
-                     ecflow.FlagType.log_error,
-                     ecflow.FlagType.checkpt_error
-                   ]
-    print("Flag list:")
-    for flg in flag_list: print("flag ",flag.type_to_string(flg))
-    print("My   list:")
-    for flg in my_flag_list: print("flag ",flag.type_to_string(flg))
-
-    assert len(flag_list) == len(my_flag_list), "expected flag list have changed"
-    expected_flags = "force_aborted,user_edit,task_aborted,edit_failed,ecfcmd_failed,killcmd_failed,statuscmd_failed,no_script,killed,status,late,message,by_rule,queue_limit,task_waiting,locked,zombie,no_reque,archived,restored,threshold,sigterm,log_error,checkpt_error";
-
-    #Set *ALL* the flags
-    for flg in flag_list:
-       flag.set( flg )
-       assert flag.is_set( flg ),"expected flag %r to be set" % flag.type_to_string(flg)
-    
-    # clear *ALL* the flags
-    assert str(flag) == expected_flags, "Expected flags \n{0}\nbut found \n{1}".format(str(flag),expected_flags)
-    for flg in flag_list:
-        flag.clear(flg)
-        assert not flag.is_set( flg ),"expected flag {0} not to be set".format(flag.type_to_string(flg))
-
-    # test reset
-    for flg in flag_list:
-       flag.set( flg )
-    flag.reset()
-    for flg in flag_list:
-        assert not flag.is_set( flg ),"expected flag %r not to be set" % flag.type_to_string(flg)
-        
-    #===========================================================================
-    # Setting flag type
-    #===========================================================================
-    for flg in my_flag_list:
-        flag.set( flg )
-        print("current flag:",flag)
-        assert flag.is_set( flg ),"expected flag %r to be set" % flag.type_to_string(flg)
-
-    #===========================================================================
-    # Node:  get the flag, should be empty for a newly created node.
-    #===========================================================================
-    suite = ecflow.Suite("s1")
-    flag = suite.get_flag()
-    for flg in flag_list:
-        assert not flag.is_set( flg ),"expected flag %r not to be set" % flag.type_to_string(flg)
-    assert str(flag) == "", "expected empty string, for an empty flag"
-    
-    #assert False
-    print("All tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestGeneratedVariable.py 5.13.0-1/Pyext/test/py_u_TestGeneratedVariable.py
--- 5.12.4-1/Pyext/test/py_u_TestGeneratedVariable.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestGeneratedVariable.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# code for testing  generated variables
-
-import os
-import ecflow
-import ecflow_test_util as Test
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
-     
-    #===========================================================================
-    print("Defs: test generated variables")
-    #===========================================================================
-    defs = ecflow.Defs()
-    suite = defs.add_suite("s1")
-    family = suite.add_family("f1")
-    task = family.add_task("t1")
-
-    print("\nsuite generated variables, Most of date related suite generated variables will only have values after the suite has begun")
-    variable_list = ecflow.VariableList()
-    suite.get_generated_variables(variable_list)
-    for gen_var in variable_list:
-        print(gen_var)
-        gen_var = suite.find_gen_variable(gen_var.name())
-        assert not gen_var.empty(), "Could not find suite generated variable " + gen_var
-    assert len(list(variable_list)) == 14,"Expected 14 generated variables for suites"    
-    assert variable_list[0].name() == "SUITE", "expected generated variable of name SUITE but found " + variable_list[0].name()
-    assert variable_list[0].value() == "s1", "expected generated variable of value 's1' but found " + variable_list[0].value()
-
-
-    print("\nfamily generated variables")
-    variable_list = ecflow.VariableList()
-    family.get_generated_variables(variable_list)
-    for gen_var in variable_list:
-        print(gen_var)
-        gen_var = family.find_gen_variable(gen_var.name())
-        assert not gen_var.empty(), "Could not find family generated variable " + gen_var
-
-    assert len(list(variable_list)) == 2,"Expected 2 generated variables for families"    
-    assert variable_list[0].name() == "FAMILY", "expected generated variable of name FAMILY but found " + variable_list[0].name()
-    assert variable_list[0].value() == "f1", "expected generated variable of value 'f1' but found " + variable_list[0].value()
-    assert variable_list[1].name() == "FAMILY1", "expected generated variable of name FAMILY1 but found " + variable_list[1].name()
-    assert variable_list[1].value() == "f1", "expected generated variable of value 'f1' but found " + variable_list[1].value()
-
-    print("\ntask generated variables")
-    variable_list = ecflow.VariableList()
-    task.get_generated_variables(variable_list)
-    for gen_var in variable_list:
-        print(gen_var)
-        gen_var = task.find_gen_variable(gen_var.name())
-        assert not gen_var.empty(), "Could not find task generated variable " + gen_var
-
-    assert len(list(variable_list)) == 8,"Expected 8 generated variables for tasks"    
-    assert variable_list[0].name() == "TASK", "expected generated variable of name TASK but found " + variable_list[0].name()
-    assert variable_list[0].value() == "t1", "expected generated variable of value 't1' but found " + variable_list[0].value()
-    assert variable_list[1].name() == "ECF_JOB", "expected generated variable of name ECF_JOB but found " + variable_list[1].name()
-    assert variable_list[1].value() == "./s1/f1/t1.job0", "expected generated variable of value './s1/f1/t1.job0' but found " + variable_list[1].value()
-    assert variable_list[2].name() == "ECF_SCRIPT", "expected generated variable of name ECF_SCRIPT but found " + variable_list[2].name()
-    assert variable_list[2].value() == "./s1/f1/t1.ecf", "expected generated variable of value './s1/f1/t1.ecf' but found " + variable_list[2].value()
-    assert variable_list[3].name() == "ECF_JOBOUT", "expected generated variable of name ECF_JOBOUT but found " + variable_list[3].name()
-    assert variable_list[3].value() == "./s1/f1/t1.0", "expected generated variable of value './s1/f1/t1.0' but found " + variable_list[3].value()
-    assert variable_list[4].name() == "ECF_TRYNO", "expected generated variable of name ECF_TRYNO but found " + variable_list[4].name()
-    assert variable_list[4].value() == "0", "expected generated variable of value '0' but found " + variable_list[4].value()
-    assert variable_list[5].name() == "ECF_RID", "expected generated variable of name ECF_RID but found " + variable_list[5].name()
-    assert variable_list[5].value() == "", "expected generated variable of value '' but found " + variable_list[5].value()
-    assert variable_list[6].name() == "ECF_NAME", "expected generated variable of name ECF_NAME but found " + variable_list[6].name()
-    assert variable_list[6].value() == "/s1/f1/t1", "expected generated variable of value '/s1/f1/t1' but found " + variable_list[6].value()
-    assert variable_list[7].name() == "ECF_PASS", "expected generated variable of name ECF_NAME but found " + variable_list[7].name()
-    assert variable_list[7].value() == "", "expected generated variable of value '' but found " + variable_list[7].value()
-
-    print("\nAll Tests pass")
-    
diff -pruN 5.12.4-1/Pyext/test/py_u_TestGetAllTasks.py 5.13.0-1/Pyext/test/py_u_TestGetAllTasks.py
--- 5.12.4-1/Pyext/test/py_u_TestGetAllTasks.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestGetAllTasks.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,103 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# Simple check for get all tasks
-from ecflow import Defs, Client, debug_build
-import ecflow_test_util as Test
-import os
-
-def create_defs():
-    defs = Defs()
-    suite = defs.add_suite("test_get_all")
-    suite.add_task("t0")
-    fam = suite.add_family("f1")
-    fam.add_task("t1") 
-    fam.add_task("t2") 
-    fam2 = fam.add_family("f2")
-    fam2.add_task("t3") 
-    return defs
-   
-def test_get_all_tasks(defs):
-  
-    task_vec2 = defs.get_all_tasks()
-    assert len(task_vec2) == 4, "Expected four tasks, but found " + str(len(task_vec2))
-   
-    assert task_vec2[0].name() == "t0", "Expected task of name t0 but found " + task_vec2[0].name()
-    assert task_vec2[1].name() == "t1", "Expected task of name t1 but found " + task_vec2[1].name()
-    assert task_vec2[2].name() == "t2", "Expected task of name t2 but found " + task_vec2[2].name()
-    assert task_vec2[3].name() == "t3", "Expected task of name t3 but found " + task_vec2[3].name()
-   
-    print("test_get_all_tasks PASSED")
-   
-def test_get_all_nodes(defs):
-    
-    # Get all the nodes make sure they are in order
-    node_vec = defs.get_all_nodes()
-    assert len(node_vec) == 7, "Expected seven nodes, but found " + str(len(node_vec))
-    assert node_vec[0].name() == "test_get_all", "Nodes should be returned in order, expected test_get_all but found" + node_vec[0].name()
-    assert node_vec[1].name() == "t0", "Nodes should be returned in order, expected 't0' but found" + node_vec[1].name()
-    assert node_vec[2].name() == "f1", "Nodes should be returned in order, expected 'f1' but found" + node_vec[2].name()
-    assert node_vec[3].name() == "t1", "Nodes should be returned in order, expected 't1' but found" + node_vec[3].name()
-    assert node_vec[4].name() == "t2", "Nodes should be returned in order, expected 't2' but found" + node_vec[4].name()
-    assert node_vec[5].name() == "f2", "Nodes should be returned in order, expected 'f2' but found" + node_vec[5].name()
-    assert node_vec[6].name() == "t3", "Nodes should be returned in order, expected 't3' but found" + node_vec[6].name()
-
-    # test empty defs
-    empty_defs = Defs()
-    node_vec = empty_defs.get_all_nodes()
-    assert len(node_vec) == 0, "Expected zero nodes, for an empty defs but found " + str(len(node_vec))
-
-    # test one suite defs
-    one_suite_defs = Defs()
-    one_suite_defs.add_suite("s1")
-    node_vec = one_suite_defs.get_all_nodes()
-    assert len(node_vec) == 1, "Expected one node, but found " + str(len(node_vec))
-
-    print("test_get_all_nodes PASSED")
-    
-def test_get_all_nodes_from_nodes():
-    defs = Defs()
-    suite = defs.add_suite("test_get_all")
-    node_vec = suite.get_all_nodes()
-    assert len(node_vec) == 1, "Expected one nodes but found " + str(len(node_vec))
-
-    fam1 = suite.add_family("f1")
-    fam2 = suite.add_family("f2")
-    fam3 = suite.add_family("f3")
-    node_vec = suite.get_all_nodes()
-    assert len(node_vec) == 4, "Expected 4 nodes but found " + str(len(node_vec))
-
-    node_vec = fam1.get_all_nodes()
-    assert len(node_vec) == 1, "Expected 1 nodes but found " + str(len(node_vec))
-
-    f1_t1 = fam1.add_task("t1") 
-    f1_t2 = fam1.add_task("t2") 
-    node_vec = fam1.get_all_nodes()
-    assert len(node_vec) == 3, "Expected 3 nodes but found " + str(len(node_vec))
-
-    node_vec = f1_t1.get_all_nodes()
-    assert len(node_vec) == 1, "Expected 1 nodes but found " + str(len(node_vec))
-
-    node_vec = suite.get_all_nodes()
-    assert len(node_vec) == 6, "Expected 6 nodes but found " + str(len(node_vec))
-
-    print("test_get_all_nodes_from_nodes PASSED")
-   
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
- 
-    test_get_all_tasks(create_defs())
-    test_get_all_nodes(create_defs())
-    test_get_all_nodes_from_nodes()
-    print("All Tests pass")    
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_TestJobGeneration.py 5.13.0-1/Pyext/test/py_u_TestJobGeneration.py
--- 5.12.4-1/Pyext/test/py_u_TestJobGeneration.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestJobGeneration.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,156 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# This code is used check job generation
-#
-import os
-import shutil   # used to remove directory tree
-
-import ecflow_test_util as Test
-from ecflow import Defs, JobCreationCtrl, TaskVec, File, Client, debug_build
-
-def ecf_includes() : return File.source_dir() + "/Pyext/test/data/includes"
-
-def suite_name(): return "suite_job_gen_" + str(os.getpid())  # allow python2 and python3 to run in parallel
-
-def create_defs(ecf_home,task_vec):
-    defs = Defs();
-    suite = defs.add_suite( suite_name() );
-    suite.add_variable("ECF_HOME",ecf_home);
-    suite.add_variable("ECF_CLIENT_EXE_PATH",File.find_client());
-    suite.add_variable("SLEEPTIME","1");
-    suite.add_variable("ECF_INCLUDE",ecf_includes());
-    
-    fam =  suite.add_family("family")
-    t1 = fam.add_task("t1")
-    t1.add_event("eventname");
-    t1.add_meter("meter",0,100,100)
-    
-    t2 = fam.add_task("t2")
-    t3 = fam.add_task("t3")
-    t4 = fam.add_task("dummy_task")
-    t4.add_variable("ECF_DUMMY_TASK","any"); # stop job generation errors for tasks without an .ecf
-    task_vec.append(t1);
-    task_vec.append(t2);
-    task_vec.append(t3);
-    task_vec.append(t4);
-    
-    # Create dir. **NOTE**, if the second component of os.path.joind(..) is absolute, 
-    # the first path is ignored, hence remove first char
-    dir_to_create = os.path.join(str(ecf_home),fam.get_abs_node_path()[1:])
-    print("Creating dir ",dir_to_create)
-    os.makedirs( dir_to_create  )
-     
-    # copy ecf files from ecflow source, to create unique file per process
-    src_t1  = os.path.join(ecf_home, "suite_job_gen" , "family" , "t1.ecf")
-    dest_t1 = os.path.join(ecf_home,  t1.get_abs_node_path()[1:] + ".ecf" )
-    src_t2  = os.path.join(ecf_home, "suite_job_gen" , "family" , "t2.ecf")
-    dest_t2 = os.path.join(ecf_home,  t2.get_abs_node_path()[1:] + ".ecf" )
-    src_t3  = os.path.join(ecf_home, "suite_job_gen" , "family" , "t3.ecf")
-    dest_t3 = os.path.join(ecf_home,  t3.get_abs_node_path()[1:] + ".ecf" )
- 
-    shutil.copy(src_t1, dest_t1)
-    shutil.copy(src_t2, dest_t2)
-    shutil.copy(src_t3, dest_t3)
-    
-    return defs
-
-
-def delete_jobs(task_vec, ecf_home):
-    print("delete jobs")
-    for task in task_vec:
-        the_job_file = ecf_home + task.get_abs_node_path() + ".job" + task.get_try_no()
-        if os.path.exists(the_job_file) :
-            print("removing file " + the_job_file)
-            try: os.remove(the_job_file)
-            except: pass
-        man_file = ecf_home + task.get_abs_node_path() + ".man"  
-        if os.path.exists(man_file) :
-            print("removing man_file " + man_file)
-            try: os.remove(man_file)
-            except: pass
-   
-def check_jobs(task_vec, ecf_home):
-    print("Check job file exists")
-    for task in task_vec:
-        variable = task.find_variable("ECF_DUMMY_TASK")
-        if not variable.empty(): continue;
-        the_job_file = ecf_home + task.get_abs_node_path() + ".job" + task.get_try_no()
-      
-        if os.path.exists(the_job_file) :
-            print("Found job file " + the_job_file)
-        else:
-            assert False, "Could not find job file " + the_job_file
-
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
-    
-    workspace = File.source_dir();
-    print(workspace)
-
-    ecf_home = workspace + "/Pyext/test/data/ECF_HOME"
-    task_vec = TaskVec()
-    defs = create_defs(ecf_home,task_vec)
-    print(str(defs))
-
-    print("Generate jobs for *ALL* tasks, to default locations ECF_HOME/ECF_NAME.job0") 
-    print(defs.check_job_creation())   
-    check_jobs(task_vec,ecf_home)
-    delete_jobs(task_vec,ecf_home)
-       
-    print("\nGenerate jobs for *ALL* tasks, to default locations ECF_HOME/ECF_NAME.job0")
-    job_ctrl = JobCreationCtrl()
-    defs.check_job_creation( job_ctrl )       
-    print(job_ctrl.get_error_msg())
-    check_jobs(task_vec,ecf_home)
-    delete_jobs(task_vec,ecf_home)
-    
-    print("\nGenerate jobs for all nodes, under path, to default locations ECF_HOME/ECF_NAME.job0")    
-    job_ctrl = JobCreationCtrl()
-    job_ctrl.set_node_path( task_vec[0].get_abs_node_path() )    
-    defs.check_job_creation(job_ctrl)       
-    print(job_ctrl.get_error_msg());
-    delete_jobs(task_vec,ecf_home)
-   
-    print("\nGenerate jobs for all tasks, to the specified directory")
-    # Directory will automatically created under the provided directory
-    job_ctrl = JobCreationCtrl()
-    job_ctrl.set_dir_for_job_creation(workspace + "/Pyext/test/data")  # generate jobs file under this directory
-    defs.check_job_creation(job_ctrl)
-    print(job_ctrl.get_error_msg())
-    
-    generated_dir = job_ctrl.get_dir_for_job_creation() + "/" + suite_name()
-    print("removing directory tree " + generated_dir)
-    shutil.rmtree(generated_dir)      
- 
-    # Create jobs for all task, to a TMP directory ($TMPDIR/ecf_check_job_creation/ECF_NAME.job0
-    # When run via rsh then TMPDIR may not be defined, hence expect exception to be thrown
-    try:
-        job_ctrl = JobCreationCtrl()                    
-        job_ctrl.generate_temp_dir()       
-        defs.check_job_creation(job_ctrl)
-        print(job_ctrl.get_error_msg())
-        print("removing directory tree " + job_ctrl.get_dir_for_job_creation())
-        shutil.rmtree(job_ctrl.get_dir_for_job_creation(),ignore_errors=True)     
-        delete_jobs(task_vec,ecf_home)
-    except RuntimeError as e:
-        print("failed: " + str(e))  
-        
-    try:
-        dir_to_del = os.path.join(ecf_home,suite_name())
-        print("removing directory tree " + dir_to_del )
-        shutil.rmtree(dir_to_del)     
-        print("All test pass")
-    except RuntimeError as e:
-        print("failed: " + str(e))    
diff -pruN 5.12.4-1/Pyext/test/py_u_TestParent.py 5.13.0-1/Pyext/test/py_u_TestParent.py
--- 5.12.4-1/Pyext/test/py_u_TestParent.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestParent.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,77 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-#  code for testing pointers and hierarchy in python
-
-from ecflow import Suite, Family, Task, Defs, Client, debug_build
-import ecflow_test_util as Test
-import os
-
-def absNodePath(node):
-    """ Given a node return its absolute node path. """
-    """ Example of using get_parent()               """
-    name_list = []
-    name_list.append(node.name())
-    parent = node.get_parent();
-    while parent:
-        name_list.append(parent.name())
-        parent = parent.get_parent()
-        
-    name_list.reverse()
-    ret = ""
-    for name in name_list:
-        ret = ret +  "/"
-        ret = ret + name
-    return ret
-    
-
-if __name__ == "__main__":  
-    Test.print_test_start(os.path.basename(__file__))
-   
-    suite = Suite("s1");
-    family = Family("f1")
-    task = Task("t1")
-
-    assert not suite.get_parent(), "Suite parent is always NULL"
-    assert not family.get_parent(), "Expect no parent"
-    assert not task.get_parent(), "Expect no parent"
-    
-    print("suite.get_defs() = " + str(suite.get_defs()))
-    print("family.get_defs() = " + str(family.get_defs()))
-    print("task.get_defs() = " + str(task.get_defs()))
-    assert not suite.get_defs(),   "Expected no defs, since suite not added to defs yet"
-    assert not family.get_defs(),  "Expected no defs"
-    assert not task.get_defs(),    "Expected no defs"
-    
-    suite.add_family(family)
-    family.add_task(task)
-    
-    family2 = Family("f2")
-    family.add_family(family2)
-
-    t1 = Task("t1")
-    family2.add_task(t1)
-       
-    defs = Defs()
-    defs.add_suite(suite);
-    
-    print(absNodePath(t1))
-    print(absNodePath(family2))
-    print(absNodePath(family))
-    print(absNodePath(suite))
-    
-    assert t1.get_abs_node_path() == absNodePath(t1),          "Expected " + t1.get_abs_node_path()      + " but got " + absNodePath(t1)
-    assert family2.get_abs_node_path() == absNodePath(family2),"Expected " + family2.get_abs_node_path() + " but got " + absNodePath(family2)
-    assert family.get_abs_node_path() == absNodePath(family),  "Expected " + family.get_abs_node_path()  + " but got " + absNodePath(family)
-    assert suite.get_abs_node_path() == absNodePath(suite),    "Expected " + family.get_abs_node_path()  + " but got " + absNodePath(suite)
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestRemove.py 5.13.0-1/Pyext/test/py_u_TestRemove.py
--- 5.12.4-1/Pyext/test/py_u_TestRemove.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestRemove.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,64 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-#  code for testing creation of defs file in python
-import os
-import ecflow
-import copy
-from ecflow import Suite, Family, Task, Defs, Clock, DState, PartExpression, Variable, Limit, InLimit, \
-                   Date, Day, Event, Meter, Label, Autocancel, Days, TimeSlot, TimeSeries, Style, State, \
-                   RepeatString, RepeatDate, RepeatInteger, RepeatDay, RepeatEnumerated, \
-                   Verify, PrintStyle, Time, Today, Late, Cron, Client, debug_build
-import ecflow_test_util as Test
-
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
-    
-    defs = Defs()
-    s0 = defs.add_suite("s0")
-    s1 = defs.add_suite("s1")
-    f1 =  s1.add_family("f1")
-    t1 = f1.add_task("t1")
-    t2 = f1.add_task("t2")
-    assert len(list(f1.nodes)) == 2 ,"Expected family to have 2 nodes"
-    defs_copy = copy.copy(defs)
-     
-    
-    t2_remove = t2.remove()
-    assert len(f1) == 1 ,"Expected family to have 1 nodes"
-
-    t1_remove = t1.remove()
-    assert len(f1) == 0 ,"Expected family to have 0 nodes"
-
-    f1_remove = f1.remove()
-    assert len(s1) == 0 ,"Expected suite to have no nodes"
-
-    node_vec = defs.get_all_nodes()
-    assert len(node_vec) == 2, "Expected 2 suites only, but found " + str(len(node_vec))
-
-    s1_remove = s1.remove()
-    node_vec = defs.get_all_nodes()
-    assert len(node_vec) == 1, "Expected 1 suites only, but found " + str(len(node_vec))
-
-    s0_remove = s0.remove()
-    node_vec = defs.get_all_nodes()
-    assert len(node_vec) == 0, "Expected 0 suites only, but found " + str(len(node_vec))
-
-    # =========================================================
-    defs2 = Defs();
-    defs2.add_suite(s0_remove)
-    s = defs2.add_suite(s1_remove) # s1_remove is returned as s
-    f =  s.add_family(f1_remove)   # f1_remove is returned as f
-    f.add_task(t1_remove)
-    f.add_task(t2_remove)
-    assert defs2 == defs_copy ,"expected defs to be the same"
diff -pruN 5.12.4-1/Pyext/test/py_u_TestRepeatArithmetic.py 5.13.0-1/Pyext/test/py_u_TestRepeatArithmetic.py
--- 5.12.4-1/Pyext/test/py_u_TestRepeatArithmetic.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestRepeatArithmetic.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,91 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# This test checks trigger evaluation uses date arithmetic when
-# the expression reference a repeat DATE variable.
-# Addition and subtraction for repeat date, should follow data arithmetic
-# The repeat variable in the expression must be on the LHS(left hand side)
-# of the expression, otherwise integer arithmetic is used
-import os
-import ecflow
-import ecflow_test_util as Test
-
-
-def test_repeat_arithmetic(repeat_to_add,repeat_to_add2):
-    defs = ecflow.Defs()
-    s1 = defs.add_suite("s1");
-    t1 = s1.add_task("t1").add_repeat( repeat_to_add );
-    t2 = s1.add_task("t2").add_trigger("t1:YMD ge 20100601");
- 
-    # Check trigger expressions
-    assert len(defs.check()) == 0,  "Expected no errors in parsing expressions."
- 
-    # Initial value of repeat is 20090101 hence trigger should fail to evaluate
-    assert t2.evaluate_trigger() == False, "Expected trigger to evaluate. 20090101 >= 20100601"
-   
-    # Check end of month - 1
-    t2.change_trigger("t1:YMD - 1 eq 20081231")
-    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101 - 1  == 20081231"
-
-    # check addition
-    t2.change_trigger("t1:YMD + 1 eq 20090102");    
-    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101 + 1  == 20090102"
-
-    # Check the end of each month + 1
-    t1.delete_repeat();
-    t1.add_repeat( repeat_to_add2 ) 
-    t2.change_trigger("t1:YMD + 1 eq 20090201");   
-    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090131 + 1  == 20090201"
-
-
-def test_repeat_datetime_arithmetic(repeat_to_add,repeat_to_add2):
-
-    defs = ecflow.Defs()
-    s1 = defs.add_suite("s1")
-    t1 = s1.add_task("t1").add_repeat( repeat_to_add )
-    t2 = s1.add_task("t2").add_trigger("t1:DT ge 20100601T000000")
-
-    # Check trigger expressions
-    print(f"## defs: {defs}")
-    assert len(defs.check()) == 0,  "Expected no errors in parsing expressions."
-
-    # Initial value of repeat is 20090101 hence trigger should fail to evaluate
-    assert t2.evaluate_trigger() == False, "Expected trigger to evaluate. 20090101T000000 >= 20100601T000000"
-
-    # Check end of month - 1 day
-    t2.change_trigger("t1:DT - 86400 eq 20081231T000000")
-    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101T000000 - 86400  == 20081231T000000"
-
-    # check addition
-    t2.change_trigger("t1:DT + 86400 eq 20090102T000000");
-    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101T000000 + 86400  == 20090102T000000"
-
-    # Check the end of each month + 1 day
-    t1.delete_repeat();
-    t1.add_repeat( repeat_to_add2 )
-    t2.change_trigger("t1:DT + 86400 eq 20090201T000000");
-    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090131 + 86400  == 20090201T000000"
-
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
-
-    test_repeat_arithmetic(ecflow.RepeatDate("YMD", 20090101, 20091231, 1),
-                           ecflow.RepeatDate("YMD", 20090131, 20101231, 1))
-    test_repeat_arithmetic(ecflow.RepeatDateList("YMD", [20090101, 20091231]),
-                           ecflow.RepeatDateList("YMD", [20090131, 20101231]))
-
-    test_repeat_datetime_arithmetic(ecflow.RepeatDateTime("DT", "20090101T000000", "20091231T000000", "24:00:00"),
-                                    ecflow.RepeatDateTime("DT", "20090131T000000", "20101231T000000", "24:00:00"))
-
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestSimulator.py 5.13.0-1/Pyext/test/py_u_TestSimulator.py
--- 5.12.4-1/Pyext/test/py_u_TestSimulator.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestSimulator.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,129 +0,0 @@
-#####1####/2####/3####/4####/5####/6####/7####/8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http:#www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#####1####/2####/3####/4####/5####/6####/7####/8
-
-#  Test that simulation works
-
-import os,fnmatch
-import ecflow
-import ecflow_test_util as Test
-
-def simulate_defs_with_time():
-    #suite test_time_series
-    #  family family
-    #      task t1
-    #         time 00:00 23:00 04:00  # should run 6 times 00:00 04:00 08:00 12:00 16:00 20:00
-    #  endfamily
-    #endsuite
-    print("simulate_defs_with_time()")
-    defs = ecflow.Defs()
-    suite = defs.add_suite("test_time_series")
-    clock = ecflow.Clock(1, 1, 2011, False)       # day,month, year, hybrid make test start at midnight, otherwise current time used
-    suite.add_clock(clock)
-    family = suite.add_family("family")
-    task = family.add_task("t1")
-    ts = ecflow.TimeSeries(ecflow.TimeSlot(0,0), ecflow.TimeSlot(23,0), ecflow.TimeSlot(4,0), True)
-    task.add_time( ecflow.Time(ts) )
-    task.add_verify( ecflow.Verify(ecflow.State.complete, 6) ) # expect task to complete 6 times
-         
-    theResult = defs.simulate()
-    assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
-    
-    print("  simple check for state change time")
-    print("   iso_extended:",task.get_state_change_time())
-    print("   iso_extended:",task.get_state_change_time("is0_extended"))
-    print("   iso         :",task.get_state_change_time("iso"))
-    print("   simple      :",task.get_state_change_time("simple"))
-    print("   rubbish     :",task.get_state_change_time("rubbish"))
- 
-    os.remove("test_time_series.def.log")
-    
-def simulate_deadlock():
-    # This simulation is expected to fail, since we have a deadlock/ race condition
-    
-    print ("simulate_deadlock")
-    # suite dead_lock
-    #  family family
-    #    task t1
-    #          trigger t2 == complete
-    #    task t2
-    #          trigger t1 == complete
-    #   endfamily
-    # endsuite
-    
-    defs = ecflow.Defs()
-    suite = defs.add_suite("dead_lock")
-    fam = suite.add_family("family")
-    fam.add_task("t1").add_trigger("t2 == complete")
-    fam.add_task("t2").add_trigger("t1 == complete")
-    
-    theResult = defs.simulate()
-    assert len(theResult) != 0, "Expected simulation to return errors, but found none" 
-    print(theResult)
-           
-    os.remove("dead_lock.def.log")
-    os.remove("defs.depth")
-    os.remove("defs.flat")
-
-def test_time_series():
-    print ("Simulator:: ...test_time_series")
-
-    # suite suite
-    #  clock real <sunday>
-    #    family family
-    #       task t1
-    #       time 00:30 23:59 04:00  # should run 6 times 00:30 4:30 8:30 12:30 16:30 20:30
-    #      endfamily
-    #endsuite
-
-    # Initialise real clock on a Monday, such that task should _only_ run
-    # on Monday since we are using a hybrid clock
-    clock = ecflow.Clock(12, 10, 2009, False)     # day,month, year, hybrid 12 October 2009 was a Monday
-
-    theDefs = ecflow.Defs()
-    suite = theDefs.add_suite("test_time_series")
-    suite.add_clock( clock )
-
-    fam = suite.add_family( "family" )
-    task = fam.add_task("t")
-    
-    task.add_time("00:30 23:59 04:00");
-    task.add_verify( ecflow.Verify(ecflow.State.complete, 6) ) # expect task to complete 6 times
-
-    theResult = theDefs.simulate()
-    assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
-
-    os.remove("test_time_series.def.log")
-    
-
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
- 
-    simulate_defs_with_time()
-    simulate_deadlock()
-    test_time_series()
-    
-    # traverse the CSim test data, make sure python simulation matches c++
-    workspace_dir = ecflow.File.source_dir()
-    csim_test_data = workspace_dir + "/CSim/test/data/good_defs"
-    print (csim_test_data)
-    for path in Test.all_files(csim_test_data,'*.def'):
-        print (path)
-        theDefs = ecflow.Defs(path)
-        theResult = theDefs.simulate()
-        assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
-
-    # remove generated .log files
-    for path in Test.all_files(".",'*.log'):
-        os.remove(path)
-        
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_TestTraversal.py 5.13.0-1/Pyext/test/py_u_TestTraversal.py
--- 5.12.4-1/Pyext/test/py_u_TestTraversal.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestTraversal.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,228 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# This file is used to test the python traversal routines
-# This is done by loading from disk a defs file.
-# traversing this defs file, and creating another defs file
-# then comparing the two. If traversal was correct. the file should be the same
-
-import ecflow
-import ecflow_test_util as Test
-import os,fnmatch,sys
-            
-class Indentor:
-    """This class manages indentation, for use with context manager
-    It is used to correctly indent the definition node tree hierarchy
-    """
-    _index = 0
-    def __init__(self):
-        Indentor._index += 1
-    def __del__(self):
-        Indentor._index -= 1
-    @classmethod
-    def indent(cls,the_file):
-        for i in range(Indentor._index):
-            the_file.write(' ')
-            
-class DefsTraverser:
-    """Traverse the ecflow.Defs definition and write to file.
-    
-    This demonstrates that all nodes in the node tree and all attributes are accessible.
-    Additionally the state data is also accessible. This class will write state data as
-    comments. If the definition was returned from the server, it allows access to latest 
-    snapshot of the state data held in the server. 
-    """
-    def __init__(self,defs,file_name):
-        assert (isinstance(defs,ecflow.Defs)),"Expected ecflow.Defs as first argument"
-        assert (isinstance(file_name,str)),"Expected a string argument. Representing a file name"
-        self.__defs = defs
-        self.__file = open(file_name, 'w')
-        
-    def write_to_file(self):
-        for extern in self.__defs.externs:
-            self.__writeln("extern " + extern)
-        for suite in self.__defs:
-            self.__write("suite ")
-            self.__print_node(suite)
-            clock = suite.get_clock()
-            if clock:
-                indent = Indentor()
-                self.__writeln(str(clock))
-                del indent
-            self.__print_nc(suite)
-            self.__writeln("endsuite")  
-        self.__file.close()
-
-    def __print_nc(self,node_container):
-        indent = Indentor()
-        for node in node_container:
-            if isinstance(node, ecflow.Task):
-                self.__write("task ")
-                self.__print_node(node)
-                self.__print_alias(node)
-            else: 
-                self.__write("family ")
-                self.__print_node(node)
-                self.__print_nc(node)
-                self.__writeln("endfamily")
-        del indent
-
-    def __print_alias(self,task):
-       indent = Indentor()
-       for alias in task:
-           self.__write("alias ")
-           self.__print_node(alias)
-           self.__writeln("endalias")
-       del indent
-
-    def __print_node(self,node):
-        self.__file.write(node.name() + " # state:" + str(node.get_state()) + "\n")
-        
-        indent = Indentor()
-        defStatus = node.get_defstatus()
-        if defStatus != ecflow.DState.queued: 
-            self.__writeln("defstatus " + str(defStatus))
-            
-        autocancel = node.get_autocancel()
-        if autocancel: self.__writeln(str(autocancel))
-
-        autoarchive = node.get_autoarchive()
-        if autoarchive: self.__writeln(str(autoarchive))
-
-        autorestore = node.get_autorestore()
-        if autorestore: self.__writeln(str(autorestore))
-        
-        repeat = node.get_repeat()
-        if not repeat.empty(): self.__writeln(str(repeat)  + " # value: " + str(repeat.value()))
-    
-        late = node.get_late()
-        if late: self.__writeln(str(late) + " # is_late: " + str(late.is_late()))
-
-        complete_expr = node.get_complete()
-        if complete_expr:
-            for part_expr in complete_expr.parts:
-                trig = "complete "
-                if part_expr.and_expr(): trig = trig + "-a "
-                if part_expr.or_expr():  trig = trig + "-o "
-                self.__write(trig)
-                self.__file.write( part_expr.get_expression() + "\n")
-        trigger_expr = node.get_trigger()
-        if trigger_expr:
-            for part_expr in trigger_expr.parts:
-                trig = "trigger "
-                if part_expr.and_expr(): trig = trig + "-a "
-                if part_expr.or_expr():  trig = trig + "-o "
-                self.__write(trig)
-                self.__file.write( part_expr.get_expression() + "\n")
-                
-        for var in node.variables:    self.__writeln("edit " + var.name() + " '" + var.value() + "'")
-        for meter in node.meters:     self.__writeln(str(meter) + " # value: " + str(meter.value()))
-        for event in node.events:     self.__writeln(str(event) + " # value: " + str(event.value()))
-        for label in node.labels:     self.__writeln(str(label) + " # value: " + label.new_value())
-        for limit in node.limits:     self.__writeln(str(limit) + " # value: " + str(limit.value()))
-        for inlimit in node.inlimits: self.__writeln(str(inlimit))
-        for the_time in node.times:   self.__writeln(str(the_time))
-        for today in node.todays:     self.__writeln(str(today))   
-        for date in node.dates:       self.__writeln(str(date))  
-        for day in node.days:         self.__writeln(str(day))   
-        for cron in node.crons:       self.__writeln(str(cron))    
-        for verify in node.verifies:  self.__writeln(str(verify))
-        for zombie in node.zombies:   self.__writeln(str(zombie))
-        for queue in node.queues:     self.__writeln(str(queue))
-        for generic in node.generics: self.__writeln(str(generic))
-        
-        del indent
-
-    def __write(self,the_string):
-        Indentor.indent(self.__file)
-        self.__file.write(the_string)
-
-    def __writeln(self,the_string):
-        Indentor.indent(self.__file)
-        self.__file.write(the_string + "\n")
-                                   
-def check_traversal(path_to_def):
-    # Open a def on disk *and* load into memory
-    reference_def = ecflow.Defs( path_to_def )
-         
-    # traverse the opened def and write it out again
-    file_name = "copy.def"
-    traverser = DefsTraverser(reference_def,file_name)
-    traverser.write_to_file()
-         
-    # restore the defs we create via traversal. If traversal was good it should
-    # be the same as def on disk.
-    try:
-        traversed_def = ecflow.Defs( file_name )
-    except RuntimeError as e: 
-        print("Could not parse file " + file_name + "\n" + str(e))
-        sys.exit(1)
-         
-    # compare the two defs
-    ecflow.Ecf.set_debug_equality(True)
-    defs_equal = (traversed_def == reference_def)
-    if not defs_equal:
-        print(str(path_to_def) + " FAILED ")
-        print("The traversed defs=========\n" + str(traversed_def) + "\nnot the same as reference def============\n" + str(reference_def))
-        print("===================== " + file_name + " ====================================")
-        the_traversed_def_on_disk = open(file_name)
-        for line in the_traversed_def_on_disk:
-            print(line)
-            
-        assert defs_equal, "Failed: ---"
-      
-        # Notice: this path does not delete file_name, left for analysis of failure
-    else:
-        print(str(path_to_def) + " PASSED ")
-        os.remove(file_name)        
-        
-
-def all_files(root, patterns='*', single_level=False, yield_folders=False):
-    """Expand patterns from semi-colon separated string to list"""
-    patterns = patterns.split(';')
-    for path, subdirs, files in os.walk(root):
-        if yield_folders:
-            files.extend(subdirs)
-        files.sort()
-        for name in files:
-            for pattern in patterns:
-                if fnmatch.fnmatch(name,pattern):
-                    yield os.path.join(path, name)
-                    break
-        if single_level:
-            break    
-        
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
- 
-    cwd = os.getcwd()
-    #print cwd
-    #print "split = " + str(os.path.split(cwd))
-    #print "basename = " + os.path.basename(cwd)
-    #print "dirname = " + os.path.dirname(cwd)
-    #print "splitext = " + str( os.path.splitext(cwd) )
-    #print "isdir = " + str(os.path.isdir(cwd))
-    
-    # Traverse all the good defs in the Parser directory
-    newpath = ""
-    if os.path.basename(cwd) == "Pyext":
-        newpath = os.path.join( os.path.dirname(cwd),"ANode/parser/test/data/good_defs" )
-    
-    #print newpath
-    for path_to_defs_file in all_files(newpath, '*.def;*.txt'):
-        check_traversal(path_to_defs_file)
-        
-    # try the mega_def. Commented out since it takes to long
-    #mega_def = os.path.join( os.path.dirname(cwd), "ANode/parser/test/data/single_defs/mega.def")
-    #check_traversal(mega_def)
-    print("All Tests pass")    
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_TestUserManual.py 5.13.0-1/Pyext/test/py_u_TestUserManual.py
--- 5.12.4-1/Pyext/test/py_u_TestUserManual.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestUserManual.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,135 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# This code is used in the user manual 
-#
-
-from ecflow import Suite, Task, RepeatDate
-      
-if __name__ == "__main__":
- 
-    class ExperimentalSuite(object):
-        def __init__(self, start, end) :
-            self.start_ = start
-            self.end_ = end
-            self.start_cycle_ = 12
-            self.end_cycle_ = 12
-            
-        def generate(self) :
-            x_suite = Suite("x")
-            make_fam = x_suite.add_family("make")
-            make_fam.add_task("build")
-            make_fam.add_task("more_work")
-            
-            main_fam = x_suite.add_family("main")
-            main_fam.add_repeat( RepeatDate("YMD",self.start_,self.end_) )
-            main_fam.add_trigger( "make == complete" )
-           
-            previous = 0
-            for FAM in ( 0, 6, 12, 18 ) :
-                fam_fam = x_suite.add_family(str(FAM))
-                if FAM > 0 :
-                    fam_fam.add_trigger( "./" + str(previous) + " == complete " )
-                   
-                self.add_complete(fam_fam,FAM)
-                
-                fam_fam.add_task("run")
-                fam_fam.add_task("run_more").add_trigger( "run == complete")
-                previous = FAM
-            return x_suite
-           
-        def add_complete(self, family, fam):
-            if fam < self.start_cycle_ and fam > self.end_cycle_ :
-                family.add_complete("../main:YMD eq " + str(self.start_) + " or ../main:YMD ge " + str(self.end_))  
-            elif fam < self.start_cycle_  :
-                family.add_complete("../main:YMD eq " + str(self.start_))            
-            elif fam > self.end_cycle_    :
-                family.add_complete("../main:YMD ge " + str(self.end_))
-            return
- 
-    print(str( ExperimentalSuite(20050601,20050605).generate() ))
-   
-# ==========================================================================
- 
-# Control structure and looping
-    var = "aa"
-    if var in ( "a", "aa", "aaa" ) :     print("it is a kind of a ")
-    elif var in ( "b", "bb", "bb" ) :    print("it is a kind of b ")
-    else :                               print("it is something else ")
-   
-              
-# ====================================================================================
-
-    # Reuseable class for adding synoptic times
-    class VarAdder(object):
-        def __init__(self, node):
-            self.node = node
-          
-        def add(self, time):
-            {
-               6:  lambda  self : self.add6(time),
-               12: lambda  self : self.add12(time),
-               18: lambda  self : self.add18(time),
-               24: lambda  self : self.add24(time) 
-             }.get(time, self.errorHandler)(self)
-      
-        def add6(self, time):  
-            print("add6 " + str(time))
-            self.node.add_today(17, 30)
-            self.node.add_variable("ANTIME", str(time))
-
-        def add12(self, time):  
-            print("add12 " + str(time))
-            self.node.add_today(19, 15)
-            self.node.add_variable("ANTIME", str(time))
-
-        def add18(self, time):  
-            print("add18 " + str(time))
-            self.node.add_time(1, 30)
-            self.node.add_variable("ANTIME", str(time))
-
-        def add24(self, time):  
-            print("add24 " + str(time))
-            self.node.add_time(3, 0)
-            self.node.add_variable("ANTIME", "0")
-            self.node.add_variable("DELTA_DAY", "1")
-            self.node.add_variable("EXPVER", "0002")
-         
-        def errorHandler(self, ignore): print("invalid time " + str(ignore))
-
-#for i in (0, 6 ,12, 18, 24):
-for i in (0, 6):
-    task = Task("t" + str(i))
-    print(task.name())
-    varAdder = VarAdder(task)
-    varAdder.add(114)
-    for var in task.variables: 
-        print(str(var) + "\n")
-    for the_time in task.times : 
-        print(str(the_time) + "\n")
-    for today in task.todays : 
-        print(str(today) + "\n")
-         
-# ==========================================================================
-
-suite = Suite("x")
-previous_time = 0
-for i in (0,6,12,18,24) :
-    the_fam = suite.add_family(str(i))
-    if i != 0:
-        the_fam.add_trigger("./" + previous_time + " == complete ")
-    the_fam.add_task("t1")
-    the_fam.add_task("t2").add_trigger("t1 == complete")
-    previous_time = str(i)
-
-# print str(suite)
diff -pruN 5.12.4-1/Pyext/test/py_u_TestWith.py 5.13.0-1/Pyext/test/py_u_TestWith.py
--- 5.12.4-1/Pyext/test/py_u_TestWith.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_TestWith.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,94 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# code for testing with statement
-# In our case it provides the ability to indent
-
-from ecflow import Defs, Suite, Task, Family, Client, Variable, Edit, debug_build
-import ecflow_test_util as Test
-import sys,os
-    
-if __name__ == "__main__":
-    Test.print_test_start(os.path.basename(__file__))
- 
-    # sys.version_info is a tuple containing (major,minor,micro,releaselevel,serial)
-    version = sys.version_info;
-    if (sys.version_info < (2, 7)):
-        print("This test only run with python version 2.7 or greater, but found : " + str(version))
-        sys.exit(0)
-    
-    # Add with context manager, in our case this only provides ability to indent
-    with Defs() as defs:
-        with defs.add_suite("s2") as s2:
-            with s2.add_family("f1") as f1:
-                with f1.add_task("t1") as t1:
-                    assert len(f1) == 1,"Expected 1 task"
-            s2.add_family("f2")
-            s2.add_task("t1")
-        assert len(s2) == 3,"Expected 2 families and one task suite"
-    assert len(defs) == 1,"Expected 1 suite"
-#    print defs
- 
-    with Suite("s2") as s2:
-        s2.add_family("f1")
-        s2.add_task("t1")
-        assert len(s2) == 2,"Expected 2 nodes family and task"
-        
-    with Family("f1") as f1:
-        f1.add_family("f2")
-        f1.add_task("t1")
-        assert len(s2) == 2,"Expected 2 nodes family and task"
-        
-        
-    #
-    # Add Nodes functional way
-    #
-    defs1 = Defs()
-    defs1.add_suite("s1").add_task("t1").add_variable("var","v")
-    defs1.add_suite("s2").add_family("f1").add_task("t1").add_variable("var","v")
-    defs1.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
-    
-    # add node using with, they should compare
-    with Defs() as defs2:
-        with defs2.add_suite("s1") as s1:
-            t1 = s1.add_task("t1")
-            t1.add_variable("var","v")
-        with defs2.add_suite("s2") as s2:
-            with s2.add_family("f1") as f1:
-                with f1.add_task("t1") as t1:
-                    t1.add_variable("var","v")
-        with defs2.add_suite("s3") as s3:
-            with s3.add_family("f1") as f1:
-                with f1.add_family("f2") as f2: 
-                    with f2.add_task("t1") as t1: 
-                        t1.add_variable("var","v")
-    
-    assert defs1 == defs2,"expected defs to be the same"     
-    
-    # add node using with, they should compare
-    with Defs() as defs3:
-        with defs3.add_suite("s1") as s1:
-            s1 + Task('t1',var='v')
-        with defs3.add_suite("s2") as s2:
-            with s2.add_family("f1") as f1:
-                with f1.add_task("t1") as t1:
-                    t1 += Edit(var='v')
-        with defs3.add_suite("s3") as s3:
-            with s3.add_family("f1") as f1:
-                with f1.add_family("f2") as f2: 
-                    with f2.add_task("t1") as t1: 
-                        t1 += Edit(var='v')
-    
-    assert defs1 == defs3,"expected defs to be the same"           
-        
-    print("All tests pass")
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_sort.py 5.13.0-1/Pyext/test/py_u_sort.py
--- 5.12.4-1/Pyext/test/py_u_sort.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_sort.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,137 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-import unittest 
-from ecflow import *
-
-class Test_sort(unittest.TestCase):
-
-    def get_object_list(self,obj,name_list):
-        if obj == 'Meter': 
-            return [ Meter(name,0,100) for name in name_list ]
-        elif obj == 'Label':
-            return [ Label(name,'value') for name in name_list ]
-        elif obj == 'Variable':
-            return [ Variable(name,'value') for name in name_list ]
-        elif obj == 'Limit':
-            return [ Limit(name,10) for name in name_list ]
-        else:
-            return [ eval(obj)(name) for name in name_list ]
-
-    def test_sort_objects(self):
-        names = [ 'zz',  'ww', 'aa']
-        object_list = [ 'Task','Family','Suite','Event','Meter','Label','Variable','Limit']
-        for obj in object_list:
-            self.assertEqual(sorted(self.get_object_list(obj,names)), self.get_object_list(obj,sorted(names)), " sort of " + obj + " failed")
-#             print(obj,'-----------------')
-#             for item in sorted(self.get_object_list(obj,names)):
-#                 print(item)
-                
-                
-class Test_sort_api(unittest.TestCase):
-    def test_sort_attributes_api(self):
-        nodes = [ Defs(), Suite('s'), Family('f'), Task('t')]
-        sort_attr = ['event','meter','label','variable','all']
-        for attr in sort_attr:
-            for node in nodes:
-                node.sort_attributes(attr)
-                node.sort_attributes(attr,True)
-                node.sort_attributes(attr,True,['/path','/path2'])
-
-        sort_attr = [AttrType.event, AttrType.meter, AttrType.label,AttrType.variable, AttrType.all  ]
-        for attr in sort_attr:
-            for node in nodes:
-                node.sort_attributes(attr)
-                node.sort_attributes(attr,True)
-                node.sort_attributes(attr,True,['/path','/path2'])
-
-# see ECFLOW-1642
-class Test_ECFLOW_1642(unittest.TestCase):
-    def get_events(self):
-        return [Event(name) for name in
-            "foo buzz bar google zulu mason".split()]
-
-    def sorted_events(self):
-        return [Event(name) for name in
-            "bar buzz foo google mason zulu".split()]
-
-    def expected_def(self):
-        defs = Defs(Suite("mysuite",
-                Family("fam1",self.get_events()),
-                Family("fam2",self.sorted_events(),
-                   Task("task1",self.sorted_events()),
-                ),
-                Task("task2",self.sorted_events()),
-                self.sorted_events()))
-        return defs
-
-    def defs_to_sort(self):
-        defs = Defs(Suite("mysuite",
-                Family("fam1",self.get_events()),
-                Family("fam2",self.get_events(),
-                   Task("task1",self.get_events()),
-                ),
-                Task("task2",self.get_events()),
-                self.get_events()))
-        return defs
-    
-    def test_no_sort(self):
-        defs = self.defs_to_sort()
-        defs.sort_attributes('event',True,['/mysuite/fam1'])
-        self.assertEqual(defs,self.expected_def(),"Expected\n" + str(self.expected_def()) + "but found\n" + str(defs))
-
-    def test_no_sort2(self):
-        defs = self.defs_to_sort()
-        defs.sort_attributes(AttrType.event,True,['/mysuite/fam1'])
-        self.assertEqual(defs,self.expected_def(),"Expected\n" + str(self.expected_def()) + "but found\n" + str(defs))
-    
-class Test_defs_sort(unittest.TestCase):
-    def test_defs_sort_attributes(self):
-        defs = Defs()
-        defs.add_variable("ZFRED", "/tmp/")
-        defs.add_variable("YECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
-        defs.add_variable("XECF_URL_BASE", "http://www.ecmwf.int")
-        defs.add_variable("AECF_URL", "publications/manuals/sms")
-        assert len(list(defs.user_variables)) == 4, "Expected *user* 4 variable"    
-     
-        # sort
-        expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED']
-        actual = []
-        defs.sort_attributes("variable");
-        for v in defs.user_variables: actual.append(v.name())
-        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
- 
-        expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
-        actual = []
-        defs.add_variable("ZZ", "x")
-        defs.sort_attributes(AttrType.variable);
-        for v in defs.user_variables: actual.append(v.name())
-        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-     
-        expected = ['AA', 'AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
-        actual = []
-        defs.add_variable("AA", "x")
-        defs.sort_attributes("all");
-        for v in defs.user_variables: actual.append(v.name())
-        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
-     
-        expected = ['AA', 'AECF_URL', 'BB','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
-        actual = []
-        defs.add_variable("BB", "x")
-        defs.sort_attributes(AttrType.all );
-        for v in defs.user_variables: actual.append(v.name())
-        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
- 
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
\ No newline at end of file
diff -pruN 5.12.4-1/Pyext/test/py_u_test.py 5.13.0-1/Pyext/test/py_u_test.py
--- 5.12.4-1/Pyext/test/py_u_test.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# SCRATCH test for ecflow python api
-
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import unittest 
-import sys
-import os
-
-def test_compile(text):
-    test_file = "py_u_test_tutorial.def"
-    file = open(test_file ,'w')
-    file.write(text)
-    file.close()
-    execfile(test_file)
-    os.remove(test_file)  
-
-class TestCron(unittest.TestCase):
-    def setUp(self):
-        pass
-    
-    def test_pass(self):
-        pass
-
-    def test_fail(self):
-        pass
-        
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_add.py 5.13.0-1/Pyext/test/py_u_test_add.py
--- 5.12.4-1/Pyext/test/py_u_test_add.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_add.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,714 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDateTime, RepeatDateList, RepeatDay, RepeatEnumerated, RepeatInteger, \
-                  RepeatString, SState, State, Style, Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, \
-                  TimeSlot, Today, UrlCmd, Variable, VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, \
-                  ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import unittest 
-import sys
-
-class Test_dunder_rshift(unittest.TestCase):
-    def test_node_dunder_rshift(self):
-        # will ONLY work if we have starting NodeContainer
-        suite = Suite('s') >> Task('t1') >> Task('t2') >> Task('t3') >> Task('t4')
-        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
-        
-        self.assertEqual(str(suite.t2.get_trigger()),"t1 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
-        self.assertEqual(str(suite.t3.get_trigger()),"t2 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
-        self.assertEqual(str(suite.t4.get_trigger()),"t3 == complete","Trigger not as expected: " + str( suite.t4.get_trigger())) 
-
-        fam = Family("f1") >> Task('t1') >> Task('t2') >> Task('t3') >> Task('t4')
-        self.assertEqual(len(list(fam)),4,"expected 4 children but found " + str(len(list(fam))) )
-
-        self.assertEqual(str(fam.t2.get_trigger()),"t1 == complete","Trigger not as expected: " + str( fam.t2.get_trigger())) 
-        self.assertEqual(str(fam.t3.get_trigger()),"t2 == complete","Trigger not as expected: " + str( fam.t3.get_trigger())) 
-        self.assertEqual(str(fam.t4.get_trigger()),"t3 == complete","Trigger not as expected: " + str( fam.t4.get_trigger())) 
-
-    def test_node_dunder_rshift_trigger_cat(self):
-        suite = Suite('s')
-        # will ONLY work if we have starting NodeContainer
-        suite >> Task('t1') >> (Task('t2') + Trigger("x == 1")) >> (Task('t3') + Trigger("y==1")) >> Task('t4')
-        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
-        
-        self.assertEqual(str(suite.t2.get_trigger()),"x == 1 AND t1 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
-        self.assertEqual(str(suite.t3.get_trigger()),"y==1 AND t2 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
-        self.assertEqual(str(suite.t4.get_trigger()),"t3 == complete","Trigger not as expected: " + str( suite.t4.get_trigger())) 
-
-class Test_dunder_lshift(unittest.TestCase):
-    def test_node_dunder_lshift(self):
-        # will ONLY work if we have starting NodeContainer
-        suite = Suite('s') << Task('t1') << Task('t2') << Task('t3') << Task('t4')
-        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
-        
-        self.assertEqual(suite.t4.get_trigger(),None,"Trigger not as expected: " + str( suite.t4.get_trigger())) 
-        self.assertEqual(str(suite.t3.get_trigger()),"t4 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
-        self.assertEqual(str(suite.t2.get_trigger()),"t3 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
-        self.assertEqual(str(suite.t1.get_trigger()),"t2 == complete","Trigger not as expected: " + str( suite.t1.get_trigger())) 
- 
-        fam = Family("f1") << Task('t1') << Task('t2') << Task('t3') << Task('t4')
-        self.assertEqual(len(list(fam)),4,"expected 4 children but found " + str(len(list(fam))) )
- 
-        self.assertEqual(fam.t4.get_trigger(),None,"Trigger not as expected: " + str( fam.t4.get_trigger())) 
-        self.assertEqual(str(fam.t3.get_trigger()),"t4 == complete","Trigger not as expected: " + str( fam.t3.get_trigger())) 
-        self.assertEqual(str(fam.t2.get_trigger()),"t3 == complete","Trigger not as expected: " + str( fam.t2.get_trigger())) 
-        self.assertEqual(str(fam.t1.get_trigger()),"t2 == complete","Trigger not as expected: " + str( fam.t1.get_trigger())) 
-
-    def test_node_dunder_lshift_trigger_cat(self):
-        suite = Suite('s')
-        # will ONLY work if we have starting NodeContainer
-        suite >> Task('t1') << (Task('t2') + Trigger("x == 1")) << (Task('t3') + Trigger("y==1")) << Task('t4')
-        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
-         
-        self.assertEqual(suite.t4.get_trigger(),None,"Trigger not as expected: " + str( suite.t4.get_trigger())) 
-        self.assertEqual(str(suite.t3.get_trigger()),"y==1 AND t4 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
-        self.assertEqual(str(suite.t2.get_trigger()),"x == 1 AND t3 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
-        self.assertEqual(str(suite.t1.get_trigger()),"t2 == complete","Trigger not as expected: " + str( suite.t1.get_trigger())) 
-
-class Test_dunder_add(unittest.TestCase):
-    
-    def test_node_dunder_add_variable(self):
-        # will ONLY work if we have starting NodeContainer
-        suite = Suite("s") + Family("f") + Family("f2") + Task("t3") + Edit(name="value")
-        self.assertEqual(len(list(suite.variables)),1 ,"expected suite to have 1 variable " + str(len(list(suite.variables))) )
-
-        suite = Suite("s") + Family("f") + Family("f2") + (Task("t3") + Edit(name="value"))
-        self.assertEqual(len(list(suite.t3.variables)),1 ,"expected task t3 to have 1 variable " + str(len(list(suite.t3.variables))) )
-                
-    def test_defs_dunder_add(self):
-        # will ONLY work if we have starting defs
-        defs = Defs() + Suite("s") + Suite("s1")
-        self.assertEqual(len(defs),2 ,"expected 2 suites but found " + str(len(defs)) )
-        
-        defs += Suite("sx")  #   + Suite('x')  wont work,   Suite('sx').__add__(Suite('x') not defined
-        self.assertEqual(len(defs),3 ,"expected 3 suites but found " + str(len(defs)) )
-        
-        defs + Suite("a") + Suite("b")
-        self.assertEqual(len(defs),5 ,"expected 5 suites but found " + str(len(defs)) )
-
-    def test_node_dunder_add_meter(self):
-        # will ONLY work if we have starting NodeContainer
-        suite = Suite("s") + Family("f") + Family("f2") + Task("t3") + Edit(name="value")
-        suite.t3 + Event(11,"event") + Meter("meter",0,10,10) + Label("label","c") + Trigger("1==1") 
-        self.assertEqual(len(suite),3 ,"expected 3 children but found " + str(len(suite)) )
-        self.assertEqual(len(list(suite.t3.events)),1 ,"expected 1 event found " + str(len(list(suite.t3.events))) )
-        self.assertEqual(len(list(suite.t3.meters)),1 ,"expected 1 event found " + str(len(list(suite.t3.meters))) )
-        self.assertEqual(len(list(suite.t3.labels)),1 ,"expected 1 event found " + str(len(list(suite.t3.labels))) )
-
-    def test_node_dunder_add(self):
-        suite = Suite("s")  
-        suite += Task("t3")  # + Task("t2") not allowed as Task("t1").__add__("t2") not defined
-        suite.t3 += Event(11,"event")  # + Task("t2") not allowed as Task("t1").__add__("t2") not defined
-        self.assertEqual(len(suite),1 ,"expected 1 children but found " + str(len(suite)) )
-        self.assertEqual(len(list(suite.t3.events)),1 ,"expected 1 event found " + str(len(list(suite.t3.events))) )
-
-        suite = Suite('s') + [ Task("t{0}".format(i)) for i in range(1,5)]
-        self.assertEqual(len(suite),4 ,"expected 4 children but found " + str(len(suite)) )
-
-    def test_dunder_add_all(self):
-        defs = Defs() + Suite("s1")
-        defs.s1 += Clock(1, 1, 2010, False)
-        defs.s1 += Autocancel(1, 10, True)
-        defs.s1 += Task('t1') + Edit({ "a":"y", "b":"bb"}, c="v",d="b") + Edit({ "e":1, "f":"bb"}) +  Edit(g="d") + Edit(h=1) +\
-                    Event(1) + Event(11,"event") + Meter("meter",0,10,10) + Label("label","c") + Trigger("1==1") + \
-                    Complete("1==1") + Limit("limit",10) + Limit("limit2",10) + InLimit("limitName","/limit",2) + \
-                    Defstatus(DState.complete) + Today(0,30) + Today("00:59") + Today("00:00 11:30 00:01") + \
-                    Time(0,30) + Time("00:59") + Time("00:00 11:30 00:01") + Day("sunday") + Day(Days.monday) + \
-                    Date(1,1,0) + Date(28,2,1960) + Autocancel(3) 
-                    
-        t1 = defs.find_abs_node("/s1/t1")
-        self.assertTrue(t1 is not None, "Can't find t1")
-        self.assertEqual(len(defs.s1),1, "Expected 1 nodes but found " + str(len(defs.s1)))
-        self.assertEqual(len(list(t1.variables)), 8, "expected 8 variables but found " + str(len(list(t1.variables))))
-        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
-        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
-        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
-        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
-        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
-        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
-        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
-        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
-        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
-        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
-        #print(defs)
-
-
-class Test_crash(unittest.TestCase):
-    def test_trigger_node_list(self):
-        suite = Suite("s")
-        fam = suite.add_family("f")
-        task = fam.add_task("t")
-        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
- 
-        suite = Suite("s")
-        fam = Family("f")
-        task = Task("t")
-        suite.add_family(fam)
-        task = fam.add_task(task)
-        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
-
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
-
-        # The following will crash or cause memory error. Since the Defs() is transitory/temp()
-        # Unlike the previous example where we keep the defs in a variable.
-        #task = Defs().add_suite("s").add_family("f").add_task("t")
-        #self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
-         
-        # Like wise this will crash since the Suite() is transitory reference counted, and goes out of scope.
-#         task = Suite("s").add_family("f").add_task("t")
-#         self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
-
-class TestListComprehension(unittest.TestCase):
-    def test_suite_list(self):
-        defs = Defs()
-        defs += [ Suite("s{0}".format(i)) for i in range(1,6) ]
-        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
-
-        defs.add( [ Suite("s{0}".format(i)) for i in range(6,11) ] )
-        self.assertEqual(len(defs), 10, " expected 10 suites but found " + str(len(defs)))
-
-        defs = Defs( [ Suite("s{0}".format(i)) for i in range(1,6) ] )
-        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
-
-    def test_family_list(self):
-        defs = Defs()
-        defs += [ Suite("suite").add( [ Family("f{0}".format(i)) for i in range(1,6)]  ) ]
-        self.assertEqual(len(defs.suite), 5, " expected 5 familes but found " + str(len(defs.suite)))
-
-        defs = Defs( [ Suite("xx", [ Family("f{0}".format(i)) for i in range(1,6)]  ) ] )
-        self.assertEqual(len(defs.xx), 5, " expected 5 familes but found " + str(len(defs.xx)))
-
-    def test_task_list(self):
-        defs = Defs()
-        defs += [ Suite("suite").add( Family("f").add( [ Task("t{0}".format(i)) for i in range(1,6)]  )) ]
-        self.assertEqual(len(defs.suite.f), 5, " expected 5 task but found " + str(len(defs.suite.f)))
-
-        defs = Defs( [ Suite("suite", Family("f",[ Task("t{0}".format(i)) for i in range(1,6)]  )) ] )
-        self.assertEqual(len(defs.suite.f), 5, " expected 5 task but found " + str(len(defs.suite.f)))
-
-    def test_task_list2(self):
-        defs = Defs()
-        defs += [ Suite("suite").add( Task("x"), 
-                                      Family("f").add( [ Task("t{0}".format(i)) for i in range(1,6)]  ),
-                                      Task("y"),
-                                      [ Family("f{0}".format(i)) for i in range(1,6) ],
-                                      Edit(a="b"),
-                                      [ Task("t{0}".format(i)) for i in range(1,6) ],
-                                    )
-                ]
-        self.assertEqual(len(defs.suite), 13, " expected 13 nodes but found " + str(len(defs.suite)))
-        self.assertEqual(len(defs.suite.f), 5, " expected 5 nodes but found " + str(len(defs.suite.f)))
-        self.assertEqual(len(list(defs.suite.variables)), 1, " expected 1 variable " + str(len(list(defs.suite.variables))))
-
-    def test_5Suite_with_5families_with_5tasks(self):
-        defs = Defs().add(   
-                [ Suite("s{0}".format(i)).add( 
-                    [ Family("f{0}".format(i)).add( 
-                        [ Task("t{0}".format(i)) 
-                              for i in range(1,6)] ) 
-                        for i in range(1,6)]  ) 
-                    for i in range(1,6) ] )
-        #print defs
-        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
-        for suite in defs:
-            self.assertEqual(len(suite), 5, " expected 5 familes but found " + str(len(suite)))
-            for fam in suite:
-                self.assertEqual(len(fam), 5, " expected 5 tasks but found " + str(len(fam)))
-                
-    def test__5Suite_with_5families_with_5tasks(self):
-        defs = Defs()
-        defs += [ Suite("s{0}".format(i)).add( 
-                        [ Family("f{0}".format(i)).add( 
-                            [ Task("t{0}".format(i)) for i in range(1,6)] ) 
-                        for i in range(1,6)] ) 
-                    for i in range(1,6) 
-                ]
-        #print defs
-        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
-        for suite in defs:
-            self.assertEqual(len(suite), 5, " expected 5 familes but found " + str(len(suite)))
-            for fam in suite:
-                self.assertEqual(len(fam), 5, " expected 5 tasks but found " + str(len(fam)))
-        
-
-class TestTrigger(unittest.TestCase):
-    def test_trigger(self):
-        t = Trigger("a == complete")
-        self.assertEqual(str(t),"a == complete","Trigger not as expected:"+ str(t))
-
-    def test_trigger_string_list(self):
-        t = Trigger(["a"])
-        self.assertEqual(str(t),"a == complete","Trigger not as expected: "+ str(t))
-
-        t = Trigger(["a == 1"])
-        self.assertEqual(str(t),"a == 1","Trigger not as expected: "+ str(t))
-        
-        t = Trigger(["a","b","c"])
-        self.assertEqual(str(t),"a == complete AND b == complete AND c == complete","Trigger not as expected: " + str(t))
-
-    def test_trigger_node_list(self):
-        t = Trigger([Task("a")])
-        self.assertEqual(str(t),"a == complete","Trigger not as expected: "+ str(t))
-
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
-        t = Trigger([task])
-        self.assertEqual(str(t),"/s/f/t == complete","Trigger not as expected: "+ str(t))
-
-    def test_trigger_string_and_node_list(self):
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        t = Trigger(["a","b",task])
-        self.assertEqual(str(t),"a == complete AND b == complete AND /s/f/t == complete","Trigger not as expected: " + str(t))
-        task += t
-        self.assertEqual(str(task.get_trigger() ),"a == complete AND b == complete AND /s/f/t == complete","Trigger not as expected: " + str(task.get_trigger())) 
-
-    def test_add(self):
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        task.add(Trigger("1==1"))
-        expr = task.get_trigger()
-        self.assertEqual(str(expr),"1==1","Trigger not as expected: " +  expr.get_expression())
-        
-        task.add(Trigger("2==1"))
-        self.assertEqual(str(expr),"1==1 AND 2==1","Trigger not as expected: " +  str(expr))
-        
-    def test_add_composition(self):
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        task.add(Trigger("1==1"))
-        task.add(Trigger("1==2",False))
-        task.add(Trigger("x==2"))
-        expr = task.get_trigger()
-        self.assertEqual(str(expr),"1==1 OR 1==2 AND x==2","Trigger not as expected: " +  expr.get_expression())
-
-
-class TestComplete(unittest.TestCase):
-    def test_trigger(self):
-        t = Complete("a == complete")
-        self.assertEqual(str(t),"a == complete","Complete not as expected:"+ str(t))
-
-    def test_Complete_string_list(self):
-        t = Complete(["a"])
-        self.assertEqual(str(t),"a == complete","Complete not as expected: "+ str(t))
-        
-        t = Complete(["a","b","c"])
-        self.assertEqual(str(t),"a == complete AND b == complete AND c == complete","Complete not as expected: " + str(t))
-
-    def test_Complete_node_list(self):
-        t = Complete([Task("a")])
-        self.assertEqual(str(t),"a == complete","Complete not as expected: "+ str(t))
-
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
-        t = Complete([task])
-        self.assertEqual(str(t),"/s/f/t == complete","Complete not as expected: "+ str(t))
-
-    def test_Complete_string_and_node_list(self):
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        t = Complete(["a","b",task])
-        self.assertEqual(str(t),"a == complete AND b == complete AND /s/f/t == complete","Complete not as expected: " + str(t))
-
-    def test_add(self):
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        task.add(Complete("1==1"))
-        expr = task.get_complete()
-        self.assertEqual(str(expr),"1==1","Complete not as expected: " +  expr.get_expression())
-        
-        task.add(Complete("2==1"))
-        self.assertEqual(str(expr),"1==1 AND 2==1","Complete not as expected: " +  str(expr))
-        
-    def test_add_composition(self):
-        defs = Defs()
-        task = defs.add_suite("s").add_family("f").add_task("t")
-        task.add( Complete("1==1"))
-        task.add( Complete("1==2",False))
-        task.add( Complete("x==2"))
-        expr = task.get_complete()
-        self.assertEqual(str(expr),"1==1 OR 1==2 AND x==2","Trigger not as expected: " +  expr.get_expression())
-
-
-class TestDefsAdd(unittest.TestCase):
-    def test_add_suite1(self):
-        defs = Defs().add(Suite("a"))
-        self.assertEqual(len(defs),1,"Expected 1 suite to be added")
-
-    def test_add_suite3(self):
-        defs = Defs().add(Suite("a"),Suite("b"),Suite("c").add(Edit(a="b")))
-        self.assertEqual(len(defs),3,"Expected 3 suite to be added")
-
-    def test_add_variables(self):
-        defs = Defs().add(Edit(a="b",b='c',d='e'))
-        self.assertEqual(len(list(defs.user_variables)),3,"Expected 3 variables to be added")
-
-    def test_add_variables2(self):
-        defs = Defs(Edit(a="b",b='c',d='e'))
-        self.assertEqual(len(list(defs.user_variables)),3,"Expected 3 variables to be added")
-        
-class TestSuiteAdd(unittest.TestCase):
-    def test_add_suite1(self):
-        s = Suite("a").add(Family("a").add(Edit(a="b")))
-        self.assertEqual(len(s),1,"Expected 1 child to be added")
-
-class TestFamilyAdd(unittest.TestCase):
-    def test_add_task(self):
-        s = Family("a").add(Task("a").add(Edit(a="b")))
-        self.assertEqual(len(s),1,"Expected 1 child to be added")
-
-class TestDefstatus(unittest.TestCase):
-    def test_illegal_defstatus(self):
-        if sys.version_info[0] == 2 and sys.version_info[1] >= 7:
-            with self.assertRaises(RuntimeError):
-                Defstatus("fred")
-            
-class TestEdit(unittest.TestCase):
-    def test_add_variable(self):
-        defs = Defs().add(Suite("s").add(Edit(a=1,b=1),Edit(c="c")))
-        self.assertEqual(len(list(defs.s.variables)), 3, "expected 3 variables")
-    
-    def test_edit(self):
-        t = Task("t1").add(
-                    Edit({ "a":"y", "b":"bb"}, c="v",d="b"),
-                    Edit({ "e":"1", "f":"bb"}),
-                    Edit(g="d"),
-                    Edit(h="1"))
-        self.assertEqual(len(list(t.variables)), 8, "expected 8 variables but found " + str(len(list(t.variables))))
-        
-class TestAddAll(unittest.TestCase):
-    def test_add(self):
-        defs = Defs().add(
-            Suite("s1").add(
-                Clock(1, 1, 2010, False),
-                Autocancel(1, 10, True),
-                Task("t1").add(
-                    Edit({ "a":"y", "b":"bb"}, c="v",d="b"),
-                    Edit({ "e":1, "f":"bb"}),
-                    Edit(g="d"),
-                    Edit(h=1),
-                    Event(1),
-                    Event(11,"event"),
-                    Meter("meter",0,10,10),
-                    Label("label","c"),
-                    Trigger("1==1"),
-                    Complete("1==1"),
-                    Limit("limit",10),Limit("limit2",10),
-                    InLimit("limitName","/limit",2),
-                    Defstatus(DState.complete),
-                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01"),
-                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01"),
-                    Day("sunday"),Day(Days.monday),
-                    Date(1,1,0),Date(28,2,1960),
-                    Autocancel(3)
-                    ),
-                [ Family("f{0}".format(i)) for i in range(1,6)]
-            )
-        )
-        t1 = defs.find_abs_node("/s1/t1")
-        self.assertTrue(t1 is not None, "Can't find t1")
-        self.assertEqual(len(defs.s1),6, "Expected 6 nodes but found " + str(len(defs.s1)))
-        self.assertEqual(len(list(t1.variables)), 8, "expected 8 variables")
-        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
-        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
-        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
-        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
-        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
-        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
-        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
-        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
-        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
-        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
-        #print(defs)
-
-    def test_raw_constructor(self):
-        defs = Defs().add(
-            Suite("s1", 
-                Clock(1, 1, 2010, False), 
-                Autocancel(1, 10, True),
-                Task("t1",
-                    Edit({ "a":"y", "b":"bb"}, c="v",d="b"),
-                    Edit({ "e":1, "f":"bb"}),
-                    Edit(g="d"),
-                    Edit(h=1),
-                    Event(1),
-                    Event(11,"event"),
-                    Meter("meter",0,10,10),
-                    Label("label","c"),
-                    Trigger("1==1"),
-                    Complete("1==1"),
-                    Limit("limit",10),Limit("limit2",10),
-                    InLimit("limitName","/limit",2),
-                    Defstatus(DState.complete),
-                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01"),
-                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01"),
-                    Day("sunday"),Day(Days.monday),
-                    Date(1,1,0),Date(28,2,1960),
-                    Autocancel(3)
-                    ),
-                [ Family("f{0}".format(i)) for i in range(1,6)]
-            )
-        )
-        print(defs)
-        t1 = defs.find_abs_node("/s1/t1")
-        self.assertTrue(t1 is not None, "Can't find t1")
-        self.assertEqual(len(defs.s1),6, "Expected 6 nodes but found " + str(len(defs.s1)))
-        self.assertEqual(len(list(t1.variables)), 8, "expected 8 variables")
-        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
-        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
-        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
-        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
-        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
-        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
-        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
-        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
-        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
-        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
-     
-     
-class TestIAdd(unittest.TestCase):
-    def test_iadd_with_getattr(self):
-        defs = Defs();
-        s1 = defs.add_suite("s1")
-        s1 += [ Task("a"),Task("b")]
-        defs.s1.a += [ Edit({ "x1":"y", "aa1":"bb"}, a="v",b="b",),
-                    Edit({ "x":"y", "aa":"bb"}),
-                    Edit(d="d")
-                ]
-        defs.s1.b += [ Event(1),
-                    Event(11,"event"),
-                    Meter("meter",0,10,10),
-                    Label("label","c"),
-                ]
-        self.assertEqual(len(list(defs.s1.a.variables)), 7, "expected 7 variables")
-        self.assertEqual(len(list(defs.s1.b.events)), 2, "expected 2 events")
-        self.assertEqual(len(list(defs.s1.b.meters)), 1, "expected 1 meter")
-        self.assertEqual(len(list(defs.s1.b.labels)), 1, "expected 1 label")
-
-    def test_iadd(self):
-        defs = Defs();
-        defs += [ Suite("s2"),Edit({ "x1":"y", "aa1":"bb"}, a="v",b="b",) ]
-        s1 = defs.add_suite("s1")
-        s1 += [ Clock(1, 1, 2010, False), Autocancel(1, 10, True) ] #+ returns the same node back
-        t1 = s1.add_task("t1")
-        t1 +=   [   Edit({ "x1":"y", "aa1":"bb"}, a="v",b="b",),
-                    Edit({ "x":"y", "aa":"bb"}),
-                    Edit(d="d"),
-                    Event(1),
-                    Event(11,"event"),
-                    Meter("meter",0,10,10),
-                    Label("label","c"),
-                    Trigger("1==1"),
-                    Complete("1==1"),
-                    Limit("limit",10),Limit("limit2",10),
-                    InLimit("limitName","/limit",2),
-                    Defstatus(DState.complete),
-                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01"),
-                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01"),
-                    Day("sunday"),Day(Days.monday),
-                    Date(1,1,0),Date(28,2,1960),
-                    Autocancel(3)
-                ]
-        self.assertTrue(t1 is not None, "Can't find t1")
-        self.assertEqual(len(list(defs.suites)), 2, "expected 7 suites")
-        self.assertEqual(len(list(t1.variables)), 7, "expected 7 variables")
-        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
-        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
-        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
-        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
-        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
-        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
-        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
-        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
-        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
-        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
-        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
-        #print(defs)
-        
-class TestComparison(unittest.TestCase):
-    def setUp(self):
-        self.cron = Cron()
-        self.cron.set_time_series(TimeSeries(TimeSlot(23 , 0) ,True)) # True means relative to suite start
-        self.late = Late()
-        self.late.submitted(TimeSlot(20, 10))
-        self.late.active(TimeSlot(20, 10))
-        self.late.complete(TimeSlot(20, 10), True)
-        self.late2 = Late()
-        self.late2.submitted(20, 10)
-        self.late2.active(20, 10)
-        self.late2.complete(20, 10, True)
-    
-        self.defs1 = Defs()
-        self.defs1.add_suite("s1").add_task("t1").add_variable("a","v").add_event(1).add_event(11,"event").add_meter("meter",0,10,10).add_label("label","c")
-        self.defs1.add_suite("s2").add_family("f1").add_task("t1").add_trigger("1==1").add_complete("1==1")
-        self.defs1.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
-        self.defs1.add_suite("edit").add_variable("a","a").add_variable("b","b") 
-        self.defs1.add_suite("limit").add_limit("limit",10).add_limit("limit2",10) 
-        self.defs1.add_suite("inlimit").add_inlimit("limitName", "/limit", 2)  
-        self.defs1.add_suite("RepeatInteger").add_repeat(RepeatInteger("integer", 0, 100, 2)) 
-        self.defs1.add_suite("RepeatEnumerated").add_repeat(RepeatEnumerated("enum", ["red", "green", "blue" ])) 
-        self.defs1.add_suite("RepeatDate").add_repeat(RepeatDate("ymd", 20100111, 20100115, 2))
-        self.defs1.add_suite("RepeatDateTime").add_repeat(RepeatDateTime("ymd", "20100111T000000", "20100115T000000", "48:00:00"))
-        self.defs1.add_suite("RepeatDateList").add_repeat(RepeatDateList("ymd",[20100111, 20100115]))
-        self.defs1.add_suite("RepeatString").add_repeat(RepeatString("string", ["a", "b", "c" ]))
-        self.defs1.add_suite("RepeatDay").add_repeat(RepeatDay(1))
-        self.defs1.add_suite("defstatus").add_defstatus(DState.active) 
-        self.defs1.add_suite("today").add_task("today").add_today("00:30").add_today(0,59).add_today("00:00 11:30 00:01")
-        self.defs1.add_suite("time").add_task("time").add_time("00:30").add_time(0,59).add_time("00:00 11:30 00:01")
-        self.defs1.add_suite("day").add_task("day").add_day("sunday").add_day(Days.monday)
-        self.defs1.add_suite("date").add_task("date").add_date(1,1,0).add_date(28,2,1960)
-        self.defs1.add_suite("cron").add_task("cron").add_cron(self.cron)
-        self.defs1.add_suite("late").add_family("late").add_late(self.late).add_task("late").add_late(self.late2)
-        self.defs1.add_suite("clock").add_clock(Clock(1, 1, 2010, False))
-        self.defs1.add_suite("autocancel").add_autocancel(3)
-        
-        zombie_suite = self.defs1.add_suite("zombie") 
-        self.zombie_life_time_in_server = 800
-        self.child_list = [ ChildCmdType.init, ChildCmdType.event, ChildCmdType.meter, ChildCmdType.label, ChildCmdType.wait, ChildCmdType.abort,ChildCmdType.complete ]
-        zombie_type_list = [ ZombieType.ecf, ZombieType.user,ZombieType.path ]
-        for zombie_type in zombie_type_list:
-            zombie_attr = ZombieAttr(zombie_type, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server)
-            zombie_suite.add_zombie(zombie_attr)
-   
- 
-    def test_compare_with_add(self):
-        defs = Defs().add(
-            Suite("s1").add(
-                Task("t1").add(
-                    Edit(a="v"),
-                    Event(1),
-                    Event(11,"event"),
-                    Meter("meter",0,10,10),
-                    Label("label","c")
-                )
-            ),
-            Suite("s2").add(
-                Family("f1").add(
-                    Task("t1").add(
-                        Trigger("1==1"),
-                        Complete("1==1")
-                    )
-                )
-            ),
-            Suite("s3").add(
-                Family("f1").add(
-                    Family("f2").add(
-                        Task("t1").add(
-                            Edit(var = "v")
-                        )
-                    )
-                )
-            ),
-            Suite("edit").add( Edit({"a": "a"}), Edit({ "b" : "b"}) ), # add separate, otherwise with dict order is undefined
-            Suite("limit").add( Limit("limit",10),Limit("limit2",10)),
-            Suite("inlimit").add( InLimit("limitName","/limit",2)),
-            Suite("RepeatInteger").add( RepeatInteger("integer", 0, 100, 2)),
-            Suite("RepeatEnumerated").add( RepeatEnumerated("enum", ["red", "green", "blue" ])),
-            Suite("RepeatDate").add( RepeatDate("ymd", 20100111, 20100115, 2)),
-            Suite("RepeatDateTime").add( RepeatDateTime("ymd", "20100111T000000", "20100115T000000", "48:00:00")),
-            Suite("RepeatDateList").add( RepeatDateList("ymd", [20100111, 20100115])),
-            Suite("RepeatString").add( RepeatString("string", ["a", "b", "c" ])),
-            Suite("RepeatDay").add( RepeatDay(1)),
-            Suite("defstatus").add( Defstatus(DState.active)),
-            Suite("today").add(
-                Task("today").add(
-                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01")
-                )
-            ),
-            Suite("time").add(
-                Task("time").add(
-                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01")
-                )
-            ),
-            Suite("day").add(
-                Task("day").add(
-                    Day("sunday"),Day(Days.monday)
-                )
-            ),
-            Suite("date").add(
-                Task("date").add(
-                    Date(1,1,0),Date(28,2,1960)
-                )
-            ),
-            Suite("cron").add(
-                Task("cron").add(
-                    self.cron
-                )
-            ),
-            Suite("late").add(
-                Family("late").add(
-                    self.late,
-                    Task("late").add(
-                        self.late2
-                    )
-                )
-            ),
-            Suite("clock").add( Clock(1, 1, 2010, False)),
-            Suite("autocancel").add( Autocancel(3)),
-            Suite("zombie").add( 
-                ZombieAttr( ZombieType.ecf, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
-                ZombieAttr( ZombieType.user, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
-                ZombieAttr( ZombieType.path, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server)
-            )
-        )      
-
-        self.assertEqual(self.defs1,defs,"defs not equal\n" + str(self.defs1) + "\n\n" + str(defs))    
-
-    def test_compare_with_raw_constructor(self):
-        defs = Defs()
-        defs += Suite('s1',Task('t1',Event(1),Event(11,'event'),Meter("meter",0,10,10),Label("label","c"),a='v'))
-        defs += Suite('s2',Family('f1',Task('t1',Trigger("1==1"),Complete("1==1"))))
-        defs += Suite('s3',Family('f1',Family('f2',Task('t1',var='v'))))
-        defs += Suite('edit',Edit(a='a'),Edit(b='b'))
-        defs += Suite('limit',Limit("limit",10),Limit("limit2",10))
-        defs += Suite('inlimit',InLimit("limitName", "/limit", 2 ))
-        defs += Suite('RepeatInteger',RepeatInteger("integer", 0, 100, 2) )
-        defs += Suite('RepeatEnumerated', RepeatEnumerated("enum", ["red", "green", "blue" ]))
-        defs += Suite('RepeatDate', RepeatDate("ymd", 20100111, 20100115, 2))
-        defs += Suite('RepeatDateTime', RepeatDateTime("ymd", "20100111T000000", "20100115T000000", "48:00:00"))
-        defs += Suite('RepeatDateList', RepeatDateList("ymd", [20100111, 20100115]))
-        defs += Suite('RepeatString',RepeatString("string", ["a", "b", "c" ]))
-        defs += Suite('RepeatDay', RepeatDay(1))
-        defs += Suite('defstatus', Defstatus('active'))
-        defs += Suite('today',Task('today',Today("00:30"),Today(0,59),Today("00:00 11:30 00:01")))
-        defs += Suite('time',Task('time',Time("00:30"),Time(0,59),Time("00:00 11:30 00:01")))
-        defs += Suite('day',Task('day',Day("sunday"),Day(Days.monday)))
-        defs += Suite('date',Task('date',Date(1,1,0),Date(28,2,1960)))
-        defs += Suite('cron',Task('cron',self.cron))
-        defs += Suite('late',Family('late',self.late,Task('late',self.late2)))
-        defs += Suite('clock',Clock(1, 1, 2010, False) )
-        defs += Suite('autocancel',Autocancel(3) )
-        
-        defs += Suite("zombie",ZombieAttr( ZombieType.ecf, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
-                               ZombieAttr( ZombieType.user, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
-                               ZombieAttr( ZombieType.path, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server))
-                               
-        self.assertEqual(self.defs1,defs,"defs not equal\n" + str(self.defs1) + "\n\n" + str(defs))    
-
-        
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_collection.py 5.13.0-1/Pyext/test/py_u_test_collection.py
--- 5.12.4-1/Pyext/test/py_u_test_collection.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_collection.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,101 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-import ecflow
-import unittest 
-
-def setup_test(self):
-    self.defs0 = ecflow.Defs()
-    self.suite0 = ecflow.Suite("s")
-    self.family0 = ecflow.Family("s")
-    self.task0 = ecflow.Task("s")
-
-    self.defs1 = ecflow.Defs();        self.defs1.add_suite("s1")
-    self.suite1 = ecflow.Suite("s");   self.suite1.add_task("t")
-    self.family1 = ecflow.Family("s"); self.family1.add_task("t")
-
-    self.defs3 = ecflow.Defs()
-    self.suite3 = ecflow.Suite("s") 
-    self.family3 = ecflow.Family("s") 
-    [ self.defs3.add_suite("s" + str(i))   for i in [ 1, 2, 3 ] ]
-    [ self.suite3.add_family("f" + str(i)) for i in [ 1, 2, 3 ] ]
-    [ self.family3.add_task("t" + str(i))  for i in [ 1, 2, 3 ] ]
-
-class TestSizedProtocol(unittest.TestCase):
-    def setUp(self):
-        setup_test(self)
-        
-    def test_empty(self):
-        self.assertEqual(len(self.defs0), 0, "Expected empty defs to be of size zero")
-        self.assertEqual(len(self.suite0), 0, "Expected empty suite to be of size zero")
-        self.assertEqual(len(self.family0), 0, "Expected empty family to be of size zero")
-        self.assertEqual(len(self.task0), 0, "Expected empty task to be of size zero")
-
-    def test_size1(self):
-        self.assertEqual(len(self.defs1), 1, "Expected defs with one suite")
-        self.assertEqual(len(self.suite1), 1, "Expected suite with one child")
-        self.assertEqual(len(self.family1), 1, "Expected family with one child")
-
-    def test_size3(self):
-        self.assertEqual(len(self.defs3), 3, "Expected defs with 3 suite but found " + str(len(self.defs3)))
-        self.assertEqual(len(self.suite3), 3, "Expected suite with 3 child but found " + str(len(self.suite3)))
-        self.assertEqual(len(self.family3), 3, "Expected family with 3 child but found " + str(len(self.family3)))
-
-class TestContainerProtocol(unittest.TestCase):
-    def setUp(self):
-        setup_test(self)
-
-    def test_contains(self):
-        self.assertEqual(("s" not in self.defs0), True, "Err in defs container")
-        self.assertEqual(("z" not in self.defs3), True, "Err in defs container")
-        self.assertEqual(("s1" in self.defs3), True, "Err in defs container")
-        self.assertEqual(("s2" in self.defs3), True, "Err in defs container")
-        self.assertEqual(("s3" in self.defs3), True, "Err in defs container")
-
-        self.assertEqual(("f" not in self.suite0), True, "Err in suites container")
-        self.assertEqual(("z" not in self.suite3), True, "Err in suites container")
-        self.assertEqual(("f1" in self.suite3), True, "Err in suites container")
-        self.assertEqual(("f2" in self.suite3), True, "Err in suites container")
-        self.assertEqual(("f3" in self.suite3), True, "Err in suites container")
-
-        self.assertEqual(("z" not in self.family0), True, "Err in family container")
-        self.assertEqual(("t" not in self.family0), True, "Err in family container")
-        self.assertEqual(("t1" in self.family3), True, "Err in family container")
-        self.assertEqual(("t2" in self.family3), True, "Err in family container")
-        self.assertEqual(("t3" in self.family3), True, "Err in family container")
-    
-class TestIterableProtocol(unittest.TestCase):
-    def setUp(self):
-        setup_test(self)
-
-    def test_iterator(self):
-        self.assertTrue(hasattr(self.defs3,'__iter__') , "defs has no __iter__")
-        self.assertTrue(hasattr(self.suite3,'__iter__') , "suite has no __iter__")
-        self.assertTrue(hasattr(self.family3,'__iter__') , "family has no __iter__")
-        self.assertTrue(hasattr(self.task0,'__iter__') , "task has no __iter__ for aliases")
-        self.assertEqual([suite.name() for suite in self.defs3 ] , ["s1","s2","s3"],"Defs iterator protocol not working")
-        self.assertEqual([child.name() for child in self.suite3] , ["f1","f2","f3"],"Suites iterator protocol not working")
-        self.assertEqual([child.name() for child in self.family3], ["t1","t2","t3"],"Family iterator protocol not working")
-        
-class TestNodesIteration(unittest.TestCase):
-    def setUp(self):
-        setup_test(self)
-
-    def test_node_iterator(self):
-        self.assertEqual([suite.name() for suite in self.defs3.suites] , ["s1","s2","s3"],"Defs.suites not working")
-        self.assertEqual([child.name() for child in self.suite3.nodes] , ["f1","f2","f3"],"Suite.nodes working")
-        self.assertEqual([child.name() for child in self.family3.nodes], ["t1","t2","t3"],"Family.nodes not working")
-        self.assertEqual([alias.name() for child in self.task0.nodes]   , []              ,"Task.nodes not working")
-
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_cron.py 5.13.0-1/Pyext/test/py_u_test_cron.py
--- 5.12.4-1/Pyext/test/py_u_test_cron.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_cron.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,114 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# SCRATCH test for ecflow python api
-
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import unittest 
-import sys
-import os
-
-class TestCron(unittest.TestCase):
-    def setUp(self):
-        cron = Cron()
-        cron.set_week_days( [0,1,2,3,4,5,6] )
-        cron.set_days_of_month( [1,2,3,4,5,6] )
-        cron.set_months( [1,2,3,4,5,6] )
-        cron.set_time_series( "+00:00 23:00 00:30" )
-        self.cron1 =  cron
-        
-        cron2 = Cron()
-        cron2.set_time_series(1, 30) # default relative = false, added in release 4.0.7
-        self.cron2 = cron2
-
-        cron3 = Cron()
-        cron3.set_week_days([0, 1, 2, 3, 4, 5, 6 ])
-        cron3.set_time_series(1, 30, True)
-        self.cron3 = cron3
-    
-        cron4 = Cron()
-        cron4.set_week_days([0, 1, 2, 3, 4, 5, 6])
-        cron4.set_time_series("00:30 01:30 00:01")
-        self.cron4 = cron4
-
-        cron5 = Cron()
-        cron5.set_week_days([0, 1, 2, 3, 4, 5, 6])
-        cron5.set_time_series("+00:30")
-        self.cron5 = cron5
-        
-        start = TimeSlot(0, 0)
-        finish = TimeSlot(23, 0)
-        incr = TimeSlot(0, 30)
-        time_series = TimeSeries(start, finish, incr, True)
-        cron6 = Cron( time_series )
-        cron6.set_week_days([0, 1, 2, 3])
-        self.cron6 = cron6
-        
-        cron7 = Cron()
-        cron7.set_week_days( [0,1,2] )                       # This cant overlap with last_week_days_of_the_month
-        cron7.set_last_week_days_of_the_month( [3,4,5,6] )   # This cant overlap with days_of_week
-        cron7.set_days_of_month( [1,2,3,4,5,6] )
-        cron7.set_months( [1,2,3,4,5,6] )
-        cron7.set_time_series( "+00:00 23:00 00:30" )
-        cron7.set_last_day_of_the_month()
-        self.cron7 = cron7
-
-    def test_me0(self):
-        cron = Cron("+00:00 23:00 00:30", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6])
-        self.assertEqual(self.cron1, cron, "cron not equal\n" + str(self.cron1) + "\n" + str(cron))
-                
-        cron = Cron("01:30")
-        self.assertEqual(self.cron2, cron, "cron not equal\n" + str(self.cron2) + "\n" + str(cron))
-
-        cron = Cron("+01:30",days_of_week=[0,1,2,3,4,5,6])
-        self.assertEqual(self.cron3, cron, "cron not equal\n" + str(self.cron3) + "\n" + str(cron))
-
-        cron = Cron("00:30 01:30 00:01",days_of_week=[0,1,2,3,4,5,6])
-        self.assertEqual(self.cron4, cron, "cron not equal\n" + str(self.cron4) + "\n" + str(cron))
-
-        cron = Cron("+00:30",days_of_week=[0,1,2,3,4,5,6])
-        self.assertEqual(self.cron5, cron, "cron not equal\n" + str(self.cron5) + "\n" + str(cron))
-
-        cron = Cron("+00:00 23:00 00:30",days_of_week=[0,1,2,3])
-        self.assertEqual(self.cron6, cron, "cron not equal\n" + str(self.cron6) + "\n" + str(cron))
-
-        cron = Cron("+00:00 23:00 00:30",days_of_week=[0,1,2],                   # This cant overlap with last_week_days_of_the_month
-                                         last_week_days_of_the_month=[3,4,5,6],  # This cant overlap with days_of_week
-                                         days_of_month=[1,2,3,4,5,6],
-                                         months=[1,2,3,4,5,6],
-                                         last_day_of_the_month=True)
-        self.assertEqual(self.cron7, cron, "cron not equal\n" + str(self.cron7) + "\n" + str(cron))
- 
-    def test_fail(self):
-        with self.assertRaises(RuntimeError):
-            cron = Cron("");  # empty
-        with self.assertRaises(RuntimeError):
-            cron = Cron("", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6]); # empty
-        with self.assertRaises(RuntimeError):
-            cron = Cron("0023", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6]) # bad time
-        with self.assertRaises(RuntimeError):
-            cron = Cron("00:10", days_of_weekss=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6]) # bad kw,days_of_weekss
-        with self.assertRaises(RuntimeError):
-            cron = Cron("00:10", days_of_week=[0,1,2,3,4,5,6],days_of_months=[1,2,3,4,5,6], months=[1,2,3,4,5,6]) # bad kw, days_of_months
-        with self.assertRaises(RuntimeError):
-            cron = Cron("00:10", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], monthss=[1,2,3,4,5,6]) # bad kw, monthss
-        with self.assertRaises(RuntimeError):
-            cron = Cron("00:10", days_of_week="0,1,2,3,4,5,6",days_of_month=[1,2,3,4,5,6], month=[1,2,3,4,5,6])  # bad kw, expect vector of string
-        
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_defs_constructor.py 5.13.0-1/Pyext/test/py_u_test_defs_constructor.py
--- 5.12.4-1/Pyext/test/py_u_test_defs_constructor.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_defs_constructor.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,148 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# SCRATCH test for ecflow python api
-
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import unittest 
-import sys
-import os
-
-class Test_default_defs(unittest.TestCase):
-     
-    def setUp(self):
-        self.file_name = 'Test_default_defs.defs'
-        defs = Defs() + Suite('s1')
-        defs.save_as_defs( self.file_name)
- 
-    def test_defs_default_constructor(self):
-        defs = Defs()                 
-        #PrintStyle.set_style( Style.MIGRATE )  
-        #print defs
-        self.assertEqual(defs.get_state(), State.unknown, "expected unknow state but found " + str(defs.get_state()))
-        self.assertEqual(defs.get_server_state(), SState.RUNNING, "expected default server state tobe running state but found " + str(defs.get_server_state()))
-        self.assertEqual(len(list(defs.suites)), 0, "expected no suites but found " + str(len(list(defs.suites))))
- 
-        defs = Defs(self.file_name)  
-        self.assertEqual(defs.get_state(), State.unknown, "expected unknow state but found " + str(defs.get_state()))
-        self.assertEqual(defs.get_server_state(), SState.RUNNING, "expected default server state tobe running state but found " + str(defs.get_server_state()))
-        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
-         
-    def tearDown(self):
-        try:  os.remove(self.file_name)
-        except: pass
-     
-class Test_defs_raw_constructor(unittest.TestCase):
-     
-    def test_defs_raw_constructor_errors(self):
-        with self.assertRaises(RuntimeError):
-            defs = Defs("file_name.def",Suite('s1'))                
-        with self.assertRaises(RuntimeError):
-            defs = Defs("file_name.def",Edit(a='b'))                
-        with self.assertRaises(RuntimeError):
-            defs = Defs("file_name.def",{'a':'b'})                
-        with self.assertRaises(RuntimeError):
-            defs = Defs("file_name.def",Variable('a','b'))                
-        with self.assertRaises(RuntimeError):
-            defs = Defs("file_name.def",[Variable('a','b')])                
-       
-    def test_defs_raw_constructor_suite_creation(self):
-        defs = Defs(Suite('s1'))                
-        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
-
-        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'))                
-        self.assertEqual(len(list(defs.suites)), 3, "expected 3 suites but found " + str(len(list(defs.suites))))
-
-        defs = Defs([ Suite('s{0}'.format(i)) for i in range(1,5) ])                
-        self.assertEqual(len(list(defs.suites)), 4, "expected 4 suites but found " + str(len(list(defs.suites))))
-
-    def test_defs_raw_constructor_variables(self):
-        defs = Defs(Edit(a='b'))                
-        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
-
-        defs = Defs(Variable('a','b'))                
-        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
-
-        defs = Defs({'a':'a','b':'b'})                
-        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
-
-        defs = Defs(a='a',b='b')  # uses kwy word arguments          
-        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
- 
-        defs = Defs(Edit(a='b'),Variable('b','b'),{'c':'a','d':'b'}, e='a',f='b')       
-        self.assertEqual(len(list(defs.user_variables)), 6, "expected 6 user variable but found " + str(len(list(defs.user_variables))))
-
-    def test_defs_raw_constructor(self):
-        defs = Defs(Suite('s1'),Edit(a='b'))                
-        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
-        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
-
-        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'),Variable('a','b'))                
-        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
-        self.assertEqual(len(list(defs.suites)), 3, "expected 3 suites but found " + str(len(list(defs.suites))))
-
-        defs = Defs([ Suite('s{0}'.format(i)) for i in range(1,5) ],{'a':'a','b':'b'})                
-        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
-        self.assertEqual(len(list(defs.suites)), 4, "expected 4 suites but found " + str(len(list(defs.suites))))
-
-        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'),a='a',b='b')  # uses kwy word arguments          
-        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
-        self.assertEqual(len(list(defs.suites)), 3, "expected 3 suites but found " + str(len(list(defs.suites))))
-
-        defs = Defs(Suite('s1'),Edit(a='b'),Variable('b','b'),{'c':'a','d':'b'}, e='a',f='b')       
-        self.assertEqual(len(list(defs.user_variables)), 6, "expected 6 user variable but found " + str(len(list(defs.user_variables))))
-        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
-
-    def test_defs_constructor(self):
-        defs = Defs(Suite('s1'),Edit(a='b'))  
-        defs2 = Defs() + Suite('s1') + Edit(a='b')  
-        defs3 = Defs()
-        defs3 += Suite('s1')
-        defs3 += Edit(a='b')
-        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
-        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
-             
-        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'),Variable('a','b'))  
-        defs2 = Defs() + Suite('s1') + Suite('s2') + Suite('s3') + Variable('a','b')   
-        defs3 = Defs().add(Suite('s1'),Suite('s2'),Suite('s3'),Variable('a','b') )           
-        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
-        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
- 
-        defs = Defs([ Suite('s{0}'.format(i)) for i in range(1,5) ],{'a':'a'})                
-        defs2 = Defs() + [ Suite('s{0}'.format(i)) for i in range(1,5) ] +  {'a':'a'}
-        defs3 = Defs()
-        for i in range(1,5):
-            defs3.add_suite('s{0}'.format(i))   
-        defs3.add_variable('a','a')        
-        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
-        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
- 
-        defs = Defs(Suite('s1'),Edit(a='a'),Variable('b','b'),{'c':'c'},{'d':'d'} )       
-        defs2 = Defs().add(Suite('s1'),Edit(a='a'),Variable('b','b'),{'c':'c'},{'d':'d'})
-        defs3 = Defs()
-        defs3.add_suite('s1')   
-        defs3.add_variable('a','a')        
-        defs3.add_variable('b','b')        
-        defs3.add_variable('c','c')        
-        defs3.add_variable('d','d')        
-        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
-        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
-
-
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_get_attr.py 5.13.0-1/Pyext/test/py_u_test_get_attr.py
--- 5.12.4-1/Pyext/test/py_u_test_get_attr.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_get_attr.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,114 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# SCRATCH test for ecflow python api
-
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate,RepeatDateList, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import unittest 
-import sys
-import os
-
-class Test_get_attr(unittest.TestCase):
-    def test_get_attr(self):
-        defs = Defs() + (Suite('s') + Family('f').add(Task('t') + Edit(var="1")))
-        defs += Edit(var="1")
-        
-        self.assertIsInstance(defs.s, Suite, "Expected suite")
-        self.assertIsInstance(defs.s.f, Family, "Expected family")
-        self.assertIsInstance(defs.s.f.t, Task, "Expected Task but found " + str(type(defs.s.f.t)))
-        
-        self.assertIsInstance(defs.var, Variable, "Expected Variable but found " + str(type(defs.var)))
-        self.assertIsInstance(defs.s.f.t.var, Variable, "Expected Variable but found " + str(type(defs.s.f.t.var)))
-        
-    def test_get_attr_generated_variables(self):
-        defs = Defs() + (Suite('s') + Family('f').add((Task('t')  + Edit(var="1") + RepeatDate("YMD", 20100111, 20100115, 2)),
-                                                      (Task('t2') + Edit(var="1") + RepeatDateList("YMD",[20100111, 20100115 ]))))
-        defs.s.f.t += Meter("meter",0,100)
-        defs.s.f.t += Event("event")
-        defs.s.f.t += Limit("limitx",10)
-        #PrintStyle.set_style(Style.STATE)
-        #print(defs)
-        
-        self.assertTrue(defs.ECF_MICRO, "expected generated variable")
-        self.assertTrue(defs.ECF_HOME, "expected generated variable")
-        self.assertTrue(defs.ECF_JOB_CMD , "expected generated variable")
-        self.assertTrue(defs.ECF_KILL_CMD , "expected generated variable")
-        self.assertTrue(defs.ECF_STATUS_CMD , "expected generated variable")
-        self.assertTrue(defs.ECF_URL_CMD , "expected generated variable")
-        self.assertTrue(defs.ECF_LOG  , "expected generated variable")
-        self.assertTrue(defs.ECF_INTERVAL   , "expected generated variable")
-        self.assertTrue(defs.ECF_LISTS   , "expected generated variable")
-        self.assertTrue(defs.ECF_CHECK   , "expected generated variable")
-        self.assertTrue(defs.ECF_CHECKOLD   , "expected generated variable")
-        self.assertTrue(defs.ECF_CHECKINTERVAL   , "expected generated variable")
-        self.assertTrue(defs.ECF_CHECKMODE   , "expected generated variable")
-        self.assertTrue(defs.ECF_TRIES   , "expected generated variable")
-        self.assertTrue(defs.ECF_VERSION   , "expected generated variable")
-        self.assertTrue(defs.ECF_PORT   , "expected generated variable")
-        self.assertTrue(defs.ECF_HOST    , "expected generated variable")
-
-        self.assertTrue(defs.s.SUITE, "expected generated variable")
-        self.assertEqual(defs.s.SUITE.value() , 's', "expected suite name of 's' but found")
-        self.assertTrue(defs.s.ECF_DATE , "expected generated variable")
-        self.assertTrue(defs.s.YYYY , "expected generated variable")
-        self.assertTrue(defs.s.DOW , "expected generated variable")
-        self.assertTrue(defs.s.DOY , "expected generated variable")
-        self.assertTrue(defs.s.DATE , "expected generated variable")
-        self.assertTrue(defs.s.DAY , "expected generated variable")
-        self.assertTrue(defs.s.DD , "expected generated variable")
-        self.assertTrue(defs.s.MM , "expected generated variable")
-        self.assertTrue(defs.s.MONTH , "expected generated variable")
-        self.assertTrue(defs.s.ECF_CLOCK , "expected generated variable")
-        self.assertTrue(defs.s.ECF_TIME , "expected generated variable")
-        self.assertTrue(defs.s.TIME  , "expected generated variable")
-    
-        self.assertTrue(defs.s.f.FAMILY   , "expected generated variable")
-        self.assertTrue(defs.s.f.FAMILY1   , "expected generated variable")
-
-        self.assertTrue(defs.s.f.t.TASK    , "expected generated variable")
-        self.assertEqual(defs.s.f.t.TASK.value() , 't', "expected task name of 's'")
-        self.assertTrue(defs.s.f.t.ECF_JOB     , "expected generated variable")
-        self.assertTrue(defs.s.f.t.ECF_SCRIPT      , "expected generated variable")
-        self.assertTrue(defs.s.f.t.ECF_JOBOUT      , "expected generated variable")
-        self.assertTrue(defs.s.f.t.ECF_TRYNO      , "expected generated variable")
-        self.assertEqual(defs.s.f.t.ECF_TRYNO.value() , '0', "expected task try no of '0'")
-        self.assertTrue(defs.s.f.t.ECF_RID      , "expected generated variable")
-        self.assertTrue(defs.s.f.t.ECF_NAME      , "expected generated variable")
-        self.assertEqual(defs.s.f.t.ECF_NAME.value()  , '/s/f/t', "expected task ECF_NAME of '/s/f/t'")
-        self.assertTrue(defs.s.f.t.ECF_PASS       , "expected generated variable")
-
-        self.assertEqual(defs.s.f.t.YMD.value() , '20100111', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t.YMD_YYYY.value() , '2010', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t.YMD_MM.value() , '1', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t.YMD_DD.value() , '11', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t.YMD_DOW.value() , '1', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t.YMD_JULIAN.value() , '2455208', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t.event.value() , 0, "expected generated event of value 0 but found " + str(defs.s.f.t.event.value()))
-        self.assertEqual(defs.s.f.t.meter.value() , 0, "expected generated meter of value 0 but found " + str(defs.s.f.t.meter.value()))
-        self.assertEqual(defs.s.f.t.limitx.value() , 0, "expected generated limit of value 0 but found " + str(defs.s.f.t.limitx.value()))#
-        
-        self.assertEqual(defs.s.f.t2.YMD.value() , '20100111', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t2.YMD_YYYY.value() , '2010', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t2.YMD_MM.value() , '1', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t2.YMD_DD.value() , '11', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t2.YMD_DOW.value() , '1', "expected generated YMD of value")
-        self.assertEqual(defs.s.f.t2.YMD_JULIAN.value() , '2455208', "expected generated YMD of value")
-
-
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_late.py 5.13.0-1/Pyext/test/py_u_test_late.py
--- 5.12.4-1/Pyext/test/py_u_test_late.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_late.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,86 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# SCRATCH test for ecflow python api
-
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import unittest 
-import sys
-import os
-
-class TestLate(unittest.TestCase):
-    def setUp(self):
-        late = Late()
-        late.submitted(TimeSlot(20, 10))
-        late.active(TimeSlot(20, 10))
-        late.complete(TimeSlot(20, 10), True)
-        self.late = late
-        #print("setUp ",str(self.late))
-         
-        late = Late()
-        late.submitted(10, 10)
-        late.active(10, 10)
-        late.complete(10, 10, False)
-        self.late1 = late
-          
-        late = Late()
-        late.submitted(10, 10)
-        self.late2 = late
-  
-        late = Late()
-        late.active(10, 10)
-        self.late3 = late
-  
-        late = Late()
-        late.complete(10, 12, False)
-        self.late4 = late
-     
-    def test_pass(self):
-        late = Late(submitted='20:10',active='20:10',complete='+20:10')
-        #print("test_pass",str(late))
-        self.assertEqual(self.late, late, "late shoud be the same:\n" + str(self.late) + "\n" + str(late))
-        
-        late = Late(submitted='10:10',active='10:10',complete='10:10')
-        self.assertEqual(self.late1, late, "late shoud be the same:\n" + str(self.late1) + "\n" + str(late))
-  
-        late = Late(submitted='10:10')
-        self.assertEqual(self.late2, late, "late shoud be the same:\n" + str(self.late2) + "\n" + str(late))
-  
-        late = Late(active='10:10')
-        self.assertEqual(self.late3, late, "late shoud be the same:\n" + str(self.late3) + "\n" + str(late))
-  
-        late = Late(complete='10:12')
-        self.assertEqual(self.late4, late, "late shoud be the same:\n" + str(self.late4) + "\n" + str(late))
-
-    def test_fail(self):
-        self.assertNotEqual(self.late ,  self.late1, "Late should not be equal")
-         
-        with self.assertRaises(RuntimeError):
-            late = Late("");  # no keyword arguments
- 
-        with self.assertRaises(RuntimeError):
-            late = Late(submittedd='20:10',active='20:10',complete='+20:10') # miss-spelt keyword
- 
-        with self.assertRaises(RuntimeError):
-            late = Late(submitted='20:10',activee='20:10',complete='+20:10') # miss-spelt keyword
- 
-        with self.assertRaises(RuntimeError):
-            late = Late(submitted='20:10',active='20:10',completee='+20:10') # miss-spelt keyword
-
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_manual.py 5.13.0-1/Pyext/test/py_u_test_manual.py
--- 5.12.4-1/Pyext/test/py_u_test_manual.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_manual.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,931 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDateTime, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import os 
-import unittest 
-
-class TestAddSuiteFamilyTask0(unittest.TestCase):
-    def setUp(self):
-        defs = Defs()
-        s = Suite('s1')
-        f = Family('f1')
-        t = Task('t1')
-        defs.add_suite(s)
-        s.add_family(f)
-        f.add_task(t)
-        self.defs = defs
-
-    def test_0(self):
-        defs = Defs()
-        defs.add_suite('s1').add_family('f1').add_task('t1')
-        self.assertEqual(self.defs, defs, "defs not equal")
-        
-    def test_1(self):
-        defs = Defs().add(
-            Suite('s1').add(
-                Family('f1').add(
-                    Task('t1'))))
-        self.assertEqual(self.defs, defs, "defs not equal")
-
-    def test_2(self):
-        defs = Defs(
-            Suite('s1',
-                  Family('f1',
-                         Task('t1'))))
-        self.assertEqual(self.defs, defs, "defs not equal")
-
-    def test_3(self):
-        defs = Defs() + (Suite('s1') + (Family('f1') + Task('t1')))
-        self.assertEqual(self.defs, defs, "defs not equal")
-
-    def test_3(self):
-        defs = Defs() + (Suite('s1') + (Family('f1') + Task('t1')))
-        self.assertEqual(self.defs, defs, "defs not equal")
-          
-class TestAddSuiteFamilyTask(unittest.TestCase):
-    def setUp(self):
-        defs = Defs()            # create an empty definition
-        suite = defs.add_suite("s1")    # create a suite and add it to the defs
-        family = suite.add_family("f1") # create a family and add it to suite
-        for i in [ "a", "b", "c" ]:     # create task ta,tb,tc
-            family.add_task( "t" + i)   # create a task and add to family
-        defs.save_as_defs("test.def")   # save defs to file "test.def"  
-         
-        self.defs = defs
-         
-    def test_me(self):
-        with Defs() as defs:
-            with defs.add_suite("s1") as suite:
-                with suite.add_family("f1") as family:
-                    for i in [ "a", "b", "c" ]:      
-                        family.add_task( "t" + i)    
-        defs.save_as_defs("test.def")    
-                     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)
-        self.assertEqual(self.defs, defs, "defs not equal")
-         
-    def test_me2(self):
-        defs = Defs().add( 
-            Suite("s1").add(
-                Family("f1").add(
-                    [ Task("t{0}".format(t)) 
-                      for t in ("a", "b", "c")] )))
-        defs.save_as_defs("test.def")   # save defs to file "test.def"  
-                     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)
-        self.assertEqual(self.defs, defs, "defs not equal")
- 
-    def test_me3(self):
-        defs = Defs()
-        defs += Suite("s1") 
-        defs.s1 += Family("f1") 
-        defs.s1.f1 += [ Task("t{0}".format(t)) 
-                        for t in ("a", "b", "c")] 
-        defs.save_as_defs("test.def")   # save defs to file "test.def"  
-                     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)
-        self.assertEqual(self.defs, defs, "defs not equal")
-        
-    def test_me4(self):
-        defs = Defs(
-                Suite("s1",
-                    Family("f1",
-                        [ Task("t{0}".format(t)) for t in ("a", "b", "c")])))
-        defs.save_as_defs("test.def")   # save defs to file "test.def"  
-                     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)
-        self.assertEqual(self.defs, defs, "defs not equal")
- 
-    def test_me5(self):
-        defs = Defs().add(   
-          [ Suite("s{0}".format(i)).add( 
-              [ Family("f{0}".format(i)).add( 
-                  [ Task("t{0}".format(i)) for i in range(1,6)] ) 
-                for i in range(1,7)]  )
-            for i in range(1,6) ] )
-        assert len(defs)==5, " expected 6 suites but found " + str(len(defs))
-        for suites in defs:
-            assert len(suites)==6, " expected 6 families but found " + str(len(suites))
-            for fam in suites:
-                assert len(fam)==5, " expected 6 tasks but found " + str(len(fam))
-                
-    def test_me6(self):
-        defs = Defs(
-                [ Suite("s{0}".format(i),
-                    [ Family("f{0}".format(i),
-                        [ Task("t{0}".format(i)) for i in range(1,6)] )
-                    for i in range(1,7)]  )
-                for i in range(1,6) ] )
-        assert len(defs)==5, " expected 5 suites but found " + str(len(defs))
-        for suites in defs:
-            assert len(suites)==6, " expected 6 families but found " + str(len(suites))
-            for fam in suites:
-                assert len(fam)==5, " expected 5 tasks but found " + str(len(fam))
-             
-    def tearDown(self):
-        unittest.TestCase.tearDown(self)
-        try: os.remove("test.def")
-        except: pass
-         
-class TestAddMeterEventLabel(unittest.TestCase):
-    def setUp(self):
-        defs = Defs()
-        suite = Suite("s1")
-        task = Task("t1")
-        defs.add_suite(suite)
-        suite.add_task(task)
-        task.add_event( 2 )                      # event reference with 2
-        task.add_event("wow")                    # event reference with name "wow"
-        task.add_event( 10,"Eventname2" )        # event referenced with name "Eventname2"
-        task.add_meter( "metername3",0,100 )     # name, min, max
-        task.add_label( "label_name4", "value" ) # name, value
-         
-        self.defs = defs
-         
-    def test_alternative(self):
-        defs = Defs().add(
-            Suite("s1").add(
-                Task("t1").add(
-                    Event(2),
-                    Event("wow"),
-                    Event(10,"Eventname2" ),
-                    Meter("metername3",0,100),
-                    Label("label_name4", "value"))))
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs,self.defs, "expected defs to be the same")
- 
-    def test_alternative1(self):
-        defs = Defs() + Suite("s1")
-        defs.s1 += Task("t1") + Event(2) + Event("wow") + \
-                    Event(10,"Eventname2" ) + Meter("metername3",0,100) + \
-                    Label("label_name4", "value") 
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-         
-    def test_alternative2(self):
-        with Defs() as defs:
-            with defs.add_suite("s1") as suite:
-                with suite.add_task("t1") as t1:
-                    t1 += [ Event(2),
-                           Event("wow"),
-                           Event(10,"Eventname2" ),
-                           Meter("metername3",0,100),
-                           Label("label_name4", "value") ]
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative3(self):
-        defs = Defs( 
-                Suite('s1',
-                    Task("t1",
-                        Event(2),
-                        Event("wow"),
-                        Event(10,"Eventname2" ),
-                        Meter("metername3",0,100),
-                        Label("label_name4", "value")))) 
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-            
-class TestAddLimitInlimit(unittest.TestCase):
-     
-    def setUp(self):
-        defs = Defs()
-        s1 = defs.add_suite("s1") 
-        s1.add_limit( "limitName4", 10 ) # name, maximum token
-        f1 = s1.add_family("f1")
-        f1.add_inlimit( "limitName4","/s1/f1",2) # limit name, path to limit, tokens consumed
-        for i in range(1,4):
-            f1.add_task( "t{0}".format(i))
-             
-        self.defs = defs
- 
-    def test_alternative(self):
-        defs = Defs().add(
-            Suite("s1").add(
-                Limit("limitName4", 10),
-                Family("f1").add(
-                    InLimit("limitName4","/s1/f1",2),
-                    [ Task("t{0}".format(t)) for t in range(1,4) ]
-                    )))
- 
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")        
- 
-    def test_alternative1(self):
-        defs = Defs() + Suite("s1") 
-        defs.s1 += [ Limit("limitName4", 10),Family("f1") ]
-        defs.s1.f1 += [ InLimit("limitName4","/s1/f1",2),
-                        [ Task("t{0}".format(t)) for t in range(1,4) ] ]
- 
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")        
-         
-    def test_alternative2(self):
-        with Defs() as defs:
-            with defs.add_suite("s1") as s1:
-                s1.add_limit( "limitName4", 10 ) # name, maximum token
-                with s1.add_family("f1") as f1:
-                    f1.add_inlimit( "limitName4","/s1/f1",2) # limit name, path to limit, tokens consumed
-                    f1 += [ Task("t{0}".format(t)) for t in range(1,4) ]
-                     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative3(self):
-        defs = Defs( 
-            Suite("s1",
-                Limit("limitName4", 10),# name, maximum token
-                Family("f1",
-                    InLimit("limitName4","/s1/f1",2), # limit name, path to limit, tokens consumed
-                    [ Task("t{0}".format(t)) for t in range(1,4) ] )))
-                     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
- 
- 
-class TestAddVariable(unittest.TestCase):
-     
-    def setUp(self):
-        defs = Defs()
-        s1 = defs.add_suite("s1") 
-        s1.add_variable("HELLO","world") # name, value
-        s1.add_variable({ "NAME":"value", "NAME2":"value2", "NAME3":"value3", "NAME4":4 }  )
-        s1.add_variable(Variable("FRED","bloggs"))
-        s1.add_variable(Variable("BILL","1"))
-         
-        defs.s1.sort_attributes("variable"); # sort since with dictionary order of addition is arbitary
-        self.defs = defs
-
-    def test_alternative0(self):
-         
-        defs = Defs(Suite("s1",HELLO="world",FRED="bloggs",BILL=1,NAME="value",NAME2="value2"))
-        defs.s1.add_variable('NAME4',4)
-        defs.s1 += Edit(NAME3="value3")
- 
-        defs.s1.sort_attributes("variable");
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
- 
-    def test_alternative(self):
-         
-        defs = Defs().add(
-                      Suite("s1").add(
-                          Edit(HELLO="world",FRED="bloggs",BILL=1,NAME="value",NAME2="value2",NAME3="value3",NAME4=4 )
-                          ))
- 
-        defs.s1.sort_attributes("variable");
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
- 
-    def test_alternative1(self):
-         
-        defs = Defs() + Suite("s1",Edit(HELLO="world"))
-        defs.s1 += [ Edit({ "NAME":"value", "NAME2":"value2", "NAME3":"value3", "NAME4":4 }, BILL=1),
-                     Edit(FRED="bloggs") ]
- 
-        defs.s1.sort_attributes("variable");
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative2(self):
-         
-        defs = Defs(
-                Suite("s1",
-                    { "HELLO":"world", "NAME":"value", "NAME2":"value2", 
-                     "NAME3":"value3", "NAME4":4, "BILL":1, "FRED":"bloggs" }))
- 
-        defs.s1.sort_attributes("variable");
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-
-class TestAddTrigger(unittest.TestCase):
-     
-    def setUp(self):
-        defs = Defs()
-        s1 = defs.add_suite("s1") 
-        t1 = s1.add_task("t1")
-        t2 = s1.add_task("t2")
-        t2.add_trigger( "t1 == active and t3 == aborted" )
-        t2.add_complete( "t3 == complete" )
-        t3 = s1.add_task("t3")
-        self.defs = defs
-
-    def test_alternative0(self):
-        
-        defs = Defs(
-                Suite("s1",
-                    Task("t1"),
-                    Task("t2",
-                        Trigger("t1 == active and t3 == aborted"),
-                        Complete("t3 == complete")),
-                    Task("t3")))
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative(self):
-        
-        defs = Defs().add(
-                 Suite("s1").add(
-                    Task("t1"),Task("t2").add(
-                        Trigger("t1 == active and t3 == aborted"),
-                        Complete("t3 == complete")),
-                    Task("t3")))
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
- 
-    def test_alternative1(self):
-         
-        defs = Defs() + Suite("s1")
-        defs.s1 += [ Task("t{0}".format(i)) for i in range(1,4) ]
-        defs.s1.t2 += [ Trigger("t1 == active and t3 == aborted"),
-                        Complete("t3 == complete") ]
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-
-class TestAddTaskChain(unittest.TestCase):
-
-    def setUp(self):
-        defs = Defs(
-                Suite("s1",
-                    Task("t1"),
-                    Task("t2",Trigger( "t1 == complete" )),
-                    Task("t3",Trigger( "t2 == complete" )),
-                    Task("t4",Trigger( "t3 == complete" ))))
-        self.defs = defs
-        
-    def test_alternative(self):
-        defs = Defs() + Suite("s1")
-        defs.s1 += [ Task("t1"),Task("t2"),
-                     Task("t3"),Task("t4") ]
-        defs.s1.t2 += Trigger( ["t1"] )
-        defs.s1.t3 += Trigger( ["t2"] )
-        defs.s1.t4 += Trigger( ["t3"] )
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-
-    def test_alternative1(self):
-        defs = Defs() + Suite("s1")
-        defs.s1 += [ Task("t1"),Task("t2"),Task("t3"),Task("t4") ]
-        defs.s1.t2 += Trigger( [ defs.s1.t1 ] )
-        defs.s1.t3 += Trigger( [ defs.s1.t2 ] )
-        defs.s1.t4 += Trigger( [ defs.s1.t3 ] )
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative1(self):
-        defs = Defs(Suite("s1"))
-        defs.s1 >> Task("t1") >> Task("t2") >> Task("t3") >> Task("t4")
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-class TestAddReverseTaskChain(unittest.TestCase):
-
-    def setUp(self):
-        defs = Defs(
-                Suite("s1",
-                    Task("t1", Trigger( "t2 == complete" )),
-                    Task("t2", Trigger( "t3 == complete" )),
-                    Task("t3", Trigger( "t4 == complete" )),
-                    Task("t4")))
-        self.defs = defs
-        
-    def test_alternative1(self):
-        defs = Defs() + Suite("s1")
-        defs.s1 << Task("t1") << Task("t2") << Task("t3") << Task("t4")
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-class TestAddLargeTrigger(unittest.TestCase):
-    
-    def setUp(self):
-        defs = Defs()
-        s1 = defs.add_suite("s1") 
-        t1 = s1.add_task("t1")
-        t2 = s1.add_task("t2")
-        t3 = s1.add_task("t3")
-        t3.add_part_trigger( "t1 == complete")
-        t3.add_part_trigger( "t2 == active", True) # here True means add as 'AND'
-        t3.add_part_trigger( "t2 == aborted", False) # here False means add as 'OR'
-        self.defs = defs
-
-    def test_alternative0(self):
-        defs = Defs( 
-                Suite("s1",
-                    Task("t1"),
-                    Task("t2"),
-                    Task("t3",
-                        Trigger("t1 == complete"), 
-                        Trigger("t2 == active"),
-                        Trigger("t2 == aborted",False))))
-        
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative(self):
-        defs = Defs().add(
-                Suite("s1").add(
-                    Task("t1"),
-                    Task("t2"),
-                    Task("t3").add(
-                        Trigger("t1 == complete"), 
-                        Trigger("t2 == active"),
-                        Trigger("t2 == aborted",False),
-                        )
-                    ))
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-
-    def test_alternative1(self):
-         
-        defs = Defs() + Suite("s1")
-        defs.s1 += [ Task("t{0}".format(i)) for i in range(1,4) ]
-        defs.s1.t3 += [ Trigger("t1 == complete"),
-                        Trigger("t2 == active"),
-                        Trigger("t2 == aborted",False) ]
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-class TestAddTimeDependencies(unittest.TestCase):
-    
-    def setUp(self):
-        defs = Defs()
-        s1 = defs.add_suite("s1") 
-        t1 = s1.add_task("date")
-        t1.add_date(1, 0, 0)       # first of every month and every year
-        t1.add_date(Date("2.*.*")) # second of every month and every year
-        t1.add_date(28,2,2026)     # 28 february 2026
-
-        t2 = s1.add_task("day")
-        t2.add_day("monday")
-        t2.add_day(Days.tuesday)
-        
-        t3 = s1.add_task("time")
-        t3.add_time("+00:30")                     # 30 minutes after suite has begun
-        t3.add_time("+00:30 20:00 01:00")         # 00:30,01:30,02:30....07:30 after suite start
-              
-        t3.add_time(0, 59, True)                  #  00:59 - 59 minutes past midnight
-        t3.add_time(Time(TimeSlot(20, 10)))       #  20:10 - 10 minutes pas eight
-        t3.add_time(Time(TimeSlot(20, 20), True)) # +20:20 - 20 minutes and 20 hours, after suite start
-
-        start = TimeSlot(0, 0)
-        finish = TimeSlot(23, 0)
-        incr = TimeSlot(0, 30)
-        time_series = TimeSeries(start, finish, incr, True)        
-        t3.add_time(Time(time_series))
-        t3.add_time(Time(0, 10))                  #  00:10 
-        t3.add_time(Time("+00:40"))               # +00:40
-        t3.add_time(Time("+00:40 20:00 01:00"))   # 00:40,01:40,02:30...17:40 after suite start
-        
-        cron = Cron()
-        cron.set_week_days( [0,1,2,3,4,5,6] )
-        cron.set_days_of_month( [1,2,3,4,5,6] )
-        cron.set_months( [1,2,3,4,5,6] )
-        cron.set_time_series( "+00:00 23:00 00:30" )
-        s1.add_task("cron").add_cron( cron );
-        
-        self.defs = defs
-        
-    def test_alternative0(self):
-        start = TimeSlot(0, 0)
-        finish = TimeSlot(23, 0)
-        incr = TimeSlot(0, 30)
-        time_series = TimeSeries(start, finish, incr, True)
-        
-        defs = Defs( 
-                Suite("s1",
-                    Task("date",
-                        Date(1, 0, 0),                   # first of every month and every year
-                        Date("2.*.*"),                   # second of every month and every yea
-                        Date(28,2,2026)),                # 28 february 2026
-                    Task("day",
-                        Day("monday"),
-                        Day(Days.tuesday)),
-                    Task("time",
-                        Time("+00:30"),                  # 30 minutes after suite has begun
-                        Time("+00:30 20:00 01:00"),      # 00:30,01:30,02:30....07:30 after suite start
-                        Time(0, 59, True),               # 00:59 - 59 minutes past midnight
-                        Time(TimeSlot(20, 10)),          # 20:10 - 10 minutes pas eight
-                        Time(TimeSlot(20, 20), True),    # +20:20 - 20 minutes and 20 hours, after suite start
-                        Time(time_series),
-                        Time(0, 10),
-                        Time("+00:40"),
-                        Time("+00:40 20:00 01:00")),
-                    Task("cron",
-                        Cron("+00:00 23:00 00:30",days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6],months=[1,2,3,4,5,6]))))
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative(self):
-        start = TimeSlot(0, 0)
-        finish = TimeSlot(23, 0)
-        incr = TimeSlot(0, 30)
-        time_series = TimeSeries(start, finish, incr, True)
-        
-        cron = Cron()
-        cron.set_week_days( [0,1,2,3,4,5,6] )
-        cron.set_days_of_month( [1,2,3,4,5,6] )
-        cron.set_months( [1,2,3,4,5,6] )
-        cron.set_time_series( "+00:00 23:00 00:30" )
-
-        defs = Defs().add(
-            Suite("s1").add(
-                Task("date").add(
-                    Date(1, 0, 0),
-                    Date("2.*.*"),
-                    Date(28,2,2026)),
-                Task("day").add(
-                    Day("monday"),
-                    Day(Days.tuesday)),
-                Task("time").add(
-                    Time("+00:30"),
-                    Time("+00:30 20:00 01:00"),
-                    Time(0, 59, True),
-                    Time(TimeSlot(20, 10)),
-                    Time(TimeSlot(20, 20), True),
-                    Time(time_series),
-                    Time(0, 10),
-                    Time("+00:40"),
-                    Time("+00:40 20:00 01:00")),
-                Task("cron").add(
-                    cron)))
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative1(self):
-        start = TimeSlot(0, 0)
-        finish = TimeSlot(23, 0)
-        incr = TimeSlot(0, 30)
-        time_series = TimeSeries(start, finish, incr, True)
-        
-        defs = Defs() + ( Suite("s1") + Task("date") + Task("day") + Task("time") + Task("cron"))
-        defs.s1.date += [ Date(1, 0, 0), Date("2.*.*"), Date(28,2,2026) ]
-        defs.s1.day += [ Day("monday"), Day(Days.tuesday) ]
-        defs.s1.time += [ Time("+00:30"), Time("+00:30 20:00 01:00"), Time(0, 59, True),
-                          Time(TimeSlot(20, 10)), Time(TimeSlot(20, 20), True),
-                          Time(time_series), Time(0, 10), Time("+00:40"),
-                          Time("+00:40 20:00 01:00") ]
-        defs.s1.cron += Cron("+00:00 23:00 00:30",
-                             days_of_week=[0,1,2,3,4,5,6],
-                             days_of_month=[1,2,3,4,5,6],
-                             months=[1,2,3,4,5,6])  
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-class TestAddDefStatus(unittest.TestCase):
-    
-    def setUp(self):
-        defs = Defs()
-        s1 = defs.add_suite("s1") 
-        s1.add_task("t1").add_defstatus(Defstatus("complete"))
-        s1.add_task("t2").add_defstatus(DState.complete)
-        
-        self.defs = defs
-
-    def test_alternative0(self):
-        defs = Defs( 
-                Suite("s1",
-                    Task("t1",Defstatus("complete")),
-                    Task("t2",Defstatus(DState.complete))))
-        
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-
-    def test_alternative(self):
-        defs = Defs().add(
-            Suite("s1").add(
-                Task("t1").add(Defstatus("complete")),
-                Task("t2").add(Defstatus(DState.complete))))
-        
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-
-    def test_alternative1(self):
-        defs = Defs() + ( Suite("s1") +  Task("t1") + Task("t2") )
-        defs.s1.t1 += Defstatus("complete") 
-        defs.s1.t2 += Defstatus(DState.complete) 
-        
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-   
-class TestAddAutocancel(unittest.TestCase):
-    
-    def setUp(self):
-        defs = Defs()
-        s1 = defs.add_suite("s1") 
-        s1.add_task("t1").add_autocancel(3)                                # delete task after 3 days after completion 
-        s1.add_task("t2").add_autocancel(1, 10, True)                      # delete task 1hr 10 min after task completion
-        s1.add_task("t3").add_autocancel(TimeSlot(2,10), True)             # delete task 2hr 10 min after task completion 
-        s1.add_task("t4").add_autocancel(Autocancel(1))                    # delete task after 1 day after task completion
-        s1.add_task("t5").add_autocancel(Autocancel( 18, 10, False))       # delete task at 6:10pm once it has completed
-        s1.add_task("t6").add_autocancel(Autocancel(TimeSlot(2,10), False))# delete task at 2:10am once it has completed
-
-        self.defs = defs
-
-    def test_alternative0(self):
-        defs = Defs( 
-                Suite("s1",
-                    Task("t1", Autocancel(3)),                    # delete task after 3 days after completion 
-                    Task("t2", Autocancel(1, 10, True)),          # delete task 1hr 10 min after task completion
-                    Task("t3", Autocancel(TimeSlot(2,10), True)), # delete task 2hr 10 min after task completion
-                    Task("t4", Autocancel(1)),                    # delete task after 1 day after task completion
-                    Task("t5", Autocancel(18, 10, False)),        # delete task at 6:10pm once it has completed
-                    Task("t6", Autocancel(2, 10, False))))        # delete task at 2:10am once it has completed
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative(self):
-        defs = Defs().add(
-            Suite("s1").add(
-                Task("t1").add(Autocancel(3)),
-                Task("t2").add(Autocancel(1, 10, True)),
-                Task("t3").add(Autocancel(TimeSlot(2,10), True)),
-                Task("t4").add(Autocancel(1)),
-                Task("t5").add(Autocancel(18, 10, False)),
-                Task("t6").add(Autocancel(2, 10, False))))
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-
-
-    def test_alternative1(self):
-        defs = Defs() + ( Suite("s1") + [ Task("t{0}".format(i)) for i in range(1,7)] )
-        defs.s1.t1 += Autocancel(3) 
-        defs.s1.t2 += Autocancel(1, 10, True) 
-        defs.s1.t3 += Autocancel(TimeSlot(2,10), True) 
-        defs.s1.t4 += Autocancel(1)     
-        defs.s1.t5 += Autocancel(18, 10, False) 
-        defs.s1.t6 += Autocancel(2, 10, False)       
-         
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-   
-class TestAddRepeat(unittest.TestCase):
-    def setUp(self):
-        def add_tasks(fam):
-            for i in range(1,3):
-                fam.add_task(Task("t{0}".format(i)))
-                
-        defs = Defs()
-        s1 = defs.add_suite("s1")
-        f1 = s1.add_family("f1")
-        f1.add_repeat( RepeatDate("YMD",20100111,20100115,2) )
-        add_tasks(f1)
-
-        f2 = s1.add_family("f2")
-        f2.add_repeat( RepeatInteger("count",0,100,2)  )
-        add_tasks(f2)
-
-        f3 = s1.add_family("f3")
-        f3.add_repeat( RepeatEnumerated("enum",["red", "green", "blue" ] )  )
-        add_tasks(f3)
-
-        f4 = s1.add_family("f4")
-        f4.add_repeat( RepeatString("enum",["a", "b", "c" ] )  )
-        add_tasks(f4)
-
-        f5 = s1.add_family("f5")
-        f5.add_repeat( RepeatDay(1)  )
-        add_tasks(f5)
-
-        f6 = s1.add_family("f6")
-        f6.add_repeat(RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00"))
-        add_tasks(f6)
-          
-        self.defs = defs
-     
-
-    def test_alternative0(self):
-        defs = Defs( 
-                Suite("s1",
-                    Family("f1",
-                       RepeatDate("YMD",20100111,20100115,2),
-                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f2",
-                       RepeatInteger("count",0,100,2),
-                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f3",
-                       RepeatEnumerated("enum",["red", "green", "blue" ] ),
-                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f4",
-                        RepeatString("enum",["a", "b", "c" ] ),
-                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f5",
-                        RepeatDay(1),
-                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f6",
-                        RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00"),
-                        [ Task("t{0}".format(i)) for i in range(1,3) ] )))
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-    def test_alternative1(self):
-        defs = Defs().add(
-                Suite("s1").add(
-                    Family("f1").add(
-                       RepeatDate("YMD",20100111,20100115,2),
-                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f2").add(
-                       RepeatInteger("count",0,100,2),
-                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f3").add(
-                       RepeatEnumerated("enum",["red", "green", "blue" ] ),
-                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f4").add(
-                        RepeatString("enum",["a", "b", "c" ] ),
-                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f5").add(
-                        RepeatDay(1),
-                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
-                    Family("f6").add(
-                        RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00"),
-                        [ Task("t{0}".format(i)) for i in range(1,3) ] )))
-
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
- 
-    def test_alternative2(self):
-        defs = Defs() + Suite("s1") 
-        defs.s1 += [ Family("f{0}".format(i)).add(
-                      [ Task("t{0}".format(i)) for i in range(1,3) ]) 
-                    for i in range(1,7) ]
-        defs.s1.f1 += RepeatDate("YMD",20100111,20100115,2)
-        defs.s1.f2 += RepeatInteger("count",0,100,2) 
-        defs.s1.f3 += RepeatEnumerated("enum",["red", "green", "blue" ] ) 
-        defs.s1.f4 += RepeatString("enum",["a", "b", "c" ] ) 
-        defs.s1.f5 += RepeatDay(1)
-        defs.s1.f6 += RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00")
-  
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-        
-        
-class TestAddLate(unittest.TestCase):
-    def setUp(self):
-        defs = Defs()
-        suite = defs.add_suite('s1')
-        
-        late = Late()
-        late.submitted( 20,10 )         # hour, min
-        late.active( 2, 10 )            # hour, min
-        late.complete( 3, 10, True)     # hour, min, relative
-        suite.add_task('t1').add_late(late)
-        self.defs = defs
- 
-    def test_1(self):
-        
-        # Can also pass late into the Task constructor
-        defs = Defs(
-                Suite('s1',
-                    Task('t1',
-                        Late(submitted='20:10',active='02:10',complete='+03:10'))))
-     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")   
-        
-    def test_2(self):
-        
-        # Can also pass late into the Task constructor
-        defs = Defs() + (Suite('s1') + Task('t1'))
-        defs.s1.t1 += Late(submitted='20:10',active='02:10',complete='+03:10')
-     
-        Ecf.set_debug_equality(True)
-        equals = (self.defs == defs)
-        Ecf.set_debug_equality(False)      
-        self.assertEqual(defs, self.defs, "expected defs to be the same")   
-        
-        
-class Deadlock(unittest.TestCase):
-    def setUp(self):
-        defs = Defs().add(
-        Suite("dead_lock").add(
-            Family("family").add(
-               Task("t1").add( Trigger("t2 == complete")),
-               Task("t2").add( Trigger("t1 == complete")))))
-        
-        self.defs = defs
-        
-    def test_me(self):
-        defs = Defs(
-            Suite("dead_lock",
-                Family('family',
-                    Task('t1', 
-                        Trigger("t2 == complete")),
-                    Task('t2', 
-                        Trigger("t1 == complete")))))
-        
-        self.assertEqual(defs, self.defs, "expected defs to be the same")
-       
-        
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_replace_node.py 5.13.0-1/Pyext/test/py_u_test_replace_node.py
--- 5.12.4-1/Pyext/test/py_u_test_replace_node.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_replace_node.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# SCRATCH test for ecflow python api
-
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import unittest 
-import sys
-import os
-import ecflow_test_util as Test
-
-class Test_replace(unittest.TestCase):
-
-    def test_replace_on_server_errors(self):
-        # expect error since nodes not attached to a definition
-        # The error should happen before we connect to the server,hence no need to start server
-        # Avoid suspending node first( since that will require node exist in the server)
-        node_vec = [ Suite('s1'), Family('f1'), Task('t1') ]
-        for node in node_vec:
-            print(node.name(), " +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
-            try: 
-                node.replace_on_server("locahost:3141",suspend_node_first=False)
-                self.assertFalse(False, "Expected failure since client definition is empty")
-            except RuntimeError as e:
-                self.assertTrue("client definition is empty" in str(e), "expected 'client definition is empty' in exception message  but found:\n"+ str(e))
-
-        
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/test/py_u_test_tutorial.py 5.13.0-1/Pyext/test/py_u_test_tutorial.py
--- 5.12.4-1/Pyext/test/py_u_test_tutorial.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/test/py_u_test_tutorial.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,1565 +0,0 @@
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #10 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
-                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
-                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
-                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
-                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
-                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
-import ecflow_test_util as Test
-import unittest 
-import shutil   # used to remove directory tree
-import os,sys
-
-def test_def_file():
-    #return "test.def"
-    return "test_tutorial_def_" + str(os.getpid()) + ".def"
-    
-def test_compile(text):    
-    # replace test.def in the text with test_def_file() so that we have a unique file per process
-    text = text.replace('test.def',test_def_file())
-    
-    test_file = "py_u_test_tutorial_" + str(os.getpid()) + ".def"
-    file = open(test_file ,'w')
-    file.write(text)
-    file.close()
-    
-    # execfile(test_file) only work for python 2.7
-    with open(test_file) as f:
-        code = compile(f.read(), test_file, 'exec')
-        exec(code)  
-        
-    os.remove(test_file)  
-
-def do_tear_down():
-    Ecf.set_debug_equality(False)      
-    try: os.remove(test_def_file())
-    except: pass
-        
-######################################################################################################
-class TestNewSuite(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)   
-           
-        home = os.path.join(os.getenv("HOME"),"course")
-        self.defs = Defs()
-        suite = self.defs.add_suite("test")
-        suite.add_variable("ECF_HOME", home)
-        suite.add_task("t1")
-         
-        with Defs() as self.defs2: 
-            with self.defs2.add_suite("test") as suite:
-                suite.add_variable("ECF_HOME", home)
-                suite.add_task("t1") 
-         
-        with Defs() as self.defs3:  
-            self.defs3.add(
-                Suite("test",
-                    Edit(ECF_HOME=home),
-                    Task("t1")))
-             
-        self.defs4 = Defs() + (Suite("test") + Edit(ECF_HOME=home))
-        self.defs4.test += Task("t1")
-        
-        self.defs5 = Defs().add(
-                Suite("test").add(
-                    Edit(ECF_HOME=home),
-                    Task("t1")))
-        
-        #print("Creating suite definition")   
-        home = os.path.join(os.getenv("HOME"),"course")
-        defs = Defs( 
-                        Suite('test',
-                            Task('t1'),
-                            ECF_HOME=home))
-        self.assertEqual(self.defs,defs,"defs not equal\n" + str(self.defs) + "\n" + str(defs))
-
-        text = """import os
-from ecflow import Defs,Suite,Task,Edit
-   
-#xx print("Creating suite definition")
-home = os.path.join(os.getenv("HOME"),  "course")
-defs = Defs( 
-        Suite('test',
-            Edit(ECF_HOME=home),
-            Task('t1')))
-#xx print(defs)
-
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,defs,"defs not equal\n" + str(test_defs) + "\n" + str(defs))
-        
-    def test_defs_equal(self):
-        self.assertEqual(self.defs, self.defs2, "defs not the equal")
-        self.assertEqual(self.defs, self.defs3, "defs not the equal")
-        self.assertEqual(self.defs, self.defs4, "defs not the equal")
-        self.assertEqual(self.defs, self.defs5, "defs not the equal")
-
-    def tearDown(self):
-        do_tear_down()
-
-######################################################################################################
-class TestFamilies(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-         
-        home = os.path.join(os.getenv("HOME"),  "course") 
-        defs = Defs().add(
-            Suite("test").add(
-                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                Family("f1").add(
-                    Task("t1"),
-                    Task("t2"))))
-        defs.save_as_defs(test_def_file())
-         
-        self.defs = defs
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit
-         
-def create_family_f1():
-    return Family("f1",
-                Task("t1"),
-                Task("t2"))
-            
-#xx print("Creating suite definition") 
-home = os.path.join(os.getenv("HOME"),  "course") 
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f1()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-
-    def test_me(self):
-        import os
-         
-        #print("Creating suite definition")
-        home = os.path.join(os.getenv("HOME"),  "course") 
-        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
-        defs.test += Family("f1") + [ Task("t{0}".format(i)) for i in range(1,3) ]
-        defs.save_as_defs(test_def_file())
-
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))        
- 
-    def tearDown(self):
-        do_tear_down()
- 
-     
-class TestVariables(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-  
-        def create_family_f1():
-            return Family("f1" ).add(
-                Task("t1").add(Edit(SLEEP=20)),
-                Task("t2").add(Edit(SLEEP=20)))
-  
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs().add( Suite("test").add(
-                            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                            create_family_f1()))
-  
-        defs.save_as_defs(test_def_file())
- 
-        self.defs = defs
-        
-    def test_me0(self):
-        text = """#import os
-from ecflow import Defs,Suite,Family,Task,Edit
-
-def create_family_f1():
-    return Family("f1",
-                Task("t1",Edit(SLEEP=20)),
-                Task("t2",Edit(SLEEP=20)))
-  
-#xx print("Creating suite definition")
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs(
-        Suite("test", 
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f1()))         
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def') 
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me2(self):
-        import os
-        home = os.path.join(os.getenv("HOME"), "course")
-  
-        with Defs() as defs: 
-            defs += Suite("test").add(
-                      Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home)) 
-            defs.test += Family("f1").add(
-                                Task("t1").add(Edit(SLEEP= 20)),
-                                Task("t2").add(Edit(SLEEP= 20)))                          
-        defs.save_as_defs(test_def_file())
-         
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-
-    def test_me3(self):
-        import os
-        home = os.path.join(os.getenv("HOME"), "course")
-  
-        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home)) 
-        defs.test += Family("f1") + (Task("t1") + Edit(SLEEP=20)) + (Task("t2") + Edit(SLEEP=20))                     
-        defs.save_as_defs(test_def_file())
-         
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-
-    def tearDown(self):
-        do_tear_down()
-         
-class TestVariableInheritance(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-         
-        def create_family_f1():
-            return Family("f1").add(
-                Edit(SLEEP=20),
-                Task("t1"),
-                Task("t2"))
-             
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs().add(Suite("test").add(
-                            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                            create_family_f1() ))
-        defs.save_as_defs(test_def_file())
-   
-        self.defs = defs;
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit
-
-def create_family_f1():
-    return Family("f1",
-            Edit(SLEEP=20),
-                Task("t1"),
-                Task("t2"))
-             
-#xx print("Creating suite definition")
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs(
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f1()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me(self):
-        import os
-         
-        def create_family_f1():
-            return Family("f1") + Edit(SLEEP=20) + Task("t1") + Task("t2")
-             
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs() + (Suite("test") + create_family_f1()) 
-        defs.test += [ Edit(ECF_HOME=home) , Edit(ECF_INCLUDE=home) ]
-        defs.save_as_defs(test_def_file())
-        
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def tearDown(self):
-        do_tear_down()
-   
-         
-class TestTriggers(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-         
-        def create_family_f1():
-            return Family("f1").add(
-                Edit(SLEEP=20),
-                Task("t1"),
-                Task("t2").add(Trigger("t1 == complete")))
-             
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs().add(Suite("test").add(
-                            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                            create_family_f1()))
-        defs.save_as_defs(test_def_file())
-  
-        self.defs = defs;
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger
-
-def create_family_f1():
-    return Family("f1",
-                Edit(SLEEP=20),
-                Task("t1"),
-                Task("t2",Trigger("t1 == complete")))
-             
-#xx print("Creating suite definition")
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f1()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-errors = defs.check()
-assert len(errors) == 0,errors
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me(self):
-        import os
-         
-        home = os.path.join(os.getenv("HOME"), "course")
-        with Suite("test") as suite:
-            suite += [ Edit(ECF_HOME=home) , Edit(ECF_INCLUDE=home) ]
-            suite += Family("f1") + Edit(SLEEP=20) + Task("t1") + Task("t2")
-            suite.f1.t2 += Trigger(["t1"]) 
-             
-        defs = Defs().add( suite )
-        defs.save_as_defs(test_def_file())
-         
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def tearDown(self):
-        do_tear_down()
-         
-         
-class TestEvents(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
- 
-        def create_family_f1():
-            return Family("f1").add(
-                        Edit(SLEEP=20),
-                        Task("t1"),
-                        Task("t2").add(
-                            Trigger("t1 == complete"),
-                            Event("a"),
-                            Event("b")),
-                        Task("t3").add(Trigger("t2:a")),
-                        Task("t4").add(Trigger("t2:b")))
-             
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs().add(
-            Suite("test").add(
-                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                create_family_f1() ))
-        defs.save_as_defs(test_def_file()) 
-  
-        self.defs = defs;
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Event
-
-def create_family_f1():
-    return Family("f1",
-                Edit(SLEEP=20),
-                Task("t1"),
-                Task("t2",
-                    Trigger("t1 == complete"),
-                    Event("a"),
-                    Event("b")),
-                Task("t3",
-                    Trigger("t2:a")),
-                Task("t4",
-                    Trigger("t2:b")))
-             
-#xx print("Creating suite definition")
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f1()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-errors = defs.check()
-assert len(errors) == 0,errors
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me(self):
-        import os
- 
-        def create_family_f1():
-            f1 = Family("f1") + [ Edit(SLEEP=20),
-                    Task("t1"),
-                    Task("t2") + Trigger(["t1"]) + Event("a") + Event("b"),
-                    Task("t3") + Trigger("t2:a"),
-                    Task("t4") + Trigger("t2:b") ]
-            return f1
-         
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs() + Suite("test")
-        defs.test += [ Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home), create_family_f1()]
-        defs.save_as_defs(test_def_file())   
-         
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def tearDown(self):
-        do_tear_down()
-         
-         
-class TestComplete(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
- 
-        def create_family_f1():
-            return Family("f1").add(
-                Edit(SLEEP= 20),
-                Task("t1"),
-                Task("t2").add(Trigger("t1 == complete"),
-                               Event("a"), Event("b")),
-                Task("t3").add(Trigger("t2:a")),
-                Task("t4").add(Trigger("t2 == complete"), 
-                               Complete("t2:b")  ))
-        
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs().add(Suite("test").add(
-                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                create_family_f1() ))
-        defs.save_as_defs(test_def_file())   
- 
-        self.defs = defs;
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event
-
-def create_family_f1():
-    return Family("f1",
-                Edit(SLEEP= 20),
-                Task("t1"),
-                Task("t2",
-                    Trigger("t1 == complete"),
-                    Event("a"), 
-                    Event("b")),
-                Task("t3",
-                    Trigger("t2:a")),
-                Task("t4",
-                    Trigger("t2 == complete"), 
-                    Complete("t2:b")))
-        
-#xx print("Creating suite definition")  
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f1()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-errors = defs.check()
-assert len(errors) == 0,errors
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me(self):
-        import os
- 
-        def create_family_f1():
-            f1 = Family("f1") + Edit(SLEEP=20) 
-            f1 += [ Task("t{0}".format(i)) for i in range(1,5) ]
-            f1.t2 += [ Trigger(["t1"]), Event("a"), Event("b") ]
-            f1.t3 += Trigger("t2:a") 
-            f1.t4 += [ Trigger(["t2"]),Complete("t2:b") ]
-            return f1
-        
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
-        defs.test += create_family_f1()      
-        defs.save_as_defs(test_def_file())   
-         
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def tearDown(self):
-        do_tear_down()
-
-         
-class TestMeter(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
- 
-        def create_family_f1():
-            return Family("f1").add(
-                        Edit(SLEEP= 20),
-                        Task("t1").add(Meter("progress", 1, 100, 90)),
-                        Task("t2").add(Trigger("t1 == complete"),
-                                       Event("a"),
-                                       Event("b")),
-                        Task("t3").add(Trigger("t2:a")),
-                        Task("t4").add(Trigger("t2 == complete"),
-                                       Complete("t2:b")),
-                        Task("t5").add(Trigger("t1:progress ge 30")),
-                        Task("t6").add(Trigger("t1:progress ge 60")),
-                        Task("t7").add(Trigger("t1:progress ge 90")))  
-        
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs().add(Suite("test").add(
-                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                create_family_f1() ))
-        defs.save_as_defs(test_def_file())   
- 
-        self.defs = defs;
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter
-
-def create_family_f1():
-    return Family("f1",
-                Edit(SLEEP= 20),
-                Task("t1", Meter("progress", 1, 100, 90)),
-                Task("t2", Trigger("t1 == complete"), Event("a"), Event("b")),
-                Task("t3", Trigger("t2:a")),
-                Task("t4", Trigger("t2 == complete"), Complete("t2:b")),
-                Task("t5", Trigger("t1:progress ge 30")),
-                Task("t6", Trigger("t1:progress ge 60")),
-                Task("t7", Trigger("t1:progress ge 90")))  
-        
-#xx print("Creating suite definition")  
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f1()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-errors = defs.check()
-assert len(errors) == 0,errors
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me(self):
-        import os
- 
-        def create_family_f1():
-            f1 = Family("f1") + Edit(SLEEP=20) 
-            f1 += [ Task("t{0}".format(i)) for i in range(1,8)]
-            f1.t1 += Meter("progress", 1, 100, 90) 
-            f1.t2 += [ Trigger(["t1"]), Event("a"), Event("b") ]
-            f1.t3 += Trigger("t2:a")
-            f1.t4 += [ Trigger(["t2"]),Complete("t2:b") ]
-            f1.t5 += Trigger("t1:progress ge 30")  
-            f1.t6 += Trigger("t1:progress ge 60")  
-            f1.t7 += Trigger("t1:progress ge 90")  
-            return f1
-        
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
-        defs.test += create_family_f1()   
-        defs.save_as_defs(test_def_file())   
-         
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def tearDown(self):
-        do_tear_down()
-         
-         
-class TestTime(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-
-        def create_family_f2():
-            f2 = Family("f2")
-            f2.add_variable("SLEEP", 20)
-            f2.add_task("t1").add_time( "00:30 23:30 00:30" ) # start(hh:mm) end(hh:mm) increment(hh:mm)
-            f2.add_task("t2").add_day( "sunday" )
-   
-            # for add_date(): day,month,year; here 0 means every month, and every year
-            t3 = f2.add_task("t3")
-            t3.add_date(1, 0, 0)           # day month year, first of every month or every year
-            t3.add_time( 12, 0 )           # hour, minutes at 12 o'clock
-   
-            f2.add_task("t4").add_time( 0, 2, True ) # hour, minutes, relative to suite start
-                                                     # 2 minutes after family f2 start
-            f2.add_task("t5").add_time( 0, 2 )       # hour, minutes suite site
-                                                     # 2 minutes past midnight
-            return f2
-            
-        defs = Defs()
-        suite = defs.add_suite("test")
-        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
-        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
-
-        #suite.add_family( create_family_f1() )
-        suite.add_family( create_family_f2() )
-        errors = defs.check()
-        assert len(errors) == 0,errors
-
-        defs.save_as_defs(test_def_file())  
- 
-        self.defs = defs;
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date
-
-def create_family_f2():
-    return Family("f2",
-            Edit(SLEEP=20),
-            Task("t1", Time("00:30 23:30 00:30")),     # start(hh:mm) end(hh:mm) increment(hh:mm)
-            Task("t2", Day("sunday")),
-            Task("t3", Date("1.*.*"), Time("12:00")),  # Date(day,month,year) - * means every day,month,year
-            Task("t4", Time("+00:02")),                # + means realative to suite begin/requeue time
-            Task("t5", Time("00:02")))                 # 2 minutes past midnight
- 
-#xx print("Creating suite definition")  
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            #create_family_f1(),
-            create_family_f2()
-            ))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-errors = defs.check()
-assert len(errors) == 0,errors
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me(self):
-        import os
-  
-        def create_family_f2():
-            f1 = Family("f2") + Edit(SLEEP=20)
-            f1 += [ Task("t{0}".format(i)) for i in range(1,6) ]
-            f1.t1 += Time("00:30 23:30 00:30")  # start(hh:mm) end(hh:mm) increment(hh:mm)
-            f1.t2 += Day( "sunday" ) 
-            f1.t3 += [ Date("1.*.*"),    
-                       Time("12:00")]   
-            f1.t4 += Time("+00:02")  
-            f1.t5 += Time("00:02")    
-            return f1
-  
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs() + ( Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
-        defs.test += create_family_f2()    
-        defs.save_as_defs(test_def_file())   
-          
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def test_add(self):
-        import os
-  
-        def create_family_f2():
-            return Family("f2").add(
-                Edit(SLEEP=20),
-                Task("t1").add( Time("00:30 23:30 00:30")),  
-                Task("t2").add( Day( "sunday" )),
-                Task("t3").add( Date("1.*.*"),   
-                                Time("12:00")),  
-                Task("t4").add( Time("+00:02")), 
-                Task("t5").add( Time("00:02")))  
-  
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs().add(Suite("test").add(
-                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-                create_family_f2()))
-        defs.save_as_defs(test_def_file())   
- 
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-        
-    def tearDown(self):
-        do_tear_down()
-     
-         
-class TestCron(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-
-        def create_family_house_keeping():
-            cron = Cron()
-            cron.set_week_days( [0] )
-            cron.set_time_series( "22:30" )
-            f2 = Family("house_keeping")
-            f2.add_task("clear_log").add_cron(cron)  
-            return f2
-            
-        defs = Defs()
-        suite = defs.add_suite("test")
-        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
-        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
-
-        #suite.add_family( create_family_f1() )
-        suite.add_family( create_family_house_keeping() )
-        errors = defs.check()
-        assert len(errors) == 0,errors
-
-        defs.save_as_defs(test_def_file())  
- 
-        self.defs = defs;
-         
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Cron
-  
-def create_family_house_keeping():
-    return Family("house_keeping",
-                Task("clear_log",
-                    Cron("22:30",days_of_week=[0])))
-          
-print("Creating suite definition") 
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs(
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_house_keeping()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-errors = defs.check()
-assert len(errors) == 0,errors
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def tearDown(self):
-        do_tear_down()
-     
-class TestIndentation(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-
-        #version = sys.version_info 
-        #if version[1] < 7: 
-        #    #print "This example requires python version 2.7, but found : " + str(version)
-        #    exit(0)
-
-        with Defs() as defs: 
-    
-            with defs.add_suite("test") as suite:
-        
-                suite += Edit(ECF_HOME=os.path.join(os.getenv("HOME"),  "course"))
-                suite += Edit(ECF_INCLUDE =os.path.join(os.getenv("HOME"),  "course"))
-        
-            with suite.add_family("f1") as f1:
-                f1 += Edit(SLEEP=20)
-                f1 += Task("t1", Meter("progress", 1, 100, 90))
-                f1 += Task("t2", Trigger("t1 == complete"), Event("a"), Event("b"))
-                f1 += Task("t3", Trigger("t2:a"))
-                f1 += Task("t4", Trigger("t2 == complete"), Complete("t2:b"))
-                f1 += Task("t5", Trigger("t1:progress ge 30"))
-                f1 += Task("t6", Trigger("t1:progress ge 60"))
-                f1 += Task("t7", Trigger("t1:progress ge 90"))
-    
-            with suite.add_family("f2") as f2:        
-                f2 += Edit(SLEEP=20)
-                f2 += Task("t1", Time("00:30 23:30 00:30"))
-                f2 += Task("t2", Day("sunday"))
-                f2 += Task("t3", Date(1, 0, 0), Time(12, 0))
-                f2 += Task("t4", Time(0, 2, True))
-                f2 += Task("t5", Time(0, 2))
-            
-        defs.save_as_defs(test_def_file())
-        self.defs = defs;
-
-    def test_preferred(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date
-
-#xx print("Creating suite definition") 
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            Family("f1",
-                Edit(SLEEP=20),
-                Task("t1", Meter("progress", 1, 100, 90)),
-                Task("t2", Trigger("t1 == complete"),Event("a"),Event("b")),
-                Task("t3", Trigger("t2:a")),
-                Task("t4", Trigger("t2 == complete"), Complete("t2:b")),
-                Task("t5", Trigger("t1:progress ge 30")),
-                Task("t6", Trigger("t1:progress ge 60")),
-                Task("t7", Trigger("t1:progress ge 90"))),
-            Family("f2",
-                Edit(SLEEP=20),
-                Task("t1", Time( "00:30 23:30 00:30" )),
-                Task("t2", Day( "sunday" )),
-                Task("t3", Date("1.*.*"), Time("12:00")),
-                Task("t4", Time("+00:02")),
-                Task("t5", Time("00:02")))))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-assert len(defs.check()) == 0, defs.check()
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def test_me(self):
-        import os
-  
-        home = os.path.join(os.getenv("HOME"), "course")
-        with Defs() as defs:
-            with defs.add_suite("test") as suite:
-                suite += [ Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home) ]
-                with suite.add_family("f1") as f1:
-                    f1 += [ Task("t{0}".format(i)) for i in range(1,8)]
-                    f1 += Edit(SLEEP=20) 
-                    f1.t1 += Meter("progress", 1, 100, 90) 
-                    f1.t2 += [ Trigger(["t1"]), Event("a"), Event("b") ]
-                    f1.t3 += Trigger("t2:a") 
-                    f1.t4 += [ Trigger(["t2"]), Complete("t2:b") ]
-                    f1.t5 += Trigger("t1:progress ge 30") 
-                    f1.t6 += Trigger("t1:progress ge 60") 
-                    f1.t7 += Trigger("t1:progress ge 90") 
-                with suite.add_family("f2") as f2:
-                    f2 += [ Edit(SLEEP=20),[ Task("t{0}".format(i)) for i in range(1,6)] ]
-                    f2.t1 += Time( "00:30 23:30 00:30" )
-                    f2.t2 += Day( "sunday" ) 
-                    f2.t3 += [ Date("1.*.*"), Time("12:00") ]
-                    f2.t4 += Time("+00:02") 
-                    f2.t5 += Time("00:02") 
-          
-        defs.save_as_defs(test_def_file())   
-          
-        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def tearDown(self):
-        do_tear_down()
-        
-         
-class TestLabel(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-
-        def create_family_f3():
-            fam = Family('f3')
-            fam.add_task('t1').add_label("info","")
-            return fam
-            
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs()
-        suite = defs.add_suite("test")
-        suite.add_variable("ECF_HOME",    home)
-        suite.add_variable("ECF_INCLUDE", home)
-
-        suite.add_family( create_family_f3() )
-        errors = defs.check()
-        assert len(errors) == 0,errors
-
-        defs.save_as_defs(test_def_file())  
- 
-        self.defs = defs;
-        
-    def test_me(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label
-
-def create_family_f3():
-    return Family("f3",
-                Task("t1",
-                Label("info","")))
- 
-#xx print("Creating suite definition")  
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f3()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-assert len(defs.check()) == 0, defs.check()
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-        
-    def tearDown(self):
-        do_tear_down()
-         
-         
-class TestRepeat(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-        
-        self.ecf_home     = File.build_dir() + "/Pyext/test/data/course_py" + str(sys.version_info[0]) + "_" + str(os.getpid()) # allow paralled runs
-        self.ecf_includes = File.source_dir() + "/Pyext/test/data/includes"
-        #print("self.ecf_home ",self.ecf_home )
- 
-        try:    os.makedirs( self.ecf_home + "/test/f4/f5")
-        except: pass
-         
-        t1_ecf = '%include <head.h>\n'
-        t1_ecf += 'ecflow_client --label=info "My name is %NAME% My value is %VALUE% My date is %DATE%\n'
-        t1_ecf += 'ecflow_client --label=date "year:%DATE_YYYY% month:%DATE_MM% day of month:%DATE_DD% day of week:%DATE_DOW%"\n'
-        t1_ecf += 'sleep %SLEEP%\n'
-        t1_ecf += '%include <tail.h>\n'
-         
-        self.t1_ecf_path = self.ecf_home + "/test/f4/f5/t1.ecf"
-        #print("self.t1_ecf_path",self.t1_ecf_path)
-        file = open(self.t1_ecf_path ,"w") 
-        file.write(t1_ecf)
-        file.close()
-    
-    def tearDown(self):
-        unittest.TestCase.tearDown(self)
-        do_tear_down()
-        os.remove(self.t1_ecf_path)
-        shutil.rmtree(self.ecf_home, ignore_errors=True)  
-     
-    def test_repeat0(self):
-    
-        def create_family_f4():
-            return Family("f4",
-                        Edit(SLEEP=2), 
-                        RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
-                        Family("f5",
-                            RepeatInteger("VALUE", 1, 10),
-                            Task("t1",
-                                RepeatDate("DATE", 20101230, 20110105),
-                                Label("info", ""),
-                                Label("date",""))))
-              
-        defs = Defs( 
-                Suite("test",
-                    Edit(ECF_HOME=self.ecf_home, ECF_INCLUDE=self.ecf_includes ),
-                    create_family_f4()))
-        #print(defs)
- 
-        result = defs.check_job_creation()
-        self.assertEqual(result, "", "expected job creation to succeed " + result)
- 
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
-                   RepeatString,RepeatInteger,RepeatDate
-        
-def create_family_f4():
-    return Family("f4",
-                Edit(SLEEP=2), 
-                RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
-                Family("f5",
-                    RepeatInteger("VALUE", 1, 10),
-                    Task("t1",
-                        RepeatDate("DATE", 20101230, 20110105),
-                        Label("info",""),
-                        Label("date",""))))
- 
-#xx print("Creating suite definition")  
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f4()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-assert len(defs.check()) == 0,defs.check() 
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-
-    def test_repeat(self):
-     
-        #print("Creating suite definition") 
-        defs = Defs(
-                Suite("test",
-                    Edit(ECF_HOME=self.ecf_home,ECF_INCLUDE=self.ecf_includes),
-                    Family("f4",
-                        Edit(SLEEP=2), 
-                        RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
-                        Family("f5",
-                            RepeatInteger("VALUE", 1, 10),
-                            Task("t1",
-                                RepeatDate("DATE", 20101230, 20110105),
-                                Label("info", ""),
-                                Label("date",""))))))
-        #print(defs)
- 
-        result = defs.check_job_creation()
-        self.assertEqual(result, "", "expected job creation to succeed " + result)
- 
-        defs.save_as_defs(test_def_file())
-
-    def test_repeat3(self):
-     
-        defs = Defs().add( Suite("test") )
-        defs.test += [ { "ECF_INCLUDE":self.ecf_includes, "ECF_HOME":self.ecf_home }, 
-                        Family("f4") ]
-        defs.test.f4 += [   Edit(SLEEP=2),
-                            RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
-                            Family("f5") ]
-        defs.test.f4.f5 += [ RepeatInteger("VALUE", 1, 10),
-                            Task("t1")]
-        defs.test.f4.f5.t1 += [ RepeatDate("DATE", 20101230, 20110105),
-                                Label("info", ""),
-                                Label("date","") ]
-        #print(defs)
-        result = defs.check_job_creation()
-        self.assertEqual(result, "", "expected job creation to succeed " + result)
- 
-        defs.save_as_defs(test_def_file())
-
-        
-class TestLimit(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-
-        def create_family_f5() :
-            f5 = Family("f5")
-            f5.add_inlimit("l1")
-            f5.add_variable("SLEEP", 20)
-            for i in range(1, 10):
-                f5.add_task( "t" + str(i) )
-            return f5
-          
-        defs = Defs()
-        suite = defs.add_suite("test")
-        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
-        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
-
-        suite.add_limit("l1", 2)
-        suite.add_family( create_family_f5() )
-        
-        defs.save_as_defs(test_def_file())
-        
-        self.defs = defs   
-        
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
-                   RepeatString,RepeatInteger,RepeatDate,InLimit,Limit
-         
-def create_family_f5() :
-    return Family("f5",
-            InLimit("l1"),
-            Edit(SLEEP=20),
-            [ Task('t{0}'.format(i)) for i in range(1,10) ] )
-     
-#xx print("Creating suite definition")  
-home = os.path.join(os.getenv("HOME"),"course")
-defs = Defs(
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            Limit("l1",2),
-            create_family_f5()))
-#xx print(defs)
- 
-#xx print("Checking job creation: .ecf -> .job0") 
-#print(defs.check_job_creation())
- 
-#xx print("Checking trigger expressions")
-assert len(defs.check()) == 0,defs.check()
- 
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs(test_def_file()) 
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-
-    def tearDown(self):
-        do_tear_down()
-
-
-class TestLateAttribute(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
- 
-        def create_family_f6() :
-            f6 = Family("f6")
-            f6.add_variable("SLEEP", 120)
-            t1 = f6.add_task("t1")
-            late = Late()
-            late.complete(0,1,True)  # hour,minute,relative,    set late flag if task take longer than a minute
-            t1.add_late(late) 
-            return f6
-       
-        defs = Defs()
-        suite = defs.add_suite("test")
-        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
-        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
-        suite.add_family( create_family_f6() )
-        #print(defs)
-
-        assert len(defs.check()) == 0, defs.check()
-
-        defs.save_as_defs(test_def_file())
-        
-        self.defs = defs
-        
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
-                   RepeatString,RepeatInteger,RepeatDate,InLimit,Limit,Late
-        
-def create_family_f6():
-    # set late flag if task t1 takes longer than a minute
-    return Family("f6",
-                Edit(SLEEP=120),
-                Task("t1",
-                    Late(complete='+00:01')))
-     
-#xx print("Creating suite definition")   
-home = os.path.join(os.getenv("HOME"),"course")
-defs = Defs( 
-        Suite("test",
-            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
-            create_family_f6()))
-#xx print(defs) 
-
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-assert len(defs.check()) == 0,defs.check() 
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-
-    def tearDown(self):
-        do_tear_down()
-    
-
-class TestPythonScripting(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)
-        
-        def create_suite(name) : 
-            suite = Suite(name)
-            for i in range(1, 7) :
-                fam = suite.add_family("f" + str(i))
-                for t in ( "a", "b", "c", "d", "e" ) :
-                    fam.add_task(t)
-            return suite 
-    
-        self.defs = Defs(create_suite('s1'))   
-        
-    def test_me(self):
-        def create_suite(name) : 
-            return Suite(name,
-                    [ Family("f{0}".format(i),
-                        [ Task(t) for t in ( "a", "b", "c", "d", "e") ]) 
-                    for i in range(1,7) ])
-     
-        defs = Defs(create_suite('s1'))   
-
-        self.assertEqual(self.defs,defs,"defs not equal\n" + str(self.defs) + "\n" + str(defs))       
-  
-    def tearDown(self):
-        Ecf.set_debug_equality(False)      
-       
-
-class TestPythonScripting2(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)
-              
-        def create_sequential_suite(name) :
-            suite = Suite(name)
-            for i in range(1, 7) :
-                fam = suite.add_family("f" + str(i))
-                if i != 1: 
-                    fam.add_trigger("f" + str(i-1) + " == complete")  # or fam.add_family( "f%d == complete" % (i-1) )
-                for t in ( "a", "b", "c", "d", "e" ) :
-                    fam.add_task(t) 
-            return suite
-    
-        self.defs = Defs(create_sequential_suite('s1'))   
-        
-    def test_me(self):
-        def create_sequential_suite(name) :
-            suite = Suite(name)
-            for i in range(1, 7) :
-                fam = suite.add_family("f" + str(i))
-                if i != 1: 
-                    fam += Trigger("f" + str(i-1) + " == complete")  # or fam.add_family( "f%d == complete" % (i-1) )
-                for t in ( "a", "b", "c", "d", "e" ) :
-                    fam.add_task(t) 
-            return suite  
-     
-        defs = Defs(create_sequential_suite ('s1'))   
-
-        self.assertEqual(self.defs,defs,"defs not equal\n" + str(self.defs) + "\n" + str(defs))       
-         
-    def tearDown(self):
-        Ecf.set_debug_equality(False)      
-
-
-class TestDataAquistionSolution(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-        
-        defs = Defs()
-        suite = defs.add_suite("data_aquisition")
-        suite.add_repeat( RepeatDay(1) )
-        suite.add_variable("ECF_HOME",    os.getenv("HOME") + "/course")
-        suite.add_variable("ECF_INCLUDE", os.getenv("HOME") + "/course")
-        suite.add_variable("ECF_FILES",   os.getenv("HOME") + "/course/data")
-        suite.add_variable("SLEEP","2")
-        for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) :
-            fcity = suite.add_family(city)
-            fcity.add_task("archive")
-            for obs_type in ( "observations", "fields", "images" ):
-                type_fam = fcity.add_family(obs_type)
-                if city in ("Exeter", "Toulouse", "Offenbach"): type_fam.add_time("00:00 23:00 01:00")
-                if city in ("Washington") :                     type_fam.add_time("00:00 23:00 03:00")
-                if city in ("Tokyo") :                          type_fam.add_time("12:00")
-                if city in ("Melbourne") :                      type_fam.add_day( "monday" )
-                if city in ("Montreal") :                       type_fam.add_date(1, 0, 0)
-         
-                type_fam.add_task("get")
-                type_fam.add_task("process").add_trigger("get eq complete")
-                type_fam.add_task("store").add_trigger("get eq complete")
-                    
-        #print(defs)
-        self.defs = defs
-        
-    def test_me0(self):
-        text = """import os
-from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
-                   RepeatString,RepeatInteger,RepeatDate
-
-home = os.path.join(os.getenv("HOME"), "course")
-defs = Defs(
-        Suite("data_aquisition",
-            RepeatDay(1),
-            Edit(ECF_HOME=home),
-            Edit(ECF_INCLUDE=home),
-            Edit(ECF_FILES=home + "/data"),
-            Edit(SLEEP=2)))
-for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) :
-    fcity = defs.data_aquisition.add_family(city)
-    fcity += Task("archive")
-    for obs_type in ( "observations", "fields", "images" ):
-        type_fam = fcity.add_family(obs_type)
-        if city in ("Exeter", "Toulouse", "Offenbach"): type_fam + Time("00:00 23:00 01:00")
-        if city in ("Washington") :                     type_fam + Time("00:00 23:00 03:00")
-        if city in ("Tokyo") :                          type_fam + Time("12:00")
-        if city in ("Melbourne") :                      type_fam + Day( "monday" )
-        if city in ("Montreal") :                       type_fam + Date(1, 0, 0)
-         
-        type_fam + Task("get") + Task("process",Trigger("get eq complete")) + Task("store",Trigger("get eq complete"))         
- 
-#xx print("Checking job creation: .ecf -> .job0")  
-#print(defs.check_job_creation())
-
-#xx print("Checking trigger expressions")
-assert len(defs.check()) == 0, defs.check()
-
-#xx print("Saving definition to file 'test.def'")
-defs.save_as_defs('test.def')
-"""
-        test_compile(text)
-        test_defs = Defs(test_def_file())
-        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
-
-    def test_me(self):
-        import os
-        
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs() + Suite("data_aquisition").add(
-                            RepeatDay(1),
-                            Edit(ECF_HOME=home),
-                            Edit(ECF_INCLUDE=home),
-                            Edit(ECF_FILES=home + "/data"),
-                            Edit(SLEEP=2))
-        for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) :
-            fcity = defs.data_aquisition.add_family(city)
-            fcity += Task("archive")
-            for obs_type in ( "observations", "fields", "images" ):
-                type_fam = fcity.add_family(obs_type)
-                if city in ("Exeter", "Toulouse", "Offenbach"): type_fam + Time("00:00 23:00 01:00")
-                if city in ("Washington") :                     type_fam + Time("00:00 23:00 03:00")
-                if city in ("Tokyo") :                          type_fam + Time("12:00")
-                if city in ("Melbourne") :                      type_fam + Day( "monday" )
-                if city in ("Montreal") :                       type_fam + Date(1, 0, 0)
-         
-                type_fam += [ Task("get"),Task("process"),Task("store") ]
-                type_fam.process += Trigger("get eq complete") 
-                type_fam.store += Trigger("get eq complete")     
-
-        self.assertEqual(self.defs, defs, "defs not equal")
-
-    def tearDown(self):
-        Ecf.set_debug_equality(False)      
-
-
-class TestOperationalSolution(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-   
-        defs = Defs()
-        suite = defs.add_suite("operation_suite")
-        suite.add_repeat( RepeatDay(1) )
-        suite.add_variable("ECF_HOME",    os.getenv("HOME") + "/course")
-        suite.add_variable("ECF_INCLUDE", os.getenv("HOME") + "/course")
-        suite.add_variable("ECF_FILES",   os.getenv("HOME") + "/course/oper")
-  
-        # Defines the triggers for the first cycle
-        cycle_triggers = "1"
-        for cycle in ( "00" , "12" ):
-
-            if cycle == "12" :
-                last_step = 240
-            else:
-                last_step = 24
- 
-            fcycle_fam = suite.add_family(cycle)
-            fcycle_fam.add_variable("CYCLE", cycle)
-            fcycle_fam.add_variable("LAST_STEP", last_step)
-      
-            if cycle_triggers != "1" :
-                fcycle_fam.add_trigger(cycle_triggers)
-                 
-            analysis_fam = fcycle_fam.add_family("analysis")
-            analysis_fam.add_task("get_observations")
-            analysis_fam.add_task("run_analysis").add_trigger("get_observations == complete")
-            analysis_fam.add_task("post_processing").add_trigger("run_analysis == complete")
- 
-            forecast_fam = fcycle_fam.add_family("forecast")
-            forecast_fam.add_trigger("analysis == complete")
-            forecast_fam.add_task("get_input_data") 
-            run_forecast_task = forecast_fam.add_task("run_forecast") 
-            run_forecast_task.add_trigger("get_input_data == complete")
-            run_forecast_task.add_meter("step", 0, last_step, last_step)
- 
-            archive_fam = fcycle_fam.add_family("archive")
-            fam_analsis = archive_fam.add_family("analysis")
-            fam_analsis.add_variable("TYPE","analysis")
-            fam_analsis.add_variable("STEP","0")
-            fam_analsis.add_trigger("../analysis/run_analysis == complete")
-            fam_analsis.add_task("save")
-    
-            for i in range(6, last_step+1, 6):  
-                step_fam = fam_analsis.add_family("step_" + str(i))     
-                step_fam.add_variable("TYPE", "forecast")  
-                step_fam.add_variable("STEP", i)  
-                step_fam.add_trigger("../../forecast/run_forecast:step ge " + str(i))
-                step_fam.add_task("save")
-
-            # Defines the triggers for the next cycle
-            cycle_triggers = "./" + cycle + " == complete"   
-                 
-        #print(defs)
-        self.defs = defs
-        
-    def test_sol1(self):
-        import os
-         
-        home = os.getenv("HOME") + "/course"
-        cycle_triggers = None
-        last_step = { "12": 240,
-                      "00": 24, }
-         
-        def cycle_trigger(cycle):
-            if cycle == "12": return Trigger("./00 == complete")
-            return None
-         
-        defs = Defs(
-            Suite("operation_suite",
-                RepeatDay(1),
-                Edit(ECF_HOME= home),
-                Edit(ECF_INCLUDE= home),
-                Edit(ECF_FILES= home + "/oper"),
-                [ Family(cycle,
-                    Edit(CYCLE=cycle),
-                    Edit(LAST_STEP=last_step[cycle]),
-        
-                    cycle_trigger(cycle),
-                    
-                    Family("analysis",
-                        Task("get_observations"),
-                        Task("run_analysis", Trigger(["get_observations"])),
-                        Task("post_processing", Trigger(["run_analysis"]))
-                    ),
-    
-                    Family("forecast",
-                        Trigger(["analysis"]),
-                        Task("get_input_data"),
-                        Task("run_forecast",
-                            Trigger(["get_input_data"]),
-                            Meter("step", 0, last_step[cycle])),
-                    ),
-                                           
-                    Family("archive",
-                        Family("analysis",
-                            Edit(TYPE="analysis"),
-                            Edit(STEP=0),
-                            Trigger("../analysis/run_analysis == complete"),
-                            Task("save"),
-                            [ Family("step_{0}".format(i),
-                                Edit(TYPE="forecast"),
-                                Edit(STEP=i),
-                                Trigger("../../forecast/run_forecast:step ge {0}".format(i)),
-                                Task("save"))
-                             for i in range(6, last_step[cycle]+1, 6) ]
-                        )
-                    )
-                ) for cycle in ( "00" , "12" ) ] 
-            )
-        )
-        #print(defs)
-        
-        self.assertEqual(self.defs, defs, "defs not equal")
-
-    def tearDown(self):
-        Ecf.set_debug_equality(False)      
-
-
-class TestBackArchivingSolution(unittest.TestCase):
-    def setUp(self):
-        Ecf.set_debug_equality(True)      
-    
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs()
-        suite = defs.add_suite("back_archiving")
-        suite.add_repeat( RepeatDay(1) )
-        suite.add_variable("ECF_HOME",    home)
-        suite.add_variable("ECF_INCLUDE", home)
-        suite.add_variable("ECF_FILES",   home + "/back")
-        suite.add_variable("SLEEP", "2")
-        suite.add_limit("access", 2)
-        for kind in ( "analysis", "forecast", "climatology", "observations", "images" ):
-            find_fam = suite.add_family(kind)
-            find_fam.add_repeat( RepeatDate("DATE", 19900101, 19950712) )
-            find_fam.add_variable("KIND", kind)
-            find_fam.add_task("get_old").add_inlimit("access")
-            find_fam.add_task("convert").add_trigger("get_old == complete")
-            find_fam.add_task("save_new").add_trigger("convert == complete")
-             
-        #print(defs)
-         
-        self.defs = defs
-         
-    def test_sol1(self):
-        import os
-        home = os.path.join(os.getenv("HOME"), "course")
-        defs = Defs( 
-            Suite("back_archiving",
-                RepeatDay(1),
-                Edit(ECF_HOME=home),
-                Edit(ECF_INCLUDE=home),
-                Edit(ECF_FILES= home + "/back"),
-                Edit(SLEEP=2),
-                Limit("access", 2),
-                [ Family(kind,
-                    RepeatDate( "DATE", 19900101, 19950712 ),
-                    Edit(KIND=kind),
-                    Task("get_old",  InLimit("access")),
-                    Task("convert",  Trigger("get_old == complete")),
-                    Task("save_new", Trigger("convert == complete")))
-                  for kind in ( "analysis", "forecast", "climatology", "observations", "images" ) ] ))
-        #print(defs)
-
-        self.assertEqual(self.defs, defs, "defs not equal")
-
-    def tearDown(self):
-        Ecf.set_debug_equality(False)      
-
-if __name__ == "__main__":
-    unittest.main()
-    print("All Tests pass")
diff -pruN 5.12.4-1/Pyext/unicode.py 5.13.0-1/Pyext/unicode.py
--- 5.12.4-1/Pyext/unicode.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Pyext/unicode.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-# Determine the python unicode
-
-import sys
-if sys.maxunicode > 65535:
-    print('UCS4 build')
-else:
-    print('UCS2 build')
diff -pruN 5.12.4-1/Server/CMakeLists.txt 5.13.0-1/Server/CMakeLists.txt
--- 5.12.4-1/Server/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,121 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-set(srcs
-  # Headers
-  src/ecflow/server/BaseServer.hpp
-  src/ecflow/server/CheckPtSaver.hpp
-  src/ecflow/server/NodeTreeTraverser.hpp
-  src/ecflow/server/Server.hpp
-  src/ecflow/server/ServerEnvironment.hpp
-  src/ecflow/server/ServerOptions.hpp
-  src/ecflow/server/SslServer.hpp
-  src/ecflow/server/SslTcpServer.hpp
-  src/ecflow/server/TcpBaseServer.hpp
-  src/ecflow/server/TcpServer.hpp
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/server/SslServer.hpp>
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/server/SslTcpServer.hpp>
-  # Sources
-  src/ecflow/server/BaseServer.cpp
-  src/ecflow/server/CheckPtSaver.cpp
-  src/ecflow/server/NodeTreeTraverser.cpp
-  src/ecflow/server/Server.cpp
-  src/ecflow/server/ServerEnvironment.cpp
-  src/ecflow/server/ServerOptions.cpp
-  src/ecflow/server/TcpBaseServer.cpp
-  src/ecflow/server/TcpServer.cpp
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/server/SslServer.cpp>
-  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/server/SslTcpServer.cpp>
-)
-
-ecbuild_add_library(
-  TARGET
-    libserver
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-  PUBLIC_LIBS
-    base
-    Boost::boost # Boost header-only libraries must be available (namely asio)
-)
-target_clangformat(libserver)
-
-# =======================================================
-# EXE ecflow_server, if OpenSSL not enabled ${OPENSSL_LIBRARIES}, is empty
-
-ecbuild_add_executable(
-  TARGET
-    ecflow_server
-  SOURCES
-    src/ecflow/server/ServerMain.cpp
-  LIBS
-    libserver
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    Threads::Threads
-)
-target_clangformat(ecflow_server)
-
-# Override default behaviour that add RPATHS during install
-# The only thing that seem to work is set INSTALL_RPATH to ""
-# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
-# had no effect
-#          
-SET_TARGET_PROPERTIES(ecflow_server
-  PROPERTIES
-    INSTALL_RPATH ""
-)
-
-# use, i.e. don't skip the full RPATH for the build tree
-#SET(CMAKE_SKIP_BUILD_RPATH  FALSE)
-
-# when building, don't use the install RPATH already
-# (but later on when installing)
-#SET(CMAKE_BUILD_WITH_INSTALL_RPATH FALSE) 
-
-# the RPATH to be used when installing
-#SET(CMAKE_INSTALL_RPATH "")
-
-# don't add the automatically determined parts of the RPATH
-# which point to directories outside the build tree to the install RPATH
-#SET(CMAKE_INSTALL_RPATH_USE_LINK_PATH FALSE)
-
-                          
-# ================================================================================                         
-# TEST
-ecbuild_add_test(
-  TARGET
-    u_server
-  LABELS
-    unit nightly
-  INCLUDES
-    src
-  SOURCES
-    test/TestCheckPtSaver.cpp
-    test/TestServerEnvironment.cpp
-    test/TestServer_main.cpp # test entry point
-    test/TestServer.cpp
-  LIBS
-    libserver
-    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    Threads::Threads
-  TEST_DEPENDS
-    u_base
-)
-
-target_clangformat(u_server CONDITION ENABLE_TESTS)
-
-# ===================================================================
-# install
-# ===================================================================
-install (TARGETS ecflow_server DESTINATION bin)
diff -pruN 5.12.4-1/Server/server_environment.cfg 5.13.0-1/Server/server_environment.cfg
--- 5.12.4-1/Server/server_environment.cfg	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/server_environment.cfg	1970-01-01 00:00:00.000000000 +0000
@@ -1,185 +0,0 @@
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-#
-# This file is used to define the standard defaults for ECF.
-# Most are *variables* used in the server
-# Some like ECF_TASK_THRESHOLD are used to debug job generation
- 
-# ******************************************************************
-# Warning: Do *NOT* use quotes around the value part.
-#   WRONG: ECF_MICRODEF = "%"
-#   RIGHT: ECF_MICRODEF = %
-# ******************************************************************
-
-#  *******************************************************************
-#  * ECF_HOME is typically the home/root for all '.ecf' files
-#  * Can be overridden with a environment variable of the same name
-#  *******************************************************************
-ECF_HOME  = .
-
-
-#  ******************************************************************
-#  * The name of check point file. i.e defs file with state
-#  * Can be overridden with a environment variable of the same name
-#  * default: is <host>.<port>.ecf.check
-#  * Note: Any settings will be prepended with <host>.<port>.
-#  ******************************************************************
-ECF_CHECK = ecf.check
-
-
-#  ******************************************************************
-#  * The name of the backup checkpoint file
-#  * Can be overridden with a environment variable of the same name
-#  * default: is <host>.<port>.ecf.check.b
-#  * Note: Any settings will be prepended with <host>.<port>.
-#  ******************************************************************
-ECF_CHECKOLD = ecf.check.b
-
-
-#  ******************************************************************
-#  * The intervals within the server that the checkpoint file should 
-#  * be saved.
-#  * Can be overridden with a environment variable of the same name
-#  ******************************************************************
-ECF_CHECKINTERVAL = 120  
-
-
-#  ******************************************************************
-#  * Check point configuration:
-#  * 
-#  * Mode must be one of: 
-#  *   CHECK_NEVER    /* No auto checkpointing                       */
-#  *   CHECK_ON_TIME  /* At intervals specified by ECF_CHECKINTERVAL */
-#  *   CHECK_ALWAYS   /* After any change                            */
-#  * The checkpoint filenames can be configured using environment variables
-#  ******************************************************************
-ECF_CHECKMODE = CHECK_ON_TIME
-
-
-#  ******************************************************************
-#  * The port number, this must be consistent between client and server
-#  * If we get "Address in use" then both client/server number should changed.
-#  * Also if two servers are started on the same machine with same port
-#  * then we will also get "Address in use" error and server will bomb out.
-#  * Can be overridden with a environment variable of the same name
-#  ******************************************************************
-ECF_PORT = 3141
-
-
-#  ******************************************************************
-#  * The name of log file.
-#  * default log file name is: <host>.<port>.ecf.log, i.e machine1.3141.ecf.log
-#  * this is required since we can have multiple servers for a single
-#  * machine, where each server will have a separate port number.
-#  * Can be overridden with a environment variable of the same name
-#  *
-#  * Note: Any settings will be prepended with <host>.<port>.
-#  ******************************************************************
-ECF_LOG = ecf.log
- 
- 
-#  ******************************************************************
-#  * The period in second for which we should traverse dependencies
-#  * and submit jobs. This should *RARELY* need changing, as it can affect
-#  * correspondence with real time
-#  ******************************************************************
-ECF_INTERVAL = 60       
- 
-
-#  ******************************************************************
-#  * The standard command use for job submission. 
-#  * Provides DEFAULT can be overridden by user variable
-#  ******************************************************************
-ECF_JOB_CMD = %ECF_JOB% 1> %ECF_JOBOUT% 2>&1
-
-
-#  ******************************************************************
-#  * Define variable for killing any jobs. 
-#  * Provides DEFAULT can be overridden by user variable
-#  * The output of the command should be written to %ECF_JOB%.kill
-#  * ecmwf: ${ECF_KILL:=/home/ma/emos/bin/ecfkill} %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1
-#  ******************************************************************
-ECF_KILL_CMD = kill -15 %ECF_RID%  
-
-
-#  ******************************************************************
-#  * This is run by the SERVER 
-#  * define variable of obtaining status. 
-#  * Provides DEFAULT can be overridden by user variable
-#  * The output of the command should be written to %ECF_JOB%.stat
-#  * ecmwf: ${ECF_STAT:=trimurti} %USER% %HOST% %ECF_RID% %ECF_JOB% status> %ECF_JOB%.stat 2>&1
-#  ******************************************************************
-ECF_STATUS_CMD = ps --pid %ECF_RID% -f > %ECF_JOB%.stat 2>&1
-
-#  ******************************************************************
-#  * This is run by the CLIENT .  check from GUI
-#  ******************************************************************
-ECF_CHECK_CMD = ps --pid %ECF_RID% -f
-
-
-#  ******************************************************************
-#  * define variables used for url command. 
-#  * Provides DEFAULT can be overriden by user variables
-#  ******************************************************************
-ECF_URL_CMD    = ${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%
-ECF_URL_BASE   = https://confluence.ecmwf.int 
-ECF_URL        = display/ECFLOW/ecflow+home
-
-#  ******************************************************************
-#  * Defines the character used in ECF_ pre-processing. i.e identifies includes
-#  * and is also used in variable substitution in '.ecf' scripts
-#  ******************************************************************
-ECF_MICRODEF = %
-
-#  ******************************************************************
-#  * The ECF_LISTS is used to identify a file, that lists the user 
-#  * who can access the server via client commands. Each client command 
-#  * (ignoring task based commands, i.e init, complete, event, meter, label)
-#  * will encode the user name of the process initiating the client request
-#  * This is then compared with list of users in the ecf.lists file.
-#  * If this file is empty, then no authentication is done
-#  * Each server can potionally have a different list.
-#  * default: <host>.<port>.ecf.lists
-#  * Note: Any settings will be prepended with <host>.<port>.
-#  ******************************************************************
-ECF_LISTS = ecf.lists
-
-#  ******************************************************************
-#  * Password file: Use when every user needs password authentication
-#  * Each server can potionally have a different password file.
-#  * default: <host>.<port>.ecf.passwd
-#  * Note: Any settings will be prepended with <host>.<port>.
-#  ******************************************************************
-ECF_PASSWD = ecf.passwd
-
-
-#  ******************************************************************
-#  * Password file:, when only a few users need password, typically
-#  * when a users UID on the remote client, does not match that on the server
-#  * Each server can potionally have a different password file.
-#  * default: <host>.<port>.ecf.custom_passwd
-#  * Note: Any settings will be prepended with <host>.<port>.
-#  ******************************************************************
-ECF_CUSTOM_PASSWD = ecf.custom_passwd
-
-# ***************************************************************************
-# * ECF_TASK_THRESHOLD:
-# * Report on an task taking longer than the threshold. !!
-# *    export ECF_TASK_THRESHOLD=4000
-# ***************************************************************************
-ECF_TASK_THRESHOLD = 4000    
-
-# ***************************************************************************
-# * ECF_PRUNE_NODE_LOG:
-# * Node log/edit history older than 30 days will be automatically
-# * pruned when the server LOADS the checkpoint file.
-# * To disable pruning, set to 0, or set the environment variable of the same
-# * name to zero.
-# ***************************************************************************
-ECF_PRUNE_NODE_LOG = 30          
-         
\ No newline at end of file
diff -pruN 5.12.4-1/Server/src/ecflow/server/BaseServer.cpp 5.13.0-1/Server/src/ecflow/server/BaseServer.cpp
--- 5.12.4-1/Server/src/ecflow/server/BaseServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/BaseServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,508 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/BaseServer.hpp" // Must come before boost/serialization headers.
-
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/date_time/posix_time/posix_time.hpp>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/ExprDuplicate.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-using boost::asio::ip::tcp;
-
-using namespace std;
-using namespace ecf;
-
-/// Constructor opens the acceptor and starts waiting for the first incoming connection.
-BaseServer::BaseServer(boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
-    : io_service_(io_service),
-      signals_(io_service),
-      defs_(Defs::create()), // ECFLOW-182
-      traverser_(this, io_service, serverEnv),
-      checkPtSaver_(this, io_service, &serverEnv),
-      serverState_(SState::HALTED),
-      serverEnv_(serverEnv) {
-    if (serverEnv_.debug())
-        cout << "-->Server::server starting server on port " << serverEnv.port() << endl;
-
-    // Must be set before checkpt file is loaded.
-    defs_->ecf_prune_node_log(serverEnv.ecf_prune_node_log());
-
-    LogFlusher logFlusher;
-
-    // Register to handle the signals.
-    // Support for emergency check pointing during system session.
-    signals_.add(SIGTERM);
-    signals_.async_wait([this](boost::system::error_code /*ec*/, int /*signo*/) { sigterm_signal_handler(); });
-
-    // Update stats, this is returned via --stats command option
-    stats().host_                    = serverEnv.hostPort().first;
-    stats().port_                    = serverEnv.hostPort().second;
-    stats().job_sub_interval_        = serverEnv.submitJobsInterval();
-    stats().checkpt_interval_        = serverEnv.checkPtInterval();
-    stats().checkpt_save_time_alarm_ = serverEnv.checkpt_save_time_alarm();
-    stats().checkpt_mode_            = serverEnv.checkMode();
-    stats().up_since_                = to_simple_string(Calendar::second_clock_time());
-    stats().version_                 = Version::description();
-    stats().status_                  = static_cast<int>(serverState_);
-    stats().ECF_HOME_                = serverEnv.ecf_home();
-    stats().ECF_CHECK_               = serverEnv.checkPtFilename();
-    stats().ECF_LOG_                 = Log::instance()->path();
-
-    // Update log file:
-    ecf::log(Log::MSG, "Server initial state is HALTED");
-
-    // The defs_ *MUST* be updated with the server state
-    // When we load from the check pt file we call update_defs_server_state();
-    if (!load_check_pt_file_on_startup()) {
-
-        // No check pt files loaded, update defs, with server state
-        update_defs_server_state(); // works on def_
-    }
-
-    /// Setup globals used to detect incremental changes to the definition
-    Ecf::set_server(true);
-}
-
-BaseServer::~BaseServer() {
-    if (serverEnv_.debug())
-        cout << "<--BaseServer::~Baseserver exiting server on port " << serverEnv_.port() << endl;
-
-    // Defs destructor may get called after we have returned from main. See ECFLOW-1291
-    // In this case the static memory used in ExprDuplicate will not be reclaimed. hence do it here:
-    // Duplicate AST are held in a static map. Delete them, to avoid valgrind and ASAN from complaining
-    ExprDuplicate reclaim_cloned_ast_memory;
-
-    defs_.reset();
-
-#ifdef DEBUG
-    if (defs_.use_count() != 0) {
-        cout << "Server::~server() defs_.use_count() = " << defs_.use_count()
-             << " something is still hold onto the defs, asserting\n";
-    }
-#endif
-    assert(defs_.use_count() == 0);
-}
-
-void BaseServer::handle_terminate() {
-    // if (serverEnv_.debug()) cout << boost::this_thread::get_id() << "   Server::handle_terminate() : cancelling
-    // checkpt and traverser timers, and signals" << endl;
-    if (serverEnv_.debug())
-        cout << "   Server::handle_terminate() : cancelling checkpt and traverser timers, and signals" << endl;
-
-    // Cancel signal
-    signals_.clear();
-    signals_.cancel();
-
-    // Cancel async timers for check pointing and traversal
-    traverser_.terminate();
-    checkPtSaver_.terminate();
-}
-
-// ============================== other privates ===========================================
-
-bool BaseServer::load_check_pt_file_on_startup() {
-    // On start up we want different behaviour.
-    // If check pt file exists and we can't load then we want to exit
-    // This avoids the server from overwriting the check point file
-    // Which may be from a different version. let the user handle it.
-    LogToCout logToCout;
-    bool checkpt_failed = false;
-    if (restore_from_checkpt(serverEnv_.checkPtFilename(), checkpt_failed)) {
-        return true;
-    }
-    bool backup_checkpt_failed = false;
-    if (restore_from_checkpt(serverEnv_.oldCheckPtFilename(), backup_checkpt_failed)) {
-        return true;
-    }
-
-    if (backup_checkpt_failed && !fs::exists(serverEnv_.checkPtFilename())) {
-        throw std::runtime_error("Cannot start server, please handle the backup checkpoint file first");
-    }
-
-    if (checkpt_failed && !fs::exists(serverEnv_.oldCheckPtFilename())) {
-        throw std::runtime_error("Cannot start server, please handle the checkpoint file first");
-    }
-    return false;
-}
-
-void BaseServer::loadCheckPtFile() {
-    // if the check point file starts with an absolute file load that first
-    // otherwise check in ECF_HOME then load it. Repeat for back up check point file
-    // The server environment has already asserted that we can *NOT* have an empty check point file
-    bool ignore;
-    if (restore_from_checkpt(serverEnv_.checkPtFilename(), ignore)) {
-        return;
-    }
-
-    if (restore_from_checkpt(serverEnv_.oldCheckPtFilename(), ignore)) {
-        return;
-    }
-}
-
-bool BaseServer::restore_from_checkpt(const std::string& filename, bool& failed) {
-    // cout << "BaseServer::restore_from_checkpt " << filename;
-    if (fs::exists(filename)) {
-        // cout << " file exists\n";
-
-        std::string s = "Loading check point file ";
-        s += filename;
-        s += " port:";
-        s += serverEnv_.the_port();
-        log(Log::MSG, s);
-
-        try {
-            defs_->restore(filename);   // this can throw
-            defs_->handle_migration();  // handle any migration of checkpt file.
-            update_defs_server_state(); // works on def_
-            LOG(Log::MSG,
-                "Loading of *DEFS* check point file SUCCEDED. Loaded " << defs_->suiteVec().size() << " suites");
-
-            // fast forward any time attributes, if suite clock is *ONLY* 1 hour behind real time
-            // This may remove autocancelled nodes, may autoarchive, may set late attribute,
-            // may expire time based attributes which will start jobs when server starts
-            if (defs_->catch_up_to_real_time()) {
-                log(Log::MSG,
-                    "Suite time attributes updated to catch up with real time. Down time was less than 1 hour");
-            }
-            return true;
-        }
-        catch (exception& e) {
-            LOG(Log::ERR, "Failed to load *DEFS* check point file " << filename << ", because: " << e.what());
-        }
-    }
-    //   else {
-    //      cout << " does *not* exist\n";
-    //   }
-    return false;
-}
-
-void BaseServer::update_defs_server_state() {
-    /// The Job submission interval, and host port are not persisted, on the DEFS
-    /// Hence when restoring from a checkpoint file, Be sure to update server state
-
-    // Do any *one* time setup on the defs
-
-    // Set the server environment *ON* the defs, so that generate variables can be created.
-    // gets the environment as read in by the server, and make available for defs
-    // ECF_HOME .
-    // ECF_CHECK ecf.check
-    // ECF_CHECKOLD ecf.check.b
-    std::vector<std::pair<std::string, std::string>> envVec;
-    serverEnv_.variables(envVec);
-    defs_->set_server().add_or_update_server_variables(envVec);
-
-    defs_->set_server().hostPort(serverEnv_.hostPort());
-    defs_->set_server().set_state(serverState_);
-
-    // let the defs store the job submission interval, & whether we want job generation.testing can disable this
-    defs_->set_server().jobSubmissionInterval(serverEnv_.submitJobsInterval());
-    defs_->set_server().jobGeneration(serverEnv_.jobGeneration());
-    LOG_ASSERT(defs_->server().jobSubmissionInterval() != 0, "");
-
-    // Since we have reloaded Defs, make sure clients, re-sync by resetting change and modify numbers on server
-    defs_->set_state_change_no(Ecf::state_change_no());
-    defs_->set_modify_change_no(Ecf::modify_change_no());
-
-    /// System needs defs to handle process that have died, and need to flagged as aborted
-    ecf::System::instance()->setDefs(defs_);
-}
-
-void BaseServer::set_server_state(SState::State ss) {
-    serverState_    = ss;
-    stats().status_ = static_cast<int>(serverState_);
-    defs_->set_server().set_state(serverState_);
-}
-
-/// ======================================================================================
-/// AbstractServer function.
-/// ======================================================================================
-
-std::pair<std::string, std::string> BaseServer::hostPort() const {
-    return serverEnv_.hostPort();
-}
-
-void BaseServer::updateDefs(defs_ptr defs, bool force) {
-    if (serverEnv_.debug())
-        std::cout << "   BaseServer::updateDefs: Loading new suites" << endl;
-
-    // After the absorb, input defs will be left with NO suites.
-    defs_->absorb(defs.get(), force);
-
-    defs_->set_most_significant_state();
-    LOG_ASSERT(defs_->server().jobSubmissionInterval() != 0, "");
-}
-
-void BaseServer::clear_defs() {
-    if (serverEnv_.debug())
-        cout << "   BaseServer::clear_defs()" << endl;
-
-    defs_->clear();
-}
-
-bool BaseServer::checkPtDefs(ecf::CheckPt::Mode m, int check_pt_interval, int check_pt_save_time_alarm) {
-    if (serverEnv_.debug())
-        cout << "   BaseServer::checkPtDefs() mode(" << m << ") check_pt_interval(" << check_pt_interval
-             << ") check_pt_save_time_alarm(" << check_pt_save_time_alarm << ")" << endl;
-
-    if (m == ecf::CheckPt::UNDEFINED && check_pt_interval == 0 && check_pt_save_time_alarm == 0) {
-        return checkPtSaver_.explicitSave(); // will always save
-    }
-    else {
-        if (m != ecf::CheckPt::UNDEFINED) {
-            serverEnv_.set_check_mode(m);
-            stats().checkpt_mode_ = serverEnv_.checkMode();
-        }
-        if (check_pt_interval > 0) {
-            serverEnv_.set_checkpt_interval(check_pt_interval);
-            stats().checkpt_interval_ = check_pt_interval;
-        }
-        if (check_pt_save_time_alarm > 0) {
-            serverEnv_.set_checkpt_save_time_alarm(check_pt_save_time_alarm);
-            stats().checkpt_save_time_alarm_ = check_pt_save_time_alarm;
-        }
-    }
-    return true;
-}
-
-void BaseServer::restore_defs_from_checkpt() {
-    if (serverEnv_.debug())
-        cout << "   BaseServer::restore_defs_from_checkpt()" << endl;
-
-    if (serverState_ != SState::HALTED) {
-        throw std::runtime_error("Cannot restore from checkpt the server must be halted first");
-    }
-
-    if (!defs_->suiteVec().empty()) {
-        // suites must be deleted manually first
-        throw std::runtime_error("Cannot restore from checkpt the server suites must be deleted first");
-    }
-
-    loadCheckPtFile();
-}
-
-void BaseServer::nodeTreeStateChanged() {
-    if (serverEnv_.debug())
-        cout << "   BaseServer::nodeTreeStateChanged()" << endl;
-
-    // will only actually save if configuration allows it
-    checkPtSaver_.saveIfAllowed();
-}
-
-bool BaseServer::allowTaskCommunication() const {
-    return (serverState_ != SState::HALTED) ? true : false;
-}
-
-void BaseServer::shutdown() {
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    if (serverEnv_.debug())
-        cout << "   BaseServer::shutdown. Stop Scheduling new jobs only" << endl;
-
-    // Stop server from creating new jobs. Don't stop the checkPtSaver_ since
-    // the jobs communication with server can still change state. Which we want
-    // to check point.
-    traverser_.stop();
-
-    // Continue check pointing since, we allow tasks communication. This can change node
-    // tree state. Which we *must* be able to checkpoint.
-    // If we go from HALTED --> SHUTDOWN, then check pointing  needs to be enabled
-    checkPtSaver_.start();
-
-    // Will update defs as well to stop job scheduling
-    set_server_state(SState::SHUTDOWN);
-}
-
-void BaseServer::halted() {
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    if (serverEnv_.debug())
-        cout << "   BaseServer::halted. Stop Scheduling new jobs *and* block task communication. Stop check pointing. "
-                "Only accept user request"
-             << endl;
-
-    // Stop server from creating new jobs. i.e Job scheduling.
-    traverser_.stop();
-
-    // *** CRITICAL*** when the server is halted, we ***MUST NOT*** do any further check pointing
-    // In a typical operational scenario where we have a home, and backup servers.
-    // The checkpoint file is copied to the backup servers periodically (via a task)
-    // hence we want to preserve the state of the last checkpoint.
-    // Added after discussion with Axel.
-    checkPtSaver_.stop();
-
-    // Stop the task communication with server. Hence nodes can be stuck
-    // in submitted/active states. Task based command will continue attempting,
-    // communication with the server for up to 24hrs.
-    // Will update defs as well to stop job scheduling
-    set_server_state(SState::HALTED);
-}
-
-void BaseServer::restart() {
-    ///           User Request    Task Request   Job Scheduling   Check-pointing
-    /// RUNNING      yes               yes              yes            yes
-    /// SHUTDOWN     yes               yes              no             yes
-    /// HALTED       yes               no               no             no
-    if (serverEnv_.debug())
-        std::cout << "   BaseServer::restart" << endl;
-
-    // The server state *MUST* be set, *before* traverser_.start(), since that can kick off job traversal.
-    // Job Scheduling can only be done under RUNNING state, hence must be before traverser_.start();
-    //
-    // If we placed set_server_state(SState::RUNNING); after we can miss time slots
-    //    See:: SUP 571- Time dependency after halt/checkpoint
-    set_server_state(SState::RUNNING);
-
-    traverser_.start();
-    checkPtSaver_.start();
-}
-
-void BaseServer::traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
-                                                     bool user_cmd_context) const {
-    traverser_.traverse_node_tree_and_job_generate(time_now, user_cmd_context);
-}
-
-bool BaseServer::reloadWhiteListFile(std::string& errorMsg) {
-    if (serverEnv_.debug())
-        cout << "   BaseServer::reloadWhiteListFile" << endl;
-    return serverEnv_.reloadWhiteListFile(errorMsg);
-}
-
-bool BaseServer::reloadPasswdFile(std::string& errorMsg) {
-    if (serverEnv_.debug())
-        cout << "   BaseServer::reloadPasswdFile" << endl;
-    return serverEnv_.reloadPasswdFile(errorMsg);
-}
-
-bool BaseServer::reloadCustomPasswdFile(std::string& errorMsg) {
-    if (serverEnv_.debug())
-        cout << "   BaseServer::reloadCustomPasswdFile " << endl;
-    return serverEnv_.reloadCustomPasswdFile(errorMsg);
-}
-
-bool BaseServer::authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) {
-    return serverEnv_.authenticateReadAccess(user, custom_user, passwd);
-}
-bool BaseServer::authenticateReadAccess(const std::string& user,
-                                        bool custom_user,
-                                        const std::string& passwd,
-                                        const std::string& path) {
-    return serverEnv_.authenticateReadAccess(user, custom_user, passwd, path);
-}
-bool BaseServer::authenticateReadAccess(const std::string& user,
-                                        bool custom_user,
-                                        const std::string& passwd,
-                                        const std::vector<std::string>& paths) {
-    return serverEnv_.authenticateReadAccess(user, custom_user, passwd, paths);
-}
-
-bool BaseServer::authenticateWriteAccess(const std::string& user) {
-    return serverEnv_.authenticateWriteAccess(user);
-}
-bool BaseServer::authenticateWriteAccess(const std::string& user, const std::string& path) {
-    return serverEnv_.authenticateWriteAccess(user, path);
-}
-bool BaseServer::authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) {
-    return serverEnv_.authenticateWriteAccess(user, paths);
-}
-
-bool BaseServer::lock(const std::string& user) {
-    if (serverEnv_.debug())
-        std::cout << "   BaseServer::lock " << user << endl;
-
-    if (userWhoHasLock_.empty()) {
-        userWhoHasLock_           = user;
-        stats().locked_by_user_   = user;
-        server_state_to_preserve_ = state();
-        shutdown();
-        return true;
-    }
-    else if (userWhoHasLock_ == user && serverState_ == SState::SHUTDOWN) {
-        // Same user attempting multiple locks
-        return true;
-    }
-    return false;
-}
-void BaseServer::unlock() {
-    if (serverEnv_.debug())
-        std::cout << "   BaseServer::unlock " << userWhoHasLock_ << endl;
-
-    userWhoHasLock_.clear();
-    stats().locked_by_user_.clear();
-
-    switch (server_state_to_preserve_) {
-        case SState::RUNNING:
-            restart();
-            break;
-        case SState::SHUTDOWN:
-            shutdown();
-            break;
-        case SState::HALTED:
-            halted();
-            break;
-    }
-}
-const std::string& BaseServer::lockedUser() const {
-    return userWhoHasLock_;
-}
-
-int BaseServer::poll_interval() const {
-    return serverEnv_.submitJobsInterval();
-}
-
-void BaseServer::debug_server_on() {
-    serverEnv_.set_debug(true);
-    std::cout << "\nEnable DEBUG, start with DUMP of server environment:\n\n";
-    std::cout << serverEnv_.dump() << endl;
-}
-
-void BaseServer::debug_server_off() {
-    serverEnv_.set_debug(false);
-}
-
-bool BaseServer::debug() const {
-    return serverEnv_.debug();
-}
-
-void BaseServer::sigterm_signal_handler() {
-    if (io_service_.stopped()) {
-        if (serverEnv_.debug())
-            cout << "-->BaseServer::sigterm_signal_handler(): io_service is stopped returning " << endl;
-        return;
-    }
-
-    if (serverEnv_.debug())
-        cout << "BaseServer::sigterm_signal_handler(): Received SIGTERM : starting check pointing" << endl;
-    ecf::log(Log::MSG, "BaseServer::sigterm_signal_handler(): Received SIGTERM : starting check pointing");
-
-    defs_->flag().set(ecf::Flag::ECF_SIGTERM);
-    checkPtDefs();
-
-    ecf::log(Log::MSG, "BaseServer::sigterm_signal_handler(): finished check pointing");
-    if (serverEnv_.debug())
-        cout << "BaseServer::sigterm_signal_handler(): finished check pointing" << endl;
-
-    // We need re-wait each time signal handler is called
-    signals_.async_wait([this](boost::system::error_code /*ec*/, int /*signo*/) { sigterm_signal_handler(); });
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/BaseServer.hpp 5.13.0-1/Server/src/ecflow/server/BaseServer.hpp
--- 5.12.4-1/Server/src/ecflow/server/BaseServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/BaseServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,111 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_BaseServer_HPP
-#define ecflow_server_BaseServer_HPP
-
-#include <boost/asio.hpp>
-
-#include "ecflow/base/AbstractServer.hpp"
-#include "ecflow/server/CheckPtSaver.hpp"
-#include "ecflow/server/NodeTreeTraverser.hpp"
-
-class ServerEnvironment;
-
-///
-/// \brief ecFlow Server, with implementation based on Boost.asio
-///
-/// The port numbers are divided into three ranges:
-///  o the Well Known Ports, (require root permission)  0   -1023
-///  o the Registered Ports,                            1024-49151
-///  o Dynamic and/or Private Ports.                    49151-65535
-///
-
-class BaseServer : public AbstractServer {
-public:
-    /// Constructor opens the acceptor and starts waiting for the first incoming
-    /// connection.
-    explicit BaseServer(boost::asio::io_service& io_service, ServerEnvironment&);
-    ~BaseServer() override;
-
-    void handle_terminate();
-
-    // abort server if check pt files exist, but can't be loaded
-    bool load_check_pt_file_on_startup();
-    void loadCheckPtFile();
-    bool restore_from_checkpt(const std::string& filename, bool& failed);
-    void update_defs_server_state();
-    void set_server_state(SState::State);
-
-    /// AbstractServer functions
-    SState::State state() const override { return serverState_; }
-    std::pair<std::string, std::string> hostPort() const override;
-    defs_ptr defs() const override { return defs_; }
-    void updateDefs(defs_ptr, bool force) override;
-    void clear_defs() override;
-    bool checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
-                     int check_pt_interval        = 0,
-                     int check_pt_save_time_alarm = 0) override;
-    void restore_defs_from_checkpt() override;
-    void nodeTreeStateChanged() override;
-    bool allowTaskCommunication() const override;
-    void shutdown() override;
-    void halted() override;
-    void restart() override;
-    bool reloadWhiteListFile(std::string& errorMsg) override;
-    bool reloadPasswdFile(std::string& errorMsg) override;
-    bool reloadCustomPasswdFile(std::string& errorMsg) override;
-    bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) override;
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::string& path) override;
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::vector<std::string>& paths) override;
-    bool authenticateWriteAccess(const std::string& user) override;
-    bool authenticateWriteAccess(const std::string& user, const std::string& path) override;
-    bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) override;
-    bool lock(const std::string& user) override;
-    void unlock() override;
-    const std::string& lockedUser() const override;
-    void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
-                                             bool user_cmd_context) const override;
-    int poll_interval() const override;
-    void debug_server_on() override;
-    void debug_server_off() override;
-    bool debug() const override;
-
-    // used in signal, for emergency check point during system session
-    void sigterm_signal_handler();
-
-protected:
-    /// The io_service used to perform asynchronous operations.
-    boost::asio::io_service& io_service_;
-
-    /// The signal_set is used to register for automatic check pointing
-    boost::asio::signal_set signals_;
-
-    defs_ptr defs_; // shared because is deleted in Test, and used in System::instance()
-    NodeTreeTraverser traverser_;
-    friend class NodeTreeTraverser;
-
-    CheckPtSaver checkPtSaver_;
-    friend class CheckPtSaver;
-
-    SState::State serverState_;
-    SState::State server_state_to_preserve_{SState::RUNNING}; // preserve state over plug cmd ECFLOW-1606
-
-    ServerEnvironment& serverEnv_;
-    std::string userWhoHasLock_;
-};
-
-#endif /* ecflow_server_BaseServer_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/CheckPtSaver.cpp 5.13.0-1/Server/src/ecflow/server/CheckPtSaver.cpp
--- 5.12.4-1/Server/src/ecflow/server/CheckPtSaver.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/CheckPtSaver.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,205 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/CheckPtSaver.hpp"
-
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/server/BaseServer.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-// #define DEBUG_CHECKPT 1
-// #define DEBUG_CHECKPT_SAVE_ALLOWED 1
-
-#ifdef DEBUG_CHECKPT
-    #include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
-#endif
-
-using namespace ecf;
-
-//-------------------------------------------------------------------------------------
-CheckPtSaver::CheckPtSaver(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment* serverEnv)
-    : server_(s),
-      timer_(io, boost::posix_time::seconds(0)),
-      firstTime_(true),
-      running_(false),
-      serverEnv_(serverEnv),
-      state_change_no_(Ecf::state_change_no()),
-      modify_change_no_(Ecf::modify_change_no()) {
-#ifdef DEBUG_CHECKPT
-    std::cout << "      CheckPtSaver::CheckPtSaver period = " << serverEnv_->checkPtInterval() << "\n";
-#endif
-}
-
-CheckPtSaver::~CheckPtSaver() {
-#ifdef DEBUG_CHECKPT
-    std::cout << "      ~CheckPtSaver::CheckPtSaver\n";
-#endif
-}
-
-void CheckPtSaver::start() {
-#ifdef DEBUG_CHECKPT
-    std::cout << "      CheckPtSaver::start() check_mode: " << serverEnv_->check_mode_str()
-              << " interval = " << serverEnv_->checkPtInterval()
-              << " time = " << to_simple_string(boost::posix_time::second_clock::universal_time()) << "\n";
-#endif
-
-    // Only save check pt periodically if configuration allows it
-    if (serverEnv_->checkMode() != ecf::CheckPt::ON_TIME) {
-#ifdef DEBUG_CHECKPT
-        std::cout << "      CheckPtSaver::start() aborted as configuration does not allow it" << std::endl;
-#endif
-        return;
-    }
-
-    running_ = true;
-
-    // * important * The time should only be started *ONCE*. Otherwise we will end up with
-    //               with explicit save each time server is halted/started.
-    if (firstTime_) {
-        firstTime_ = false;
-        timer_.expires_from_now(boost::posix_time::seconds(serverEnv_->checkPtInterval()));
-        timer_.async_wait(
-            server_->io_service_.wrap([this](const boost::system::error_code& error) { periodicSaveCheckPt(error); }));
-    }
-}
-
-void CheckPtSaver::stop() { // The server is stopped by cancelling all outstanding asynchronous
-                            // operations. Once all operations have finished the io_service::run() call
-                            // will exit.
-#ifdef DEBUG_CHECKPT
-    std::cout << "      CheckPtSaver::stop() check_mode: " << serverEnv_->check_mode_str()
-              << " interval = " << serverEnv_->checkPtInterval() << "\n";
-#endif
-    running_ = false;
-}
-
-void CheckPtSaver::terminate() {
-    timer_.cancel();
-}
-
-bool CheckPtSaver::explicitSave(bool from_server) const {
-    try {
-#ifdef DEBUG_CHECKPT
-        std::cout << "      CheckPtSaver::explicitSave() Saving checkpt file " << serverEnv_->checkPtFilename() << "\n";
-#endif
-        // In order to detect *SLOW* operations (i.e. disk related), which *AFFECT* server performance,
-        // the following timer measures how long we take to store the CheckPoint file.
-        // After the Definitions are stored, if a configured warning threshold is passed a warning is issues.
-        DurationTimer timer;
-
-        fs::path checkPtFile(serverEnv_->checkPtFilename());
-        fs::path oldCheckPtFile(serverEnv_->oldCheckPtFilename());
-        CheckPtSaver::storeWithBackup(checkPtFile, oldCheckPtFile, [&](const fs::path& file_path) {
-            server_->defs_->save_as_checkpt(file_path.string());
-        });
-
-        state_change_no_  = Ecf::state_change_no();  // For periodic update only save checkPt if it has changed
-        modify_change_no_ = Ecf::modify_change_no(); // For periodic update only save checkPt if it has changed
-
-        if (from_server) {
-            // Create new time stamp otherwise we end up using the time stamp from the last command
-            Log::instance()->cache_time_stamp();
-            std::string msg = Str::SVR_CMD();
-            msg += CtsApi::checkPtDefsArg();
-            std::stringstream ss;
-            ss << msg << " in " << timer.duration() << " seconds";
-            log(Log::MSG, ss.str());
-        }
-
-        /// If Save take longer than checkpt_save_time_alarm, then set a flag on server
-        /// So that user can be aware of it.
-        if (static_cast<size_t>(timer.duration()) > server_->serverEnv_.checkpt_save_time_alarm()) {
-            server_->defs_->flag().set(ecf::Flag::LATE);
-            std::stringstream ss;
-            ss << "Check pt save time(" << timer.duration() << ") is greater than alarm time("
-               << server_->serverEnv_.checkpt_save_time_alarm()
-               << "). Excessive save times can interfere with scheduling!";
-            log(Log::WAR, ss.str());
-        }
-#ifdef DEBUG_CHECKPT
-        std::cout << " backup and save took " << durationTimer.duration() << " seconds\n";
-#endif
-    }
-    catch (std::exception& e) {
-        std::string msg = "Could not save checkPoint file! ";
-        msg += e.what();
-        server_->defs_->flag().set(ecf::Flag::CHECKPT_ERROR);
-        server_->defs()->set_server().add_or_update_user_variables("ECF_CHECKPT_ERROR", msg);
-        LOG(Log::ERR, msg);
-        return false;
-    }
-
-    return true;
-}
-
-void CheckPtSaver::periodicSaveCheckPt(const boost::system::error_code& error) {
-#ifdef DEBUG_CHECKPT
-    std::cout << "      CheckPtSaver::periodicSaveCheckPt() interval = " << serverEnv_->checkPtInterval()
-              << "  time: " << to_simple_string(boost::posix_time::second_clock::universal_time()) << "\n";
-#endif
-    if (error == boost::asio::error::operation_aborted) {
-#ifdef DEBUG_CHECKPT
-        std::cout << "      CheckPtSaver::periodicSaveCheckPt : boost::asio::error::operation_aborted : time "
-                     "cancelled: Node running("
-                  << running_ << ")  interval = " << serverEnv_->checkPtInterval() << "\n";
-#endif
-        return;
-    }
-    else if (error) {
-        LogFlusher logFlusher;
-        LogToCout toCoutAsWell;
-        LOG(Log::ERR, "CheckPtSaver::periodicSaveCheckPt " << error.message());
-        return;
-    }
-
-    if (running_) {
-        // state changed
-        if (state_change_no_ != Ecf::state_change_no() || modify_change_no_ != Ecf::modify_change_no()) {
-            doSave();
-        }
-    }
-
-    /// Appears that expires_from_now is more accurate then expires_at
-    timer_.expires_from_now(boost::posix_time::seconds(serverEnv_->checkPtInterval()));
-    timer_.async_wait(
-        server_->io_service_.wrap([this](const boost::system::error_code& error) { periodicSaveCheckPt(error); }));
-}
-
-void CheckPtSaver::doSave() const {
-#ifdef DEBUG_CHECKPT
-    std::cout << "      CheckPtSaver::doSave()\n";
-#endif
-    // Check to see if configuration allows save
-    if (serverEnv_->checkMode() == ecf::CheckPt::NEVER) {
-#ifdef DEBUG_CHECKPT
-        std::cout << "     CheckPtSaver::doSave() configuration does not allow save \n";
-#endif
-        return;
-    }
-    (void)explicitSave(true /* from the server, hence log */);
-}
-
-void CheckPtSaver::saveIfAllowed() {
-    // Call on each state change. Hence will get many times
-#ifdef DEBUG_CHECKPT_SAVE_ALLOWED
-    std::cout << "      CheckPtSaver::saveIfAllowed()\n";
-#endif
-
-    // Check to see if configuration allows immediate save.
-    if (serverEnv_->checkMode() == ecf::CheckPt::ALWAYS) {
-        doSave();
-    }
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/CheckPtSaver.hpp 5.13.0-1/Server/src/ecflow/server/CheckPtSaver.hpp
--- 5.12.4-1/Server/src/ecflow/server/CheckPtSaver.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/CheckPtSaver.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,126 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_CheckPtSaver_HPP
-#define ecflow_server_CheckPtSaver_HPP
-
-#include <boost/asio.hpp>
-
-#include "ecflow/core/Filesystem.hpp"
-
-class ServerEnvironment;
-class BaseServer;
-
-///
-/// \brief This class will save the defs file periodically. The period is obtained from
-/// ServerEnvironment. The save of the check point file is controlled by
-/// the settings in ServerEnvironment
-///
-/// The checkpoint files is the defs file, with state. However its saved in
-/// boost serialisation format(i.e can be text,binary,portable binary)
-///
-
-class CheckPtSaver {
-public:
-    CheckPtSaver(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment*);
-    // Disable copy (and move) semantics
-    CheckPtSaver(const CheckPtSaver&)                  = delete;
-    const CheckPtSaver& operator=(const CheckPtSaver&) = delete;
-
-    ~CheckPtSaver();
-
-    /// Start periodical save of the checkpoint file
-    void start();
-
-    /// Stop periodical save of the checkPoint file
-    void stop();
-
-    /// terminate: This will cancel the timer and any pending async operation
-    /// If timer has already expired, then the handler function will be
-    /// passed an operation aborted error code.
-    /// Called when the server is exiting. We must be sure to cancel all
-    /// async handlers or the server, will not stop.
-    void terminate();
-
-    /// Will always save the check pt file. Independent of any server environment
-    /// The input argument is used in logging. When check pointing via user command
-    /// we log the request. However we also check point automatically via the server
-    /// This allows us to distinguish the two cases in the log file:
-    /// Return true if no errors, otherwise false
-    bool explicitSave(bool from_server = false) const;
-
-    /// This function is called after node state changes. Check for save
-    /// CheckPt::ON_TIME - will do nothing since we will save periodically
-    /// CheckPt::NEVER   - will return immediately
-    /// CheckPt::ALWAYS  - will save immediately, may cause performance issues with large Node trees
-    void saveIfAllowed();
-
-    /**
-     * Stores a set of data in the current file location, ensuring a backup file retains the previous version.
-     *
-     * @tparam STORE the type of the function that stores the data
-     * @param current the file path to the current data, which will become the backup
-     * @param backup the file path to the previous backup, to be discarded
-     * @param store the function that actually performs the storage
-     */
-    template <typename STORE>
-    static void storeWithBackup(const fs::path& current, const fs::path& backup, STORE store) {
-        // 1. Save the Definitions to a temporary CheckPoint file
-        //
-        // In case an issue occurs while saving the CheckPoint file (e.g. thrown
-        // exception, or server crash), the procedure is always interrupted without
-        // changes to the current+old CheckPoint files in order to facilitate recovery.
-        //
-        fs::path temporary = fs::unique_path(current.string() + "%%%%-%%%%-%%%%-%%%%");
-        store(temporary.string());
-
-        // 2. Backup the current CheckPoint files
-        //
-        // Important: The current checkpoint is only backed up if it exists
-        // and has size greater than zero bytes. This approach avoid backing up
-        // empty files, resulting from a full file system, and overriding relevant
-        // old content that might be otherwise available.
-        //
-        // The backup effectively replaces the old with the current CheckPoint file.
-        //
-        if (fs::exists(current) && fs::file_size(current) > 0) {
-            fs::remove(backup);
-            fs::rename(current, backup);
-        }
-
-        // 3. Promote the temporary to current CheckPoint file
-        fs::rename(temporary, current);
-    }
-
-private:
-    /// save the node tree in the server to a checkPt file.
-    /// this is controlled by the configuration. If the configuration does not
-    /// allow a save, does nothing
-    void doSave() const;
-
-    /// Called periodically to save checkPoint file
-    /// We use error parameter, since when we cancel the timer via, terminate
-    /// we do NOT want to do an explicit save *PLUS* we want to return without
-    /// starting another async operation. Otherwise the server will not return
-    ///
-    /// This will call doSave() but *ONLY* if there has been a state change
-    /// This avoids writing out a checkpt file, unnecessarily & filling up log file
-    void periodicSaveCheckPt(const boost::system::error_code& error);
-
-    BaseServer* server_;
-    boost::asio::deadline_timer timer_;
-    bool firstTime_;
-    bool running_;
-    const ServerEnvironment* serverEnv_;
-    mutable unsigned int state_change_no_;  // detect state change in defs
-    mutable unsigned int modify_change_no_; // detect state change in defs
-};
-
-#endif /* ecflow_server_CheckPtSaver_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/NodeTreeTraverser.cpp 5.13.0-1/Server/src/ecflow/server/NodeTreeTraverser.cpp
--- 5.12.4-1/Server/src/ecflow/server/NodeTreeTraverser.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/NodeTreeTraverser.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,402 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/NodeTreeTraverser.hpp"
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/CalendarUpdateParams.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Jobs.hpp"
-#include "ecflow/node/JobsParam.hpp"
-#include "ecflow/server/BaseServer.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-// #define DEBUG_TRAVERSER 1
-// #define DEBUG_POLL 1
-
-#ifdef DEBUG_TRAVERSER
-    #include <iostream>
-#endif
-using namespace std;
-using namespace ecf;
-using namespace boost::posix_time;
-
-// ***********************************************************************
-// It was noticed that having a poll of 60 seconds was not very accurate
-// even when the server was not active, could be out by as much as 25 seconds
-// Hence we poll every second, and check it against the minute boundary
-// ************************************************************************
-
-NodeTreeTraverser::NodeTreeTraverser(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment& serverEnv)
-    : server_(s),
-      serverEnv_(serverEnv),
-      timer_(io, boost::posix_time::seconds(0)),
-      interval_(0, 0, serverEnv_.submitJobsInterval(), 0),
-#ifdef DEBUG_TRAVERSER
-      count_(0),
-#endif
-      firstTime_(true),
-      running_(false) {
-#ifdef DEBUG_TRAVERSER
-    std::cout << "NodeTreeTraverser::NodeTreeTraverser period = " << serverEnv_.submitJobsInterval() << "\n";
-#endif
-}
-
-NodeTreeTraverser::~NodeTreeTraverser() {
-#ifdef DEBUG_TRAVERSER
-    std::cout << "~NodeTreeTraverser::NodeTreeTraverser\n";
-#endif
-}
-
-void NodeTreeTraverser::start() {
-#ifdef DEBUG_TRAVERSER
-    {
-        LogToCout toCoutAsWell;
-        LOG(Log::DBG,
-            "NodeTreeTraverser::start() server_state(" << SState::to_string(server_->state()) << ") running("
-                                                       << running_ << ")  count(" << count_ << ") firstTime_("
-                                                       << firstTime_ << ")");
-    }
-#endif
-
-    if (!running_) {
-#ifdef DEBUG_TRAVERSER
-        count_ = 0;
-#endif
-        running_ = true;
-        if (firstTime_) {
-            // If the server is stopped/started we want to avoid skewing the calendar, since each time
-            // we call traverse, the calendar is updated with the server poll. hence we must make sure
-            // we only start it once here
-            last_time_      = Calendar::second_clock_time();
-            next_poll_time_ = last_time_;
-            firstTime_      = false;
-
-            /// ==========================================================================
-            /// Make sure we *ALIGN* the poll period exactly *** to the minute*** boundary
-            /// ==========================================================================
-            if (60 == serverEnv_.submitJobsInterval()) {
-
-                time_duration time_of_day      = last_time_.time_of_day();
-                int seconds_to_minute_boundary = 60 - time_of_day.seconds();
-
-#ifdef DEBUG_TRAVERSER
-                std::cout << "  NodeTreeTraverser::start: time_of_day(" << to_simple_string(time_of_day)
-                          << ") seconds_to_minute_boundary(" << seconds_to_minute_boundary << ")\n";
-#endif
-
-                if (seconds_to_minute_boundary != 0) {
-
-                    // Make sure subsequent polls are *ALIGNED* to minute boundary
-                    next_poll_time_ = last_time_ + seconds(seconds_to_minute_boundary);
-#ifdef DEBUG_TRAVERSER
-                    std::cout << "  NodeTreeTraverser::start: next_poll_time_(" << to_simple_string(next_poll_time_)
-                              << ")\n";
-#endif
-
-                    // ************************************************************************************************
-                    // ** This relies on next_poll_time_ being set first, to ensure job generation does not take longer
-                    // ************************************************************************************************
-#ifdef DEBUG_TRAVERSER
-                    std::cout << "  NodeTreeTraverser::start: Do an immediate job generation. Since we don't want to "
-                                 "wait for minute boundary, when starting.\n";
-#endif
-                    update_suite_calendar_and_traverse_node_tree(last_time_);
-                }
-            }
-
-            start_timer();
-        }
-    }
-}
-
-void NodeTreeTraverser::stop() {
-#ifdef DEBUG_TRAVERSER
-    {
-        LogToCout toCoutAsWell;
-        LOG(Log::DBG, "   NodeTreeTraverser::stop() count(" << count_ << ")");
-    }
-#endif
-
-    running_ = false;
-}
-
-void NodeTreeTraverser::terminate() {
-#ifdef DEBUG_TRAVERSER
-    {
-        LogToCout toCoutAsWell;
-        LOG(Log::DBG, "   NodeTreeTraverser::terminate() count(" << count_ << ")");
-    }
-#endif
-
-    timer_.cancel();
-}
-
-void NodeTreeTraverser::do_traverse() {
-    // since we poll every second, if less than next poll (every 60 seconds) continue.
-    ptime time_now = Calendar::second_clock_time();
-    if (time_now < next_poll_time_) {
-
-        // minimise the number of node tree traversal, to once every second, but only *IF* required
-        // Note: if we are a few seconds to the poll time, but job generation takes a while
-        //       we can get warning about the interval took to long. See below:
-
-        // LOG(Log::DBG,"get_job_generation_count() = " << server_->get_job_generation_count());
-        if (server_->get_job_generation_count() > 0) {
-            traverse_node_tree_and_job_generate(time_now, false /* not in command context */);
-        }
-
-        start_timer(); // timer fires *EVERY* second
-        return;
-    }
-    // time_now >= next_poll_time_
-
-    LogFlusher logFlusher;
-
-    // We have SOFT real time, we poll every second, BUT only update the suite calendar at job submission interval.
-    // However, we cannot guarantee to hit exactly at the next poll time
-    // *** traverse node tree and increment next_poll_time_ ***
-    time_duration duration          = time_now - last_time_;
-    int diff_from_last_time         = duration.total_seconds();
-    int submitJobsIntervalInSeconds = serverEnv_.submitJobsInterval();
-
-#ifdef DEBUG_TRAVERSER
-    int real_diff = diff_from_last_time - submitJobsIntervalInSeconds;
-    std::stringstream ss;
-    ss << "   NodeTreeTraverser::traverse() diff_from_last_time:" << diff_from_last_time << " running:" << running_
-       << " count:" << count_ << " real_diff:" << real_diff << "  time_now:" << to_simple_string(time_now);
-    if (diff_from_last_time == 0)
-        ss << ": FIRST time: ";
-#endif
-
-    /// Update server stat's. ie records number of requests for each poll period
-    server_->update_stats(diff_from_last_time);
-
-    /// The poll times will *vary* since we are trying to keep up with the hard real time.
-    if (diff_from_last_time > submitJobsIntervalInSeconds) {
-
-        /// This will happen from time to time, hence only report, for real wayward times
-        int diff = diff_from_last_time - submitJobsIntervalInSeconds;
-        if (diff > (submitJobsIntervalInSeconds * 0.25)) {
-            LOG(Log::WAR,
-                ": interval is (" << submitJobsIntervalInSeconds << " seconds) but took (" << diff_from_last_time
-                                  << " seconds)");
-        }
-    }
-
-    /// Remove any stale zombies
-    server_->zombie_ctrl().remove_stale_zombies(time_now);
-
-#ifdef DEBUG_TRAVERSER
-    time_duration traverse_duration = Calendar::second_clock_time() - time_now;
-    ss << " Traverse duration:" << traverse_duration.total_seconds();
-#endif
-
-    // We poll *EVERY second but update the next_poll_time_ to be consistent with the job submission interval
-    // Hence the next poll times *will* vary( SOFT REAL TIME ).
-    // Note: On server start, we modified the next_poll_time_ to hit the minute boundary.
-    //
-    //         FIRST          time_now(skip)                                   time_now(traverse node tree)
-    //           |                |         L                                      |         S
-    //           V                V------------------------|                       V-----------------|
-    // ==========0====================0====================0====================0====================0
-    //           ^                    ^                    ^                    ^                    ^
-    //           |                    |                    |                    |                    |
-    //         last_time_       next_poll_time_       next_poll_time_      next_poll_time_      next_poll_time_
-    //         next_poll_time_
-    //                                ^                                         ^
-    //                                |                                         |
-    //                             last_time_                                last_time_
-    //                             reset to previous next_poll_time_, to avoid yo-yoing, messages about poll being
-    //                             long/short
-    //
-    // Update next_poll_time_: WE  *ONLY* get here if time_now >= next_poll_time
-
-    if (time_now > next_poll_time_) {
-
-        /// Continue updating next_poll_time_ by interval_ until it is greater time_now
-#ifdef DEBUG_TRAVERSER
-        {
-            ss << ": Shorten the poll time : Current time(" << to_simple_string(time_now) << ") > current poll_time("
-               << to_simple_string(next_poll_time_) << ")";
-            time_duration diff = time_now - next_poll_time_;
-            ss << " by " << diff.total_seconds() << " seconds: ";
-        }
-#endif
-
-        while (next_poll_time_ <= time_now) {
-            next_poll_time_ += interval_;
-        }
-    }
-    else {
-
-        /// Hit the poll time: Should get here when traverse called for the *FIRST* time ( since time_now ==
-        /// next_poll_time_)
-#ifdef DEBUG_TRAVERSER
-        ss << ": On poll time: ";
-#endif
-
-        next_poll_time_ += interval_;
-    }
-
-    // At begin time for very large suites, slow disk, and in test, during job generation we can miss the next poll
-    // time(i.e a,b) This means that on the next poll time because last_time was not updated, to be immediately behind
-    // the next poll time by 'interval_' seconds an erroneous report is logged about missing the poll time
-    //
-    //         FIRST                                                               Time_now
-    //           |                                                                    |
-    //           V                    a                    b                    c     X
-    // ==========0====================0====================0====================0====================0
-    //           ^                    ^                    ^                    ^                    ^
-    //           |                    |                    |                    |                    |
-    //         last_time_       next_poll_time_       next_poll_time_      next_poll_time_      next_poll_time_
-    //
-    // Hence we need to ensure that last_time is always less that next_poll_time_ by interval_
-    // In the diagram above missed poll time a and b, then we need to set last_time_ to 'c' and *NOT* 'a' | 'b'
-    last_time_ = next_poll_time_ - interval_;
-
-#ifdef DEBUG_TRAVERSER
-    {
-        ss << " Next Poll at:" << to_simple_string(next_poll_time_);
-        LogToCout toCoutAsWell;
-        LOG(Log::DBG, ss.str());
-    }
-#endif
-
-    // Start node tree traversal.
-    // ************************************************************************************************
-    // ** This relies on next_poll_time_ being set first, to ensure job generation does not take longer
-    // ************************************************************************************************
-    update_suite_calendar_and_traverse_node_tree(time_now);
-
-    start_timer(); // timer fires *EVERY* second
-}
-
-void NodeTreeTraverser::start_timer() {
-    /// Appears that expires_from_now is more accurate then expires_at i.e timer_.expires_at( timer_.expires_at() +
-    /// boost::posix_time::seconds( poll_at ) );
-    timer_.expires_from_now(boost::posix_time::seconds(1));
-    timer_.async_wait(server_->io_service_.wrap([this](const boost::system::error_code& error) { traverse(error); }));
-}
-
-void NodeTreeTraverser::traverse(const boost::system::error_code& error) {
-    if (error == boost::asio::error::operation_aborted) {
-#ifdef DEBUG_TRAVERSER
-        {
-            LogToCout toCoutAsWell;
-            LOG(Log::DBG, "NodeTreeTraverser::traverse Timer was cancelled");
-        }
-#endif
-        return;
-    }
-    else if (error) {
-        LogToCout toCoutAsWell;
-        std::string msg = "NodeTreeTraverser::traverse error: ";
-        msg += error.message();
-        ecf::log(Log::ERR, msg);
-        return;
-    }
-
-    do_traverse();
-}
-
-void NodeTreeTraverser::update_suite_calendar_and_traverse_node_tree(const boost::posix_time::ptime& time_now) {
-    // *****************************************************************************
-    // JOB SUBMISSION SEEMS TO WORK BEST IF THE CALENDAR INCREMENT HAPPENS FIRST
-    // HOWEVER THIS MEANS WE MAY MISS THE VERY FIRST JOB SUBMISSION. ??
-    // Note: events, meters and task completion kickoff another job submission
-    //       There seems to be greater stability in terms of testing as it allows
-    //       process to complete, before the calendar is incremented.
-    // *****************************************************************************
-
-    // This functions gets called every 60 seconds or so, update calendar && time
-    // dependent variables in case any jobs depend on them. By default, the calendar
-    // update interval is the same as submitJobsInterval for non-real calendars,
-    // however for testing both real/non-real calendars the calendar increment can be
-    // changed to speed up calendar. This is done by setting the calendar increment
-    // on the suite (i.e. via the defs file) which will _override_ this setting.
-    //
-    // Additionally, by passing in the flag running_, it allows suites which want to
-    // stop the calendar updates, when the server is stopped to do so.
-    // For real time calendars we make one system call here, instead of many times in each suite
-    //
-    // In the case where defs/node tree is suspended, updateCalendar will continue
-    // to mark those time dependencies that are free, as free.
-    // This information is then used during the resume.
-#ifdef DEBUG_TRAVERSER
-    ++count_;
-#endif
-    CalendarUpdateParams calParams(time_now, interval_ /* calendar increment */, running_);
-    server_->defs_->updateCalendar(calParams);
-
-    traverse_node_tree_and_job_generate(time_now, false /* not in command context */);
-}
-
-void NodeTreeTraverser::traverse_node_tree_and_job_generate(const boost::posix_time::ptime& start_time,
-                                                            bool user_cmd_context) const {
-    // **************************************************************************************
-    // This can be called at the end of a user command (force, alter, requeue, etc.).
-    // Hence, start_time may be >= poll_time.
-    //
-    // Note: for child command we just call increment_job_generation_count()
-    // **************************************************************************************
-
-    if (running_) {
-#ifdef DEBUG_JOB_SUBMISSION
-        jobsParam.logDebugMessage(" from NodeTreeTraverser::traverse_node_tree_and_job_generate()");
-#endif
-
-        // ** In the *NON* command context, we should always have start_time < next_poll_time_
-        if (user_cmd_context && start_time >= next_poll_time_) {
-            server_->increment_job_generation_count();
-            return;
-        }
-
-        server_->reset_job_generation_count();
-
-        // Pass submit jobs interval, so that we can check jobs submission occurs within the allocated time.
-        // By default, job generation is enabled.
-        // However, for testing, we allow job generation to be disabled.
-        JobsParam jobsParam(serverEnv_.submitJobsInterval(), serverEnv_.jobGeneration());
-
-        // If job generation takes longer than the time to *reach* next_poll_time_, then time out.
-        // Hence, we start out with 60 seconds, and time for job generation should decrease. Until reset back to 60
-        // Should allow greater child communication.
-        // By setting set_next_poll_time, we enable timeout of job generation.
-        // ** IMPLIES => next_poll_time_ must be set first, before *THIS* function is called **
-        // Note: There are other place where we may not want to timeout job generation.
-        jobsParam.set_next_poll_time(next_poll_time_);
-
-        Jobs jobs(server_->defs_);
-        if (!jobs.generate(jobsParam)) {
-            ecf::log(Log::ERR, jobsParam.getErrorMsg());
-        }
-        if (jobsParam.timed_out_of_job_generation()) {
-            // Implies we timed out, hence time_out_time >= next_poll_time_
-            const ptime& time_out_time = jobsParam.time_out_time();
-
-            // Timeout could occur because job generation started just a few seconds before the poll time.
-            // Excessive warnings are avoided by issuing warnings only if `time_out_time > next_poll_time_`.
-            // Notice: the following implementation considers 5 seconds of leeway.
-            if (!time_out_time.is_special() && time_out_time > next_poll_time_) {
-                const int leeway       = 5;
-                time_duration duration = time_out_time - next_poll_time_;
-                if (duration.total_seconds() >= leeway || serverEnv_.submitJobsInterval() != 60) {
-
-                    std::stringstream ss;
-                    ss << "Job generation *timed* out: start time:" << start_time << "  time_out_time:" << time_out_time
-                       << "  poll_time:" << next_poll_time_;
-                    ecf::log(Log::WAR, ss.str());
-                }
-            }
-        }
-    }
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/NodeTreeTraverser.hpp 5.13.0-1/Server/src/ecflow/server/NodeTreeTraverser.hpp
--- 5.12.4-1/Server/src/ecflow/server/NodeTreeTraverser.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/NodeTreeTraverser.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,90 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_NodeTreeTraverser_HPP
-#define ecflow_server_NodeTreeTraverser_HPP
-
-///
-/// \brief This class will traverse the node tree periodically, It is tied to a server.
-/// This implementation uses a strand to ensure sequential processing of the node dependency traversal
-/// in the presence of multiple threads, without the need of explicit locking. i.e mutex's
-///
-/// For testing we make the distinction between the poll period, and calendar update interval
-/// Some suites require a real time calendar. Hence we must make sure that
-/// poll interval is in sync with real time.
-///
-
-#include <boost/asio.hpp>
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-
-class BaseServer;
-class ServerEnvironment;
-// #define DEBUG_TRAVERSER 1
-
-class NodeTreeTraverser {
-public:
-    NodeTreeTraverser(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment& serverEnv);
-    // Disable copy (and move) semantics
-    NodeTreeTraverser(const NodeTreeTraverser&)                  = delete;
-    const NodeTreeTraverser& operator=(const NodeTreeTraverser&) = delete;
-
-    ~NodeTreeTraverser();
-
-    /// If first time Starts traversing Node tree and resolving dependencies.
-    /// This essentially starts Jobs scheduling. Calling start more than once does nothing.
-    /// On subsequent calls to start resume is called. Which may cause immediate
-    /// job generation. (i.e for those nodes whose node are free of time dependencies)
-    /// Timer will be aligned to the minute boundary
-    void start();
-
-    /// Suspends job scheduling (for real time calendars/suite)
-    /// Shutdown & suspend (are very similar) shutdown operate at the top/level.
-    /// Both should have effect of stopping job submission and not the event loop
-    ///
-    /// During a system session, a node can be placed into suspend mode.
-    /// In suspend mode, no jobs are submitted. (**** However node which are
-    /// free to run are marked****).
-    ///
-    /// When the session is resumed, those node than were marked, have
-    /// the task's submitted. ( This means that job dependent on a time dependency
-    /// does not need to be held for the following day)
-    void stop();
-
-    /// terminate: This will cancel the timer and any pending async operation
-    /// If timer has already expired, then the handler function will be
-    /// passed an operation aborted error code.
-    /// Called when the server is exiting. We must be sure to cancel all
-    /// async handlers or the server, will not stop.
-    void terminate();
-
-    /// This can be called at the end of a *USER* command(force,alter,requeue,etc), hence time_now may be >= poll_time
-    /// If this is the case, we will defer job generation
-    void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now, bool user_cmd_context) const;
-
-private:
-    void traverse(const boost::system::error_code& error);
-    void do_traverse();
-    void start_timer();
-    void update_suite_calendar_and_traverse_node_tree(const boost::posix_time::ptime& time_now);
-
-    BaseServer* server_;
-    const ServerEnvironment& serverEnv_;
-    boost::asio::deadline_timer timer_;
-    boost::posix_time::ptime last_time_;        // ensure poll is in sync
-    boost::posix_time::ptime next_poll_time_;   // Keep as sync as possible with hard real times
-    boost::posix_time::time_duration interval_; // Job submission interval
-#ifdef DEBUG_TRAVERSER
-    int count_;
-#endif
-    bool firstTime_;
-    bool running_;
-};
-
-#endif /* ecflow_server_NodeTreeTraverser_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/Server.cpp 5.13.0-1/Server/src/ecflow/server/Server.cpp
--- 5.12.4-1/Server/src/ecflow/server/Server.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/Server.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/Server.hpp"
-
-Server::Server(boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
-    : BaseServer(io_service, serverEnv),
-      tcp_server_(this, io_service, serverEnv) {
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/Server.hpp 5.13.0-1/Server/src/ecflow/server/Server.hpp
--- 5.12.4-1/Server/src/ecflow/server/Server.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/Server.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,27 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_Server_HPP
-#define ecflow_server_Server_HPP
-
-#include "ecflow/server/BaseServer.hpp"
-#include "ecflow/server/TcpServer.hpp"
-
-class Server : public BaseServer {
-public:
-    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
-    explicit Server(boost::asio::io_service& io_service, ServerEnvironment&);
-    ~Server() override = default;
-
-private:
-    TcpServer tcp_server_;
-};
-
-#endif /* ecflow_server_Server_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/ServerEnvironment.cpp 5.13.0-1/Server/src/ecflow/server/ServerEnvironment.cpp
--- 5.12.4-1/Server/src/ecflow/server/ServerEnvironment.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/ServerEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,833 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/ServerEnvironment.hpp"
-
-#include <cstdlib> // for getenv()
-#include <iostream>
-
-#include <boost/program_options.hpp>
-
-#include "ecflow/core/Calendar.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Pid.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/node/JobProfiler.hpp"
-#include "ecflow/node/System.hpp"
-#include "ecflow/server/ServerOptions.hpp"
-
-using namespace ecf;
-using namespace std;
-using namespace boost;
-namespace po = boost::program_options;
-
-static std::string the_check_mode(ecf::CheckPt::Mode mode) {
-    switch (mode) {
-        case ecf::CheckPt::NEVER:
-            return "CHECK_NEVER";
-            break;
-        case ecf::CheckPt::ON_TIME:
-            return "CHECK_ON_TIME";
-            break;
-        case ecf::CheckPt::ALWAYS:
-            return "CHECK_ALWAYS";
-            break;
-        case ecf::CheckPt::UNDEFINED:
-            return "UNDEFINED";
-            break;
-    }
-    cout << "ServerEnvironment.cpp theCheckMode: assert failed\n";
-    assert(false);
-    return std::string();
-}
-
-// This can be overridden by calling "server --ecfinterval 3" for test purposes
-const int defaultSubmitJobsInterval = 60;
-
-////////////////////////////////////////////////////////////////////////////////////////////
-// class ServerEnvironment:
-///////////////////////////////////////////////////////////////////////////////////////////
-
-ServerEnvironment::ServerEnvironment(int argc, char* argv[])
-    : serverHost_(host_name_.name()),
-      serverPort_(0),
-      checkPtInterval_(0),
-      checkpt_save_time_alarm_(CheckPt::default_save_time_alarm()),
-      submitJobsInterval_(defaultSubmitJobsInterval),
-      ecf_prune_node_log_(0),
-      jobGeneration_(true),
-      debug_(false),
-      help_option_(false),
-      version_option_(false),
-      checkMode_(ecf::CheckPt::ON_TIME),
-      tcp_protocol_(boost::asio::ip::tcp::v4()) {
-    Ecf::set_server(true);
-
-    init(argc, argv, "server_environment.cfg");
-    if (debug_)
-        std::cout << dump() << "\n";
-}
-
-// This is ONLY used in test
-ServerEnvironment::ServerEnvironment(int argc, char* argv[], const std::string& path_to_config_file)
-    : serverHost_(host_name_.name()),
-      serverPort_(0),
-      checkPtInterval_(0),
-      checkpt_save_time_alarm_(CheckPt::default_save_time_alarm()),
-      submitJobsInterval_(defaultSubmitJobsInterval),
-      ecf_prune_node_log_(0),
-      jobGeneration_(true),
-      debug_(false),
-      help_option_(false),
-      version_option_(false),
-      checkMode_(ecf::CheckPt::ON_TIME),
-      tcp_protocol_(boost::asio::ip::tcp::v4()) {
-    Ecf::set_server(true);
-
-    init(argc, argv, path_to_config_file);
-    if (debug_)
-        std::cout << dump() << "\n";
-}
-
-void ServerEnvironment::init(int argc, char* argv[], const std::string& path_to_config_file) {
-    std::string log_file_name;
-    try {
-        read_config_file(log_file_name, path_to_config_file);
-        read_environment_variables(log_file_name); // overrides any settings in the config file
-    }
-    catch (std::exception& e) {
-        std::string msg           = "Exception in ServerEnvironment::ServerEnvironment() : ";
-        std::string exception_msg = e.what();
-        // On ecgate, wrong locale, causes an exception where msg is empty
-        if (exception_msg.empty())
-            msg += "Invalid locale? Check locale using 'locale -a', then export/set LANG environment";
-        else
-            msg += e.what();
-        throw ServerEnvironmentException(msg);
-    }
-
-    // get server process id. This may be visualised in xecf. makes it easier to kill server
-    try {
-        ecf_pid_ = Pid::getpid();
-    }
-    catch (...) {
-        throw ServerEnvironmentException("ServerEnvironment::ServerEnvironment:: Could not convert PID to a string\n");
-    }
-    // std::cout << "PID = " << ecf_pid_ << "\n";
-
-    // The options(argc/argv) must be read after the environment, since they override everything else
-    ServerOptions options(argc, argv, this);
-    help_option_ = options.help_option();
-    if (help_option_)
-        return; // User is printing the help
-    version_option_ = options.version_option();
-    if (version_option_)
-        return; // User is printing the version
-
-    /// Config, Environment, or Options may have updated port, update port dependent file names
-    /// If we have default names make unique, by prefixing host and port
-    assert(!ecf_checkpt_file_.empty());        // expect name of form "ecf.check"
-    assert(!ecf_backup_checkpt_file_.empty()); // expect name of form "ecf.check.b"
-    assert(!log_file_name.empty());            // expect name of form "ecf.log"
-    assert(!ecf_white_list_file_.empty());     // expect name of form "ecf.lists"
-    assert(!ecf_passwd_file_.empty());         // expect name of form "ecf.passwd"
-    assert(!ecf_passwd_custom_file_.empty());  // expect name of form "ecf.custom_passwd"
-
-    std::string port = ecf::convert_to<std::string>(serverPort_);
-
-    // If path is absolute leave as is
-    if (ecf_checkpt_file_ == Ecf::CHECKPT())
-        ecf_checkpt_file_ = host_name_.prefix_host_and_port(port, ecf_checkpt_file_);
-    if (ecf_checkpt_file_[0] != '/') {
-        // Prepend with ECF_HOME
-        std::string check_pt = ecf_home();
-        check_pt += Str::PATH_SEPERATOR();
-        check_pt += ecf_checkpt_file_;
-        ecf_checkpt_file_ = check_pt;
-    }
-
-    // If path is absolute leave as is
-    if (ecf_backup_checkpt_file_ == Ecf::BACKUP_CHECKPT())
-        ecf_backup_checkpt_file_ = host_name_.prefix_host_and_port(port, ecf_backup_checkpt_file_);
-    if (ecf_backup_checkpt_file_[0] != '/') {
-        std::string check_pt = ecf_home();
-        check_pt += Str::PATH_SEPERATOR();
-        check_pt += ecf_backup_checkpt_file_;
-        ecf_backup_checkpt_file_ = check_pt;
-    }
-
-    if (ecf_white_list_file_ == Str::WHITE_LIST_FILE())
-        ecf_white_list_file_ = host_name_.prefix_host_and_port(port, ecf_white_list_file_);
-
-    if (ecf_passwd_file_ == Str::ECF_PASSWD())
-        ecf_passwd_file_ = host_name_.prefix_host_and_port(port, ecf_passwd_file_);
-
-    if (ecf_passwd_custom_file_ == Str::ECF_CUSTOM_PASSWD())
-        ecf_passwd_custom_file_ = host_name_.prefix_host_and_port(port, ecf_passwd_custom_file_);
-
-    // Change directory to ECF_HOME and check thats its accessible
-    change_dir_to_ecf_home_and_check_accesibility();
-
-    // LOG FILE ================================================================================
-    if (log_file_name == Ecf::LOG_FILE())
-        log_file_name = host_name_.prefix_host_and_port(port, log_file_name);
-
-    // Create the Log file. The log file is obtained from the environment. Hence **must** be done last.
-    // From ecflow version 4.9.0 we no longer flush for each command. This can enabled/disabled
-    Log::create(log_file_name);
-
-    // Init log file:
-    LOG(Log::MSG, ""); // previous log may not end in newline
-    LOG(Log::MSG, "Started at " << to_simple_string(Calendar::second_clock_time()) << " universal time");
-    if (tcp_protocol_.family() == 2 /*PF_INET*/)
-        LOG(Log::MSG, "Host(" << hostPort().first << ")  Port(" << hostPort().second << ") using TCP/IP v4");
-    else
-        LOG(Log::MSG, "Host(" << hostPort().first << ")  Port(" << hostPort().second << ") using TCP/IP v6");
-    LOG(Log::MSG, "ECF_HOME " << ecf_home());
-    LOG(Log::MSG, "Job scheduling interval: " << submitJobsInterval_);
-}
-
-ServerEnvironment::~ServerEnvironment() {
-    /// Destroy singleton to avoid valgrind from complaining
-    Log::destroy();
-    System::destroy();
-}
-
-bool ServerEnvironment::valid(std::string& errorMsg) const {
-    /// This must be called *AFTER* the constructor
-    //   cout << "*****************************************************************************\n";
-    //   cout << "ServerEnvironment::valid\n";
-    //   cout << "*****************************************************************************\n";
-
-    if (serverHost_.empty()) {
-        errorMsg = "Could not determine the server host.";
-        return false;
-    }
-    std::stringstream ss;
-    if (serverPort_ == 0 || serverPort_ <= 1023 || serverPort_ >= 49151) {
-
-        ss << "Server port " << serverPort_ << " not set correctly. \n";
-        ss << "The port numbers are divided into three ranges.\n";
-        ss << "   o the Well Known Ports, (require root permission)      0 -1023\n";
-        ss << "   o the Registered Ports,                             1024 -49151\n";
-        ss << "   o Dynamic and/or Private Ports.                    49151 -65535\n\n";
-        ss << "Please set in the range 1024-49151 via argument or \n";
-        ss << "Server/src/environment.cfg.h or set the environment variable ECF_PORT. \n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (ecfHome_.empty()) {
-        ss << "No ECF_HOME specified. Please set in Server/server_environment.cfg or\n";
-        ss << "set the environment variable ECF_HOME\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (!Log::instance() || Log::instance()->path().empty()) {
-        ss << "No log file name specified. Please set in Server/server_environment.cfg or\n";
-        ss << "set the environment variable ECF_LOG\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (checkPtInterval_ == 0) {
-        ss << "Checkpoint interval not set. Please set in Server/server_environment.cfg or\n";
-        ss << "set the environment variable ECF_CHECKINTERVAL. The value must be\n";
-        ss << "convertible to a integer\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (submitJobsInterval_ < 1 || submitJobsInterval_ > 60) {
-        ss << "Submit jobs interval not set correctly. Please set in Server/server_environment.cfg\n";
-        ss << "or provide as an argument. It must be in the range [1-60] \n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (ecf_prune_node_log_ < 0) {
-        ss << "ECF_PRUNE_NODE_LOG not set correctly. Please set in Server/server_environment.cfg\n";
-        ss << "or via environment variable of same name. It must be in the range [1-356] \n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (ecf_checkpt_file_.empty()) {
-        ss << "No checkpoint file name specified. Please set in Server/server_environment.cfg or\n";
-        ss << "set the environment variable ECF_CHECK\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (ecf_backup_checkpt_file_.empty()) {
-        ss << "No old checkpoint file name specified. Please set in Server/server_environment.cfg or\n";
-        ss << "set the environment variable ECF_CHECKOLD\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (checkMode_ == ecf::CheckPt::UNDEFINED) {
-        ss << "No ECF_CHECKMODE specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (ecf_cmd_.empty()) {
-        ss << "No ECF_JOB_CMD specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (killCmd_.empty()) {
-        ss << "No ECF_KILL_CMD specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (statusCmd_.empty()) {
-        ss << "No ECF_STATUS_CMD specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (checkCmd_.empty()) {
-        ss << "No ECF_CHECK_CMD specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (urlCmd_.empty()) {
-        ss << "No ECF_URL_CMD specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (urlBase_.empty()) {
-        ss << "No ECF_URL_BASE specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (url_.empty()) {
-        ss << "No ECF_URL specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-    if (ecf_micro_.empty()) {
-        ss << "No ECF_MICRODEF specified. Please set in Server/server_environment.cfg\n";
-        errorMsg = ss.str();
-        return false;
-    }
-
-    if (!ecf_passwd_file_.empty() && fs::exists(ecf_passwd_file_)) {
-        if (!passwd_file_.load(ecf_passwd_file_, debug(), errorMsg)) {
-            std::cout << "Error: could not parse ECF_PASSWD file " << ecf_passwd_file_ << "\n" << errorMsg << "\n";
-            return false;
-        }
-        if (!passwd_file_.check_at_least_one_user_with_host_and_port(serverHost_, the_port())) {
-            std::cout << "Error: password file " << ecf_passwd_file_;
-            std::cout << " does not contain any users, which match the host and port of this server\n";
-            return false;
-        }
-    }
-
-    if (!ecf_passwd_custom_file_.empty() && fs::exists(ecf_passwd_custom_file_)) {
-        if (!passwd_custom_file_.load(ecf_passwd_custom_file_, debug(), errorMsg)) {
-            std::cout << "Error: could not parse ECF_CUSTOM_PASSWD file " << ecf_passwd_custom_file_ << "\n"
-                      << errorMsg << "\n";
-            return false;
-        }
-        if (!passwd_custom_file_.check_at_least_one_user_with_host_and_port(serverHost_, the_port())) {
-            std::cout << "Error: custom password file " << ecf_passwd_custom_file_;
-            std::cout << " does not contain any users, which match the host and port of this server\n";
-            return false;
-        }
-    }
-
-    // If the white list file is empty or does not exist, *ON* server start, its perfectly valid
-    // i.e any user is free to access the server
-    if (ecf_white_list_file_.empty())
-        return true;
-    if (!fs::exists(ecf_white_list_file_))
-        return true;
-
-    /// read in the ecf white list file that specifies valid users and their access rights
-    /// If the file can't be opened returns false and an error message and false;
-    /// Automatically add server admin(user) with write access, as this will allow admin reload
-    return load_whitelist_file(errorMsg);
-}
-
-std::pair<std::string, std::string> ServerEnvironment::hostPort() const {
-    return std::make_pair(serverHost_, the_port());
-}
-
-std::string ServerEnvironment::the_port() const {
-    return ecf::convert_to<std::string>(serverPort_);
-}
-
-void ServerEnvironment::variables(std::vector<std::pair<std::string, std::string>>& theRetVec) const {
-    // Variables read in from the environment
-    // Need to setup client environment.
-    // The server sets these variable for use by the client. i.e when creating the jobs
-    // The clients then uses them to communicate back with the server.
-    theRetVec.emplace_back(Str::ECF_PORT(), the_port());
-    theRetVec.emplace_back(Str::ECF_HOST(), serverHost_);
-
-    theRetVec.emplace_back(Str::ECF_HOME(), ecfHome_);
-    theRetVec.emplace_back(std::string("ECF_LOG"), Log::instance()->path());
-    theRetVec.emplace_back(std::string("ECF_CHECK"), ecf_checkpt_file_);
-    theRetVec.emplace_back(std::string("ECF_CHECKOLD"), ecf_backup_checkpt_file_);
-    theRetVec.emplace_back(std::string("ECF_INTERVAL"), ecf::convert_to<std::string>(submitJobsInterval_));
-
-    // These variable are read in from the environment, but are not exposed
-    // since they only affect the server
-    // ECF_CHECKINTERVAL
-
-    theRetVec.emplace_back(std::string("ECF_LISTS"),
-                           ecf_white_list_file_); // read only variable, changing it has no effect
-    theRetVec.emplace_back(std::string("ECF_PASSWD"),
-                           ecf_passwd_file_); // read only variable, changing it has no effect
-    theRetVec.emplace_back(std::string("ECF_CUSTOM_PASSWD"),
-                           ecf_passwd_custom_file_); // read only variable, changing it has no effect
-
-    // variables that can be overridden, in the suite definition
-    theRetVec.emplace_back(std::string("ECF_JOB_CMD"), ecf_cmd_);
-    theRetVec.emplace_back(std::string("ECF_KILL_CMD"), killCmd_);
-    theRetVec.emplace_back(std::string("ECF_STATUS_CMD"), statusCmd_);
-    theRetVec.emplace_back(std::string("ECF_CHECK_CMD"), checkCmd_);
-    theRetVec.emplace_back(std::string("ECF_URL_CMD"), urlCmd_);
-    theRetVec.emplace_back(std::string("ECF_URL_BASE"), urlBase_);
-    theRetVec.emplace_back(std::string("ECF_URL"), url_);
-    theRetVec.emplace_back(std::string("ECF_MICRO"), ecf_micro_);
-
-    // Reference variable, these should be read only
-    theRetVec.emplace_back(std::string("ECF_PID"), ecf_pid_);           // server PID
-    theRetVec.emplace_back(std::string("ECF_VERSION"), Version::raw()); // server version
-
-#ifdef ECF_OPENSSL
-    if (ssl_.enabled()) {
-        theRetVec.emplace_back(
-            std::string("ECF_SSL"),
-            ssl_.ssl()); // 1 means shared ssl certificate, <host>.<port> means server specific certificates
-    }
-#endif
-}
-
-bool ServerEnvironment::reloadWhiteListFile(std::string& errorMsg) {
-    if (debug())
-        cout << "ServerEnvironment::reloadWhiteListFile:(" << ecf_white_list_file_ << ") CWD("
-             << fs::current_path().string() << ")\n";
-    if (ecf_white_list_file_.empty()) {
-        errorMsg += "The ECF_LISTS file ";
-        errorMsg += ecf_white_list_file_;
-        errorMsg += " has not been specified.";
-        return false;
-    }
-    if (!fs::exists(ecf_white_list_file_)) {
-        errorMsg += "The ECF_LISTS file ";
-        errorMsg += ecf_white_list_file_;
-        errorMsg += " does not exist. Server CWD : " + fs::current_path().string();
-        return false;
-    }
-
-    return load_whitelist_file(errorMsg);
-}
-
-bool ServerEnvironment::load_whitelist_file(std::string& errorMsg) const {
-    // Only override valid users if we successfully opened and parsed file
-    if (white_list_file_.load(ecf_white_list_file_, debug(), errorMsg)) {
-        // If user accidentally remove the server/user from white list,
-        // they will not be able reload white list, since it requires write access.
-        // (Requires terminate, modify white list, restart to fix)
-        // Hence always allow server user write access *IF* required for non empty file
-        white_list_file_.allow_write_access_for_server_user();
-        return true;
-    }
-    return false;
-}
-
-bool ServerEnvironment::reloadPasswdFile(std::string& errorMsg) {
-    if (debug())
-        cout << "ServerEnvironment::reloadPasswdFile:(" << ecf_passwd_file_ << ") CWD(" << fs::current_path().string()
-             << ")\n";
-    if (ecf_passwd_file_.empty()) {
-        errorMsg += "The ECF_PASSWD file ";
-        errorMsg += ecf_passwd_file_;
-        errorMsg += " has not been specified.";
-        return false;
-    }
-    if (!fs::exists(ecf_passwd_file_)) {
-        errorMsg += "The ECF_PASSWD file ";
-        errorMsg += ecf_passwd_file_;
-        errorMsg += " does not exist. Server CWD : " + fs::current_path().string();
-        return false;
-    }
-
-    // Only override valid users if we successfully opened and parsed file
-    return passwd_file_.load(ecf_passwd_file_, debug(), errorMsg);
-}
-
-bool ServerEnvironment::reloadCustomPasswdFile(std::string& errorMsg) {
-    if (debug())
-        cout << "ServerEnvironment::reloadPasswdFile:(" << ecf_passwd_custom_file_ << ") CWD("
-             << fs::current_path().string() << ")\n";
-    if (ecf_passwd_custom_file_.empty()) {
-        errorMsg += "The ECF_CUSTOM_PASSWD file ";
-        errorMsg += ecf_passwd_custom_file_;
-        errorMsg += " has not been specified.";
-        return false;
-    }
-    if (!fs::exists(ecf_passwd_custom_file_)) {
-        errorMsg += "The ECF_CUSTOM_PASSWD file ";
-        errorMsg += ecf_passwd_custom_file_;
-        errorMsg += " does not exist. Server CWD : " + fs::current_path().string();
-        return false;
-    }
-
-    // Only override valid users if we successfully opened and parsed file
-    return passwd_custom_file_.load(ecf_passwd_custom_file_, debug(), errorMsg);
-}
-
-bool ServerEnvironment::authenticateReadAccess(const std::string& user,
-                                               bool custom_user,
-                                               const std::string& passwd) const {
-    if (!custom_user) {
-        if (!passwd_file_.authenticate(user, passwd))
-            return false;
-    }
-    else {
-        if (!passwd_custom_file_.authenticate(user, passwd))
-            return false;
-    }
-
-    // if *NO* users specified then all users are valid
-    return white_list_file_.verify_read_access(user);
-}
-
-bool ServerEnvironment::authenticateReadAccess(const std::string& user,
-                                               bool custom_user,
-                                               const std::string& passwd,
-                                               const std::string& path) const {
-    if (!custom_user) {
-        if (!passwd_file_.authenticate(user, passwd))
-            return false;
-    }
-    else {
-        if (!passwd_custom_file_.authenticate(user, passwd))
-            return false;
-    }
-
-    return white_list_file_.verify_read_access(user, path);
-}
-
-bool ServerEnvironment::authenticateReadAccess(const std::string& user,
-                                               bool custom_user,
-                                               const std::string& passwd,
-                                               const std::vector<std::string>& paths) const {
-    if (!custom_user) {
-        if (!passwd_file_.authenticate(user, passwd))
-            return false;
-    }
-    else {
-        if (!passwd_custom_file_.authenticate(user, passwd))
-            return false;
-    }
-
-    return white_list_file_.verify_read_access(user, paths);
-}
-
-bool ServerEnvironment::authenticateWriteAccess(const std::string& user) const {
-    // if *NO* users specified then all users have write access
-    return white_list_file_.verify_write_access(user);
-}
-bool ServerEnvironment::authenticateWriteAccess(const std::string& user, const std::string& path) const {
-    return white_list_file_.verify_write_access(user, path);
-}
-bool ServerEnvironment::authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) const {
-    return white_list_file_.verify_write_access(user, paths);
-}
-
-// ============================================================================================
-// Privates:
-// ============================================================================================
-
-void ServerEnvironment::read_config_file(std::string& log_file_name, const std::string& path_to_config_file) {
-    if (debug())
-        cout << "ServerEnvironment::read_config_file() current_path = " << fs::current_path() << "\n";
-
-    try {
-        std::string theCheckMode;
-        int the_task_threshold = 0;
-
-        // read the environment from the config file.
-        // **** Port *must* be read before log file, and check pt files
-        po::options_description config_file_options("Configuration");
-        config_file_options.add_options()(
-            "ECF_HOME", po::value<std::string>(&ecfHome_)->default_value("."), "ECF_HOME, the home for all ECF files")(
-            "ECF_PORT",
-            po::value<int>(&serverPort_)->default_value(3141),
-            "The port number. Clients must use same port.")(
-            "ECF_CHECK",
-            po::value<std::string>(&ecf_checkpt_file_)->default_value(Ecf::CHECKPT()),
-            "Check point file name")(
-            "ECF_CHECKOLD",
-            po::value<std::string>(&ecf_backup_checkpt_file_)->default_value(Ecf::BACKUP_CHECKPT()),
-            "Backup checkpoint file name")(
-            "ECF_LOG", po::value<std::string>(&log_file_name)->default_value(Ecf::LOG_FILE()), "Log file name")(
-            "ECF_CHECKINTERVAL",
-            po::value<int>(&checkPtInterval_)->default_value(CheckPt::default_interval()),
-            "The interval in seconds to save check point file")(
-            "ECF_INTERVAL",
-            po::value<int>(&submitJobsInterval_)->default_value(defaultSubmitJobsInterval),
-            "Check time dependencies and submit any jobs")(
-            "ECF_CHECKMODE",
-            po::value<std::string>(&theCheckMode),
-            "The check mode, must be one of CHECK_NEVER, CHECK_ON_TIME, CHECK_ALWAYS")(
-            "ECF_JOB_CMD",
-            po::value<std::string>(&ecf_cmd_)->default_value(Ecf::JOB_CMD()),
-            "Command to be executed to submit a job.")(
-            "ECF_KILL_CMD",
-            po::value<std::string>(&killCmd_)->default_value(Ecf::KILL_CMD()),
-            "Command to be executed to kill a job.")(
-            "ECF_STATUS_CMD",
-            po::value<std::string>(&statusCmd_)->default_value(Ecf::STATUS_CMD()),
-            "Command to be obtain the job status from server.")(
-            "ECF_CHECK_CMD",
-            po::value<std::string>(&checkCmd_)->default_value(Ecf::CHECK_CMD()),
-            "Command to be obtain the job status from client.")(
-            "ECF_URL_CMD",
-            po::value<std::string>(&urlCmd_)->default_value(Ecf::URL_CMD()),
-            "Command to be obtain url.")(
-            "ECF_URL_BASE", po::value<std::string>(&urlBase_)->default_value(Ecf::URL_BASE()), "Defines url base.")(
-            "ECF_URL", po::value<std::string>(&url_)->default_value(Ecf::URL()), "The default url.")(
-            "ECF_MICRODEF",
-            po::value<std::string>(&ecf_micro_)->default_value(Ecf::MICRO()),
-            "Preprocessor character for variable substitution and including files")(
-            "ECF_LISTS",
-            po::value<std::string>(&ecf_white_list_file_)->default_value(Str::WHITE_LIST_FILE()),
-            "Path name to file the list valid users and their access rights")(
-            "ECF_PASSWD",
-            po::value<std::string>(&ecf_passwd_file_)->default_value(Str::ECF_PASSWD()),
-            "Path name to passwd file")(
-            "ECF_CUSTOM_PASSWD",
-            po::value<std::string>(&ecf_passwd_custom_file_)->default_value(Str::ECF_CUSTOM_PASSWD()),
-            "Path name to custom passwd file, for user who don't use login name")(
-            "ECF_TASK_THRESHOLD",
-            po::value<int>(&the_task_threshold)->default_value(JobProfiler::task_threshold_default()),
-            "The defaults thresholds when profiling job generation")(
-            "ECF_PRUNE_NODE_LOG",
-            po::value<int>(&ecf_prune_node_log_)->default_value(30),
-            "Node log, older than 180 days automatically pruned when checkpoint file loaded");
-
-        ifstream ifs(path_to_config_file.c_str());
-        if (!ifs) {
-            if (debug())
-                cout << "Could not load server_environment.cfg " << path_to_config_file << "\n";
-        }
-
-        /// This is *NOT* redundant, when the file is empty/not present, then the default value
-        /// defined above are set.
-        po::variables_map vm;
-        po::store(parse_config_file(ifs, config_file_options), vm);
-        po::notify(vm);
-
-        if (theCheckMode == "CHECK_ON_TIME")
-            checkMode_ = ecf::CheckPt::ON_TIME;
-        else if (theCheckMode == "CHECK_NEVER")
-            checkMode_ = ecf::CheckPt::NEVER;
-        else if (theCheckMode == "CHECK_ALWAYS")
-            checkMode_ = ecf::CheckPt::ALWAYS;
-
-        if (the_task_threshold != 0) {
-            JobProfiler::set_task_threshold(the_task_threshold);
-        }
-    }
-    catch (std::exception& e) {
-        cerr << "ServerEnvironment::read_config_file() " << e.what() << "\n";
-    }
-}
-
-void ServerEnvironment::read_environment_variables(std::string& log_file_name) {
-    if (debug())
-        cout << "ServerEnvironment::read_environment_variables()\n";
-
-    char* serverPort = getenv(Str::ECF_PORT().c_str());
-    if (serverPort) {
-        std::string port = serverPort;
-        try {
-            serverPort_ = ecf::convert_to<int>(port);
-        }
-        catch (const ecf::bad_conversion&) {
-            std::stringstream ss;
-            ss << "ServerEnvironment::read_environment_variables(): ECF_PORT is defined(" << port
-               << ") but value is *not* convertible to an integer\n";
-            throw ServerEnvironmentException(ss.str());
-        }
-    }
-    char* checkPtInterval = getenv("ECF_CHECKINTERVAL");
-    if (checkPtInterval) {
-        std::string interval = checkPtInterval;
-        try {
-            checkPtInterval_ = ecf::convert_to<int>(interval);
-        }
-        catch (const ecf::bad_conversion&) {
-            std::stringstream ss;
-            ss << "ServerEnvironment::read_environment_variables(): ECF_CHECKINTERVAL is defined(" << interval
-               << ") but value is *not* convertible to an integer\n";
-            throw ServerEnvironmentException(ss.str());
-        }
-    }
-
-    char* ecfHome = getenv(Str::ECF_HOME().c_str());
-    if (ecfHome)
-        ecfHome_ = ecfHome;
-    if (ecfHome_ == ".") { // expand to absolute paths
-        ecfHome_ = fs::current_path().string();
-    }
-
-    char* logFileName = getenv("ECF_LOG");
-    if (logFileName)
-        log_file_name = logFileName;
-
-    char* checkPtFileName = getenv("ECF_CHECK");
-    if (checkPtFileName)
-        ecf_checkpt_file_ = checkPtFileName;
-
-    char* oldCheckPtFileName = getenv("ECF_CHECKOLD");
-    if (oldCheckPtFileName)
-        ecf_backup_checkpt_file_ = oldCheckPtFileName;
-
-    char* smsWhiteListFile = getenv("ECF_LISTS");
-    if (smsWhiteListFile)
-        ecf_white_list_file_ = smsWhiteListFile;
-
-    char* passwd = getenv("ECF_PASSWD");
-    if (passwd)
-        ecf_passwd_file_ = passwd;
-
-    char* custom_passwd = getenv("ECF_CUSTOM_PASSWD");
-    if (custom_passwd)
-        ecf_passwd_custom_file_ = custom_passwd;
-
-    char* ecf_prune_node_log = getenv("ECF_PRUNE_NODE_LOG");
-    if (ecf_prune_node_log) {
-        try {
-            ecf_prune_node_log_ = ecf::convert_to<int>(ecf_prune_node_log);
-        }
-        catch (const ecf::bad_conversion&) {
-            std::stringstream ss;
-            ss << "ServerEnviroment::read_environment_variables: ECF_PRUNE_NODE_LOG must be convertible to an integer, "
-                  "But found: "
-               << ecf_prune_node_log;
-            throw ServerEnvironmentException(ss.str());
-        }
-    }
-
-    if (getenv("ECF_DEBUG_SERVER")) {
-        debug_ = true; // can also be enabled via --debug option
-    }
-
-#ifdef ECF_OPENSSL
-    // IF ECF_SSL= 1 search server.crt
-    // ELSE          search <host>.<port>.crt
-    ssl_.enable_if_defined(serverHost_, the_port());
-#endif
-
-    char* threshold = getenv("ECF_TASK_THRESHOLD");
-    if (threshold) {
-        std::string task_threshold = threshold;
-        try {
-            JobProfiler::set_task_threshold(ecf::convert_to<int>(task_threshold));
-        }
-        catch (...) {
-            std::stringstream ss;
-            ss << "ServerEnvironment::read_environment_variables(): ECF_TASK_THRESHOLD is defined(" << threshold
-               << ") but value is *not* convertible to an integer\n";
-            throw ServerEnvironmentException(ss.str());
-        }
-    }
-}
-
-void ServerEnvironment::change_dir_to_ecf_home_and_check_accesibility() {
-    if (chdir(ecfHome_.c_str()) != 0) {
-        std::stringstream ss;
-        ss << "Can't chdir to ECF_HOME " << ecfHome_ << "\n";
-        throw ServerEnvironmentException(ss.str());
-    }
-    if (access(ecfHome_.c_str(), X_OK | R_OK | W_OK) != 0) {
-        // R_OK test for read permission
-        // W_OK test for write permission
-        // X_OK test for execute or search permission
-        // F_OK  test whether the directories leading to the file can be searched and the file exists.
-        std::stringstream ss;
-        ss << "Access restriction on ECF_HOME " << ecfHome_ << "\n";
-        throw ServerEnvironmentException(ss.str());
-    }
-}
-
-std::string ServerEnvironment::check_mode_str() const {
-    return the_check_mode(checkMode_);
-}
-
-std::string ServerEnvironment::dump() const {
-    std::stringstream ss;
-    ss << "ECF_HOME = '" << ecfHome_ << "'\n";
-    ss << "ECF_LOG = '" << Log::instance()->path() << "'\n";
-    ss << "ECF_PORT = '" << serverPort_ << "'\n";
-    ss << "ECF_CHECK = '" << ecf_checkpt_file_ << "'\n";
-    ss << "ECF_CHECKOLD = '" << ecf_backup_checkpt_file_ << "'\n";
-    ss << "ECF_CHECKINTERVAL = '" << checkPtInterval_ << "'\n";
-    ss << "ECF_INTERVAL = '" << submitJobsInterval_ << "'\n";
-    ss << "ECF_CHECKMODE = '" << the_check_mode(checkMode_) << "'\n";
-    ss << "ECF_JOB_CMD = '" << ecf_cmd_ << "'\n";
-    ss << "ECF_KILL_CMD = '" << killCmd_ << "'\n";
-    ss << "ECF_STATUS_CMD = '" << statusCmd_ << "'\n";
-    ss << "ECF_CHECK_CMD = '" << checkCmd_ << "'\n";
-    ss << "ECF_URL_CMD = '" << urlCmd_ << "'\n";
-    ss << "ECF_URL_BASE = '" << urlBase_ << "'\n";
-    ss << "ECF_URL = '" << url_ << "'\n";
-    ss << "ECF_MICRO = '" << ecf_micro_ << "'\n";
-    ss << "ECF_PRUNE_NODE_LOG = '" << ecf_prune_node_log_ << "'\n";
-    ss << "check pt save time alarm " << checkpt_save_time_alarm_ << "\n";
-    ss << "Job generation " << jobGeneration_ << "\n";
-    ss << "Server host name " << serverHost_ << "\n";
-    ss << "ECF_PASSWD = " << ecf_passwd_file_ << "\n";
-    ss << "ECF_CUSTOM_PASSWD = " << ecf_passwd_custom_file_ << "\n";
-    if (tcp_protocol_.family() == 2 /*PF_INET*/)
-        ss << "TCP Protocol  v4 \n";
-    else if (tcp_protocol_.family() == 10 /*PF_INET6*/)
-        ss << "TCP Protocol  v6 \n";
-
-#ifdef ECF_OPENSSL
-    ss << "ECF_SSL = " << ssl_ << "\n";
-#endif
-
-    ss << white_list_file_.dump_valid_users();
-    return ss.str();
-}
-
-std::vector<std::string> ServerEnvironment::expected_variables() {
-    std::vector<std::string> expected_variables;
-    expected_variables.push_back(Str::ECF_HOME());
-    expected_variables.emplace_back("ECF_LOG");
-    expected_variables.emplace_back("ECF_CHECK");
-    expected_variables.emplace_back("ECF_CHECKOLD");
-    expected_variables.emplace_back("ECF_JOB_CMD");
-    expected_variables.emplace_back("ECF_KILL_CMD");
-    expected_variables.emplace_back("ECF_STATUS_CMD");
-    expected_variables.emplace_back("ECF_CHECK_CMD");
-    expected_variables.emplace_back("ECF_URL_CMD");
-    expected_variables.emplace_back("ECF_URL_BASE");
-    expected_variables.emplace_back("ECF_URL");
-    expected_variables.emplace_back("ECF_MICRO");
-    expected_variables.emplace_back("ECF_PID");
-    expected_variables.emplace_back("ECF_VERSION");
-    expected_variables.emplace_back("ECF_LISTS");
-    expected_variables.push_back(Str::ECF_PORT());
-    expected_variables.push_back(Str::ECF_HOST());
-    expected_variables.emplace_back("ECF_INTERVAL");
-    expected_variables.emplace_back("ECF_PASSWD");
-    expected_variables.emplace_back("ECF_CUSTOM_PASSWD");
-#ifdef ECF_OPENSSL
-    if (getenv("ECF_SSL"))
-        expected_variables.emplace_back("ECF_SSL");
-#endif
-    return expected_variables;
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/ServerEnvironment.hpp 5.13.0-1/Server/src/ecflow/server/ServerEnvironment.hpp
--- 5.12.4-1/Server/src/ecflow/server/ServerEnvironment.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/ServerEnvironment.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,243 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_ServerEnvironment_HPP
-#define ecflow_server_ServerEnvironment_HPP
-
-///
-/// \brief The server environment is read from the configuration file. This defines
-/// the defaults for the server,and is configurable by the user, at run time
-/// Alternatively some variable can be set via environment. See environment.cfg
-///
-/// The server must be created before the log file. Since the log is initialised
-/// with the log file name from the server environment
-///
-
-#include <string>
-#include <vector>
-
-#include <boost/asio.hpp>
-
-#include "ecflow/core/CheckPt.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/PasswdFile.hpp"
-#include "ecflow/core/WhiteListFile.hpp"
-
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/Openssl.hpp"
-#endif
-
-// Added ServerEvinronmentException so that it can be in the same scope as server
-// in ServerMain. Previously we had a separate try block
-// Also distinguish between server and environment errors
-class ServerEnvironmentException : public std::runtime_error {
-public:
-    explicit ServerEnvironmentException(const std::string& msg) : std::runtime_error(msg) {}
-};
-
-class ServerEnvironment {
-public:
-    ServerEnvironment(int argc, char* argv[]);
-    ServerEnvironment(int argc, char* argv[], const std::string& path_to_config_file); // *only used in test*
-    // Disable copy (and move) semantics
-    ServerEnvironment(const ServerEnvironment&)                  = delete;
-    const ServerEnvironment& operator=(const ServerEnvironment&) = delete;
-
-    ~ServerEnvironment();
-
-    /// return true if option are valid false and error message otherwise
-    bool valid(std::string& errorMsg) const;
-
-    /// return the directory path associated with smshome
-    /// but can be overridden by the environment variable ECF_HOME
-    std::string ecf_home() const { return ecfHome_; }
-
-    /// returns the server host and port
-    std::pair<std::string, std::string> hostPort() const;
-
-#ifdef ECF_OPENSSL
-    /// return true if ssl enable via command line, AND SSL libraries are found
-    ecf::Openssl& openssl() { return ssl_; }
-    bool ssl() const { return ssl_.enabled(); }
-    void enable_ssl() { ssl_.enable(serverHost_, the_port()); } // search server.crt first, then <host>.<port>.crt
-#endif
-
-    /// returns the server port. This has a default value defined in server_environment.cfg
-    /// but can be overridden by the environment variable ECF_PORT
-    int port() const { return serverPort_; }
-    std::string the_port() const;
-
-    /// returns the TCP protocol. default is TCPv4. Can be changed via command line to TCPv6
-    boost::asio::ip::tcp tcp_protocol() const { return tcp_protocol_; }
-
-    /// Return true if job generation is enabled. By default job generation is enabled however
-    /// for test/debug we can elect to disable, it.
-    bool jobGeneration() const { return jobGeneration_; }
-
-    /// Whenever we save the checkpt, we time how long this takes.
-    /// For very large definition the time can be significant and start to interfere with
-    /// the scheduling. (i.e since write to disk is blocking).
-    /// The default is defined by CheckPt::default_save_time_alarm(). When the save time exceeds this, the late flag is
-    /// set on the definition. This needs to be manually reset.
-    size_t checkpt_save_time_alarm() const { return checkpt_save_time_alarm_; }
-    void set_checkpt_save_time_alarm(size_t t) { checkpt_save_time_alarm_ = t; }
-
-    /// returns the path of the checkpoint file. This has a default name set in server_environment.cfg
-    /// but can be overridden by the environment variable ECF_CHECK
-    /// if the check point file starts with an absolute path return as is:
-    /// otherwise returns ECF_HOME/ecf_checkpt_file_
-    const std::string& checkPtFilename() const { return ecf_checkpt_file_; }
-
-    /// returns the path of the old checkPointFile. This has a default name set in server_environment.cfg
-    /// but can be overridden by the environment variable ECF_CHECKOLD
-    /// if the check point file starts with an absolute path return as is:
-    /// otherwise returns ECF_HOME/ecf_backup_checkpt_file_
-    const std::string& oldCheckPtFilename() const { return ecf_backup_checkpt_file_; }
-
-    /// returns the checkPt interval. This is the time in seconds, at which point the server
-    /// serializes the defs node tree. This is called the check point file.
-    /// This has a default value set in environment.cfg
-    /// but can be overridden by the environment variable ECF_CHECKINTERVAL
-    /// if set via environment variable it must be convertible to an integer
-    int checkPtInterval() const { return checkPtInterval_; }
-
-    /// set the check point interval. Typically set via client interface
-    /// value should > 0 for valid values.
-    void set_checkpt_interval(int v) {
-        if (v > 0)
-            checkPtInterval_ = v;
-    }
-
-    /// returns the check mode. This specifies options for saving of the checkPoint file:
-    ecf::CheckPt::Mode checkMode() const { return checkMode_; }
-    void set_check_mode(ecf::CheckPt::Mode m) { checkMode_ = m; }
-    std::string check_mode_str() const;
-
-    /// returns the number of seconds at which we should check time dependencies
-    /// this includes evaluating trigger dependencies and submit the corresponding jobs.
-    /// This is set at 60 seconds. But will vary for debug/test purposes only.
-    /// For Testing the state change queued->submitted->active duration < submitJobsInterval
-    /// If this state change happens at the job submission boundary then
-    /// time series can get a skew.
-    int submitJobsInterval() const { return submitJobsInterval_; }
-
-    /// Returns ECF_PRUNE_NODE_LOG as an integer representing days
-    /// Node log/edit history older than this is pruned when loading the checkpoint file
-    /// Default value is 30 days. To alter change config file or set an environment variable.
-    /// A value of 0, means no pruning. i.e keep old edit history .
-    int ecf_prune_node_log() const { return ecf_prune_node_log_; }
-
-    /// returns server variables, as vector of pairs.
-    /// Some of these variables hold environment variables
-    /// Note:: additional variable are created for use by clients, i.e like
-    ///        ECF_PORT(jobs, server, client)
-    ///        ECF_HOST(jobs).   ECF_HOST is the server machine host name
-    void variables(std::vector<std::pair<std::string, std::string>>&) const;
-
-    /// Ask the server to reload file the hold list of users and their access rights
-    /// The white list file is specified by the environment variable ECF_LISTS
-    /// This allows/disallows user access on the live server
-    /// Return true if file is reloaded ok, else false and error message if:
-    /// 	a/ File does not exist
-    ///  	b/ File is empty
-    ///  	c/ Errors in parsing file
-    /// If errors arise the exist user still stay in affect
-    bool reloadWhiteListFile(std::string& errorMsg);
-
-    bool reloadPasswdFile(std::string& errorMsg);
-    bool reloadCustomPasswdFile(std::string& errorMsg);
-
-    /// There are several kinds of authentification:
-    ///     a/ None
-    ///     b/ List mode.   ASCII file based on ECF_LISTS is defined
-    ///     c/ Secure mode. binary file based ECF_PASSWD is defined
-    /// At the moment we will only implement options a/ and b/
-    //
-    /// Returns true if the given user has access to the server, false otherwise
-    bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) const;
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::string& path) const;
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::vector<std::string>& paths) const;
-    bool authenticateWriteAccess(const std::string& user) const;
-    bool authenticateWriteAccess(const std::string& user, const std::string& path) const;
-    bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) const;
-
-    /// return true if help option was selected
-    bool help_option() const { return help_option_; }
-    bool version_option() const { return version_option_; }
-
-    /// debug is enabled via --debug or server invocation
-    bool debug() const { return debug_; }
-    void set_debug(bool f) { debug_ = f; }
-
-    std::string dump() const;
-
-    static std::vector<std::string> expected_variables();
-
-private:
-    void init(int argc, char* argv[], const std::string& path_to_config_file);
-
-    ///  defaults are read from a config file
-    void read_config_file(std::string& log_file_name, const std::string& path_to_config_file);
-
-    /// Get the standard environment variables, overwrite any settings from config file
-    void read_environment_variables(std::string& log_file_name);
-
-    void change_dir_to_ecf_home_and_check_accesibility();
-
-    bool load_whitelist_file(std::string& err) const;
-
-private:
-    ecf::Host host_name_;
-    std::string serverHost_; // must be after host_name_, since used in init
-    int serverPort_;
-    int checkPtInterval_;
-    int checkpt_save_time_alarm_;
-    int submitJobsInterval_;
-    int ecf_prune_node_log_;
-    bool jobGeneration_; // used in debug/test mode only
-    bool debug_;
-    bool help_option_;
-    bool version_option_;
-    ecf::CheckPt::Mode checkMode_;
-    std::string ecfHome_;
-    std::string ecf_checkpt_file_;
-    std::string ecf_backup_checkpt_file_;
-    std::string ecf_pid_;
-    std::string killCmd_;
-    std::string statusCmd_;
-    std::string checkCmd_;
-    std::string urlCmd_;
-    std::string urlBase_;
-    std::string url_;
-    std::string ecf_cmd_;
-    std::string ecf_micro_;
-    std::string ecf_white_list_file_;
-    mutable WhiteListFile white_list_file_;
-
-    std::string ecf_passwd_file_;
-    std::string ecf_passwd_custom_file_;
-    mutable PasswdFile passwd_file_;
-    mutable PasswdFile passwd_custom_file_;
-
-#ifdef ECF_OPENSSL
-    ecf::Openssl ssl_;
-#endif
-
-    boost::asio::ip::tcp tcp_protocol_; // defaults to IPv4 TCP protocol
-    friend class ServerOptions;
-};
-
-#endif /* ecflow_server_ServerEnvironment_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/ServerMain.cpp 5.13.0-1/Server/src/ecflow/server/ServerMain.cpp
--- 5.12.4-1/Server/src/ecflow/server/ServerMain.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/ServerMain.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,110 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/server/Server.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-#ifdef ECF_OPENSSL
-    #include "ecflow/server/SslServer.hpp"
-#endif
-
-using namespace ecf;
-using namespace std;
-
-///
-/// \brief The Server entrypoint
-///
-
-int run_server(boost::asio::io_service& io_service, const ServerEnvironment& server_environment) {
-    for (;;) {
-        try {
-            /// Start the server
-            /// The io_service::run() call will block until all asynchronous operations
-            /// have finished. While the server is running, there is always at least one
-            /// asynchronous operation outstanding: the asynchronous accept call waiting
-            /// for new incoming connections.
-            io_service.run();
-            if (server_environment.debug())
-                cout << "Normal exit from server\n";
-            break;
-        }
-        catch (std::exception& e) {
-            // deal with errors from the handlers
-            std::string msg = "run_server:: ";
-            msg += e.what();
-            std::cerr << msg << endl;
-            ecf::log(Log::ERR, msg);
-        }
-        if (server_environment.debug())
-            cout << "Server EXITING: <------------------------------------------------ port:"
-                 << server_environment.port() << endl;
-    }
-    return 0;
-}
-
-int main(int argc, char* argv[]) {
-
-    try {
-        // Get the environment settings, and parse argument line and init the log file
-        ServerEnvironment server_environment(argc, argv); // This can throw ServerEnvironmentException
-        if (server_environment.help_option())
-            return 0;
-        if (server_environment.version_option())
-            return 0;
-        std::string errorMsg;
-        if (!server_environment.valid(errorMsg)) {
-            cerr << errorMsg;
-            ecf::log(Log::ERR, errorMsg);
-            return 1;
-        }
-
-        if (server_environment.debug())
-            cout << "Server started: ------------------------------------------------>port:"
-                 << server_environment.port() << endl;
-
-        boost::asio::io_service io_service;
-#ifdef ECF_OPENSSL
-        if (server_environment.ssl()) {
-            SslServer theServer(io_service, server_environment); // This can throw exception, bind address in use.
-            return run_server(io_service, server_environment);
-        }
-        else {
-            Server theServer(io_service, server_environment); // This can throw exception, bind address in use.
-            return run_server(io_service, server_environment);
-        }
-#else
-        Server theServer(io_service, server_environment); // This can throw exception, bind address in use.
-        return run_server(io_service, server_environment);
-#endif
-    }
-    catch (ServerEnvironmentException& e) {
-        // *** deal with server options and environment exceptions
-        std::cerr << "Could not load the server environment or options :\n" << e.what() << "\n";
-        std::cerr << "Invalid locale? Check locale using 'locale -a', then export/set LANG environment\n";
-    }
-    catch (std::exception& e) {
-        // *** deal with errors from the server constructor ****
-        std::string msg = "Exception in ServerMain:: ";
-        msg += e.what();
-        std::cerr << msg << endl;
-        ecf::log(Log::ERR, msg);
-
-        // dump server environment
-        cerr << "\nServer environment:\n";
-        ServerEnvironment server_env(argc, argv); // This can throw ServerEnvironmentException
-        std::cerr << server_env.dump();
-    }
-    catch (...) {
-        std::string msg = "ServerMain:: unknown exception";
-        std::cerr << msg << endl;
-        ecf::log(Log::ERR, msg);
-    }
-    return 1;
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/ServerOptions.cpp 5.13.0-1/Server/src/ecflow/server/ServerOptions.cpp
--- 5.12.4-1/Server/src/ecflow/server/ServerOptions.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/ServerOptions.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,179 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/ServerOptions.hpp"
-
-#include <iostream>
-
-#include "ecflow/core/Version.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-#ifdef ECF_OPENSSL
-    #include "ecflow/base/Openssl.hpp"
-#endif
-
-using namespace std;
-using namespace ecf;
-namespace po = boost::program_options;
-
-ServerOptions::ServerOptions(int argc, char* argv[], ServerEnvironment* env) {
-    std::stringstream ss;
-    ss << "\n" << Version::description() << "\nServer options";
-    po::options_description desc(ss.str(), po::options_description::m_default_line_length + 80);
-
-    desc.add_options()("help,h",
-                       "The server reads the LANG for the locale. Please ensure that\n"
-                       "locale is valid otherwise the server will abort on startup.\n"
-                       "For a list of valid locale use 'locale -a'.\n"
-                       "\n"
-                       "The server will read the following environment variables:\n"
-                       "ECF_PORT:\n"
-                       "  Defines the port that the server will listen to.\n"
-                       "  The port number must be consistent between client and server\n"
-                       "  If two servers are started on the same machine with same port\n"
-                       "  then a 'Address in use' error is shown and server will exit.\n"
-                       "  The default value for client/server is 3141\n"
-                       "ECF_HOME:\n"
-                       "  This is the home/root for all '.ecf' scripts.\n"
-                       "  When the server starts it will change directory to ECF_HOME,\n"
-                       "  hence the directory must be accessible and writable.\n"
-                       "  The default value is the current working directory\n"
-                       "ECF_LOG:\n"
-                       "  Overrides the name of log file.\n"
-                       "  The default log file name is: <host>.<port>.ecf.log, i.e. machine1.3141.ecf.log\n"
-                       "  this is required since we can have multiple servers for a single machine.\n"
-                       "  Where each server will have a separate port number.\n"
-                       "  Note: Any settings will be prepended with <host>.<port>.\n"
-                       "ECF_CHECK:\n"
-                       "  Defines the name of the check point file.\n"
-                       "  This stores the state of the definition in memory,\n"
-                       "  and allows recovery from crash. By default the server on start up will load\n"
-                       "  the check point file or back up check point file if they exist.\n"
-                       "  The default is <host>.<port>.ecf.check\n"
-                       "  Any settings will be prepended with <host>.<port>.\n"
-                       "ECF_CHECKOLD:\n"
-                       "  The name of the backup checkpoint file\n"
-                       "  default is <host>.<port>.ecf.check.b\n"
-                       "  Any settings will be prepended with <host>.<port>.\n"
-                       "ECF_CHECKINTERVAL:\n"
-                       "  The interval in seconds within the server that the checkpoint file is saved\n"
-                       "  Values less than 60 seconds are not recommended\n"
-                       "  The default value is 120 seconds\n"
-                       "ECF_LISTS:\n"
-                       "  This variable is used to identify a file, that lists the user\n"
-                       "  who can access the server via client commands. Each client command\n"
-                       "  (ignoring child commands, i.e init, complete, event, meter, label, wait)\n"
-                       "  will encode the user name of the process initiating the client request\n"
-                       "  This is then compared with list of users in the ecf.lists file.\n"
-                       "  If this file is empty, then no authentication is done.\n"
-                       "  Each server can potentially have a different list.\n"
-                       "  The default is <host>.<port>.ecf.lists if no ECF_LISTS is specified.\n"
-                       "  Note: If the path to a ecf.lists is specified as i.e /var/tmp/ecflow/ecf.lists\n"
-                       "        then no prefix is added, the path is kept as is.\n"
-                       "        However if 'ECF_LISTS=ecf.lists' then this matches the default, and the\n"
-                       "        server will expect <host>.<port>.ecf.lists \n"
-                       "ECF_TASK_THRESHOLD:\n"
-                       "  The Job generation process is expected to take less than 60 seconds\n"
-                       "  This is used to aid debugging of task taking excessive times for job generation\n"
-                       "  The causes can be:\n"
-                       "    a/ Slow disk I/0, or when server is run an a virtual machine\n"
-                       "    b/ Insufficient memory, when compared to the size of the scripts/definition\n"
-                       "    c/ Large number of jobs submitted at the same time, and/or very large scripts\n"
-                       "  Any task taking longer than the specified time in milliseconds will be logged.\n"
-                       "  WAR:[..] Job generation for task /suite/family/dodgy_task took 5000ms,\n"
-                       "  Exceeds ECF_TASK_THRESHOLD. The default threshold is 4000 milliseconds\n"
-                       "  Note: 1000 milliseconds = 1 second\n"
-                       "    export ECF_TASK_THRESHOLD=1500\n"
-                       "ECF_PRUNE_NODE_LOG:\n"
-                       "  The node log history is stored in memory and written to the checkpoint file as backup.\n"
-                       "  Overtime this can build up. If the server is restored from a checkpoint file, then all\n"
-                       "  node log/edit history older than 30 days is automatically pruned, thus saving space\n"
-                       "  in memory and disk. The environment variable of this name can be used to alter the days.\n"
-                       "  If set to zero all edit history is preserved.\n"
-#ifdef ECF_OPENSSL
-                       "ECF_SSL:\n"
-                       "  Enables encrypted communication between client and server.\n"
-                       "  You will need to ensure open ssl in installed on your system\n"
-                       "  In order to use openssl, we need set up some certificates.\n"
-                       "  (These will be self signed certificates, rather than a certificate authority).\n"
-#endif
-                       "\n"
-                       "These defaults along with several other can be specified in the file\n"
-                       "server_environment.cfg. The file should be placed in the current working\n"
-                       "directory. It can be found in ecFlow source tree under Server/ directory.\n"
-                       "Please read this file to see the available options.\n"
-                       "Note: Environment variables _override_ any settings made in the\n"
-                       "server_environment.cfg file.")(
-        "port",
-        po::value<int>(),
-        "<int> <Allowed range 1024-49151> The socket/port the server is listening too. default = 3141\n"
-        "If set will override the environment variable ECF_PORT")(
-        "ecfinterval", po::value<int>(), "<int> <Allowed range 1-60>  Submit jobs interval. For DEBUG/Test only")(
-        "v6", "Use IPv6 TCP protocol. Default is IPv4")
-#ifdef ECF_OPENSSL
-        ("ssl", ecf::Openssl::ssl_info())
-#endif
-            ("dis_job_gen", "Disable job generation. For DEBUG/Test only.")("debug,d", "Enable debug output.")(
-                "version,v",
-                "Show ecflow version number,boost library version, compiler used and compilation date, then exit");
-
-    po::store(po::parse_command_line(argc, argv, desc), vm_);
-    po::notify(vm_);
-
-    if (vm_.count("help"))
-        cout << desc << "\n";
-
-    if (vm_.count("version")) {
-        cout << Version::description() << "\n";
-    }
-
-    if (vm_.count("debug"))
-        env->debug_ = true;
-
-    if (vm_.count("port")) {
-        if (env->debug_)
-            cout << "ServerOptions:: The port number set to '" << vm_["port"].as<int>() << "'\n";
-        env->serverPort_ = vm_["port"].as<int>();
-    }
-    if (vm_.count("ecfinterval")) {
-        if (env->debug_)
-            cout << "ServerOptions: The ecfinterval set to '" << vm_["ecfinterval"].as<int>() << "'\n";
-        env->submitJobsInterval_ = vm_["ecfinterval"].as<int>();
-    }
-    if (vm_.count("v6")) {
-        if (env->debug_)
-            cout << "ServerOptions: The tcp protocol set to v6\n";
-        env->tcp_protocol_ = boost::asio::ip::tcp::v6();
-    }
-    if (vm_.count("dis_job_gen")) {
-        if (env->debug_)
-            cout << "ServerOptions: The dis_job_gen is set\n";
-        env->jobGeneration_ = false;
-    }
-#ifdef ECF_OPENSSL
-    if (vm_.count("ssl")) {
-        if (env->debug_)
-            cout << "ServerOptions: ssl server \n";
-        env->enable_ssl(); // search server.crt first, then <host>.<port>.crt
-    }
-#endif
-}
-
-bool ServerOptions::help_option() const {
-    if (vm_.count("help"))
-        return true;
-    return false;
-}
-
-bool ServerOptions::version_option() const {
-    if (vm_.count("version"))
-        return true;
-    return false;
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/ServerOptions.hpp 5.13.0-1/Server/src/ecflow/server/ServerOptions.hpp
--- 5.12.4-1/Server/src/ecflow/server/ServerOptions.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/ServerOptions.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_ServerOptions_HPP
-#define ecflow_server_ServerOptions_HPP
-
-///
-/// \brief This class will parse the server arguments.
-/// It will update the ServerEnvironment
-///
-
-#include <boost/program_options.hpp>
-class ServerEnvironment;
-
-class ServerOptions {
-public:
-    ServerOptions(int argc, char* argv[], ServerEnvironment*);
-    // Disable copy (and move) semantics
-    ServerOptions(const ServerOptions&)                  = delete;
-    const ServerOptions& operator=(const ServerOptions&) = delete;
-
-    /// return true if help selected, else false
-    bool help_option() const;
-    bool version_option() const;
-
-private:
-    boost::program_options::variables_map vm_;
-};
-
-#endif /*ecflow_server_ServerOptions_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/SslServer.cpp 5.13.0-1/Server/src/ecflow/server/SslServer.cpp
--- 5.12.4-1/Server/src/ecflow/server/SslServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/SslServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,22 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/SslServer.hpp"
-
-#include "ecflow/server/ServerEnvironment.hpp"
-
-SslServer::SslServer(boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
-    : BaseServer(io_service, serverEnv),
-      server_(this, io_service, serverEnv) {
-}
-
-const std::string& SslServer::ssl() const {
-    return serverEnv_.openssl().ssl();
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/SslServer.hpp 5.13.0-1/Server/src/ecflow/server/SslServer.hpp
--- 5.12.4-1/Server/src/ecflow/server/SslServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/SslServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_SslServer_HPP
-#define ecflow_server_SslServer_HPP
-
-#include "ecflow/server/BaseServer.hpp"
-#include "ecflow/server/SslTcpServer.hpp"
-
-class SslServer : public BaseServer {
-public:
-    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
-    explicit SslServer(boost::asio::io_service& io_service, ServerEnvironment&);
-    ~SslServer() override = default;
-
-private:
-    /// AbstractServer functions
-    const std::string& ssl() const override;
-
-    SslTcpServer server_;
-};
-
-#endif
diff -pruN 5.12.4-1/Server/src/ecflow/server/SslTcpServer.cpp 5.13.0-1/Server/src/ecflow/server/SslTcpServer.cpp
--- 5.12.4-1/Server/src/ecflow/server/SslTcpServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/SslTcpServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,148 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/SslTcpServer.hpp"
-
-#include <iostream>
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-#include "ecflow/server/SslServer.hpp"
-
-using boost::asio::ip::tcp;
-using namespace std;
-using namespace ecf;
-
-SslTcpServer::SslTcpServer(SslServer* server, boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
-    : TcpBaseServer(server, io_service, serverEnv) {
-    server_->stats().ECF_SSL_ = serverEnv.openssl().info();
-
-    serverEnv.openssl().init_for_server();
-
-    start_accept();
-}
-
-void SslTcpServer::start_accept() {
-    if (serverEnv_.debug())
-        cout << "   SslTcpServer::start_accept()" << endl;
-
-    ssl_connection_ptr new_conn =
-        std::make_shared<ssl_connection>(boost::ref(io_service_), boost::ref(serverEnv_.openssl().context()));
-
-    acceptor_.async_accept(new_conn->socket_ll(),
-                           [this, new_conn](const boost::system::error_code& e) { handle_accept(e, new_conn); });
-}
-
-void SslTcpServer::handle_accept(const boost::system::error_code& e, ssl_connection_ptr conn) {
-    if (serverEnv_.debug())
-        cout << "   SslTcpServer::handle_accept" << endl;
-
-    // Check whether the server was stopped by a signal before this completion
-    // handler had a chance to run.
-    if (!acceptor_.is_open()) {
-        if (serverEnv_.debug())
-            cout << "   SslTcpServer::handle_accept:  acceptor is closed, returning" << endl;
-        return;
-    }
-
-    if (!e) {
-        // Read and interpret message from the client
-        conn->socket().async_handshake(
-            boost::asio::ssl::stream_base::server,
-            [this, conn](const boost::system::error_code& error) { this->handle_handshake(error, conn); });
-    }
-    else {
-        if (serverEnv_.debug())
-            cout << "   SslTcpServer::handle_accept " << e.message() << endl;
-        if (e != boost::asio::error::operation_aborted) {
-            // An error occurred. Log it
-            LogToCout toCoutAsWell;
-            LogFlusher logFlusher;
-            LOG(Log::ERR, "   SslTcpServer::handle_accept error occurred  " << e.message());
-        }
-    }
-
-    // Start an accept operation for a new connection.
-    // *NOTE* previously we had *ONLY* called this if there was no errors
-    //        However this would means that server would run out work.
-    //        When there were errors.!
-    // Moved here to follow the examples used in ASIO.
-    // However can this get into an infinite loop ???
-    start_accept();
-}
-
-void SslTcpServer::handle_handshake(const boost::system::error_code& e, ssl_connection_ptr new_conn) {
-    if (serverEnv_.debug())
-        cout << "   SslTcpServer::handle_handshake" << endl;
-
-    if (!e) {
-        // Successfully accepted a new connection. Determine what the
-        // client sent to us. The connection::async_read() function will
-        // automatically. serialise the inbound_request_ data structure for us.
-        new_conn->async_read(inbound_request_, [this, new_conn](const boost::system::error_code& error) {
-            this->handle_read(error, new_conn);
-        });
-    }
-    else {
-        // An error occurred.
-        LogToCout toCoutAsWell;
-        LOG(Log::ERR, "SslTcpServer::handle_handshake: " << e.message());
-    }
-}
-
-void SslTcpServer::handle_read(const boost::system::error_code& e, ssl_connection_ptr conn) {
-    /// Handle completion of a write operation.
-    // **********************************************************************************
-    // This function *must* finish with write, otherwise it ends up being called recursively
-    // ***********************************************************************************
-    if (!e) {
-
-        handle_request(); // populates outbound_response_
-
-        // Always *Reply* back to the client, Otherwise client will get EOF
-        conn->async_write(outbound_response_,
-                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
-    }
-    else {
-        handle_read_error(e); // populates outbound_response_
-        conn->async_write(outbound_response_,
-                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
-    }
-}
-
-void SslTcpServer::handle_write(const boost::system::error_code& e, ssl_connection_ptr conn) {
-    // Handle completion of a write operation.
-    // Nothing to do. The socket will be closed automatically when the last
-    // reference to the connection object goes away.
-    if (serverEnv_.debug())
-        cout << "   SslTcpServer::handle_write: client request " << inbound_request_ << " replying with  "
-             << outbound_response_ << endl;
-
-    if (e) {
-        LogFlusher logFlusher;
-        ecf::LogToCout logToCout;
-        std::stringstream ss;
-        ss << "SslTcpServer::handle_write: " << e.message() << " : for request " << inbound_request_;
-        log(Log::ERR, ss.str());
-        return;
-    }
-
-    // Do any necessary clean up after outbound_response_  has run. i.e like re-claiming memory
-    outbound_response_.cleanup();
-
-    (void)shutdown_socket(conn, "SslTcpServer::handle_write:");
-
-    // If asked to terminate we do it here rather than in handle_read.
-    // So that we have responded to the client.
-    // *HOWEVER* only do this if the request was successful.
-    //           we do this by checking that the out bound response was ok
-    //           i.e a read only user should not be allowed to terminate server.
-    handle_terminate_request();
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/SslTcpServer.hpp 5.13.0-1/Server/src/ecflow/server/SslTcpServer.hpp
--- 5.12.4-1/Server/src/ecflow/server/SslTcpServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/SslTcpServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_SslTcpServer_HPP
-#define ecflow_server_SslTcpServer_HPP
-
-#include "ecflow/base/ssl_connection.hpp"
-#include "ecflow/server/TcpBaseServer.hpp"
-class SslServer;
-
-class SslTcpServer : public TcpBaseServer {
-public:
-    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
-    explicit SslTcpServer(SslServer*, boost::asio::io_service& io_service, ServerEnvironment&);
-    ~SslTcpServer() = default;
-
-private:
-    /// ssl and connection functions
-    void handle_handshake(const boost::system::error_code& error, ssl_connection_ptr conn);
-
-    /// Handle completion of a accept operation.
-    void handle_accept(const boost::system::error_code& e, ssl_connection_ptr conn);
-
-    /// Handle completion of a write operation.
-    void handle_write(const boost::system::error_code& e, ssl_connection_ptr conn);
-
-    /// Handle completion of a read operation.
-    void handle_read(const boost::system::error_code& e, ssl_connection_ptr conn);
-
-    void start_accept();
-};
-
-#endif /* ecflow_server_SslTcpServer_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/TcpBaseServer.cpp 5.13.0-1/Server/src/ecflow/server/TcpBaseServer.cpp
--- 5.12.4-1/Server/src/ecflow/server/TcpBaseServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/TcpBaseServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,153 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/TcpBaseServer.hpp"
-
-#include <iostream>
-
-#include "ecflow/base/cts/task/AbortCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/task/CompleteCmd.hpp"      // required to enforce cereal registration
-#include "ecflow/base/cts/task/CtsWaitCmd.hpp"       // required to enforce cereal registration
-#include "ecflow/base/cts/task/EventCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/task/InitCmd.hpp"          // required to enforce cereal registration
-#include "ecflow/base/cts/task/LabelCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/task/MeterCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/task/QueueCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/AlterCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/BeginCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/CFileCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/CSyncCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/CheckPtCmd.hpp"       // required to enforce cereal registration
-#include "ecflow/base/cts/user/ClientHandleCmd.hpp"  // required to enforce cereal registration
-#include "ecflow/base/cts/user/CtsCmd.hpp"           // required to enforce cereal registration
-#include "ecflow/base/cts/user/CtsNodeCmd.hpp"       // required to enforce cereal registration
-#include "ecflow/base/cts/user/DeleteCmd.hpp"        // required to enforce cereal registration
-#include "ecflow/base/cts/user/EditScriptCmd.hpp"    // required to enforce cereal registration
-#include "ecflow/base/cts/user/ForceCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/FreeDepCmd.hpp"       // required to enforce cereal registration
-#include "ecflow/base/cts/user/GroupCTSCmd.hpp"      // required to enforce cereal registration
-#include "ecflow/base/cts/user/LoadDefsCmd.hpp"      // required to enforce cereal registration
-#include "ecflow/base/cts/user/LogCmd.hpp"           // required to enforce cereal registration
-#include "ecflow/base/cts/user/LogMessageCmd.hpp"    // required to enforce cereal registration
-#include "ecflow/base/cts/user/MoveCmd.hpp"          // required to enforce cereal registration
-#include "ecflow/base/cts/user/OrderNodeCmd.hpp"     // required to enforce cereal registration
-#include "ecflow/base/cts/user/PathsCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/PlugCmd.hpp"          // required to enforce cereal registration
-#include "ecflow/base/cts/user/QueryCmd.hpp"         // required to enforce cereal registration
-#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"   // required to enforce cereal registration
-#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"   // required to enforce cereal registration
-#include "ecflow/base/cts/user/RunNodeCmd.hpp"       // required to enforce cereal registration
-#include "ecflow/base/cts/user/ServerVersionCmd.hpp" // required to enforce cereal registration
-#include "ecflow/base/cts/user/ShowCmd.hpp"          // required to enforce cereal registration
-#include "ecflow/base/cts/user/ZombieCmd.hpp"        // required to enforce cereal registration
-#include "ecflow/base/stc/PreAllocatedReply.hpp"
-#include "ecflow/core/Version.hpp"
-#include "ecflow/server/BaseServer.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-using boost::asio::ip::tcp;
-
-using namespace std;
-using namespace ecf;
-
-TcpBaseServer::TcpBaseServer(BaseServer* server, boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
-    : server_(server),
-      io_service_(io_service),
-      serverEnv_(serverEnv),
-      acceptor_(io_service) {
-    // Open the acceptor with the option to reuse the address (i.e. SO_REUSEADDR).
-    boost::asio::ip::tcp::endpoint endpoint(serverEnv.tcp_protocol(), serverEnv.port());
-    acceptor_.open(endpoint.protocol());
-    acceptor_.set_option(boost::asio::ip::tcp::acceptor::reuse_address(true));
-    acceptor_.bind(endpoint);
-    acceptor_.listen(); // address is use error, when it comes, bombs out here
-}
-
-void TcpBaseServer::handle_request() {
-    // See what kind of message we got from the client
-    if (serverEnv_.debug())
-        std::cout << "   TcpBaseServer::handle_request  : client request " << inbound_request_ << endl;
-
-    try {
-        // Service the in bound request, handling the request will populate the outbound_response_
-        // Note:: Handle request will first authenticate
-        outbound_response_.set_cmd(inbound_request_.handleRequest(server_));
-    }
-    catch (exception& e) {
-        outbound_response_.set_cmd(PreAllocatedReply::error_cmd(e.what()));
-    }
-
-    // Do any necessary clean up after inbound_request_ has run. i.e like re-claiming memory
-    inbound_request_.cleanup();
-}
-
-void TcpBaseServer::handle_read_error(const boost::system::error_code& e) {
-    // An error occurred.
-    // o/ If client has been killed/disconnected/timed out
-    //       TcpServer::handle_read : End of file
-    //
-    // o/ If a *new* client talks to an *old* server, with an unrecognised request/command i.e mixing 4/5 series
-    //    we will see:
-    //       Connection::handle_read_data .............
-    //       TcpServer::handle_read : Invalid argument
-    LogToCout toCoutAsWell;
-    LogFlusher logFlusher;
-    LOG(Log::ERR, "TcpBaseServer::handle_read_error: " << e.message());
-
-    // *Reply* back to the client, This may fail in the client;
-    std::pair<std::string, std::string> host_port = server_->hostPort();
-    std::string msg                               = " ->Server:";
-    msg += host_port.first;
-    msg += "@";
-    msg += host_port.second;
-    msg += " (";
-    msg += Version::raw();
-    msg += ") replied with: ";
-    msg += e.message();
-    outbound_response_.set_cmd(PreAllocatedReply::error_cmd(msg));
-}
-
-void TcpBaseServer::handle_terminate_request() {
-    // If asked to terminate we do it here rather than in handle_read.
-    // So that we have responded to the client.
-    // *HOWEVER* only do this if the request was successful.
-    //           we do this by checking that the out bound response was ok
-    //           i.e a read only user should not be allowed to terminate server.
-    if (inbound_request_.terminateRequest()) {
-        if (serverEnv_.debug())
-            cout << "   <-- TcpBaseServer::handle_terminate_request  exiting server via terminate() port "
-                 << serverEnv_.port() << endl;
-        terminate();
-    }
-}
-
-void TcpBaseServer::terminate() {
-    // The server is terminated by cancelling all outstanding asynchronous
-    // operations. Once all operations have finished the io_service::run() call  will exit.
-    if (serverEnv_.debug())
-        cout << "   Server::terminate(): posting call to Server::handle_terminate" << endl;
-
-    // Post a call to the stop function so that Server::stop() is safe to call from any thread.
-    io_service_.post([this]() { handle_terminate(); });
-}
-
-void TcpBaseServer::handle_terminate() {
-    // if (serverEnv_.debug()) cout << boost::this_thread::get_id() << "   Server::handle_terminate() : cancelling
-    // checkpt and traverser timers, and signals" << endl;
-    if (serverEnv_.debug())
-        cout << "   Server::handle_terminate() : cancelling checkpt and traverser timers, and signals" << endl;
-
-    server_->handle_terminate();
-
-    acceptor_.close();
-
-    // Stop the io_service object's event processing loop. Will cause run to return immediately
-    io_service_.stop();
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/TcpBaseServer.hpp 5.13.0-1/Server/src/ecflow/server/TcpBaseServer.hpp
--- 5.12.4-1/Server/src/ecflow/server/TcpBaseServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/TcpBaseServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,74 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_TcpBaseServer_HPP
-#define ecflow_server_TcpBaseServer_HPP
-
-#include <boost/asio.hpp>
-
-#include "ecflow/base/ClientToServerRequest.hpp"
-#include "ecflow/base/ServerToClientResponse.hpp"
-#include "ecflow/core/Log.hpp"
-
-class BaseServer;
-class ServerEnvironment;
-
-class TcpBaseServer {
-public:
-    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
-    explicit TcpBaseServer(BaseServer*, boost::asio::io_service& io_service, ServerEnvironment&);
-    ~TcpBaseServer() = default;
-
-    void handle_request();
-    void handle_read_error(const boost::system::error_code& e);
-
-    /// Terminate the server gracefully. Need to cancel all timers, close all sockets
-    /// Server will hang if there are any pending async handlers
-    void handle_terminate_request();
-    void terminate();
-    void handle_terminate();
-
-    template <typename T>
-    bool shutdown_socket(T conn, const std::string& msg) const {
-        // For portable behaviour with respect to graceful closure of a connected socket,
-        // call shutdown() before closing the socket.
-        //
-        //    conn->socket().shutdown(boost::asio::ip::tcp::socket::shutdown_both)
-        // This *CAN* throw an error if the client side socket is not connected. client may have been killed *OR* timed
-        // out i.e "shutdown: Transport endpoint is not connected"
-        //
-        // Since this can happen, instead of throwing, we use non-throwing version & just report it
-        boost::system::error_code ec;
-        conn->socket_ll().shutdown(boost::asio::ip::tcp::socket::shutdown_both, ec);
-        if (ec) {
-            ecf::LogToCout logToCout;
-            ecf::LogFlusher logFlusher;
-            std::stringstream ss;
-            ss << msg << " socket shutdown both failed: " << ec.message() << " : for request " << inbound_request_;
-            ecf::log(ecf::Log::ERR, ss.str());
-            return false;
-        }
-        return true;
-    }
-
-protected:
-    BaseServer* server_;
-    boost::asio::io_service& io_service_;
-    ServerEnvironment& serverEnv_;
-
-    /// The acceptor object used to accept incoming socket connections.
-    boost::asio::ip::tcp::acceptor acceptor_;
-
-    /// The data, typically loaded once, and then sent to many clients
-    ClientToServerRequest inbound_request_;
-    ServerToClientResponse outbound_response_;
-};
-
-#endif /* ecflow_server_TcpBaseServer_HPP */
diff -pruN 5.12.4-1/Server/src/ecflow/server/TcpServer.cpp 5.13.0-1/Server/src/ecflow/server/TcpServer.cpp
--- 5.12.4-1/Server/src/ecflow/server/TcpServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/TcpServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,136 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/server/TcpServer.hpp"
-
-#include <iostream>
-
-#include "ecflow/core/Log.hpp"
-#include "ecflow/server/Server.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-using boost::asio::ip::tcp;
-
-using namespace std;
-using namespace ecf;
-
-TcpServer::TcpServer(Server* server, boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
-    : TcpBaseServer(server, io_service, serverEnv) {
-    // timer_.stop(); // for timing of commands.
-
-    start_accept();
-}
-
-void TcpServer::start_accept() {
-    if (serverEnv_.debug())
-        cout << "   TcpServer::start_accept()" << endl;
-    connection_ptr new_conn = std::make_shared<connection>(boost::ref(io_service_));
-    acceptor_.async_accept(new_conn->socket_ll(),
-                           [this, new_conn](const boost::system::error_code& e) { handle_accept(e, new_conn); });
-}
-
-void TcpServer::handle_accept(const boost::system::error_code& e, connection_ptr conn) {
-    if (serverEnv_.debug())
-        cout << "   TcpServer::handle_accept" << endl;
-
-    // Check whether the server was stopped by a signal before this completion
-    // handler had a chance to run.
-    if (!acceptor_.is_open()) {
-        if (serverEnv_.debug())
-            cout << "   TcpServer::handle_accept:  acceptor is closed, returning" << endl;
-        return;
-    }
-
-    if (!e) {
-        // Read and interpret message from the client
-        // Successfully accepted a new connection. Determine what the
-        // client sent to us. The connection::async_read() function will
-        // automatically. serialise the inbound_request_ data structure for us.
-        conn->async_read(inbound_request_,
-                         [this, conn](const boost::system::error_code& error) { this->handle_read(error, conn); });
-    }
-    else {
-        if (serverEnv_.debug())
-            cout << "   TcpServer::handle_accept " << e.message() << endl;
-        if (e != boost::asio::error::operation_aborted) {
-            // An error occurred. Log it
-            LogToCout toCoutAsWell;
-            LogFlusher logFlusher;
-            LOG(Log::ERR, "   TcpServer::handle_accept error occurred  " << e.message());
-        }
-    }
-
-    // Start an accept operation for a new connection.
-    // *NOTE* previously we had *ONLY* called this if there was no errors
-    //        However this would means that server would run out work.
-    //        When there were errors.!
-    // Moved here to follow the examples used in ASIO.
-    // However can this get into an infinite loop ???
-    start_accept();
-}
-
-void TcpServer::handle_read(const boost::system::error_code& e, connection_ptr conn) {
-    // start read
-    // timer_.start();
-
-    /// Handle completion of a write operation.
-    // **********************************************************************************
-    // This function *must* finish with write, otherwise it ends up being called recursively
-    // ***********************************************************************************
-    if (!e) {
-
-        handle_request(); // populates outbound_response_
-        // log(Log::DBG," handle_read()  n"  + timer_.format(3,Str::cpu_timer_format()));
-
-        // start write
-        // timer_.start();
-
-        // Always *Reply* back to the client, Otherwise client will get EOF
-        conn->async_write(outbound_response_,
-                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
-    }
-    else {
-        handle_read_error(e); // populates outbound_response_
-        conn->async_write(outbound_response_,
-                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
-    }
-}
-
-void TcpServer::handle_write(const boost::system::error_code& e, connection_ptr conn) {
-    // Handle completion of a write operation.
-    // Nothing to do. The socket will be closed automatically when the last
-    // reference to the connection object goes away.
-    if (serverEnv_.debug())
-        cout << "   TcpServer::handle_write: client request " << inbound_request_ << " replying with  "
-             << outbound_response_ << endl;
-
-    if (e) {
-        LogFlusher logFlusher;
-        ecf::LogToCout logToCout;
-        std::stringstream ss;
-        ss << "TcpServer::handle_write: " << e.message() << " : for request " << inbound_request_;
-        log(Log::ERR, ss.str());
-        return;
-    }
-
-    // Do any necessary clean up after outbound_response_  has run. i.e like re-claiming memory
-    outbound_response_.cleanup();
-
-    (void)shutdown_socket(conn, "TcpServer::handle_write:");
-
-    // If asked to terminate we do it here rather than in handle_read.
-    // So that we have responded to the client.
-    // *HOWEVER* only do this if the request was successful.
-    //           we do this by checking that the out bound response was ok
-    //           i.e a read only user should not be allowed to terminate server.
-    handle_terminate_request();
-
-    // log(Log::DBG," handle_write() "  + timer_.format(3,Str::cpu_timer_format()));
-}
diff -pruN 5.12.4-1/Server/src/ecflow/server/TcpServer.hpp 5.13.0-1/Server/src/ecflow/server/TcpServer.hpp
--- 5.12.4-1/Server/src/ecflow/server/TcpServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/src/ecflow/server/TcpServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,39 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_server_TcpServer_HPP
-#define ecflow_server_TcpServer_HPP
-
-#include "ecflow/base/Connection.hpp"
-#include "ecflow/server/TcpBaseServer.hpp"
-class Server;
-
-class TcpServer : public TcpBaseServer {
-public:
-    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
-    explicit TcpServer(Server*, boost::asio::io_service& io_service, ServerEnvironment&);
-    ~TcpServer() = default;
-
-private:
-    /// Handle completion of a accept operation.
-    void handle_accept(const boost::system::error_code& e, connection_ptr conn);
-
-    /// Handle completion of a write operation.
-    void handle_write(const boost::system::error_code& e, connection_ptr conn);
-
-    /// Handle completion of a read operation.
-    void handle_read(const boost::system::error_code& e, connection_ptr conn);
-
-    void start_accept();
-
-    // boost::timer::cpu_timer timer_; // time_cmds for debug
-};
-
-#endif /* ecflow_server_TcpServer_HPP */
diff -pruN 5.12.4-1/Server/test/TestCheckPtSaver.cpp 5.13.0-1/Server/test/TestCheckPtSaver.cpp
--- 5.12.4-1/Server/test/TestCheckPtSaver.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/test/TestCheckPtSaver.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,132 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/server/CheckPtSaver.hpp"
-
-// TODO: Move the following trace_*_function to a common test module/library
-static void trace_test() {
-    std::cout << "..." << boost::unit_test::framework::current_test_case().full_name() << "\n";
-}
-
-/**
- * A self cleaning test file, useful to automate test data storage/cleanup, with automatic generation of file names.
- */
-class TestFile {
-public:
-    /**
-     * Create a handle for a 'non-existent' data file
-     */
-    explicit TestFile(const std::string& basename) : absolute_path_(TestFile::unique_absolute_path(basename)) {}
-
-    /**
-     * Create a handle for a data file, with the given content
-     */
-    TestFile(const std::string& basename, const std::string& content)
-        : absolute_path_(TestFile::unique_absolute_path(basename)) {
-        f_store(absolute_path_.string(), content);
-    }
-    ~TestFile() { fs::remove(absolute_path_); }
-
-    [[nodiscard]] const fs::path& path() const { return absolute_path_; }
-    [[nodiscard]] std::string load() const { return f_load(absolute_path_); }
-
-    static fs::path unique_absolute_path(const std::string& basename) {
-        return fs::absolute(fs::unique_path(basename));
-    }
-
-private:
-    static void f_store(const fs::path& outfile, const std::string& data) {
-        std::ofstream ofs(outfile.string());
-        ofs << data;
-    }
-
-    static std::string f_load(const fs::path& infile) {
-        std::ifstream ifs(infile.string());
-        std::string buffer((std::istreambuf_iterator<char>(ifs)), std::istreambuf_iterator<char>());
-        return buffer;
-    }
-
-private:
-    fs::path absolute_path_;
-};
-
-void handle_store(const fs::path& temporary) {
-    std::ofstream ofs(temporary.string());
-    ofs << "2";
-}
-
-BOOST_AUTO_TEST_SUITE(U_Server)
-
-BOOST_AUTO_TEST_SUITE(T_CheckPtSaver)
-
-BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case0) {
-    trace_test();
-
-    // Case 0: neither current and backup exist
-
-    TestFile current("current_%%%%-%%%%-%%%%"); // Important: no actual file is created
-    TestFile backup("backup_%%%%-%%%%-%%%%");   // Important: no actual file is created
-
-    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
-
-    BOOST_CHECK_EQUAL(current.load(), "2");
-    BOOST_CHECK(!fs::exists(backup.path()));
-}
-
-BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case1) {
-    trace_test();
-
-    // Case 1: current and backup both exist and are non-empty
-
-    TestFile current("current_%%%%-%%%%-%%%%", "1");
-    TestFile backup("backup_%%%%-%%%%-%%%%", "X");
-
-    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
-
-    BOOST_CHECK_EQUAL(current.load(), "2");
-    BOOST_CHECK_EQUAL(backup.load(), "1");
-}
-
-BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case2) {
-    trace_test();
-
-    // Case 2: current and backup both exist, and current is empty
-
-    TestFile current("current_%%%%-%%%%-%%%%", ""); // Important: file is created empty
-    TestFile backup("backup_%%%%-%%%%-%%%%", "X");
-
-    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
-
-    BOOST_CHECK_EQUAL(current.load(), "2");
-    BOOST_CHECK_EQUAL(backup.load(), "X");
-}
-
-BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case3) {
-    trace_test();
-
-    // Case 3: current exists, but no backup is available
-
-    TestFile current("current_%%%%-%%%%-%%%%", "1");
-    TestFile backup("backup_%%%%-%%%%-%%%%"); // Important: no actual file is created
-
-    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
-
-    BOOST_CHECK_EQUAL(current.load(), "2");
-    BOOST_CHECK_EQUAL(backup.load(), "1");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Server/test/TestServer.cpp 5.13.0-1/Server/test/TestServer.cpp
--- 5.12.4-1/Server/test/TestServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/test/TestServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,210 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/EcfPortLock.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/server/Server.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Server)
-
-BOOST_AUTO_TEST_SUITE(T_Server)
-
-// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-// make public the function we wish to test:
-// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-class TestServer : public Server {
-public:
-    explicit TestServer(boost::asio::io_service& io_service, ServerEnvironment& s) : Server(io_service, s) {}
-    ~TestServer() override = default;
-
-    // abort server if check pt files exist, but can't be loaded
-    //   bool load_check_pt_file_on_startup();
-    //   void loadCheckPtFile();
-    //   bool restore_from_checkpt(const std::string& filename, bool& failed);
-    //   void set_server_state(SState::State);
-
-    /// AbstractServer functions
-    SState::State state() const override { return Server::state(); }
-    std::pair<std::string, std::string> hostPort() const override { return Server::hostPort(); }
-    defs_ptr defs() const override { return Server::defs(); }
-    // virtual void updateDefs(defs_ptr,bool force);
-    void clear_defs() override { Server::clear_defs(); }
-    //   virtual void checkPtDefs(ecf::CheckPt::Mode m = ecf::CheckPt::UNDEFINED,
-    //                               int check_pt_interval = 0,
-    //                               int check_pt_save_time_alarm = 0);
-    void restore_defs_from_checkpt() override { Server::restore_defs_from_checkpt(); }
-    void nodeTreeStateChanged() override { Server::nodeTreeStateChanged(); }
-    bool allowTaskCommunication() const override { return Server::allowTaskCommunication(); }
-    void shutdown() override { Server::shutdown(); }
-    void halted() override { Server::halted(); }
-    void restart() override { Server::restart(); }
-
-    bool reloadWhiteListFile(std::string& errorMsg) override { return Server::reloadWhiteListFile(errorMsg); }
-    bool reloadPasswdFile(std::string& errorMsg) override { return Server::reloadPasswdFile(errorMsg); }
-
-    bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) override {
-        return Server::authenticateReadAccess(user, custom_user, passwd);
-    }
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::string& path) override {
-        return Server::authenticateReadAccess(user, custom_user, passwd, path);
-    }
-    bool authenticateReadAccess(const std::string& user,
-                                bool custom_user,
-                                const std::string& passwd,
-                                const std::vector<std::string>& paths) override {
-        return Server::authenticateReadAccess(user, custom_user, passwd, paths);
-    }
-
-    bool authenticateWriteAccess(const std::string& user) override { return Server::authenticateWriteAccess(user); }
-    bool authenticateWriteAccess(const std::string& user, const std::string& path) override {
-        return Server::authenticateWriteAccess(user, path);
-    }
-    bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) override {
-        return Server::authenticateWriteAccess(user, paths);
-    }
-
-    bool lock(const std::string& user) override { return Server::lock(user); }
-    void unlock() override { Server::unlock(); }
-    const std::string& lockedUser() const override { return Server::lockedUser(); }
-    //   virtual void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now, bool
-    //   user_cmd_context) const;
-    int poll_interval() const override { return Server::poll_interval(); }
-    //   virtual void debug_server_on();
-    //   virtual void debug_server_off();
-    //   virtual bool debug() const;
-};
-
-void test_the_server(const std::string& port) {
-    std::string server_port = "--port=" + port;
-    int argc                = 3;
-    char* argv[]            = {const_cast<char*>("ServerEnvironment"),
-                               const_cast<char*>(server_port.c_str()),
-                               const_cast<char*>("--ecfinterval=12")};
-
-    ServerEnvironment server_environment(argc, argv); // This can throw ServerEnvironmentException
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(server_environment.valid(errorMsg), errorMsg);
-
-    {
-        boost::asio::io_service io_service;
-        TestServer theServer(io_service, server_environment); // This can throw exception, bind address in use.
-
-        BOOST_REQUIRE_MESSAGE(theServer.defs(), "Expected defs to be created");
-
-        const std::vector<Variable>& server_variables = theServer.defs()->server().server_variables();
-        BOOST_REQUIRE_MESSAGE(!server_variables.empty(), "Expected defs to be updated with the server variables");
-
-        // for(size_t i = 0; i < server_variables.size(); ++i)  cout << server_variables[i].dump() << "\n";
-        const std::string& ecf_port = theServer.defs()->server().find_variable("ECF_PORT");
-        BOOST_REQUIRE_MESSAGE(ecf_port == port,
-                              "Expected port " << port << " but found " << ecf_port
-                                               << " defs server variables, should be in sync with server");
-
-        const std::string& interval = theServer.defs()->server().find_variable("ECF_INTERVAL");
-        BOOST_REQUIRE_MESSAGE(interval == "12",
-                              "Expected interval 12 but found "
-                                  << interval << " defs server variables, should be in sync with server");
-        BOOST_REQUIRE_MESSAGE(theServer.poll_interval() == 12,
-                              "Expected poll interval 12 but found " << theServer.poll_interval());
-
-        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::HALTED,
-                              "Expected halted at server start but found " << SState::to_string(theServer.state()));
-        theServer.halted();
-        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::HALTED, "Expected halted ");
-        theServer.shutdown();
-        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::SHUTDOWN, "Expected shutdown ");
-        theServer.restart();
-        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::RUNNING, "Expected shutdown ");
-
-        BOOST_REQUIRE_MESSAGE(theServer.lock("fred"), "Expected to lock user fred");
-        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::SHUTDOWN, "Locking should shutdown server");
-        BOOST_REQUIRE_MESSAGE(theServer.lockedUser() == "fred",
-                              "Expected locked user 'fred' but found " << theServer.lockedUser());
-        theServer.unlock();
-        BOOST_REQUIRE_MESSAGE(theServer.lockedUser().empty(),
-                              "Expected no locked user but found " << theServer.lockedUser());
-        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::RUNNING, "Expected unlock to restart server ");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_server) {
-    cout << "Server:: ...test_server\n";
-
-    // Create a unique port number, allowing debug and release,gnu,clang,intel to run at the same time
-    // Hence the lock file is not always sufficient.
-    // ECF_FREE_PORT should be unique among  gnu,clang,intel, etc
-    std::string the_port1 = "3144";
-    char* test_ecf_port   = getenv("ECF_FREE_PORT"); // from metabuilder, allow parallel tests
-    if (test_ecf_port)
-        the_port1 = test_ecf_port;
-    cout << "  Find free port to start server, starting with port " << the_port1 << "\n";
-
-    auto the_port = ecf::convert_to<int>(the_port1);
-    while (!EcfPortLock::is_free(the_port))
-        the_port++;
-    std::string port = ecf::convert_to<std::string>(the_port);
-    EcfPortLock::create(port);
-    cout << "  Found free port: " << port << " ";
-
-    Host h;
-    int count = 0;
-    while (1) {
-        try {
-            test_the_server(port);
-            cout << "\n";
-            break;
-        }
-        catch (...) {
-            count++;
-
-            // cleanup
-            fs::remove(h.ecf_log_file(port));
-            EcfPortLock::remove(port);
-
-            cout << " : port " << port << " is used, trying next port\n";
-
-            the_port = ecf::convert_to<int>(port);
-            the_port++;
-
-            while (!EcfPortLock::is_free(the_port))
-                the_port++;
-            port = ecf::convert_to<std::string>(the_port);
-            EcfPortLock::create(port);
-            cout << "  Found free port: " << port << "\n";
-
-            BOOST_REQUIRE_MESSAGE(count < 20, "Could not find new port after 20 attempts");
-        }
-    }
-
-    // cleanup
-    fs::remove(h.ecf_log_file(port));
-    EcfPortLock::remove(port);
-
-    /// Destroy Log singleton to avoid valgrind from complaining
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Server/test/TestServerEnvironment.cpp 5.13.0-1/Server/test/TestServerEnvironment.cpp
--- 5.12.4-1/Server/test/TestServerEnvironment.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/test/TestServerEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,367 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <iostream>
-#include <stdexcept>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/core/CheckPt.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Log.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/JobProfiler.hpp"
-#include "ecflow/server/ServerEnvironment.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(U_Server)
-
-BOOST_AUTO_TEST_SUITE(T_ServerEnvironment)
-
-BOOST_AUTO_TEST_CASE(test_server_environment_ecfinterval) {
-    cout << "Server:: ...test_server_environment_ecfinterval\n";
-
-    // ecflow server interval is valid for range [1-60]
-    std::string port = Str::DEFAULT_PORT_NUMBER();
-    for (int i = -10; i < 70; ++i) {
-        string errorMsg;
-        string argument = "--ecfinterval=" + ecf::convert_to<std::string>(i);
-
-        int argc     = 2;
-        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>(argument.c_str())};
-        ServerEnvironment serverEnv(argc, argv);
-        bool valid = serverEnv.valid(errorMsg);
-        if (i > 0 && i < 61) {
-            BOOST_REQUIRE_MESSAGE(valid, "Server environment ecfinterval valid range is [1-60] " << errorMsg);
-            BOOST_CHECK_MESSAGE(serverEnv.submitJobsInterval() == i,
-                                "Expected submit jobs interval of " << i << " but found "
-                                                                    << serverEnv.submitJobsInterval());
-        }
-        else
-            BOOST_CHECK_MESSAGE(!valid, "Server environment ecfinterval valid range is [1-60] " << errorMsg);
-
-        port = serverEnv.the_port();
-    }
-
-    Host h;
-    fs::remove(h.ecf_log_file(port));
-}
-
-BOOST_AUTO_TEST_CASE(test_server_environment_port) {
-    cout << "Server:: ...test_server_environment_port\n";
-
-    // The port numbers are divided into three ranges.\n";
-    //  o the Well Known Ports, (require root permission)      0 -1023\n";
-    //  o the Registered Ports,                             1024 -49151\n";
-    //  o Dynamic and/or Private Ports.                    49151 -65535\n\n";
-    //  Please set in the range 1024-49151 via argument or \n";
-    Host h;
-    int argc = 2;
-    {
-        std::string errorMsg;
-        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=0")};
-        ServerEnvironment serverEnv(argc, argv);
-        BOOST_CHECK_MESSAGE(!serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
-        fs::remove(h.ecf_log_file(serverEnv.the_port()));
-    }
-    {
-        std::string errorMsg;
-        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=1000")};
-        ServerEnvironment serverEnv(argc, argv);
-        BOOST_CHECK_MESSAGE(!serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
-        fs::remove(h.ecf_log_file(serverEnv.the_port()));
-    }
-    {
-        std::string errorMsg;
-        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=49151")};
-        ServerEnvironment serverEnv(argc, argv);
-        BOOST_CHECK_MESSAGE(!serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
-        fs::remove(h.ecf_log_file(serverEnv.the_port()));
-    }
-
-    {
-        std::string errorMsg;
-        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=3144")};
-        ServerEnvironment serverEnv(argc, argv);
-        BOOST_CHECK_MESSAGE(serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
-        BOOST_CHECK_MESSAGE(serverEnv.port() == 3144, "Expected 3144 but found " << serverEnv.port());
-        fs::remove(h.ecf_log_file(serverEnv.the_port()));
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_server_environment_log_file) {
-    // Regression test log file creation
-    cout << "Server:: ...test_server_environment_log_file\n";
-
-    int argc     = 2;
-    char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=3144")};
-    ServerEnvironment serverEnv(argc, argv);
-
-    BOOST_CHECK_MESSAGE(Log::instance(), "Log singleton not created");
-    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()), "Log file not created");
-
-    // Check that server variable ECF_LOG created and value is correct
-    std::vector<std::pair<std::string, std::string>> server_vars;
-    serverEnv.variables(server_vars);
-
-    bool found_var = false;
-    typedef std::pair<std::string, std::string> mpair;
-    for (const mpair& p : server_vars) {
-        if (Str::ECF_LOG() == p.first) {
-            BOOST_CHECK_MESSAGE(p.second == Log::instance()->path(),
-                                "Expected " << Log::instance()->path() << " but found " << p.second);
-            found_var = true;
-            break;
-        }
-    }
-    BOOST_CHECK_MESSAGE(found_var, "Failed to find server variable ECF_LOG");
-
-    // tear down remove the log file created by ServerEnvironment
-    Host h;
-    fs::remove(h.ecf_log_file(serverEnv.the_port()));
-
-    /// Destroy Log singleton to avoid valgrind from complaining
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_server_config_file) {
-    // Regression test to make sure the server environment variable don't get removed
-    cout << "Server:: ...test_server_config_file\n";
-
-    int argc     = 1;
-    char* argv[] = {const_cast<char*>("ServerEnvironment")};
-
-    ServerEnvironment serverEnv(argc, argv, File::test_data("Server/server_environment.cfg", "Server"));
-
-    std::vector<std::string> expected_variables = ServerEnvironment::expected_variables();
-
-    std::vector<std::pair<std::string, std::string>> server_vars;
-    serverEnv.variables(server_vars);
-    for (const std::string& expected_var : expected_variables) {
-
-        bool found_var = false;
-        typedef std::pair<std::string, std::string> s_pair;
-        for (const s_pair& p : server_vars) {
-            if (expected_var == p.first) {
-                found_var = true;
-                break;
-            }
-        }
-        BOOST_CHECK_MESSAGE(found_var, "Failed to find server var " << expected_var);
-    }
-
-    {
-        // check other way, so that this test gets updated
-        typedef std::pair<std::string, std::string> mpair;
-        for (const mpair& p : server_vars) {
-            bool found_var = false;
-            for (const std::string& expected_var : expected_variables) {
-                if (expected_var == p.first) {
-                    found_var = true;
-                    break;
-                }
-            }
-            BOOST_CHECK_MESSAGE(found_var, "Failed to update test for server var " << p.first);
-        }
-    }
-
-    // Check the values in the server config file, are the *SAME* as the defaults, when config is *NOT* present
-    // Please note do *NOT* use quotes for the values, otherwise quotes get added.
-    // WRONG: ECF_MICRODEF = "%"
-    // RIGHT: ECF_MICRODEF = %
-    // o IGNORE ECF_CHECK: We *ONLY check those value in the config, that should not be altered.
-    //                     since we add root path, and append with host/port
-    // o ignore ECF_CHECKMODE: not a server variable
-    //
-    typedef std::pair<std::string, std::string> mpair;
-    for (const mpair& p : server_vars) {
-        // std::cout << "server variables " << p.first << "  " << p.second << "\n";
-        if (Str::ECF_HOME() == p.first) {
-            BOOST_CHECK_MESSAGE(p.second == fs::current_path().string(),
-                                "for ECF_HOME expected " << fs::current_path().string() << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_PORT") == p.first && !getenv("ECF_PORT")) {
-            BOOST_CHECK_MESSAGE(p.second == Str::DEFAULT_PORT_NUMBER(),
-                                "for ECF_PORT expected " << Str::DEFAULT_PORT_NUMBER() << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_CHECKINTERVAL") == p.first) {
-            std::string expected = ecf::convert_to<std::string>(CheckPt::default_interval());
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_CHECKINTERVAL expected " << CheckPt::default_interval() << " but found "
-                                                                  << p.second);
-            continue;
-        }
-        if (string("ECF_INTERVAL") == p.first) {
-            std::string expected = "60";
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_INTERVAL expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_JOB_CMD") == p.first) {
-            std::string expected = Ecf::JOB_CMD();
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_JOB_CMD expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_KILL_CMD") == p.first) {
-            std::string expected = Ecf::KILL_CMD();
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_KILL_CMD expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_STATUS_CMD") == p.first) {
-            std::string expected = Ecf::STATUS_CMD();
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_STATUS_CMD expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_CHECK_CMD") == p.first) {
-            std::string expected = Ecf::CHECK_CMD();
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_CHECK_CMD expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_URL_CMD") == p.first) {
-            std::string expected = Ecf::URL_CMD();
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_URL_CMD expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_URL_BASE") == p.first) {
-            std::string expected = Ecf::URL_BASE();
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_URL_BASE expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_URL") == p.first) {
-            std::string expected = Ecf::URL();
-            BOOST_CHECK_MESSAGE(p.second == expected, "for ECF_URL expected " << expected << " but found " << p.second);
-            continue;
-        }
-        if (string("ECF_MICRODEF") == p.first) {
-            std::string expected = Ecf::MICRO();
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_MICRODEF expected " << expected << " but found " << p.second);
-            continue;
-        }
-
-        if (string("ECF_PASSWD") == p.first) {
-
-            Host host;
-            std::string port = Str::DEFAULT_PORT_NUMBER();
-            if (getenv("ECF_PORT"))
-                port = getenv("ECF_PORT");
-            std::string expected = host.prefix_host_and_port(port, Str::ECF_PASSWD());
-
-            BOOST_CHECK_MESSAGE(p.second == expected,
-                                "for ECF_PASSWD expected " << expected << " but found " << p.second);
-            continue;
-        }
-    }
-
-    // tear down remove the log file created by ServerEnvironment
-    Host host;
-    fs::remove(host.ecf_log_file(serverEnv.the_port()));
-}
-
-BOOST_AUTO_TEST_CASE(test_server_environment_variables) {
-    // Regression test to make sure the server environment variable don't get removed
-    cout << "Server:: ...test_server_environment_variables\n";
-
-    int argc     = 2;
-    char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=3144")};
-    ServerEnvironment serverEnv(argc, argv);
-
-    std::vector<std::string> expected_variables = ServerEnvironment::expected_variables();
-
-    std::vector<std::pair<std::string, std::string>> server_vars;
-    serverEnv.variables(server_vars);
-    for (const std::string& expected_var : expected_variables) {
-
-        bool found_var = false;
-        typedef std::pair<std::string, std::string> mpair;
-        for (const mpair& p : server_vars) {
-            if (expected_var == p.first) {
-                found_var = true;
-                break;
-            }
-        }
-        BOOST_CHECK_MESSAGE(found_var, "Failed to find server var " << expected_var);
-    }
-
-    // check other way, so that this test gets updated
-    typedef std::pair<std::string, std::string> mpair;
-    for (const mpair& p : server_vars) {
-        bool found_var = false;
-        for (const std::string& expected_var : expected_variables) {
-            if (expected_var == p.first) {
-                found_var = true;
-                break;
-            }
-        }
-        BOOST_CHECK_MESSAGE(found_var, "Failed to update test for server var " << p.first);
-    }
-
-    // tear down remove the log file created by ServerEnvironment
-    Host h;
-    fs::remove(h.ecf_log_file(serverEnv.the_port()));
-
-    /// Destroy Log singleton to avoid valgrind from complaining
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_CASE(test_server_profile_threshold_environment_variable) {
-    cout << "Server:: ...test_server_profile_threshold_environment_variable\n";
-    int argc     = 1;
-    char* argv[] = {const_cast<char*>("ServerEnvironment")};
-    {
-        auto* put = const_cast<char*>("ECF_TASK_THRESHOLD=9");
-        BOOST_CHECK_MESSAGE(putenv(put) == 0, "putenv failed for " << put);
-    }
-    ServerEnvironment serverEnv(argc, argv);
-    BOOST_CHECK_MESSAGE(JobProfiler::task_threshold() == 9,
-                        "Expected task threshold of 9 but found " << JobProfiler::task_threshold());
-
-    // ==================================================================================
-    // Note test for errors
-    vector<string> dodgy_thresholds;
-    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=x");
-    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=,");
-    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=:");
-    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=,,");
-
-    for (auto& dodgy_threshold : dodgy_thresholds) {
-        // cout << "check -------> " << dodgy_thresholds[i] << endl;
-        BOOST_CHECK_MESSAGE(putenv(const_cast<char*>(dodgy_threshold.c_str())) == 0,
-                            "putenv failed for " << dodgy_threshold);
-        BOOST_CHECK_THROW(ServerEnvironment serverEnv(argc, argv), std::runtime_error);
-    }
-
-    unsetenv(const_cast<char*>(
-        "ECF_TASK_THRESHOLD")); // remove from env, otherwise valgrind complains, *AND* affects other tests
-
-    Host h;
-    fs::remove(h.ecf_log_file(serverEnv.the_port()));
-
-    /// Destroy Log singleton to avoid valgrind from complaining
-    Log::destroy();
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Server/test/TestServer_main.cpp 5.13.0-1/Server/test/TestServer_main.cpp
--- 5.12.4-1/Server/test/TestServer_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Server/test/TestServer_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Server
-#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/Test/CMakeLists.txt 5.13.0-1/Test/CMakeLists.txt
--- 5.12.4-1/Test/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,128 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-set(srcs
-  # Headers
-  src/ServerTestHarness.hpp
-  src/TestFixture.hpp
-  src/ZombieUtil.hpp
-  # Sources
-  src/ServerTestHarness.cpp
-  src/TestFixture.cpp
-  src/ZombieUtill.cpp
-)
-
-ecbuild_add_library(
-  TARGET
-    libharness
-  NOINSTALL
-  TYPE STATIC
-  SOURCES
-    ${srcs}
-  PUBLIC_INCLUDES
-    src
-    ../Base/test
-  PUBLIC_LIBS
-    libclient
-    base
-    node
-    attributes
-    core
-)
-target_clangformat(libharness)
-
-# =================================================================
-# test
-
-if (ENABLE_ALL_TESTS)
-
-  set(test_srcs
-    Test_main.cpp # test entry point
-    TestAbortCmd.cpp
-    TestAlias.cpp
-    TestClkSync.cpp
-    TestComplete.cpp
-    TestCron.cpp
-    TestCtsWaitCmd.cpp
-    TestDayDate.cpp
-    TestEcfNoScriptCmd.cpp
-    TestEcfScriptCmd.cpp
-    TestEvents.cpp
-    TestFileCmd.cpp
-    TestHandle.cpp
-    TestInitAddVariable.cpp
-    TestKillCmd.cpp
-    TestLate.cpp
-    TestLimit.cpp
-    TestOrderCmd.cpp
-    TestQueueCmd.cpp
-    TestRepeat.cpp
-    TestRequeueNode.cpp
-    TestServer.cpp
-    TestSpecificIssues.cpp
-    TestSuspend.cpp
-    TestTime.cpp
-    TestToday.cpp
-    TestTrigger.cpp
-    TestWhyCmd.cpp
-  )
-
-  ecbuild_add_test(
-    TARGET
-      s_test
-    LABELS
-      integration
-      nightly
-    SOURCES
-      ${test_srcs}
-    LIBS
-      libharness
-      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    TEST_DEPENDS
-      s_client
-  )
-  target_clangformat(s_test CONDITION ENABLE_TESTS)
-
-  ecbuild_add_test(
-    TARGET
-      s_zombies
-    LABELS
-      integration
-      nightly
-    SOURCES
-      TestZombies.cpp
-      TestZombies_main.cpp # test entry point
-    LIBS
-      libharness
-      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    TEST_DEPENDS
-      s_test
-  )
-  target_clangformat(s_zombies CONDITION ENABLE_TESTS)
-
-  # This test runs forever, hence not suitable as unit test.
-  ecbuild_add_test(
-    TARGET
-      s_single
-    LABELS
-      integration
-      manual
-    SOURCES
-      TestSingle.cpp
-      TestSingle_main.cpp # test entry point
-    LIBS
-      libharness
-      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    TEST_DEPENDS
-      s_client
-  )
-  target_clangformat(s_single CONDITION ENABLE_TESTS)
-
-endif()
diff -pruN 5.12.4-1/Test/TestAbortCmd.cpp 5.13.0-1/Test/TestAbortCmd.cpp
--- 5.12.4-1/Test/TestAbortCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestAbortCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,94 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_AbortCmd)
-
-// Test the abort command. This will test the abort command and the
-// retry behaviour. i.e if a task is aborted, and the variable ECF_TRIES
-// is defined. Then providing its value is less the the task's try number
-// we should do an immediate job submission.
-BOOST_AUTO_TEST_CASE(test_abort_cmd) {
-    DurationTimer timer;
-    cout << "Test:: ...test_abort_cmd " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in ecf includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_task_abort_cmd
-    //   edit ECF_TRIES '4'
-    //   family family0
-    //     task abort
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_abort_cmd");
-        suite->addVariable(Variable("ECF_TRIES", "4"));
-        family_ptr fam0 = suite->add_family("family0");
-        task_ptr abort  = fam0->add_task("abort");
-        abort->addVerify(VerifyAttr(NState::ABORTED, 3));  // task should abort 3 times & succeed on 4th attempt
-        abort->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
-    }
-
-    // Create a custom ecf file for test_task_abort_cmd/family0/abort to invoke the child abort command
-    std::string templateEcfFile;
-    templateEcfFile += "%include <head.h>\n";
-    templateEcfFile += "\n";
-    templateEcfFile += "echo do some work\n";
-    templateEcfFile += "if [ %ECF_TRYNO% -le 3 ] ; then\n";
-    templateEcfFile += "   %ECF_CLIENT_EXE_PATH% --abort=\"expected abort at task try no %ECF_TRYNO%\"\n";
-    templateEcfFile += "   trap 0       # Remove all traps\n";
-    templateEcfFile += "   exit 0       # End the shell before child command complete\n";
-    templateEcfFile += "fi\n";
-    templateEcfFile += "\n";
-    templateEcfFile += "%include <tail.h>\n";
-
-    // The test harness will create corresponding directory structure
-    // Override the default ECF file, with our custom ECF_ file
-    std::map<std::string, std::string> taskEcfFileMap;
-    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "abort"), templateEcfFile));
-
-    // Avoid standard verification since we expect to abort many times
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_abort_cmd.def"), taskEcfFileMap);
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestAlias.cpp 5.13.0-1/Test/TestAlias.cpp
--- 5.12.4-1/Test/TestAlias.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestAlias.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,243 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <limits> // for std::numeric_limits<int>::max()
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/base/cts/user/CFileCmd.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/NOrder.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Alias.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///
-///    This test will TEST:
-///       o Alias creation and running
-///       o Alias ordering
-///       o Alias deletion
-///    Will indirectly test the Alias memento's
-///
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Alias)
-
-void wait_for_alias_to_complete(const std::string& alias_path) {
-    AssertTimer assertTimer(10, false); // Bomb out after 10 seconds, fall back if test fail
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "Could not get the defs from server\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs  = TestFixture::client().defs();
-        node_ptr alias = defs->findAbsNode(alias_path);
-        BOOST_REQUIRE_MESSAGE(alias.get(),
-                              "Could not locate created alias at path " << alias_path << "\n"
-                                                                        << TestFixture::client().errorMsg());
-        if (alias->state() == NState::COMPLETE)
-            break;
-        sleep(2);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_alias) {
-    DurationTimer timer;
-    cout << "Test:: ...test_alias " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in ecf includes
-    //                     Allows test to run without requiring installation
-    Defs theDefs;
-    task_ptr task_a;
-    {
-        suite_ptr suite = theDefs.add_suite("test_alias");
-        suite->add_variable("SLEEPTIME", "0");
-        task_a = suite->add_task("task_a");
-        task_a->addMeter(Meter("meter", 0, 20, 20));
-        task_a->addEvent(Event(1, "event"));
-        task_a->addLabel(Label("task_a_label", "Label1"));
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_alias.def"));
-
-    // After the task has completed create a Alias
-    TestFixture::client().set_throw_on_error(false);
-
-    // Get the ecf script from the current task and use it to create alias
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().file(
-                              task_a->absNodePath(), CFileCmd::toString(CFileCmd::ECF), "10000") == 0,
-                          "Expected to retreive script\n"
-                              << TestFixture::client().errorMsg());
-    std::string script = TestFixture::client().get_string();
-    BOOST_CHECK_MESSAGE(!script.empty(), "script for task " << task_a->absNodePath() << " is empty");
-
-    // TEST Alias CREATION and running =============================================================================
-    // Split the file into line
-    std::vector<std::string> script_lines;
-    Str::split(script, script_lines, "\n");
-
-    NameValueVec used_variables;
-    int result = TestFixture::client().edit_script_submit(
-        task_a->absNodePath(), used_variables, script_lines, true /*create alias*/, true /*run alias*/);
-    BOOST_REQUIRE_MESSAGE(result == 0,
-                          "Expected alias creation and run to succeed\n"
-                              << TestFixture::client().errorMsg());
-    std::string alias0_path = task_a->absNodePath() + "/alias0";
-
-    // Wait for alias to complete.
-    wait_for_alias_to_complete(alias0_path);
-
-    // #ifdef DEBUG
-    //    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0, "Could not get the defs from server\n" <<
-    //    TestFixture::client().errorMsg()); defs_ptr defs = TestFixture::client().defs(); PrintStyle
-    //    style(PrintStyle::STATE); std::cout << *defs;
-    // #endif
-
-    // TEST ORDERING:: Create another alias, but don't run it.
-    // =============================================================================
-    result = TestFixture::client().edit_script_submit(
-        task_a->absNodePath(), used_variables, script_lines, true /*create alias*/, false /*run alias*/);
-    BOOST_REQUIRE_MESSAGE(result == 0, "Expected alias creation succeed\n" << TestFixture::client().errorMsg());
-    {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "Could not get the defs from server\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        std::vector<alias_ptr> aliases;
-        defs->get_all_aliases(aliases);
-        BOOST_REQUIRE_MESSAGE(aliases.size() == 2, "Expected 2 aliases\n" << TestFixture::client().errorMsg());
-    }
-
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::DOWN)) == 0,
-                          "Expected order NOrder::DOWN to succeed\n"
-                              << TestFixture::client().errorMsg());
-    {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "Could not get the defs from server\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
-        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
-
-        std::vector<std::string> expected;
-        expected.push_back("alias1");
-        expected.push_back("alias0");
-        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                              "NOrder::DOWN expected "
-                                  << ecf::algorithm::join(expected) << " but found "
-                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-    }
-
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::UP)) == 0,
-                          "Expected order NOrder::UP to succeed\n"
-                              << TestFixture::client().errorMsg());
-    {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "Could not get the defs from server\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
-        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
-
-        std::vector<std::string> expected;
-        expected.push_back("alias0");
-        expected.push_back("alias1");
-        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                              "NOrder::UP expected "
-                                  << ecf::algorithm::join(expected) << " but found "
-                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-    }
-
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::ORDER)) == 0,
-                          "Expected order NOrder::ORDER to succeed\n"
-                              << TestFixture::client().errorMsg());
-    {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "Could not get the defs from server\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
-        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
-
-        std::vector<std::string> expected;
-        expected.push_back("alias1");
-        expected.push_back("alias0");
-        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                              "NOrder::ORDER expected "
-                                  << ecf::algorithm::join(expected) << " but found "
-                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-    }
-
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::ALPHA)) == 0,
-                          "Expected order NOrder::ALPHA to succeed\n"
-                              << TestFixture::client().errorMsg());
-    {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "Could not get the defs from server\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
-        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
-
-        std::vector<std::string> expected;
-        expected.push_back("alias0");
-        expected.push_back("alias1");
-        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
-                              "NOrder::ALPHA expected "
-                                  << ecf::algorithm::join(expected) << " but found "
-                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
-    }
-
-    // TEST Alias DELETION =============================================================================
-    std::string alias1_path = task_a->absNodePath() + "/alias1";
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_node(alias0_path) == 0,
-                          "delete alias0 failed\n"
-                              << TestFixture::client().errorMsg());
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_node(alias1_path) == 0,
-                          "delete alias1 failed\n"
-                              << TestFixture::client().errorMsg());
-
-    // Get the defs from the server
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                          "Could not get the defs from server\n"
-                              << TestFixture::client().errorMsg());
-    defs_ptr defs = TestFixture::client().defs();
-    std::vector<alias_ptr> aliases;
-    defs->get_all_aliases(aliases);
-    BOOST_REQUIRE_MESSAGE(aliases.empty(), "Alias deletion falied\n" << TestFixture::client().errorMsg());
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestClkSync.cpp 5.13.0-1/Test/TestClkSync.cpp
--- 5.12.4-1/Test/TestClkSync.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestClkSync.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,168 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_ClkSync)
-
-BOOST_AUTO_TEST_CASE(test_clk_sync) {
-    // This test is used to test sync'ing of the suite calendars
-    // The default clock type is *real*. We will create a suite with a hybrid clock attribute
-    // For the suite calendar, we do not persist the clock type(hybrid/real), since this can be
-    // obtained from the clock attribute. Hence a hybrid calendar in the server, will arrive as
-    // real calendar at the client side. (i.e via the memento). It is then up to the client
-    // to update the calendar with clock type stored in the clock attribute.
-    // See:void Suite::set_memento( const SuiteCalendarMemento* memento )
-    // This test(implicitly) will check that after an incremental sync that suite calendar and
-    // suite clock attribute, that both are of the same clock type.
-    // This is done in ServerTestHarness via invariant checking.
-
-    DurationTimer timer;
-    cout << "Test:: ...test_clk_sync " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in ecf includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    //  suite test_clk_sync
-    //    clocl hybrid
-    //    task a
-    //       meter myMeter 0 100
-    //  endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_clk_sync");
-        suite->addClock(ClockAttr(true)); // add hybrid clock
-        task_ptr task_a = suite->add_task("a");
-        task_a->addMeter(Meter("myMeter", 0, 100, 100));
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_clk_sync.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_suite_calendar_sync) {
-    DurationTimer timer;
-    cout << "Test:: ...test_suite_calendar_sync " << flush;
-    TestClean clean_at_start_and_end;
-
-    // When using ECF_SSL sync is to slow.
-    if (getenv("ECF_SSL")) {
-        cout << " ignore test undel ECF_SSL\n";
-        return;
-    }
-
-    // Test that sync_local(true), sync's the suite clock/calendar.
-    Defs theDefs;
-    {
-        boost::posix_time::ptime today = Calendar::second_clock_time();
-        suite_ptr suite                = theDefs.add_suite("test_suite_calendar_sync");
-        family_ptr fam                 = suite->add_family("family");
-        task_ptr task                  = fam->add_task("t1");
-
-        // Don't use hybrid for day dependency as that will force node to complete if days is not the same
-        ClockAttr clockAttr(today, false);
-        suite->addClock(clockAttr);
-
-        // ** add tomorrow days so that node stays queued, hence EXPECT no job and no output **
-        task->addDay(DayAttr(today.date() + boost::gregorian::date_duration(1)));
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_suite_calendar_sync.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Get full defs, so that next sync_local does incremental update
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
-                          CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
-    std::stringstream ss;
-    ss << "\nStart time"
-       << "\n  sync_full: suite time : " << TestFixture::client().defs()->suiteVec()[0]->calendar().toString()
-       << " cal_count(" << TestFixture::client().defs()->updateCalendarCount() << ")\n";
-
-    for (size_t i = 0; i < 3; i++) {
-        // Occasionally we get a random failure.
-        // It is suspected that BETWEEN the two calls below, one off
-        //    Suite::updateCalendar() or Suite::resolveDependencies() is called in the server:
-        // Unfortunately the data required to confirm this is not available on the client side: i.e.
-        //  - Defs::updateCalendarCount_ not persisted with incremental clk sync
-        //  - Suite::calendar_change_no_
-        // To minimise this, avoid sleep that is same as job submission interval
-
-        sleep(TestFixture::job_submission_interval() + 1); // expect 1 minute increment in suite_time.
-
-        ss << "loop:" << i << "\n";
-
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local(true /*sync suite clock*/) == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        boost::posix_time::ptime sync_clock_suiteTime =
-            TestFixture::client().defs()->suiteVec()[0]->calendar().suiteTime();
-        ss << "   Sync clock suite time:" << to_simple_string(sync_clock_suiteTime) << " full_sync("
-           << TestFixture::client().server_reply().full_sync() << ")"
-           << " in_sync(" << TestFixture::client().server_reply().in_sync() << ") cal_count("
-           << TestFixture::client().defs()->updateCalendarCount() << ")\n";
-
-        // suiteVec is now invalidated
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
-                              CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
-        boost::posix_time::ptime sync_full_suiteTime =
-            TestFixture::client().defs()->suiteVec()[0]->calendar().suiteTime();
-        ss << "   Sync full suite time :" << to_simple_string(sync_full_suiteTime) << " full_sync("
-           << TestFixture::client().server_reply().full_sync() << ")"
-           << " in_sync(" << TestFixture::client().server_reply().in_sync() << ") cal_count("
-           << TestFixture::client().defs()->updateCalendarCount() << ")\n";
-
-        BOOST_REQUIRE_MESSAGE(sync_clock_suiteTime == sync_full_suiteTime,
-                              ss.str() << "\nloop:" << i << " waited for " << TestFixture::job_submission_interval() + 1
-                                       << "s for each loop"
-                                          "\n"
-                                       << TestFixture::client().defs());
-    }
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestComplete.cpp 5.13.0-1/Test/TestComplete.cpp
--- 5.12.4-1/Test/TestComplete.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestComplete.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,172 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Complete)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-//
-// This test shows the use of repeat and complete. this shows how
-// we can repeat a family without waiting for all the children to
-// complete. See page 65 of user manual
-//
-// As protection against user, a family should not complete
-// if any of its children are still in ACTIVE or SUBMIITED state.
-//
-// **************************************************************************
-// Note: When we use a complete expression. Node resolution will set complete
-//      hierarchically
-// **************************************************************************
-BOOST_AUTO_TEST_CASE(test_complete) {
-    DurationTimer timer;
-    cout << "Test:: ...test_complete " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_complete
-    //   family family
-    //     repeat integer YMD 0 1
-    //     complete ./family/check:nofiles  # repeat family with waiting for children to complete
-    //     task check
-    //       event 1 nofiles
-    //     task t1
-    //       trigger check==complete
-    //       task t2
-    //     trigger t2 == complete   #  never runs
-    //   endfamily
-    // endsuite
-    std::string eventName = "nofiles";
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_complete");
-        family_ptr fam  = suite->add_family("family");
-        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat family 2 times
-        fam->add_complete("/test_complete/family/check:nofiles");
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 2)); // family should complete 2 times
-
-        task_ptr task_check = fam->add_task("check");
-        task_check->addEvent(Event(1, eventName));
-        task_check->addVerify(VerifyAttr(NState::COMPLETE, 2));
-
-        task_ptr task_t1 = fam->add_task("t1");
-        task_t1->add_trigger("check == complete");
-        task_t1->addVerify(VerifyAttr(NState::COMPLETE, 2));
-
-        task_ptr task_t2 = fam->add_task("t2");
-        task_t2->add_trigger("t2 == complete");
-        task_t2->addVerify(VerifyAttr(NState::COMPLETE, 2));
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_complete.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_complete_does_not_hold) {
-    DurationTimer timer;
-    cout << "Test:: ...test_complete_does_not_hold " << flush;
-
-    /// This test shows that a complete expression should not hold a node
-    /// A complete should complete a node, and not hold it
-
-    // suite test_complete
-    //   family family
-    //     complete 1 == 0            # impossible expression that never evaluates
-    //     task t1                    # task t1 should still run
-    //     task t2
-    //         complete 1 == 0        # impossible expression that never evaluates
-    //         trigger t1 == complete # task t2 should still run
-    //     endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_complete_does_not_hold");
-        family_ptr fam  = suite->add_family("family");
-        fam->add_complete("1 == 0");
-        task_ptr t1 = fam->add_task("t1");
-        t1->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        task_ptr t2 = fam->add_task("t2");
-        t2->add_trigger("t1 == complete");
-        t2->add_complete("1 == 0");
-        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_complete_does_not_hold.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_complete_with_empty_family) {
-    DurationTimer timer;
-    cout << "Test:: ...test_complete_with_empty_family " << flush;
-
-    // Test a family with a complete expression and that has no children
-
-    // suite test_complete_with_empty_family
-    //   family empty
-    //      complete /test_complete_with_empty_family/family/t1 == complete and
-    //               /test_complete_with_empty_family/family/t2 == complete
-    //   family family
-    //       task t1
-    //       task t2
-    //     endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite  = theDefs.add_suite("test_complete_with_empty_family");
-        family_ptr empty = suite->add_family("empty");
-        empty->add_complete("/test_complete_with_empty_family/family/t1 == complete and "
-                            "/test_complete_with_empty_family/family/t2 == complete");
-        empty->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        family_ptr fam = suite->add_family("family");
-        fam->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        fam->add_task("t2")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_complete_with_empty_family.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestCron.cpp 5.13.0-1/Test/TestCron.cpp
--- 5.12.4-1/Test/TestCron.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestCron.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,144 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Cron)
-
-static void wait_for_cron(int max_time_to_wait, const std::string& path) {
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    TestFixture::client().set_throw_on_error(false);
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        if (defs) {
-            node_ptr node = defs->findAbsNode(path);
-            BOOST_REQUIRE_MESSAGE(node, "Could not find task at path " << path);
-            if (node) {
-                const std::vector<VerifyAttr>& verifys = node->verifys();
-                BOOST_REQUIRE_MESSAGE(verifys.size() == 1, "Expected 1 verify");
-                if (!verifys.empty()) {
-                    if (verifys[0].actual() == verifys[0].expected()) {
-                        break;
-                    }
-                }
-            }
-        }
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                                  "wait_for_cron: Test wait " << assertTimer.duration()
-                                                              << " taking longer than time constraint of "
-                                                              << assertTimer.timeConstraint() << " aborting\n"
-                                                              << *defs);
-            break;
-        }
-        sleep(1);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_cron_time_series) {
-    DurationTimer timer;
-    cout << "Test:: ...test_cron_time_series " << flush;
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_cron_time_series
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       cron <start> <finish> <incr>
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    std::string path;
-    {
-        // Initialise clock with todays date and time, then create a cron attribute
-        // with a time series, so that task runs 3 times
-
-        // Note: we don't use:
-        //    boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
-        // Because this can fail with:
-        //    Test:: ...test_cron_time_series unknown location(0): fatal error in
-        //             "test_cron_time_series": std::out_of_range:
-        //             TimeSeries::TimeSeries: Invalid time series: Start time(23:58) is greater than end time(00:02)
-        // i.e
-        // if the test is started at 23:58, then adding the end time of by doing start_time + 5 will fail the check
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
-        boost::posix_time::ptime time2        = theLocalTime + minutes(5);
-
-        suite_ptr suite = theDefs.add_suite("test_cron_time_series");
-        ClockAttr clockAttr(theLocalTime, false);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
-
-        CronAttr cronAttr;
-        cronAttr.addTimeSeries(
-            ecf::TimeSlot(time1.time_of_day()), ecf::TimeSlot(time2.time_of_day()), ecf::TimeSlot(0, 2));
-        task->addCron(cronAttr);
-
-        path = task->absNodePath();
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.add_default_sleep_time(
-        false); // avoid missing time steps due to submit->active->complete > job submission interval
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_cron_time_series.def"),
-                          1 /* timeout ignored*/,
-                          false /*waitForTestCompletion*/);
-
-    // crons are *infinite*, just wait for cron to complete 3 times
-    wait_for_cron(40, path);
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestCtsWaitCmd.cpp 5.13.0-1/Test/TestCtsWaitCmd.cpp
--- 5.12.4-1/Test/TestCtsWaitCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestCtsWaitCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,226 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_CtsWaitCmd)
-
-static void create_defs(Defs& theDefs, const std::string& suite_name) {
-    // suite test_wait_cmd
-    //   family family0
-    //       task wait
-    //   family family1
-    //       task a
-    //       task b
-    //   endfamily
-    //   family family2
-    //          task aa
-    //          task bb
-    //    endfamily
-    // endsuite
-    suite_ptr suite = theDefs.add_suite(suite_name);
-    family_ptr fam0 = suite->add_family("family0");
-    task_ptr wait   = fam0->add_task("wait");
-    wait->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
-
-    family_ptr fam1 = suite->add_family("family1");
-    fam1->add_task("a");
-    fam1->add_task("b");
-
-    family_ptr fam2 = suite->add_family("family2");
-    fam2->add_task("aa");
-    fam2->add_task("bb");
-}
-
-static bool wait_for_state(std::vector<std::pair<std::string, NState::State>>& path_state_vec, int max_time_to_wait) {
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs      = TestFixture::client().defs();
-        bool all_states_ok = true;
-        for (size_t i = 0; i < path_state_vec.size(); ++i) {
-            node_ptr node = defs->findAbsNode(path_state_vec[i].first);
-            BOOST_REQUIRE_MESSAGE(node,
-                                  "Could not find path '" << path_state_vec[i].first << "' in the defs\n"
-                                                          << *defs);
-            if (node->state() != path_state_vec[i].second) {
-                all_states_ok = false;
-                break;
-            }
-        }
-        if (all_states_ok)
-            return true;
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                                  "wait_for_state: Test wait " << assertTimer.duration()
-                                                               << " taking longer than time constraint of "
-                                                               << assertTimer.timeConstraint() << " aborting\n"
-                                                               << *defs);
-            break;
-        }
-        sleep(1);
-    }
-    return false;
-}
-
-// Test the wait command. The Wait command is a child command.
-// The wait command is provided an expression. This expression is evaluated
-// in the server. If the evaluate returns false then the client should
-// blocks until the evaluation is true.
-// In this case the job associated with task 'wait' should block until the expression evaluates
-// to true, which should be after the completion of all other tasks
-BOOST_AUTO_TEST_CASE(test_wait_cmd) {
-    DurationTimer timer;
-    cout << "Test:: ...test_wait_cmd " << flush;
-    TestClean clean_at_start_and_end;
-
-    Defs theDefs;
-    create_defs(theDefs, "test_wait_cmd");
-
-    // Create a custom sms file for test_wait_cmd/family0/wait to invoke the child wait command
-    // with an expression that forces it to block, until all other tasks complete
-    std::string templateEcfFileForWait;
-    templateEcfFileForWait += "%include <head.h>\n";
-    templateEcfFileForWait += "\n";
-    templateEcfFileForWait += "echo do some work\n";
-    templateEcfFileForWait += "%ECF_CLIENT_EXE_PATH% --wait=\"../family1/a eq complete and ../family1/b eq complete "
-                              "and ../family2/aa eq complete and ../family2/bb eq complete\"\n";
-    templateEcfFileForWait += "\n";
-    templateEcfFileForWait += "%include <tail.h>\n";
-
-    // The test harness will create corresponding directory structure
-    // Override the default ECF_ file, with our custom ECF_ file
-    std::map<std::string, std::string> taskEcfFileMap;
-    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "wait"), templateEcfFileForWait));
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_wait_cmd.def"), taskEcfFileMap);
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_wait_cmd_parse_fail) {
-    DurationTimer timer;
-    cout << "Test:: ...test_wait_cmd_parse_fail " << flush;
-
-    // This time we add a wait expression that
-    // should fail to parse, and we should return an error
-    // The error should captured by the trap in .ecf script, which will
-    // then abort the task
-    Defs theDefs;
-    create_defs(theDefs, "test_wait_cmd_parse_fail");
-
-    // Create a custom ecf file for test_wait_cmd/family0/wait to invoke the child wait command
-    std::string templateEcfFileForWait;
-    templateEcfFileForWait += "%include <head.h>\n";
-    templateEcfFileForWait += "\n";
-    templateEcfFileForWait += "echo do some work\n";
-    templateEcfFileForWait += "%ECF_CLIENT_EXE_PATH% --wait=\"(((((((((../family1/a eq complete and ../family1/b eq "
-                              "complete and ../family2/aa eq complete and ../family2/bb eq complete\"\n";
-    templateEcfFileForWait += "\n";
-    templateEcfFileForWait += "%include <tail.h>\n";
-
-    std::map<std::string, std::string> taskEcfFileMap;
-    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "wait"), templateEcfFileForWait));
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_wait_cmd_parse_fail.def"),
-                          taskEcfFileMap,
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    // wait for family1 and family2 to complete
-    std::vector<std::pair<std::string, NState::State>> path_state_vec;
-    path_state_vec.push_back(std::make_pair(std::string("/test_wait_cmd_parse_fail/family1"), NState::COMPLETE));
-    path_state_vec.push_back(std::make_pair(std::string("/test_wait_cmd_parse_fail/family2"), NState::COMPLETE));
-    wait_for_state(path_state_vec, 10);
-
-    // wait for 'wait' task to abort
-    path_state_vec.clear();
-    path_state_vec.push_back(std::make_pair(std::string("/test_wait_cmd_parse_fail/family0/wait"), NState::ABORTED));
-    wait_for_state(path_state_vec, 10);
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_wait_cmd_non_existant_paths) {
-    DurationTimer timer;
-    cout << "Test:: ...test_wait_cmd_non_existant_paths " << flush;
-
-    // This time we add a wait expression that should fail
-    // because the paths referenced in the expression don't exist
-    Defs theDefs;
-    create_defs(theDefs, "test_wait_cmd_non_existant_paths");
-
-    // Create a custom ecf file for test_wait_cmd/family0/wait to invoke the child wait command
-    // NOTE: ../family1/FRED does not exist
-    std::string templateEcfFileForWait;
-    templateEcfFileForWait += "%include <head.h>\n";
-    templateEcfFileForWait += "\n";
-    templateEcfFileForWait += "echo do some work\n";
-    templateEcfFileForWait += "%ECF_CLIENT_EXE_PATH% --wait=\"../family1/FRED eq complete and ../family1/b eq complete "
-                              "and ../family2/aa eq complete and ../family2/bb eq complete\"\n";
-    templateEcfFileForWait += "\n";
-    templateEcfFileForWait += "%include <tail.h>\n";
-
-    std::map<std::string, std::string> taskEcfFileMap;
-    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "wait"), templateEcfFileForWait));
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_wait_cmd_non_existant_paths.def"),
-                          taskEcfFileMap,
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    // wait for family1 and family2 to complete
-    std::vector<std::pair<std::string, NState::State>> path_state_vec;
-    path_state_vec.push_back(
-        std::make_pair(std::string("/test_wait_cmd_non_existant_paths/family1"), NState::COMPLETE));
-    path_state_vec.push_back(
-        std::make_pair(std::string("/test_wait_cmd_non_existant_paths/family2"), NState::COMPLETE));
-    wait_for_state(path_state_vec, 10);
-
-    // wait for 'wait' task to abort
-    path_state_vec.clear();
-    path_state_vec.push_back(
-        std::make_pair(std::string("/test_wait_cmd_non_existant_paths/family0/wait"), NState::ABORTED));
-    wait_for_state(path_state_vec, 10);
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestDayDate.cpp 5.13.0-1/Test/TestDayDate.cpp
--- 5.12.4-1/Test/TestDayDate.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestDayDate.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,141 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_DayDate)
-
-BOOST_AUTO_TEST_CASE(test_day_at_midnight) {
-    // See ECFLOW-337 versus ECFLOW-1550
-    DurationTimer timer;
-    cout << "Test:: ...test_day_at_midnight " << flush;
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_time_real_series
-    //  edit SLEEPTIME 1
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <date>
-    //  family family
-    //     day  monday
-    //     time 23:59
-    //     task t1
-    //     task t2   # will stray into Tuesday but should still run
-    //     task t3   # will stray into Tuesday but should still run
-    //     endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_day_at_midnight");
-        ClockAttr clockAttr(boost::posix_time::ptime(date(2019, 9, 9), time_duration(23, 58, 0)),
-                            false); // Monday @ 23:58
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addTime(ecf::TimeAttr("23:59"));
-        fam->addDay(DayAttr(DayAttr::MONDAY));
-        fam->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        task_ptr t2 = fam->add_task("t2");
-        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        t2->add_trigger("t1 == complete");
-
-        task_ptr t3 = fam->add_task("t3");
-        t3->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        t3->add_trigger("t2 == complete");
-    }
-    // cout << "\n" << theDefs;
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_day_at_midnight.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_date_at_midnight) {
-    // See ECFLOW-337 versus ECFLOW-1550
-    DurationTimer timer;
-    cout << "Test:: ...test_date_at_midnight " << flush;
-    TestClean clean_at_start_and_end;
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_time_real_series
-    //  edit SLEEPTIME 1
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  clock real <date>
-    //  family family
-    //     date 9.9.2019 # Monday
-    //     time 23:59
-    //     task t1
-    //     task t2   # will stray into Tuesday but should still run
-    //     task t3   # will stray into Tuesday but should still run
-    //     endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_date_at_midnight");
-        ClockAttr clockAttr(boost::posix_time::ptime(date(2019, 9, 9), time_duration(23, 58, 0)),
-                            false); // Monday @ 23:58
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        fam->addTime(ecf::TimeAttr("23:59"));
-        fam->addDate(DateAttr("9.9.2019"));
-        fam->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        task_ptr t2 = fam->add_task("t2");
-        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        t2->add_trigger("t1 == complete");
-
-        task_ptr t3 = fam->add_task("t3");
-        t3->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        t3->add_trigger("t2 == complete");
-    }
-    // cout << "\n" << theDefs;
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_date_at_midnight.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestEcfNoScriptCmd.cpp 5.13.0-1/Test/TestEcfNoScriptCmd.cpp
--- 5.12.4-1/Test/TestEcfNoScriptCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestEcfNoScriptCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,81 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_EcfNoScriptCmd)
-
-BOOST_AUTO_TEST_CASE(test_ecf_no_script) {
-    // This test is used to case where we ONLY want to execute ECF_JOB_CMD WITHOUT processing .ecf script.
-    // For this ECF_NO_SCRIPT must be set to any value.
-    // The ECF_JOB_CMD must then encompass ecflow_client --init/complete and the environment settings
-    // Additionally the user can see the output by directing the word done to ECF_JOBOUT
-    // Although ServerTestHarness creates the .ecf file, they are ignored when ECF_NO_SCRIPT is specified.
-
-    DurationTimer timer;
-    cout << "Test:: ...test_ecf_no_script " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    //  suite test_ecf_no_script_cmd
-    //       edit ECF_NO_SCRIPT 1
-    //       edit ECF_JOB_CMD "export ECF_PASS=%ECF_PASS%;...."
-    //       task t1
-    //       task t2
-    //      endfamily
-    //  endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_ecf_no_script");
-        suite->add_variable("ECF_NO_SCRIPT", "1");
-        std::string ecf_job_cmd = "export ECF_PASS=%ECF_PASS%;export ECF_PORT=%ECF_PORT%;export "
-                                  "ECF_HOST=%ECF_HOST%;export ECF_NAME=%ECF_NAME%;export ECF_TRYNO=%ECF_TRYNO%;";
-        ecf_job_cmd += "%ECF_CLIENT_EXE_PATH% --init=$$; echo 'test test_ecf_no_script' >> %ECF_JOBOUT%; "
-                       "%ECF_CLIENT_EXE_PATH% --complete";
-        suite->add_variable("ECF_JOB_CMD", ecf_job_cmd);
-        suite->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        suite->add_task("t2")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        // cout << theDefs;
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_ecf_no_script.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestEcfScriptCmd.cpp 5.13.0-1/Test/TestEcfScriptCmd.cpp
--- 5.12.4-1/Test/TestEcfScriptCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestEcfScriptCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_EcfScriptCmd)
-
-BOOST_AUTO_TEST_CASE(test_ECF_SCRIPT_CMD) {
-    DurationTimer timer;
-    cout << "Test:: ...test_ECF_SCRIPT_CMD " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    //  suite test_ECF_SCRIPT_CMD
-    //    family family
-    //      task check
-    //          edit ECF_SCRIPT_CMD "cat $ECF_HOME/test_ECF_SCRIPT_CMD/family/check.ecf"
-    //      task t1
-    //          trigger check == complete
-    //          edit ECF_SCRIPT_CMD "cat $ECF_HOME/test_ECF_SCRIPT_CMD/family/t1.ecf"
-    //    endfamily
-    //  endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_ECF_SCRIPT_CMD");
-        family_ptr fam  = suite->add_family("family");
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        task_ptr task_check = fam->add_task("check");
-        task_check->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        task_check->add_variable("ECF_SCRIPT_CMD",
-                                 "cat " + TestFixture::smshome() + task_check->absNodePath() + File::ECF_EXTN());
-
-        task_ptr task_t1 = fam->add_task("t1");
-        task_t1->add_trigger("check == complete");
-        task_t1->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        task_t1->add_variable("ECF_SCRIPT_CMD",
-                              "cat " + TestFixture::smshome() + task_t1->absNodePath() + File::ECF_EXTN());
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_ECF_SCRIPT_CMD.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestEvents.cpp 5.13.0-1/Test/TestEvents.cpp
--- 5.12.4-1/Test/TestEvents.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestEvents.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,170 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Events)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-
-BOOST_AUTO_TEST_CASE(test_event_and_query) {
-    DurationTimer timer;
-    cout << "Test:: ...test_event_and_query " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    //  suite test_events
-    //    family family1
-    //        task a
-    //          event 1 myEvent          # initial value is clear(default), child command is expected to set
-    //          event ecflow_1527 set    # initial value is set,            child command is expected to clear
-    //          meter myMeter 0 100
-    //          label task_a_label Label1
-    //        task b
-    //           trigger a:myEvent and a:ecflow_1527 == clear
-    //           label task_b_label label1
-    //     endfamily
-    //     family family2
-    //           task aa
-    //              trigger ../family1/a:myMeter >= 90 and ../family1/a:myEvent
-    //           task bb
-    //              trigger ../family1/a:myMeter >= 50  or  ../family1/a:myEvent
-    //      endfamily
-    //  endsuite
-    Defs theDefs;
-    task_ptr task_a;
-    task_ptr task_b;
-    suite_ptr suite;
-    {
-        suite = theDefs.add_suite("test_events");
-        suite->addLimit(Limit("limit_x", 15)); // just to test query ; limit
-        {
-            family_ptr fam = suite->add_family("family1");
-            task_a         = fam->add_task("a");
-            task_a->addMeter(Meter("myMeter", 0, 100, 100));                // ServerTestHarness will add correct ecf
-            task_a->addEvent(Event(1, "myEvent"));                          // ServerTestHarness will add correct ecf
-            task_a->addEvent(Event("ecflow_1527", true /*initial value*/)); // ServerTestHarness will add correct ecf
-            task_a->addLabel(Label("task_a_label", "task_a_label_value"));  // ServerTestHarness will add correct ecf
-            task_a->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-            task_b = fam->add_task("b");
-            task_b->add_trigger("a:myEvent and a:ecflow_1527 == clear");
-            task_b->addLabel(Label(
-                "task_b_label", "task_b_label_value", "new_label_value")); // ServerTestHarness will add correct ecf
-            task_b->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-        {
-            family_ptr fam2  = suite->add_family("family2");
-            task_ptr task_aa = fam2->add_task("aa");
-            task_ptr task_bb = fam2->add_task("bb");
-            task_aa->add_trigger("../family1/a:myMeter >= 90 and ../family1/a:myEvent");
-            task_aa->addVerify(VerifyAttr(NState::COMPLETE, 1));
-            task_bb->add_trigger("../family1/a:myMeter >= 50  or  ../family1/a:myEvent");
-            task_bb->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-        // cout << theDefs;
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_events.def"));
-
-    TestFixture::client().set_child_path(task_a->absNodePath()); // simulate call from a job, to see logging of job/task
-                                                                 // calling TestFixture::client().query()
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("meter", task_a->absNodePath(), "myMeter") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "100",
-                        "Expected query of meter to return 100 but found " << TestFixture::client().get_string());
-
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("event", task_a->absNodePath(), "myEvent") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "set",
-                        "Expected query of event to return 'set' but found " << TestFixture::client().get_string());
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("event", task_a->absNodePath(), "ecflow_1527") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "clear",
-                        "Expected query of event to return 'clear' but found " << TestFixture::client().get_string());
-
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("variable", task_a->absNodePath(), "ECF_TRYNO") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "1",
-                        "Expected query of variable(ECF_TRYNO) to return '1' but found "
-                            << TestFixture::client().get_string());
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("variable", task_a->absNodePath(), "ECF_PORT") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == TestFixture::client().port(),
-                        "Expected query of variable(ECF_PORT) to return "
-                            << TestFixture::client().port() << " but found " << TestFixture::client().get_string());
-
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("trigger", task_a->absNodePath(), "b == complete") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "true",
-                        "Expected query of trigger to return 'true' but found " << TestFixture::client().get_string());
-
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("label", task_a->absNodePath(), "task_a_label") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "task_a_label_value",
-                        "Expected query of label to return 'task_a_label_value' but found "
-                            << TestFixture::client().get_string());
-
-    BOOST_CHECK_MESSAGE(TestFixture::client().query("label", task_b->absNodePath(), "task_b_label") == 0,
-                        "query command failed " << TestFixture::client().errorMsg());
-    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "new_label_value",
-                        "Expected query of label to return 'new_label_value' but found "
-                            << TestFixture::client().get_string());
-
-    // Added since in 5.2.0 (only 5.2.0 server supports this behaviour)
-    if (!getenv("ECF_DISABLE_TEST_FOR_OLD_SERVERS")) {
-        BOOST_CHECK_MESSAGE(TestFixture::client().query("limit", suite->absNodePath(), "limit_x") == 0,
-                            "query command failed " << TestFixture::client().errorMsg());
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "0",
-                            "Expected query of limit to return '0' but found " << TestFixture::client().get_string());
-
-        BOOST_CHECK_MESSAGE(TestFixture::client().query("limit_max", suite->absNodePath(), "limit_x") == 0,
-                            "query command failed " << TestFixture::client().errorMsg());
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "15",
-                            "Expected query of limit_max to return '15' but found "
-                                << TestFixture::client().get_string());
-    }
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestFileCmd.cpp 5.13.0-1/Test/TestFileCmd.cpp
--- 5.12.4-1/Test/TestFileCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestFileCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,139 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/base/cts/user/CFileCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///
-/// \note This is used to INVOKE a SINGLE test. Easier for debugging
-///
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_FileCmd)
-
-BOOST_AUTO_TEST_CASE(test_file_cmd) {
-    DurationTimer timer;
-    cout << "Test:: ...test_file_cmd " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocate-able
-    // suite test_file_cmd
-    //  edit SLEEPTIME 1
-    //  edit ECF_INCLUDE $ECF_HOME/includes
-    //  family family
-    //     task t1
-    //     task t2
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_file_cmd");
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        family_ptr fam = suite->add_family("family");
-        int taskSize   = 2; // on linux 1024 tasks take ~4 seconds for job submission
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files AND will generate man files for node containers
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.generateManFileForNodeContainers();
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_file_cmd.def"));
-
-    // Now invoke the file command to extract <ecffile,job file,job output, manual >
-    // If the requests succeeded the client needs to create a temporary file, and populate it with
-    // the contents of the string returned from the server
-    TestFixture::client().set_throw_on_error(false);
-
-    std::vector<Node*> nodeVec;
-    theDefs.getAllNodes(nodeVec);
-
-    for (Node* node : nodeVec) {
-
-        string nodePath                            = node->absNodePath();
-        std::vector<CFileCmd::File_t> fileTypesVec = CFileCmd::fileTypesVec();
-        for (size_t i = 0; i < fileTypesVec.size(); i++) {
-
-            string file_type                 = CFileCmd::toString(fileTypesVec[i]);
-            std::vector<std::string> theArgs = CtsApi::file(nodePath, file_type, "10000");
-            std::string args;
-            for (size_t x = 0; x < theArgs.size(); x++) {
-                args += theArgs[x];
-                args += " ";
-            }
-
-            int theResult = TestFixture::client().file(nodePath, file_type, "10000");
-            //         cout << "nodePath = " << nodePath << " fileType = " << file_type << " args passed = " << args <<
-            //         " pass = " << theResult << "\n";
-
-            /// Expect KILL and STAT file types to fail, i.e since we have not called those commands
-            if (fileTypesVec[i] == CFileCmd::KILL || fileTypesVec[i] == CFileCmd::STAT) {
-                BOOST_CHECK_MESSAGE(theResult == 1,
-                                    args << " Expected " << CFileCmd::toString(fileTypesVec[i]) << " to fail");
-                continue;
-            }
-
-            if (node->isSubmittable() || fileTypesVec[i] == CFileCmd::MANUAL) {
-                // For suite and families only manual is valid
-                BOOST_CHECK_MESSAGE(theResult == 0,
-                                    args << " failed for Node should return 0.\n"
-                                         << TestFixture::client().errorMsg());
-                BOOST_CHECK_MESSAGE(!TestFixture::client().get_string().empty(), " file contents empty for  " << args);
-            }
-            else {
-                // Should fail
-                BOOST_CHECK_MESSAGE(theResult != 0,
-                                    args << " Expected failure for node " << node->debugNodePath()
-                                         << " with file= " << CFileCmd::toString(fileTypesVec[i]));
-                if (theResult == 0) {
-                    std::cout << "Found file contents:''\n";
-                    std::cout << TestFixture::client().get_string();
-                    std::cout << "''\n";
-                }
-            }
-        }
-    }
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestHandle.cpp 5.13.0-1/Test/TestHandle.cpp
--- 5.12.4-1/Test/TestHandle.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestHandle.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,418 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <limits> // for std::numeric_limits<int>::max()
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///
-/// \note This is used to INVOKE a SINGLE test.
-/// Making it easier for Easier for debugging and development
-///
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Handle)
-
-BOOST_AUTO_TEST_CASE(test_handle) {
-    DurationTimer timer;
-    cout << "Test:: ...test_handle " << flush;
-    TestClean clean_at_start_and_end;
-
-    Defs theDefs;
-    {
-        for (int s = 0; s < 7; s++) {
-            suite_ptr suite = theDefs.add_suite("s" + ecf::convert_to<std::string>(s));
-            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
-            for (int t = 0; t < 2; t++) {
-                suite->add_task("t" + ecf::convert_to<std::string>(t));
-            }
-        }
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_handle.def"),
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    std::vector<std::string> suites_s0_s1_s2;
-    suites_s0_s1_s2.push_back("s0");
-    suites_s0_s1_s2.push_back("s1");
-    suites_s0_s1_s2.push_back("s2");
-    std::vector<std::string> suites_s3_s4;
-    suites_s3_s4.push_back("s3");
-    suites_s3_s4.push_back("s4");
-    std::vector<std::string> suites_s0_s1_s2_s3_s4;
-    suites_s0_s1_s2_s3_s4.push_back("s0");
-    suites_s0_s1_s2_s3_s4.push_back("s1");
-    suites_s0_s1_s2_s3_s4.push_back("s2"), suites_s0_s1_s2_s3_s4.push_back("s3"), suites_s0_s1_s2_s3_s4.push_back("s4");
-    ;
-    std::vector<std::pair<unsigned int, std::vector<std::string>>> ch_suites;
-
-    {
-        // register suites s0,s1,s2
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
-
-        // get the handle associated with the registered suites
-        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
-
-        // Check the sync_local() does a full sync for our handle
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after registering");
-
-        // Now check the suites were registered, correctly
-        TestFixture::client().ch_suites();
-        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
-        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
-        BOOST_CHECK_MESSAGE(ch_suites.size() == 1, "Expected to have registered a single set");
-        BOOST_CHECK_MESSAGE(ch_suites[0].first == client_handle,
-                            "Expected first client handle to be: " << client_handle << ", but found "
-                                                                   << ch_suites[0].first);
-        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2");
-
-        // Now drop the handle and Check handle was dropped
-        TestFixture::client().ch_drop(client_handle);
-        TestFixture::client().ch_suites();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have no registered suites");
-    }
-
-    {
-        // register suites s0,s1,s2
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
-
-        // get the handle associated with the registered suites
-        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
-        BOOST_CHECK_MESSAGE(client_handle == 1, "Expected to have handle 1");
-
-        // Check the sync_local() does a full sync for our handle. *THIS* should also clear the handle_changed flag
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after registering");
-
-        // add additional suites & check suites were added to our handle. Sync_local should returna full_sync()
-        std::vector<std::string> added_suites;
-        added_suites.push_back("s3");
-        added_suites.push_back("s4");
-        TestFixture::client().ch_add(client_handle, added_suites);
-
-        TestFixture::client().ch_suites();
-        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
-        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
-        BOOST_CHECK_MESSAGE(ch_suites.size() == 1, "Expected to have registered a single set");
-        BOOST_CHECK_MESSAGE(ch_suites[0].first == client_handle,
-                            "Expected first client handle to be: " << client_handle << ", but found "
-                                                                   << ch_suites[0].first);
-        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2_s3_s4, "Expected suites s0,s1,s2,s3,s4");
-
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after adding suites.");
-
-        // remove the added suites, and check they were removed
-        TestFixture::client().ch_remove(client_handle, added_suites);
-
-        TestFixture::client().ch_suites();
-        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
-        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
-        BOOST_CHECK_MESSAGE(ch_suites.size() == 1, "Expected to have registered a single set");
-        BOOST_CHECK_MESSAGE(ch_suites[0].first == client_handle,
-                            "Expected first client handle to be: " << client_handle << ", but found "
-                                                                   << ch_suites[0].first);
-        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2");
-
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after removing suites");
-
-        // Now drop the handle and check handle was dropped
-        TestFixture::client().ch_drop(client_handle);
-        TestFixture::client().ch_suites();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have no registered suites");
-    }
-
-    {
-        // register suites s0,s1,s2
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
-
-        // register suite s3,s4
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s3_s4);
-
-        // get all the registered suites
-        TestFixture::client().ch_suites();
-        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
-        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
-        BOOST_CHECK_MESSAGE(ch_suites.size() == 2, "Expected to have 2 registered sets");
-        BOOST_CHECK_MESSAGE(ch_suites[0].first == 1,
-                            "Expected first client handle to be 1, but found " << ch_suites[0].first);
-        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2, in first handle");
-        BOOST_CHECK_MESSAGE(ch_suites[1].first == 2,
-                            "Expected second client handle to be 2, but found " << ch_suites[1].first);
-        BOOST_CHECK_MESSAGE(ch_suites[1].second == suites_s3_s4, "Expected suites s3,s4 , in second handle");
-
-        // Drop all handles
-        for (size_t i = 0; i < ch_suites.size(); i++)
-            TestFixture::client().ch_drop(ch_suites[i].first);
-        TestFixture::client().ch_suites();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have no registered suites");
-    }
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_handle_sync) {
-    DurationTimer timer;
-    cout << "Test:: ...test_handle_sync " << flush;
-    TestClean clean_at_start_and_end;
-
-    Defs theDefs;
-    {
-        for (int s = 0; s < 7; s++) {
-            suite_ptr suite = theDefs.add_suite("s" + ecf::convert_to<std::string>(s));
-            suite->addDefStatus(DState::SUSPENDED);
-            for (int t = 0; t < 2; t++) {
-                suite->add_task("t" + ecf::convert_to<std::string>(t));
-            }
-        }
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_handle_sync.def"),
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    std::vector<std::string> suites_s0_s1_s2;
-    suites_s0_s1_s2.push_back("s0");
-    suites_s0_s1_s2.push_back("s1");
-    suites_s0_s1_s2.push_back("s2");
-    std::vector<std::pair<unsigned int, std::vector<std::string>>> ch_suites;
-
-    {
-        // register suites s0,s1,s2
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
-        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
-        TestFixture::client().news_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after registering");
-        TestFixture::client().sync_local(); // sync for any changes to get full update before test starts
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after registering");
-        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3,
-                            "Expected 3 suites back from sync, after registering 3 suites "
-                                << *TestFixture::client().defs());
-
-        // make a change to a suite not in our handle, that does not cause state propagation.
-        // State propagation changes the defs state. The defs state is sync regardless
-        TestFixture::client().suspend("/s3");
-        TestFixture::client().news_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().get_news(),
-                            "Expected no change since suite s3 is not in our handle");
-
-        // make a change to a suite *not* in our handle, that *does* cause state propagation.
-        TestFixture::client().force("/s3/t0", "aborted");
-        TestFixture::client().news_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(),
-                            "Expected change via state propagation to defs, even though s3 not in our handle");
-
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
-                            "Expected incremental change, not a full update");
-
-        // make a change to a suite in our handle
-        TestFixture::client().force("/s0", "complete");
-        TestFixture::client().news_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news since state changed");
-
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
-                            "Expected incremental change, not a full update");
-
-        TestFixture::client().ch_drop(client_handle);
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have no registered suites");
-    }
-
-    {
-        // register suites s0,s1,s2
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
-        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
-        TestFixture::client().news_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after registering");
-        TestFixture::client().sync_local(); // sync for any changes to get full update before test starts
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after registering");
-
-        // make a small change to a suite *IN* our handle
-        TestFixture::client().force("/s1", "complete");
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
-                            "Expected incremental change, not a full update");
-
-        // Change the order
-        TestFixture::client().order("/s0", "alpha");
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental update");
-
-        TestFixture::client().ch_drop(client_handle);
-        TestFixture::client().suites();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have no registered suites");
-    }
-
-    {
-        // register suites s0,s1,s2
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
-        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
-        TestFixture::client().news_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after registering");
-        TestFixture::client().sync_local(); // sync for any changes to get full update **before** test starts
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after registering");
-
-        // make a small change to a suite *IN* our handle
-        TestFixture::client().force("/s1", "unknown");
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
-                            "Expected incremental change, not a full update");
-
-        // DELETE suite s2, i.e make a change that should force a *FULL* update
-        TestFixture::client().delete_node("/s2", true /*force*/);
-        TestFixture::client().news_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after deleting node");
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(), "Expected full update");
-
-        // Check that suite s2 is STILL in our handle.
-        // delete suites STAY registered until they are explicitly deleted
-        TestFixture::client().ch_suites();
-        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
-        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2, in handle");
-
-        TestFixture::client().ch_drop(client_handle);
-        TestFixture::client().ch_suites();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have no registered suites");
-    }
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_handle_add_remove_add) {
-    DurationTimer timer;
-    cout << "Test:: ...test_handle_add_remove_add " << flush;
-    TestClean clean_at_start_and_end;
-
-    defs_ptr theDefs = Defs::create();
-    {
-        for (int s = 0; s < 3; s++) {
-            suite_ptr suite = theDefs->add_suite("s" + ecf::convert_to<std::string>(s));
-            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
-            for (int t = 0; t < 2; t++) {
-                suite->add_task("t" + ecf::convert_to<std::string>(t));
-            }
-        }
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    // ADD
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(*theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_handle_sync.def"),
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    TestFixture::client().set_throw_on_error(true);
-    std::vector<std::string> suites_s0_s1_s2;
-    suites_s0_s1_s2.push_back("s0");
-    suites_s0_s1_s2.push_back("s1");
-    suites_s0_s1_s2.push_back("s2");
-
-    {
-        // register suites s0
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
-        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
-        BOOST_CHECK_MESSAGE(client_handle == 1, "Expected handle of value 1 but found " << client_handle);
-
-        // Get the registered suites
-        TestFixture::client().ch_suites();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have registered suites");
-
-        // Check the sync_local() does a full sync for our handle
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after registering");
-        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3,
-                            "Expected 3 suites back from sync " << *TestFixture::client().defs());
-
-        // DELETE suites. They should stay *registered*
-        TestFixture::client().delete_node("/s0");
-        TestFixture::client().delete_node("/s1");
-        TestFixture::client().delete_node("/s2");
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after deleting suite");
-        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 0,
-                            "Expected 0 suites back from sync " << *TestFixture::client().defs());
-
-        // Check suites are still registered. Only explicit drop can remove registered suites
-        TestFixture::client().ch_suites();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have registered suites");
-
-        // RELOAD the defs, which includes s0,s1,s2:: THIS SHOULD GET RE_ADDED TO OUR EXISTING HANDLE's
-        // The handle references to the suites should get *refreshed*
-        TestFixture::client().load(theDefs);
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() since client handle should be refreshed with new suite_pts");
-        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3,
-                            "Expected 3 suites back from sync " << *TestFixture::client().defs());
-
-        TestFixture::client().ch_drop(client_handle);
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
-                            "Expected to have no registered suites");
-    }
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestInitAddVariable.cpp 5.13.0-1/Test/TestInitAddVariable.cpp
--- 5.12.4-1/Test/TestInitAddVariable.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestInitAddVariable.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,106 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_InitAddVariable)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-BOOST_AUTO_TEST_CASE(test_init_add_variable) {
-    // Added since in 5.2.0 (only 5.2.0 server supports this behaviour)
-    if (getenv("ECF_DISABLE_TEST_FOR_OLD_SERVERS")) {
-        std::cout << "\n    Disable test_init_add_variable for old server , re-enable when 5.2.0 is minimum version\n";
-        return;
-    }
-
-    DurationTimer timer;
-    cout << "Test:: ...test_init_add_variable " << flush;
-    TestClean clean_at_start_and_end;
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_server_job_submission
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   edit INIT_ADD_VARIABLES --add "NAME1=1" "NAME2=2"
-    //   edit COMPLETE_DEL_VARIABLES --remove NAME1 NAME2
-    //   family family
-    //     task t1     # can't place trigger on t1, otherwise we have dead lock. Variables added at ACTIVE, but trigger
-    //     expression resolved at QUEUE time task t2
-    //       trigger t1:NAME1 == 1 and t1:NAME2 == 2
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_init_add_variable");
-        suite->add_variable("INIT_ADD_VARIABLES", "--add NAME1=1 NAME2=2");
-        suite->add_variable("COMPLETE_DEL_VARIABLES", "--remove NAME1 NAME2");
-        family_ptr fam = suite->add_family("family");
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        task_ptr t1 = fam->add_task("t1");
-        t1->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        t1->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval()));
-
-        task_ptr t2 = fam->add_task("t2");
-        t2->add_trigger("t1 == active and ./t1:NAME1 == 1 and ./t1:NAME2 == 2");
-        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        theDefs.auto_add_externs(); // since NAME1 and NAME2 not defined
-    }
-    // cout << theDefs;
-
-    // The test harness will create corresponding directory structure and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_init_add_variable.def"));
-
-    TestFixture::client().sync_local();
-    BOOST_CHECK_MESSAGE(TestFixture::client().defs(), "Expected defs");
-
-    {
-        node_ptr t1 = TestFixture::client().defs()->findAbsNode("/test_init_add_variable/family/t1");
-        BOOST_CHECK_MESSAGE(t1, "Expected task to be found");
-        const Variable& v1 = t1->findVariable("NAME1");
-        const Variable& v2 = t1->findVariable("NAME2");
-        BOOST_CHECK_MESSAGE(v1.empty() && v2.empty(), "Expected not to find variables NAME1 and NAME2");
-    }
-    {
-        node_ptr t2 = TestFixture::client().defs()->findAbsNode("/test_init_add_variable/family/t2");
-        BOOST_CHECK_MESSAGE(t2, "Expected task to be found");
-        const Variable& v1 = t2->findVariable("NAME1");
-        const Variable& v2 = t2->findVariable("NAME2");
-        BOOST_CHECK_MESSAGE(v1.empty() && v2.empty(), "Expected not to find variables NAME1 and NAME2");
-    }
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestKillCmd.cpp 5.13.0-1/Test/TestKillCmd.cpp
--- 5.12.4-1/Test/TestKillCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestKillCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,149 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///
-/// \note This is used to INVOKE a SINGLE test. Easier for debugging
-///
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_KillCmd)
-
-// forward declare functions
-static bool kill_cmd(bool kill_task);
-static bool waitForTaskState(NState::State state, int max_time_to_wait);
-
-// test:: test the kill command. Create a task that runs a long time
-// The associated job is then killed. This should leave task in aborted state
-BOOST_AUTO_TEST_CASE(test_kill_cmd) {
-    DurationTimer timer;
-    cout << "Test:: ...test_kill_cmd " << flush;
-    TestClean clean_at_start_and_end;
-    BOOST_REQUIRE_MESSAGE(kill_cmd(true), " kill of task '/test_kill_cmd/family/t0' failed");
-    cout << timer.duration() << "\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_hierarchical_kill_cmd) {
-    DurationTimer timer;
-    cout << "Test:: ...test_hierarchical_kill_cmd " << flush;
-    TestClean clean_at_start_and_end;
-    BOOST_REQUIRE_MESSAGE(kill_cmd(false), "kill of suite '/test_kill_cmd' failed");
-    cout << timer.duration() << "\n";
-}
-
-static bool kill_cmd(bool kill_task) {
-    /// Create dir location for log file.
-    std::string defs_location = ServerTestHarness::testDataDefsLocation("test_kill_cmd.def");
-    fs::path new_path         = defs_location;
-    if (!fs::exists(new_path.parent_path())) {
-        File::createMissingDirectories(new_path.parent_path().string());
-    }
-
-    Defs theDefs;
-    std::string kill_path;
-    {
-        suite_ptr suite;
-        if (kill_task)
-            suite = theDefs.add_suite("test_kill_task");
-        else
-            suite = theDefs.add_suite("test_kill_suite");
-        suite->addVariable(Variable("ECF_TRIES", "1")); // do not try again
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t0");
-        task->addMeter(Meter("meter", 0, 200, 100)); // Make sure it run long enough, to receive kill, on slow systems
-        task->addVerify(VerifyAttr(NState::ABORTED, 1)); // task should abort 1 times
-        if (kill_task)
-            kill_path = task->absNodePath();
-        else
-            kill_path = suite->absNodePath();
-    }
-
-    // *******************************************************************
-    // Important: The following will *not* work:
-    //    theDefs.set_server().add_or_update_variables("ECF_TRIES","1");                     // Override ECF_TRIES so
-    //    don't try to restart aborted jobs theDefs.set_server().add_or_update_variables("ECF_KILL_CMD","kill -15
-    //    %ECF_RID%"); // Provide a mechanism to kill the running job
-    // Since calling the begin command in the server,
-    // will update the defs with the server environment, and hence overriding
-    // any env variable of the same name, set here. Hence just use addVariable as above.
-    // *************************************************************************
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, defs_location, 1 /*timeout*/, false /* don't wait for test to finish */);
-
-    // cout << "test_kill_cmd Waiting for task to become active\n";
-    TestFixture::client().set_throw_on_error(false);
-    (void)waitForTaskState(NState::ACTIVE, 10);
-
-    // cout << "test_kill_cmd Now kill the active jobs\n";
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().kill(kill_path) == 0,
-                          CtsApi::to_string(CtsApi::kill(kill_path)) << " failed should return 0.\n"
-                                                                     << TestFixture::client().errorMsg());
-
-    // cout << "test_kill_cmd Wait for the task to be aborted\n";
-    return waitForTaskState(NState::ABORTED, 20);
-}
-
-static bool waitForTaskState(NState::State state, int max_time_to_wait) {
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        vector<Task*> tasks;
-        defs->getAllTasks(tasks);
-        for (Task* task : tasks) {
-            if (task->state() == state) {
-                return true;
-            }
-        }
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                                  "waitForTaskState "
-                                      << NState::toString(state) << " Test wait " << assertTimer.duration()
-                                      << " taking longer than time constraint of " << assertTimer.timeConstraint()
-                                      << " aborting\n"
-                                      << *defs);
-            break;
-        }
-        sleep(2);
-    }
-    return false;
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestLate.cpp 5.13.0-1/Test/TestLate.cpp
--- 5.12.4-1/Test/TestLate.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestLate.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,132 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <limits> // for std::numeric_limits<int>::max()
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/LateAttr.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Late)
-
-BOOST_AUTO_TEST_CASE(test_late) {
-    DurationTimer timer;
-    cout << "Test:: ...test_late " << flush;
-    TestClean clean_at_start_and_end;
-
-    /// This test will sleep longer than the job submission interval
-    /// which cause the task to be late
-    /// as the active time has been set for 1 minute.
-    /// The check for lateness is ONLY done are server poll time.
-    /// Hence the task run time must be at least twice the poll time.
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_late");
-        suite->add_variable(
-            "SLEEPTIME",
-            ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2)); // this will cause the late
-
-        task_ptr task = suite->add_task("t1");
-        ecf::LateAttr lateAttr;
-        lateAttr.addComplete(ecf::TimeSlot(0, 1), true);
-
-        task->addLate(lateAttr);
-
-        suite->add_task("t2")->add_trigger(task->absNodePath() + "<flag>late");
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_late.def"));
-
-    TestFixture::client().set_throw_on_error(true);
-    TestFixture::client().sync_local();
-    BOOST_CHECK_MESSAGE(TestFixture::client().defs(), "Expected defs");
-
-    node_ptr node = TestFixture::client().defs()->findAbsNode("/test_late/t1");
-    BOOST_REQUIRE_MESSAGE(node, "Expected task to be found");
-
-    ecf::LateAttr* late = node->get_late();
-    BOOST_CHECK_MESSAGE(late->isLate(), "Expected late to be set");
-    BOOST_CHECK_MESSAGE(node->flag().is_set(ecf::Flag::LATE), "Expected late flag to be set");
-
-    node_ptr t2 = TestFixture::client().defs()->findAbsNode("/test_late/t2");
-    BOOST_REQUIRE_MESSAGE(t2, "Expected task to be found");
-    BOOST_CHECK_MESSAGE(t2->state() == NState::COMPLETE, "Expected late trigger to work");
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_late_hierarchically) {
-    // ECFLOW-610
-    DurationTimer timer;
-    cout << "Test:: ...test_late_hierarchically " << flush;
-    TestClean clean_at_start_and_end;
-
-    /// This test will sleep longer than the job submission interval
-    /// which cause the task to be late
-    /// as the active time has been set for 1 minute.
-    /// The check for lateness is ONLY done are server poll time.
-    /// Hence the task run time must be at least twice the poll time.
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_late_hierarchically");
-        suite->add_variable(
-            "SLEEPTIME",
-            ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2)); // this will cause the late
-        ecf::LateAttr lateAttr;
-        lateAttr.addComplete(ecf::TimeSlot(0, 1), true);
-        suite->addLate(lateAttr);
-
-        family_ptr fam = suite->add_family("f1");
-        fam->add_task("t1");
-        fam->add_task("t2");
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_late_hierarchically.def"));
-
-    TestFixture::client().set_throw_on_error(true);
-    TestFixture::client().sync_local();
-    BOOST_CHECK_MESSAGE(TestFixture::client().defs(), "Expected defs");
-
-    node_ptr t1 = TestFixture::client().defs()->findAbsNode("/test_late_hierarchically/f1/t1");
-    BOOST_CHECK_MESSAGE(t1, "Expected task to be found");
-    BOOST_CHECK_MESSAGE(t1->flag().is_set(ecf::Flag::LATE), "Expected late flag to be set");
-
-    node_ptr t2 = TestFixture::client().defs()->findAbsNode("/test_late_hierarchically/f1/t2");
-    BOOST_CHECK_MESSAGE(t2, "Expected task to be found");
-    BOOST_CHECK_MESSAGE(t2->flag().is_set(ecf::Flag::LATE), "Expected late flag to be set");
-
-    // cout << TestFixture::client().defs() << "\n";
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestLimit.cpp 5.13.0-1/Test/TestLimit.cpp
--- 5.12.4-1/Test/TestLimit.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestLimit.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,113 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Limit)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-BOOST_AUTO_TEST_CASE(test_limit) {
-    DurationTimer timer;
-    cout << "Test:: ...test_limit " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Test the ecf file can be found via ECF_SCRIPT
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // Create the defs file
-    // suite test_limit
-    //   limit disk 50
-    //   limit fast 1
-    //   edit ECF_HOME data/ECF_HOME    # added by test harness
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     inlimit /suite1:fast
-    //     task t1
-    //     task t2
-    //     task t3
-    //   endfamily
-    //   family family2
-    //     inlimit /suite1:disk 20
-    //     task t1
-    //     task t2
-    //     task t3
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        std::string suiteName   = "test_limit";
-        std::string pathToLimit = "/" + suiteName;
-
-        suite_ptr suite = theDefs.add_suite(suiteName);
-        suite->addLimit(Limit("fast", 1));
-        suite->addLimit(Limit("disk", 50));
-
-        family_ptr fam = suite->add_family("family");
-        fam->addInLimit(InLimit("fast", pathToLimit));
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        int taskSize = 3;
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-
-        family_ptr fam2 = suite->add_family("family2");
-        fam2->addInLimit(InLimit("disk", pathToLimit, 20));
-        fam2->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam2->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_limit.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestOrderCmd.cpp 5.13.0-1/Test/TestOrderCmd.cpp
--- 5.12.4-1/Test/TestOrderCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestOrderCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,252 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <limits> // for std::numeric_limits<int>::max()
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///
-/// \note This is used to INVOKE a SINGLE test.
-/// Making it easier for Easier for debugging and development
-///
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_OrderCmd)
-
-std::vector<std::string> to_string_vec(const std::vector<suite_ptr>& sv) {
-    std::vector<std::string> r;
-    r.reserve(sv.size());
-    for (size_t i = 0; i < sv.size(); i++)
-        r.push_back(sv[i]->name());
-    return r;
-}
-
-std::vector<std::string> to_string_vec(const std::vector<node_ptr>& sv) {
-    std::vector<std::string> r;
-    r.reserve(sv.size());
-    for (size_t i = 0; i < sv.size(); i++)
-        r.push_back(sv[i]->name());
-    return r;
-}
-
-void test_ordering() {
-
-    TestFixture::client().set_throw_on_error(true);
-    std::vector<std::string> str_a_b_c;
-    str_a_b_c.push_back("a");
-    str_a_b_c.push_back("b");
-    str_a_b_c.push_back("c");
-    std::vector<std::string> str_c_b_a;
-    str_c_b_a.push_back("c");
-    str_c_b_a.push_back("b");
-    str_c_b_a.push_back("a");
-    std::vector<std::string> str_b_c_a;
-    str_b_c_a.push_back("b");
-    str_b_c_a.push_back("c");
-    str_b_c_a.push_back("a");
-    std::vector<std::string> str_b_a_c;
-    str_b_a_c.push_back("b");
-    str_b_a_c.push_back("a");
-    str_b_a_c.push_back("c");
-    std::vector<std::string> str_a_c_b;
-    str_a_c_b.push_back("a");
-    str_a_c_b.push_back("c");
-    str_a_c_b.push_back("b");
-    TestFixture::client().sync_local(); // First sync_local will do a full sync
-    {
-        // TEST SUITE ORDERING
-        TestFixture::client().order("/a", NOrder::toString(NOrder::ORDER));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_c_b_a,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a", NOrder::toString(NOrder::ALPHA));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_a_b_c,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a", NOrder::toString(NOrder::BOTTOM));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_b_c_a,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a", NOrder::toString(NOrder::ALPHA));
-        TestFixture::client().order("/a", NOrder::toString(NOrder::DOWN));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_b_a_c,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a", NOrder::toString(NOrder::ALPHA));
-        TestFixture::client().order("/c", NOrder::toString(NOrder::UP));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_a_c_b,
-                            "Order not as expected");
-    }
-    {
-        // TEST FAMILY ordering
-        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ORDER));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_c_b_a,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ALPHA));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_a_b_c,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a/a", NOrder::toString(NOrder::BOTTOM));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_b_c_a,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ALPHA));
-        TestFixture::client().order("/a/a", NOrder::toString(NOrder::DOWN));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_b_a_c,
-                            "Order not as expected");
-
-        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ALPHA));
-        TestFixture::client().order("/a/c", NOrder::toString(NOrder::UP));
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
-        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_a_c_b,
-                            "Order not as expected");
-    }
-}
-
-BOOST_AUTO_TEST_CASE(test_change_order) {
-    DurationTimer timer;
-    cout << "Test:: ...test_change_order " << flush;
-    TestClean clean_at_start_and_end;
-
-    /// NOT: We *DONT* need to run the jobs for this TEST
-    std::vector<std::string> str_a_b_c;
-    str_a_b_c.push_back("a");
-    str_a_b_c.push_back("b");
-    str_a_b_c.push_back("c");
-    Defs theDefs;
-    {
-        for (size_t s = 0; s < str_a_b_c.size(); s++) {
-            suite_ptr suite = theDefs.add_suite(str_a_b_c[s]);
-            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
-            for (size_t f = 0; f < str_a_b_c.size(); f++) {
-                family_ptr fam = suite->add_family(str_a_b_c[f]);
-                for (size_t t = 0; t < str_a_b_c.size(); t++) {
-                    fam->add_task(str_a_b_c[t]);
-                }
-            }
-        }
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_change_order.def"),
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    test_ordering();
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_handle_change_order) {
-    DurationTimer timer;
-    cout << "Test:: ...test_handle_change_order " << flush;
-    TestClean clean_at_start_and_end;
-
-    std::vector<std::string> str_a_b_c;
-    str_a_b_c.push_back("a");
-    str_a_b_c.push_back("b");
-    str_a_b_c.push_back("c");
-    std::vector<std::string> suite_a_b_c_d_e;
-    suite_a_b_c_d_e.push_back("a");
-    suite_a_b_c_d_e.push_back("b");
-    suite_a_b_c_d_e.push_back("c");
-    suite_a_b_c_d_e.push_back("d");
-    suite_a_b_c_d_e.push_back("e");
-    Defs theDefs;
-    {
-        for (size_t s = 0; s < suite_a_b_c_d_e.size(); s++) {
-            suite_ptr suite = theDefs.add_suite(suite_a_b_c_d_e[s]);
-            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
-            for (size_t f = 0; f < str_a_b_c.size(); f++) {
-                family_ptr fam = suite->add_family(str_a_b_c[f]);
-                for (size_t t = 0; t < str_a_b_c.size(); t++) {
-                    fam->add_task(str_a_b_c[t]);
-                }
-            }
-        }
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_change_order.def"),
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    TestFixture::client().set_throw_on_error(true);
-    TestFixture::client().sync_local(); // First sync_local will do a full sync
-    {
-        // register suites a,b,c
-        std::vector<std::string> suites_a_b_c;
-        suites_a_b_c.push_back("a");
-        suites_a_b_c.push_back("b");
-        suites_a_b_c.push_back("c");
-        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_a_b_c);
-
-        // Check the sync_local() does a full sync for our handle
-        TestFixture::client().sync_local();
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
-        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
-                            "Expected a full_sync() after registering");
-        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3, "Expected sync to return 3 suites.");
-    }
-
-    // Do same test, this time sync_local will only return suite a,b,c (i.e suite d,e not registered and hence left out)
-    // Ording should still be applied to the whole suite.
-    test_ordering();
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestQueueCmd.cpp 5.13.0-1/Test/TestQueueCmd.cpp
--- 5.12.4-1/Test/TestQueueCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestQueueCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,102 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_QueueCmd)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-
-BOOST_AUTO_TEST_CASE(test_queue) {
-    DurationTimer timer;
-    cout << "Test:: ...test_queue " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_queue
-    //   family f1
-    //     queue q1 1 2 3
-    //     task t
-    //   endfamily
-    //   family f2
-    //     task a
-    //       queue q2 1 2 3
-    //     task b
-    //       trigger /test_queue/f1:q1 > 1
-    //     task c
-    //       trigger /test_queue/f2/a:q2 > 1
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        std::vector<std::string> queue_items;
-        queue_items.emplace_back("1");
-        queue_items.emplace_back("2");
-        queue_items.emplace_back("3");
-        suite_ptr suite = theDefs.add_suite("test_queue");
-        {
-            family_ptr f1 = suite->add_family("f1");
-            QueueAttr q1("q1", queue_items);
-            f1->add_queue(q1);
-            f1->add_task("t")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-            family_ptr f2 = suite->add_family("f2");
-            task_ptr a    = f2->add_task("a");
-            QueueAttr q2("q2", queue_items);
-            a->add_queue(q2);
-
-            task_ptr b = f2->add_task("b");
-            b->add_trigger("/test_queue/f1:q1 > 1");
-            b->addVerify(VerifyAttr(NState::COMPLETE, 1));
-            task_ptr c = f2->add_task("c");
-            c->add_trigger("/test_queue/f2/a:q2 > 1");
-            c->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-        // cout << theDefs;
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_queue.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestRepeat.cpp 5.13.0-1/Test/TestRepeat.cpp
--- 5.12.4-1/Test/TestRepeat.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestRepeat.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,359 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/base/WhyCmd.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Repeat)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-BOOST_AUTO_TEST_CASE(test_repeat_integer) {
-    DurationTimer timer;
-    cout << "Test:: ...test_repeat_integer " << flush;
-    TestClean clean_at_start_and_end;
-
-    // ********************************************************************************
-    // IMPORTANT: A family will only complete when it has reached the end of the repeats
-    // *********************************************************************************
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_repeat_integer
-    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     repeat integer VAR 0 2 1     # run at 0, 1     2 times
-    //     task t<n>
-    //     ....
-    //   endfamily
-    // endsuite
-
-    // Each task/job should be run *4* times, according to the repeats
-    // Mimics nested loops
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_repeat_integer");
-        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat suite 2 times,
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat family 2 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 4));
-        int taskSize = 2; // on linux 1024 tasks take ~4 seconds for job submission
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // task should complete 4 times
-        }
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_integer.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date) {
-    DurationTimer timer;
-    cout << "Test:: ...test_repeat_date " << flush;
-    TestClean clean_at_start_and_end;
-
-    // ********************************************************************************
-    // IMPORTANT: A family will only complete when it has reached the end of the repeats
-    // *********************************************************************************
-    // suite test_repeat_date
-    // family family
-    //   repeat date DATE 20110630 20110632
-    //   task t<n>
-    //      ....
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_repeat_date");
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatDate("DATE", 20110630, 20110704));
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 5));
-        int taskSize = 2;
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 5));
-        }
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_date.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_date_list) {
-    DurationTimer timer;
-    cout << "Test:: ...test_repeat_date_list " << flush;
-    TestClean clean_at_start_and_end;
-
-    // ********************************************************************************
-    // IMPORTANT: A family will only complete when it has reached the end of the repeats
-    // *********************************************************************************
-    // suite test_repeat_date
-    // family family
-    //   repeat datelist DATE 20110630 20110632
-    //   task t<n>
-    //   ....
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_repeat_date_list");
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatDateList("DATE", {20110630, 20110704}));
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 2));
-        int taskSize = 2;
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 2));
-        }
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_date.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_enumerator) {
-    DurationTimer timer;
-    cout << "Test:: ...test_repeat_enumerator " << flush;
-    TestClean clean_at_start_and_end;
-
-    // ********************************************************************************
-    // IMPORTANT: A family will only complete when it has reached the end of the repeats
-    // *********************************************************************************
-    // suite test_repeat_enumerator
-    //   family top
-    //     family plot
-    //       family iasi_plots
-    //         repeat enumerated month "200801" "200802"
-    //         task t1
-    //       endfamily
-    //     endfamily
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        suite_ptr suite       = theDefs.add_suite("test_repeat_enumerator");
-        family_ptr top        = suite->add_family("top");
-        family_ptr plot       = top->add_family("plot");
-        family_ptr iasi_plots = plot->add_family("iasi_plots");
-        vector<string> months;
-        months.reserve(12);
-        months.push_back("200801");
-        months.push_back("200802");
-        iasi_plots->addRepeat(RepeatEnumerated("month", months));
-        task_ptr t1 = iasi_plots->add_task("t1");
-        t1->addVerify(VerifyAttr(NState::COMPLETE, 2));
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_enumerator.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_repeat_defstatus) {
-    DurationTimer timer;
-    cout << "Test:: ...test_repeat_defstatus " << flush;
-    TestClean clean_at_start_and_end;
-
-    // TEST SHOULD COMPLETE STRAIGHT AWAY SINCE WE HAVE A DEFSTATUS COMPLETE
-    // since the complete state is set on all children of suite.
-
-    // Create the defs file corresponding to the text below
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_repeat_defstatus
-    //   defstatus complete
-    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     repeat integer VAR 0 2 1     # run at 0, 1     2 times
-    //     task t<n>
-    //     ....
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_repeat_defstatus");
-        suite->addDefStatus(DState::COMPLETE);
-        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1));
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1));
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        int taskSize = 2; // on linux 1024 tasks take ~4 seconds for job submission
-        for (int i = 0; i < taskSize; i++) {
-
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_defstatus.def"));
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-// #define DEBUG_ME 1
-BOOST_AUTO_TEST_CASE(test_repeat_clears_user_edit) {
-    // Tests code:: Node::requeueOrSetMostSignificantStateUpNodeTree()
-    // In *PARTICULAR* THE REQUE caused by the repeat, this ensures we clear NO_REQUE_IF_SINGLE_TIME_DEP
-    // So that the effect of manual run/force complete are negated via automated re-queue caused by a REPEAT
-
-    DurationTimer timer;
-    cout << "Test:: ...test_repeat_clears_user_edit " << flush;
-    TestClean clean_at_start_and_end;
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_repeat_clears_user_edit
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     repeat integer VAR 0 3     # run at 0,1,2    i.e 3 times
-    //     task t<n>
-    //       time <current time>
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    task_ptr task;
-    {
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-        boost::posix_time::ptime time1        = theLocalTime + minutes(3);
-
-        suite_ptr suite = theDefs.add_suite("test_repeat_clears_user_edit");
-        ClockAttr clockAttr(theLocalTime, false);
-        suite->addClock(clockAttr);
-
-        suite->addDefStatus(DState::SUSPENDED);
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatInteger("VAR", 0, 2, 1)); // repeat family 3 times
-        task = fam->add_task("t1");
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3));
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_repeat_integer.def"),
-                          40,
-                          false /* waitFortestcompletion */);
-
-#ifdef DEBUG_ME
-    PrintStyle style(PrintStyle::STATE);
-    TestFixture::client().sync_local();
-    defs_ptr server_defs = TestFixture::client().defs();
-    cout << "At start ============================================\n";
-    cout << server_defs << "\n";
-#endif
-
-    // USER EDIT, on task with a time. The force complete will expire the time.
-    // Forcing a task with the time attribute, to complete state, should invalidate/expire the time,
-    // Hence it should hold indefinitely, or until it is re-queued manually, or automatically via a Repeat/cron.
-    // This Test ensures the the *REQUEUE* via the repeat, resets the time based attribute
-    TestFixture::client().force(task->absNodePath(), "complete", true);
-    TestFixture::client().force(task->absNodePath(), "complete", true);
-
-#ifdef DEBUG_ME
-    TestFixture::client().sync_local();
-    server_defs = TestFixture::client().defs();
-    cout << "After 2 force complete ============================================\n";
-    cout << server_defs << "\n";
-
-    node_ptr the_task = server_defs->findAbsNode(task->absNodePath());
-    BOOST_REQUIRE_MESSAGE(the_task, "Task " << task->absNodePath() << " not found");
-    WhyCmd whyCmd(server_defs, the_task->absNodePath());
-    std::string reason = whyCmd.why();
-    cout << "Why command ============================================\n";
-    std::cout << reason << "\n\n";
-#endif
-
-    // resume the suspend suite
-    TestFixture::client().resume("/test_repeat_clears_user_edit");
-
-#ifdef DEBUG_ME
-    TestFixture::client().sync_local();
-    server_defs = TestFixture::client().defs();
-    cout << "At Resume ============================================\n";
-    cout << server_defs << "\n";
-#endif
-
-    // Wait for final LOOP of the repeat, and test to finish
-    int timeout             = 20;
-    bool verifyAttrInServer = true;
-    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
-    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return defs after wait of 20 seconds");
-
-#ifdef DEBUG_ME
-    cout << "At test finish ============================================\n";
-    cout << serverDefs << "\n";
-#endif
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestRequeueNode.cpp 5.13.0-1/Test/TestRequeueNode.cpp
--- 5.12.4-1/Test/TestRequeueNode.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestRequeueNode.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,113 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_RequeueNode)
-
-BOOST_AUTO_TEST_CASE(test_requeue_node) {
-    DurationTimer timer;
-    cout << "Test:: ...test_requeue_node " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_repeat_integer
-    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     repeat integer VAR 0 2 1     # run at 0, 1     2 times
-    //     task t<n>
-    //     ....
-    //   endfamily
-    // endsuite
-
-    // Each task/job should be run *4* times, according to the repeats Mimics nested loops
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_requeue_node");
-        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat suite 2 times
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
-        family_ptr fam = suite->add_family("family");
-        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat family 2 times
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 4));
-        int taskSize = 2; // on linux 1024 tasks take ~4 seconds for job submission
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // task should complete 4 times
-        }
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_requeue_node.def"));
-
-    // Now re-queue the whole suite
-    TestFixture::client().set_throw_on_error(true);
-    TestFixture::client().requeue("/test_requeue_node");
-
-    // Wait for test to finish
-    int timeout             = 30;
-    bool verifyAttrInServer = false;
-    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
-    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return server after re-queue");
-
-    // cout << "Printing Defs \n";
-    // std::cout << *serverDefs.get();
-
-    // since we requeue, each task should have completed 8 times
-    std::vector<Task*> taskVec;
-    serverDefs->getAllTasks(taskVec);
-    for (Task* t : taskVec) {
-        for (const VerifyAttr& v : t->verifys()) {
-            if (v.state() == NState::COMPLETE) {
-                BOOST_CHECK_MESSAGE(v.actual() == 8,
-                                    "Expected task " << t->absNodePath()
-                                                     << " to complete 8 times, due to reque, but it completed only "
-                                                     << v.actual() << " times\n");
-            }
-        }
-    }
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestServer.cpp 5.13.0-1/Test/TestServer.cpp
--- 5.12.4-1/Test/TestServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,155 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Server)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-BOOST_AUTO_TEST_CASE(test_server_job_submission) {
-    DurationTimer timer;
-    cout << "Test:: ...test_server_job_submission " << flush;
-    TestClean clean_at_start_and_end;
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_server_job_submission
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     task t<n>
-    //     ....
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_server_job_submission");
-        family_ptr fam  = suite->add_family("family");
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        int taskSize = 3; // on linux 1024 tasks take ~4 seconds for job submission
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-    }
-
-    // The test harness will create corresponding directory structure and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_server_job_submission.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_restore_defs_from_check_pt) {
-    DurationTimer timer;
-    cout << "Test:: ...test_restore_defs_from_check_pt " << flush;
-    TestClean clean_at_start_and_end;
-    // **********************************************************************
-    // In order for this test to work, we need to disable the automatic
-    // check pointing done by the server. Otherwise it will interfere with
-    // this test. This is re-enabled at the end of the test
-    // ************************************************************************
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_restore_defs_from_check_pt");
-        suite->addTask(Task::create("t1"));
-        theDefs.addSuite(suite);
-    }
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_restore_defs_from_check_pt.def"));
-
-    TestFixture::client().set_throw_on_error(false);
-
-    // Disable server check pointing
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().checkPtDefs(ecf::CheckPt::NEVER) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::NEVER) << " failed should return 0\n"
-                                                                   << TestFixture::client().errorMsg());
-
-    Host h;
-    std::string check_pt_file_name = h.ecf_checkpt_file(TestFixture::port());
-
-    // make sure we have a valid definition with at least one suite before start
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0, "Expected getDefs() to succeed\n");
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 1, "Expected 1 suite at the start\n");
-
-    // Check pt, make sure file exist on disk and has a non zero file size\n";
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().checkPtDefs() == 0,
-                          "Expected Check-pt to succeed.\n"
-                              << TestFixture::client().errorMsg());
-    BOOST_REQUIRE_MESSAGE(fs::exists(check_pt_file_name),
-                          CtsApi::checkPtDefs() << " failed file(" << check_pt_file_name << ") not saved");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(check_pt_file_name) != 0,
-                          "Expected check point file(" << check_pt_file_name << ") to have file size > 0");
-
-    // Make sure restore from check pt, only works if server is halted and there are no suites\n";
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().restoreDefsFromCheckPt() == 1,
-                          "Expected restoreDefsFromCheckPt to *FAIL* since server not halted\n");
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().haltServer() == 0,
-                          "Expected halt server to succeed\n"
-                              << TestFixture::client().errorMsg());
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().restoreDefsFromCheckPt() == 1,
-                          "Expected restoreDefsFromCheckPt to *FAIL* since definition not deleted yet\n");
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_all() == 0,
-                          "Expected delete all nodes to succeed\n"
-                              << TestFixture::client().errorMsg());
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
-                          "Expected getDefs() to succeed, i.e expected empty defs\n");
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().defs()->suiteVec().empty(), "Expected no suites, after delete_all()\n");
-
-    // make sure check pt file still exists, sanity test\n";
-    BOOST_REQUIRE_MESSAGE(fs::exists(check_pt_file_name),
-                          CtsApi::checkPtDefs() << " failed file(" << check_pt_file_name << ") not saved");
-    BOOST_REQUIRE_MESSAGE(fs::file_size(check_pt_file_name) != 0,
-                          "Expected check point file(" << check_pt_file_name << ") to have file size > 0");
-
-    // make sure restore actually worked, by retrieving the definition and counting the suites\n";
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().restoreDefsFromCheckPt() == 0,
-                          "Expected restoreDefsFromCheckPt to *SUCCEED*, since server halted and defs deleted \n"
-                              << TestFixture::client().errorMsg());
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
-                          "Get defs failed should return 0\n"
-                              << TestFixture::client().errorMsg());
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 1,
-                          "Restore from check pt did not work. expected 1 suite but found "
-                              << TestFixture::client().defs()->suiteVec().size());
-
-    // restore default check pointing, for test that follow
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().checkPtDefs(ecf::CheckPt::ON_TIME, 120) == 0,
-                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
-                                                                     << TestFixture::client().errorMsg());
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestSingle.cpp 5.13.0-1/Test/TestSingle.cpp
--- 5.12.4-1/Test/TestSingle.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestSingle.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,260 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <limits> // for std::numeric_limits<int>::max()
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///
-/// \note This is used to INVOKE a SINGLE test.
-/// Making it easier for Easier for debugging and development
-///
-
-BOOST_AUTO_TEST_SUITE(TestSingleSuite)
-
-BOOST_AUTO_TEST_CASE(test_stress) {
-    // at 4000 : limit reached os cannot create more than 3946 process
-    //   Job creation failed for task /test_stress/family/t3996 could not create child process
-    int no_of_tasks_to_run                       = 250;
-    int run_test_for_n_seconds                   = 240;
-    int max_time_for_suspended_suite_to_complete = 60;
-
-    DurationTimer timer;
-    std::string test_name      = "test_stress";
-    std::string test_name_path = "/" + test_name;
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite(test_name);
-        family_ptr fam  = suite->add_family("family");
-        for (int i = 0; i < no_of_tasks_to_run; i++) {
-            task_ptr t = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            t->addRepeat(RepeatDay(1));
-            t->addEvent(Event("event"));
-            t->addLabel(Label("name", "value"));
-            t->addMeter(Meter("meter", 0, 10));
-        }
-    }
-
-    // BOOST_REQUIRE_MESSAGE(TestFixture::job_submission_interval()==60,"Job submission interval not set correctly
-    // expected 60 but found " << TestFixture::job_submission_interval());
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation(test_name + ".def"),
-                          120 /*timeout ignored*/,
-                          false /*don't wait for test completion */);
-
-    cout << "Timing test for " << run_test_for_n_seconds << "... seconds  no_of_tasks_to_run " << no_of_tasks_to_run
-         << endl;
-
-    TestFixture::client().set_throw_on_error(false);
-    sleep(run_test_for_n_seconds);
-    cout << "   suspending suite, to let jobs complete" << endl;
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                          "sync_local failed should return 0\n"
-                              << TestFixture::client().errorMsg());
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().suspend(test_name_path) == 0,
-                          "suspend failed should return 0\n"
-                              << TestFixture::client().errorMsg());
-
-    cout << "   Waiting " << max_time_for_suspended_suite_to_complete << " seconds for all jobs to complete" << endl;
-    AssertTimer assertTimer(max_time_for_suspended_suite_to_complete,
-                            false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        sleep(3);
-
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        if (defs) {
-            int no_of_active_tasks    = 0;
-            int no_of_submitted_tasks = 0;
-            std::vector<Task*> vec;
-            defs->getAllTasks(vec);
-            for (size_t i = 0; i < vec.size(); i++) {
-                if (vec[i]->get_state().first == NState::ACTIVE)
-                    no_of_active_tasks++;
-                else if (vec[i]->get_state().first == NState::SUBMITTED)
-                    no_of_submitted_tasks++;
-            }
-            cout << "   still active:" << no_of_active_tasks << "  still submitted:" << no_of_submitted_tasks << endl;
-            if (no_of_active_tasks == 0 && no_of_submitted_tasks == 0)
-                break;
-        }
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                                  "   test_stress : Test wait " << assertTimer.duration()
-                                                                << " taking longer than time constraint of "
-                                                                << assertTimer.timeConstraint() << " aborting\n");
-            break;
-        }
-    }
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-// DO NOT delete
-// This is used to test large defs. and hence server performance & memory leaks
-// Be sure to comment out defstatus suspended in mega.def
-// BOOST_AUTO_TEST_CASE( test_mega_def )
-//{
-//   DurationTimer timer;
-//
-//   // location to mega.def and left over log file
-//   std::string log_file = File::test_data("ANode/parser/test/data/single_defs/mega.def_log","parser");
-//   std::string path = File::test_data("ANode/parser/test/data/single_defs/mega.def","parser");
-//
-//   cout << "Test:: ..." << path << " log file: " << log_file << flush;
-//
-//   // Remove the log file.
-//   fs::remove(log_file);
-//
-//   // parse in file
-//   Defs theDefs;
-//   std::string errorMsg,warningMsg;
-//   BOOST_REQUIRE_MESSAGE(theDefs.restore(path,errorMsg,warningMsg),errorMsg);
-//
-//   ServerTestHarness serverTestHarness;
-//   serverTestHarness.check_task_duration_less_than_server_poll(false); // Add variable
-//   CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL
-//   serverTestHarness.run(theDefs,path,std::numeric_limits<int>::max()/*timeout*/  );
-//
-//   cout << timer.duration() << "\n";
-//}
-
-// DO NOT delete
-// This is used to test with thousands of labels
-// BOOST_AUTO_TEST_CASE( test_large_client_labels_calls )
-//{
-//   DurationTimer timer;
-//   cout << "Test:: ...test_large_client_labels_calls "<< flush;
-//   TestClean clean_at_start_and_end;
-//
-//   //# Note: we have to use relative paths, since these tests are relocatable
-//   // suite test_large_client_labels_calls
-//   //   family family
-//   //       task t1
-//   //          label name "value"
-//   //    endfamily
-//   // endsuite
-//   Defs theDefs;
-//   {
-//      suite_ptr suite = theDefs.add_suite("test_large_client_labels_calls");
-//      family_ptr fam = suite->add_family("family");
-//      task_ptr t1 = fam->add_task("t1");
-//      t1->addLabel( Label("name","value"));
-//   }
-//
-//   // Create a custom ecf file for test_large_client_labels_calls/family/t1 to invoke label commands
-//   std::string templateEcfFile;
-//   templateEcfFile += "%include <head.h>\n";
-//   templateEcfFile += "\n";
-//   templateEcfFile += "echo do some work\n";
-//   templateEcfFile += "i=1\n";
-//   templateEcfFile += "while [ \"$i\" -le 10000 ] \n";
-//   templateEcfFile += "do\n";
-//   templateEcfFile += "  %ECF_CLIENT_EXE_PATH% --label=name
-//   \"1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890\"\n";
-//   templateEcfFile += "  i=$((i+1))\n";
-//   templateEcfFile += "done\n";
-//   templateEcfFile += "\n";
-//   templateEcfFile += "%include <tail.h>\n";
-//
-//   // The test harness will create corresponding directory structure
-//   // Override the default ECF file, with our custom ECF_ file
-//   std::map<std::string,std::string> taskEcfFileMap;
-//   taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs,"t1"),templateEcfFile));
-//
-//    // Avoid standard verification since we expect to abort many times
-//   ServerTestHarness serverTestHarness;
-//   serverTestHarness.run(theDefs,ServerTestHarness::testDataDefsLocation("test_large_client_labels_calls.def"),
-//   taskEcfFileMap,1000000);
-//
-//   cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n" <<
-//   endl;
-//}
-//
-
-//// DO NOT delete
-/// The following  test verifies that the job generation is largely linear.
-/// Job submission interval was 3 seconds. In release mode.
-///
-/// Test duration is highly dependent on the OS/process handling.
-/// No of tasks     Job generation    Peak request/sec in server
-///   10                  -
-///   100                 -
-///   500                 -                     364
-///   1000               4                      450
-///   1500               6                      550
-///   2000               9                      880
-///   3000               15                     800
-///   4000               24                     923
-///   5000               29                     800
-///   6000               37                     900
-// void time_for_tasks(int tasks) {
-//
-//    std::string test_name = "test_stress_" + ecf::convert_to<std::string>(tasks);
-//    cout << "Test:: ..." << test_name  << flush;
-//
-//    Defs theDefs;
-//    {
-//       suite_ptr suite = theDefs.add_suite( test_name );
-//       family_ptr fam = suite->add_family("fam" );
-//       for(int i = 0; i < tasks; i++) {
-//          fam->add_task( "t" + ecf::convert_to<std::string>(i));
-//       }
-//       //      suite->addRepeat( RepeatDate("YMD",19000101,99991201,1) );
-//    }
-//
-//    ServerTestHarness serverTestHarness;
-//    serverTestHarness.check_task_duration_less_than_server_poll(false); // Add variable
-//    CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL DurationTimer timer;
-//    serverTestHarness.run(theDefs,ServerTestHarness::testDataDefsLocation(test_name + ".def"),
-//    std::numeric_limits<int>::max()/*timeout*/  ); cout << "  " << timer.duration() << "s\n";
-// }
-//
-//// Use to stress test server. i.e continually fire client requests.
-// BOOST_AUTO_TEST_CASE( test_stress )
-//{
-//    time_for_tasks(10);
-//    time_for_tasks(100);
-//    time_for_tasks(500);
-//    time_for_tasks(1000);
-//    time_for_tasks(1500);
-//    time_for_tasks(2000);
-//    time_for_tasks(3000);
-//    time_for_tasks(4000);
-//    time_for_tasks(5000);
-// }
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestSingle_main.cpp 5.13.0-1/Test/TestSingle_main.cpp
--- 5.12.4-1/Test/TestSingle_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestSingle_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Single
-#include <boost/test/included/unit_test.hpp>
-
-#include "TestFixture.hpp"
-
-// Global test fixture.
-//
-// Note: Due to boost deficiency this can't be easily accessed, so TestFixture makes use of global data.
-//
-BOOST_GLOBAL_FIXTURE(TestFixture);
diff -pruN 5.12.4-1/Test/TestSpecificIssues.cpp 5.13.0-1/Test/TestSpecificIssues.cpp
--- 5.12.4-1/Test/TestSpecificIssues.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestSpecificIssues.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,92 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_SpecificIssues)
-
-BOOST_AUTO_TEST_CASE(test_ECFLOW_1589) {
-    // Test ECF_JOB_CMD where task *completes* but the ECF_JOB_CMD still fails. i.e ECFLOW-1589
-
-    DurationTimer timer;
-    cout << "Test:: ...test_ECFLOW_1589 " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    //  suite test_ECFLOW_1589
-    //     task t1
-    //  endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_ECFLOW_1589");
-        suite->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        // cout << theDefs;
-    }
-
-    // Create a custom ecf file for test_task_abort_cmd/family0/abort to invoke the child abort command
-    std::string templateEcfFile;
-    templateEcfFile += "%include <head.h>\n";
-    templateEcfFile += "\n";
-    templateEcfFile += "echo do some work\n";
-    templateEcfFile += "\n";
-    templateEcfFile += "%include <bad_tail.h>\n"; // this will exit 1
-
-    // The test harness will create corresponding directory structure
-    // Override the default ECF file, with our custom ECF_ file
-    std::map<std::string, std::string> taskEcfFileMap;
-    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "t1"), templateEcfFile));
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_ECFLOW_1589.def"), taskEcfFileMap);
-
-    // Since the job will call exit 1, i.e from bad_tail.h, we expect ecf::Flag::JOBCMD_FAILED
-    // and since task t1 has *ALREADY* completed we expect ecf::Flag::ZOMBIE
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                          "sync_local failed should return 0\n"
-                              << TestFixture::client().errorMsg());
-    defs_ptr defs = TestFixture::client().defs();
-    // cout << defs;
-    node_ptr task = defs->findAbsNode("/test_ECFLOW_1589/t1");
-    BOOST_REQUIRE_MESSAGE(task, "Expected to find task\n");
-    BOOST_CHECK_MESSAGE(task->flag().is_set(ecf::Flag::ZOMBIE), "expected zombie flag to be set\n");
-    BOOST_CHECK_MESSAGE(task->flag().is_set(ecf::Flag::JOBCMD_FAILED),
-                        "expected JOBCMD_FAILED failed flag to be set\n");
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestSuspend.cpp 5.13.0-1/Test/TestSuspend.cpp
--- 5.12.4-1/Test/TestSuspend.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestSuspend.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,239 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-#if defined(_AIX)
-static int timeout = 30;
-#else
-static int timeout = 20;
-#endif
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Suspend)
-
-static void waitForTimeDependenciesToBeFree(int max_time_to_wait) {
-    // wait for a period of time, while time dependencies fire.
-    TestFixture::client().set_throw_on_error(false);
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        vector<Task*> tasks;
-        defs->getAllTasks(tasks);
-        size_t taskTimeDepIsFree = 0;
-        for (Task* task : tasks) {
-            size_t attSetFree = 0;
-            for (const ecf::TimeAttr& timeAttr : task->timeVec()) {
-                if (timeAttr.isFree(task->suite()->calendar()))
-                    attSetFree++;
-            }
-            if (attSetFree == task->timeVec().size())
-                taskTimeDepIsFree++;
-        }
-        if (taskTimeDepIsFree == tasks.size())
-            break;
-
-        BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                              "waitForTimeDependenciesToBeFree Test wait "
-                                  << assertTimer.duration() << " taking longer than time constraint of "
-                                  << assertTimer.timeConstraint() << " aborting");
-        sleep(1);
-    }
-}
-
-// test:: suspend/shutdown. During suspend the time dependencies should still
-// be handled. When the server/node is restarted/resumed the task should
-// be submitted straight away.(i.e providing no trigger/complete dependencies)
-BOOST_AUTO_TEST_CASE(test_shutdown) {
-    DurationTimer timer;
-    cout << "Test:: ...test_shutdown " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    Defs theDefs;
-    {
-        // Initialise clock with today's date and time, then create a time attribute
-        // with today's time + minute Avoid adding directly to TimeSlot
-        // i.e. if local time is 9:59, and we create a TimeSlot like
-        //     task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
-        // The minute will be 62, which is illegal and will not parse
-        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
-
-        // For each 2 seconds of poll in the server update calendar by 1 minute
-        // Note: if we use 1 seconds poll to update calendar by 1 minute, then
-        //       we will find that state change happens at job submission interval,
-        //       and hence skews time series.  Which can leave state in a queued state,
-        //       and hence test never completes
-        suite_ptr suite = theDefs.add_suite("test_shutdown");
-        ClockAttr clockAttr(theLocalTime);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        int taskSize   = 2; // on linux 1024 tasks take ~4 seconds for job submission
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-
-            boost::posix_time::ptime time1 = theLocalTime + minutes(1 + i);
-            task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
-
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
-        }
-    }
-
-    // The test harness will create corresponding directory structure and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_shutdown.def"),
-                          1,
-                          false /* don't wait for test to finish */);
-
-    // Shutdown the server. The time dependencies *should* still be handled
-    // *** If this test fails, in that we fail to restart() server it will mess up
-    // *** any following test.
-    TestFixture::client().set_throw_on_error(false);
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().shutdownServer() == 0,
-                          CtsApi::shutdownServer() << " failed should return 0.\n"
-                                                   << TestFixture::client().errorMsg());
-
-    // wait for a period of time, while time dependencies fire.
-    (void)waitForTimeDependenciesToBeFree(timeout);
-
-    // restart server, all jobs should be launched straight away
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().restartServer() == 0,
-                          CtsApi::restartServer() << " failed should return 0.\n"
-                                                  << TestFixture::client().errorMsg());
-
-    // Wait for submitted jobs in restart server to complete
-    bool verifyAttrInServer = true;
-    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
-    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return server after restartServer");
-
-    // cout << "Printing Defs \n";
-    // std::cout << *serverDefs.get();
-
-    cout << timer.duration() << " update-calendar-count(" << serverDefs->updateCalendarCount() << ")\n";
-}
-
-// test:: suspend/shutdown. During suspend the time dependencies should still
-// be handled. When the server/node is restarted/resumed the task should
-// be submitted straight away.(i.e providing no trigger/complete dependencies)
-BOOST_AUTO_TEST_CASE(test_suspend_node) {
-    DurationTimer timer;
-    cout << "Test:: ...test_suspend_node " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-    Defs theDefs;
-    {
-        // Initialise clock with today's date and time, then create a time attribute
-        // with today's time + minute Avoid adding directly to TimeSlot
-        // i.e. if local time is 9:59, and we create a TimeSlot like
-        //     task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
-        // The minute will be 62, which is illegal and will not parse
-        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
-
-        suite_ptr suite = theDefs.add_suite("test_suspend_node");
-        ClockAttr clockAttr(theLocalTime);
-        suite->addClock(clockAttr);
-
-        task_ptr t1                    = suite->add_task("t1");
-        boost::posix_time::ptime time1 = theLocalTime + minutes(1);
-        t1->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
-
-        task_ptr t2                    = suite->add_task("t2");
-        boost::posix_time::ptime time2 = theLocalTime + minutes(2);
-        t2->addTime(ecf::TimeAttr(ecf::TimeSlot(time2.time_of_day())));
-
-        family_ptr fam = suite->add_family("family");
-        for (int i = 0; i < 2; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
-
-            boost::posix_time::ptime time3 = theLocalTime + minutes(1 + i);
-            task->addTime(ecf::TimeAttr(ecf::TimeSlot(time3.time_of_day())));
-        }
-    }
-
-    // The test harness will create corresponding directory structure and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_suspend_node.def"),
-                          1,
-                          false /* don't wait for test to finish */);
-
-    // SUSPEND the family. The time dependencies *should* still be handled
-    TestFixture::client().set_throw_on_error(false);
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().suspend("/test_suspend_node/family") == 0,
-                          CtsApi::to_string(CtsApi::suspend("/test_suspend_node/family"))
-                              << " failed should return 0.\n"
-                              << TestFixture::client().errorMsg());
-
-    // wait for a period of time, while time dependencies fire.
-    waitForTimeDependenciesToBeFree(timeout);
-
-    // RESUME the family, all jobs should be launched straight away, since time dependencies should be free
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().resume("/test_suspend_node/family") == 0,
-                          CtsApi::to_string(CtsApi::resume("/test_suspend_node/family"))
-                              << " failed should return 0.\n"
-                              << TestFixture::client().errorMsg());
-
-    // Wait for submitted jobs to complete
-    bool verifyAttrInServer = true;
-    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
-    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return server after restartServer");
-
-    // cout << "Printing Defs \n";
-    // std::cout << *serverDefs.get();
-
-    cout << timer.duration() << " update-calendar-count(" << serverDefs->updateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestTime.cpp 5.13.0-1/Test/TestTime.cpp
--- 5.12.4-1/Test/TestTime.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestTime.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,431 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Time)
-
-BOOST_AUTO_TEST_CASE(test_single_real_time) {
-    DurationTimer timer;
-    cout << "Test:: ...test_single_real_time " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       time 10:00
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with fixed date and time, then create a time attribute
-        // with todays time + minute
-        // Avoid adding directly to TimeSlot
-        // i.e if local time is 9:59 and we create a TimeSlot like
-        //       task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
-        // The the minute will be 62, which is illegal and will not parse
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
-
-        // For each 2 seconds of poll in the server update calendar by 1 minute
-        // Note: if we use 1 seconds poll to update calendar by 1 minute, then
-        //       we will find that state change happens at job submission interval,
-        //       and hence skews time series.  Which can leave state in a queued state,
-        //       and hence test never completes
-        suite_ptr suite = theDefs.add_suite("test_single_real_time");
-        ClockAttr clockAttr(theLocalTime, false);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_single_real_time.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_single_time_trigger) {
-    // ECFLOW-833
-    DurationTimer timer;
-    cout << "Test:: ...test_single_time_trigger " << flush;
-    TestClean clean_at_start_and_end;
-
-    // Create the defs file corresponding to the text below
-    // ECF_HOME variable is automatically added by the test harness.
-    // ECF_INCLUDE variable is automatically added by the test harness.
-    // SLEEPTIME variable is automatically added by the test harness.
-    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
-    //                     This is substituted in sms includes
-    //                     Allows test to run without requiring installation
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       trigger /suite:TIME == 1001
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with fixed date and time, then create a time attribute
-        // with todays time + minute
-        // Avoid adding directly to TimeSlot
-        // i.e if local time is 9:59 and we create a TimeSlot like
-        //       task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
-        // The the minute will be 62, which is illegal and will not parse
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-
-        // For each 2 seconds of poll in the server update calendar by 1 minute
-        // Note: if we use 1 seconds poll to update calendar by 1 minute, then
-        //       we will find that state change happens at job submission interval,
-        //       and hence skews time series.  Which can leave state in a queued state,
-        //       and hence test never completes
-        suite_ptr suite = theDefs.add_suite("test_single_time_trigger");
-        ClockAttr clockAttr(theLocalTime, false);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        std::stringstream ss;
-        ss << "/test_single_time_trigger:TIME == "
-           << "1001";
-        task->add_trigger(ss.str());
-        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_single_time_trigger.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_time_multiple_single_slot) {
-    DurationTimer timer;
-    cout << "Test:: ...test_time_multiple_single_slot " << flush;
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step.
-    // *sometimes* just submitted->active can take many times job submission interval.
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_time_multiple_single_slot
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       time 10:01
-    //       time 10:04
-    //       time 10:07
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with todays date and time, then create a time attribute
-        // with todays time + minute.
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
-        boost::posix_time::ptime time2        = time1 + minutes(TestFixture::job_submission_interval());
-        boost::posix_time::ptime time3        = time2 + minutes(TestFixture::job_submission_interval());
-
-        suite_ptr suite = theDefs.add_suite("test_time_multiple_single_slot");
-        ClockAttr clockAttr(theLocalTime, false);
-        suite->addClock(clockAttr);
-        suite->add_variable("SLEEPTIME", "1");
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time2.time_of_day())));
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time3.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_multiple_single_slot.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_time_relative_time_series) {
-    DurationTimer timer;
-    cout << "Test:: ...test_time_relative_time_series " << flush;
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_time_relative_time_series
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       time +<start> <finish> incr
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with todays date and time, then create a time attribute
-        // with a time series, so that task runs 3 times relative to suite start
-        suite_ptr suite = theDefs.add_suite("test_time_relative_time_series");
-        ClockAttr clockAttr(Calendar::second_clock_time(), false);
-        suite->addClock(clockAttr);
-        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() - 2));
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(
-            ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 7), ecf::TimeSlot(0, 3), true /*relative to suite start*/
-            ));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_relative_time_series.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_time_real_series) {
-    DurationTimer timer;
-    cout << "Test:: ...test_time_real_series " << flush;
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_time_real_series
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <date>
-    //   family family
-    //     task t1
-    //       time <start> <finish> <incr>
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with todays date and time, then create a time attribute
-        // with a time series, so that task runs 3 times
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
-        boost::posix_time::ptime time2        = time1 + minutes(TestFixture::job_submission_interval() * 2);
-
-        suite_ptr suite = theDefs.add_suite("test_time_real_series");
-        suite->add_variable("SLEEPTIME", "1");
-
-        ClockAttr clockAttr(theLocalTime, false);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day()),
-                                    ecf::TimeSlot(time2.time_of_day()),
-                                    ecf::TimeSlot(0, TestFixture::job_submission_interval())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
-                                                          // 1 +    7  + 13
-                                                          // 1 + (2*n) + (2*n) = 1 + 4n
-        // start = 1, finish = 13, when n=3, when n = job submission interval
-        // to complete 3 times, we must use interval of n*2
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    // serverTestHarness.add_default_sleep_time(false); // avoid missing time steps due to submit->active->complete >
-    // job submission interval
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_real_series.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_single_real_time_near_midnight) {
-    DurationTimer timer;
-    cout << "Test:: ...test_single_real_time_near_midnight " << flush;
-    TestClean clean_at_start_and_end;
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite suite
-    //   edit SLEEPTIME 4
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       time 23:59
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // ECFLOW-130
-        // Make sure job completes after midnight.
-        // The task SHOULD stay complete and *NOT* requeue
-        // Since TestHarness requires suite completion, we dont need to do anything.
-        boost::posix_time::ptime time_start  = boost::posix_time::ptime(date(2010, 6, 21), time_duration(23, 59, 0));
-        boost::posix_time::ptime clock_start = time_start - minutes(1);
-
-        suite_ptr suite = theDefs.add_suite("test_single_real_time_near_midnight");
-        ClockAttr clockAttr(clock_start, false);
-        suite->addClock(clockAttr);
-        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2));
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time_start.time_of_day())));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
-    }
-
-    // The test harness will create corresponding directory structure and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_single_real_time_near_midnight.def"));
-
-#ifdef DEBUG_ME
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                          "Could not get the defs from server\n"
-                              << TestFixture::client().errorMsg());
-    defs_ptr defs = TestFixture::client().defs();
-    PrintStyle style(PrintStyle::STATE);
-    std::cout << *defs;
-#endif
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_time_real_series_near_midnight) {
-    DurationTimer timer;
-    cout << "Test:: ...test_time_real_series_near_midnight " << flush;
-    int the_server_version = TestFixture::server_version();
-    if (the_server_version == 403) {
-        cout << " SKIPPING, This test does not work with 403, current server version is " << the_server_version << "\n";
-        return;
-    }
-
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_time_real_series
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <date>
-    //   family family
-    //     task t1
-    //       time <start> <finish> <incr>
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // ECFLOW-130
-        // make sure that last job, *runs* and completes after midnight.
-        // It should stay complete and not requeue.
-        // Test harness, will check suite task->family->suite completes, hence no need to do anything
-        boost::posix_time::ptime last_time   = boost::posix_time::ptime(date(2010, 6, 21), time_duration(23, 59, 0));
-        boost::posix_time::ptime first_time  = last_time - minutes(TestFixture::job_submission_interval() * 2);
-        boost::posix_time::ptime clock_start = first_time - minutes(1);
-
-        suite_ptr suite = theDefs.add_suite("test_time_real_series_near_midnight");
-        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2));
-
-        ClockAttr clockAttr(clock_start, false);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(first_time.time_of_day()),
-                                    ecf::TimeSlot(last_time.time_of_day()),
-                                    ecf::TimeSlot(0, TestFixture::job_submission_interval() * 2)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 2)); // task should complete 2 times
-    }
-
-    // The test harness will create corresponding directory structure and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_real_series_near_midnight.def"));
-
-#ifdef DEBUG_ME
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                          "Could not get the defs from server\n"
-                              << TestFixture::client().errorMsg());
-    defs_ptr defs = TestFixture::client().defs();
-    PrintStyle style(PrintStyle::STATE);
-    std::cout << *defs;
-#endif
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestToday.cpp 5.13.0-1/Test/TestToday.cpp
--- 5.12.4-1/Test/TestToday.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestToday.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,190 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Today)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-BOOST_AUTO_TEST_CASE(test_today_single_slot) {
-    DurationTimer timer;
-    cout << "Test:: ...test_today_single_slot " << flush;
-    TestClean clean_at_start_and_end;
-
-    // **************************************************************************
-    // It does not really make sense to have multiple today attributes
-    // since as soon as one today has expired the task is free to run
-    // suite test_today_mutiple_single_slot
-    //    edit SLEEPTIME 1
-    //    edit ECF_INCLUDE $ECF_HOME/includes
-    //    clock real <todays date>
-    //    family family
-    //       task t1
-    //          today 10.01  // after 10.01, the node is free, for 10.02,10.03
-    //          today 10.04
-    //    endfamily
-    // endsuite
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_today_single_slot
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       today 11.12
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with todays date and time, then create a today attribute
-        // one hour past the clock todays time. The node should be free to run.
-        boost::posix_time::ptime theLocalTime    = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-        boost::posix_time::ptime time_minus_hour = theLocalTime - hours(1);
-
-        suite_ptr suite = theDefs.add_suite("test_today_single_slot");
-        ClockAttr clockAttr(theLocalTime, false, true /*positive gain*/);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addToday(ecf::TodayAttr(ecf::TimeSlot(time_minus_hour.time_of_day())));
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard sms files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_today_single_slot.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_today_relative_time_series) {
-    DurationTimer timer;
-    cout << "Test:: ...test_today_relative_time_series " << flush;
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_today_relative_time_series
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       today <start> <finish> <incr>
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with todays date and time, then create a today attribute
-        // with a time series, so that task runs 3 times
-        suite_ptr suite = theDefs.add_suite("test_today_relative_time_series");
-        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() - 1));
-        ClockAttr clockAttr(Calendar::second_clock_time(), false);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t");
-        task->addToday(ecf::TodayAttr(
-            ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 7), ecf::TimeSlot(0, 3), true /*relative to suite start*/
-            ));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_today_relative_time_series.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_today_real_time_series) {
-    DurationTimer timer;
-    cout << "Test:: ...test_today_real_time_series " << flush;
-    TestClean clean_at_start_and_end;
-
-    // SLOW SYSTEMS
-    // for each time attribute leave GAP of 3 * job submission interval
-    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
-    // Also the task duration must be greater than job_submission_interval,  otherwise
-    // we will get multiple invocation for the same time step
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_today_real_time_series
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   clock real <todays date>
-    //   family family
-    //     task t1
-    //       today 10:01 10:07 00:03
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        // Initialise clock with a fixed date and time, then create a today attribute
-        // with a time series, so that task runs 3 times
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
-        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
-        boost::posix_time::ptime time2        = theLocalTime + minutes(7);
-
-        suite_ptr suite = theDefs.add_suite("test_today_real_time_series");
-        ClockAttr clockAttr(theLocalTime, false);
-        suite->addClock(clockAttr);
-        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() - 1));
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        family_ptr fam = suite->add_family("family");
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        task_ptr task = fam->add_task("t");
-        task->addToday(ecf::TodayAttr(
-            ecf::TimeSlot(time1.time_of_day()), ecf::TimeSlot(time2.time_of_day()), ecf::TimeSlot(0, 3)));
-        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
-    }
-
-    // The test harness will create corresponding directory structure
-    // and populate with standard ecf files.
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_today_real_time_series.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestTrigger.cpp 5.13.0-1/Test/TestTrigger.cpp
--- 5.12.4-1/Test/TestTrigger.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestTrigger.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,143 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <cstdlib>
-#include <fstream>
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "ecflow/attribute/VerifyAttr.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Trigger)
-
-// In the test case we will dynamically create all the test data.
-// The data is created dynamically so that we can stress test the server
-// This test does not have any time dependencies in the def file.
-BOOST_AUTO_TEST_CASE(test_triggers_and_meters) {
-    DurationTimer timer;
-    cout << "Test:: ...test_triggers_and_meters " << flush;
-    TestClean clean_at_start_and_end;
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_triggers_and_meters
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     task model
-    //       meter file 0 100 100
-    //       task t0
-    //         trigger model:file ge 10
-    //       task t1
-    //         trigger model:file ge 20
-    //       task t2
-    //         trigger model:file ge 30
-    //       ....
-    //   endfamily
-    // endsuite
-    std::string meterName = "file";
-    std::string taskName  = "model";
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_triggers_and_meters");
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        family_ptr fam = suite->add_family("family");
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-
-        task_ptr taskModel = fam->add_task(taskName);
-        taskModel->addMeter(Meter(meterName, 0, 100, 100)); // ServerTestHarness will add correct ecf
-
-        int taskSize = 9; // on linux 1024 tasks take ~4 seconds for job submission
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i * 10 + 10));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-            task->add_trigger(taskName + Str::COLON() + meterName + " ge " + ecf::convert_to<std::string>(i * 10 + 10));
-        }
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_triggers_and_meters.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_triggers_with_limits) {
-    // One family is in the limits, another is without. Bit of hack
-    // But shows use of limits in triggers
-    DurationTimer timer;
-    cout << "Test:: ...test_triggers_with_limits " << flush;
-    TestClean clean_at_start_and_end;
-
-    // # Note: we have to use relative paths, since these tests are relocatable
-    // suite test_triggers_with_limits
-    //   limit limit 10
-    //   edit SLEEPTIME 1
-    //   edit ECF_INCLUDE $ECF_HOME/includes
-    //   family family
-    //     inlimit /test_triggers_and_meters:limit 3
-    //     task model
-    //     task t0
-    //     task t1
-    //     task t2
-    //   endfamily
-    //   family other
-    //     trigger /test_triggers_with_limits:limit >1
-    //     task t1
-    //     task t2
-    //   endfamily
-    // endsuite
-    Defs theDefs;
-    {
-        suite_ptr suite = theDefs.add_suite("test_triggers_with_limits");
-        suite->addLimit(Limit("limit", 10));
-        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        family_ptr fam = suite->add_family("family");
-        fam->addInLimit(InLimit("limit", "/test_triggers_with_limits", 3));
-        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        int taskSize = 10;
-        for (int i = 0; i < taskSize; i++) {
-            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-
-        family_ptr fam2 = suite->add_family("other");
-        fam2->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        fam2->add_trigger("/test_triggers_with_limits:limit > 1");
-        for (int i = 0; i < 3; i++) {
-            task_ptr task = fam2->add_task("t" + ecf::convert_to<std::string>(i));
-            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
-        }
-    }
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_triggers_and_meters.def"));
-
-    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestWhyCmd.cpp 5.13.0-1/Test/TestWhyCmd.cpp
--- 5.12.4-1/Test/TestWhyCmd.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestWhyCmd.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,540 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ecflow/base/WhyCmd.hpp"
-#include "ecflow/base/cts/ClientToServerCmd.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Limit.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_WhyCmd)
-
-static unsigned int waitForWhy(const std::string& path, const std::string& why, int max_time_to_wait) {
-    unsigned int updateCalendarCount = 0;
-    TestFixture::client().set_throw_on_error(false);
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-
-        /// Why command relies on the Suite serializing the calendar. If this is changed we need to get the full defs
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-
-        /// called to test that sync suite clock works
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local(true /*sync suite clock*/) == 0,
-                              "sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr server_defs = TestFixture::client().defs();
-        updateCalendarCount  = server_defs->updateCalendarCount();
-
-        WhyCmd whyCmd(server_defs, path);
-        std::string reason = whyCmd.why();
-        // std::cout << reason;
-
-        if (reason.find(why) != std::string::npos) {
-            // see the reason why job is not running
-            std::cout << reason;
-            break;
-        }
-
-        BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                              "waitForWhy Test wait " << assertTimer.duration()
-                                                      << " taking longer than time constraint of "
-                                                      << assertTimer.timeConstraint() << " aborting\n"
-                                                      << *server_defs);
-        sleep(1);
-    }
-    return updateCalendarCount;
-}
-
-BOOST_AUTO_TEST_CASE(test_why_day) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_day " << flush;
-    TestClean clean_at_start_and_end;
-
-    Defs theDefs;
-    {
-        boost::posix_time::ptime today = Calendar::second_clock_time();
-        suite_ptr suite                = Suite::create("test_why_day");
-        family_ptr fam                 = Family::create("family");
-        task_ptr task                  = Task::create("t1");
-
-        // Dont use hybrid for day dependency as that will force node to complete if days is not the same
-        ClockAttr clockAttr(today, false);
-        suite->addClock(clockAttr);
-
-        // ** add tomorrow days so that node stays queued **
-        task->addDay(DayAttr(today.date() + boost::gregorian::date_duration(1)));
-
-        fam->addTask(task);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_day.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // The job should not be submitted and should stay queued since the day does not match
-    // running the why command, should report dependency on day
-    unsigned int updateCalendarCount = waitForWhy("/test_why_day/family/t1", "day", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_date) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_date " << flush;
-
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_why_date");
-        family_ptr fam  = Family::create("family");
-        task_ptr task   = Task::create("t1");
-
-        // Don't use hybrid for date dependency as that will force node to complete if date is not the same
-        boost::posix_time::ptime today = Calendar::second_clock_time();
-        ClockAttr clockAttr(today, false);
-        suite->addClock(clockAttr);
-
-        // ** add tomorrow date so that node stays queued **
-        task->addDate(DateAttr(today.date() + boost::gregorian::date_duration(1)));
-        fam->addTask(task);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_date.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // The job should not be submitted and should stay queued since the day does not match
-    // running the why command, should report dependency on day
-    unsigned int updateCalendarCount = waitForWhy("/test_why_date/family/t1", "date", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_time) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_time " << flush;
-
-    Defs theDefs;
-    {
-        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
-        boost::posix_time::ptime time1        = theLocalTime - hours(1);
-
-        suite_ptr suite = Suite::create("test_why_time");
-        family_ptr fam  = Family::create("family");
-        task_ptr task   = Task::create("t1");
-
-        ClockAttr clockAttr(theLocalTime);
-        suite->addClock(clockAttr);
-
-        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
-        fam->addTask(task);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_time.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // The job should not be submitted and should stay queued since the time does not match
-    // running the why command, should report dependency on time
-    unsigned int updateCalendarCount = waitForWhy("/test_why_time/family/t1", "time", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_today) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_today " << flush;
-
-    Defs theDefs;
-    {
-        // IMPORTANT: A Node with a today attribute is *free* to run *IF* the suite
-        //            calendar time is greater than the today date.
-        //            Hence if we start this test just before midnight i.e 11.20,
-        //            and add hour , then the today time would be 00:20
-        //            *i.e node is free to run*
-        // This is not what we want for this test. i.e we depend on node being queued
-        // in order to test the why command. Also the following tests, start
-        // by deleting all nodes. This will fail due to active/submitted tasks
-        // Hence can *NOT* use:
-        // boost::posix_time::ptime theLocalTime =  Calendar::second_clock_time();
-        // boost::posix_time::ptime time1 =  theLocalTime + hours(1);
-
-        // Use a hard coded a time, to avoid failure if test is run just before midnight
-        boost::posix_time::ptime theLocalTime(date(2010, 2, 10), hours(1));
-        boost::posix_time::ptime time1 = theLocalTime + hours(1);
-
-        suite_ptr suite = theDefs.add_suite("test_why_today");
-        ClockAttr clockAttr(theLocalTime);
-        suite->addClock(clockAttr);
-
-        family_ptr fam = suite->add_family("family");
-        task_ptr task  = fam->add_task("t1");
-        task->addToday(ecf::TodayAttr(ecf::TimeSlot(time1.time_of_day())));
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_today.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // The job should not be submitted and should stay queued since the time does not match
-    // running the why command, should report dependency on time
-    unsigned int updateCalendarCount = waitForWhy("/test_why_today/family/t1", "today", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_cron) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_cron " << flush;
-
-    Defs theDefs;
-    {
-        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(11, 0, 0));
-        boost::posix_time::ptime time1        = theLocalTime - hours(3);
-        boost::posix_time::ptime time2        = theLocalTime - hours(1);
-        boost::gregorian::date todaysDate     = theLocalTime.date();
-
-        suite_ptr suite = Suite::create("test_why_cron");
-        family_ptr fam  = Family::create("family");
-        task_ptr task   = Task::create("t1");
-
-        ClockAttr clockAttr(theLocalTime, false /*real*/);
-        suite->addClock(clockAttr);
-
-        // ** IMPORTANT **, for a date in the future we must match day of week,
-        // ***************  day of month, and year, i.e the results are ANDED
-        // ***************  this can lead to unexpected time in the future
-        // ***************  if all 3 dependencies are present, as *below*
-        ecf::CronAttr cronAttr;
-        ecf::TimeSlot start(time1.time_of_day());  // in the past
-        ecf::TimeSlot finish(time2.time_of_day()); // in the past
-        ecf::TimeSlot incr(0, 5);
-        cronAttr.addTimeSeries(start, finish, incr);
-
-        std::vector<int> weekDays;
-        weekDays.push_back(todaysDate.day_of_week().as_number());
-        std::vector<int> daysOfMonth;
-        daysOfMonth.push_back(todaysDate.day());
-        std::vector<int> months;
-        months.push_back(todaysDate.month());
-        cronAttr.addWeekDays(weekDays);
-        cronAttr.addDaysOfMonth(daysOfMonth);
-        cronAttr.addMonths(months);
-
-        task->addCron(cronAttr);
-
-        fam->addTask(task);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_cron.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // The job should not be submitted and should stay queued we are past the cron time
-    // running the why command, should report dependency on cron
-    unsigned int updateCalendarCount = waitForWhy("/test_why_cron/family/t1", "cron", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_limit) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_limit " << flush;
-
-    // Testing for limits requires that we have least some jobs are submitted.
-    // we need to kill these jobs, at the end of test.
-
-    // suite test_why_limit
-    //   limit disk 50
-    //   family family
-    //     inlimit /suite1:disk 50
-    //     task t0
-    //     task t1
-    //     task t2
-    //     task t3
-    //     task t4
-    //     task t5
-    //   endfamily
-    // endsuite
-
-    Defs theDefs;
-    {
-        std::string suiteName   = "test_why_limit";
-        std::string pathToLimit = "/" + suiteName;
-        suite_ptr suite         = theDefs.add_suite(suiteName);
-        suite->addVariable(Variable("ECF_TRIES", "1"));
-        suite->addLimit(Limit("disk", 50));
-
-        family_ptr fam = suite->add_family("family");
-        fam->addInLimit(InLimit("disk", pathToLimit, 50));
-        int taskSize = 6;
-        for (int i = 0; i < taskSize; i++) {
-            fam->addTask(Task::create("t" + ecf::convert_to<std::string>(i)));
-        }
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_limit.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Only one job should be submitted, at a time, we will query on task t5, which
-    // should still be queued because the limit is full
-    // running the why command, should report dependency on limit
-    waitForWhy("/test_why_limit/family/t5", "limit", 10);
-
-    // The main check is over. Wait for jobs to complete
-    int updateCalendarCount = 0;
-    TestFixture::client().set_throw_on_error(false);
-    {
-        AssertTimer assertTimer(50, false); // Bomb out after n seconds, fall back if test fail
-        while (1) {
-            BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
-                                  CtsApi::get() << " failed should return 0\n"
-                                                << TestFixture::client().errorMsg());
-            defs_ptr defs       = TestFixture::client().defs();
-            updateCalendarCount = defs->updateCalendarCount();
-            bool wait           = false;
-            vector<Task*> tasks;
-            defs->getAllTasks(tasks);
-            for (Task* task : tasks) {
-                if (task->state() != NState::COMPLETE)
-                    wait = true;
-            }
-            if (!wait)
-                break;
-            if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-                cout << "waitFor jobs to complete, wait time of " << assertTimer.duration()
-                     << " taking longer than time constraint of " << assertTimer.timeConstraint()
-                     << " aborting, ......breaking out\n"
-                     << *defs << "\n";
-            }
-            sleep(1);
-        }
-    }
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_trigger) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_trigger " << flush;
-
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_why_trigger");
-        family_ptr fam  = Family::create("family");
-        task_ptr task   = Task::create("t1");
-        task->add_trigger("1 == 0");
-        fam->addTask(task);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_trigger.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Waiting for a trigger expression which will never evaluate
-    unsigned int updateCalendarCount = waitForWhy("/test_why_trigger/family/t1", "expression", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_meter) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_meter " << flush;
-
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_why_meter");
-        family_ptr fam  = Family::create("family");
-        fam->addMeter(Meter("meter", 0, 100, 100));
-        task_ptr task = Task::create("t1");
-        task->add_trigger("/test_why_meter/family:meter > 20");
-        fam->addTask(task);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_meter.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Waiting for a trigger expression which references a meter.
-    unsigned int updateCalendarCount = waitForWhy("/test_why_meter/family/t1", "/test_why_meter/family:meter", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_event) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_event " << flush;
-
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_why_event");
-        family_ptr fam  = Family::create("family");
-        task_ptr t1     = Task::create("t1");
-        task_ptr t2     = Task::create("t2");
-        t2->addEvent(Event(1, "theEvent"));
-        t2->add_trigger("1 == 0"); // make sure task t2 never runs
-        t1->add_trigger("/test_why_event/family/t2:theEvent == set");
-        fam->addTask(t1);
-        fam->addTask(t2);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_event.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Task t1, should stay queued because the event on task t2 is never set.
-    unsigned int updateCalendarCount =
-        waitForWhy("/test_why_event/family/t1", "/test_why_event/family/t2:theEvent", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_user_var) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_user_var " << flush;
-
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_why_user_var");
-        family_ptr fam  = Family::create("family");
-        task_ptr t1     = Task::create("t1");
-        suite->addVariable(Variable("user_var", "10"));
-        t1->add_trigger("/test_why_user_var:user_var eq 100");
-        fam->addTask(t1);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_user_var.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Task t1, should stay queued because the user variable 'user_var' value  = 10, is not 100
-    unsigned int updateCalendarCount = waitForWhy("/test_why_user_var/family/t1", "/test_why_user_var:user_var", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_gen_var) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_gen_var " << flush;
-
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_why_gen_var");
-        family_ptr fam  = Family::create("family");
-        task_ptr t1     = Task::create("t1");
-        t1->add_trigger("/test_why_gen_var/family/t1:ECF_TRYNO eq 100");
-        fam->addTask(t1);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_gen_var.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Task t1, should stay queued because the generated variable 'ECF_TRYNO' value  = 0, is not 100
-    unsigned int updateCalendarCount =
-        waitForWhy("/test_why_gen_var/family/t1", "/test_why_gen_var/family/t1:ECF_TRYNO", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_CASE(test_why_repeat) {
-    DurationTimer timer;
-    cout << "Test:: ...test_why_repeat " << flush;
-
-    Defs theDefs;
-    {
-        suite_ptr suite = Suite::create("test_why_repeat");
-        family_ptr fam  = Family::create("family");
-        task_ptr t1     = Task::create("t1");
-        suite->addRepeat(RepeatInteger("suite_repeat_var", 0, 3, 1));
-        fam->addRepeat(RepeatInteger("family_repeat_var", 0, 3, 1));
-        t1->add_trigger(
-            "/test_why_repeat/family:family_repeat_var eq 100  or /test_why_repeat:suite_repeat_var eq 100");
-        fam->addTask(t1);
-        suite->addFamily(fam);
-        theDefs.addSuite(suite);
-    }
-
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation("test_why_repeat.def"),
-                          1 /*timeout*/,
-                          false /* waitForTestCompletion*/);
-
-    // Task t1, should stay queued because the repeat variable on the suite and family do not match
-    unsigned int updateCalendarCount =
-        waitForWhy("/test_why_repeat/family/t1", "/test_why_repeat/family:family_repeat_var", 10);
-
-    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestZombies.cpp 5.13.0-1/Test/TestZombies.cpp
--- 5.12.4-1/Test/TestZombies.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestZombies.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1228 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <limits> // for std::numeric_limits<int>::max()
-
-#include <boost/date_time/posix_time/posix_time_types.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ServerTestHarness.hpp"
-#include "TestFixture.hpp"
-#include "ZombieUtil.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-using namespace boost::gregorian;
-using namespace boost::posix_time;
-
-///
-/// \note This is used to INVOKE a SINGLE test.
-/// Making it easier for Easier for debugging and development
-///
-
-// ****************************************************************
-// In the test below we create two sets of process. One of these
-// being a zombie. The test below create a list of user Zombies.
-//   In the cases where these test fail
-//   The dump of zombies shows that only One call was made.(i.e the initial creation of the Zombie)
-//   and that the proces-id is not defined.
-//   This implies that at test start, that not all process were started.
-//   ??Note sure why?? This can be seen by enabling debug in TaskCmds which
-//   shows that the Task INIT command was never received ???
-// Updated these test to detect STALE *user* zombies & remove them
-// i.e. where we have created a user Zombie but there is no associated process ??
-// *******************************************************************
-
-#define DO_TEST1 1
-#define DO_TEST2 1
-#define DO_TEST3 1
-#define DO_TEST4 1
-#define DO_TEST5 1
-#define DO_TEST6 1
-#define DO_TEST7 1
-#define DO_TEST8 1
-#define DO_TEST9 1
-#define DO_TEST10 1
-#define DO_TEST11 1
-#define DO_TEST12 1
-
-static bool ecf_debug_enabled = false; // allow environment(ECF_DEBUG_ZOMBIES) to enable debug
-
-BOOST_AUTO_TEST_SUITE(S_Test)
-
-BOOST_AUTO_TEST_SUITE(T_Zombies)
-
-enum WaitType { SINGLE, ALL };
-static int timeout      = 32;
-static int NUM_OF_TASKS = 5;
-
-static std::string dump_tasks(const vector<Task*>& tasks) {
-    std::stringstream ss;
-    ss << "     task status: no of tasks(" << tasks.size() << ")\n";
-    for (const Task* task : tasks) {
-        ss << "      " << task->absNodePath() << " " << NState::toString(task->state())
-           << " passwd:" << task->jobsPassword() << " pid:" << task->process_or_remote_id()
-           << " flag:" << task->get_flag().to_string();
-        if (task->state() == NState::ABORTED)
-            ss << " " << task->abortedReason();
-        ss << "\n";
-    }
-    ss << "\n";
-    return ss.str();
-}
-
-static std::string dump_task_status() {
-    TestFixture::client().sync_local();
-    defs_ptr defs = TestFixture::client().defs();
-    vector<Task*> tasks;
-    defs->getAllTasks(tasks);
-    return dump_tasks(tasks);
-}
-
-static void dump_zombies() {
-    TestFixture::client().zombieGet();
-    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-    std::cout << Zombie::pretty_print(zombies, 6);
-    std::cout << dump_task_status();
-}
-
-static bool waitForTaskStates(WaitType num_of_tasks, NState::State state1, NState::State state2, int max_time_to_wait) {
-    std::string wait_type_str = (num_of_tasks == SINGLE) ? "SINGLE" : "ALL";
-    if (ecf_debug_enabled) {
-        if (num_of_tasks == SINGLE) {
-            if (state1 == state2)
-                std::cout << "\n   Waiting for SINGLE task to reach state " << NState::toString(state1) << "\n";
-            else
-                std::cout << "\n   Waiting for SINGLE task to reach state " << NState::toString(state1) << " || "
-                          << NState::toString(state2) << "\n";
-        }
-        else {
-            if (state1 == state2)
-                std::cout << "\n   Waiting for ALL tasks to reach state " << NState::toString(state1) << "\n";
-            else
-                std::cout << "\n   Waiting for ALL tasks to reach state " << NState::toString(state1) << " || "
-                          << NState::toString(state2) << "\n";
-        }
-    }
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
-                              "waitForTaskStates:*error* sync_local failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        defs_ptr defs = TestFixture::client().defs();
-        vector<Task*> tasks;
-        defs->getAllTasks(tasks);
-        if (num_of_tasks == SINGLE) {
-            for (Task* task : tasks) {
-                if (task->state() == state1 || task->state() == state2) {
-                    if (ecf_debug_enabled) {
-                        if (task->state() == state1)
-                            std::cout << "    Found at least one Task with state " << NState::toString(state1)
-                                      << " returning\n";
-                        if (state1 != state2 && task->state() == state2)
-                            std::cout << "    Found at least one Task with state " << NState::toString(state2)
-                                      << " returning\n";
-                        dump_zombies();
-                    }
-                    return true;
-                }
-            }
-        }
-        else {
-            size_t count = 0;
-            for (Task* task : tasks) {
-                if (task->state() == state1 || task->state() == state2)
-                    count++;
-            }
-            if (count == tasks.size()) {
-                if (ecf_debug_enabled) {
-                    if (state2 == state1)
-                        std::cout << "    All tasks(" << tasks.size() << ") have reached state "
-                                  << NState::toString(state1) << " returning\n";
-                    else
-                        std::cout << "    All tasks(" << tasks.size() << ") have reached state "
-                                  << NState::toString(state1) << " || " << NState::toString(state2) << " returning\n";
-                    dump_tasks(tasks);
-                    dump_zombies();
-                }
-                return true;
-            }
-        }
-
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            if (ecf_debug_enabled) {
-                dump_zombies();
-                dump_tasks(tasks);
-                std::cout << "waitForTaskState " << wait_type_str << " reach state " << NState::toString(state1)
-                          << " || " << NState::toString(state2) << " Test taking longer than time constraint of "
-                          << assertTimer.timeConstraint() << " returning false\n";
-            }
-            break;
-        }
-        sleep(1);
-    }
-    dump_zombies();
-    return false;
-}
-
-static bool waitForTaskState(WaitType wait_type, NState::State state1, int max_time_to_wait) {
-    return waitForTaskStates(wait_type, state1, state1, max_time_to_wait);
-}
-
-static bool waitForZombieCreation(size_t no_of_zombies, int max_time_to_wait) {
-    if (ecf_debug_enabled)
-        std::cout << "\n   Waiting for " << no_of_zombies
-                  << " zombies to be created. max_time_to_wait:" << max_time_to_wait << "s\n";
-
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
-                              "zombieGet failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        if (zombies.size() >= no_of_zombies) {
-            if (ecf_debug_enabled) {
-                std::cout << Zombie::pretty_print(zombies, 3);
-                std::cout << "     Found " << no_of_zombies << " zombies. returning after " << assertTimer.duration()
-                          << "s\n";
-            }
-            return true;
-        }
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            if (zombies.size() > 0) {
-                if (ecf_debug_enabled) {
-                    std::cout << "   *Timeout* out found only " << zombies.size() << " zombies."
-                              << " Quit waiting.\n";
-                    std::cout << Zombie::pretty_print(zombies, 3);
-                }
-                return true;
-            }
-
-            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                                  "\n*error* waitForZombieCreation expected "
-                                      << no_of_zombies << " zombies but found "
-                                      << TestFixture::client().server_reply().zombies().size()
-                                      << " : Test taking longer than time constraint of "
-                                      << assertTimer.timeConstraint() << "s aborting\n"
-                                      << dump_task_status());
-            break;
-        }
-        sleep(1);
-    }
-    return false;
-}
-
-static void remove_stale_zombies() {
-    // Remove those zombies that have only *ZERO* calls hence PID is empty
-    // There is no associated process/child command that has updated the zombie
-    if (ecf_debug_enabled)
-        cout << "\n   remove_stale_zombies\n";
-
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
-                          "*error* zombieGet failed should return 0\n"
-                              << TestFixture::client().errorMsg());
-    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-    for (const Zombie& z : zombies) {
-        if (z.process_or_remote_id().empty()) {
-            cout << "\n      **** removing_stale_zombies ***** " << z << "\n";
-            cout << "        Typically happens when a submitted job, never creates a process ?\n";
-            cout << "        Since the process never communicated back, the pid is empty.\n";
-            TestFixture::client().zombieRemove(z);
-        }
-    }
-}
-
-static void wait_for_zombies_of_type(Child::ZombieType zt, int no_of_tasks, int max_time_to_wait) {
-    if (ecf_debug_enabled)
-        cout << "\n   wait_for_zombies_of_type: " << Child::to_string(zt) << " no_of_tasks:" << no_of_tasks
-             << " max_time_to_wait:" << max_time_to_wait << "s\n";
-
-    std::vector<Zombie> zombies;
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
-                              "*error* zombieGet failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        zombies           = TestFixture::client().server_reply().zombies();
-        int no_of_zombies = 0;
-        for (const Zombie& z : zombies) {
-            if (z.type() == zt)
-                no_of_zombies++;
-        }
-        if (no_of_zombies >= no_of_tasks)
-            break;
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            // BOOST_WARN_MESSAGE(assertTimer.duration() <  assertTimer.timeConstraint(),
-            std::cout << "wait_for_zombies_of_type. Expected " << no_of_tasks << " " << Child::to_string(zt)
-                      << " zombies, but found " << no_of_zombies << "\nTest taking longer than time constraint of "
-                      << assertTimer.timeConstraint() << "\n"
-                      << Zombie::pretty_print(zombies, 6) << "\n"
-                      << dump_task_status() << "\n"
-                      << "... breaking out\n";
-            return;
-        }
-        sleep(1);
-    }
-
-    if (ecf_debug_enabled) {
-        cout << Zombie::pretty_print(zombies, 6) << "\n";
-        cout << dump_task_status();
-    }
-}
-
-static void check_expected_no_of_zombies(size_t expected) {
-    if (ecf_debug_enabled)
-        cout << "   check_expected_no_of_zombies: " << expected << "\n";
-    TestFixture::client().zombieGet();
-    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-
-    BOOST_CHECK_MESSAGE(zombies.size() == expected,
-                        "*error* Expected " << expected << " zombies but got " << zombies.size());
-    if (zombies.size() != expected) {
-        std::cout << Zombie::pretty_print(zombies, 6);
-    }
-}
-
-static void check_expected_no_of_zombies_range(size_t min_expected, size_t max_expected) {
-    if (ecf_debug_enabled)
-        cout << "   check_expected_no_of_zombies_range: min:" << min_expected << " max:" << max_expected << "\n";
-    TestFixture::client().zombieGet();
-    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-
-    bool in_range = (zombies.size() >= min_expected && zombies.size() <= max_expected);
-    BOOST_CHECK_MESSAGE(in_range,
-                        "*error* Expected range(" << min_expected << "-" << max_expected << ") zombies but got "
-                                                  << zombies.size());
-    if (!in_range) {
-        std::cout << Zombie::pretty_print(zombies, 6);
-    }
-}
-
-static int check_at_least_one_zombie() {
-    TestFixture::client().zombieGet();
-    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-    if (ecf_debug_enabled) {
-        std::cout << "\n   check_at_least_one_zombie: actual " << zombies.size() << "\n";
-        std::cout << Zombie::pretty_print(zombies, 6);
-    }
-    BOOST_CHECK_MESSAGE(zombies.size() >= 1, "*error* Expected at least one zombies but got nothing\n");
-    return zombies.size();
-}
-
-static bool wait_for_zombie_termination(int max_time_to_wait) {
-    if (ecf_debug_enabled)
-        std::cout << "\n   wait_for_zombie_termination: max_time_to_wait:" << max_time_to_wait << "\n";
-
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        TestFixture::client().zombieGet();
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        if (zombies.empty()) {
-            if (ecf_debug_enabled)
-                cout << "      zombies empty. Waited for " << assertTimer.duration() << "s returning\n";
-            break;
-        }
-
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            if (ecf_debug_enabled) {
-                std::cout << "      wait_for_zombie_termination: taking longer than time constraint of "
-                          << assertTimer.timeConstraint() << " returning\n";
-                std::cout << Zombie::pretty_print(zombies, 6);
-            }
-            return false;
-        }
-        sleep(1);
-    }
-    return true;
-}
-
-static void wait_for_zombies_child_cmd(WaitType wait_type,
-                                       ecf::Child::CmdType child_cmd,
-                                       int max_time_to_wait,
-                                       bool do_delete = false) {
-    if (ecf_debug_enabled) {
-        std::cout << "\n   Waiting for ";
-        if (wait_type == SINGLE)
-            std::cout << "SINGLE";
-        else
-            std::cout << "ALL";
-        std::cout << "  child (" << Child::to_string(child_cmd) << ") cmd; ";
-        if (do_delete)
-            std::cout << " then DELETE zombies ";
-        std::cout << "=============================================================================================\n";
-    }
-
-    bool child_type_found = false;
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        TestFixture::client().zombieGet();
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        if (ecf_debug_enabled)
-            std::cout << "    Get zombies returned " << zombies.size() << "\n";
-
-        if (zombies.empty() && child_type_found && do_delete) {
-            if (ecf_debug_enabled)
-                std::cout << "   No zombies. (do_delete) was set returning\n";
-            return;
-        }
-
-        size_t completed_zombies = 0;
-        for (const Zombie& z : zombies) {
-            if (ecf_debug_enabled)
-                std::cout << "   " << z << "\n";
-            if (z.last_child_cmd() == child_cmd) {
-                child_type_found = true;
-                completed_zombies++;
-                if (wait_type == SINGLE) {
-                    if (ecf_debug_enabled) {
-                        std::cout << "   " << z << "\n";
-                        std::cout << "   Found SINGLE zombie of correct child type returning\n";
-                    }
-                    return;
-                }
-            }
-        }
-
-        if (completed_zombies == zombies.size() && child_type_found) {
-            if (ecf_debug_enabled) {
-                std::cout << "   Found ALL(" << completed_zombies << ") zombies of child type "
-                          << Child::to_string(child_cmd) << "\n";
-                std::cout << Zombie::pretty_print(zombies, 6);
-            }
-            if (do_delete) {
-                for (const Zombie& z : zombies) {
-                    if (ecf_debug_enabled)
-                        std::cout << "   deleteing " << z << "\n";
-                    TestFixture::client().zombieRemove(z);
-                }
-            }
-            return;
-        }
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            std::cout << Zombie::pretty_print(zombies, 3);
-            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                                  "*error* wait_for_zombies_child_cmd Test wait "
-                                      << assertTimer.duration() << " taking longer than time constraint of "
-                                      << assertTimer.timeConstraint() << " aborting\n");
-        }
-        sleep(1);
-    }
-}
-
-static void wait_for_no_zombies(int max_time_to_wait) {
-    if (ecf_debug_enabled)
-        std::cout << "\n   wait_for_no_zombies, for " << max_time_to_wait << "s\n";
-
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        TestFixture::client().zombieGet();
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        if (ecf_debug_enabled) {
-            std::cout << "      Get zombies returned " << zombies.size() << "\n";
-            if (!zombies.empty())
-                std::cout << Zombie::pretty_print(zombies, 6) << "\n";
-        }
-        if (zombies.empty()) {
-            if (ecf_debug_enabled)
-                std::cout << "      returning after " << assertTimer.duration() << "s\n";
-            return;
-        }
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            std::cout << "\n" << Zombie::pretty_print(zombies, 6);
-            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
-                                  "*error* wait_for_no_zombies Test wait "
-                                      << assertTimer.duration() << " taking longer than time constraint of "
-                                      << assertTimer.timeConstraint() << " aborting\n");
-        }
-        sleep(2);
-    }
-}
-
-static void populate_defs(Defs& theDefs, const std::string& suite_name) {
-    suite_ptr suite = theDefs.add_suite(suite_name);
-    suite->addVariable(Variable("SLEEPTIME", "5")); // sleep for longer than normal to allow for creation of zombies
-    family_ptr family = suite->add_family("f");
-    for (int i = 0; i < NUM_OF_TASKS; i++) {
-        family->add_task("t" + ecf::convert_to<std::string>(i));
-    }
-    suite->add_variable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL", "_any_");
-}
-
-static void
-create_and_start_test(Defs& theDefs, const std::string& suite_name, const std::string& create_zombies_with) {
-    if (ecf_debug_enabled) {
-        std::cout << "   create_and_start_test  " << suite_name << "  using  " << create_zombies_with << "\n";
-    }
-
-    /// Avoid side effects from previous test, by removing all zombies
-    TestFixture::client().zombieGet();
-    if (!TestFixture::client().server_reply().zombies().empty()) {
-        (void)ZombieUtil::do_zombie_user_action(
-            User::REMOVE, TestFixture::client().server_reply().zombies().size(), timeout);
-    }
-
-    if (ecf_debug_enabled)
-        std::cout << "   creating server test harness\n";
-
-    // The test harness will create corresponding directory structure & default ecf file
-    ServerTestHarness serverTestHarness;
-    serverTestHarness.run(theDefs,
-                          ServerTestHarness::testDataDefsLocation(suite_name + ".def"),
-                          1 /*timeout*/,
-                          false /* don't wait for test to finish */);
-
-    // Wait for a single task to reach state submitted or active, before creating zombies
-    waitForTaskStates(SINGLE, NState::SUBMITTED, NState::ACTIVE, timeout);
-
-    // ******************************************************************************
-    // IMPORTANT: If Job generation takes to long i.e >= next poll then it will TIMEOUT.
-    //            Hence use the number of submitted/active tasks, as the expected number of zombies.
-    //            This must be done before creating zombies by changing state.
-    // *******************************************************************************
-    size_t number_submitted_or_active = 0;
-    TestFixture::client().sync_local();
-    defs_ptr defs = TestFixture::client().defs();
-    vector<Task*> tasks;
-    defs->getAllTasks(tasks);
-    for (const auto& task : tasks) {
-        if (task->state() == NState::SUBMITTED || task->state() == NState::ACTIVE)
-            number_submitted_or_active++;
-    }
-    if (ecf_debug_enabled)
-        std::cout << "   found " << number_submitted_or_active << " in submitted or active state\n";
-
-    if (create_zombies_with == "delete") {
-        if (ecf_debug_enabled)
-            std::cout << "   create USER zombies by deleting all the nodes in the server\n";
-        TestFixture::client().delete_all(true /* force */);
-    }
-    else if (create_zombies_with == "begin") {
-        /// Begin with force, Should create user zombies. WILL only catch those task that are submitted
-        /// It may well be that job submission, may only get a subset, others, which come for submission *later*
-        /// on will be ECF zombies.
-        /// Note: If we wait for SUMBITTED, then we get the case, where we have two task jobs
-        ///       with same password, BUT different process id ??????
-        ///       i.e The begin has regenerate the job file, so we get job started twice.
-        ///       This should be trapped by the server, as Task should be active
-        if (ecf_debug_enabled) {
-            std::cout
-                << "   Calling begin_all_suites, now have 2 sets of jobs, The first/original set are now zombies\n";
-            std::cout << "   - Second set of jobs can fail on creation with (Text File busy),\n";
-            std::cout
-                << "     since server is creating a new job file, whilst zombie process in running the same job file\n";
-            std::cout << "   - The first set can fail, because process not created, but server and has created 2nd job "
-                         "file(same path),\n";
-            std::cout << "     but not made it executable yet. Hence expect (exited with status 126) i.e exe' found "
-                         "but not executable\n";
-        }
-        TestFixture::client().set_throw_on_error(false);
-        if (TestFixture::client().begin_all_suites(true /* force */) == 1) {
-            std::cout << "   Begin raised exception: because " << TestFixture::client().errorMsg() << " ***\n";
-        }
-        TestFixture::client().set_throw_on_error(true);
-    }
-    else if (create_zombies_with == "queued") {
-        if (ecf_debug_enabled) {
-            std::cout << "   Creating zombies by setting all tasks to queued\n";
-            std::cout
-                << "   This should increment the try number, avoiding (Text File busy) and (exited with status 126)\n";
-            std::cout
-                << "   Zombies(first set) will have try_no:1 and the queued tasks(second set) will have try number2\n";
-        }
-        std::vector<Task*> tasks;
-        theDefs.getAllTasks(tasks);
-        std::vector<std::string> paths;
-        for (auto task : tasks)
-            paths.emplace_back(task->absNodePath());
-
-        TestFixture::client().set_throw_on_error(false);
-        if (TestFixture::client().force(paths, "queued") == 1) {
-            std::cout << "   force queued raised exception: because " << TestFixture::client().errorMsg() << " ***\n";
-        }
-        TestFixture::client().set_throw_on_error(true);
-    }
-    else if (create_zombies_with == "complete") {
-
-        if (ecf_debug_enabled)
-            std::cout << "   create USER zombies by calling complete\n";
-        std::string path = "/" + suite_name;
-        TestFixture::client().force(path, "complete", true /*recursive*/);
-    }
-    else if (create_zombies_with == "aborted") {
-
-        if (ecf_debug_enabled)
-            std::cout << "   create USER zombies by calling abort\n";
-        std::string path = "/" + suite_name;
-        TestFixture::client().force(path, "aborted", true /*recursive*/);
-    }
-    else {
-        BOOST_REQUIRE_MESSAGE(false, "*error* Create zombies via " << create_zombies_with << " unrecognised");
-    }
-
-    /// When jobs try to communicate with server via child commands they will block the Child commands
-    if (waitForZombieCreation(number_submitted_or_active, timeout)) {
-
-        /// Check we have zombies and they are of type USER
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        BOOST_CHECK_MESSAGE(zombies.size() > 0, "*error* NO zombies created");
-        for (const Zombie& z : zombies) {
-            if (create_zombies_with == "begin") {
-                BOOST_CHECK_MESSAGE(z.type() == Child::USER,
-                                    "*error* Creating zombies via begin, Expected 'user' zombie type but got: " << z);
-            }
-            else if (create_zombies_with == "queued") {
-                BOOST_CHECK_MESSAGE(z.type() == Child::USER,
-                                    "*error* Creating zombies via queued, Expected 'user' zombie type but got: " << z);
-            }
-            else if (create_zombies_with == "delete") {
-                BOOST_CHECK_MESSAGE(
-                    z.type() == Child::USER || z.type() == Child::PATH,
-                    "*error* Creating zombies via delete, Expected 'user | path' zombie type but got: " << z);
-            }
-            else if (create_zombies_with == "complete") {
-                BOOST_CHECK_MESSAGE(z.type() == Child::USER, "*error* Expected 'user' zombie type but got: " << z);
-            }
-            else if (create_zombies_with == "aborted") {
-                BOOST_CHECK_MESSAGE(z.type() == Child::USER, "*error* Expected 'user' zombie type but got: " << z);
-            }
-            else {
-                BOOST_CHECK_MESSAGE(z.type() == Child::ECF, "*error* Expected 'ecf' zombie type but got: " << z);
-            }
-        }
-    }
-    if (ecf_debug_enabled) {
-        cout << dump_task_status();
-    }
-}
-
-static void create_and_start_test(const std::string& suite_name,
-                                  const std::string& create_zombies_with,
-                                  bool add_delay_before_init = false) {
-
-    if (ecf_debug_enabled) {
-        TestFixture::client().get_log_path();
-        std::cout << "\n   Creating defs, log path " << TestFixture::client().get_string() << "\n";
-    }
-    Defs theDefs;
-    populate_defs(theDefs, suite_name);
-    if (add_delay_before_init) {
-        suite_ptr suite = theDefs.findSuite(suite_name);
-        suite->add_variable("ADD_DELAY_BEFORE_INIT", "sleep 1"); // add delay before --init
-        if (ecf_debug_enabled)
-            std::cout << "   adding a delay of 1 second before --init is called\n";
-    }
-    create_and_start_test(theDefs, suite_name, create_zombies_with);
-}
-
-////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-
-BOOST_AUTO_TEST_CASE(enable_debug_for_ECF_TRY_NO_Greater_than_one) {
-    BOOST_CHECK_MESSAGE(true, "dummy test");
-
-    if (getenv("ECF_DEBUG_ZOMBIES")) {
-        ecf_debug_enabled = true;
-        cout << "Test:: ... debug_enabled" << endl;
-    }
-}
-
-#ifdef DO_TEST1
-BOOST_AUTO_TEST_CASE(test_path_zombie_creation) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    cout << "Test:: ...test_path_zombie_creation " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    // User zombies will be converted to path zombies by the server
-    create_and_start_test("test_path_zombie_creation", "delete"); // create zombie via delete
-
-    // The job generation can timeout, hence we may not have submitted the full number of tasks & hence expected zombies
-    // can vary
-    check_expected_no_of_zombies_range(1, NUM_OF_TASKS);
-
-    // The server will automatically change existing zombie to be of type PATH
-    // when no task nodes exists
-    // *Note* in test environment the client invoker will try connecting to the server
-    // ****** for 5 seconds, after that an error is returned. This will cause the
-    // ****** job to abort.
-    wait_for_zombies_of_type(Child::PATH, NUM_OF_TASKS, timeout);
-
-    // Fob all the zombies. This will UNBLOCK the child commands allowing them to complete
-    // Fobing does *NOT* alter node tree state, however COMPLETE should auto delete the zombie
-    // Hence after this command, the number of fobed zombies may *NOT* be the same
-    // as the number of tasks. Since the fobed zombies are auto deleted when a complete
-    // child command is received.
-    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
-    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
-
-    // Wait for zombies to be deleted in the server
-    if (!wait_for_zombie_termination(timeout)) {
-        remove_stale_zombies();
-    }
-
-    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
-    check_expected_no_of_zombies(0);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST2
-BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fob) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    cout << "Test:: ...test_user_zombies_for_delete_fob " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    // User zombies will be converted to path zombies by the server
-    create_and_start_test(
-        "test_user_zombies_for_delete_fob", "delete", true /* add a delay before init */); // create zombie via delete
-
-    // expect at least one zombie
-    (void)check_at_least_one_zombie();
-
-    // Fob all the zombies. This will UNBLOCK the child commands allowing them to finish
-    // Fobing does *NOT* alter node tree state, however COMPLETE should auto delete the zombie
-    // Hence after this command, the number of fobed zombies may *NOT* be the same
-    // as the number of tasks. Since the fobed zombies are auto deleted when a complete
-    // child command is recieved.
-    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
-    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
-
-    // Wait for zombies to be deleted in the server
-    if (!wait_for_zombie_termination(timeout)) {
-        remove_stale_zombies(); // see notes above
-    }
-
-    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
-    check_expected_no_of_zombies(0);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST3
-BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fail) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    cout << "Test:: ...test_user_zombies_for_delete_fail " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    // User zombies will be converted to path zombies by the server
-    create_and_start_test("test_user_zombies_for_delete_fail", "delete");
-
-    check_at_least_one_zombie();
-
-    // Fail all the zombies. This will UNBLOCK and terminate the child commands allowing them to finish
-    int no_of_failed_zombies = ZombieUtil::do_zombie_user_action(User::FAIL, NUM_OF_TASKS, timeout);
-    BOOST_CHECK_MESSAGE(no_of_failed_zombies > 0, "*error* Expected > 0 Failed zombies but found none");
-
-    check_at_least_one_zombie();
-
-    // Wait for zombies to abort, then remove all the zombies
-    wait_for_zombies_child_cmd(ALL, ecf::Child::ABORT, timeout, true /* delete */);
-
-    check_expected_no_of_zombies(0);
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-// test_zombies_attr_for_begin/f/t1 user 26 ZzD/ycIW <pid> 1 calls(1) BLOCK INIT
-
-#ifdef DO_TEST4
-BOOST_AUTO_TEST_CASE(test_user_zombies_for_begin) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    cout << "Test:: ...test_user_zombies_for_begin " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    // Note: if when we start to create zombies and some tasks are still queued *NOT* all will be zombies.
-    create_and_start_test("test_user_zombies_for_begin", "begin");
-
-    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete or abort
-    /// The second set can still abort, if the first set are busy with job file. look for '(Text file busy)'
-    /// Previously we had tried again, but fix for ECFLOW-1216, means we now don't try again,hence allow abort
-    BOOST_REQUIRE_MESSAGE(waitForTaskStates(ALL, NState::COMPLETE, NState::ABORTED, timeout),
-                          "*error* Expected non-zombie tasks to complete or abort");
-
-    // Note: if when we started to create zombies and some tasks are still queued *NOT* all will be zombies.
-    int no_of_zombies = check_at_least_one_zombie();
-
-    // Fob all the zombies. This will UNBLOCK the child commands allowing them to finish
-    // Hence after this command, the number of fobed zombies may *NOT* be the same
-    // as the number of tasks. Since the fobed zombies are auto deleted when a complete
-    // child command is received.
-    //
-    /// When we have two sets of completes, we just fob, automatically. See TaskCmd::authenticate
-    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, no_of_zombies, timeout);
-    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
-
-    // Fobing does *NOT* alter node tree state, however child COMPLETE should auto delete the zombie
-    if (!wait_for_zombie_termination(timeout)) {
-        remove_stale_zombies(); // see notes above
-    }
-
-    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
-    check_expected_no_of_zombies(0);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST5
-BOOST_AUTO_TEST_CASE(test_zombies_attr) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_zombies_attr";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    create_and_start_test(
-        suite_name, "queued", true /* add a delay before init */); // create zombies re-queuing submitted/active tasks
-
-    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete or abort
-    /// Creating zombies by queuing submitted/active tasks, increments try number of the second set.
-    /// This avoid text file busy,(i.e by using begin/requeue creating a job file, whilst its already running)
-    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
-                          "*error* Expected non-zombie tasks to complete");
-
-    check_at_least_one_zombie();
-
-    /// *** Fobbing will not change state of the node tree ****
-    if (ecf_debug_enabled)
-        std::cout << "   Add a zombie attribute 'user:fob::' to the suite, which fobs all child commands\n";
-    TestFixture::client().alter("/" + suite_name, "add", "zombie", "user:fob::");
-
-    // Fobbing causes auto deletion of zombies, when the Child complete is reached
-    if (!wait_for_zombie_termination(timeout)) {
-        remove_stale_zombies(); // see notes above
-    }
-
-    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
-    check_expected_no_of_zombies(0);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST6
-BOOST_AUTO_TEST_CASE(test_user_zombies_for_adopt) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_user_zombies_for_adopt";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    // Using "queued" to create zombies will mean we update try_no, zombies will not share output.
-    // This avoid'(Text file busy)'
-    create_and_start_test(suite_name, "queued", true /* add delay before init */);
-
-    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete
-    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
-                          "*error* Expected non-zombie tasks to complete");
-
-    check_at_least_one_zombie();
-
-    /// Adopt all the zombies. This will UNBLOCK the child commands allowing them to finish
-    /// This test below fail on AIX, its too fast , task's may already be adopted and hence don't fail
-    int no_of_adopted_zombied = ZombieUtil::do_zombie_user_action(User::ADOPT, NUM_OF_TASKS, timeout);
-    if (ecf_debug_enabled)
-        cout << "   found " << no_of_adopted_zombied << " zombies for adoption\n";
-
-    /// The blocked zombies are free, start with blocked init command
-    (void)waitForTaskState(SINGLE, NState::ACTIVE, timeout);
-
-    /// Now wait for all tasks to complete
-    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
-                          "*error* Expected zombie tasks to complete");
-
-    remove_stale_zombies(); // see notes above
-
-    // After adoption the zombies should be removed
-    check_expected_no_of_zombies(0);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST7
-BOOST_AUTO_TEST_CASE(test_zombies_attr_for_adopt) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_zombies_attr_for_adopt";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    create_and_start_test(suite_name, "queued", true /* add a delay before init */);
-
-    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete
-    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
-                          "*error* Expected non-zombie tasks to complete");
-
-    // expected 5 zombies, ie because we have NUM_OF_TASKS tasks. These should all be blocking
-    check_at_least_one_zombie();
-
-    if (ecf_debug_enabled)
-        std::cout << "   Add a zombie attribute 'user:adopt::' to the suite, which *ADOPTS* all zombies allowing them "
-                     "to complete\n";
-    TestFixture::client().alter("/" + suite_name, "add", "zombie", "user:adopt::");
-
-    if (ecf_debug_enabled)
-        dump_zombies();
-
-    /// The blocked zombies are free, start with blocked init command
-    /// This may fail on AIX, its too fast , task's may already be complete, dont fail
-    (void)waitForTaskState(SINGLE, NState::ACTIVE, timeout);
-
-    /// Now wait for all tasks to complete. ** They may be complete from last process set **
-    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
-                          "*error* Expected all zombie task to complete after adopt");
-
-    remove_stale_zombies(); // see notes above
-
-    // After adoption the zombies should be removed
-    check_expected_no_of_zombies(0);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST8
-BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_complete) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_user_zombie_creation_via_complete";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    create_and_start_test(suite_name, "complete");
-
-    /// Since we have set tasks to complete, we should only have *ONE* set of zombies
-    check_at_least_one_zombie();
-
-    // Fob all the zombies child commands allowing them to finish
-    (void)ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
-
-    // Wait for zombies to complete, they should get removed automatically
-    wait_for_no_zombies(timeout);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST9
-BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_abort) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_user_zombie_creation_via_abort";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    create_and_start_test(suite_name, "aborted");
-
-    /// Since we have set tasks to complete, we should only have *ONE* set of zombies
-    check_at_least_one_zombie();
-
-    // Fob all the zombies child commands allowing them to finish
-    (void)ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
-
-    // Wait for zombies to complete, they should get removed automatically
-    wait_for_no_zombies(timeout);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST10
-BOOST_AUTO_TEST_CASE(test_zombie_inheritance) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_zombie_inheritance";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // Add zombie attribute, make sure it inherited
-    Defs theDefs;
-    populate_defs(theDefs, suite_name);
-    suite_ptr suite = theDefs.findSuite(suite_name);
-    suite->addZombie(ZombieAttr(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
-    suite->addZombie(ZombieAttr(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
-    suite->addZombie(ZombieAttr(ecf::Child::ECF_PID, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
-    suite->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
-    suite->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
-    suite->addZombie(ZombieAttr(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
-
-    create_and_start_test(theDefs, suite_name, "complete");
-
-    /// Since we have set tasks to complete, we should only have *ONE* set of zombies
-    // expect NUM_OF_TASKS zombies, ie because we have NUM_OF_TASKS tasks
-    TestFixture::client().set_throw_on_error(true);
-    TestFixture::client().zombieGet();
-    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-    BOOST_CHECK_MESSAGE(!zombies.empty(), "No zombies found");
-    for (const Zombie& z : zombies) {
-        BOOST_CHECK_MESSAGE(z.user_action() == ecf::User::FOB,
-                            "*error* Expected zombies with user action of type FOB but found "
-                                << User::to_string(z.user_action()));
-        break;
-    }
-
-    // Wait for zombies to complete, they should get removed automatically
-    wait_for_no_zombies(timeout);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST11
-static int wait_for_killed_zombies(int no_of_tasks, int max_time_to_wait) {
-    if (ecf_debug_enabled)
-        std::cout << "\n   wait_for_killed_zombies\n";
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (1) {
-        int killed = 0;
-        TestFixture::client().zombieGet();
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        for (const Zombie& z : zombies) {
-            if (z.kill())
-                killed++;
-        }
-        if (ecf_debug_enabled)
-            std::cout << "   found " << killed << " killed zombies\n";
-
-        if (killed == no_of_tasks)
-            return killed;
-
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            cout << "   wait_for_killed_zombies Test wait " << assertTimer.duration()
-                 << " taking longer than time constraint of " << assertTimer.timeConstraint() << " breaking out\n"
-                 << Zombie::pretty_print(zombies, 6) << "\n";
-            return killed;
-        }
-        sleep(2);
-    }
-    return 0;
-}
-
-BOOST_AUTO_TEST_CASE(test_zombie_kill) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_zombie_kill";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // This command creates user zombies up front, these may not have a pid, if task in submitted state
-    create_and_start_test(suite_name, "complete");
-
-    check_at_least_one_zombie();
-
-    // kill all the zombies, i.e kill -15 on the script
-    // This will be trapped by the signal and hence will call abort
-    (void)ZombieUtil::do_zombie_user_action(User::KILL, NUM_OF_TASKS, timeout);
-
-    // wait for kill zombies. This should eventually lead to process terminating
-    int killed = wait_for_killed_zombies(NUM_OF_TASKS, timeout);
-    BOOST_CHECK_MESSAGE(killed > 0, "*error* Expected " << NUM_OF_TASKS << " killed ");
-
-    {
-        // wait for process to be killed: killing is a separate process, we could well
-        // have got to the complete, before the process is killed.
-        // Once the complete is fobed it terminate the process.
-        AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
-        while (1) {
-            int completed = 0;
-            int aborted   = 0;
-            TestFixture::client().zombieGet();
-            std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-            for (const Zombie& z : zombies) {
-                if (z.last_child_cmd() == ecf::Child::ABORT)
-                    aborted++;
-                if (z.last_child_cmd() == ecf::Child::COMPLETE)
-                    completed++;
-            }
-            if (aborted + completed == NUM_OF_TASKS)
-                break;
-            if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-                cout << "   wait for for abort:  found " << aborted + completed
-                     << " aborted & completed tasks. Test wait " << assertTimer.duration()
-                     << " taking longer than time constraint of " << assertTimer.timeConstraint() << " breaking out\n"
-                     << Zombie::pretty_print(zombies, 6) << "\n";
-                break;
-            }
-            sleep(1);
-        }
-    }
-    {
-        bool task_became_blocked = false;
-        // wait for process to be die
-        AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
-        while (1) {
-            TestFixture::client().zombieGet();
-            std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-            for (const Zombie& z : zombies) {
-                if (z.block()) { // something went wrong, fob so don't leave process hanging
-                    TestFixture::client().zombieFob(z);
-                    task_became_blocked = true;
-                    cout << "Zombies blocking ?? " << z << "\n";
-                }
-            }
-            if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-                if (task_became_blocked) {
-                    cout << "   Task became blocked, fobing" << assertTimer.duration()
-                         << " taking longer than time constraint of " << assertTimer.timeConstraint()
-                         << " breaking out\n"
-                         << Zombie::pretty_print(zombies, 6) << "\n";
-                }
-                break;
-            }
-            sleep(1);
-        }
-    }
-
-    // remove the killed zombies
-    (void)ZombieUtil::do_zombie_user_action(User::REMOVE, NUM_OF_TASKS, timeout, false);
-
-    wait_for_no_zombies(timeout);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-#ifdef DO_TEST12
-
-static void remove_all_user_zombies() {
-    if (ecf_debug_enabled) {
-        cout << "\n   remove_all_user_zombies\n";
-        dump_zombies();
-    }
-
-    int removed_count = 0;
-    AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
-    while (removed_count < NUM_OF_TASKS) {
-        TestFixture::client().zombieGet();
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        for (const Zombie& z : zombies) {
-            if (z.type() == ecf::Child::USER) {
-                TestFixture::client().zombieRemove(z); // This should be immediate, and is not remembered
-                removed_count++;
-            }
-        }
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            cout << "      removed " << removed_count
-                 << " user zombies. Quit waiting, to remove all zombies of type USER\n";
-            cout << Zombie::pretty_print(zombies, 6);
-            return;
-        }
-        sleep(1);
-    }
-    if (ecf_debug_enabled)
-        dump_zombies();
-}
-BOOST_AUTO_TEST_CASE(test_ecf_zombie_type_creation) {
-    if (ecf_debug_enabled)
-        std::cout << "\n\n=============================================================================\n";
-    DurationTimer timer;
-    std::string suite_name = "test_ecf_zombie_type_creation";
-    cout << "Test:: ..." << suite_name << " " << flush;
-    if (ecf_debug_enabled)
-        cout << "\n";
-    TestClean clean_at_start_and_end;
-
-    // some systems are really quick, where tasks are already active, when we make them zombies, then the next
-    // client command in the zombie is: --complete. This distorts the test. Since if the real task is complete and
-    // we get a zombie with --complete, the server lets it through and the zombie process terminates.
-    // To get round this we will introduce a delay, before we get --init
-    create_and_start_test(suite_name, "queued", true /* add a delay before init */);
-
-    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete
-    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
-                          "*error* Expected non-zombie tasks to complete");
-
-    // wait and remove all *USER* zombies.
-    remove_all_user_zombies();
-
-    // wait of at least *ONE* zombie of type *ECF*
-    wait_for_zombies_of_type(Child::ECF, NUM_OF_TASKS, timeout);
-
-    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
-    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
-
-    // Fobing does *NOT* alter node tree state, however child COMPLETE should auto delete the zombie
-    if (!wait_for_zombie_termination(timeout)) {
-        remove_stale_zombies(); // see notes above
-    }
-
-    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was received
-    check_expected_no_of_zombies(0);
-
-    cout << timer.duration() << "s\n";
-}
-#endif
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Test/TestZombies_main.cpp 5.13.0-1/Test/TestZombies_main.cpp
--- 5.12.4-1/Test/TestZombies_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/TestZombies_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_Zombies
-#include <boost/test/included/unit_test.hpp>
-
-#include "TestFixture.hpp"
-
-// Global test fixture.
-//
-// Note: Due to boost deficiency this can't be easily accessed, so TestFixture makes use of global data.
-//
-BOOST_GLOBAL_FIXTURE(TestFixture);
diff -pruN 5.12.4-1/Test/Test_main.cpp 5.13.0-1/Test/Test_main.cpp
--- 5.12.4-1/Test/Test_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/Test_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test
-#include <boost/test/included/unit_test.hpp>
-
-#include "TestFixture.hpp"
-
-// Global test fixture.
-//
-// Note: Due to boost deficiency this can't be easily accessed, so TestFixture makes use of global data.
-//
-BOOST_GLOBAL_FIXTURE(TestFixture);
diff -pruN 5.12.4-1/Test/data/.gitignore 5.13.0-1/Test/data/.gitignore
--- 5.12.4-1/Test/data/.gitignore	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/data/.gitignore	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-/ECF_HOME_debug
-/ECF_HOME_release
-/ECF_HOME_release_clang/
-/ECF_HOME_release_gnu/
-/ECF_HOME_release_intel/
-/ECF_HOME_debug_gnu/
-/ECF_HOME_release_gnu_python3/
-/ECF_HOME_release_gnu_shared/
-/ECF_HOME_release_gnu_ssl/
diff -pruN 5.12.4-1/Test/data/includes/bad_tail.h 5.13.0-1/Test/data/includes/bad_tail.h
--- 5.12.4-1/Test/data/includes/bad_tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/data/includes/bad_tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #5 $
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# wait for background process to stop.
-# If we did not have background jobs, closly called foreround jobs
-# may arrive out of order at the server, causing unnecessary zombies
-# The wait should prevent this.
-wait
-
-# record shell time, see head.h
-%ecfmicro !
-finish_time=$(date +%s)
-!ecfmicro %
-echo "Job End: Time duration: $((finish_time - start_time)) secs."
-
-# Notify ECF of a normal end
-%ECF_CLIENT_EXE_PATH% --complete %COMPLETE_DEL_VARIABLES:%
-trap 0                          # Remove all traps
-exit 1                          # End the shell
-
diff -pruN 5.12.4-1/Test/data/includes/head.h 5.13.0-1/Test/data/includes/head.h
--- 5.12.4-1/Test/data/includes/head.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/data/includes/head.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,98 +0,0 @@
-#!/bin/ksh
-#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #5 $ 
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0 
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-# In applying this licence, ECMWF does not waive the privileges and immunities 
-# granted to it by virtue of its status as an intergovernmental organisation 
-# nor does it submit to any jurisdiction. 
-#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-%manual
-#This is the manual from the head.h file
-%end
-
-set -e # stop the shell on first error
-set -u # fail when using an undefined variable
-set -x # echo script lines as they are executed
-set -o pipefail # fail if last(rightmost) command exits with a non-zero status
-
-# record JOB time
-%ecfmicro !
-job_start_time=$(date +%s)
-!ecfmicro %
-
-# Defines the three variables that are needed for any
-# communication with ECF
-
-export ECF_PORT=%ECF_PORT%    # The port number on the ecflow server
-export ECF_HOST=%ECF_HOST:%   # The hostname where the server is running
-export ECF_NAME=%ECF_NAME%    # The name of this current task
-export ECF_PASS=%ECF_PASS%    # A unique password
-export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
-#export ECF_DEBUG_CLIENT=1
-if [[ "%ECF_SSL:%" != "" ]] ; then
-   export ECF_SSL=%ECF_SSL:%   # if server is SSL make sure client is
-fi
-
-# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
-# on Mac we get
-#   Host User-MacBook-Pro.local not found: 3(NXDOMAIN)
-# Should be using 'dig user-MacBook-Pro.local'
-os_name=$(uname -s)
-if [[ $os_name = Linux ]] ; then
-   host %ECF_HOST%
-fi
-
-# to debug client communication with the server, enable this environment
-#export ECF_DEBUG_CLIENT=1
-
-# Typically we dont set this, however the zombie automated test require this.
-# it allows us to disambiguate a zombie from a real job.
-export ECF_RID=$$
-
-# Tell ECF_ we have stated
-# The ECF_ variable ECF_RID will be set to parameter of smsinit
-# Here we give the current PID.
-
-
-
-# Defined a error hanlder
-ERROR() {
-	echo "ERROR() called"
-	set +e        # Clear -e flag, so we don't fail
-	wait          # wait for background process to stop
-   # when the following signals arrive do nothing, stops recursive signals/error function being called
-	trap 0 1 2 3 4 5 6 7 8 10 12 13 15
-   # Notify ECF_ that something went wrong
-	%ECF_CLIENT_EXE_PATH% --abort
-	trap 0        # Remove the trap
-	exit 0        # End the script
-}
-
-# Trap any calls to exit and errors caught by the -e flag
-
-trap ERROR 0
-
-# Trap any signal that may cause the script to fail
-
-trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
-
-%ADD_DELAY_BEFORE_INIT:% # ADD_DELAY_BEFORE_INIT is used by some tests, to slow things down on fast systems
-
-# record INIT time
-%ecfmicro !
-init_start_time=$(date +%s)
-!ecfmicro %
-
-%ECF_CLIENT_EXE_PATH% --init=$$ %INIT_ADD_VARIABLES:%
-
-# record TIME between init and complete
-%ecfmicro !
-start_time=$(date +%s)
-!ecfmicro %
-echo "Job start: *INIT* took : $((start_time - init_start_time)) secs"
diff -pruN 5.12.4-1/Test/data/includes/tail.h 5.13.0-1/Test/data/includes/tail.h
--- 5.12.4-1/Test/data/includes/tail.h	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/data/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-# Name        :
-# Author      : Avi
-# Revision    : $Revision: #5 $ 
-#
-# Copyright 2009- ECMWF.
-# This software is licensed under the terms of the Apache Licence version 2.0 
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-# In applying this licence, ECMWF does not waive the privileges and immunities 
-# granted to it by virtue of its status as an intergovernmental organisation 
-# nor does it submit to any jurisdiction. 
-#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-
-# wait for background process to stop.
-# If we did not have background jobs, closly called foreround jobs
-# may arrive out of order at the server, causing unnecessary zombies
-# The wait should prevent this.
-wait
-
-# record time between init and complete see head.h
-%ecfmicro !
-finish_time=$(date +%s)
-!ecfmicro %
-echo "Job End: Time duration: $((finish_time - start_time)) secs *BETWEEN* init and complete"
-
-# Notify ECF of a normal end
-%ECF_CLIENT_EXE_PATH% --complete %COMPLETE_DEL_VARIABLES:%
-
-%ecfmicro !
-job_finish_time=$(date +%s)
-!ecfmicro %
-echo "Job End: *COMPLETE*  took    : $((job_finish_time - finish_time)) secs"
-echo "Job End: *JOB* duration took : $((job_finish_time - job_start_time)) secs"
-
-trap 0                          # Remove all traps
-exit 0                          # End the shell
-
diff -pruN 5.12.4-1/Test/samples/cron.def 5.13.0-1/Test/samples/cron.def
--- 5.12.4-1/Test/samples/cron.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/samples/cron.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,105 +0,0 @@
-suite cron
-
-   clock real  # Need real clock otherwise crons would be complete
-   task cron0
-      cron 00:25 23:59 00:30
-      
-   task cron1
-      cron -w 0 , 1, 2 -m 5, 6, 7 , 8,9,10      10:00  20:00  01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
-
-   task cron1_1
-      cron -w 0,1,2 -m 9,10  10:00  14:00  01:00  
-      
-   task cron2
-         cron 23:00                              # run every day at 23:00
-         
-   task cron3
-      cron 10:00 20:00 01:00                  # run every hour between 10am and 8pm
-      
-   task cron4
-      cron -w 0,1 10:00                       # run every sunday and monday at 10am
-      
-   task cron5
-      cron -d 10,11,12 12:00                  # run 10th, 11th and 12th of each month at noon
-      
-   task cron6
-      cron -m 1,2,3 12:00                     # run on Jan,Feb and March every day at noon.
-      
-   task cron7
-      cron -w 0,6 12:00
-      
-   task cron8
-      cron -w 0,1,2,3,4,5,6 12:00
-      
-   task cron9
-      cron -w 0 -m 5,6,7,8 10:00 20:00 01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
-   
-   task cron10
-      cron -w 0,1,2 -d 1,20,24 -m 5,6,7,8 10:00 20:00 01:00  #  
-
-
-   task cron11
-      cron 00:00 23:59 00:01  #  run every minute
-      
-   family f1
-      cron -d 22 12:00
-      task t1
-      task t2
-   endfamily
-   family f2
-      cron -d 8 12:00
-      task t1
-      task t2
-   endfamily
-   
-   family t1
-      task t1
-         cron 00:01
-         cron 23:59
-         
-     task t2
-         cron 09:00
-         cron 12:00
-
-     task t3
-         cron 12:00
-         cron 18:00
-
-     task t4
-         cron 18:00
-         cron 23:00
-         
-     task t5
-         cron 10:00
-    task t6
-         cron 11:00
-    task t7
-         cron 12:00
-    task t8
-         cron 13:00
-    task t9
-         cron 14:00
-    task t10
-         cron 15:00
-    task t11
-         cron 16:00
-    task t12
-         cron 17:00
-    task t13
-         cron 18:00
-    task t14
-         cron 19:00
-    task t15
-         cron 20:00
-    task t16
-         cron 21:00
-    task t17
-         cron 22:00
-    task t18
-         cron 23:00
-    task t19
-         cron 23:00
-    task t20
-         cron 00:00   
-   endfamily          
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Test/samples/time.def 5.13.0-1/Test/samples/time.def
--- 5.12.4-1/Test/samples/time.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/samples/time.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,84 +0,0 @@
-suite time
-  clock real
-  family time_range
-   task t
-     time 07:00 23:00 00:30
-   task t2
-     cron 09:00 23:00 00:05
-   task t3
-     time 13:00
-   task t4
-     time 23:00
-   task t5
-      time 07:00
-      time 08:00
-      time 09:00
-      time 10:00
-      time 13:00
-      time 14:00
-      time 15:00
-      time 16:00
-      time 17:00
-    task every_minute
-     time 00:01 23:59 00:01
-     edit SLEEP 90          # task takes longer than one minute
-  endfamily
-   family t1
-      task t1
-         time 00:01
-         time 23:59
-         
-     task t2
-         time 09:00
-         time 12:00
-
-     task t3
-         time 12:00
-         time 18:00
-
-     task t4
-         time 18:00
-         time 23:00
-         
-     task t5_1
-         time 08:00
-    task t5
-         time 10:00
-    task t6
-         time 11:00
-    task t7
-         time 12:00
-    task t8
-         time 13:00
-         time 15:00
-    task t9
-         time 14:00
-    task t10
-         time 15:00
-    task t11
-         time 16:00
-         time 17:00
-         time 18:00
-         time 19:00
-         trigger 1 == 0
-    task t12
-         time 17:00
-    task t13
-         time 18:00
-    task t14
-         time 19:00
-    task t15
-         time 20:00
-    task t16
-         time 21:00
-    task t17
-         time 22:00
-    task t18
-         time 23:00
-    task t19
-         time 23:00
-         trigger 1 == 0
-    task t20
-         time 00:00
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Test/samples/today.def 5.13.0-1/Test/samples/today.def
--- 5.12.4-1/Test/samples/today.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/samples/today.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,75 +0,0 @@
-suite today
-  clock real
-  family time_range
-   task t
-     today 07:00 23:00 00:30
-   task t2
-     today 09:00 23:00 00:05
-   task t3
-     today 13:00
-   task t4
-     today 23:00
-   task t5
-      today 09:00
-      today 13:00
-      today 14:00
-      today 15:00
-      today 16:00
-      today 17:00
-  endfamily
-   family t1
-      task t1
-         today 00:01
-         today 23:59
-      task t1_1
-         today 09:01
-         today 09:30
-     task t2
-         today 09:00
-         today 12:00
-     task t3
-         today 12:00
-         today 18:00
-     task t4
-         today 18:00
-         today 23:00
-     task t5
-         today 10:00
-     task t5_1
-         today 08:00    
-    task t6
-         today 11:00
-         today 11:30
-    task t7
-         today 12:00
-         today 12:30
-         today 13:30
-         today 14:30
-    task t8
-         today 13:00
-    task t9
-         today 14:00
-    task t10
-         today 15:00
-    task t11
-         today 16:00
-    task t12
-         today 17:00
-    task t13
-         today 18:00
-    task t14
-         today 19:00
-    task t15
-         today 20:00
-    task t16
-         today 21:00
-    task t17
-         today 22:00
-    task t18
-         today 23:00
-    task t19
-         today 23:00
-    task t20
-         today 00:00
-   endfamily
-endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/Test/src/ServerTestHarness.cpp 5.13.0-1/Test/src/ServerTestHarness.cpp
--- 5.12.4-1/Test/src/ServerTestHarness.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/src/ServerTestHarness.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,583 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ServerTestHarness.hpp"
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestFixture.hpp"
-#include "ecflow/attribute/QueueAttr.hpp"
-#include "ecflow/base/WhyCmd.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/core/DurationTimer.hpp"
-#include "ecflow/core/Ecf.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Family.hpp"
-#include "ecflow/node/Suite.hpp"
-#include "ecflow/node/Task.hpp"
-
-using namespace std;
-using namespace ecf;
-
-// #define DEBUG_TEST_WAITER 1
-// #define DEBUG_TEST_WAITER_DEFS 1
-// #define DEBUG_TEST_HARNESS 1
-// #define DEBUG_DIFF 1
-
-ServerTestHarness::ServerTestHarness() : print_style_(PrintStyle::STATE) {
-}
-
-void ServerTestHarness::run(Defs& theClientDefs,
-                            const std::string& defs_filename,
-                            const std::map<std::string, std::string>& customTaskSmsMap,
-                            int timeout,
-                            bool waitForTestCompletion) {
-    defs_filename_ = defs_filename;
-
-    /// RUN the TEST
-    defs_ptr serverDefs = doRun(theClientDefs, customTaskSmsMap, timeout, waitForTestCompletion);
-}
-
-void ServerTestHarness::run(Defs& defs, const std::string& defs_filename, int timeout, bool waitForTestCompletion) {
-    std::map<std::string, std::string> customTaskSmsMap;
-    run(defs, defs_filename, customTaskSmsMap, timeout, waitForTestCompletion);
-}
-
-struct null_deleter
-{
-    void operator()(void const*) const {}
-};
-
-defs_ptr ServerTestHarness::doRun(Defs& theClientDefs,
-                                  const std::map<std::string, std::string>& customTaskSmsMap,
-                                  int timeout,
-                                  bool waitForTestCompletion) {
-#ifdef DEBUG_TEST_HARNESS
-    cout << "ServerTestHarness::doRun " << defs_filename_ << " timeout=" << timeout
-         << "  waitForTestCompletion = " << waitForTestCompletion << "\n";
-#endif
-    BOOST_REQUIRE_MESSAGE(!theClientDefs.suiteVec().empty(), "No suite defined");
-
-#ifdef DEBUG_TEST_HARNESS
-    cout << "   ServerTestHarness::doRun: Get the client exe. This can be client exe on another platform hence cant "
-            "run here\n";
-#endif
-    std::string theClientExePath = TestFixture::theClientExePath();
-    BOOST_REQUIRE_MESSAGE(!theClientExePath.empty(), " The client program could not be found");
-
-#ifdef DEBUG_TEST_HARNESS
-    cout << "   ServerTestHarness::doRun: Create ECF directory structure corresponding to Node tree\n";
-#endif
-    // Automatically add variable ECF_HOME to each suite, before saving to disk
-    // This is needed to locate ECF_FILE includes
-    std::string ecf_home = testDataLocation(defs_filename_);
-
-    // Most test just define one suite, however the mega.def has up to 26 suites
-    // If set this can be used to choose which suite to begin.
-    std::string suiteName;
-
-    // ECF_CLIENT_EXE_PATH allows dependence on client exe without installation
-    // Allow user to add SLEEPTIME, otherwise add a default
-    int customSmsCnt    = 0;
-    auto taskSmsMapSize = static_cast<int>(customTaskSmsMap.size());
-    for (suite_ptr s : theClientDefs.suiteVec()) {
-
-        // Always override these to correctly locate files.
-        s->addVariable(Variable(Str::ECF_HOME(), ecf_home));
-        s->addVariable(Variable("ECF_CLIENT_EXE_PATH", theClientExePath));
-        s->addVariable(Variable(Str::ECF_INCLUDE(), TestFixture::includes()));
-
-        if (s->findVariable("SLEEPTIME").empty())
-            s->addVariable(Variable("SLEEPTIME", "1"));
-
-        if (check_task_duration_less_than_server_poll_) {
-            if (s->findVariable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL").empty())
-                s->addVariable(Variable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL", "_any_"));
-        }
-        suiteName = s->name();
-
-        // recursively create directory structure from ECF_HOME and populate tasks with sms files
-        createDirAndEcfFiles(s.get(), ecf_home, customTaskSmsMap, customSmsCnt);
-    }
-    BOOST_REQUIRE_MESSAGE(customSmsCnt == taskSmsMapSize,
-                          "customSmsCnt:"
-                              << customSmsCnt << " does not match " << taskSmsMapSize
-                              << " createDirAndEcfFiles did not create all sms file corresponding to tasks");
-
-    // If the defs has more than one suite, then start them all.
-    if (theClientDefs.suiteVec().size() != 1) {
-        suiteName.clear();
-#ifdef DEBUG_TEST_HARNESS
-        cout << "   ServerTestHarness::doRun: defs has " << theClientDefs.suiteVec().size()
-             << " suites hence will begin all of them\n";
-#endif
-    }
-
-    bool load_defs_from_disk = true;
-    {
-#ifdef DEBUG_TEST_HARNESS
-        cout << "   ServerTestHarness::doRun: Save the Defs file to disk. " << defs_filename_ << "\n";
-#endif
-        std::ofstream theClientDefsFile(defs_filename_.c_str());
-        if (theClientDefsFile.fail()) {
-            // The file is *not on disk*, just use in memory defs
-            load_defs_from_disk = false;
-        }
-        else {
-            PrintStyle style(PrintStyle::DEFS); // needed for output
-            theClientDefsFile << theClientDefs;
-        }
-    }
-
-    // Set the location of the new log file. Close the current log file and create new log file
-    // The defs file name should have been set to the test location
-    // The log file is CLEARED so that previous run is ignored
-    std::string new_log_file_path = defs_filename_ + "_log";
-#ifdef DEBUG_TEST_HARNESS
-    cout << "   ServerTestHarness::new_log_file_path = " << new_log_file_path << "\n";
-#endif
-    TestFixture::client().new_log(new_log_file_path);
-    TestFixture::client().clearLog();
-
-#ifdef DEBUG_TEST_HARNESS
-    cout << "   ServerTestHarness::doRun: Delete all nodes in server. Using force to allow as many tests as possible\n";
-#endif
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_all(true /*force, even if it creates zombies*/) == 0,
-                          CtsApi::to_string(CtsApi::delete_node())
-                              << " failed should return 0. Should Delete ALL existing defs in the server\n"
-                              << TestFixture::client().errorMsg());
-
-#ifdef DEBUG_TEST_HARNESS
-    cout << "   ServerTestHarness::doRun: Load new defs in the server\n";
-#endif
-    if (load_defs_from_disk) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().loadDefs(defs_filename_) == 0,
-                              "load defs failed should return 0. Should Load defs file "
-                                  << defs_filename_ << " into the server from current working directory\n"
-                                  << TestFixture::client().errorMsg());
-    }
-    else {
-        // load expects a defs_ptr
-        defs_ptr defs(&theClientDefs, null_deleter());
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().load(defs) == 0,
-                              "load defs failed should return 0. Should Load defs file "
-                                  << defs_filename_ << " into the server\n"
-                                  << TestFixture::client().errorMsg());
-    }
-
-#ifdef DEBUG_TEST_HARNESS
-    cout << "   ServerTestHarness::doRun: Restart server \n";
-#endif
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().restartServer() == 0,
-                          CtsApi::restartServer()
-                              << " failed should return 0. Should restart the server via a client command\n"
-                              << TestFixture::client().errorMsg());
-
-#ifdef DEBUG_TEST_HARNESS
-    cout << "   ServerTestHarness::doRun: Calling begin on suite " << suiteName << "\n";
-#endif
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().begin(suiteName) == 0,
-                          CtsApi::begin(suiteName)
-                              << " failed should return 0. Should Begin the suite " << suiteName << "\n"
-                              << TestFixture::client().errorMsg());
-
-    if (waitForTestCompletion) {
-#ifdef DEBUG_TEST_HARNESS
-        cout << "   ServerTestHarness::doRun: Waiting for test to finish\n";
-#endif
-        return testWaiter(theClientDefs, timeout, true /* test against verification attributes on defs */);
-    }
-    return defs_ptr();
-}
-
-static void test_invariants(defs_ptr the_defs, const std::string& title) {
-    std::string errorMsg;
-    BOOST_CHECK_MESSAGE(the_defs->checkInvariants(errorMsg), title << " Invariants failed " << errorMsg);
-}
-
-bool verify_attribute_verification() {
-    // In  version 4.0.1: We changed the way families changed states. i.e families will now change to state complete
-    // before being requeued. See ECFLOW-96 Families with loops(cron/repeat) should log complete
-    // This meant that when we run the migration tests, i.e new client with old server (with new test)
-    // It would fail some the test, during verify attribute verification. ie. where we count the number of times
-    // a node completes. To enable these tests to still run, we will disable verify attribute verification
-    return true;
-}
-
-defs_ptr ServerTestHarness::testWaiter(const Defs& theClientDefs, int timeout, bool verifyAttr) {
-#ifdef DEBUG_TEST_WAITER
-    cout << "ServerTestHarness::testWaiter \n";
-#endif
-
-#ifdef DEBUG_DIFF
-    std::string dump_defs_filename = "test.def";
-    int counter                    = 0;
-#endif
-    DebugEquality debug_equality; // only as affect in DEBUG build
-
-    BOOST_REQUIRE_MESSAGE(TestFixture::client().client_handle() == 0,
-                          "Client handle expected to be zero but found " << TestFixture::client().client_handle());
-
-    /// This function will test sync'ing. by getting the sync and full defs, then comparing them
-    AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
-
-    // test the incremental changes
-    defs_ptr incremental_defs;
-    defs_ptr full_defs;
-
-    int sleepTime         = (theClientDefs.suiteVec().size() == 1) ? TestFixture::job_submission_interval() : 10;
-    int sleep_fudgeFactor = TestFixture::job_submission_interval();
-
-    // How do we terminate this test?
-    // The test succeeds if the suite state is complete,
-    while (true) {
-#ifdef DEBUG_TEST_WAITER
-        std::cout << "sleepTime = " << sleepTime << "\n";
-#endif
-        sleep(sleepTime);    // avoid calling get excessively, by using sleep
-        DurationTimer timer; // automatically adjust sleep time
-
-        bool server_changed = false;
-        if (!full_defs.get()) {
-            server_changed = true;
-            // ********************************************************************************
-            // Calling getDefs will also force a flush of the log file. This is required since we
-            // copy the log file locally on the shared file system for cross platform testing
-            // ******************************************************************************
-            BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
-                                  CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
-            full_defs        = TestFixture::client().defs();
-            incremental_defs = TestFixture::client().defs();
-            BOOST_REQUIRE_MESSAGE(full_defs.get(), "get command failed to get node tree from server");
-            BOOST_REQUIRE_MESSAGE(incremental_defs.get(), "get command failed to get node tree from server");
-
-            // Ensure that when suite was loaded in server, that others suites were discarded
-            BOOST_CHECK_MESSAGE(theClientDefs.suiteVec().size() == full_defs->suiteVec().size(),
-                                "mismatch in client suite count " << theClientDefs.suiteVec().size() << " and server "
-                                                                  << full_defs->suiteVec().size());
-            test_invariants(full_defs, "First time for getting full defs");
-        }
-        else {
-            BOOST_CHECK_MESSAGE(TestFixture::client().news(full_defs) == 0,
-                                "news failed should return 0 " << TestFixture::client().errorMsg());
-            server_changed = TestFixture::client().get_news();
-            //			std::cout << "server_changed = " << server_changed << "\n";
-            if (server_changed) {
-
-                // Get the incremental changes **FIRST** and compare this with the full defs later on
-                BOOST_REQUIRE_MESSAGE(TestFixture::client().sync(incremental_defs) == 0,
-                                      "sync failed should return 0 " << TestFixture::client().errorMsg());
-                BOOST_CHECK_MESSAGE(TestFixture::client().in_sync(),
-                                    "in_sync expected to return true, when we have changes in server");
-                test_invariants(incremental_defs, "After syncing with incremental defs.");
-
-                // get the FULL defs
-                BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
-                                      CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
-                full_defs = TestFixture::client().defs();
-                BOOST_REQUIRE_MESSAGE(full_defs.get(), "get command failed to get node tree from server");
-                test_invariants(full_defs, "After getting the full defs.");
-
-                // **** NOTE ****: There could have been state change between the calls:
-                // **************: 	 TestFixture::client().sync(incremental_defs)
-                // **************:    TestFixture::client().getDefs()
-                // **************: hence we can only compare, incremental and full defs if
-                // **************: state and modification numbers are the same:
-                BOOST_REQUIRE_MESSAGE(incremental_defs.get() != full_defs.get(), " Expected two different defs trees ");
-                if (incremental_defs->state_change_no() == full_defs->state_change_no() &&
-                    incremental_defs->modify_change_no() == full_defs->modify_change_no()) {
-                    BOOST_CHECK_MESSAGE(
-                        *full_defs == *incremental_defs,
-                        "Full and incremental defs should be the same. (state_change_no,modify_change_no) ("
-                            << incremental_defs->state_change_no() << "," << incremental_defs->modify_change_no()
-                            << ")");
-                }
-                else {
-#ifdef DEBUG_TEST_WAITER
-                    std::cout << "***** ServerTestHarness::testWaiter: State change between getting incremental and "
-                                 "full defs\n";
-#endif
-                }
-            }
-        }
-
-        int hasAutoCancel       = 0;
-        size_t completeSuiteCnt = 0;
-        if (server_changed) {
-
-#ifdef DEBUG_DIFF
-            {
-                counter++;
-                std::string filename = dump_defs_filename + ecf::convert_to<std::string>(counter);
-                std::ofstream theFile(filename.c_str());
-
-                std::vector<Task*> tasks;
-                full_defs->getAllTasks(tasks);
-                int unknown            = 0;
-                int complete           = 0;
-                int queued             = 0;
-                int aborted            = 0;
-                int submitted          = 0;
-                int active             = 0;
-                size_t password_size   = 0;
-                size_t process_id_size = 0;
-                for (size_t i = 0; i < tasks.size(); i++) {
-                    switch (tasks[i]->state()) {
-                        case NState::UNKNOWN:
-                            unknown++;
-                            break;
-                        case NState::COMPLETE:
-                            complete++;
-                            break;
-                        case NState::QUEUED:
-                            queued++;
-                            break;
-                        case NState::ABORTED:
-                            aborted++;
-                            break;
-                        case NState::SUBMITTED:
-                            submitted++;
-                            break;
-                        case NState::ACTIVE:
-                            active++;
-                            break;
-                    }
-                    password_size += tasks[i]->jobsPassword().size();
-                    process_id_size += tasks[i]->process_or_remote_id().size();
-                }
-                theFile << "task password_size(" << password_size << ") process_id_size(" << process_id_size
-                        << ")   total = " << (password_size + process_id_size) << endl;
-                theFile << "unknown: " << unknown << "\n";
-                theFile << "complete: " << complete << "\n";
-                theFile << "queued: " << queued << "\n";
-                theFile << "aborted: " << aborted << "\n";
-                theFile << "submitted: " << submitted << "\n";
-                theFile << "active: " << active << "\n";
-                theFile << *full_defs.get();
-            }
-#endif
-            std::string errorMsg;
-            BOOST_REQUIRE_MESSAGE(full_defs->checkInvariants(errorMsg), "Invariants failed " << errorMsg);
-
-            // record the number of times that the server updated the calendar. Allow debug of time dependencies
-            serverUpdateCalendarCount_ = full_defs->updateCalendarCount();
-
-            for (suite_ptr s : full_defs->suiteVec()) {
-                if (s->state() == NState::COMPLETE)
-                    completeSuiteCnt++;
-                if (s->hasAutoCancel())
-                    hasAutoCancel++;
-            }
-
-#ifdef DEBUG_TEST_WAITER_DEFS
-            cout << "\nPrinting Defs "
-                    "==================================================================================\n";
-            std::cout << *full_defs.get();
-            cout << "completeSuiteCnt = " << completeSuiteCnt
-                 << " full_defs->suiteVec().size() = " << full_defs->suiteVec().size()
-                 << " hasAutoCancel = " << hasAutoCancel << "\n";
-#endif
-            if ((full_defs->suiteVec().size() == completeSuiteCnt) && (hasAutoCancel == 0)) {
-
-                if (verifyAttr && verify_attribute_verification()) {
-                    // Do verification of expected state changes
-                    string localErrorMessage;
-                    BOOST_REQUIRE_MESSAGE(full_defs->verification(localErrorMessage),
-                                          localErrorMessage << "\n"
-                                                            << *full_defs.get());
-                }
-                return full_defs;
-            }
-        }
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-            // Give clues why we are not finishing on time, by using Why and by dumping out node tree
-            cout << "Test time " << assertTimer.duration() << " taking longer than time constraint of "
-                 << assertTimer.timeConstraint() << " aborting\n";
-            cout << "   completeSuiteCnt = " << completeSuiteCnt << "\n";
-            cout << "   full_defs->suiteVec().size() = " << full_defs->suiteVec().size() << "\n";
-            cout << "   hasAutoCancel = " << hasAutoCancel << "\n";
-            std::cout << "update-calendar-count(" << serverUpdateCalendarCount_ << ")\n";
-            std::cout << "WHY:\n";
-            WhyCmd reason(full_defs, "" /* do a top down why */);
-            std::cout << reason.why() << "\n";
-        }
-        BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(), "\n" << *full_defs);
-        if (assertTimer.duration() >= assertTimer.timeConstraint())
-            break; // fix warning on AIX
-
-        // auto adjust sleep time.
-        sleepTime = timer.duration() + sleep_fudgeFactor;
-    }
-    return defs_ptr();
-}
-
-void ServerTestHarness::createDirAndEcfFiles(NodeContainer* nc,
-                                             const std::string& smshome,
-                                             const std::map<std::string, std::string>& customTaskSmsMap,
-                                             int& customSmsCnt) const {
-    std::string directory = smshome + nc->absNodePath();
-#ifdef DEBUG_TEST_HARNESS
-    cout << "creating directory  " << directory << "\n";
-#endif
-
-    if (!fs::exists(smshome))
-        fs::create_directory(smshome);
-    if (!fs::exists(directory))
-        fs::create_directory(directory);
-
-    if (generateManFileForNodeContainers_) {
-        std::string manFileName = smshome + nc->absNodePath() + File::MAN_EXTN();
-        std::ofstream theManFile(manFileName.c_str());
-        theManFile << "%manual\n";
-        theManFile << "This file auto generated by ServerTestHarness::createDirAndEcfFiles for all Node Containers\n";
-        theManFile << "%end\n";
-    }
-
-    for (node_ptr n : nc->nodeVec()) {
-
-        Task* t = n->isTask();
-        if (t) {
-            std::string ecf_file = smshome + t->absNodePath() + File::ECF_EXTN();
-#ifdef DEBUG_TEST_HARNESS
-            cout << "creating ecf file  " << ecf_file << "\n";
-#endif
-            // Create ECF file with default template or custom  file.
-            std::ofstream theEcfFile(ecf_file.c_str());
-            auto it = customTaskSmsMap.find(t->absNodePath());
-            if (it == customTaskSmsMap.end())
-                theEcfFile << getDefaultTemplateEcfFile(t);
-            else {
-                theEcfFile << (*it).second;
-                customSmsCnt++;
-            }
-        }
-        else {
-            Family* f = n->isFamily();
-            assert(f);
-            createDirAndEcfFiles(f, smshome, customTaskSmsMap, customSmsCnt);
-        }
-    }
-}
-
-static void add_queue(std::string& content, const std::vector<QueueAttr>& queues) {
-    for (const QueueAttr& queue : queues) {
-        content += "\n";
-        content += "for i in";
-        const std::vector<std::string>& queue_list = queue.list();
-        for (const auto& i : queue_list) {
-            content += " ";
-            content += i;
-        }
-        content += "\n";
-        content += "do\n";
-        content += "   step=$(%ECF_CLIENT_EXE_PATH% --queue=" + queue.name() + " active )\n";
-        content += "   echo $step\n";
-        content += "   sleep %SLEEPTIME%\n";
-        content += "   %ECF_CLIENT_EXE_PATH% --queue=" + queue.name() + " complete $step\n";
-        content += "done\n";
-    }
-}
-
-std::string ServerTestHarness::getDefaultTemplateEcfFile(Task* t) const {
-    std::string templateEcfFile;
-
-    templateEcfFile += "%manual\n";
-    templateEcfFile += "This is the default ecf script file used for testing\n";
-    templateEcfFile += "%end\n";
-    templateEcfFile += "%comment\n";
-    templateEcfFile += "# Using angle brackets should use ECF_INCLUDE\n";
-    templateEcfFile += "%end\n";
-    templateEcfFile += "%include <head.h>\n";
-    templateEcfFile += "\n";
-    for (const Event& e : t->events()) {
-        // if initial value is set, then child cmd clears
-        // else if initial value is clear, then child cmd sets (default)
-        if (e.initial_value())
-            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --event=" + e.name_or_number() + " clear\n";
-        else
-            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --event=" + e.name_or_number() + "\n";
-    }
-    for (const Meter& m : t->meters()) {
-        templateEcfFile += "for i in";
-        int min   = m.min();
-        int max   = m.max();
-        int delta = abs(max - min) / 10;
-        for (int i = min + delta; i <= max; i = i + delta) {
-            templateEcfFile += " ";
-            templateEcfFile += ecf::convert_to<std::string>(i);
-        }
-        templateEcfFile += "\n";
-        templateEcfFile += "do\n";
-        templateEcfFile += "   %ECF_CLIENT_EXE_PATH% --meter=" + m.name() + " $i\n";
-        templateEcfFile += "   sleep %SLEEPTIME%\n";
-        templateEcfFile += "done\n";
-    }
-    /// labels require at least 2 arguments,
-    for (const Label& label : t->labels()) {
-        if (!label.new_value().empty()) {
-            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --label=" + label.name() + " " + label.new_value() + "\n";
-        }
-        else if (!label.value().empty()) {
-            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --label=" + label.name() + " " + label.value() + "\n";
-        }
-    }
-
-    /// Queues
-    add_queue(templateEcfFile, t->queues());
-    Node* parent = t->parent();
-    while (parent) {
-        add_queue(templateEcfFile, parent->queues());
-        parent = parent->parent();
-    }
-
-    if (add_default_sleep_time_ && t->events().empty() && t->meters().empty() && t->queues().empty()) {
-        templateEcfFile += "\n# SLEEPTIME is defined the Client Defs.def file. Test variable substitution\n";
-        templateEcfFile += "sleep %SLEEPTIME%\n";
-    }
-    templateEcfFile += "\n%include <tail.h>\n";
-    return templateEcfFile;
-}
-
-std::string ServerTestHarness::testDataDefsLocation(const std::string& defsFile) {
-    // DefsFile is of the form base_name.def"
-    // We want to place the defs and log file in the same location as its test directory
-    //   test/data/ECF_HOME/base_name/base_name.def
-    std::string testData = testDataLocation(defsFile) + "/" + defsFile;
-    return testData;
-}
-
-std::string ServerTestHarness::testDataLocation(const std::string& defsFile) {
-    // DefsFile is of the form:
-    //   base_name.def
-    //   /tmp/path/base_name.def
-    //
-    // We want to place the defs and log file in the same location as its test directory
-    //   test/data/ECF_HOME/base_name
-    //
-    std::string base_name = defsFile;
-    size_t slash_pos      = defsFile.rfind('/', defsFile.length());
-    if (slash_pos != std::string::npos) {
-        base_name = base_name.erase(0, slash_pos + 1);
-    }
-
-    size_t dot_pos = base_name.rfind('.', base_name.length());
-    assert(dot_pos != std::string::npos); // missing '.'
-    base_name = base_name.substr(0, dot_pos);
-
-    std::string testData = TestFixture::smshome() + "/" + base_name;
-    return testData;
-}
diff -pruN 5.12.4-1/Test/src/ServerTestHarness.hpp 5.13.0-1/Test/src/ServerTestHarness.hpp
--- 5.12.4-1/Test/src/ServerTestHarness.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/src/ServerTestHarness.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,119 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_test_harness_ServerTestHarness_HPP
-#define ecflow_test_harness_ServerTestHarness_HPP
-
-#include <map>
-#include <string>
-
-#include "ZombieUtil.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/node/NodeFwd.hpp"
-
-// This class provides a test harness for running defs file in a client server environment
-// To avoid Address in use errors, we can have client/server use a different port number
-// This is more important when doing instrumentation in HP-UX, as that can take a long time.
-//
-// The Server is started/stopped by use of the Global text Fixture
-// See class TestFixture.hpp
-//
-class ServerTestHarness {
-    ServerTestHarness(const ServerTestHarness&)                  = delete;
-    const ServerTestHarness& operator=(const ServerTestHarness&) = delete;
-
-public:
-    // if standardVerification is true, we test task goes through normal life cycle
-    // changes. else we compare the log file states with golden log file
-    // Comparing log files across platforms is not reliable, and ignored
-    ServerTestHarness();
-
-    /// generate man files for Suite and family nodes
-    void generateManFileForNodeContainers() { generateManFileForNodeContainers_ = true; }
-
-    /// Enable/disable checking for server poll being to small.
-    /// This test creates dummy .ecf files. Since these tests are run with the server poll
-    /// which is less than 60, we need the task duration between submit->active->complete duration to be less
-    /// the server poll. Tests with time dependencies of one minute separation will be missed.\n"
-    /// Make this configurable since for large defs, when we have 1000's of tasks the
-    /// task duration times are not deterministic
-    void check_task_duration_less_than_server_poll(bool f) { check_task_duration_less_than_server_poll_ = f; }
-
-    /// Sometimes on slow systems we want to disable sleep time.
-    /// since the time duration between submit->active->complete is greater than job submission interval
-    /// and hence time slots get missed.
-    /// The Default is to add the sleep time always for events and meters and when there is NO events or meters
-    /// This flags is used for the *specific* case when there is *no* events/meters.
-    void add_default_sleep_time(bool f) { add_default_sleep_time_ = f; }
-
-    // Run the following defs file in the test harness.
-    // If no map is provided then a default sms file is fabricated, otherwise
-    // the map allows a sms file string to be associated with a task path
-    // map.first = absolute task path
-    // map.second =  sms file string
-#if defined(_AIX)
-    void run(Defs&,
-             const std::string& defs_file,
-             const std::map<std::string, std::string>&,
-             int timeout                = 120,
-             bool waitForTestCompletion = true);
-    void run(Defs&, const std::string& defs_file, int timeout = 120, bool waitForTestCompletion = true);
-#elif defined(HPUX)
-    void run(Defs&,
-             const std::string& defs_file,
-             const std::map<std::string, std::string>&,
-             int timeout                = 100,
-             bool waitForTestCompletion = true);
-    void run(Defs&, const std::string& defs_file, int timeout = 100, bool waitForTestCompletion = true);
-#else
-    void run(Defs&,
-             const std::string& defs_file,
-             const std::map<std::string, std::string>&,
-             int timeout                = 40,
-             bool waitForTestCompletion = true);
-    void run(Defs&, const std::string& defs_file, int timeout = 40, bool waitForTestCompletion = true);
-#endif
-
-    /// Returns the location of the defs file, such thats it in the test data area
-    static std::string testDataDefsLocation(const std::string& defsFile);
-
-    /// The test data location
-    static std::string testDataLocation(const std::string& defsFile);
-
-    /// This function is used for waiting for test to finish
-    /// returns the defs from the server at test completeion
-    defs_ptr testWaiter(const Defs& theClientDefs, // The defs on the client side
-                        int timeout,               // How long should we wait for test to finish
-                        bool verifyAttr);          // Test verification use verify attributes on defs
-
-    /// for debug return the number of times the calendar was updated in the server
-    unsigned int serverUpdateCalendarCount() const { return serverUpdateCalendarCount_; }
-
-private:
-    defs_ptr doRun(Defs&, const std::map<std::string, std::string>&, int sleepTime, bool waitForTestCompletion);
-
-    void createDirAndEcfFiles(NodeContainer* nc,
-                              const std::string& smshome,
-                              const std::map<std::string, std::string>& taskSmsMap,
-                              int& customSmsCnt) const;
-
-    /// default ecf file will cater for events and meters
-    std::string getDefaultTemplateEcfFile(Task* t) const;
-
-private:
-    bool generateManFileForNodeContainers_{false};
-    bool check_task_duration_less_than_server_poll_{true};
-    bool add_default_sleep_time_{true};
-    int serverUpdateCalendarCount_{0};
-    std::string defs_filename_;
-    PrintStyle print_style_; // by default show state when writing defs to standard out. RAII
-};
-
-#endif /* ecflow_test_harness_ServerTestHarness_HPP */
diff -pruN 5.12.4-1/Test/src/TestFixture.cpp 5.13.0-1/Test/src/TestFixture.cpp
--- 5.12.4-1/Test/src/TestFixture.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/src/TestFixture.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,427 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "TestFixture.hpp"
-
-#include <cstdlib> // for getenv()
-#include <fstream> // for ofstream
-#include <iostream>
-
-#include "TestHelper.hpp"
-#include "ecflow/base/cts/user/CtsApi.hpp"
-#include "ecflow/client/ClientEnvironment.hpp" // needed for static ClientEnvironment::hostSpecified(); ONLY
-#include "ecflow/client/Rtt.hpp"
-#include "ecflow/core/EcfPortLock.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Filesystem.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Task.hpp"
-
-#ifdef DEBUG
-std::string rtt_filename = "rtt.dat";
-#else
-std::string rtt_filename = "rtt_d.dat";
-#endif
-std::string TestFixture::scratchSmsHome_ = "";
-std::string TestFixture::host_;
-std::string TestFixture::port_;
-std::string TestFixture::test_dir_;
-std::string TestFixture::project_test_dir_ = "Test";
-
-using namespace std;
-using namespace ecf;
-
-// ************************************************************************************************
-// For test purpose the server can be started:
-//  1/ By this test fixture
-//  2/ Externally but on the same machine. by defining env variable: export ECF_HOST=localhost
-//     WHY? To test for memory leak. (i.e. with valgrind)
-//  3/ Externally but on a different platform. by defining env variable: export ECF_HOST=itanium
-//     In this case we NEED to copy the test data, so that it is
-//     accessible by the client AND server
-//
-//  When invoking the server Externally _MUST_ use   .
-//     ./Server/bin/gcc.<version>/debug/server --ecfinterval=2
-//        The --ecfinterval=2 is _important_ or test will take a long time
-// ************************************************************************************************
-
-// Uncomment to preserve the files for test
-// #define DEBUG_HOST_SERVER 1
-#define DEBUG_LOCAL_SERVER 1
-
-TestFixture::TestFixture(const std::string& project_test_dir) : print_style_(PrintStyle::STATE) {
-    init(project_test_dir);
-}
-
-TestFixture::TestFixture() : print_style_(PrintStyle::STATE) {
-    init("Test");
-}
-
-ClientInvoker& TestFixture::client() {
-    static ClientInvoker theClient_;
-    return theClient_;
-}
-
-void TestFixture::init(const std::string& project_test_dir) {
-    TestFixture::project_test_dir_ = project_test_dir;
-    auto test_dir                  = local_ecf_home();
-    std::cout << "TestFixture::TestFixture() project_test_dir      :" << project_test_dir << "\n";
-    std::cout << "TestFixture::TestFixture() local_ecf_home        :" << test_dir << "\n";
-    std::cout << "TestFixture::TestFixture() jobSubmissionInterval :" << job_submission_interval() << "\n";
-    std::cout << "TestFixture::TestFixture() cwd                   :" << fs::current_path() << "\n";
-
-    if (!fs::exists(test_dir)) {
-        fs::create_directories(test_dir);
-    }
-
-    // client side file for recording all ClientInvoker round trip times
-    fs::remove(rtt_filename);
-    Rtt::create(rtt_filename);
-
-    // ********************************************************
-    // Note: Global fixture Constructor cannot use BOOST macro
-    // ********************************************************
-
-    // Let first see if we need do anything. If ECF_HOST is specified (ie the name
-    // of the machine, which has the ecflow server), only then do we need to do anything.
-    // The server must have access to the file system specified by ECF_HOME.
-    // This becomes an issue when the server is on a different machine
-    host_ = ClientEnvironment::hostSpecified();
-    port_ = ClientEnvironment::portSpecified(); // returns ECF_PORT, otherwise Str::DEFAULT_PORT_NUMBER
-#ifdef ECF_OPENSSL
-    if (getenv("ECF_SSL"))
-        std::cout << "   Openssl enabled\n";
-#endif
-    if (!host_.empty() && host_ != Str::LOCALHOST()) {
-
-        client().set_host_port(host_, port_);
-        std::cout << "   EXTERNAL SERVER running on _ANOTHER_ PLATFORM, assuming " << host_ << ":" << port_
-                  << " copying test data ...\n";
-
-        // Must use a file system accessible from the server. Use $SCRATCH
-        // Duplicate test data, required to scratch area and reset ECF_HOME
-        char* scratchEnv = getenv("SCRATCH");
-        assert(scratchEnv != NULL);
-        std::string theSCRATCHArea(scratchEnv);
-        assert(!theSCRATCHArea.empty());
-
-        theSCRATCHArea += "/test_dir";
-        test_dir_ = theSCRATCHArea; // test_dir_ needed in destructor
-        if (fs::exists(test_dir_)) {
-            fs::remove_all(test_dir_);
-        }
-        theSCRATCHArea += "/ECF_HOME";
-        scratchSmsHome_ = theSCRATCHArea;
-
-        BOOST_REQUIRE_MESSAGE(File::createDirectories(theSCRATCHArea),
-                              "File::createDirectories(theSCRATCHArea) failed");
-        BOOST_REQUIRE_MESSAGE(fs::exists(theSCRATCHArea), "theSCRATCHArea does not exist");
-
-        // Ensure that local includes data exists. This needs to be copied to SCRATCH
-        BOOST_REQUIRE_MESSAGE(fs::exists(includes()), "The includes dir does not exist does not exist");
-
-        // Copy over the includes directory to the SCRATCH area.
-        std::string scratchIncludes = test_dir_ + "/";
-        std::string do_copy         = "cp -r " + includes() + " " + scratchIncludes;
-        if (system(do_copy.c_str()) != 0)
-            assert(false);
-
-        // clear log file
-        clearLog();
-    }
-    else if (!host_.empty() && host_ == Str::LOCALHOST()) {
-
-        client().set_host_port(host_, port_);
-        std::cout << "   EXTERNAL SERVER running on _SAME_ PLATFORM. Assuming " << client().host() << ":"
-                  << client().port() << "\n";
-
-        // Print the server stats before we start + checks if it is up and running::
-        client().set_cli(true); // so server stats are written to standard out
-        if (client().stats() != 0) {
-            std::cout << "   ClientInvoker " << CtsApi::stats() << " failed: " << client().errorMsg()
-                      << ". Is the server running?\n";
-            assert(false);
-        }
-        client().set_cli(false);
-
-        // log file may have been deleted, by previous tests. Create a new log file
-        std::string the_log_file = TestFixture::pathToLogFile();
-        if (!fs::exists(the_log_file)) {
-            std::cout << "   Log file " << the_log_file << " does NOT exist, attempting to recreate\n";
-            std::cout << "   Creating new log(via remote server) file " << the_log_file << "\n";
-            if (0 == client().new_log(the_log_file)) {
-                client().logMsg("Created new log file. msg sent to force new log file to be written to disk");
-            }
-            else
-                cout << "   Log file " << TestFixture::pathToLogFile() << " creation failed " << client().errorMsg()
-                     << "\n";
-        }
-        else
-            cout << "   Log file " << the_log_file << " already exists\n";
-    }
-    else {
-        // For local host start by removing log file. Server invocation should create a new log file
-        fs::remove(fs::path(pathToLogFile()));
-        host_ = Str::LOCALHOST();
-
-        // Create a unique port number, allowing debug and release to run at the same time
-        // Note: linux64 and linux64intel, can run on same machine, on different workspace
-        // Hence the lock file is not sufficient. Hence we will make a client server call.
-        cout << "Find free port to start server, starting with port " << port_ << "\n";
-        auto the_port = ecf::convert_to<int>(port_);
-        while (!EcfPortLock::is_free(the_port))
-            the_port++;
-        port_ = ClientInvoker::find_free_port(the_port, true /*show debug output */);
-        EcfPortLock::create(port_);
-
-        // host_ is empty update to localhost, **since** port may have changed, update ClinetInvoker
-        client().set_host_port(host_, port_);
-
-        // Remove the generated check point files, at start of test, otherwise server will load check point file
-        Host h;
-        fs::remove(h.ecf_checkpt_file(port_));
-        fs::remove(h.ecf_backup_checkpt_file(port_));
-
-        std::string theServerInvokePath = File::find_ecf_server_path();
-        assert(!theServerInvokePath.empty());
-        theServerInvokePath += " --port=" + port_;
-        theServerInvokePath += " --ecfinterval=" + ecf::convert_to<std::string>(job_submission_interval());
-        theServerInvokePath += "&";
-        if (system(theServerInvokePath.c_str()) != 0)
-            assert(false); // " Server invoke failed "
-
-        std::cout << "   ECF_HOST not specified, starting LOCAL " << theServerInvokePath << "\n";
-    }
-
-    /// Ping the server to see if its running
-    /// Assume remote/local server started on the default port
-    /// Either way, we wait for 60 seconds for server, for it to respond to pings
-    /// This is important when server is started locally. We must wait for it to come alive.
-    if (!client().wait_for_server_reply()) {
-        cout << "   Ping server on " << client().host() << Str::COLON() << client().port()
-             << " failed. Is the server running ? " << client().errorMsg() << "\n";
-        assert(false);
-    }
-    cout << "   Ping OK: server running on:  " << client().host() << Str::COLON() << client().port() << "\n";
-
-    // Log file must exist, otherwise test will not work. Log file required for comparison
-    if (!fs::exists(TestFixture::pathToLogFile())) {
-        cout << "   Log file " << TestFixture::pathToLogFile() << " does not exist *************************** \n";
-        assert(false);
-    }
-
-    // Check host and port match
-    assert(host_ == client().host());
-    assert(port_ == client().port());
-}
-
-TestFixture::~TestFixture() {
-    // Note: Global fixture Destructor cannot use BOOST macro
-    std::cout << "TestFixture::~TestFixture() " << client().host() << ":" << client().port() << "\n";
-
-    // destructors should not allow exception propagation
-    try {
-#ifndef DEBUG_HOST_SERVER
-        if (!host_.empty() && fs::exists(test_dir_)) {
-            fs::remove_all(test_dir_);
-        }
-#endif
-#ifndef DEBUG_LOCAL_SERVER
-        if (fs::exists(local_ecf_home())) {
-            fs::remove_all(local_ecf_home());
-        }
-#endif
-
-        std::cout << "   Print the server suites\n";
-        client().set_cli(true);             // so server stats are written to standard out
-        client().set_throw_on_error(false); // destructors should not allow exception propagation
-        if (client().suites() != 0) {
-            std::cout << "TestFixture::~TestFixture(): ClientInvoker " << CtsApi::suites()
-                      << " failed: " << client().errorMsg() << "\n";
-        }
-
-        std::cout << "   Print the server stats\n";
-        if (client().stats() != 0) {
-            std::cout << "TestFixture::~TestFixture(): ClientInvoker " << CtsApi::stats()
-                      << " failed: " << client().errorMsg() << "\n";
-        }
-
-        std::cout << "   Kill the server, as all suites are complete. will work for local or external\n";
-        if (client().terminateServer() != 0) {
-            std::cout << "TestFixture::~TestFixture():  ClientInvoker " << CtsApi::terminateServer()
-                      << " failed: " << client().errorMsg() << "\n";
-            EcfPortLock::remove(port_);
-            assert(false);
-        }
-        sleep(1); // allow time to update log file
-
-        std::cout << "   Remove the generated check point files, at end of test\n";
-        Host host;
-        fs::remove(host.ecf_log_file(port_));
-        fs::remove(host.ecf_checkpt_file(port_));
-        fs::remove(host.ecf_backup_checkpt_file(port_));
-
-        std::cout << "   remove the lock file\n";
-        EcfPortLock::remove(port_);
-
-        std::cout << "   Rtt::destroy(), so that we flush the rtt_filename\n";
-        Rtt::destroy();
-
-        cout << "\nTiming: *NOTE*: The child commands *NOT* recorded. Since its a separate exe(ecflow_client), called "
-                "via .ecf script\n";
-        cout << Rtt::analyis(rtt_filename); // report round trip times
-        fs::remove(rtt_filename);
-    }
-    catch (std::exception& ex) {
-        std::cout << "TestFixture::~TestFixture() caught exception " << ex.what() << "\n";
-    }
-    catch (...) {
-        std::cout << "TestFixture::~TestFixture() caught unknown exception\n";
-    }
-
-    std::cout << "TestFixture::~TestFixture() END\n";
-}
-
-int TestFixture::job_submission_interval() {
-    int jobSubmissionInterval = 3;
-#if defined(HPUX) || defined(_AIX)
-    jobSubmissionInterval += 3;
-#endif
-    return jobSubmissionInterval;
-}
-
-std::string TestFixture::smshome() {
-    if (serverOnLocalMachine())
-        return local_ecf_home();
-    return scratchSmsHome_;
-}
-
-bool TestFixture::serverOnLocalMachine() {
-    return (host_.empty() || host_ == Str::LOCALHOST());
-}
-
-std::string TestFixture::theClientExePath() {
-    if (serverOnLocalMachine())
-        return File::find_ecf_client_path();
-
-    char* client_path_p = getenv("ECF_CLIENT_EXE_PATH");
-    if (client_path_p == nullptr) {
-
-        // Try this before complaining
-        std::string path = "/usr/local/apps/ecflow/current/bin/ecflow_client";
-        if (fs::exists(path))
-            return path;
-
-        cout << "Please set ECF_CLIENT_EXE_PATH. This needs to be set to path to the client executable\n";
-        cout << "The client must be the one that was built on the same platform as the server\n";
-        assert(false);
-    }
-    return string(client_path_p);
-}
-
-void TestFixture::clearLog() {
-
-    // Can't remove log on remote server, just clear the log file
-    client().clearLog();
-}
-
-std::string TestFixture::pathToLogFile() {
-    if (serverOnLocalMachine()) {
-        Host host;
-        return host.ecf_log_file(port_);
-    }
-
-    char* pathToRemoteLog_p = getenv("ECF_LOG");
-    if (pathToRemoteLog_p == nullptr) {
-        cout << "TestFixture::pathToLogFile(): assert failed\n";
-        cout << "Please set ECF_LOG. This needs to be set to path to the log file\n";
-        cout << "that can be seen by the client and server\n";
-        assert(false);
-    }
-    return std::string(pathToRemoteLog_p);
-}
-
-std::string TestFixture::local_ecf_home() {
-    std::string compiler = "unknown";
-#if defined(_AIX)
-    compiler = "aix";
-#elif defined(HPUX)
-    compiler = "hpux";
-#else
-    #if defined(__clang__)
-    compiler = "clang";
-    #elif defined(__INTEL_COMPILER)
-    compiler = "intel";
-    #elif defined(_CRAYC)
-    compiler = "cray";
-    #else
-    compiler = "gnu";
-    #endif
-#endif
-
-    std::string build_type = "unknown";
-#ifdef DEBUG
-    build_type = "debug";
-#else
-    build_type = "release";
-#endif
-
-    std::string rel_path = "data/ECF_HOME_" + build_type + "_" + compiler;
-
-    // Allow post-fix to be added, to allow test to run in parallel
-    if (const char* custom_postfix = getenv("TEST_ECF_HOME_POSTFIX"); custom_postfix) {
-        rel_path += custom_postfix;
-    }
-
-    std::string absolute_path = File::test_data_in_current_dir(rel_path);
-    return absolute_path;
-}
-
-std::string TestFixture::includes() {
-    // Get to the root source directory
-    std::string includes_path = File::root_source_dir();
-    includes_path += "/";
-    includes_path += project_test_dir_;
-    includes_path += "/data/includes";
-    // std::cout << "includes_path = " << includes_path << " ==============================================\n";
-    return includes_path;
-}
-
-/// Given a task name like "a" find the find the first task matching that name
-/// and returns is abs node path
-std::string TestFixture::taskAbsNodePath(const Defs& theDefs, const std::string& taskName) {
-    std::vector<Task*> vec;
-    theDefs.getAllTasks(vec);
-    for (Task* t : vec) {
-        if (t->name() == taskName)
-            return t->absNodePath();
-    }
-
-    cout << "TestFixture::taskAbsNodePath: assert failed: Could not find task " << taskName << "\n";
-    assert(false); // could not find the task ??
-    return string();
-}
-
-int TestFixture::server_version() {
-    client().server_version();
-    std::string the_server_version_str = TestFixture::client().get_string();
-    // cout << "\nserver_version_str = " << the_server_version_str << "\n";
-    BOOST_REQUIRE_MESSAGE(Str::replace_all(the_server_version_str, ".", ""),
-                          "failed to find '.' in server version string " << TestFixture::client().get_string());
-
-    // Could 4.0.8rc1
-    Str::replace_all(the_server_version_str, "rc1", "");
-    Str::replace_all(the_server_version_str, "rc2", "");
-    auto the_server_version = ecf::convert_to<int>(the_server_version_str);
-    return the_server_version;
-}
diff -pruN 5.12.4-1/Test/src/TestFixture.hpp 5.13.0-1/Test/src/TestFixture.hpp
--- 5.12.4-1/Test/src/TestFixture.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/src/TestFixture.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,106 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_test_harness_TestFixture_HPP
-#define ecflow_test_harness_TestFixture_HPP
-
-///
-/// \brief This Fixture facilitates the test of client/server on different platforms
-///
-/// In order to carry out the test, we must have a common file system.
-/// We will use $SCRATCH as this is accessible by both client and server.
-/// This means copying over the test data
-///
-/// When TextFixture is GLOBAL, then we can't seem to call any of the
-/// BOOST_REQUIRE_MESSAGE() macro in constructor/descructor as this causes a crash
-/// i.e order of initialisation issues
-///
-
-#include <string>
-
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/PrintStyle.hpp"
-
-class Defs;
-
-//
-// Need to use static data, since with boost global fixture, its not possible to access
-// the global test fixture in each of the test cases
-//
-struct TestFixture
-{
-
-    // Constructor will invoke the server, destructor will kill the server
-    // Since this class is static, the constructor/destructor cannot call
-    // any of BOOST MACRO, since the unit test will not be there.
-    // When running across platforms will will assume server is already running
-    explicit TestFixture(const std::string& project_test_dir /* Test or view */);
-    TestFixture();
-    ~TestFixture();
-
-    // Configure the server with the job submission interval.
-    // i.e for each 'n' seconds of job submission interval the calendar
-    // is typically incremented by 1 minute. Hence speeding up the
-    // time and thus the testing. See Calendar for further details
-    static int job_submission_interval();
-
-    /// The location of ECF home will vary. If client/server on same machines we
-    /// return test data location. Otherwise we need return a common file system location
-    /// that was created in the constructor
-    static std::string smshome();
-
-    /// Will end up checking to see if ECF_HOST is specified. This specifies the name
-    /// of the machine that is running the server. Otherwise return true
-    static bool serverOnLocalMachine();
-
-    /// If running locally returns  location of client exe, if a server is on a remote
-    /// machine, we need to determine its location.
-    // Several options:
-    //    a/ Search for hard code path
-    //    b/ Ask server about test data, i.e. client exe path, log file location , etc
-    //       More flexible
-    static std::string theClientExePath();
-
-    /// When multiple tests are run , we need to clear the log file
-    static void clearLog();
-
-    /// When local just returns ecf.log, when remote return path to log file
-    static std::string pathToLogFile();
-
-    /// Given a task name like "a" find the find the first task matching that name
-    /// and returns is abs node path
-    static std::string taskAbsNodePath(const Defs& theDefs, const std::string& taskName);
-
-    /// Location of the includes used in the ecf file
-    static std::string includes();
-
-    /// returns the server version as an integer.
-    /// This allows as to ignore some tests, when testing old servers.(with new clients).
-    static int server_version();
-
-    // Use for all comms with server
-    static ClientInvoker& client();
-    static std::string port() { return port_; }
-
-private:
-    static std::string local_ecf_home();
-
-    void init(const std::string& project_test_dir);
-
-private:
-    static std::string scratchSmsHome_;
-    static std::string host_;
-    static std::string port_;
-    static std::string test_dir_;         // used when we have an external server, different platform
-    static std::string project_test_dir_; // "Test" or "view"
-    PrintStyle print_style_;              // by default show state when writing defs to standard out. RAII
-};
-
-#endif /* ecflow_test_harness_TestFixture_HPP */
diff -pruN 5.12.4-1/Test/src/ZombieUtil.hpp 5.13.0-1/Test/src/ZombieUtil.hpp
--- 5.12.4-1/Test/src/ZombieUtil.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/src/ZombieUtil.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_test_harness_ZombieUtil_HPP
-#define ecflow_test_harness_ZombieUtil_HPP
-
-#include "ecflow/core/Child.hpp"
-#include "ecflow/core/User.hpp"
-
-class ClientInvoker;
-
-class ZombieUtil {
-private:
-    ZombieUtil(const ZombieUtil&)                  = delete;
-    const ZombieUtil& operator=(const ZombieUtil&) = delete;
-
-public:
-    static void test_clean_up(int timeout);
-    static int do_zombie_user_action(ecf::User::Action uc,
-                                     int expected_action_cnt,
-                                     int max_time_to_wait,
-                                     bool fail_if_to_long = true);
-};
-
-class TestClean {
-private:
-    TestClean(const TestClean&)                  = delete;
-    const TestClean& operator=(const TestClean&) = delete;
-
-public:
-    explicit TestClean(int timeout = 25) : timeout_(timeout) { ZombieUtil::test_clean_up(timeout); }
-    ~TestClean() { ZombieUtil::test_clean_up(timeout_); }
-
-private:
-    int timeout_;
-};
-
-#endif /* ecflow_test_harness_ZombieUtil_HPP */
diff -pruN 5.12.4-1/Test/src/ZombieUtill.cpp 5.13.0-1/Test/src/ZombieUtill.cpp
--- 5.12.4-1/Test/src/ZombieUtill.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Test/src/ZombieUtill.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,173 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestFixture.hpp"
-#include "ZombieUtil.hpp"
-#include "ecflow/attribute/Zombie.hpp"
-#include "ecflow/core/AssertTimer.hpp"
-
-using namespace std;
-using namespace ecf;
-
-void ZombieUtil::test_clean_up(int timeout) {
-
-    // try to tidy up. Avoid leaving zombie process that mess up tests
-    TestFixture::client().zombieGet();
-    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-    if (!zombies.empty()) {
-        cout << "\nZombieUtil::test_clean_up: Found Zombies:\n";
-        cout << "Client Environment:\n" << TestFixture::client().to_string() << "\n";
-        cout << Zombie::pretty_print(zombies, 9) << "\n, attempting to *fob* then *remove* ...\n";
-
-        int no_fobed =
-            do_zombie_user_action(User::FOB, zombies.size(), timeout, false /* don't fail if it takes to long */);
-
-        // In order to FOB, we must wait, till a child command, talks to the server.
-        if (no_fobed) {
-            int wait = 5;
-#if defined(HPUX) || defined(_AIX)
-            wait += 5; // On these platforms wait longer,
-#endif
-            cout << "   Fobed " << no_fobed << " left over zombies. sleeping for " << wait
-                 << "s before attempting to remove\n";
-            sleep(wait);
-        }
-        (void)do_zombie_user_action(User::REMOVE, no_fobed, timeout, false /* don't fail if it takes to long */);
-    }
-}
-
-int ZombieUtil::do_zombie_user_action(User::Action uc,
-                                      int expected_action_cnt,
-                                      int max_time_to_wait,
-                                      bool fail_if_to_long) {
-    /// return the number of zombies set to user action;
-    bool ecf_debug_zombies = false;
-    if (getenv("ECF_DEBUG_ZOMBIES")) {
-        ecf_debug_zombies = true;
-        cout << "\n   do_zombie_user_action " << User::to_string(uc) << " expected_action_cnt " << expected_action_cnt
-             << "\n";
-    }
-
-    int action_set = 0;
-    std::vector<Zombie> action_set_zombies;
-    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
-    while (true) {
-        BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
-                              "zombieGet failed should return 0\n"
-                                  << TestFixture::client().errorMsg());
-        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
-        bool continue_looping       = false;
-        for (const Zombie& z : zombies) {
-            switch (uc) {
-                case User::FOB: {
-                    if (!z.fob()) {
-                        TestFixture::client().zombieFob(z); // UNBLOCK, child commands, allow zombie to complete, will
-                                                            // clear server_reply().zombies()
-                        continue_looping = true;
-                        action_set++;
-                        action_set_zombies.push_back(z);
-                    }
-                    break;
-                }
-                case User::FAIL: {
-                    if (!z.fail()) {
-                        TestFixture::client().zombieFail(z); // UNBLOCK, child commands, allow zombie to complete, will
-                                                             // clear server_reply().zombies()
-                        continue_looping = true;
-                        action_set++;
-                        action_set_zombies.push_back(z);
-                    }
-                    break;
-                }
-                case User::ADOPT: {
-                    if (!z.adopt()) {
-                        TestFixture::client().zombieAdopt(z); // UNBLOCK, child commands, allow zombie to complete, will
-                                                              // clear server_reply().zombies()
-                        continue_looping = true;
-                        action_set++;
-                        action_set_zombies.push_back(z);
-                    }
-                    break;
-                }
-                case User::REMOVE: {
-                    if (!z.remove()) {                         // should always return false
-                        TestFixture::client().zombieRemove(z); // This should be immediate, and is not remembered
-                        continue_looping = true;
-                        action_set++;
-                        action_set_zombies.push_back(z);
-                    }
-                    break;
-                }
-                case User::BLOCK: {
-                    if (!z.block()) {
-                        TestFixture::client().zombieBlock(z);
-                        continue_looping = true;
-                        action_set++;
-                        action_set_zombies.push_back(z);
-                    }
-                    break;
-                }
-                case User::KILL: {
-                    if (!z.kill()) {
-                        TestFixture::client().zombieKill(z);
-                        continue_looping = true;
-                        action_set++;
-                        action_set_zombies.push_back(z);
-                    }
-                    break;
-                }
-            }
-        }
-
-        if (expected_action_cnt == action_set) {
-            break; // return
-        }
-
-        if (!continue_looping && action_set > 0) {
-            if (expected_action_cnt == 0)
-                break; // return, some clients set this as 0
-        }
-
-        // make sure test does not take too long.
-        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
-
-            if (expected_action_cnt > 0 && action_set > 0) {
-                if (ecf_debug_zombies)
-                    cout << "   timeing out after action_set = " << action_set
-                         << " expected_action_cnt = " << expected_action_cnt << "\n";
-                break;
-            }
-
-            std::stringstream ss;
-            ss << "do_zombie_user_action:\nExpected " << expected_action_cnt << " zombies with user action "
-               << User::to_string(uc) << " but found " << action_set << "\naction set zombies\n"
-               << Zombie::pretty_print(action_set_zombies, 6) << ", Test taking longer than time constraint of "
-               << assertTimer.timeConstraint();
-            if (fail_if_to_long) {
-                BOOST_REQUIRE_MESSAGE(false, ss.str() << " aborting\n" << Zombie::pretty_print(zombies, 6));
-            }
-            else {
-                cout << ss.str() << " breaking out\n" << Zombie::pretty_print(zombies, 6) << "\n";
-                break;
-            }
-        }
-        sleep(1);
-    }
-
-    if (ecf_debug_zombies) {
-        cout << "   " << action_set << " zombies set to user action " << User::to_string(uc) << " returning\n";
-        cout << Zombie::pretty_print(action_set_zombies, 6);
-    }
-    return action_set;
-}
diff -pruN 5.12.4-1/Udp/CMakeLists.txt 5.13.0-1/Udp/CMakeLists.txt
--- 5.12.4-1/Udp/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,144 +0,0 @@
-#
-# Copyright 2009- ECMWF.
-#
-# This software is licensed under the terms of the Apache Licence version 2.0
-# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
-# In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation
-# nor does it submit to any jurisdiction.
-#
-
-# ==============================================================================
-# ECFLOW UDP library
-
-set(LIB_TARGET libecflow_udp)
-
-set(${LIB_TARGET}_srcs
-  # Headers
-  src/ecflow/udp/ClientAPI.hpp
-  src/ecflow/udp/RequestHandler.hpp
-  src/ecflow/udp/Trace.hpp
-  src/ecflow/udp/UDPServer.hpp
-  src/ecflow/udp/UDPServerEnvironment.hpp
-  src/ecflow/udp/UDPServerOptions.hpp
-  # Sources
-  src/ecflow/udp/ClientAPI.cpp
-  src/ecflow/udp/RequestHandler.cpp
-  src/ecflow/udp/Trace.cpp
-  src/ecflow/udp/UDPServerEnvironment.cpp
-  src/ecflow/udp/UDPServerOptions.cpp
-)
-
-ecbuild_add_library(
-  TARGET
-    ${LIB_TARGET}
-  TYPE STATIC
-  NOINSTALL
-  SOURCES
-    ${${LIB_TARGET}_srcs}
-  PRIVATE_INCLUDES
-    src
-  PUBLIC_LIBS
-    libclient
-    nlohmann::json
-    Boost::boost
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-    Threads::Threads
-)
-target_clangformat(${LIB_TARGET})
-
-# ==============================================================================
-# ECFLOW UDP server
-
-set(SERVER_TARGET ecflow_udp)
-
-set(${SERVER_TARGET}_srcs
-  # Sources
-  src/ecflow/udp/UDPServerMain.cpp
-)
-
-ecbuild_add_executable(
-  TARGET ${SERVER_TARGET}
-  SOURCES ${${SERVER_TARGET}_srcs}
-  INCLUDES
-    src
-  LIBS
-    ${LIB_TARGET}
-    core
-)
-set_target_properties(${SERVER_TARGET} PROPERTIES
-  INSTALL_RPATH ""
-)
-target_clangformat(${SERVER_TARGET})
-
-
-# ==============================================================================
-# ECFLOW UDP Client
-
-set(CLIENT_TARGET ecflow_udp_client)
-
-set(${CLIENT_TARGET}_srcs
-  # HEADERS
-  src/ecflow/udp/UDPClient.hpp
-  # SOURCES
-  src/ecflow/udp/UDPClientMain.cpp
-)
-
-ecbuild_add_executable(
-  TARGET ${CLIENT_TARGET}
-  SOURCES ${${CLIENT_TARGET}_srcs}
-  INCLUDES
-    src
-  LIBS
-    pthread
-    Boost::boost
-    Boost::filesystem
-)
-set_target_properties(${CLIENT_TARGET} PROPERTIES
-  INSTALL_RPATH ""
-)
-
-target_clangformat(${CLIENT_TARGET})
-
-# ==============================================================================
-# ECFLOW UDP Test(s)
-
-set(TEST_TARGET s_udp)
-
-list(APPEND ${TEST_TARGET}_srcs
-  # HEADERS
-  test/TestSupport.hpp
-  # SOURCES
-  test/TestUDP_main.cpp
-  test/TestUDPServer.cpp
-)
-
-ecbuild_add_test(
-  TARGET
-    ${TEST_TARGET}
-  LABELS
-    integration nightly
-  SOURCES
-    ${${TEST_TARGET}_srcs}
-  LIBS
-    ${LIB_TARGET}
-    libclient
-    Boost::boost
-    Boost::unit_test_framework
-    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
-  DEPENDS
-    ecflow_server # the server is launched to support tests
-    ${SERVER_TARGET}
-  DEFINITIONS
-    ${BOOST_TEST_DYN_LINK}
-  INCLUDES
-    src
-  WORKING_DIRECTORY
-    ${CMAKE_CURRENT_BINARY_DIR}/test_sandbox
-  ENVIRONMENT
-    "PATH=${CMAKE_BINARY_DIR}/bin:$ENV{PATH}"
-)
-
-target_clangformat(${TEST_TARGET} CONDITION ENABLE_TESTS)
-
-file(COPY test/data/reference.def DESTINATION ${CMAKE_CURRENT_BINARY_DIR}/test_sandbox/data)
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/ClientAPI.cpp 5.13.0-1/Udp/src/ecflow/udp/ClientAPI.cpp
--- 5.12.4-1/Udp/src/ecflow/udp/ClientAPI.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/ClientAPI.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,89 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/udp/ClientAPI.hpp"
-
-#include "ecflow/client/ClientInvoker.hpp"
-
-namespace ecf {
-
-template <typename F>
-void ClientAPI::try_invoke(F f) const {
-    try {
-        f(invoker_);
-    }
-    catch (std::runtime_error& e) {
-        throw ClientAPIException(std::string("Client error detected: ") + e.what());
-    }
-    catch (...) {
-        throw ClientAPIException("Unknown client error detected");
-    }
-}
-
-ClientAPI::ClientAPI() : invoker_(std::make_unique<ClientInvoker>()) {
-}
-
-ClientAPI::~ClientAPI() = default;
-
-void ClientAPI::user_set_name(const std::string& username) {
-    invoker_->set_user_name(username);
-}
-
-void ClientAPI::user_set_password(const std::string& password) {
-    invoker_->set_password(password);
-}
-
-void ClientAPI::user_update_meter(const std::string& path, const std::string& name, const std::string& value) const {
-    try_invoke([&path, &name, &value](const auto& invoker) { invoker->alter(path, "change", "meter", name, value); });
-}
-
-void ClientAPI::user_update_label(const std::string& path, const std::string& name, const std::string& value) const {
-    try_invoke([&path, &name, &value](const auto& invoker) { invoker->alter(path, "change", "label", name, value); });
-}
-
-void ClientAPI::user_clear_event(const std::string& path, const std::string& name) const {
-    try_invoke([&path, &name](const auto& invoker) { invoker->alter(path, "change", "event", name, "clear"); });
-}
-void ClientAPI::user_set_event(const std::string& path, const std::string& name) const {
-    try_invoke([&path, &name](const auto& invoker) { invoker->alter(path, "change", "event", name, "set"); });
-}
-
-void ClientAPI::child_set_remote_id(const std::string& pid) {
-    invoker_->set_child_pid(pid);
-}
-
-void ClientAPI::child_set_password(const std::string& password) {
-    invoker_->set_child_password(password);
-}
-
-void ClientAPI::child_set_try_no(int try_no) {
-    invoker_->set_child_try_no(try_no);
-}
-
-void ClientAPI::child_update_meter(const std::string& path, const std::string& name, const std::string& value) const {
-    invoker_->set_child_path(path);
-    try_invoke([name, value](const auto& invoker) { invoker->meterTask(name, value); });
-}
-
-void ClientAPI::child_update_label(const std::string& path, const std::string& name, const std::string& value) const {
-    invoker_->set_child_path(path);
-    try_invoke([name, value](const auto& invoker) { invoker->labelTask(name, std::vector<std::string>{value}); });
-}
-
-void ClientAPI::child_clear_event(const std::string& path, const std::string& name) const {
-    invoker_->set_child_path(path);
-    try_invoke([name](const auto& invoker) { invoker->eventTask(name, "clear"); });
-}
-void ClientAPI::child_set_event(const std::string& path, const std::string& name) const {
-    invoker_->set_child_path(path);
-    try_invoke([name](const auto& invoker) { invoker->eventTask(name, "set"); });
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/ClientAPI.hpp 5.13.0-1/Udp/src/ecflow/udp/ClientAPI.hpp
--- 5.12.4-1/Udp/src/ecflow/udp/ClientAPI.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/ClientAPI.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_ClientApi_HPP
-#define ecflow_udp_ClientApi_HPP
-
-#include <memory>
-#include <stdexcept>
-#include <string>
-
-// Forward Declaration
-class ClientInvoker;
-
-namespace ecf {
-
-struct ClientAPIException : public std::runtime_error
-{
-    explicit ClientAPIException(const char* msg) : std::runtime_error(msg) {}
-    explicit ClientAPIException(const std::string& msg) : std::runtime_error(msg) {}
-};
-
-/**
- * The ClientAPI enables the operations available to ecFlow UDP clients.
- */
-class ClientAPI {
-public:
-    ClientAPI();
-    ClientAPI(const ClientAPI&) = delete;
-    ClientAPI(ClientAPI&&)      = delete;
-    ~ClientAPI();
-
-    /// Define the User Name
-    void user_set_name(const std::string& username);
-
-    /// Define the User Password
-    void user_set_password(const std::string& password);
-
-    void user_update_meter(const std::string& path, const std::string& name, const std::string& value) const;
-    void user_update_label(const std::string& path, const std::string& name, const std::string& value) const;
-    void user_clear_event(const std::string& path, const std::string& name) const;
-    void user_set_event(const std::string& path, const std::string& name) const;
-
-    /// Define the Remote Id (i.e. ECF_RID) for a child Task request
-    void child_set_remote_id(const std::string& pid);
-    /// Define the Password (i.e. ECF_PASS) for a child Task request
-    void child_set_password(const std::string& password);
-    /// Define the Try Number (i.e. ECF_TRYNO) for a child Task request
-    void child_set_try_no(int try_no);
-
-    // Notice that, in the following functions, path represents ECF_NAME for a Task request
-    void child_update_meter(const std::string& path, const std::string& name, const std::string& value) const;
-    void child_update_label(const std::string& path, const std::string& name, const std::string& value) const;
-    void child_clear_event(const std::string& path, const std::string& name) const;
-    void child_set_event(const std::string& path, const std::string& name) const;
-
-private:
-    template <typename F>
-    void try_invoke(F f) const;
-
-private:
-    std::unique_ptr<ClientInvoker> invoker_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_udp_ClientApi_HPP */
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/RequestHandler.cpp 5.13.0-1/Udp/src/ecflow/udp/RequestHandler.cpp
--- 5.12.4-1/Udp/src/ecflow/udp/RequestHandler.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/RequestHandler.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,429 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/udp/RequestHandler.hpp"
-
-#include <string>
-#include <vector>
-
-#include <nlohmann/json.hpp>
-
-#include "ecflow/core/Converter.hpp"
-#include "ecflow/udp/ClientAPI.hpp"
-#include "ecflow/udp/Trace.hpp"
-
-namespace ecf {
-
-namespace /* __anonymous__ */ {
-
-/// The interface of a `command`
-class BasicCommand {
-public:
-    virtual void execute(ClientAPI& ctx) = 0;
-    virtual ~BasicCommand()              = default;
-};
-
-/// The default implementation of a `command`, enables CRTP-based mixins
-template <typename COMMAND>
-class DefaultCommand : public BasicCommand {
-public:
-    void execute(ClientAPI& client) final { static_cast<COMMAND*>(this)->actually_execute(client); }
-};
-
-/// The `command` to update an ecFlow meter (issued by an ecFlow user)
-class CommandUserAlterMeter : public DefaultCommand<CommandUserAlterMeter> {
-public:
-    explicit CommandUserAlterMeter(std::string path, std::string name, int value)
-        : path_{std::move(path)},
-          name_{std::move(name)},
-          value_{value} {};
-    void actually_execute(const ClientAPI& client) const {
-        client.user_update_meter(path_, name_, std::to_string(value_));
-    };
-
-    static constexpr const char* COMMAND_TAG = "alter_meter";
-
-private:
-    std::string path_;
-    std::string name_;
-    int value_;
-};
-
-/// The `command` to update an ecFlow label (issued by an ecFlow user)
-class CommandUserAlterLabel : public DefaultCommand<CommandUserAlterLabel> {
-public:
-    explicit CommandUserAlterLabel(std::string path, std::string name, std::string value)
-        : path_{std::move(path)},
-          name_{std::move(name)},
-          value_{std::move(value)} {};
-    void actually_execute(const ClientAPI& client) const { client.user_update_label(path_, name_, value_); };
-
-    static constexpr const char* COMMAND_TAG = "alter_label";
-
-private:
-    std::string path_;
-    std::string name_;
-    std::string value_;
-};
-
-/// The `command` to update an ecFlow event (issued by an ecFlow user)
-class CommandUserAlterEvent : public DefaultCommand<CommandUserAlterEvent> {
-public:
-    explicit CommandUserAlterEvent(std::string path, std::string name, bool value)
-        : path_{std::move(path)},
-          name_{std::move(name)},
-          value_{value} {};
-    void actually_execute(const ClientAPI& client) const {
-        if (value_) {
-            client.user_set_event(path_, name_);
-        }
-        else {
-            client.user_clear_event(path_, name_);
-        }
-    };
-
-    static constexpr const char* COMMAND_TAG = "alter_event";
-
-private:
-    std::string path_;
-    std::string name_;
-    bool value_;
-};
-
-/// The `command` to update an ecFlow meter (issued by an ecFlow child process)
-class CommandChildUpdateMeter : public DefaultCommand<CommandChildUpdateMeter> {
-public:
-    explicit CommandChildUpdateMeter(std::string path, std::string name, int value)
-        : path_{std::move(path)},
-          name_{std::move(name)},
-          value_{value} {};
-    void actually_execute(const ClientAPI& client) const {
-        client.child_update_meter(path_, name_, std::to_string(value_));
-    };
-
-    static constexpr const char* COMMAND_TAG = "meter";
-
-private:
-    std::string path_;
-    std::string name_;
-    int value_;
-};
-
-/// The `command` to update an ecFlow label (issued by an ecFlow child process)
-class CommandChildUpdateLabel : public DefaultCommand<CommandChildUpdateLabel> {
-public:
-    explicit CommandChildUpdateLabel(std::string path, std::string name, std::string value)
-        : path_{std::move(path)},
-          name_{std::move(name)},
-          value_{std::move(value)} {};
-    void actually_execute(const ClientAPI& client) const { client.child_update_label(path_, name_, value_); };
-
-    static constexpr const char* COMMAND_TAG = "label";
-
-private:
-    std::string path_;
-    std::string name_;
-    std::string value_;
-};
-
-/// The `command` to update an ecFlow event (issued by an ecFlow child process)
-class CommandChildUpdateEvent : public DefaultCommand<CommandChildUpdateEvent> {
-public:
-    explicit CommandChildUpdateEvent(std::string path, std::string name, bool value)
-        : path_{std::move(path)},
-          name_{std::move(name)},
-          value_{value} {};
-    void actually_execute(const ClientAPI& client) const {
-        if (value_) {
-            client.child_set_event(path_, name_);
-        }
-        else {
-            client.child_clear_event(path_, name_);
-        }
-    };
-
-    static constexpr const char* COMMAND_TAG = "event";
-
-private:
-    std::string path_;
-    std::string name_;
-    bool value_;
-};
-
-/// The actual (type erased) `command`
-class Command {
-public:
-    //
-    // (1) Declaring a user-defined constructor effectively disables a default constructor
-    // (2) Since the std::unique_ptr data member has a deleted copy-constructor,
-    //     the implicitly deplared copy-constructor of Command is also deleted
-    // (3) An implicitly declared move-constructor makes Command a move-only class
-    //
-
-    template <typename COMMAND, typename... ARGS>
-    static Command make_command(ARGS&&... args) {
-        return Command{std::make_unique<COMMAND>(std::forward<ARGS>(args)...)};
-    }
-
-    void execute(ClientAPI& client) const { impl_->execute(client); }
-
-private:
-    explicit Command(std::unique_ptr<BasicCommand>&& impl) : impl_{std::move(impl)} {}
-
-    std::unique_ptr<BasicCommand> impl_;
-};
-
-/// The `command` build interface
-class CommandBuilder {
-public:
-    virtual ~CommandBuilder()                 = default;
-    virtual const char* name()                = 0;
-    virtual Command build(nlohmann::json obj) = 0;
-};
-
-/// The builder for a `command` to update an ecFlow label (issued by an ecFlow user)
-class CommandUserAlterLabelBuilder : public CommandBuilder {
-public:
-    const char* name() override { return CommandUserAlterLabel::COMMAND_TAG; };
-    Command build(nlohmann::json obj) override {
-        assert(obj.at("command") == name());
-
-        std::string name  = obj.at("name");
-        std::string path  = obj.at("path");
-        std::string value = obj.at("value");
-
-        return Command::make_command<CommandUserAlterLabel>(path, name, value);
-    }
-};
-
-/// The builder for a `command` to update an ecFlow meter (issued by an ecFlow user)
-class CommandUserAlterMeterBuilder : public CommandBuilder {
-public:
-    const char* name() override { return CommandUserAlterMeter::COMMAND_TAG; };
-    Command build(nlohmann::json obj) override {
-        assert(obj.at("command") == name());
-
-        std::string name  = obj.at("name");
-        std::string path  = obj.at("path");
-        std::string value = obj.at("value");
-
-        auto meter_value = ecf::convert_to<int>(value);
-
-        return Command::make_command<CommandUserAlterMeter>(path, name, meter_value);
-    }
-};
-
-/// The builder for a `command` to update an ecFlow event (issued by an ecFlow user)
-class CommandUserAlterEventBuilder : public CommandBuilder {
-public:
-    const char* name() override { return CommandUserAlterEvent::COMMAND_TAG; };
-    Command build(nlohmann::json obj) override {
-        assert(obj.at("command") == name());
-
-        std::string name  = obj.at("name");
-        std::string path  = obj.at("path");
-        std::string value = obj.at("value");
-
-        bool event_value;
-        if (value == "1") {
-            event_value = true;
-        }
-        else if (value == "0") {
-            event_value = false;
-        }
-        else {
-            throw std::runtime_error("Unexpected Event value");
-        }
-
-        return Command::make_command<CommandUserAlterEvent>(path, name, event_value);
-    }
-};
-
-/// The builder for a `command` to update an ecFlow label (issued by an ecFlow child process)
-class CommandChildUpdateLabelBuilder : public CommandBuilder {
-public:
-    const char* name() override { return CommandChildUpdateLabel::COMMAND_TAG; };
-    Command build(nlohmann::json obj) override {
-        assert(obj.at("command") == name());
-
-        std::string name  = obj.at("name");
-        std::string path  = obj.at("path");
-        std::string value = obj.at("value");
-
-        TRACE_NFO("CommandChildUpdateLabelBuilder", "update to label ", path, ":", name, " to value: ", value)
-
-        return Command::make_command<CommandChildUpdateLabel>(path, name, value);
-    }
-};
-
-/// The builder for a `command` to update an ecFlow meter (issued by an ecFlow child process)
-class CommandChildUpdateMeterBuilder : public CommandBuilder {
-public:
-    const char* name() override { return CommandChildUpdateMeter::COMMAND_TAG; };
-    Command build(nlohmann::json obj) override {
-        assert(obj.at("command") == name());
-
-        std::string name  = obj.at("name");
-        std::string path  = obj.at("path");
-        std::string value = obj.at("value");
-
-        auto meter_value = ecf::convert_to<int>(value);
-
-        TRACE_NFO("CommandChildUpdateLabelBuilder", "update to meter ", path, ":", name, " to value: ", meter_value)
-
-        return Command::make_command<CommandChildUpdateMeter>(path, name, meter_value);
-    }
-};
-
-/// The builder for a `command` to update an ecFlow event (issued by an ecFlow child process)
-class CommandChildUpdateEventBuilder : public CommandBuilder {
-public:
-    const char* name() override { return CommandChildUpdateEvent::COMMAND_TAG; };
-    Command build(nlohmann::json obj) override {
-        assert(obj.at("command") == name());
-
-        std::string name  = obj.at("name");
-        std::string path  = obj.at("path");
-        std::string value = obj.at("value");
-
-        bool event_value;
-        if (value == "1") {
-            event_value = true;
-        }
-        else if (value == "0") {
-            event_value = false;
-        }
-        else {
-            throw std::runtime_error("Unexpected Event value");
-        }
-
-        TRACE_NFO("CommandChildUpdateLabelBuilder", "update to event ", path, ":", name, " to value: ", event_value)
-
-        return Command::make_command<CommandChildUpdateEvent>(path, name, event_value);
-    }
-};
-
-/// The factory of `command`; creates commands based on JSON data
-class CommandFactory {
-public:
-    CommandFactory() : builders_{} {
-        builders_.push_back(std::make_unique<CommandUserAlterLabelBuilder>());
-        builders_.push_back(std::make_unique<CommandUserAlterMeterBuilder>());
-        builders_.push_back(std::make_unique<CommandUserAlterEventBuilder>());
-        builders_.push_back(std::make_unique<CommandChildUpdateLabelBuilder>());
-        builders_.push_back(std::make_unique<CommandChildUpdateMeterBuilder>());
-        builders_.push_back(std::make_unique<CommandChildUpdateEventBuilder>());
-    };
-
-    Command make_command_from(nlohmann::json obj) {
-        std::string name = obj.at("command");
-        auto found       = std::find_if(std::begin(builders_), std::end(builders_), [&name](const auto& builder) {
-            return builder->name() == name;
-        });
-
-        if (found == std::end(builders_)) {
-            throw std::runtime_error("Unknown command detected");
-        }
-
-        return found->get()->build(obj);
-    }
-
-    std::vector<std::unique_ptr<CommandBuilder>> builders_;
-};
-
-class JSONRequestHandler {
-public:
-    JSONRequestHandler() : client_{} {}
-
-    void handle(const nlohmann::json& request) {
-        try {
-            std::string method_type = request.at("method");
-
-            // process "header"
-            if (request.contains("header")) {
-                nlohmann::json header = request.at("header");
-                configure_authentication(header);
-            }
-
-            // process "data"
-            if (method_type == "put") {
-                auto payload = request.at("payload");
-
-                Command command = command_factory_.make_command_from(payload);
-                command.execute(client_);
-            }
-            else {
-                TRACE_ERR("JSONRequestHandler", "unknown method: ", method_type)
-            }
-        }
-        catch (nlohmann::json::exception& e) {
-            TRACE_ERR("JSONRequestHandler", "JSON format error: ", e.what())
-            return;
-        }
-        catch (ClientAPIException& e) {
-            TRACE_ERR("JSONRequestHandler", "Client invocation error: ", e.what())
-            return;
-        }
-        catch (...) {
-            TRACE_ERR("JSONRequestHandler", "Unknown error detected handling request")
-            return;
-        }
-
-        TRACE_NFO("JSONRequestHandler", "request handled successfully")
-    }
-
-    void configure_authentication(const nlohmann::json& header) {
-        for (const auto& [key, value] : header.items()) {
-
-            if (key == "user_name") {
-                client_.user_set_name(value);
-            }
-            else if (key == "user_password") {
-                client_.user_set_password(value);
-            }
-            else if (key == "task_rid") {
-                client_.child_set_remote_id(value);
-            }
-            else if (key == "task_password") {
-                client_.child_set_password(value);
-            }
-            else if (key == "task_try_no") {
-                client_.child_set_try_no(value);
-            }
-            else {
-                TRACE_ERR("JSONRequestHandler", "unknown header: ", key, ", ignored.")
-            }
-        }
-    }
-
-private:
-    ClientAPI client_;
-    CommandFactory command_factory_;
-};
-
-} // namespace
-
-void RequestHandler::handle(const RequestHandler::inbound_t& request) const {
-    try {
-        TRACE_NFO("RequestHandler", "Processing request: ", request)
-
-        nlohmann::json inbound = nlohmann::json::parse(request);
-        JSONRequestHandler handler;
-        handler.handle(inbound);
-    }
-    catch (nlohmann::json::exception& e) {
-        TRACE_ERR("RequestHandler", "Unable to parse JSON request")
-    }
-    catch (...) {
-        TRACE_ERR("RequestHandler", "Unknown error detected")
-    }
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/RequestHandler.hpp 5.13.0-1/Udp/src/ecflow/udp/RequestHandler.hpp
--- 5.12.4-1/Udp/src/ecflow/udp/RequestHandler.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/RequestHandler.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_RequestHandler_HPP
-#define ecflow_udp_RequestHandler_HPP
-
-#include <string>
-
-namespace ecf {
-
-/**
- * Enables the handling of all requests by a ecFlow UDP server
- */
-struct RequestHandler
-{
-public:
-    using inbound_t = std::string;
-
-public:
-    void handle(const inbound_t& request) const;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_udp_RequestHandler_HPP */
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/Trace.cpp 5.13.0-1/Udp/src/ecflow/udp/Trace.cpp
--- 5.12.4-1/Udp/src/ecflow/udp/Trace.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/Trace.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/udp/Trace.hpp"
-
-#include <iostream>
-
-namespace ecf::log {
-
-Trace::Trace() : output_{std::cout}, verbose_{false} {
-}
-
-void Trace::store(const std::string& entry) const {
-    output_ << entry << std::endl;
-}
-
-Trace& getTrace() {
-    static Trace instance;
-    return instance;
-}
-
-} // namespace ecf::log
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/Trace.hpp 5.13.0-1/Udp/src/ecflow/udp/Trace.hpp
--- 5.12.4-1/Udp/src/ecflow/udp/Trace.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/Trace.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_Trace_HPP
-#define ecflow_udp_Trace_HPP
-
-#include <sstream>
-#include <string>
-
-namespace ecf::log {
-
-class Trace {
-public:
-    Trace();
-    ~Trace() = default;
-
-    inline void setVerbose(bool verbose) { verbose_ = verbose; }
-
-    template <typename... ARGS>
-    void add(const std::string& qualifier, const std::string& location, ARGS... args) const {
-        if (verbose_) {
-            std::ostringstream os;
-            os << "   " << location << " (" << qualifier << "): ";
-            ((os << args), ...);
-            store(os.str());
-        }
-    }
-
-private:
-    void store(const std::string& entry) const;
-
-    std::ostream& output_;
-    bool verbose_;
-};
-
-Trace& getTrace();
-
-} // namespace ecf::log
-
-#define TRACE_VERBOSE(verbose) \
-    { ecf::log::getTrace().setVerbose(verbose); }
-
-#define TRACE_NFO(location, ...) \
-    { ecf::log::getTrace().add("info", location, __VA_ARGS__); }
-
-#define TRACE_ERR(location, ...) \
-    { ecf::log::getTrace().add("error", location, __VA_ARGS__); }
-
-#define TRACE_FATAL(location, ...) \
-    { ecf::log::getTrace().add("error", location, __VA_ARGS__); }
-
-#endif /* ecflow_udp_Trace_HPP */
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPClient.hpp 5.13.0-1/Udp/src/ecflow/udp/UDPClient.hpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPClient.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPClient.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,95 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_UDPClient_HPP
-#define ecflow_udp_UDPClient_HPP
-
-#include <string>
-
-#include <boost/asio.hpp>
-
-namespace ecf {
-
-namespace internal_detail {
-
-/**
- * The UDP connection implemented using Boost.ASIO, sends a single Datagram in a "fire and forget" protocol.
- */
-class BaseUDPConnection {
-public:
-    BaseUDPConnection(boost::asio::io_service& io_service,
-                      boost::asio::ip::udp::endpoint server_endpoint,
-                      const std::string& request)
-        : socket_(io_service),
-          server_endpoint_(std::move(server_endpoint)) {
-        // Open socket connection
-        socket_.open(boost::asio::ip::udp::v4());
-        // Start 'protocol'...
-        start(request);
-    }
-
-private:
-    void start(const std::string& request) {
-        std::array<char, 65'507> request_buffer{};
-        std::copy_n(std::begin(request), request.size() + 1, std::begin(request_buffer));
-
-        // Send request
-        socket_.async_send_to(boost::asio::buffer(request_buffer, request.size() + 1),
-                              server_endpoint_,
-                              [this](const boost::system::error_code& error, size_t bytes_transferred) {
-                                  this->handle_send(error, bytes_transferred);
-                              });
-    }
-
-    void handle_send(const boost::system::error_code& error, std::size_t bytes_transferred [[maybe_unused]]) {
-        if (error) {
-            throw std::runtime_error("Unable to send request to ecFlow UDP");
-        }
-    }
-
-    boost::asio::ip::udp::socket socket_;
-
-    boost::asio::ip::udp::endpoint server_endpoint_;
-};
-
-} // namespace internal_detail
-
-/**
- * The UDP client implemented using Boost.ASIO.
- */
-class BaseUDPClient {
-public:
-    using hostname_t = std::string;
-    using port_t     = std::string;
-    using data_t     = std::string;
-
-public:
-    BaseUDPClient(hostname_t host, port_t port) : host_{std::move(host)}, port_{std::move(port)} {}
-
-    void send(const data_t& data) {
-        boost::asio::io_service io_service;
-        boost::asio::ip::udp::resolver resolver(io_service);
-        boost::asio::ip::udp::resolver::query query(boost::asio::ip::udp::v4(), host_, port_);
-        boost::asio::ip::udp::endpoint server_endpoint = *resolver.resolve(query);
-
-        internal_detail::BaseUDPConnection connection(io_service, server_endpoint, data);
-        io_service.run();
-    }
-
-private:
-    hostname_t host_;
-    port_t port_;
-};
-
-using UDPClient = BaseUDPClient;
-
-} // namespace ecf
-
-#endif /* ecflow_udp_UDPClient_HPP */
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPClientMain.cpp 5.13.0-1/Udp/src/ecflow/udp/UDPClientMain.cpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPClientMain.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPClientMain.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <utility>
-
-#include "ecflow/udp/UDPClient.hpp"
-
-int main(int argc, char* argv[]) {
-    if (argc != 4) {
-        std::cerr << "Usage: udp_client <host> <port> <request>" << std::endl;
-        return EXIT_FAILURE;
-    }
-
-    try {
-        std::string host    = argv[1];
-        std::string port    = argv[2];
-        std::string request = argv[3];
-
-        ecf::UDPClient client(host, port);
-        client.send(request);
-    }
-    catch (std::exception& e) {
-        std::cerr << e.what() << std::endl;
-        return EXIT_FAILURE;
-    }
-    catch (...) {
-        std::cerr << "Unknown error..." << std::endl;
-        return EXIT_FAILURE;
-    }
-
-    return EXIT_SUCCESS;
-}
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPServer.hpp 5.13.0-1/Udp/src/ecflow/udp/UDPServer.hpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPServer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPServer.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,99 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_UDPServer_HPP
-#define ecflow_udp_UDPServer_HPP
-
-#include <string>
-
-#include <boost/asio.hpp>
-
-#include "ecflow/udp/RequestHandler.hpp"
-
-namespace ecf {
-
-namespace internal_detail {
-
-template <typename HANDLER>
-class BaseUdpServerConnection {
-public:
-    BaseUdpServerConnection(HANDLER handler,
-                            boost::asio::io_service& io_service,
-                            const boost::asio::ip::udp::endpoint& server_endpoint)
-        : handler_{std::move(handler)},
-          socket_(io_service, server_endpoint),
-          client_endpoint_{},
-          buffer_{} {
-        start();
-    }
-
-private:
-    void start() {
-        // Receive request
-        socket_.async_receive_from(boost::asio::buffer(buffer_),
-                                   client_endpoint_,
-                                   [this](const boost::system::error_code& error, size_t bytes_transferred) {
-                                       this->handleReceive(error, bytes_transferred);
-                                   });
-    }
-
-    void handleReceive(const boost::system::error_code& error, std::size_t bytes_transferred) {
-        if (!error) {
-            // Take inbound request from (inbound) buffer...
-            std::string request;
-            std::copy_n(std::begin(buffer_), bytes_transferred, std::back_inserter(request));
-
-            // Process request
-            handler_.handle(request);
-        }
-        else {
-            std::cerr << "    BaseUDPServer (error): failure when receiving message" << std::endl;
-        }
-
-        start();
-    }
-
-private:
-    HANDLER handler_;
-    boost::asio::ip::udp::socket socket_;
-
-    // Used as information passed between async calls
-    boost::asio::ip::udp::endpoint client_endpoint_;
-    std::array<char, 65'507> buffer_;
-};
-
-} // namespace internal_detail
-
-/**
- * The UDP server listens for network packets, and delegates the requests to the given HANDLER
- */
-template <typename HANDLER>
-class BaseUdpServer {
-public:
-    BaseUdpServer(HANDLER handler, uint16_t port)
-        : io_service_{},
-          server_endpoint_{boost::asio::ip::udp::v4(), port},
-          connection_{handler, io_service_, server_endpoint_} {}
-    BaseUdpServer(const BaseUdpServer&) = delete;
-    BaseUdpServer(BaseUdpServer&&)      = delete;
-
-    void run() { io_service_.run(); }
-
-private:
-    boost::asio::io_service io_service_;
-    boost::asio::ip::udp::endpoint server_endpoint_;
-    internal_detail::BaseUdpServerConnection<HANDLER> connection_;
-};
-
-using UDPServer = BaseUdpServer<RequestHandler>;
-
-} // namespace ecf
-
-#endif /* ecflow_udp_UDPServer_HPP */
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPServerEnvironment.cpp 5.13.0-1/Udp/src/ecflow/udp/UDPServerEnvironment.cpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPServerEnvironment.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPServerEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,51 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/udp/UDPServerEnvironment.hpp"
-
-#include <cstdio>
-
-namespace ecf {
-
-namespace /* __anonymous__ */ {
-
-// all variables to be collected
-const char* const variables[] = {UDPServerEnvironment::ECF_UDP_VERBOSE,
-                                 UDPServerEnvironment::ECF_UDP_PORT,
-                                 UDPServerEnvironment::ECF_HOST,
-                                 UDPServerEnvironment::ECF_PORT};
-
-// the options related to each of the variables
-const std::unordered_map<std::string, std::string> options_map = {{UDPServerEnvironment::ECF_UDP_VERBOSE, "verbose"},
-                                                                  {UDPServerEnvironment::ECF_UDP_PORT, "port"},
-                                                                  {UDPServerEnvironment::ECF_HOST, "ecflow_host"},
-                                                                  {UDPServerEnvironment::ECF_PORT, "ecflow_port"}};
-
-} // namespace
-
-UDPServerEnvironment::UDPServerEnvironment() : environment_{} {
-    for (auto variable : variables) {
-        if (const char* value = ::getenv(variable); value) {
-            environment_[variable] = value;
-        }
-    }
-}
-
-std::string UDPServerEnvironment::as_configuration_file() const {
-    std::ostringstream os;
-    for (const auto& entry : environment_) {
-        if (auto found = options_map.find(entry.first); found != std::end(options_map)) {
-            os << found->second << "=" << entry.second << std::endl;
-        }
-    }
-    return os.str();
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPServerEnvironment.hpp 5.13.0-1/Udp/src/ecflow/udp/UDPServerEnvironment.hpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPServerEnvironment.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPServerEnvironment.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,62 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_UDPServerEnvironment_HPP
-#define ecflow_udp_UDPServerEnvironment_HPP
-
-#include <optional>
-#include <string>
-#include <unordered_map>
-#include <vector>
-
-#include "ecflow/core/Converter.hpp"
-
-namespace ecf {
-
-/**
- * Allows to collect information about environment variables related to ecFlow UDP,
- * and eventually customizes the options used to launch the server.
- */
-class UDPServerEnvironment {
-private:
-    using storage_t = std::unordered_map<std::string, std::string>;
-
-public:
-    UDPServerEnvironment();
-
-    bool get_variable(const std::string& key) const {
-        auto found = environment_.find(key);
-        return found != std::end(environment_);
-    }
-
-    template <typename U, std::enable_if_t<!std::is_same_v<bool, U>, bool> = true>
-    std::optional<U> get_variable(const std::string& key) const {
-        auto found = environment_.find(key);
-        if (found != std::end(environment_)) {
-            return ecf::convert_to<U>(found->second);
-        }
-        return {};
-    }
-
-    std::string as_configuration_file() const;
-
-public:
-    static constexpr const char* ECF_UDP_VERBOSE = "ECF_UDP_VERBOSE";
-    static constexpr const char* ECF_UDP_PORT    = "ECF_UDP_PORT";
-    static constexpr const char* ECF_HOST        = "ECF_HOST";
-    static constexpr const char* ECF_PORT        = "ECF_PORT";
-
-private:
-    storage_t environment_;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_udp_UDPServerEnvironment_HPP */
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPServerMain.cpp 5.13.0-1/Udp/src/ecflow/udp/UDPServerMain.cpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPServerMain.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPServerMain.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,104 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <iostream>
-#include <string>
-
-#include "ecflow/core/ecflow_version.h"
-#include "ecflow/udp/RequestHandler.hpp"
-#include "ecflow/udp/Trace.hpp"
-#include "ecflow/udp/UDPServer.hpp"
-#include "ecflow/udp/UDPServerOptions.hpp"
-
-static std::string ecflow_udp_server_version() {
-#ifdef DEBUG
-    const std::string TAG = " (debug) ";
-#else
-    const std::string TAG = " ";
-#endif
-
-    std::ostringstream oss;
-    oss << "Ecflow UDP" << TAG << "version(" << ECFLOW_RELEASE << "." << ECFLOW_MAJOR << "." << ECFLOW_MINOR << ")";
-    return oss.str();
-}
-
-static void run_server(uint16_t port) {
-    ecf::RequestHandler handler;
-    ecf::UDPServer server{handler, port};
-    server.run();
-}
-
-static int launch_server(const ecf::UDPServerOptions& options) {
-    bool verbose = options.has_verbose();
-    TRACE_VERBOSE(verbose)
-
-    auto port = options.get_option<size_t>(ecf::UDPServerOptions::OPTION_PORT);
-    TRACE_NFO("UDPServerMain", "starting server on port ", port)
-
-    try {
-        run_server(static_cast<uint16_t>(port));
-    }
-    catch (const std::exception& e) {
-        TRACE_FATAL("UDPServerMain", e.what())
-        return EXIT_FAILURE;
-    }
-    catch (...) {
-        TRACE_FATAL("UDPServerMain", "unknown error detected")
-        return EXIT_FAILURE;
-    }
-
-    return EXIT_SUCCESS;
-}
-
-int main(int argc, char* argv[]) try {
-
-    ecf::UDPServerOptions options(argc, const_cast<const char**>(argv));
-
-    if (options.has_help()) {
-        std::cout << std::endl << "  ecFlow UDP" << std::endl << std::endl;
-        std::cout << options.get_description() << std::endl;
-        return EXIT_SUCCESS;
-    }
-    if (options.has_version()) {
-        std::cout << ecflow_udp_server_version() << std::endl;
-        return EXIT_SUCCESS;
-    }
-
-    {
-        // Ensure the Client uses the ecFlow host+port
-        auto ecflow_host = options.get_optional_option<std::string>(ecf::UDPServerOptions::OPTION_ECFLOW_HOST);
-        auto ecflow_port = options.get_optional_option<size_t>(ecf::UDPServerOptions::OPTION_ECFLOW_PORT);
-        if (ecflow_host) {
-            setenv("ECF_HOST", ecflow_host.value().c_str(), 1);
-        }
-        if (ecflow_port) {
-            setenv("ECF_PORT", std::to_string(ecflow_port.value()).c_str(), 1);
-        }
-        // Avoid that the Client automatically uses environment passwords
-        unsetenv("ECF_PASSWD");
-        unsetenv("ECF_CUSTOM_PASSWD");
-
-        launch_server(options);
-    }
-
-    return EXIT_SUCCESS;
-}
-catch (ecf::InvalidCLIOption& e) {
-    std::cout << "Error: Invalid CLI option detected: " << e.what() << std::endl;
-    return EXIT_FAILURE;
-}
-catch (std::exception& e) {
-    std::cout << "Error: Unexpected problem detected: " << e.what() << std::endl;
-    return EXIT_FAILURE;
-}
-catch (...) {
-    std::cout << "Error: Unknown problem detected. Cowardly giving up!..." << std::endl;
-    return EXIT_FAILURE;
-}
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPServerOptions.cpp 5.13.0-1/Udp/src/ecflow/udp/UDPServerOptions.cpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPServerOptions.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPServerOptions.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,98 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include "ecflow/udp/UDPServerOptions.hpp"
-
-#include "ecflow/udp/UDPServerEnvironment.hpp"
-
-namespace ecf {
-
-InvalidCLIOption::~InvalidCLIOption() = default;
-
-namespace {
-
-template <typename... Args>
-std::string as_string(Args... args) {
-    std::ostringstream os;
-    ((os << args), ...);
-    return os.str();
-}
-
-} // namespace
-
-UDPServerOptions::UDPServerOptions(int argc, const char* argv[]) : general{create_options()}, variables{} {
-
-    po::options_description all_options("All");
-    all_options.add(general);
-
-    try {
-        // Collect command line options
-        po::command_line_parser parser{argc, argv};
-        parser.options(all_options)
-            .style(po::command_line_style::default_style | po::command_line_style::allow_slash_for_short);
-        auto cli_options = parser.run();
-        po::store(cli_options, variables);
-
-        // Collect environment options
-        // note: by being processed later, environment options don't override cli options)
-        UDPServerEnvironment environment;
-        std::stringstream ss;
-        ss << environment.as_configuration_file();
-        auto env_options = po::parse_config_file(ss, all_options, true);
-        po::store(env_options, variables);
-
-        ensure_valid_options(variables);
-
-        po::notify(variables);
-    }
-    catch (const po::error& error) {
-        throw InvalidCLIOption(error.what());
-    }
-    catch (const InvalidCLIOption& error) {
-        throw error;
-    }
-}
-
-void UDPServerOptions::ensure_valid_options(const po::variables_map& variables) {
-    if (variables.count(OPTION_HELP) > 0) {
-        // Nothing to do, help will be displayed even if other options are provided
-        return;
-    }
-
-    if (variables.count(OPTION_VERSION) > 0) {
-        // Nothing to do, version will be displayed even if other options are provided
-        return;
-    }
-
-    // Add all necessary options validation here!...
-}
-
-po::options_description UDPServerOptions::create_options() {
-    po::options_description general{"General"};
-    // clang-format off
-    general.add_options()
-        (as_string(OPTION_HELP, ",h").c_str(),
-                        "Display options help")
-        (as_string(OPTION_VERSION, ",v").c_str(),
-                        "Display version information")
-        (as_string(OPTION_VERBOSE).c_str(),
-                        "Display debug information during execution")
-        (as_string(OPTION_PORT, ",p").c_str(), po::value<size_t>()->default_value(8080),
-                        "The port to listen for UDP packets")
-        (as_string(OPTION_ECFLOW_HOST).c_str(), po::value<std::string>(),
-                        "The ecFlow server port to forward requests")
-        (as_string(OPTION_ECFLOW_PORT).c_str(), po::value<size_t>()->default_value(3141),
-                        "The ecFlow server port to forward requests");
-    // clang-format on
-
-    return general;
-}
-
-} // namespace ecf
diff -pruN 5.12.4-1/Udp/src/ecflow/udp/UDPServerOptions.hpp 5.13.0-1/Udp/src/ecflow/udp/UDPServerOptions.hpp
--- 5.12.4-1/Udp/src/ecflow/udp/UDPServerOptions.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/src/ecflow/udp/UDPServerOptions.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,79 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_UDPServerOptions_HPP
-#define ecflow_udp_UDPServerOptions_HPP
-
-#include <optional>
-#include <string>
-
-#include <boost/program_options.hpp>
-
-namespace po = boost::program_options;
-
-namespace ecf {
-
-class InvalidCLIOption : public std::logic_error {
-public:
-    explicit InvalidCLIOption(const std::string& error) : logic_error(error) {}
-    InvalidCLIOption(const InvalidCLIOption&) = default;
-    virtual ~InvalidCLIOption();
-};
-
-/**
- * Processes the CLI options used by ecFlow UDP server, including any environment variables that need to be considered.
- */
-class UDPServerOptions {
-public:
-    UDPServerOptions(int argc, const char* argv[]);
-
-    ~UDPServerOptions() = default;
-
-    bool get_option(const std::string& option) const { return variables.count(option) > 0; }
-
-    template <typename U, std::enable_if_t<!std::is_same_v<bool, U>, bool> = true>
-    const U& get_option(const std::string& option) const {
-        return variables[option].template as<U>();
-    }
-
-    template <typename U, std::enable_if_t<!std::is_same_v<bool, U>, bool> = true>
-    std::optional<U> get_optional_option(const std::string& option) const {
-        if (variables.count(option) > 0) {
-            return variables[option].template as<U>();
-        }
-        return std::nullopt;
-    }
-
-    bool has_help() const { return get_option(OPTION_HELP); }
-    bool has_version() const { return get_option(OPTION_VERSION); }
-    bool has_verbose() const { return get_option(OPTION_VERBOSE); }
-
-    const po::options_description& get_description() const { return general; }
-
-    static po::options_description create_options();
-
-public:
-    static inline const char* OPTION_HELP        = "help";
-    static inline const char* OPTION_VERSION     = "version";
-    static inline const char* OPTION_VERBOSE     = "verbose";
-    static inline const char* OPTION_PORT        = "port";
-    static inline const char* OPTION_ECFLOW_HOST = "ecflow_host";
-    static inline const char* OPTION_ECFLOW_PORT = "ecflow_port";
-
-private:
-    static void ensure_valid_options(const po::variables_map& variables);
-
-    po::options_description general;
-    po::variables_map variables;
-};
-
-} // namespace ecf
-
-#endif /* ecflow_udp_UDPServerOptions_HPP */
diff -pruN 5.12.4-1/Udp/test/TestSupport.hpp 5.13.0-1/Udp/test/TestSupport.hpp
--- 5.12.4-1/Udp/test/TestSupport.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/test/TestSupport.hpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,294 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#ifndef ecflow_udp_test_TestSupport_HPP
-#define ecflow_udp_test_TestSupport_HPP
-
-#include <memory>
-#include <thread>
-
-#include <boost/asio.hpp>
-#include <boost/process.hpp>
-#include <boost/test/unit_test.hpp>
-
-#include "ecflow/attribute/NodeAttr.hpp"
-#include "ecflow/client/ClientInvoker.hpp"
-#include "ecflow/core/EcfPortLock.hpp"
-#include "ecflow/core/File.hpp"
-#include "ecflow/core/Host.hpp"
-#include "ecflow/core/Str.hpp"
-#include "ecflow/node/Defs.hpp"
-#include "ecflow/node/Node.hpp"
-#include "ecflow/udp/UDPClient.hpp"
-
-namespace bp = boost::process;
-
-namespace ecf::test {
-
-template <typename SERVER>
-class BaseMockServer {
-public:
-    using hostname_t = std::string;
-    using port_t     = uint16_t;
-
-    template <typename... Args>
-    BaseMockServer(hostname_t host, port_t port, Args... args) : host_{std::move(host)},
-                                                                 port_{port},
-                                                                 server_{} {
-        BOOST_REQUIRE_MESSAGE(!host_.empty(), "determiner host name");
-        BOOST_REQUIRE_MESSAGE(port_ > 0, "port is be larger than 0");
-
-        server_ = SERVER::launch(host_, port_, std::forward<Args>(args)...);
-        std::cout << "   MOCK: " << SERVER::designation << " has been started!" << std::endl;
-    }
-    BaseMockServer(const BaseMockServer&) = delete;
-    BaseMockServer(BaseMockServer&&)      = delete;
-
-    ~BaseMockServer() {
-        server_.terminate();
-        SERVER::cleanup(host_, port_);
-        std::cout << "   MOCK: " << SERVER::designation << " has been terminated!" << std::endl;
-    }
-
-    const hostname_t& host() const { return host_; }
-    uint16_t port() const { return port_; }
-
-private:
-    hostname_t host_;
-    uint16_t port_;
-
-    bp::child server_;
-};
-
-/**
- * A "mock" ecFlow server, launches the server on a separate process, and enables checking changes in Defs state
- */
-class MockServer : public BaseMockServer<MockServer> {
-public:
-    explicit MockServer(port_t port) : BaseMockServer<MockServer>(ecf::Host{}.name(), port) {}
-
-    void load_definition(const std::string& defs) const {
-        ClientInvoker client(ecf::Str::LOCALHOST(), port());
-        try {
-            BOOST_REQUIRE_MESSAGE(fs::exists(defs), "definitions file exists at: " + defs);
-            auto error = client.loadDefs(defs);
-            BOOST_REQUIRE_MESSAGE(!error, "load definitions, without error ");
-        }
-        catch (std::exception& e) {
-            BOOST_REQUIRE_MESSAGE(
-                false, "load definitions, without throwing exception (but threw: " + std::string(e.what()) + ")");
-        }
-
-        std::cout << "   MOCK: reference ecFlow suite has been loaded" << std::endl;
-    }
-
-    Meter get_meter(const std::string& path, const std::string& name) const {
-        node_ptr node = get_node_at(path);
-        return get_attribute_by_name(node->meters(), name);
-    }
-
-    Label get_label(const std::string& path, const std::string& name) const {
-        node_ptr node = get_node_at(path);
-        return get_attribute_by_name(node->labels(), name);
-    }
-
-    Event get_event(const std::string& path, const std::string& name) const {
-        node_ptr node = get_node_at(path);
-        return get_attribute_by_name(node->events(), name);
-    }
-
-private:
-    node_ptr get_node_at(const std::string& path) const {
-        std::cout << "   Creating ecflow_client connected to " << host() << ":" << port() << std::endl;
-        ClientInvoker client(ecf::Str::LOCALHOST(), port());
-
-        // load all definitions
-        std::shared_ptr<Defs> defs = nullptr;
-        client.sync(defs);
-
-        // select node at intended path
-        node_ptr node = defs->findAbsNode(path);
-        BOOST_REQUIRE_MESSAGE(node, "unable to find node");
-
-        return node;
-    }
-
-    template <typename ATTRIBUTE>
-    static ATTRIBUTE get_attribute_by_name(const std::vector<ATTRIBUTE>& attribs, const std::string& name) {
-        auto found = std::find_if(
-            std::begin(attribs), std::end(attribs), [&name](const ATTRIBUTE& attrib) { return attrib.name() == name; });
-        BOOST_REQUIRE_MESSAGE(found != std::end(attribs), "unable to find attribute");
-        return *found;
-    }
-
-public:
-    static constexpr const char* designation = "ecFlow server";
-
-    static bp::child launch(const hostname_t& host, port_t port) {
-        // Just for precaution, in case a previous run didn't clean up...
-        cleanup(host, port);
-
-        std::string invoke_command = ecf::File::find_ecf_server_path();
-
-        BOOST_REQUIRE_MESSAGE(!invoke_command.empty(), "The server program could not be found");
-        BOOST_REQUIRE_MESSAGE(fs::exists(invoke_command), "Server exe does not exist at:" << invoke_command);
-
-        invoke_command += " --port ";
-        invoke_command += std::to_string(port);
-        invoke_command += " -d &";
-
-        std::cout << "Launching ecflow_server @" << host << ":" << port << ", with: " << invoke_command << std::endl;
-
-        bp::child child(invoke_command);
-
-        ClientInvoker client(ecf::Str::LOCALHOST(), port);
-        if (!client.wait_for_server_reply(5)) {
-            BOOST_REQUIRE_MESSAGE(false, "could not launch ecflow server");
-        }
-
-        return child;
-    }
-
-    static void cleanup(const hostname_t& host, port_t port) {
-        // Clean up temporary files created by the server instance
-        std::string temporaries[]{host + '.' + std::to_string(port) + ".ecf.check",
-                                  host + '.' + std::to_string(port) + ".ecf.check.b",
-                                  host + '.' + std::to_string(port) + ".ecf.log"};
-        for (const auto& t : temporaries) {
-            fs::remove(t);
-        }
-    }
-};
-
-/**
- * A "mock" ecFlow UDP server, launches the server on a separate process, and enables triggering operations
- */
-class MockUDPServer : public BaseMockServer<MockUDPServer> {
-public:
-    explicit MockUDPServer(port_t port, port_t ecflow_port)
-        : BaseMockServer<MockUDPServer>("localhost", port, ecflow_port) {}
-
-    void update_label(const std::string& path, const std::string& name, const std::string& value) {
-        auto request = format_request(path, "alter_label", name, value);
-        send(request);
-    }
-
-    void update_meter(const std::string& path, const std::string& name, int value) {
-        auto request = format_request(path, "alter_meter", name, value);
-        send(request);
-    }
-
-    void clear_event(const std::string& path, const std::string& name) {
-        auto request = format_request(path, "alter_event", name, "0");
-        send(request);
-    }
-    void set_event(const std::string& path, const std::string& name) {
-        auto request = format_request(path, "alter_event", name, "1");
-        send(request);
-    }
-
-    void send(const std::string& request) {
-        std::cout << "   MOCK: UDP Client sending request: " << request << std::endl;
-        sendRequest(port(), request);
-    }
-
-private:
-    template <typename V>
-    static std::string
-    format_request(const std::string& path, const std::string& command, const std::string& name, V value) {
-        std::ostringstream oss;
-        // clang-format off
-        oss << R"({)"
-                << R"("method":"put",)"
-                << R"("payload":)"
-                << R"({)"
-                    << R"("command":")" << command << R"(",)"
-                    << R"("path":")" << path << R"(",)"
-                    << R"("name":")" << name << R"(",)"
-                    << R"("value":")"<< value << R"(")"
-                << R"(})"
-            << R"(})";
-        // clang-format on
-        return oss.str();
-    }
-
-    static void sendRequest(uint16_t port, const std::string& request) {
-        const std::string host = "localhost";
-        std::cout << "   Creating ecflow_udp client connected to " << host << ":" << port << std::endl;
-        ecf::UDPClient client(host, std::to_string(port));
-        client.send(request);
-
-        // Wait for request to flow...
-        std::this_thread::sleep_for(std::chrono::milliseconds(50));
-    }
-
-public:
-    static constexpr const char* designation = "ecFlow UDP";
-
-    static bp::child launch(const hostname_t& host, port_t port, port_t ecflow_port) {
-
-        std::string invoke_command = ecf::File::root_build_dir() + "/bin/ecflow_udp";
-        invoke_command += " --port ";
-        invoke_command += std::to_string(port);
-        invoke_command += " --ecflow_port ";
-        invoke_command += std::to_string(ecflow_port);
-        invoke_command += " --verbose";
-
-        std::cout << "   Launching ecflow_udp @" << host << ":" << port << ", with: " << invoke_command << std::endl;
-
-        bp::child server(invoke_command);
-
-        // Wait for server to start...
-        std::this_thread::sleep_for(std::chrono::milliseconds(2000));
-
-        return server;
-    }
-
-    static void cleanup(const hostname_t& host, port_t port) {
-        // No clean up needed for ecFlow UDP
-    }
-};
-
-/**
- * This fixture provisions the tests with both an ecFlow server and an ecFlow UDP server.
- */
-struct EnableServersFixture
-{
-    EnableServersFixture() : EnableServersFixture(get_ecflow_server_port(), get_ecflow_udp_port()) {}
-    ~EnableServersFixture() = default;
-
-    ecf::test::MockServer ecflow_server;
-    ecf::test::MockUDPServer ecflow_udp;
-
-private:
-    static MockServer::port_t get_ecflow_server_port() {
-        MockServer::port_t selected_port = 3199;
-        std::cout << "   Attempting to use port: " << selected_port << std::endl;
-        while (!EcfPortLock::is_free(selected_port)) {
-            std::cout << "   Selected port: " << selected_port << " is not available." << std::endl;
-            ++selected_port;
-            std::cout << "   Attempting to use port: " << selected_port << std::endl;
-        }
-        std::cout << "   Found free port: " << selected_port << "\n";
-        return selected_port;
-    }
-    static MockServer::port_t get_ecflow_udp_port() { return 3198; }
-
-    EnableServersFixture(MockServer::port_t ecflow_server_port, MockServer::port_t ecflow_udp_port)
-        : ecflow_server(ecflow_server_port),
-          ecflow_udp(ecflow_udp_port, ecflow_server_port) {
-        // Load 'reference' suite for tests...
-        ecflow_server.load_definition("data/reference.def");
-    }
-};
-
-} // namespace ecf::test
-
-#endif /* ecflow_udp_test_TestSupport_HPP */
diff -pruN 5.12.4-1/Udp/test/TestUDPServer.cpp 5.13.0-1/Udp/test/TestUDPServer.cpp
--- 5.12.4-1/Udp/test/TestUDPServer.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/test/TestUDPServer.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,170 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#include <boost/test/unit_test.hpp>
-
-#include "TestSupport.hpp"
-
-namespace ut = boost::unit_test;
-
-BOOST_FIXTURE_TEST_SUITE(S_UDP, ecf::test::EnableServersFixture)
-
-BOOST_AUTO_TEST_SUITE(T_UDPServer)
-
-BOOST_AUTO_TEST_CASE(can_update_events) {
-    // Family f2
-    {
-        auto event = ecflow_server.get_event("/s1/f2", "event_at_f2");
-        BOOST_TEST(!event.value());
-
-        ecflow_udp.set_event("/s1/f2", "event_at_f2");
-        event = ecflow_server.get_event("/s1/f2", "event_at_f2");
-        BOOST_TEST(event.value());
-
-        ecflow_udp.clear_event("/s1/f2", "event_at_f2");
-        event = ecflow_server.get_event("/s1/f2", "event_at_f2");
-        BOOST_TEST(!event.value());
-    }
-    // Family f3
-    {
-        auto event = ecflow_server.get_event("/s1/f2/f3", "event_at_f3");
-        BOOST_TEST(!event.value());
-
-        ecflow_udp.set_event("/s1/f2/f3", "event_at_f3");
-        event = ecflow_server.get_event("/s1/f2/f3", "event_at_f3");
-        BOOST_TEST(event.value());
-
-        ecflow_udp.clear_event("/s1/f2/f3", "event_at_f3");
-        event = ecflow_server.get_event("/s1/f2/f3", "event_at_f3");
-        BOOST_TEST(!event.value());
-    }
-    // Task t4
-    {
-        auto event = ecflow_server.get_event("/s1/f2/f3/t4", "event_at_t4");
-        BOOST_TEST(!event.value());
-
-        ecflow_udp.set_event("/s1/f2/f3/t4", "event_at_t4");
-        event = ecflow_server.get_event("/s1/f2/f3/t4", "event_at_t4");
-        BOOST_TEST(event.value());
-
-        ecflow_udp.clear_event("/s1/f2/f3/t4", "event_at_t4");
-        event = ecflow_server.get_event("/s1/f2/f3/t4", "event_at_t4");
-        BOOST_TEST(!event.value());
-    }
-}
-
-BOOST_AUTO_TEST_CASE(can_update_labels) {
-    // Family f2
-    {
-        auto label = ecflow_server.get_label("/s1/f2", "label_at_f2");
-        BOOST_TEST(label.new_value() == "");
-    }
-    {
-        ecflow_udp.update_label("/s1/f2", "label_at_f2", "some_value");
-        auto label = ecflow_server.get_label("/s1/f2", "label_at_f2");
-        BOOST_TEST(label.new_value() == "some_value");
-    }
-    // Family f3
-    {
-        auto label = ecflow_server.get_label("/s1/f2/f3", "label_at_f3");
-        BOOST_TEST(label.new_value() == "");
-    }
-    {
-        ecflow_udp.update_label("/s1/f2/f3", "label_at_f3", "another_value");
-        auto label = ecflow_server.get_label("/s1/f2/f3", "label_at_f3");
-        BOOST_TEST(label.new_value() == "another_value");
-    }
-    // Task t4
-    {
-        auto label = ecflow_server.get_label("/s1/f2/f3/t4", "label_at_t4");
-        BOOST_TEST(label.new_value() == "");
-    }
-    std::string values[] = {"a", "b", "c", "d"};
-    for (auto value : values) {
-        ecflow_udp.update_label("/s1/f2/f3/t4", "label_at_t4", value);
-        auto label = ecflow_server.get_label("/s1/f2/f3/t4", "label_at_t4");
-        BOOST_TEST(label.new_value() == value);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(can_update_meters) {
-    // Family f2
-    {
-        auto meter = ecflow_server.get_meter("/s1/f2", "meter_at_f2");
-        BOOST_TEST(meter.value() == 0);
-    }
-    {
-        ecflow_udp.update_meter("/s1/f2", "meter_at_f2", 49);
-        auto meter = ecflow_server.get_meter("/s1/f2", "meter_at_f2");
-        BOOST_TEST(meter.value() == 49);
-    }
-    // Family f3
-    {
-        auto meter = ecflow_server.get_meter("/s1/f2/f3", "meter_at_f3");
-        BOOST_TEST(meter.value() == 0);
-    }
-    {
-        ecflow_udp.update_meter("/s1/f2/f3", "meter_at_f3", 50);
-        auto meter = ecflow_server.get_meter("/s1/f2/f3", "meter_at_f3");
-        BOOST_TEST(meter.value() == 50);
-    }
-    // Task t4
-    {
-        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
-        BOOST_TEST(meter.value() == 0);
-    }
-    int values[] = {0, 10, 25, 50, 75, 100};
-    for (auto value : values) {
-        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", value);
-        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
-        BOOST_TEST(meter.value() == value);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(can_update_meter_outside_valid_range) {
-    {
-        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", 50);
-        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
-        BOOST_TEST(meter.value() == 50);
-    }
-    {
-        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", -1);
-        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
-        BOOST_TEST(meter.value() == 50);
-    }
-    {
-        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", 101);
-        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
-        BOOST_TEST(meter.value() == 50);
-    }
-}
-
-BOOST_AUTO_TEST_CASE(can_handle_invalid_json_request) {
-    ecflow_udp.send(R"()");
-    ecflow_udp.send(R"({})");
-    ecflow_udp.send(R"({"method": "invalid", "data": {}})");
-    ecflow_udp.send(R"({"method": "put", "data": {}})");
-    ecflow_udp.send(R"({"method": "put", "data": {"type": "invalid"}})");
-    ecflow_udp.send(R"({"method": "put", "data": {"type": "label"}})");
-    ecflow_udp.send(R"({"method": "put", "data": {"type": "label", "name": "a_name"}})");
-    ecflow_udp.send(R"({"method": "put", "data": {"type": "label", "name": "a_name", "path": "a_path}})");
-    ecflow_udp.send(R"({"method": "put", "data": {"type": "meter"}})");
-    ecflow_udp.send(R"({"method": "put", "data": {"type": "meter", "name": "a_name"}})");
-    ecflow_udp.send(R"({"method": "put", "data": {"type": "meter", "name": "a_name", "path": "a_path}})");
-}
-
-BOOST_AUTO_TEST_CASE(can_authenticate_requests) {
-
-    ecflow_udp.send(R"()");
-}
-
-BOOST_AUTO_TEST_SUITE_END()
-
-BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/Udp/test/TestUDP_main.cpp 5.13.0-1/Udp/test/TestUDP_main.cpp
--- 5.12.4-1/Udp/test/TestUDP_main.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/test/TestUDP_main.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright 2009- ECMWF.
- *
- * This software is licensed under the terms of the Apache Licence version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
- * In applying this licence, ECMWF does not waive the privileges and immunities
- * granted to it by virtue of its status as an intergovernmental organisation
- * nor does it submit to any jurisdiction.
- */
-
-#define BOOST_TEST_MODULE Test_UDP
-#include <boost/test/unit_test.hpp>
diff -pruN 5.12.4-1/Udp/test/data/reference.def 5.13.0-1/Udp/test/data/reference.def
--- 5.12.4-1/Udp/test/data/reference.def	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Udp/test/data/reference.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,21 +0,0 @@
- 
-#
-# The defs used to test ecflow_udp
-#
-
-suite s1
-  family f2
-    event event_at_f2
-    label label_at_f2 ""
-    meter meter_at_f2 0 100 80
-    family f3
-      event event_at_f3
-      label label_at_f3 ""
-      meter meter_at_f3 0 100 80
-      task t4
-        event event_at_t4
-        label label_at_t4 ""
-        meter meter_at_t4 0 100 80
-    endfamily
-  endfamily
-endsuite
diff -pruN 5.12.4-1/Viewer/ecflowUI/images/aviso.svg 5.13.0-1/Viewer/ecflowUI/images/aviso.svg
--- 5.12.4-1/Viewer/ecflowUI/images/aviso.svg	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/images/aviso.svg	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,137 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   width="60"
+   height="32"
+   id="svg2"
+   version="1.1"
+   inkscape:version="1.3.2 (091e20e, 2023-11-25)"
+   sodipodi:docname="aviso.svg"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:dc="http://purl.org/dc/elements/1.1/">
+  <defs
+     id="defs4" />
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="18.75"
+     inkscape:cx="42.693333"
+     inkscape:cy="16.586667"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer3"
+     showgrid="true"
+     inkscape:snap-grids="false"
+     inkscape:window-width="1512"
+     inkscape:window-height="865"
+     inkscape:window-x="0"
+     inkscape:window-y="38"
+     inkscape:window-maximized="0"
+     inkscape:showpageshadow="2"
+     inkscape:pagecheckerboard="0"
+     inkscape:deskcolor="#d1d1d1">
+    <inkscape:grid
+       type="xygrid"
+       id="grid2816"
+       empspacing="5"
+       visible="true"
+       enabled="true"
+       snapvisiblegridlinesonly="true"
+       originx="0"
+       originy="0"
+       spacingy="1"
+       spacingx="1"
+       units="px" />
+  </sodipodi:namedview>
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <cc:license
+           rdf:resource="Apache License 2.0" />
+        <dc:creator>
+          <cc:Agent>
+            <dc:title />
+          </cc:Agent>
+        </dc:creator>
+        <dc:publisher>
+          <cc:Agent>
+            <dc:title>ECMWF</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:language>en-GB</dc:language>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>ecFlowUI  icon</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:description>ecFlowUI icon</dc:description>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:groupmode="layer"
+     id="layer3"
+     inkscape:label="circle"
+     style="display:inline">
+    <circle
+       style="fill:#333333;stroke:none;stroke-width:1.06667"
+       id="path1"
+       cx="16.360003"
+       cy="16.013336"
+       r="16" />
+    <path
+       style="fill:none;stroke-width:1.20903"
+       d="m 28.992712,11.829419 2.142512,4.471291 -1.740791,3.974483"
+       id="path3"
+       sodipodi:nodetypes="ccc" />
+    <text
+       xml:space="preserve"
+       style="font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;font-size:29.3333px;font-family:'Times New Roman';-inkscape-font-specification:'Times New Roman,  Bold';fill:#ffffff;fill-opacity:1;stroke:#ffffff;stroke-width:1.26666;stroke-dasharray:none;stroke-opacity:1"
+       x="6.3222198"
+       y="24.065346"
+       id="text1"><tspan
+         sodipodi:role="line"
+         id="tspan1"
+         x="6.3222198"
+         y="24.065346"
+         style="font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;font-size:29.3333px;font-family:'Times New Roman';-inkscape-font-specification:'Times New Roman,  Bold';fill:#ffffff;stroke:#ffffff;stroke-width:1.26666">A</tspan></text>
+    <path
+       style="fill:#333333;stroke:none;stroke-width:0.498518"
+       d="m 37.747345,8.1911167 c 0,0 2.710014,2.6550333 2.786042,8.1035723 0.07603,5.448539 -3.024275,8.04272 -3.024275,8.04272 l -4.069113,0.0037 c 0,0 3.670537,-3.347927 3.654647,-8.200586 -0.01589,-4.852659 -3.162069,-7.988886 -3.162069,-7.988886 1.254703,-0.019912 2.5613,-0.00644 3.814768,0.039432 z"
+       id="path10"
+       sodipodi:nodetypes="czcczccc" />
+    <path
+       style="fill:#333333;stroke:none;stroke-width:0.579718"
+       d="m 45.587345,5.3281796 c 0,0 3.403347,3.3237301 3.479375,10.6917784 0.07603,7.36805 -3.717608,11.142822 -3.717608,11.142822 l -4.069113,0.005 c 0,0 4.150537,-4.527396 4.134647,-11.089636 -0.01589,-6.5622913 -3.482069,-10.7500723 -3.482069,-10.7500723 1.254703,-0.026927 2.4013,-0.062033 3.654768,-9.3e-6 z"
+       id="path2"
+       sodipodi:nodetypes="czcczccc" />
+    <path
+       style="fill:#333333;stroke:none;stroke-width:0.659713"
+       d="m 52.947345,1.871744 c 0,0 5.003347,4.521101 5.079375,14.062866 0.07603,9.541766 -5.317608,14.213361 -5.317608,14.213361 l -4.069113,0.0064 c 0,0 6.017204,-5.759872 6.001314,-14.258098 -0.01589,-8.4982932 -5.508736,-14.0247431 -5.508736,-14.0247431 1.254703,-0.034871 2.667967,-0.080335 3.921435,-1.2e-5 z"
+       id="path4"
+       sodipodi:nodetypes="czcczccc" />
+  </g>
+  <g
+     inkscape:groupmode="layer"
+     id="layer2"
+     inkscape:label="item"
+     style="display:inline" />
+  <g
+     inkscape:groupmode="layer"
+     id="layer4"
+     inkscape:label="top" />
+</svg>
diff -pruN 5.12.4-1/Viewer/ecflowUI/images/icon_no_access.svg 5.13.0-1/Viewer/ecflowUI/images/icon_no_access.svg
--- 5.12.4-1/Viewer/ecflowUI/images/icon_no_access.svg	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/images/icon_no_access.svg	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+<?xml version="1.0" encoding="utf-8"?>
+<svg width="32" height="32" viewBox="0 0 36 36" version="1.0"
+     xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
+  <title>no_access</title>
+  <path d="M18,2A16,16,0,1,0,34,18,16,16,0,0,0,18,2Zm0,30A14,14,0,1,1,32,18,14,14,0,0,1,18,32Z"
+        class="circle_outline"></path>
+  <path
+      d="M27.15,15H8.85A1.85,1.85,0,0,0,7,16.85v2.29A1.85,1.85,0,0,0,8.85,21H27.15A1.85,1.85,0,0,0,29,19.15V16.85A1.85,1.85,0,0,0,27.15,15Zm.25,4.15a.25.25,0,0,1-.25.25H8.85a.25.25,0,0,1-.25-.25V16.85a.25.25,0,0,1,.25-.25H27.15a.25.25,0,0,1,.25.25Z"
+      class="dash_outline"></path>
+</svg>
diff -pruN 5.12.4-1/Viewer/ecflowUI/images/remote.svg 5.13.0-1/Viewer/ecflowUI/images/remote.svg
--- 5.12.4-1/Viewer/ecflowUI/images/remote.svg	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/images/remote.svg	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,137 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   width="60"
+   height="32"
+   id="svg2"
+   version="1.1"
+   inkscape:version="1.3.2 (091e20e, 2023-11-25)"
+   sodipodi:docname="aviso.svg"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:dc="http://purl.org/dc/elements/1.1/">
+  <defs
+     id="defs4" />
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="18.75"
+     inkscape:cx="42.693333"
+     inkscape:cy="16.586667"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer3"
+     showgrid="true"
+     inkscape:snap-grids="false"
+     inkscape:window-width="1512"
+     inkscape:window-height="865"
+     inkscape:window-x="0"
+     inkscape:window-y="38"
+     inkscape:window-maximized="0"
+     inkscape:showpageshadow="2"
+     inkscape:pagecheckerboard="0"
+     inkscape:deskcolor="#d1d1d1">
+    <inkscape:grid
+       type="xygrid"
+       id="grid2816"
+       empspacing="5"
+       visible="true"
+       enabled="true"
+       snapvisiblegridlinesonly="true"
+       originx="0"
+       originy="0"
+       spacingy="1"
+       spacingx="1"
+       units="px" />
+  </sodipodi:namedview>
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <cc:license
+           rdf:resource="Apache License 2.0" />
+        <dc:creator>
+          <cc:Agent>
+            <dc:title />
+          </cc:Agent>
+        </dc:creator>
+        <dc:publisher>
+          <cc:Agent>
+            <dc:title>ECMWF</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:language>en-GB</dc:language>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>ecFlowUI  icon</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:description>ecFlowUI icon</dc:description>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:groupmode="layer"
+     id="layer3"
+     inkscape:label="circle"
+     style="display:inline">
+    <circle
+       style="fill:#333333;stroke:none;stroke-width:1.06667"
+       id="path1"
+       cx="16.360003"
+       cy="16.013336"
+       r="16" />
+    <path
+       style="fill:none;stroke-width:1.20903"
+       d="m 28.992712,11.829419 2.142512,4.471291 -1.740791,3.974483"
+       id="path3"
+       sodipodi:nodetypes="ccc" />
+    <text
+       xml:space="preserve"
+       style="font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;font-size:29.3333px;font-family:'Times New Roman';-inkscape-font-specification:'Times New Roman,  Bold';fill:#ffffff;fill-opacity:1;stroke:#ffffff;stroke-width:1.26666;stroke-dasharray:none;stroke-opacity:1"
+       x="6.3222198"
+       y="24.065346"
+       id="text1"><tspan
+         sodipodi:role="line"
+         id="tspan1"
+         x="6.3222198"
+         y="24.065346"
+         style="font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;font-size:29.3333px;font-family:'Times New Roman';-inkscape-font-specification:'Times New Roman,  Bold';fill:#ffffff;stroke:#ffffff;stroke-width:1.26666">E</tspan></text>
+    <path
+       style="fill:#333333;stroke:none;stroke-width:0.498518"
+       d="m 37.747345,8.1911167 c 0,0 2.710014,2.6550333 2.786042,8.1035723 0.07603,5.448539 -3.024275,8.04272 -3.024275,8.04272 l -4.069113,0.0037 c 0,0 3.670537,-3.347927 3.654647,-8.200586 -0.01589,-4.852659 -3.162069,-7.988886 -3.162069,-7.988886 1.254703,-0.019912 2.5613,-0.00644 3.814768,0.039432 z"
+       id="path10"
+       sodipodi:nodetypes="czcczccc" />
+    <path
+       style="fill:#333333;stroke:none;stroke-width:0.579718"
+       d="m 45.587345,5.3281796 c 0,0 3.403347,3.3237301 3.479375,10.6917784 0.07603,7.36805 -3.717608,11.142822 -3.717608,11.142822 l -4.069113,0.005 c 0,0 4.150537,-4.527396 4.134647,-11.089636 -0.01589,-6.5622913 -3.482069,-10.7500723 -3.482069,-10.7500723 1.254703,-0.026927 2.4013,-0.062033 3.654768,-9.3e-6 z"
+       id="path2"
+       sodipodi:nodetypes="czcczccc" />
+    <path
+       style="fill:#333333;stroke:none;stroke-width:0.659713"
+       d="m 52.947345,1.871744 c 0,0 5.003347,4.521101 5.079375,14.062866 0.07603,9.541766 -5.317608,14.213361 -5.317608,14.213361 l -4.069113,0.0064 c 0,0 6.017204,-5.759872 6.001314,-14.258098 -0.01589,-8.4982932 -5.508736,-14.0247431 -5.508736,-14.0247431 1.254703,-0.034871 2.667967,-0.080335 3.921435,-1.2e-5 z"
+       id="path4"
+       sodipodi:nodetypes="czcczccc" />
+  </g>
+  <g
+     inkscape:groupmode="layer"
+     id="layer2"
+     inkscape:label="item"
+     style="display:inline" />
+  <g
+     inkscape:groupmode="layer"
+     id="layer4"
+     inkscape:label="top" />
+</svg>
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/CMakeLists.txt 5.13.0-1/Viewer/ecflowUI/src/CMakeLists.txt
--- 5.12.4-1/Viewer/ecflowUI/src/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -215,6 +215,7 @@ set(viewer_srcs
   VAutoArchiveAttr.hpp
   VAutoCancelAttr.hpp
   VAutoRestoreAttr.hpp
+  VAvisoAttr.hpp
   VConfig.hpp
   VConfigLoader.hpp
   VDateAttr.hpp
@@ -235,6 +236,7 @@ set(viewer_srcs
   VLimitAttr.hpp
   VLimiterAttr.hpp
   VMeterAttr.hpp
+  VMirrorAttr.hpp
   VModelData.hpp
   VNState.hpp
   VNode.hpp
@@ -491,6 +493,7 @@ set(viewer_srcs
   VAutoArchiveAttr.cpp
   VAutoCancelAttr.cpp
   VAutoRestoreAttr.cpp
+  VAvisoAttr.cpp
   VConfig.cpp
   VConfigLoader.cpp
   VDateAttr.cpp
@@ -510,6 +513,7 @@ set(viewer_srcs
   VLimitAttr.cpp
   VLimiterAttr.cpp
   VMeterAttr.cpp
+  VMirrorAttr.cpp
   VModelData.cpp
   VNode.cpp
   VNodeList.cpp
@@ -811,9 +815,7 @@ ecbuild_add_executable(
     ${CMAKE_CURRENT_BINARY_DIR}
   LIBS
     viewer
-    libclient
-    base
-    node
+    ecflow_all
     Threads::Threads
     m
     dl
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/NodeExpression.cpp 5.13.0-1/Viewer/ecflowUI/src/NodeExpression.cpp
--- 5.12.4-1/Viewer/ecflowUI/src/NodeExpression.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/NodeExpression.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -59,19 +59,8 @@ NodeExpressionParser::NodeExpressionPars
     }
 
     QStringList attrNames;
-    attrNames << "meter"
-              << "event"
-              << "repeat"
-              << "trigger"
-              << "label"
-              << "time"
-              << "date"
-              << "late"
-              << "limit"
-              << "limit"
-              << "limiter"
-              << "var"
-              << "genvar";
+    attrNames << "meter" << "event" << "repeat" << "trigger" << "label" << "time" << "date" << "late" << "limit"
+              << "limiter" << "var" << "genvar" << "mirror" << "aviso";
     Q_FOREACH (QString s, attrNames) {
         VAttributeType* t = VAttributeType::find(s.toStdString());
         Q_ASSERT(t);
@@ -121,10 +110,8 @@ bool NodeExpressionParser::isEnvVar(cons
 }
 
 bool NodeExpressionParser::isNodeHasAttribute(const std::string& str) const {
-    if (str == "has_triggers" || str == "has_time" || str == "has_date" || str == "locked")
-        return true;
-
-    return false;
+    constexpr std::array searchable = {"has_triggers", "has_time", "has_date", "locked", "has_aviso", "has_mirror"};
+    return std::find(searchable.begin(), searchable.end(), str) != searchable.end();
 }
 
 bool NodeExpressionParser::isNodeFlag(const std::string& str) const {
@@ -137,18 +124,30 @@ bool NodeExpressionParser::isNodeFlag(co
 }
 
 bool NodeExpressionParser::isWhatToSearchIn(const std::string& str, bool& isAttr) const {
-    // list of non-attribute items that we can search in
-    if (str == "node_name" || str == "node_path") {
+
+    constexpr auto is_searchable_nonattribute = [](const std::string& str) {
+        static constexpr std::array searchable = {"node_name", "node_path"};
+        return std::find(searchable.begin(), searchable.end(), str) != searchable.end();
+    };
+
+    constexpr auto is_searchable_attribute = [](const std::string& str) {
+        static constexpr std::array searchable = {
+            "var_name",           "var_value",          "var_type",           "label_name",  "label_value",
+            "meter_name",         "meter_value",        "event_name",         "event_value", "date_name",
+            "time_name",          "limit_name",         "limit_value",        "limit_max",   "limiter_name",
+            "repeat_name",        "repeat_value",       "trigger_expression", "mirror_name", "mirror_remote_path",
+            "mirror_remote_host", "mirror_remote_port", "mirror_polling",     "aviso_name",  "aviso_listener",
+            "aviso_url",          "aviso_schema",       "aviso_polling",      "aviso_auth"};
+        return std::find(searchable.begin(), searchable.end(), str) != searchable.end();
+    };
+
+    if (is_searchable_nonattribute(str)) {
         isAttr = false;
         return true;
     }
 
     // list of attributes that we can search in
-    else if (str == "var_name" || str == "var_value" || str == "var_type" || str == "label_name" ||
-             str == "label_value" || str == "meter_name" || str == "meter_value" || str == "event_name" ||
-             str == "event_value" || str == "date_name" || str == "time_name" || str == "limit_name" ||
-             str == "limit_value" || str == "limit_max" || str == "limiter_name" || str == "repeat_name" ||
-             str == "repeat_value" || str == "trigger_expression") {
+    else if (is_searchable_attribute(str)) {
         isAttr = true;
         return true;
     }
@@ -818,6 +817,12 @@ bool NodeAttributeCondition::execute(VIt
         else if (nodeAttrName_ == "has_triggers") {
             return (node->triggerAst() || node->completeAst());
         }
+        else if (nodeAttrName_ == "has_aviso") {
+            return !node->avisos().empty();
+        }
+        else if (nodeAttrName_ == "has_mirror") {
+            return !node->mirrors().empty();
+        }
     }
 
     return false;
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/NodeExpression.hpp 5.13.0-1/Viewer/ecflowUI/src/NodeExpression.hpp
--- 5.12.4-1/Viewer/ecflowUI/src/NodeExpression.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/NodeExpression.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -45,6 +45,8 @@ public:
         LIMITER,
         VAR,
         GENVAR,
+        AVISO,
+        MIRROR,
         BADATTRIBUTE
     };
 
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/NodeViewDelegate.cpp 5.13.0-1/Viewer/ecflowUI/src/NodeViewDelegate.cpp
--- 5.12.4-1/Viewer/ecflowUI/src/NodeViewDelegate.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/NodeViewDelegate.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -84,6 +84,9 @@ NodeViewDelegate::NodeViewDelegate(QWidg
         errPix_    = QPixmap(QPixmap::fromImage(img));
     }
 
+    avisoPixId_ = IconProvider::add(":/viewer/aviso.svg", "aviso");
+    mirrorPixId_ = IconProvider::add(":/viewer/remote.svg", "mirror");
+
     grad_.setCoordinateMode(QGradient::ObjectBoundingMode);
     grad_.setStart(0, 0);
     grad_.setFinalStop(0, 1);
@@ -120,6 +123,8 @@ NodeViewDelegate::NodeViewDelegate(QWidg
 
     attrRenderers_["meter"]       = &NodeViewDelegate::renderMeter;
     attrRenderers_["label"]       = &NodeViewDelegate::renderLabel;
+    attrRenderers_["aviso"]       = &NodeViewDelegate::renderAviso;
+    attrRenderers_["mirror"]      = &NodeViewDelegate::renderMirror;
     attrRenderers_["event"]       = &NodeViewDelegate::renderEvent;
     attrRenderers_["var"]         = &NodeViewDelegate::renderVar;
     attrRenderers_["genvar"]      = &NodeViewDelegate::renderGenvar;
@@ -634,6 +639,324 @@ void NodeViewDelegate::renderLabel(QPain
 
     // Draw name
     painter->setPen(fontPen);
+    painter->setFont(nameFont);
+    painter->drawText(attrBox_->adjustTextRect(nameRect), Qt::AlignLeft | Qt::AlignVCenter, name);
+
+    // Draw value
+    painter->setPen(fontPen);
+    painter->setFont(valFont);
+
+    if (multiCnt == 0)
+        painter->drawText(attrBox_->adjustTextRect(valRect), Qt::AlignLeft | Qt::AlignVCenter, val);
+    else {
+        painter->drawText(attrBox_->adjustTextRect(valRect), Qt::AlignLeft | Qt::AlignVCenter, valFirst);
+        painter->drawText(valRestRect, Qt::AlignLeft | Qt::AlignVCenter, valRest);
+    }
+
+    if (selected && drawAttrSelectionRect_) {
+        QRect sr = option.rect;
+        sr.setWidth(rightPos - sr.x());
+        renderSelectionRect(painter, attrBox_->adjustSelectionRect(sr));
+    }
+
+    if (setClipRect) {
+        painter->restore();
+    }
+
+    size = QSize(totalWidth, labelHeight(multiCnt + 1));
+}
+
+void NodeViewDelegate::renderAviso(QPainter* painter,
+                                   QStringList data,
+                                   const QStyleOptionViewItem& option,
+                                   QSize& size) const {
+
+    int totalWidth = 0;
+    size           = QSize(totalWidth, attrBox_->fullHeight);
+
+    if (data.count() < 2)
+        return;
+
+    QString name = data.at(1); // + ":";
+    QString val;
+    if (data.count() > 2)
+        val = data.at(2);
+
+    bool selected = option.state & QStyle::State_Selected;
+
+    // The border rect (we will adjust its  width)
+    QRect contRect = option.rect.adjusted(attrBox_->leftMargin,
+                                          attrBox_->topMargin + attrBox_->topPadding,
+                                          0,
+                                          -attrBox_->bottomMargin - attrBox_->bottomPadding);
+
+    int currentRight = contRect.x();
+    int multiCnt     = val.count('\n');
+
+    QRect avisoRect;
+    QRect nameRect;
+    QRect valRect, valRestRect;
+
+    QFont nameFont = attrFont_;
+    nameFont.setBold(true);
+    QFont valFont = attrFont_;
+    QString valFirst, valRest;
+    QString full;
+
+    auto avisoPix = IconProvider::pixmapToHeight(avisoPixId_, contRect.height());
+    avisoRect     = contRect.adjusted(attrBox_->leftPadding, 0, 0, 0);
+    avisoRect.setWidth(avisoPix.width());
+
+    if (multiCnt == 0) {
+        // The text rectangle
+        QFontMetrics fm(nameFont);
+        int nameWidth = ViewerUtil::textWidth(fm, name);
+        nameRect      = contRect;
+        nameRect.setX(avisoRect.x() + avisoRect.width() + attrBox_->spacing);
+        nameRect.setWidth(nameWidth);
+
+        // The value rectangle
+        fm           = QFontMetrics(valFont);
+        int valWidth = ViewerUtil::textWidth(fm, val);
+        valRect      = nameRect;
+        valRect.setX(nameRect.x() + nameRect.width() + attrBox_->spacing);
+        valRect.setWidth(valWidth);
+
+        // Adjust the filled rect width
+        currentRight = valRect.x() + valRect.width();
+    }
+    else {
+        // The text rectangle
+        QFontMetrics fm(nameFont);
+        int nameWidth = ViewerUtil::textWidth(fm, name);
+        nameRect      = contRect;
+        nameRect.setX(avisoRect.x() + avisoRect.width() + attrBox_->spacing);
+        nameRect.setWidth(nameWidth);
+        nameRect.setHeight(attrBox_->height - attrBox_->topPadding - attrBox_->bottomPadding);
+
+        // The value rectangles
+        fm = QFontMetrics(valFont);
+
+        // First row comes after the name rect!
+        QStringList valLst = val.split("\n");
+        Q_ASSERT(valLst.count() > 0);
+        valFirst = valLst[0];
+
+        valRect = nameRect;
+        valRect.setX(nameRect.x() + nameRect.width() + attrBox_->spacing);
+        valRect.setWidth(ViewerUtil::textWidth(fm, valFirst));
+
+        // The rest of the rows
+        valLst.takeFirst();
+        valRest       = valLst.join("\n");
+        QSize valSize = fm.size(0, valRest);
+
+        valRestRect = QRect(nameRect.x(), nameRect.y() + nameRect.height() + 2, valSize.width(), valSize.height());
+
+        currentRight = qMax(valRect.x() + valRect.width(), valRestRect.x() + valRestRect.width());
+
+        val = valFirst + " " + valRest;
+    }
+
+    // Define clipping
+    int rightPos           = currentRight + attrBox_->rightPadding + attrBox_->rightMargin;
+    totalWidth             = rightPos - option.rect.left();
+    const bool setClipRect = rightPos > option.rect.right();
+    if (setClipRect) {
+        painter->save();
+        painter->setClipRect(option.rect);
+    }
+
+    QPen fontPen(Qt::black);
+    LabelStyle* labelStyle = labelStyle_[DefaultLabel];
+    QList<LabelType> types;
+    types << ErrorLabel << WarningLabel << InfoLabel;
+    full = name + " " + val;
+    Q_FOREACH (LabelType t, types) {
+        if (labelStyle_[t]->enabled_) {
+            if (full.contains(labelStyle_[t]->regex_)) {
+                labelStyle = labelStyle_[t];
+                break;
+            }
+        }
+    }
+
+    if (labelStyle) {
+        if (labelStyle->enabled_) {
+            fontPen = labelStyle->fontPen_;
+            // draw bg
+            if (labelStyle->enabledBg_) {
+                QRect sr = option.rect;
+                sr.setWidth(rightPos - sr.x());
+                painter->fillRect(attrBox_->adjustSelectionRect(sr), labelStyle->bgBrush_);
+            }
+        }
+    }
+
+    // aviso pixmap
+    painter->drawPixmap(avisoRect, avisoPix);
+
+    // Draw name
+    painter->setPen(fontPen);
+    painter->setFont(nameFont);
+    painter->drawText(attrBox_->adjustTextRect(nameRect), Qt::AlignLeft | Qt::AlignVCenter, name);
+
+    // Draw value
+    painter->setPen(fontPen);
+    painter->setFont(valFont);
+
+    if (multiCnt == 0)
+        painter->drawText(attrBox_->adjustTextRect(valRect), Qt::AlignLeft | Qt::AlignVCenter, val);
+    else {
+        painter->drawText(attrBox_->adjustTextRect(valRect), Qt::AlignLeft | Qt::AlignVCenter, valFirst);
+        painter->drawText(valRestRect, Qt::AlignLeft | Qt::AlignVCenter, valRest);
+    }
+
+    if (selected && drawAttrSelectionRect_) {
+        QRect sr = option.rect;
+        sr.setWidth(rightPos - sr.x());
+        renderSelectionRect(painter, attrBox_->adjustSelectionRect(sr));
+    }
+
+    if (setClipRect) {
+        painter->restore();
+    }
+
+    size = QSize(totalWidth, labelHeight(multiCnt + 1));
+}
+
+void NodeViewDelegate::renderMirror(QPainter* painter,
+                                   QStringList data,
+                                   const QStyleOptionViewItem& option,
+                                   QSize& size) const {
+
+    int totalWidth = 0;
+    size           = QSize(totalWidth, attrBox_->fullHeight);
+
+    if (data.count() < 2)
+        return;
+
+    QString name = data.at(1); // + ":";
+    QString val;
+    if (data.count() > 2)
+        val = data.at(2);
+
+    bool selected = option.state & QStyle::State_Selected;
+
+    // The border rect (we will adjust its  width)
+    QRect contRect = option.rect.adjusted(attrBox_->leftMargin,
+                                          attrBox_->topMargin + attrBox_->topPadding,
+                                          0,
+                                          -attrBox_->bottomMargin - attrBox_->bottomPadding);
+
+    int currentRight = contRect.x();
+    int multiCnt     = val.count('\n');
+
+    QRect mirrorRect;
+    QRect nameRect;
+    QRect valRect, valRestRect;
+
+    QFont nameFont = attrFont_;
+    nameFont.setBold(true);
+    QFont valFont = attrFont_;
+    QString valFirst, valRest;
+    QString full;
+
+    auto avisoPix = IconProvider::pixmapToHeight(mirrorPixId_, contRect.height());
+    mirrorRect    = contRect.adjusted(attrBox_->leftPadding, 0, 0, 0);
+    mirrorRect.setWidth(avisoPix.width());
+
+    if (multiCnt == 0) {
+        // The text rectangle
+        QFontMetrics fm(nameFont);
+        int nameWidth = ViewerUtil::textWidth(fm, name);
+        nameRect      = contRect;
+        nameRect.setX(mirrorRect.x() + mirrorRect.width() + attrBox_->spacing);
+        nameRect.setWidth(nameWidth);
+
+        // The value rectangle
+        fm           = QFontMetrics(valFont);
+        int valWidth = ViewerUtil::textWidth(fm, val);
+        valRect      = nameRect;
+        valRect.setX(nameRect.x() + nameRect.width() + attrBox_->spacing);
+        valRect.setWidth(valWidth);
+
+        // Adjust the filled rect width
+        currentRight = valRect.x() + valRect.width();
+    }
+    else {
+        // The text rectangle
+        QFontMetrics fm(nameFont);
+        int nameWidth = ViewerUtil::textWidth(fm, name);
+        nameRect      = contRect;
+        nameRect.setX(mirrorRect.x() + mirrorRect.width() + attrBox_->spacing);
+        nameRect.setWidth(nameWidth);
+        nameRect.setHeight(attrBox_->height - attrBox_->topPadding - attrBox_->bottomPadding);
+
+        // The value rectangles
+        fm = QFontMetrics(valFont);
+
+        // First row comes after the name rect!
+        QStringList valLst = val.split("\n");
+        Q_ASSERT(valLst.count() > 0);
+        valFirst = valLst[0];
+
+        valRect = nameRect;
+        valRect.setX(nameRect.x() + nameRect.width() + attrBox_->spacing);
+        valRect.setWidth(ViewerUtil::textWidth(fm, valFirst));
+
+        // The rest of the rows
+        valLst.takeFirst();
+        valRest       = valLst.join("\n");
+        QSize valSize = fm.size(0, valRest);
+
+        valRestRect = QRect(nameRect.x(), nameRect.y() + nameRect.height() + 2, valSize.width(), valSize.height());
+
+        currentRight = qMax(valRect.x() + valRect.width(), valRestRect.x() + valRestRect.width());
+
+        val = valFirst + " " + valRest;
+    }
+
+    // Define clipping
+    int rightPos           = currentRight + attrBox_->rightPadding + attrBox_->rightMargin;
+    totalWidth             = rightPos - option.rect.left();
+    const bool setClipRect = rightPos > option.rect.right();
+    if (setClipRect) {
+        painter->save();
+        painter->setClipRect(option.rect);
+    }
+
+    QPen fontPen(Qt::black);
+    LabelStyle* labelStyle = labelStyle_[DefaultLabel];
+    QList<LabelType> types;
+    types << ErrorLabel << WarningLabel << InfoLabel;
+    full = name + " " + val;
+    Q_FOREACH (LabelType t, types) {
+        if (labelStyle_[t]->enabled_) {
+            if (full.contains(labelStyle_[t]->regex_)) {
+                labelStyle = labelStyle_[t];
+                break;
+            }
+        }
+    }
+
+    if (labelStyle) {
+        if (labelStyle->enabled_) {
+            fontPen = labelStyle->fontPen_;
+            // draw bg
+            if (labelStyle->enabledBg_) {
+                QRect sr = option.rect;
+                sr.setWidth(rightPos - sr.x());
+                painter->fillRect(attrBox_->adjustSelectionRect(sr), labelStyle->bgBrush_);
+            }
+        }
+    }
+
+    // aviso pixmap
+    painter->drawPixmap(mirrorRect, avisoPix);
+
+    // Draw name
+    painter->setPen(fontPen);
     painter->setFont(nameFont);
     painter->drawText(attrBox_->adjustTextRect(nameRect), Qt::AlignLeft | Qt::AlignVCenter, name);
 
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/NodeViewDelegate.hpp 5.13.0-1/Viewer/ecflowUI/src/NodeViewDelegate.hpp
--- 5.12.4-1/Viewer/ecflowUI/src/NodeViewDelegate.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/NodeViewDelegate.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -172,6 +172,8 @@ protected:
 
     virtual void renderMeter(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderLabel(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
+    virtual void renderAviso(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
+    virtual void renderMirror(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderEvent(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderVar(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
     virtual void renderGenvar(QPainter* painter, QStringList data, const QStyleOptionViewItem& option, QSize&) const;
@@ -245,6 +247,8 @@ protected:
     QPen holdingTimeFontPen_;
     QPen holdingDateFontPen_;
 
+    int avisoPixId_;
+    int mirrorPixId_;
     int holdingTimePixId_;
     int holdingDatePixId_;
 
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VAttributeType.cpp 5.13.0-1/Viewer/ecflowUI/src/VAttributeType.cpp
--- 5.12.4-1/Viewer/ecflowUI/src/VAttributeType.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VAttributeType.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -154,6 +154,7 @@ static SimpleLoader<VAttributeType> load
 #include "VAutoArchiveAttr.hpp"
 #include "VAutoCancelAttr.hpp"
 #include "VAutoRestoreAttr.hpp"
+#include "VAvisoAttr.hpp"
 #include "VDateAttr.hpp"
 #include "VEventAttr.hpp"
 #include "VGenVarAttr.hpp"
@@ -162,6 +163,7 @@ static SimpleLoader<VAttributeType> load
 #include "VLimitAttr.hpp"
 #include "VLimiterAttr.hpp"
 #include "VMeterAttr.hpp"
+#include "VMirrorAttr.hpp"
 #include "VQueueAttr.hpp"
 #include "VRepeatAttr.hpp"
 #include "VTimeAttr.hpp"
@@ -171,6 +173,8 @@ static SimpleLoader<VAttributeType> load
 static VLabelAttrType labelAttrType;
 static VMeterAttrType meterAttType;
 static VEventAttrType eventAttrType;
+static VAvisoAttrType avisoAttrType;
+static VMirrorAttrType mirrorAttrType;
 static VLimitAttrType limitAttrType;
 static VLimiterAttrType limiterAttrType;
 static VRepeatAttrType repeatAttrType;
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VAvisoAttr.cpp 5.13.0-1/Viewer/ecflowUI/src/VAvisoAttr.cpp
--- 5.12.4-1/Viewer/ecflowUI/src/VAvisoAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VAvisoAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,150 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "VAvisoAttr.hpp"
+
+#include "VAttributeType.hpp"
+#include "VNode.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+
+//================================
+// VAvisoAttrType
+//================================
+
+VAvisoAttrType::VAvisoAttrType() : VAttributeType("aviso") {
+    dataCount_                         = 9;
+    searchKeyToData_["aviso_name"]     = NameIndex;
+    searchKeyToData_["aviso_listener"] = ListenerIndex;
+    searchKeyToData_["aviso_url"]      = UrlIndex;
+    searchKeyToData_["aviso_schema"]   = SchemaIndex;
+    searchKeyToData_["aviso_polling"]  = PollingIndex;
+    searchKeyToData_["aviso_revision"] = RevisionIndex;
+    searchKeyToData_["aviso_auth"]     = AuthIndex;
+    searchKeyToData_["aviso_reason"]   = ReasonIndex;
+    scanProc_                          = VAvisoAttr::scan;
+}
+
+QString VAvisoAttrType::toolTip(QStringList d) const {
+    QString t = "<b>Type:</b> Aviso<br>";
+    if (d.count() == dataCount_) {
+        t += "<b>Name:</b> " + d[NameIndex] + "<br>";
+        t += "<b>Listener:</b> " + d[ListenerIndex] + "<br>";
+        t += "<b>URL:</b> " + d[UrlIndex] + "<br>";
+        t += "<b>Schema:</b> " + d[SchemaIndex] + "<br>";
+        t += "<b>Polling:</b> " + d[PollingIndex] + " s<br>";
+        t += "<b>Revision:</b> " + d[RevisionIndex] + "<br>";
+        t += "<b>Auth:</b> " + d[AuthIndex];
+        if (auto& reason = d[ReasonIndex]; !reason.isEmpty()) {
+            t += "<br><b>Reason:</b> <span style=\"color:red\">" + d[ReasonIndex] + "</span>";
+        }
+    }
+    return t;
+}
+
+QString VAvisoAttrType::definition(QStringList d) const {
+    QString t = "aviso";
+    if (d.count() == dataCount_) {
+        t += " " + d[NameIndex] + " '" + d[ListenerIndex] + "'";
+    }
+    return t;
+}
+
+void VAvisoAttrType::encode(const ecf::AvisoAttr& aviso, QStringList& data, bool firstLine) const {
+    std::string val = aviso.listener();
+
+    if (firstLine) {
+        std::size_t pos = val.find("\n");
+        if (pos != std::string::npos) {
+            val.resize(pos);
+        }
+    }
+
+    data << qName_                                  // TypeIndex
+         << QString::fromStdString(aviso.name())    // NameIndex
+         << QString::fromStdString(val)             // ListenerIndex
+         << QString::fromStdString(aviso.url())     // UrlIndex
+         << QString::fromStdString(aviso.schema())  // SchemaIndex
+         << QString::fromStdString(aviso.polling()) // PollingIndex
+         << QString::number(aviso.revision())       // Revision Index
+         << QString::fromStdString(aviso.auth())    // AuthIndex
+         << QString::fromStdString(aviso.reason()); // ReasonIndex
+}
+
+void VAvisoAttrType::encode_empty(QStringList& data) const {
+    data << qName_;
+}
+
+//=====================================================
+//
+// VAvisoAttr
+//
+//=====================================================
+
+VAvisoAttr::VAvisoAttr(VNode* parent, [[maybe_unused]] const ecf::AvisoAttr& aviso, int index)
+    : VAttribute(parent, index) {
+}
+
+int VAvisoAttr::lineNum() const {
+    if (parent_->node_) {
+        const std::vector<ecf::AvisoAttr>& v = parent_->node_->avisos();
+        std::string val                      = v[index_].listener();
+        return std::count(val.begin(), val.end(), '\n') + 1;
+    }
+
+    return 1;
+}
+
+VAttributeType* VAvisoAttr::type() const {
+    static VAttributeType* atype = VAttributeType::find("aviso");
+    return atype;
+}
+
+QStringList VAvisoAttr::data(bool firstLine) const {
+    static auto* atype = static_cast<VAvisoAttrType*>(type());
+    QStringList s;
+    if (parent_->node_) {
+        const std::vector<ecf::AvisoAttr>& v = parent_->node_->avisos();
+        if (index_ < static_cast<int>(v.size()))
+            atype->encode(v[index_], s, firstLine);
+
+        // this can happen temporarily during update when:
+        //
+        // - an attribute was already deleted
+        // - the notification was emitted from the update thread, but
+        //   has not yet reached the main thread
+        // - here, in the main thread, we still have the old (incorrect) attribute number
+        //
+        // * In this case, as safety measure, we encode an empty attribute.
+        //   When the notification arrives all the attributes of the given node will be rescanned
+        //   and will be set with the correct state.
+        else
+            atype->encode_empty(s);
+    }
+    return s;
+}
+
+std::string VAvisoAttr::strName() const {
+    if (parent_->node_) {
+        const std::vector<ecf::AvisoAttr>& v = parent_->node_->avisos();
+        return v[index_].name();
+    }
+    return {};
+}
+
+void VAvisoAttr::scan(VNode* vnode, std::vector<VAttribute*>& vec) {
+    if (vnode->node_) {
+        const std::vector<ecf::AvisoAttr>& v = vnode->node_->avisos();
+
+        auto n = static_cast<int>(v.size());
+        for (int i = 0; i < n; i++) {
+            vec.push_back(new VAvisoAttr(vnode, v[i], i));
+        }
+    }
+}
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VAvisoAttr.hpp 5.13.0-1/Viewer/ecflowUI/src/VAvisoAttr.hpp
--- 5.12.4-1/Viewer/ecflowUI/src/VAvisoAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VAvisoAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_viewer_VAvisoAttr_HPP
+#define ecflow_viewer_VAvisoAttr_HPP
+
+#include <string>
+#include <vector>
+
+#include <QStringList>
+
+#include "VAttribute.hpp"
+#include "VAttributeType.hpp"
+
+class AttributeFilter;
+class VAttributeType;
+class VNode;
+
+namespace ecf {
+class AvisoAttr;
+}
+
+class VAvisoAttrType : public VAttributeType {
+public:
+    explicit VAvisoAttrType();
+    QString toolTip(QStringList d) const override;
+    QString definition(QStringList d) const override;
+    void encode(const ecf::AvisoAttr& aviso, QStringList& data, bool firstLine) const;
+    void encode_empty(QStringList& data) const;
+
+private:
+    enum DataIndex {
+        TypeIndex     = 0,
+        NameIndex     = 1,
+        ListenerIndex = 2,
+        UrlIndex      = 3,
+        SchemaIndex   = 4,
+        PollingIndex  = 5,
+        RevisionIndex = 6,
+        AuthIndex     = 7,
+        ReasonIndex   = 8
+    };
+};
+
+class VAvisoAttr : public VAttribute {
+public:
+    VAvisoAttr(VNode* parent, const ecf::AvisoAttr&, int index);
+
+    int lineNum() const override;
+    VAttributeType* type() const override;
+    QStringList data(bool firstLine) const override;
+    std::string strName() const override;
+
+    static void scan(VNode* vnode, std::vector<VAttribute*>& vec);
+};
+
+#endif /* ecflow_viewer_VAvisoAttr_HPP */
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VIcon.cpp 5.13.0-1/Viewer/ecflowUI/src/VIcon.cpp
--- 5.12.4-1/Viewer/ecflowUI/src/VIcon.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VIcon.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -139,6 +139,12 @@ public:
     bool show(VNode*) override;
 };
 
+class VRemoteErrorIcon : public VIcon {
+public:
+    explicit VRemoteErrorIcon(const std::string& name) : VIcon(name) {}
+    bool show(VNode*) override;
+};
+
 //==========================================================
 //
 // Create VIcon instances
@@ -162,6 +168,7 @@ static VRestoredIcon restoredIcon("resto
 static VSlowJobCreationIcon slowJobCreationIcon("slow_job");
 static VNoLogIcon noLog("no_log");
 static VCheckpointErrorIcon noCheckptIcon("checkpt_err");
+static VRemoteErrorIcon remoteErrorIcon("remote_err");
 
 //==========================================================
 //
@@ -557,3 +564,11 @@ bool VCheckpointErrorIcon::show(VNode* n
 
     return n->isFlagSet(ecf::Flag::CHECKPT_ERROR);
 }
+
+bool VRemoteErrorIcon::show(VNode* n) {
+    if (!n || n->isServer()) {
+        return false;
+    }
+
+    return n->isFlagSet(ecf::Flag::REMOTE_ERROR);
+}
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VMirrorAttr.cpp 5.13.0-1/Viewer/ecflowUI/src/VMirrorAttr.cpp
--- 5.12.4-1/Viewer/ecflowUI/src/VMirrorAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VMirrorAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,134 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "VMirrorAttr.hpp"
+
+#include "VAttributeType.hpp"
+#include "VNode.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+
+//================================
+// VMirrorAttrType
+//================================
+
+VMirrorAttrType::VMirrorAttrType() : VAttributeType("mirror") {
+    dataCount_                             = 9;
+    searchKeyToData_["mirror_name"]        = NameIndex;
+    searchKeyToData_["mirror_remote_path"] = RemotePathIndex;
+    searchKeyToData_["mirror_remote_host"] = RemoteHostIndex;
+    searchKeyToData_["mirror_remote_port"] = RemotePortIndex;
+    searchKeyToData_["mirror_polling"]     = PollingIndex;
+    scanProc_                              = VMirrorAttr::scan;
+}
+
+QString VMirrorAttrType::toolTip(QStringList d) const {
+    QString t = "<b>Type:</b> Mirror<br>";
+    if (d.count() == dataCount_) {
+        t += "<b>Name:</b> " + d[NameIndex] + "<br>";
+        t += "<b>Remote Path:</b> " + d[RemotePathIndex] + "<br>";
+        t += "<b>Remote Host:</b> " + d[RemoteHostIndex] + "<br>";
+        t += "<b>Remote Port:</b> " + d[RemotePortIndex] + "<br>";
+        t += "<b>Polling:</b> " + d[PollingIndex] + "<br>";
+        t += "<b>SSL:</b> " + d[SslIndex] + "<br>";
+        t += "<b>Auth:</b> " + d[AuthIndex];
+        if (const auto& reason = d[ReasonIndex]; !reason.isEmpty()) {
+            t += "<br><b>Reason:</b> <span style=\"color:red\">" + d[ReasonIndex] + "</span>";
+        }
+    }
+    return t;
+}
+
+QString VMirrorAttrType::definition(QStringList d) const {
+    QString t = "mirror";
+    if (d.count() == dataCount_) {
+        t += " " + d[NameIndex] + " '" + d[RemoteHostIndex] + ":" + d[RemotePortIndex] + "' at '" + d[RemotePathIndex] +
+             "'";
+    }
+    return t;
+}
+
+void VMirrorAttrType::encode(const ecf::MirrorAttr& mirror, QStringList& data, bool firstLine) const {
+
+    data << qName_                                                  // TypeIndex
+         << QString::fromStdString(mirror.name())                   // NameIndex
+         << QString::fromStdString(mirror.remote_path())            // RemotePathIndex
+         << QString::fromStdString(mirror.remote_host())            // RemoteHostIndex
+         << QString::fromStdString(mirror.remote_port())            // RemotePortIndex
+         << QString::fromStdString(mirror.polling())                // PollingIndex
+         << QString::fromStdString(mirror.ssl() ? "true" : "false") // SslIndex
+         << QString::fromStdString(mirror.auth())                   // AuthIndex
+         << QString::fromStdString(mirror.reason());                // ReasonIndex
+}
+
+void VMirrorAttrType::encode_empty(QStringList& data) const {
+    data << qName_;
+}
+
+//=====================================================
+//
+// VMirrorAttr
+//
+//=====================================================
+
+VMirrorAttr::VMirrorAttr(VNode* parent, [[maybe_unused]] const ecf::MirrorAttr& mirror, int index)
+    : VAttribute(parent, index) {
+}
+
+int VMirrorAttr::lineNum() const {
+    return 1;
+}
+
+VAttributeType* VMirrorAttr::type() const {
+    static VAttributeType* atype = VAttributeType::find("mirror");
+    return atype;
+}
+
+QStringList VMirrorAttr::data(bool firstLine) const {
+    static auto* atype = static_cast<VMirrorAttrType*>(type());
+    QStringList s;
+    if (parent_->node_) {
+        const std::vector<ecf::MirrorAttr>& v = parent_->node_->mirrors();
+        if (index_ < static_cast<int>(v.size()))
+            atype->encode(v[index_], s, firstLine);
+
+        // this can happen temporarily during update when:
+        //
+        // - an attribute was already deleted
+        // - the notification was emitted from the update thread, but
+        //   has not yet reached the main thread
+        // - here, in the main thread, we still have the old (incorrect) attribute number
+        //
+        // * In this case, as safety measure, we encode an empty attribute.
+        //   When the notification arrives all the attributes of the given node will be rescanned
+        //   and will be set with the correct state.
+        else
+            atype->encode_empty(s);
+    }
+    return s;
+}
+
+std::string VMirrorAttr::strName() const {
+    if (parent_->node_) {
+        const std::vector<ecf::MirrorAttr>& v = parent_->node_->mirrors();
+        return v[index_].name();
+    }
+    return {};
+}
+
+void VMirrorAttr::scan(VNode* vnode, std::vector<VAttribute*>& vec) {
+    if (vnode->node_) {
+        const std::vector<ecf::MirrorAttr>& v = vnode->node_->mirrors();
+
+        auto n = static_cast<int>(v.size());
+        for (int i = 0; i < n; i++) {
+            vec.push_back(new VMirrorAttr(vnode, v[i], i));
+        }
+    }
+}
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VMirrorAttr.hpp 5.13.0-1/Viewer/ecflowUI/src/VMirrorAttr.hpp
--- 5.12.4-1/Viewer/ecflowUI/src/VMirrorAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VMirrorAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_viewer_VMirrorAttr_HPP
+#define ecflow_viewer_VMirrorAttr_HPP
+
+#include <string>
+#include <vector>
+
+#include <QStringList>
+
+#include "VAttribute.hpp"
+#include "VAttributeType.hpp"
+
+class AttributeFilter;
+class VAttributeType;
+class VNode;
+
+namespace ecf {
+class MirrorAttr;
+}
+
+class VMirrorAttrType : public VAttributeType {
+public:
+    explicit VMirrorAttrType();
+    QString toolTip(QStringList d) const override;
+    QString definition(QStringList d) const override;
+    void encode(const ecf::MirrorAttr& mirror, QStringList& data, bool firstLine) const;
+    void encode_empty(QStringList& data) const;
+
+private:
+    enum DataIndex {
+        TypeIndex       = 0,
+        NameIndex       = 1,
+        RemotePathIndex = 2,
+        RemoteHostIndex = 3,
+        RemotePortIndex = 4,
+        PollingIndex    = 5,
+        SslIndex        = 6,
+        AuthIndex       = 7,
+        ReasonIndex     = 8
+    };
+};
+
+class VMirrorAttr : public VAttribute {
+public:
+    VMirrorAttr(VNode* parent, const ecf::MirrorAttr&, int index);
+
+    int lineNum() const override;
+    VAttributeType* type() const override;
+    QStringList data(bool firstLine) const override;
+    std::string strName() const override;
+
+    static void scan(VNode* vnode, std::vector<VAttribute*>& vec);
+};
+
+#endif /* ecflow_viewer_VMirrorAttr_HPP */
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VModelData.cpp 5.13.0-1/Viewer/ecflowUI/src/VModelData.cpp
--- 5.12.4-1/Viewer/ecflowUI/src/VModelData.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VModelData.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -319,7 +319,8 @@ void VTreeServer::notifyBeginNodeChange(
                 it == ecf::Aspect::LIMIT || it == ecf::Aspect::EXPR_TRIGGER || it == ecf::Aspect::EXPR_COMPLETE ||
                 it == ecf::Aspect::REPEAT || it == ecf::Aspect::REPEAT_INDEX || it == ecf::Aspect::NODE_VARIABLE ||
                 it == ecf::Aspect::LATE || it == ecf::Aspect::TODAY || it == ecf::Aspect::TIME ||
-                it == ecf::Aspect::DAY || it == ecf::Aspect::CRON || it == ecf::Aspect::DATE) {
+                it == ecf::Aspect::DAY || it == ecf::Aspect::CRON || it == ecf::Aspect::DATE ||
+                it == ecf::Aspect::AVISO || it == ecf::Aspect::MIRROR) {
                 if (node && node->isAttrInitialised()) {
                     Q_EMIT attributesChanged(this, node);
                 }
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/VNode.hpp 5.13.0-1/Viewer/ecflowUI/src/VNode.hpp
--- 5.12.4-1/Viewer/ecflowUI/src/VNode.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/VNode.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -87,7 +87,9 @@ class VNode : public VItem {
     friend class VServer;
     friend class VLabelAttr;
     friend class VMeterAttr;
+    friend class VMirrorAttr;
     friend class VEventAttr;
+    friend class VAvisoAttr;
     friend class VRepeatAttr;
     friend class VTriggerAttr;
     friend class VLimitAttr;
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/Viewer.hpp 5.13.0-1/Viewer/ecflowUI/src/Viewer.hpp
--- 5.12.4-1/Viewer/ecflowUI/src/Viewer.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/Viewer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -31,6 +31,8 @@ enum AttributeType {
     LabelAttribute,
     MeterAttribute,
     EventAttribute,
+    AvisoAttribute,
+    MirrorAttribute,
     RepeatAttribute,
     TimeAttribute,
     DateAttribute,
diff -pruN 5.12.4-1/Viewer/ecflowUI/src/viewer.qrc 5.13.0-1/Viewer/ecflowUI/src/viewer.qrc
--- 5.12.4-1/Viewer/ecflowUI/src/viewer.qrc	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/ecflowUI/src/viewer.qrc	2024-06-20 10:11:46.000000000 +0000
@@ -14,6 +14,7 @@
     <file alias="icon_archived.svg">../images/icon_archived.svg</file>
     <file alias="icon_calendar.svg">../images/icon_calendar.svg</file>
     <file alias="icon_checkpt_err.svg">../images/icon_checkpt_err.svg</file>
+    <file alias="icon_remote_err.svg">../images/icon_no_access.svg</file>
     <file alias="icon_clock.svg">../images/icon_clock.svg</file>     
     <file alias="icon_clock_free.svg">../images/icon_clock_free.svg</file>
     <file alias="icon_complete.svg">../images/icon_complete.svg</file>
@@ -43,6 +44,7 @@
     <file alias="add_tab.svg">../images/add_tab.svg</file> 
     <file alias="add_variable_column.svg">../images/add_variable_column.svg</file>    
     <file alias="attribute.svg">../images/attribute.svg</file>
+    <file alias="aviso.svg">../images/aviso.svg</file>
     <file alias="autoscroll.svg">../images/autoscroll.svg</file>
     <file alias="autoscroll_off.svg">../images/autoscroll_off.svg</file>
     <file alias="chain.svg">../images/chain.svg</file>
@@ -127,6 +129,7 @@
     <file alias="reload.svg">../images/reload.svg</file>
     <file alias="reload_green.svg">../images/reload_green.svg</file>
     <file alias="reload_one.svg">../images/reload_one.svg</file>
+    <file alias="remote.svg">../images/remote.svg</file>
     <file alias="remove.svg">../images/remove.svg</file>
     <file alias="rescue.svg">../images/rescue.svg</file>
     <file alias="reset_to_default.svg">../images/reset_to_default.svg</file>
diff -pruN 5.12.4-1/Viewer/libViewer/src/CMakeLists.txt 5.13.0-1/Viewer/libViewer/src/CMakeLists.txt
--- 5.12.4-1/Viewer/libViewer/src/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/libViewer/src/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -80,7 +80,7 @@ ecbuild_add_library(
   PRIVATE_DEFINITIONS
     ECFLOW_SHARED_DIR="${CMAKE_INSTALL_PREFIX}/share/ecflow"
   PRIVATE_LIBS
-    core
+    ecflow_all
     Boost::boost
     $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
     # Qt5
diff -pruN 5.12.4-1/Viewer/libViewer/src/IconProvider.cpp 5.13.0-1/Viewer/libViewer/src/IconProvider.cpp
--- 5.12.4-1/Viewer/libViewer/src/IconProvider.cpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/libViewer/src/IconProvider.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -63,6 +63,32 @@ QPixmap IconItem::pixmap(int size) {
     return {};
 }
 
+
+QPixmap IconItem::pixmapToHeight(int size) {
+    auto it = pixmapsByHeight_.find(size);
+    if (it != pixmapsByHeight_.end())
+        return it->second;
+    else {
+        QPixmap pix;
+        QImageReader imgR(path_);
+        if (imgR.canRead()) {
+            int w = imgR.size().width();
+            int h = imgR.size().height();
+            float r = static_cast<float>(w)/static_cast<float>(h);
+            imgR.setScaledSize(QSize(size*r, size));
+            QImage img = imgR.read();
+            pix        = QPixmap::fromImage(img);
+        }
+        else {
+            pix = unknown(size);
+        }
+
+        pixmapsByHeight_[size] = pix;
+        return pix;
+    }
+    return {};
+}
+
 QPixmap IconItem::unknown(int size) {
     return unknownIcon.pixmap(size);
 }
@@ -126,6 +152,10 @@ QPixmap IconProvider::pixmap(int id, int
     return icon(id)->pixmap(size);
 }
 
+QPixmap IconProvider::pixmapToHeight(int id, int size) {
+    return icon(id)->pixmapToHeight(size);
+}
+
 QPixmap IconProvider::lockPixmap(int size) {
     return lockIcon.pixmap(size);
 }
diff -pruN 5.12.4-1/Viewer/libViewer/src/IconProvider.hpp 5.13.0-1/Viewer/libViewer/src/IconProvider.hpp
--- 5.12.4-1/Viewer/libViewer/src/IconProvider.hpp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/Viewer/libViewer/src/IconProvider.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -21,6 +21,7 @@ public:
     virtual ~IconItem() = default;
 
     QPixmap pixmap(int);
+    QPixmap pixmapToHeight(int size);
     int id() const { return id_; }
     QString path() const { return path_; }
 
@@ -29,6 +30,7 @@ protected:
 
     QString path_;
     std::map<int, QPixmap> pixmaps_;
+    std::map<int, QPixmap> pixmapsByHeight_;
     int id_;
 };
 
@@ -49,6 +51,7 @@ public:
     static QString path(int id);
     static QPixmap pixmap(QString name, int size);
     static QPixmap pixmap(int id, int size);
+    static QPixmap pixmapToHeight(int id, int size);
 
     static QPixmap lockPixmap(int);
     static QPixmap warningPixmap(int);
diff -pruN 5.12.4-1/bin/CMakeLists.txt 5.13.0-1/bin/CMakeLists.txt
--- 5.12.4-1/bin/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/bin/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+install( PROGRAMS ecbuild DESTINATION ${INSTALL_BIN_DIR} )
diff -pruN 5.12.4-1/bin/ecbuild 5.13.0-1/bin/ecbuild
--- 5.12.4-1/bin/ecbuild	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/bin/ecbuild	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,460 @@
+#!/bin/bash --noprofile
+
+# (C) Copyright 2011- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence Version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation nor
+# does it submit to any jurisdiction.
+
+set -eua
+
+CMAKE_MIN_REQUIRED=3.11
+CMAKE_BUILD_VERSION=3.18.3
+
+usage()
+{
+  echo "Usage: ecbuild [--help] [--version]"
+  exit $1
+}
+
+help()
+{
+    cat <<EOF
+USAGE:
+
+  ecbuild [--help] [--version]
+  ecbuild [option...] [--] [cmake-argument...] <path-to-source>
+  ecbuild [option...] [--] [cmake-argument...] <path-to-existing-build>
+
+DESCRIPTION:
+
+  ecbuild is a build system based on CMake, but providing a lot of macro's
+  to make it easier to work with. Upon execution,
+  the equivalent cmake command is printed.
+
+  ecbuild/cmake must be called from an out-of-source build directory and
+  forbids in-source builds.
+
+SYNOPSIS:
+
+    --help         Display this help
+    --version      Display ecbuild version
+
+Available values for "option":
+
+    --cmakebin=<path>
+          Set which cmake binary to use. Default is 'cmake'
+
+    --prefix=<prefix>
+          Set the install path to <prefix>.
+          Equivalent to cmake argument "-DCMAKE_INSTALL_PREFIX=<prefix>"
+
+    --build=<build-type>
+          Set the build-type to <build-type>.
+          Equivalent to cmake argument "-DCMAKE_BUILD_TYPE=<build-type>"
+          <build-type> can be any of:
+             - debug : Lowest optimization level, useful for debugging
+             - release : Highest optimization level, for best performance
+             - bit : Highest optimization level while staying bit-reproducible
+             - ...others depending on project
+
+    --log=<log-level>
+          Set the ecbuild log-level
+          Equivalent to "-DECBUILD_LOG_LEVEL=<log-level>"
+          <log-level> can be any of:
+             - DEBUG
+             - INFO
+             - WARN
+             - ERROR
+             - CRITICAL
+             - OFF
+          Every choice outputs also the log-levels listed below itself
+
+    --static
+          Build static libraries.
+          Equivalent to "-DBUILD_SHARED_LIBS=OFF"
+
+    --dynamic, --shared
+          Build dynamic libraries (usually the default).
+          Equivalent to "-DBUILD_SHARED_LIBS=ON"
+
+    --config=<config>
+          Configuration file using CMake syntax that gets included
+          Equivalent to cmake argument "-DECBUILD_CONFIG=<config-file>"
+
+    --toolchain=<toolchain>
+          Use a platform specific toolchain, containing settings such
+          as compilation flags, locations of commonly used dependencies.
+          <toolchain> should be the path to a custom toolchain file.
+          Equivalent to cmake argument "-DCMAKE_TOOLCHAIN_FILE=<toolchain-file>"
+
+    --cache=<ecbuild-cache-file>    (advanced)
+          A file called "ecbuild-cache.cmake" is generated during configuration.
+          This file can be moved to a safe location, and specified for future
+          builds to speed up checking of compiler/platform capabilities. Note
+          that this is only accelerating fresh builds, as cmake internally
+          caches also. Therefore this option is *not* recommended.
+
+    --get-cmake[=<prefix>]
+          Automatically download CMake binaries from version $CMAKE_BUILD_VERSION.
+          Requires an internet connection. If no prefix is given, install into
+          $PWD/.local/.
+
+    --build-cmake[=<prefix>]
+          Automatically download and build CMake version $CMAKE_BUILD_VERSION.
+          Requires an internet connection and may take a while. If no prefix
+          is given, install into $PWD/.local/.
+
+    --dryrun
+          Don't actually execute the cmake call, just print what would have
+          been executed.
+
+
+Available values for "cmake-argument":
+
+    Any value that can be usually passed to cmake to (re)configure the build.
+    Typically these values start with "-D".
+        example:  -DENABLE_TESTS=ON  -DENABLE_MPI=OFF  -DECKIT_PATH=...
+
+    They can be explicitly separated from [option...] with a "--", for the case
+    there is a conflicting option with the "cmake" executable, and the latter's
+    option is requested.
+
+------------------------------------------------------------------------
+
+NOTE: When reconfiguring a build, it is only necessary to change the relevant
+options, as everything stays cached. For example:
+  > ecbuild --prefix=PREFIX .
+  > ecbuild -DENABLE_TESTS=ON .
+
+------------------------------------------------------------------------
+
+Compiling:
+
+  To compile the project with <N> threads:
+    > make -j<N>
+
+  To get verbose compilation/linking output:
+    > make VERBOSE=1
+
+Testing:
+
+  To run the project's tests
+    > ctest
+
+  Also check the ctest manual/help for more options on running tests
+
+Installing:
+
+  To install the project in location PREFIX with
+       "--prefix=PREFIX" or
+       "-DCMAKE_INSTALL_PREFIX=PREFIX"
+    > make install
+
+------------------------------------------------------------------------
+ECMWF"
+
+EOF
+    exit $1
+}
+
+INSTALL_DIR="$( cd $( dirname "${BASH_SOURCE[0]}" ) && pwd -P )"
+export ecbuild_ROOT="$( cd "$INSTALL_DIR/.." && pwd -P )"
+export ecbuild_DIR=$ecbuild_ROOT # for versions of CMake < 3.12
+ECBUILD_MODULE_PATH=""
+# If there is a directory share/ecbuild/cmake relative to the parent directory
+# (as in an install tree), add it to CMAKE_MODULE_PATH
+if [ -d $INSTALL_DIR/../share/ecbuild/cmake ]; then
+  ECBUILD_MODULE_PATH="$( cd "$INSTALL_DIR/../share/ecbuild/cmake" && pwd -P )"
+# If there is a cmake subdirectory relative to the script directory (as in a
+# tarball), add it to CMAKE_MODULE_PATH
+elif [ -d $INSTALL_DIR/../cmake ]; then
+  ECBUILD_MODULE_PATH="$( cd "$INSTALL_DIR/../cmake" && pwd -P )"
+fi
+
+# Fail if we couldn't find ecBuild modules
+if [ ! -f "$ECBUILD_MODULE_PATH/ecbuild_system.cmake" ]; then
+  echo "FATAL: ecBuild modules could not be found in either $INSTALL_DIR/../share/ecbuild/cmake or $INSTALL_DIR/../cmake" >&2
+  exit 1
+fi
+
+ADD_ECBUILD_OPTIONS="-DCMAKE_MODULE_PATH=$ECBUILD_MODULE_PATH"
+
+version()
+{
+  ecbuild_version=$(cat ${ECBUILD_MODULE_PATH}/VERSION)
+  echo "ecbuild version ${ecbuild_version}"
+  command -v cmake >/dev/null 2>&1 || { exit 0; }
+  cmake --version | head -1
+  exit 0
+}
+
+log()
+{
+  log_level=$(tr "[a-z]" "[A-Z]" <<< "$1")
+  ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DECBUILD_LOG_LEVEL=${log_level}"
+}
+
+prefix()
+{
+  ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DCMAKE_INSTALL_PREFIX=${1/#\~\//$HOME/}"
+}
+
+config()
+{
+  arg=${1/#\~\//$HOME/}
+  if [ -f $arg ]; then
+    config_file=$arg
+    config_file="$( cd $( dirname "${config_file}" ) && pwd -P )/$( basename ${config_file} )"
+  else
+    echo "Error:"
+    echo "   Config file [$arg] is not found or is not a file."
+    exit 1
+  fi
+  ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DECBUILD_CONFIG=${config_file}"
+}
+
+toolchain()
+{
+  arg=${1/#\~\//$HOME/}
+  if [ -f $arg ]; then
+    toolchain_file=$arg
+  fi
+  if [ -z ${toolchain_file+x} ]; then
+    echo "Error toolchain $arg is not valid"
+    exit 1
+  else
+    ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DCMAKE_TOOLCHAIN_FILE=${toolchain_file}"
+  fi
+}
+
+cache()
+{
+  arg=$1
+  if [ -f $arg ]; then
+    cache_file=$arg
+    cache_file="$( cd $( dirname "${cache_file}" ) && pwd -P )/$( basename ${cache_file} )"
+  else
+    echo "Error:"
+    echo "   Cache file [$arg] is not found or is not a file."
+    exit 1
+  fi
+  ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DECBUILD_CACHE=${cache_file}"
+}
+
+if test $# -eq 0; then
+    usage 1
+fi
+
+while test $# -gt 0; do
+
+    # Split --option=value in $opt="--option" and $val="value"
+
+    opt=""
+    val=""
+
+    case "$1" in
+    --*=*)
+      opt=`echo "$1" | sed 's/=.*//'`
+      val=`echo "$1" | sed 's/--[_a-zA-Z0-9-]*=//'`
+      ;;
+    --*)
+      opt=$1
+      ;;
+    # -D*)
+    #   ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS $1"
+    #   ;;
+    *)
+      break
+      ;;
+    esac
+
+    # echo "debug opt: $opt $val"
+
+    # Parse options
+    case "$opt" in
+      --help)
+        help 0
+  	    ;;
+      --version)
+        version
+        ;;
+      --dryrun)
+        dryrun="yes"
+        ;;
+      --cmakebin)
+        cmakebin="$val"
+        ;;
+      --prefix)
+        prefix "$val"
+        ;;
+      --build)
+        ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DCMAKE_BUILD_TYPE=$val"
+        ;;
+      --log)
+        log $val
+        ;;
+      --static)
+        ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DBUILD_SHARED_LIBS=OFF"
+        ;;
+      --dynamic)
+        ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DBUILD_SHARED_LIBS=ON"
+        ;;
+      --shared)
+        ADD_ECBUILD_OPTIONS="$ADD_ECBUILD_OPTIONS -DBUILD_SHARED_LIBS=ON"
+        ;;
+      --toolchain)
+        toolchain $val
+        ;;
+      --config)
+        config $val
+        ;;
+      --cache)
+        cache $val
+        ;;
+      --get-cmake)
+        get_cmake="bin"
+        if [[ -n $val ]]; then
+          cmake_prefix="$val"
+        fi
+        ;;
+      --build-cmake)
+        get_cmake="src"
+        if [[ -n $val ]]; then
+          cmake_prefix="$val"
+        fi
+        ;;
+      --)
+        shift
+        break
+        ;;
+      *)
+        echo "unknown option: $opt"
+	      usage 1
+        ;;
+    esac
+    shift
+done
+
+# If no arguments remain, set srcARG to "."
+if [ $# -eq 0 ]; then
+  srcARG="."
+fi
+
+if [ -z ${toolchain_file+x} ]; then
+  if [ -z ${ECBUILD_TOOLCHAIN+x} ]; then :
+  else
+    toolchain ${ECBUILD_TOOLCHAIN}
+    echo "ecbuild toolchain set using environment variable ECBUILD_TOOLCHAIN"
+  fi
+fi
+
+src=${srcARG:=""}
+cmake=${cmakebin:=cmake}
+dryrun=${dryrun:=no}
+get_cmake=${get_cmake:=""}
+cmake_prefix=${cmake_prefix:=$PWD/.local}
+cmake_found=""
+cmake_version_sufficient=""
+
+
+# Check that version $1 satisfies $2
+# CMake versions have no more than 4 fields
+# Version sort (sort -V) is not available on all platforms
+version_gte() {
+  [ "$2" = "$(echo -e "$1\n$2" | sort -t '.' -k 1,1 -k 2,2 -k 3,3 -k 4,4 -g | head -n1)" ]
+}
+
+# Download a CMake tarball
+# $1: version
+# $2: suffix (optional)
+download_cmake() {
+  tarball=cmake-$1${2:-""}.tar.gz
+  if [[ ! -r $tarball ]]; then
+    shortver=$(echo $1 | cut -d. -f1-2)
+    url=http://www.cmake.org/files/v$shortver/$tarball
+    # -N          Download only if the remote version of the file is newer
+    # --continue  Continue an interrupted download
+    # -T 60       Time out a download attempt after 60 seconds
+    # -t 3        Only make 3 download attempts
+    wget -N --continue -T 60 -t 3 $url || {
+      echo "Failed to download CMake release $1." >&2
+      echo "Please download from $url" >&2
+      echo "and place $tarball in $PWD" >&2
+      exit 1
+    }
+  fi
+  echo $tarball
+}
+
+# Use already built CMake if any
+if [[ -x "${cmake_prefix}/bin/cmake" ]]; then
+  echo "Using already built CMake in ${cmake_prefix}/bin/cmake" >&2
+  cmake="${cmake_prefix}/bin/cmake"
+# Get a CMake binary if requested and no sufficient version found
+elif [[ $get_cmake = "bin" ]]; then
+  plat=$(uname -s)
+  arch=$(uname -m)
+  if [[ "${plat}" != "Linux" ]] && [[ "${plat}" != "Darwin" ]] ; then
+    echo "Cannot download CMake binaries for this platform." >&2
+    echo "Please use --build-cmake to build from source." >&2
+    exit 1
+  fi
+  if [[ "${arch}" != "x86_64" ]] ; then
+    echo "Cannot download CMake binaries for this architecture." >&2
+    echo "Please use --build-cmake to build from source." >&2
+    exit 1
+  fi
+  echo "Downloading CMake version ${CMAKE_BUILD_VERSION} binaries and installing into ${cmake_prefix} ..." >&2
+  tarball=$(download_cmake "${CMAKE_BUILD_VERSION}" "-${plat}-${arch}")
+  mkdir -p "${cmake_prefix}"
+  tar xzf $tarball -C "${cmake_prefix}" --strip-components=1
+  cmake="${cmake_prefix}/bin/cmake"
+# Build CMake from source if requested and no sufficient version found
+elif [[ $get_cmake = "src" ]]; then
+  echo "Building CMake version ${CMAKE_BUILD_VERSION} and installing into ${cmake_prefix} ..." >&2
+  tarball=$(download_cmake "${CMAKE_BUILD_VERSION}")
+  tar xzf $tarball
+  (
+    mkdir -p build_cmake
+    cd build_cmake
+    ../cmake-${CMAKE_BUILD_VERSION}/bootstrap --prefix="${cmake_prefix}" && make && make install
+  )
+  cmake="${cmake_prefix}/bin/cmake"
+fi
+
+# Check if the cmake version is sufficient
+if $(command -v $cmake >/dev/null 2>&1); then
+  cmake_found="yes"
+  cmake_version=$($cmake --version | head -n1 | awk '{ print $3 }')
+  echo "Found CMake version $cmake_version" >& 2
+  if version_gte $cmake_version $CMAKE_MIN_REQUIRED; then
+    cmake_version_sufficient="yes"
+  fi
+fi
+
+# Fail if we don't have a sufficient CMake
+if [[ ! $cmake_version_sufficient ]]; then
+  if [[ ! $cmake_found ]]; then
+    echo "CMake is required and cannot be found in the PATH." >&2
+  else
+    echo "CMake version $CMAKE_MIN_REQUIRED is required but only $cmake_version was found." >&2
+  fi
+  echo "" >&2
+  echo "  Try 'module load cmake', specify a CMake binary with --cmakebin=/path/to/cmake" >&2
+  echo "  or  let ecbuild download and build CMake with the --build-cmake option." >&2
+  exit 1
+fi
+
+echo ""
+echo "$cmake ${ADD_ECBUILD_OPTIONS} $@ $src"
+echo ""
+
+if [ ${dryrun} == "yes" ]; then
+  echo "[DRYRUN] -- not executing"
+  exit 0
+fi
+
+$cmake ${ADD_ECBUILD_OPTIONS} "$@" $src
diff -pruN 5.12.4-1/build_scripts/clean.sh 5.13.0-1/build_scripts/clean.sh
--- 5.12.4-1/build_scripts/clean.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/clean.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-#!/bin/sh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-cd $WK
-
-# Remove the bin directories
-rm -rf ACore/bin
-rm -rf ANattr/bin
-rm -rf ANode/bin 
-rm -rf ANode/parser/bin 
-rm -rf Base/bin
-rm -rf CSim/bin
-rm -rf Client/bin 
-rm -rf Server/bin 
-rm -rf Test/bin
-rm -rf Pyext/bin 
-   
-# remove generated files
-rm -rf Doc/online/_build/*
-rm -rf Test/data/ECF_HOME_debug*
-rm -rf Test/data/ECF_HOME_release*
-rm -rf ANode/parser/test/data/single_defs/mega.def_log
-rm -rf Pyext/test/data/CUSTOMER
-rm -rf Pyext/test.def
-rm -rf Pyext/build
-rm -rf Pyext/timestamp
-rm -rf bin
-rm -rf build
-rm -rf RemoteSystemsTempFiles
-rm -rf *.dat
-rm -rf *.log
-
-find . -name \*~ -exec rm -rf \*~ {} \; -print
-find . -name \*.mk -exec rm -rf \*.mk {} \; -print
-find . -name \*.o -exec rm -rf \*.mk {} \; -print
-find . -name \*.so -exec rm -rf \*.so {} \; -print
-find . -name \*.tmp -exec rm -rf \*.tmp {} \; -print
-find . -name \*.job\* -exec rm -rf \*.job\* {} \; -print
-find . -name \*.check -exec rm -rf \*.check {} \; -print
-find . -name \*.flat -exec rm -rf \*.flat {} \; -print
-find . -name \*.depth -exec rm -rf \*.depth {} \; -print
-find . -name \*.out -exec rm -rf \*.out {} \; -print
-find . -name \*.pyc -exec rm -rf \*.pyc {} \; -print
-find . -name t\*.1 -exec rm -rf t\*.1 {} \; -print
-find . -name gmon.out -exec rm -rf gmon.out {} \; -print
-find . -name gnuplot.dat -exec rm -rf gnuplot.dat {} \; -print
-find . -name gnuplot.script -exec rm -rf gnuplot.script {} \; -print
-find . -name ecflow.html -exec rm -rf ecflow.html {} \; -print
-find . -name core -exec rm -rf core {} \; -print
-find . -name callgrind.out.\* -exec rm -rf callgrind.out.\* {} \; -print
-find . -name massif.out.\* -exec rm -rf massif.out.* {} \; -print
-
-for file in `hostname`.*.ecf.* ; do
-    echo $file
-    rm -rf $file
-done
-
-# remove any defs file at the workspace level. There should not be any
-rm -rf *.def
-   
-# Remove any lock file create by tests which used EcfPortLock.hpp
-rm -rf *.lock
-
diff -pruN 5.12.4-1/build_scripts/ecflow_asan.supp 5.13.0-1/build_scripts/ecflow_asan.supp
--- 5.12.4-1/build_scripts/ecflow_asan.supp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/ecflow_asan.supp	1970-01-01 00:00:00.000000000 +0000
@@ -1,3 +0,0 @@
-#interceptor_via_fun:NameOfCFunctionToSuppress
-#interceptor_via_fun:-[ClassName objCMethodToSuppress:]
-#interceptor_via_lib:NameOfTheLibraryToSuppress
diff -pruN 5.12.4-1/build_scripts/ecflow_lsan.supp 5.13.0-1/build_scripts/ecflow_lsan.supp
--- 5.12.4-1/build_scripts/ecflow_lsan.supp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/ecflow_lsan.supp	1970-01-01 00:00:00.000000000 +0000
@@ -1,11 +0,0 @@
-# Needed for python ONLY
-# https://github.com/google/sanitizers/wiki/AddressSanitizerLeakSanitizer#suppressions
-leak:__interceptor_fopen64 
-leak:list_resize 
-leak:_PyString_Resize
-leak:type_new 
-leak:__interceptor_calloc
-leak:__interceptor_malloc
-leak:boost::python::objects::function_object
-leak:boost::python::api::object
-leak:init_module_ecflow
diff -pruN 5.12.4-1/build_scripts/eclipse_c++_code_style.xml 5.13.0-1/build_scripts/eclipse_c++_code_style.xml
--- 5.12.4-1/build_scripts/eclipse_c++_code_style.xml	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/eclipse_c++_code_style.xml	1970-01-01 00:00:00.000000000 +0000
@@ -1,155 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<profiles version="1">
-<profile kind="CodeFormatterProfile" name="eclipse_c++_code_style" version="1">
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_method_declaration" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_for" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_in_empty_block" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.lineSplit" value="100"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_base_types" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.keep_else_statement_on_same_line" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_switchstatements_compare_to_switch" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_brace_in_array_initializer" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_method_declaration_parameters" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_if" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_exception_specification" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_parenthesized_expression" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_base_types" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_body_declarations_compare_to_access_specifier" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_exception_specification" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_template_arguments" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_block" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_method_declaration" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.use_tabs_only_for_leading_indentations" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_labeled_statement" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_case" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_array_initializer" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_enum_declarations" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_expressions_in_array_initializer" value="18"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_declarator_list" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_bracket" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_for" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_prefix_operator" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.tabulation.size" value="3"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_else_in_if_statement" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_enumerator_list" value="48"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_parenthesized_expression" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_parens_in_method_declaration" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_declarator_list" value="16"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_switch" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_parenthesized_expression" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_empty_lines" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_switchstatements_compare_to_cases" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.keep_empty_array_initializer_on_one_line" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_method_declaration" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.put_empty_statement_on_new_line" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_switch" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_cast" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_braces_in_array_initializer" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.brace_position_for_method_declaration" value="next_line"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_while" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_question_in_conditional" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_semicolon" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_angle_bracket_in_template_arguments" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_base_clause" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_breaks_compare_to_cases" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_unary_operator" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_declarator_list" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_arguments_in_method_invocation" value="18"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_while" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_brackets" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_bracket" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_parameters_in_method_declaration" value="18"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_closing_brace_in_array_initializer" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.number_of_empty_lines_to_preserve" value="1"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_method_invocation" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_brace_in_array_initializer" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_semicolon_in_for" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.brace_position_for_block" value="end_of_line"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_conditional" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.brace_position_for_type_declaration" value="end_of_line"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_assignment_operator" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_angle_bracket_in_template_arguments" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_expression_list" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_angle_bracket_in_template_parameters" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.continuation_indentation" value="3"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_expression_list" value="0"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_method_declaration" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_template_parameters" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_default" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_binary_operator" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_conditional_expression" value="16"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_parens_in_method_invocation" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_array_initializer" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_if" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.format_guardian_clause_on_one_line" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_cast" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_access_specifier_compare_to_type_header" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_type_declaration" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_labeled_statement" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.continuation_indentation_for_array_initializer" value="2"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_method_declaration_parameters" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_semicolon_in_for" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_method_invocation" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_body_declarations_compare_to_namespace_header" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_brace_in_block" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_assignment_operator" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_compact_if" value="0"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_array_initializer" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_at_end_of_file_if_missing" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_template_parameters" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_expression_list" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_question_in_conditional" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_exception_specification" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_binary_operator" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_identifier_in_function_declaration" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_base_clause_in_type_declaration" value="16"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_method_declaration_throws" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_parens_in_exception_specification" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_method_invocation_arguments" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_declaration_compare_to_template_header" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_unary_operator" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_switch" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_statements_compare_to_body" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_method_declaration_throws" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indent_statements_compare_to_block" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_template_arguments" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_catch_in_try_statement" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.alignment_for_throws_clause_in_method_declaration" value="18"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_method_invocation" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_paren_in_cast" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_catch" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_angle_bracket_in_template_parameters" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.tabulation.char" value="space"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_angle_bracket_in_template_parameters" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_while" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_method_invocation_arguments" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.brace_position_for_block_in_case" value="end_of_line"/>
-<setting id="org.eclipse.cdt.core.formatter.compact_else_if" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_postfix_operator" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_base_clause" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_after_template_declaration" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_catch" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.keep_then_statement_on_same_line" value="true"/>
-<setting id="org.eclipse.cdt.core.formatter.brace_position_for_switch" value="end_of_line"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_if" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_switch" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.keep_imple_if_on_one_line" value="false"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_after_opening_brace_in_array_initializer" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.indentation.size" value="3"/>
-<setting id="org.eclipse.cdt.core.formatter.brace_position_for_namespace_declaration" value="end_of_line"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_conditional" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_enum_declarations" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_prefix_operator" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_angle_bracket_in_template_arguments" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.brace_position_for_array_initializer" value="end_of_line"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_case" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_catch" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_namespace_declaration" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_postfix_operator" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_bracket" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_while_in_do_statement" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_for" value="do not insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_angle_bracket_in_template_parameters" value="insert"/>
-<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_angle_bracket_in_template_arguments" value="do not insert"/>
-</profile>
-</profiles>
diff -pruN 5.12.4-1/build_scripts/iwyu/boost.imp 5.13.0-1/build_scripts/iwyu/boost.imp
--- 5.12.4-1/build_scripts/iwyu/boost.imp	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/iwyu/boost.imp	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-[
-{ symbol: ["std::stringstream", "private", "<sstream>", "public"] },
-
-{ include: ["@<boost/date_time/posix_time/.*>",    "public", "<boost/date_time/posix_time/posix_time.hpp>",       "public"] },
-{ include: ["@<boost/date_time/posix_time/.*>",    "public", "<boost/date_time/posix_time/posix_time_types.hpp>", "public"] },
-
-{ include : ["<boost/preprocessor/comparison/not_equal.hpp>",          "private", "<boost/test/unit_test.hpp>",      "public"] },  
-{ include : ["<boost/preprocessor/control/iif.hpp>",                   "private", "<boost/test/unit_test.hpp>",      "public"] },      
-{ include : ["<boost/preprocessor/logical/bool.hpp>",                  "private", "<boost/test/unit_test.hpp>",      "public"] },                      
-{ include : ["<boost/preprocessor/logical/compl.hpp>",                 "private", "<boost/test/unit_test.hpp>",      "public"] },                       
-{ include : ["<boost/test/tools/old/interface.hpp>",                   "private", "<boost/test/unit_test.hpp>",      "public"] },                        
-{ include : ["<boost/test/unit_test_suite.hpp>",                       "private", "<boost/test/unit_test.hpp>",      "public"] },                            
-{ include : ["<boost/test/utils/basic_cstring/basic_cstring.hpp>",     "private", "<boost/test/unit_test.hpp>",      "public"] },           
-{ include : ["<boost/test/utils/basic_cstring/basic_cstring_fwd.hpp>", "private", "<boost/test/unit_test.hpp>",      "public"] },      
-{ include : ["<boost/test/utils/lazy_ostream.hpp>",                    "private", "<boost/test/unit_test.hpp>",      "public"] },      
-
-{ include: ["@<boost/bind/.*>", private, "<boost/bind.hpp>", public ] },
-{ include: ["@<boost/format/.*>", private, "<boost/format.hpp>", public ] },
-{ include: ["@<boost/filesystem/.*>", private, "<boost/filesystem.hpp>", public ] },
-{ include: ["@<boost/function/.*>", private, "<boost/function.hpp>", public ] }
-
-]                
-                                
\ No newline at end of file
diff -pruN 5.12.4-1/build_scripts/mac.sh 5.13.0-1/build_scripts/mac.sh
--- 5.12.4-1/build_scripts/mac.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/mac.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,258 +0,0 @@
-#/bin/bash
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-# GDB setup:
-# https://www.thomasvitale.com/how-to-setup-gdb-and-eclipse-to-debug-c-files-on-macos-sierra/
-#
-# Using lldb-mi debugger
-#https://wiki.eclipse.org/CDT/User/FAQ#How_do_I_get_the_LLDB_debugger.3F
-#
-
-# ====================================================================
-show_error_and_exit() {
-   echo "mac.sh expects at least one argument"
-   echo " mac.sh [ options] "
-   echo ""
-   echo "   debug          - make a DEBUG build"
-   echo "   make           - run make after cmake"
-   echo "   test           - enable all tests"
-   echo "   gcc            - use gcc instead of clang(default)"
-   echo "   no_test        - disable all tests"
-   echo "   xcode          - enable xcode project"
-   echo "   ctest          - all ctest -R <test> -V"
-   echo "   clang          - build with clang compiler"
-   echo "   shared         - build with shared boost libs"
-   echo "   no_gui         - Don't build the gui"
-   echo "   no_ssl         - build without using openssl"
-   echo "   log            - enable debug output"
-   exit 1
-}
-
-# ====================================================================================
-# Build type to Release    
-mode_arg=release
-compiler=clang
-
-no_test_arg=
-make_arg=
-shared_arg=
-test_arg=
-ctest_arg=
-no_gui_arg=
-no_ssl_arg=
-log_arg=
-clean_arg=
-install_arg=
-asan_arg=
-msan_arg=
-ubsan_arg=
-xcode_arg=
-
-
-while [[ "$#" != 0 ]] ; do   
-
-   if [[ "$1" = debug || "$1" = release ]] ; then
-      mode_arg=$1
-   elif  [[ "$1" = make ]] ; then
-      make_arg=$1
-      shift
-      while [[ "$#" != 0 ]] ; do
-         make_arg="$make_arg $1"
-         shift
-      done
-      break
-   elif [[ "$1" = clean ]] ;   then clean_arg=$1 ;
-   elif [[ "$1" = install ]] ; then install_arg=$1 ;
-   elif [[ "$1" = shared ]] ;  then shared_arg=$1 ;
-   elif [[ "$1" = gcc ]] ;     then compiler=$1 ;
-   elif [[ "$1" = clang ]] ;   then compiler=$1 ;
-   elif [[ "$1" = no_gui ]] ;  then no_gui_arg=$1 ;
-   elif [[ "$1" = no_ssl ]] ;  then no_ssl_arg=$1 ;
-   elif [[ "$1" = log ]]   ;   then log_arg=$1 ;
-   elif [[ "$1" = test ]] ;    then test_arg=$1 ;
-   elif [[ "$1" = asan ]]  ;   then asan_arg=$1 ;
-   elif [[ "$1" = msan ]]  ;   then msan_arg=$1 ;
-   elif [[ "$1" = ubsan ]]  ;  then ubsan_arg=$1 ;
-   elif [[ "$1" = no_test ]]  ;  then no_test_arg=$1 ;
-   elif [[ "$1" = xcode ]]  ;  then xcode_arg=$1 ;
-   elif [[ "$1" = ctest ]] ;   then  
-      ctest_arg=$1 ; 
-      shift
-      while [[ "$#" != 0 ]] ; do
-         ctest_arg="$ctest_arg $1"
-         shift
-      done
-      break
-   else
-     show_error_and_exit
-   fi
-
-   # shift remove last argument
-   shift
-done
-
-
-# ====================================================================================
-# default to Release  
-cmake_build_type=
-if [[ $mode_arg = debug ]] ; then
-    cmake_build_type=Debug
-else
-    cmake_build_type=Release
-fi
-
-CXX_FLAGS="-fvisibility=hidden -fvisibility-inlines-hidden -Wno-deprecated-declarations"
-CXX_LINK_FLAGS=""
-
-cmake_extra_options=""
-if [[ "$compiler" = clang ]] ; then
-    # relies on brew install
-    # brew install cmake
-    # brew install qt
-    #
-    # the brew version of boost was built with -fvisibility=hidden -fvisibility-inlines-hidden
-    # We need same flags, otherwise large warning messages
-    # brew install boost
-    # brew install boost-python3
-    #
-    # https://medium.com/@timmykko/using-openssl-library-with-macos-sierra-7807cfd47892
-    # brew install openssl  # however this may not set the right links
-    #
-    # Do the following if config steps fails with cannot find openssl
-    # ln -s /usr/local/opt/openssl/include/openssl /usr/local/include
-    #
-    # ln -s /usr/local/opt/openssl/lib/libssl.1.1.1.dylib /usr/local/lib/
-    #
-    # to list the clang default system search path use:
-    # clang -x c -v -E /dev/null
-   cmake_extra_options="$cmake_extra_options -DBOOST_ROOT=/usr/local"
-   CXX_FLAGS="$CXX_FLAGS -ftemplate-depth=512"
-else
-   # brew install gcc
-   # manually installed boost, built with brew gcc
-   # If you get errors like:
-   #   dyld: Symbol not found: ___emutls_get_address
-   #   Referenced from: /usr/local/opt/gcc/lib/gcc/10/libstdc++.6.dylib
-   #   Expected in: /usr/lib/libSystem.B.dylib
-   # then try:
-   #   brew link --overwrite gcc
-   cmake_extra_options="$cmake_extra_options -DBOOST_ROOT=${HOME}/boost/boost_1_73_0"
-   cmake_extra_options="$cmake_extra_options -DCMAKE_C_COMPILER=/usr/local/opt/gcc@10/bin/gcc-10"
-   cmake_extra_options="$cmake_extra_options -DCMAKE_CXX_COMPILER=/usr/local/opt/gcc@10/bin/g++-10"
-fi
-
-if [[ "$asan_arg" = asan ]] ; then
-
-   CXX_FLAGS="$CXX_FLAGS -fsanitize=address -fno-omit-frame-pointer"
-   CXX_LINK_FLAGS="$CXX_LINK_FLAGS -fsanitize=address"
-   export ECF_TEST_SANITIZER_AS=1  # enable address sanitizer tests
-   
-   #cmake_extra_options="$cmake_extra_options -CMAKE_CXX_LINK_EXECUTABLE= "
-   #cmake -DCMAKE_LINKER=/path/to/linker -DCMAKE_CXX_LINK_EXECUTABLE="<CMAKE_LINKER> <FLAGS> <CMAKE_CXX_LINK_FLAGS> <LINK_FLAGS> <OBJECTS> -o <TARGET> <LINK_LIBRARIES>"
-   #cmake_extra_options="$cmake_extra_options -DCMAKE_BUILD_TYPE=ASAN"
-   cmake_extra_options="$cmake_extra_options -DCMAKE_LINKER=/Library/Developer/CommandLineTools/usr/bin/clang"
-fi
-if [[ "$ubsan_arg" = ubsan ]] ; then
-   #CXX_FLAGS="$CXX_FLAGS -fsanitize=undefined -fsanitize-minimal-runtime -fno-omit-frame-pointer -fno-sanitize-recover=all" # exit after all errors minimal info
-   #CXX_FLAGS="$CXX_FLAGS -fsanitize=undefined -fno-omit-frame-pointer -fno-sanitize-recover=all"                           # exit on first error, max info
-   CXX_FLAGS="$CXX_FLAGS -fsanitize=undefined -fno-omit-frame-pointer"                                                     # report error, max info, no exit on error
-   CXX_LINK_FLAGS="$CXX_LINK_FLAGS -fsanitize=undefined"
-   export ECF_TEST_SANITIZER_UB=1  # enable undefined behaviour tests
-   cmake_extra_options="$cmake_extra_options -DCMAKE_LINKER=/Library/Developer/CommandLineTools/usr/bin/clang"
-fi
-if [[ "$msan_arg" = msan ]] ; then
-   CXX_FLAGS="$CXX_FLAGS -fsanitize=memory -fno-omit-frame-pointer -fsanitize-memory-track-origins"
-   CXX_LINK_FLAGS="$CXX_LINK_FLAGS -fsanitize=memory"
-   cmake_extra_options="$cmake_extra_options -DCMAKE_LINKER=/Library/Developer/CommandLineTools/usr/bin/clang"
-fi
-
-
-if [[ "$shared_arg" = shared ]] ; then
-   cmake_extra_options="$cmake_extra_options -DENABLE_STATIC_BOOST_LIBS=OFF"
-fi
-
-if [[ "$no_test_arg" = no_test ]] ; then
-   cmake_extra_options="$cmake_extra_options -DENABLE_TESTS=OFF"
-fi
-
-log_options=
-if [[ $log_arg = log ]] ; then
-    log_options="-DECBUILD_LOG_LEVEL=DEBUG"
-fi
-
-gui_options=
-if [[ $no_gui_arg = no_gui ]] ; then
-    gui_options="-DENABLE_UI=OFF"
-fi
-
-ssl_options="-DOPENSSL_ROOT_DIR=/usr/local/opt/openssl"
-if [[ $no_ssl_arg = no_ssl ]] ; then
-    ssl_options="-DENABLE_SSL=OFF"
-fi
-
-test_options=
-if [[ $test_arg = test ]] ; then
-   test_options="-DENABLE_ALL_TESTS=ON"
-fi
-
-bdir_root=${HOME}/git/ecflow/bdir
-
-if [[ "$xcode_arg" = xcode ]] ; then
-   cmake_extra_options="$cmake_extra_options -GXcode"
-   bdir_root=${HOME}/git/ecflow/bdir_xcode
-fi
-
-bdir=${bdir_root}/$mode_arg/$compiler
-
-if [[ $clean_arg = clean ]] ; then
-   rm -rf ${bdir_root}
-fi
-mkdir -p $bdir
-cd $bdir
-
-if [[ "$ctest_arg" != "" ]] ; then
-
-    if [[ "$asan_arg" = asan ]] ; then
-      ASAN_OPTIONS=detect_leaks=1
-    fi
-    
-    $ctest_arg 
-    exit 0
-fi
-
-
-# ====================================================================================
-# Use for local install
-version=$(awk '/^project/ && /ecflow/ && /VERSION/ {for (I=1;I<=NF;I++) if ($I == "VERSION") {print $(I+1)};}' ${HOME}/git/ecflow/CMakeLists.txt) 
-#echo $version
-
-# ====================================================================================
-# default to install in $HOME/install, otherwise if install passed, /usr/local/opt  
-install_prefix=${HOME}/install/ecflow/${version}
-if [[ $install_arg = install ]] ; then
-    install_prefix=/usr/local/opt/ecflow/${version}
-fi
-
-cmake ${HOME}/git/ecflow \
-      -DCMAKE_MODULE_PATH=${HOME}/git/ecbuild/cmake \
-      -DCMAKE_CXX_FLAGS="$CXX_FLAGS" \
-      -DCMAKE_EXE_LINKER_FLAGS="$CXX_LINK_FLAGS" \
-      -DCMAKE_BUILD_TYPE=$cmake_build_type \
-      -DCMAKE_PREFIX_PATH=/usr/local/opt/qt \
-      -DCMAKE_INSTALL_PREFIX=${install_prefix} \
-      ${cmake_extra_options} \
-      ${gui_options} \
-      ${ssl_options} \
-      ${log_options} \
-      ${test_options}  
-      
-# =============================================================================================
-if [[ "$make_arg" != "" ]] ; then
-    $make_arg 
-fi
-
diff -pruN 5.12.4-1/build_scripts/massif.sh 5.13.0-1/build_scripts/massif.sh
--- 5.12.4-1/build_scripts/massif.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/massif.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,33 +0,0 @@
-#!/bin/sh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-cd $WK
-
-# if argument is release test the release version else stick with debug
-mode=debug
-if test "$1" = release
-then
-   mode=release
-fi
-
-
-compiler=gcc-$(gcc -dumpversion)
-echo "valgrind: variant=$mode compiler=$compiler"
-
-valgrind --tool=massif ACore/bin/$compiler/$mode/u_acore
-valgrind --tool=massif ANattr/bin/$compiler/$mode/u_anattr
-valgrind --tool=massif ANode/bin/$compiler/$mode/u_anode
-valgrind --tool=massif ANode/parser/bin/$compiler/$mode/u_aparser
-valgrind --tool=massif Base/bin/$compiler/$mode/u_base
-valgrind --tool=massif Client/bin/$compiler/$mode/s_client
-valgrind --tool=massif Server/bin/$compiler/$mode/u_server
-valgrind --tool=massif Test/bin/$compiler/$mode/s_test
-valgrind --tool=massif Simulator/bin/$compiler/$mode/c_csim
-#valgrind --tool=massif ANode/parser/bin/$compiler/$mode/perf_aparser
-
diff -pruN 5.12.4-1/build_scripts/migrate.sh 5.13.0-1/build_scripts/migrate.sh
--- 5.12.4-1/build_scripts/migrate.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/migrate.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-
-
-prepare_migration() {
-   module load ecflow
-   while read nick host port
-   do
-     LOG="--host=$host --port=$port"
-     ecflow_client $LOG --ping || continue
-     version=$(ecflow_client $LOG --server_version)
-     echo $nick $host $port $version
-     /usr/local/apps/ecflow/$version/bin/ecflow_client $LOG --migrate > $host.$port.mig
-   done < /usr/local/apps/ecflow/current/lib/servers
-}
-
-prepare_migration
diff -pruN 5.12.4-1/build_scripts/profile.sh 5.13.0-1/build_scripts/profile.sh
--- 5.12.4-1/build_scripts/profile.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/profile.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,59 +0,0 @@
-#!/bin/sh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-# will run gprof
-
-echo "building profile versions";
-cd $WK
-bjam -j2 -q variant=profile
-
- 
-compiler=gcc-$(gcc -dumpversion)
-echo "gprof: variant=profile compiler=$compiler"
-
-#
-cd $WK/ACore
-bin/$compiler/profile/u_acore
-gprof bin/$compiler/profile/u_acore   gmon.out   >   gprof.out
-
-cd $WK/ANattr
-bin/$compiler/profile/u_anattr
-gprof bin/$compiler/profile/u_anattr gmon.out   >   gprof.out
-
-cd $WK/ANode
-bin/$compiler/profile/u_anode
-gprof bin/$compiler/profile/u_anode gmon.out   >   gprof.out
-
-cd $WK/ANode/parser
-bin/$compiler/profile/u_aparser
-gprof bin/$compiler/profile/u_aparser gmon.out   >   gprof.out
-
-cd $WK/Base
-bin/$compiler/profile/u_base
-gprof bin/$compiler/profile/u_base gmon.out   >   gprof.out
-
-cd $WK/Client
-bin/$compiler/profile/s_client
-gprof bin/$compiler/profile/s_client gmon.out   >   gprof.out
-
-cd $WK/Server
-bin/$compiler/profile/u_server
-gprof bin/$compiler/profile/u_server gmon.out   >   gprof.out
-
-cd $WK/Test
-bin/$compiler/profile/test
-gprof bin/$compiler/profile/test gmon.out   >   gprof.out
-
-cd $WK/CSim
-bin/$compiler/profile/c_csim
-gprof bin/$compiler/profile/c_csim gmon.out   >   gprof.out
-
-cd $WK/ANode/parser
-bin/$compiler/profile/perf_aparser
-gprof bin/$compiler/profile/perf_aparser gmon.out   >   gprof.out
diff -pruN 5.12.4-1/build_scripts/rmbin.sh 5.13.0-1/build_scripts/rmbin.sh
--- 5.12.4-1/build_scripts/rmbin.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/rmbin.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,22 +0,0 @@
-#!/bin/sh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-cd $WK
- 
-rm -rf ACore/bin
-rm -rf ANattr/bin
-rm -rf ANode/bin 
-rm -rf ANode/parser/bin 
-rm -rf Base/bin
-rm -rf CSim/bin
-rm -rf Client/bin 
-rm -rf Server/bin 
-rm -rf Test/bin
-rm -rf Pyext/bin 
-   
\ No newline at end of file
diff -pruN 5.12.4-1/build_scripts/run-clang-tidy.py 5.13.0-1/build_scripts/run-clang-tidy.py
--- 5.12.4-1/build_scripts/run-clang-tidy.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/run-clang-tidy.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,314 +0,0 @@
-#!/usr/bin/env python
-# https://github.com/llvm-mirror/clang-tools-extra/blob/master/clang-tidy/tool/run-clang-tidy.py
-#===- run-clang-tidy.py - Parallel clang-tidy runner ---------*- python -*--===#
-#
-#                     The LLVM Compiler Infrastructure
-#
-# This file is distributed under the University of Illinois Open Source
-# License. See LICENSE.TXT for details.
-#
-#===------------------------------------------------------------------------===#
-# FIXME: Integrate with clang-tidy-diff.py
-# NOTE: Original in: https://github.com/llvm-mirror/clang-tools-extra/blob/master/clang-tidy/tool/run-clang-tidy.py
-
-"""
-Parallel clang-tidy runner
-==========================
-
-Runs clang-tidy over all files in a compilation database. Requires clang-tidy
-and clang-apply-replacements in $PATH.
-
-Example invocations.
-- Run clang-tidy on all files in the current working directory with a default
-  set of checks and show warnings in the cpp files and all project headers.
-    run-clang-tidy.py $PWD
-
-- Fix all header guards.
-    run-clang-tidy.py -fix -checks=-*,llvm-header-guard
-
-- Fix all header guards included from clang-tidy and header guards
-  for clang-tidy headers.
-    run-clang-tidy.py -fix -checks=-*,llvm-header-guard extra/clang-tidy \
-                      -header-filter=extra/clang-tidy
-
-Compilation database setup:
-http://clang.llvm.org/docs/HowToSetupToolingForLLVM.html
-"""
-
-from __future__ import print_function
-
-import argparse
-import glob
-import json
-import multiprocessing
-import os
-import re
-import shutil
-import subprocess
-import sys
-import tempfile
-import threading
-import traceback
-import yaml
-
-is_py2 = sys.version[0] == '2'
-
-if is_py2:
-    import Queue as queue
-else:
-    import queue as queue
-
-def find_compilation_database(path):
-  """Adjusts the directory until a compilation database is found."""
-  result = './'
-  while not os.path.isfile(os.path.join(result, path)):
-    if os.path.realpath(result) == '/':
-      print('Error: could not find compilation database.')
-      sys.exit(1)
-    result += '../'
-  return os.path.realpath(result)
-
-
-def make_absolute(f, directory):
-  if os.path.isabs(f):
-    return f
-  return os.path.normpath(os.path.join(directory, f))
-
-
-def get_tidy_invocation(f, clang_tidy_binary, checks, tmpdir, build_path,
-                        header_filter, extra_arg, extra_arg_before, quiet,
-                        config):
-  """Gets a command line for clang-tidy."""
-  start = [clang_tidy_binary]
-  if header_filter is not None:
-    start.append('-header-filter=' + header_filter)
-  else:
-    # Show warnings in all in-project headers by default.
-    start.append('-header-filter=^' + build_path + '/.*')
-  if checks:
-    start.append('-checks=' + checks)
-  if tmpdir is not None:
-    start.append('-export-fixes')
-    # Get a temporary file. We immediately close the handle so clang-tidy can
-    # overwrite it.
-    (handle, name) = tempfile.mkstemp(suffix='.yaml', dir=tmpdir)
-    os.close(handle)
-    start.append(name)
-  for arg in extra_arg:
-      start.append('-extra-arg=%s' % arg)
-  for arg in extra_arg_before:
-      start.append('-extra-arg-before=%s' % arg)
-  start.append('-p=' + build_path)
-  if quiet:
-      start.append('-quiet')
-  if config:
-      start.append('-config=' + config)
-  start.append(f)
-  return start
-
-
-def merge_replacement_files(tmpdir, mergefile):
-  """Merge all replacement files in a directory into a single file"""
-  # The fixes suggested by clang-tidy >= 4.0.0 are given under
-  # the top level key 'Diagnostics' in the output yaml files
-  mergekey="Diagnostics"
-  merged=[]
-  for replacefile in glob.iglob(os.path.join(tmpdir, '*.yaml')):
-    content = yaml.safe_load(open(replacefile, 'r'))
-    if not content:
-      continue # Skip empty files.
-    merged.extend(content.get(mergekey, []))
-
-  if merged:
-    # MainSourceFile: The key is required by the definition inside
-    # include/clang/Tooling/ReplacementsYaml.h, but the value
-    # is actually never used inside clang-apply-replacements,
-    # so we set it to '' here.
-    output = { 'MainSourceFile': '', mergekey: merged }
-    with open(mergefile, 'w') as out:
-      yaml.safe_dump(output, out)
-  else:
-    # Empty the file:
-    open(mergefile, 'w').close()
-
-
-def check_clang_apply_replacements_binary(args):
-  """Checks if invoking supplied clang-apply-replacements binary works."""
-  try:
-    subprocess.check_call([args.clang_apply_replacements_binary, '--version'])
-  except:
-    print('Unable to run clang-apply-replacements. Is clang-apply-replacements '
-          'binary correctly specified?', file=sys.stderr)
-    traceback.print_exc()
-    sys.exit(1)
-
-
-def apply_fixes(args, tmpdir):
-  """Calls clang-apply-fixes on a given directory."""
-  invocation = [args.clang_apply_replacements_binary]
-  if args.format:
-    invocation.append('-format')
-  if args.style:
-    invocation.append('-style=' + args.style)
-  invocation.append(tmpdir)
-  subprocess.call(invocation)
-
-
-def run_tidy(args, tmpdir, build_path, queue, failed_files):
-  """Takes filenames out of queue and runs clang-tidy on them."""
-  while True:
-    name = queue.get()
-    invocation = get_tidy_invocation(name, args.clang_tidy_binary, args.checks,
-                                     tmpdir, build_path, args.header_filter,
-                                     args.extra_arg, args.extra_arg_before,
-                                     args.quiet, args.config)
-    sys.stdout.write(' '.join(invocation) + '\n')
-    return_code = subprocess.call(invocation)
-    if return_code != 0:
-      failed_files.append(name)
-    queue.task_done()
-
-
-def main():
-  parser = argparse.ArgumentParser(description='Runs clang-tidy over all files '
-                                   'in a compilation database. Requires '
-                                   'clang-tidy and clang-apply-replacements in '
-                                   '$PATH.')
-  parser.add_argument('-clang-tidy-binary', metavar='PATH',
-                      default='clang-tidy',
-                      help='path to clang-tidy binary')
-  parser.add_argument('-clang-apply-replacements-binary', metavar='PATH',
-                      default='clang-apply-replacements',
-                      help='path to clang-apply-replacements binary')
-  parser.add_argument('-checks', default=None,
-                      help='checks filter, when not specified, use clang-tidy '
-                      'default')
-  parser.add_argument('-config', default=None,
-                      help='Specifies a configuration in YAML/JSON format: '
-                      '  -config="{Checks: \'*\', '
-                      '                       CheckOptions: [{key: x, '
-                      '                                       value: y}]}" '
-                      'When the value is empty, clang-tidy will '
-                      'attempt to find a file named .clang-tidy for '
-                      'each source file in its parent directories.')
-  parser.add_argument('-header-filter', default=None,
-                      help='regular expression matching the names of the '
-                      'headers to output diagnostics from. Diagnostics from '
-                      'the main file of each translation unit are always '
-                      'displayed.')
-  parser.add_argument('-export-fixes', metavar='filename', dest='export_fixes',
-                      help='Create a yaml file to store suggested fixes in, '
-                      'which can be applied with clang-apply-replacements.')
-  parser.add_argument('-j', type=int, default=0,
-                      help='number of tidy instances to be run in parallel.')
-  parser.add_argument('files', nargs='*', default=['.*'],
-                      help='files to be processed (regex on path)')
-  parser.add_argument('-fix', action='store_true', help='apply fix-its')
-  parser.add_argument('-format', action='store_true', help='Reformat code '
-                      'after applying fixes')
-  parser.add_argument('-style', default='file', help='The style of reformat '
-                      'code after applying fixes')
-  parser.add_argument('-p', dest='build_path',
-                      help='Path used to read a compile command database.')
-  parser.add_argument('-extra-arg', dest='extra_arg',
-                      action='append', default=[],
-                      help='Additional argument to append to the compiler '
-                      'command line.')
-  parser.add_argument('-extra-arg-before', dest='extra_arg_before',
-                      action='append', default=[],
-                      help='Additional argument to prepend to the compiler '
-                      'command line.')
-  parser.add_argument('-quiet', action='store_true',
-                      help='Run clang-tidy in quiet mode')
-  args = parser.parse_args()
-
-  db_path = 'compile_commands.json'
-
-  if args.build_path is not None:
-    build_path = args.build_path
-  else:
-    # Find our database
-    build_path = find_compilation_database(db_path)
-
-  try:
-    invocation = [args.clang_tidy_binary, '-list-checks']
-    invocation.append('-p=' + build_path)
-    if args.checks:
-      invocation.append('-checks=' + args.checks)
-    invocation.append('-')
-    subprocess.check_call(invocation)
-  except:
-    print("Unable to run clang-tidy.", file=sys.stderr)
-    sys.exit(1)
-
-  # Load the database and extract all files.
-  database = json.load(open(os.path.join(build_path, db_path)))
-  files = [make_absolute(entry['file'], entry['directory'])
-           for entry in database]
-
-  max_task = args.j
-  if max_task == 0:
-    max_task = multiprocessing.cpu_count()
-
-  tmpdir = None
-  if args.fix or args.export_fixes:
-    check_clang_apply_replacements_binary(args)
-    tmpdir = tempfile.mkdtemp()
-
-  # Build up a big regexy filter from all command line arguments.
-  file_name_re = re.compile('|'.join(args.files))
-
-  return_code = 0
-  try:
-    # Spin up a bunch of tidy-launching threads.
-    task_queue = queue.Queue(max_task)
-    # List of files with a non-zero return code.
-    failed_files = []
-    for _ in range(max_task):
-      t = threading.Thread(target=run_tidy,
-                           args=(args, tmpdir, build_path, task_queue, failed_files))
-      t.daemon = True
-      t.start()
-
-    # Fill the queue with files.
-    for name in files:
-      if file_name_re.search(name):
-        task_queue.put(name)
-
-    # Wait for all threads to be done.
-    task_queue.join()
-    if len(failed_files):
-      return_code = 1
-
-  except KeyboardInterrupt:
-    # This is a sad hack. Unfortunately subprocess goes
-    # bonkers with ctrl-c and we start forking merrily.
-    print('\nCtrl-C detected, goodbye.')
-    if tmpdir:
-      shutil.rmtree(tmpdir)
-    os.kill(0, 9)
-
-  if args.export_fixes:
-    print('Writing fixes to ' + args.export_fixes + ' ...')
-    try:
-      merge_replacement_files(tmpdir, args.export_fixes)
-    except:
-      print('Error exporting fixes.\n', file=sys.stderr)
-      traceback.print_exc()
-      return_code=1
-
-  if args.fix:
-    print('Applying fixes ...')
-    try:
-      apply_fixes(args, tmpdir)
-    except:
-      print('Error applying fixes.\n', file=sys.stderr)
-      traceback.print_exc()
-      return_code=1
-
-  if tmpdir:
-    shutil.rmtree(tmpdir)
-  sys.exit(return_code)
-
-if __name__ == '__main__':
-  main()
\ No newline at end of file
diff -pruN 5.12.4-1/build_scripts/shell_client.sh 5.13.0-1/build_scripts/shell_client.sh
--- 5.12.4-1/build_scripts/shell_client.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/shell_client.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-#!/bin/sh
-
-function meter_payload() {
-   # $1 path_to_task
-   # $2 password
-   # $3 process_id
-   # $4 try no
-   # $5 meter_name
-   # $6 meter value
-   
-    boost_preamble="22 serialization::archive 10 0 0 0 1 2"
-    meter_cmd="8 MeterCmd 1 0 0 0 0 0 0"
-    
-    path_to_task=$1
-    password=$2
-    process_id=$3
-    try_no=$4
-    meter_name=$5
-    meter_value=$6
-    
-    path_to_task_size=$(echo ${#path_to_task}) 
-    password_size=$(expr length  $password  )  
-    process_id_size=$(expr length  $process_id )  
-    meter_name_size=$(expr length  $meter_name )  
-    
-    data="$boost_preamble $meter_cmd $path_to_task_size $path_to_task $password_size $password $process_id_size $process_id $try_no $meter_name_size $meter_name $meter_value"
-    header=$(printf '%8.8s' $(echo "obase=16; ${#data}" | bc) )
-     
-    payload=$header$data
-    return "$payload"
-}
-
-path_to_task="/all_trigger_examples/a"
-password="F5Q0eiJu"
-process_id="24053"
-try_no="1"
-meter_name=METER
-meter_value="10"
-
-payload=$(meter_payload $path_to_task $password $process_id $try_no $meter_name $meter_value)
-echo "$payload"
diff -pruN 5.12.4-1/build_scripts/test.sh 5.13.0-1/build_scripts/test.sh
--- 5.12.4-1/build_scripts/test.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/test.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,232 +0,0 @@
-#!/bin/sh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-#===================================================================
-# Run all the ecflow tests, note use !/bin/bash to keep rpm happy, it uses bash
-#===================================================================
-
-if [ "$#" -gt 4 ] ; then
-   echo "Maximum of 3 arguments expected"
-   echo " arg1-mode    (optional) default = release  [ release | debug | profile ]"
-   echo " arg2-compiler(optional) default = linux/gcc-$(gcc -dumpversion)"
-   echo " arg3-safe    (optional) default = no  [ no | safe ] safe means only run deterministic tests"
-   echo " arg5-link    (optional) default = static [ static | shared ] use boost static/shared directory to reference tests"
-   echo " arg5-ssl     (optional) default = off [ off | ssl ] ssl means test ssl version of ecflow"
-   exit 1
-fi
-
-link=static
-mode=release
-compiler_arg=
-safe=no
-ssl=off
-while [ "$#" -ne 0 ] ; do   
-   if [ "$1" = debug -o "$1" = release -o "$1" = profile ] ; then
-      mode=$1
-   elif [ "$1" = safe ] ;   then safe=yes ;
-   elif [ "$1" = ssl ] ;    then ssl=on ;
-   elif [ "$1" = shared ] ; then link=shared ;
-   else
-      compiler_arg=$1
-   fi
-   # shift remove last argument
-   shift
-done
-
-if [ ${#mode} -eq 0 ] ; then
-   echo "test expects mode i.e. debug or release"
-   exit 1
-fi
-
-link_dir=
-if [ ${link} = static ] ; then
-   link_dir=/link-static
-fi
-
-echo "mode=$mode compiler=$compiler_arg safe=$safe ssl=$ssl link=$link link_dir=$link_dir"
-
-#======================================================================
-# remove python test, so that they are rerun
-rm -rf Pyext/bin/*.test   
-
-# Remove any lock file create by tests which used EcfPortLock.hpp
-# ** However DO *NOT* remove this locks for in ecflow test.ecf
-# ** as they allow the debug and release test to run at the same time.
-rm -rf *.lock
- 
-# Check that a command is in the PATH.
-test_path ()
-{
-    if `command -v command 1>/dev/null 2>/dev/null`; then
-        command -v $1 1>/dev/null 2>/dev/null
-    else
-        hash $1 1>/dev/null 2>/dev/null
-    fi
-}
-
-# Check that the OS name, as returned by "uname", is as given.
-test_uname ()
-{
-    if test_path uname; then
-        test `uname` = $*
-    fi
-}
-
-unset ECF_PORT
-OPEN_SSL=
-
-if test_uname Linux ; then
-
-   TOOLSET=
-   CXXFLAGS=
-   compiler=gcc-$(gcc -dumpversion)
-   
-   # When on cray check PE_ENV for environment
-   if [ "$PE_ENV" = INTEL -o "$PE_ENV" = CRAY -o "$PE_ENV" = GNU ]
-   then
-       CXXFLAGS=cxxflags=-fPIC
-       TOOLSET=toolset=gcc
-       if [ "$PE_ENV" = INTEL ] ; then
-          compiler=intel-linux
-          TOOLSET=toolset=intel
-       fi
-       if [ "$PE_ENV" = CRAY ] ; then
-          compiler=cray
-          TOOLSET=toolset=cray
-       fi
-   fi   
-   
-   # Allow the compiler to be overridden on linux
-   if [ ${#compiler_arg} -ne 0 ] ; then
-      compiler=$compiler_arg
-   fi
-
-   exe_path=$compiler/${mode}${link_dir}
-   
-   if [ "$ssl" = on ] ; then
-      exe_path="$exe_path/ssl-on"
-      OPEN_SSL="ssl=on"
-   fi
-   
-   echo "*****************************************"
-   echo "Testing: $exe_path"
-   echo "*****************************************"
-
-   ACore/bin/$exe_path/u_acore      --log_level=message $TEST_OPTS
-   ANattr/bin/$exe_path/u_anattr    --log_level=message $TEST_OPTS
-   ANode/bin/$exe_path/u_anode      --log_level=message $TEST_OPTS
-   ANode/parser/bin/$exe_path/u_aparser  --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      ANode/parser/bin/$exe_path/perf_aparser --log_level=message $TEST_OPTS
-   fi
-   Base/bin/$exe_path/u_base         --log_level=message $TEST_OPTS
-   
-   if [ "$safe" = no ] ; then
-      # run python/C++ test
-      cd Pyext
-      $BOOST_ROOT/b2 $TOOLSET "$CXXFLAGS" variant=$mode link=$link $OPEN_SSL test-all $TEST_OPTS
-      cd ..
-   fi
-   
-   Client/bin/$exe_path/s_client     --log_level=message $TEST_OPTS
-   Server/bin/$exe_path/u_server     --log_level=message $TEST_OPTS
-   CSim/bin/$exe_path/c_csim         --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      Test/bin/$exe_path/s_test          --log_level=message $TEST_OPTS
-      Test/bin/$exe_path/s_test_zombies  --log_level=message $TEST_OPTS
-   fi
-   
-elif test_uname Darwin ; then
-
-   TOOLSET=
-   CXXFLAGS=cxxflags="-Wno-deprecated-declarations -Wno-maybe-uninitialized -fvisibility-inlines-hidden -fvisibility=hidden"
-   compiler=gcc-$(/usr/local/opt/gcc@10/bin/gcc-10 -dumpversion)
-   
-   exe_path=$compiler/${mode}${link_dir}
-   
-   echo "*****************************************"
-   echo "Testing: $exe_path"
-   echo "*****************************************"
-
-   ACore/bin/$exe_path/u_acore          --log_level=message $TEST_OPTS
-   ANattr/bin/$exe_path/u_anattr        --log_level=message $TEST_OPTS
-   ANode/bin/$exe_path/u_anode          --log_level=message $TEST_OPTS
-   ANode/parser/bin/$exe_path/u_aparser --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      ANode/parser/bin/$exe_path/perf_aparser --log_level=message $TEST_OPTS
-   fi
-   Base/bin/$exe_path/u_base         --log_level=message $TEST_OPTS
-   
-   if [ "$safe" = no ] ; then
-      # run python/C++ test
-      cd Pyext
-      $BOOST_ROOT/b2 $TOOLSET "$CXXFLAGS" variant=$mode link=$link $OPEN_SSL test-all $TEST_OPTS
-      cd ..
-   fi
-   
-   Client/bin/$exe_path/s_client     --log_level=message $TEST_OPTS
-   Server/bin/$exe_path/u_server     --log_level=message $TEST_OPTS
-   CSim/bin/$exe_path/c_csim         --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      Test/bin/$exe_path/s_test          --log_level=message $TEST_OPTS
-      Test/bin/$exe_path/s_test_zombies  --log_level=message $TEST_OPTS
-   fi
-   
-elif test_uname HP-UX ; then
-
-   echo "Testing: variant=$mode"
-   ACore/bin/acc/$mode/threading-multi/u_acore  --log_level=message $TEST_OPTS
-   ANattr/bin/acc/$mode/threading-multi/u_anattr  --log_level=message $TEST_OPTS
-   ANode/bin/acc/$mode/threading-multi/u_anode  --log_level=message $TEST_OPTS
-   ANode/parser/bin/acc/$mode/threading-multi/u_aparser  --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      ANode/parser/bin/acc/$mode/threading-multi/perf_aparser  --log_level=message $TEST_OPTS
-   fi
-   Base/bin/acc/$mode/threading-multi/u_base  --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      # run python/C++ test, use test to bypass 'with' statement tests
-      cd Pyext
-      $BOOST_ROOT/b2 variant=$mode test $TEST_OPTS
-      cd ..
-   fi
-   exit 1
-   Client/bin/acc/$mode/threading-multi/s_client  --log_level=message $TEST_OPTS
-   Server/bin/acc/$mode/threading-multi/u_server  --log_level=message $TEST_OPTS
-   CSim/bin/acc/$mode/threading-multi/c_csim  --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      Test/bin/acc/$mode/threading-multi/s_test  --log_level=message $TEST_OPTS
-      Test/bin/acc/$mode/threading-multi/s_test_zombies  --log_level=message $TEST_OPTS
-   fi
-   
-elif test_uname AIX ; then
-
-   echo "Testing: $ARCH variant=$mode"
-   
-   ACore/bin/vacpp/$mode/threading-multi/u_acore  --log_level=message $TEST_OPTS
-   ANattr/bin/vacpp/$mode/threading-multi/u_anattr  --log_level=message $TEST_OPTS
-   ANode/bin/vacpp/$mode/threading-multi/u_anode  --log_level=message $TEST_OPTS
-   ANode/parser/bin/vacpp/$mode/threading-multi/u_aparser  --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      ANode/parser/bin/vacpp/$mode/threading-multi/perf_aparser  --log_level=message $TEST_OPTS
-   fi
-   Base/bin/vacpp/$mode/threading-multi/u_base  --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      # run python/C++ test
-      cd Pyext
-      $BOOST_ROOT/b2 variant=$mode test-all $TEST_OPTS
-      cd ..
-   fi
-   Client/bin/vacpp/$mode/threading-multi/s_client  --log_level=message $TEST_OPTS
-   Server/bin/vacpp/$mode/threading-multi/u_server  --log_level=message $TEST_OPTS
-   CSim/bin/vacpp/$mode/threading-multi/c_csim  --log_level=message $TEST_OPTS
-   if [ "$safe" = no ] ; then
-      Test/bin/vacpp/$mode/threading-multi/s_test  --log_level=message $TEST_OPTS
-      Test/bin/vacpp/$mode/threading-multi/s_test_zombies  --log_level=message $TEST_OPTS
-   fi
-fi
diff -pruN 5.12.4-1/build_scripts/val.sh 5.13.0-1/build_scripts/val.sh
--- 5.12.4-1/build_scripts/val.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/val.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,53 +0,0 @@
-#!/bin/sh
-
-## Copyright 2009- ECMWF.
-## This software is licensed under the terms of the Apache Licence version 2.0 
-## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-## In applying this licence, ECMWF does not waive the privileges and immunities 
-## granted to it by virtue of its status as an intergovernmental organisation 
-## nor does it submit to any jurisdiction. 
-
-# This script will run valgrind on all the automated test
-# Assume WK is defined
-
-#===========================================================================
-# load the latest valgrind
-module load valgrind/3.14.0
-#===========================================================================
-
-cd $WK
-
-# if argument is release test the release version else stick with debug
-mode=debug
-if test "$1" = release
-then
-   mode=release
-fi
-
-compiler=gcc-$(gcc -dumpversion)
-
-echo "valgrind: variant=$mode compiler=$compiler"
-
-#
-# Use valgrind which is newer than standard installation
-#
-# Note: To valgrind the server, start it separately on a different shell and define ECF_HOST=localhost
-# export ECF_HOST=localhost
-# valgrind Server/bin/$compiler/$mode/ecflow_server --interval=3
-# Then restart this shell
-   
-
-# Use the valgrind option --track-origins=yes to have it track the origin of uninitialized values. 
-# This will make it slower and take more memory, but can be very helpful if you need to track down 
-# the origin of an uninitialized value.
-
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ACore/bin/$compiler/$mode/u_acore
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ANattr/bin/$compiler/$mode/u_anattr
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ANode/bin/$compiler/$mode/u_anode
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ANode/parser/bin/$compiler/$mode/u_aparser
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes Base/bin/$compiler/$mode/u_base
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes Client/bin/$compiler/$mode/s_client
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes Server/bin/$compiler/$mode/u_server
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --num-callers=30 --error-exitcode=1 --partial-loads-ok=yes Test/bin/$compiler/$mode/s_test
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --num-callers=30 --error-exitcode=1 --partial-loads-ok=yes Test/bin/$compiler/$mode/s_test_zombies
-valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes CSim/bin/$compiler/$mode/c_csim
diff -pruN 5.12.4-1/build_scripts/wait_for_server_reply.sh 5.13.0-1/build_scripts/wait_for_server_reply.sh
--- 5.12.4-1/build_scripts/wait_for_server_reply.sh	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/build_scripts/wait_for_server_reply.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,22 +0,0 @@
-#!/bin/sh
-
-# wait for server to start
-set +e # ignore error 
-count=0
-while [ 1 ] ; do   
-    sleep 3
-    ecflow_client --ping 2> /dev/null
-    if [[ $? == 0 ]] ; then
-        echo "server up and running"
-        break;
-    fi
-    count=$((count + 1))
-    #echo $count
-    if [ "$count" -gt "2" ] ; then
-        echo "Timed out after 60 seconds"
-        exit 1
-    fi
-done
-set -e  # re-enable error 
-
- 
\ No newline at end of file
diff -pruN 5.12.4-1/cmake/CompilerOptions.cmake 5.13.0-1/cmake/CompilerOptions.cmake
--- 5.12.4-1/cmake/CompilerOptions.cmake	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/cmake/CompilerOptions.cmake	2024-06-20 10:11:46.000000000 +0000
@@ -61,12 +61,18 @@ if (HAVE_WARNINGS)
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:GNU>>:-Wno-deprecated-declarations>
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:GNU>>:-Wno-unused-result>
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:GNU>>:-Wno-unused-parameter>
-    ## Clang (MacOS AppleClang + Homebrew, AMD Clang-base)
+    ## Clang (MacOS Homebrew, AMD Clang-base)
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:Clang>>:-Wno-deprecated-copy-with-user-provided-copy> # silence warnings in Qt5 related headers
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:Clang>>:-Wno-deprecated-declarations>
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:Clang>>:-Wno-missing-field-initializers> # silence warning in Boost.Python related headers
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:Clang>>:-Wno-overloaded-virtual>
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:Clang>>:-Wno-unused-parameter>
+    ## Clang (MacOS AppleClang)
+    $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:AppleClang>>:-Wno-deprecated-copy-with-user-provided-copy> # silence warnings in Qt5 related headers
+    $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:AppleClang>>:-Wno-deprecated-declarations>
+    $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:AppleClang>>:-Wno-missing-field-initializers> # silence warning in Boost.Python related headers
+    $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:AppleClang>>:-Wno-overloaded-virtual>
+    $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:AppleClang>>:-Wno-unused-parameter>
     ## Clang (Intel Clang-based)
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:IntelLLVM>>:-Wno-deprecated-copy-with-user-provided-copy> # silence warnings in Qt5 related headers
     $<$<AND:$<COMPILE_LANGUAGE:CXX>,$<CXX_COMPILER_ID:IntelLLVM>>:-Wno-deprecated-declarations>
diff -pruN 5.12.4-1/cmake/FindClangFormat.cmake 5.13.0-1/cmake/FindClangFormat.cmake
--- 5.12.4-1/cmake/FindClangFormat.cmake	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/cmake/FindClangFormat.cmake	2024-06-20 10:11:46.000000000 +0000
@@ -32,13 +32,17 @@
 function(target_clangformat TARGET)
 
   set(options "")
-  set(single_value_args CONDITION)
-  set(multi_value_args "")
+  set(single_value_args "")
+  set(multi_value_args CONDITION)
   cmake_parse_arguments( ARGS "${options}" "${single_value_args}" "${multi_value_args}" ${ARGN} )
 
   # Skip setup if condition supplied and FALSE
-  if (NOT ${ARGS_CONDITION})
-    return()
+  if (DEFINED ARGS_CONDITION)
+    if (${${ARGS_CONDITION}})
+      # Do nothing, just continue
+    else()
+      return()
+    endif()
   endif()
 
   # Skip setup if clang-format is not available...
diff -pruN 5.12.4-1/debian/changelog 5.13.0-1/debian/changelog
--- 5.12.4-1/debian/changelog	2024-04-25 07:19:47.000000000 +0000
+++ 5.13.0-1/debian/changelog	2024-06-24 09:56:34.000000000 +0000
@@ -1,3 +1,9 @@
+ecflow (5.13.0-1) unstable; urgency=medium
+
+  * New upstream release
+
+ -- Alastair McKinstry <mckinstry@debian.org>  Mon, 24 Jun 2024 10:56:34 +0100
+
 ecflow (5.12.4-1) unstable; urgency=medium
 
   * New upstream release
diff -pruN 5.12.4-1/debian/patches/python3.patch 5.13.0-1/debian/patches/python3.patch
--- 5.12.4-1/debian/patches/python3.patch	2024-04-25 07:19:47.000000000 +0000
+++ 5.13.0-1/debian/patches/python3.patch	2024-06-24 09:56:34.000000000 +0000
@@ -3,35 +3,6 @@ Author: Alastair McKinstry <mckinstry@de
 Forwarded: no
 Last-Updated: 2018-10-16
 
---- a/Pyext/script.py
-+++ b/Pyext/script.py
-@@ -7,5 +7,7 @@
- 
- #
- #
--print 'Hello World !'
-+from __future__ import print_function
-+
-+print ('Hello World !')
- number = 42
---- a/Pyext/samples/api/sms2ecf.py
-+++ b/Pyext/samples/api/sms2ecf.py
-@@ -1,5 +1,6 @@
- #!/usr/bin/env python
- """ one module to store needed function to translate SMS-ECFLOW suites """
-+from __future__ import print_function
- import sys
- ECF_MODE = "ecflow" # "sms"
- 
-@@ -54,7 +55,7 @@
-     'SMSLOGTIMEOUT': 'ECF_LOGTIMEOUT',
- }
- 
--DICT_ECF_SMS = dict((v, k) for k, v in DICT_SMS_ECF.items())
-+DICT_ECF_SMS = dict((v, k) for k, v in list(DICT_SMS_ECF.items()))
-       
- def translate(name, value=None):
-     """ find and replace submit, kill and status command, according to
 --- a/tools/ecflow_fuse.py
 +++ b/tools/ecflow_fuse.py
 @@ -1,4 +1,4 @@
diff -pruN 5.12.4-1/debian/patches/reproducible.patch 5.13.0-1/debian/patches/reproducible.patch
--- 5.12.4-1/debian/patches/reproducible.patch	2024-04-25 07:19:47.000000000 +0000
+++ 5.13.0-1/debian/patches/reproducible.patch	2024-06-24 09:56:34.000000000 +0000
@@ -3,14 +3,3 @@ Author: Alastair McKinstry <mckinstry@de
 Last-Updated: 2017-07-11
 Forwarded: no
 
---- a/ACore/src/ecflow/core/Version.cpp
-+++ b/ACore/src/ecflow/core/Version.cpp
-@@ -71,7 +71,7 @@
-     ss << " openssl(enabled)";
- #endif
- 
--    ss << " Compiled on " << __DATE__ << " " << __TIME__;
-+    ss << " Debian build ";
-     return ss.str();
- }
- 
diff -pruN 5.12.4-1/debian/patches/series 5.13.0-1/debian/patches/series
--- 5.12.4-1/debian/patches/series	2024-04-25 07:19:47.000000000 +0000
+++ 5.13.0-1/debian/patches/series	2024-06-24 09:56:34.000000000 +0000
@@ -1,6 +1,6 @@
 perl-interpeter.patch
 hurd.patch
-setsid.patch
+# setsid.patch
 python3.patch
-reproducible.patch
-disable-test.patch
+# reproducible.patch
+# disable-test.patch
diff -pruN 5.12.4-1/docs/CMakeLists.txt 5.13.0-1/docs/CMakeLists.txt
--- 5.12.4-1/docs/CMakeLists.txt	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -58,7 +58,7 @@ add_custom_command(
   COMMAND
     ${CMAKE_COMMAND} -E rm -rf ${CMAKE_CURRENT_BINARY_DIR}/build_python_api/_build
   COMMAND
-    ${CMAKE_COMMAND} -E env "PYTHONPATH=${CMAKE_BINARY_DIR}/Pyext/python3"
+    ${CMAKE_COMMAND} -E env "PYTHONPATH=${CMAKE_BINARY_DIR}/libs/pyext/python3"
         ${SPHINX_EXECUTABLE} -M html
           ${CMAKE_CURRENT_SOURCE_DIR}/build_python_api
           ${CMAKE_CURRENT_BINARY_DIR}/build_python_api/_build
@@ -88,7 +88,7 @@ add_custom_target(ecflow_python_docs DEP
 add_custom_command(
   OUTPUT generate_ecflow_docs
   COMMAND
-    ${CMAKE_COMMAND} -E env "PYTHONPATH=${CMAKE_BINARY_DIR}/Pyext/python3"
+    ${CMAKE_COMMAND} -E env "PYTHONPATH=${CMAKE_BINARY_DIR}/libs/pyext/python3"
       ${SPHINX_EXECUTABLE} -M html
           ${CMAKE_CURRENT_SOURCE_DIR}
           ${CMAKE_CURRENT_BINARY_DIR}/_build
diff -pruN 5.12.4-1/docs/build_python_api/glossary.yaml 5.13.0-1/docs/build_python_api/glossary.yaml
--- 5.12.4-1/docs/build_python_api/glossary.yaml	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/build_python_api/glossary.yaml	2024-06-20 10:11:46.000000000 +0000
@@ -1,6 +1,7 @@
 - active
 - aborted
 - autocancel
+- aviso
 - complete expression
 - check point
 - child command
@@ -25,6 +26,7 @@
 - late
 - limit
 - meter
+- mirror
 - node
 - pre-processing
 - queue
diff -pruN 5.12.4-1/docs/client_api/api/alter.rst 5.13.0-1/docs/client_api/api/alter.rst
--- 5.12.4-1/docs/client_api/api/alter.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/client_api/api/alter.rst	2024-06-20 10:11:46.000000000 +0000
@@ -16,14 +16,15 @@ alter
             one option must be specified
    arg2 = For delete:
             [ variable | time | today | date  | day | cron | event | meter | late | generic | queue |
-              label | trigger | complete | repeat | limit | inlimit | limit_path | zombie ]
+              label | trigger | complete | repeat | limit | inlimit | limit_path | zombie | aviso | mirror ]
           For change:
             [ variable | clock_type | clock_gain | clock_date | clock_sync  | event | meter | label |
-              trigger  | complete   | repeat     | limit_max  | limit_value | defstatus | late | time | today ]
+              trigger  | complete   | repeat     | limit_max  | limit_value | defstatus | late | time |
+              today, aviso, mirror ]
             *NOTE* If the clock is changed, then the suite will need to be re-queued in order for
             the change to take effect fully.
           For add:
-            [ variable | time | today | date | day | zombie | late | limit | inlimit | label ]
+            [ variable | time | today | date | day | zombie | late | limit | inlimit | label | aviso | mirror ]
           For set_flag and clear_flag:
             [ force_aborted | user_edit | task_aborted | edit_failed | ecfcmd_failed 
               statuscmd_failed | killcmd_failed | no_script | killed | status | late | message | 
@@ -32,13 +33,19 @@ alter
           For sort:
             [ event | meter | label | variable| limit | all ]
    arg3 = name/value
-          when changing, attributes like variable,meter,event,label,limits,late
-          we expect arguments to be quoted. For sort this argument can be called 'recursive'
    arg4 = new_value
-          specifies the new value only used for 'change'/'add'
-          values with spaces must be quoted
    arg5 = paths : At least one node path required.The paths must start with a leading '/' character
    
+   When adding or updating attributes, such as variable, meter, event, label, limits, or late,
+     the name (arg3) and value (arg4) must be quoted.
+   
+   When sorting attributes, 'recursive' can be used as the value (arg3)
+   
+   When adding or updating aviso and mirror attributes, the value (arg4) is expected to be a quoted list of
+     configuration options. For example:
+      * for aviso, "--remote_path /s1/f1/t2 --remote_host host --polling 20 --remote_port 3141 --ssl)"
+      * for mirror, "--listener '{ \"event\": \"mars\", \"request\": { \"class\": "od" } }'
+                     --url http://aviso/ --schema /path/to/schema --polling 60"
    
    Usage:
    
diff -pruN 5.12.4-1/docs/conf.py 5.13.0-1/docs/conf.py
--- 5.12.4-1/docs/conf.py	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/conf.py	2024-06-20 10:11:46.000000000 +0000
@@ -93,7 +93,7 @@ rst_prolog = """
 
 
 def get_ecflow_version():
-    version = "5.12.4"
+    version = "5.13.0"
     ecflow_version = version.split(".")
     print("Extracted ecflow version '" + str(ecflow_version))
     return ecflow_version
diff -pruN 5.12.4-1/docs/glossary.rst 5.13.0-1/docs/glossary.rst
--- 5.12.4-1/docs/glossary.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/glossary.rst	2024-06-20 10:11:46.000000000 +0000
@@ -47,6 +47,46 @@
          * - :ref:`grammar`
            - :token:`autocancel`
 
+   aviso
+      An aviso is an attribute of a :term:`Node<node>` (typically a :term:`Task<task>`),
+      and creates a dependency on an external Aviso server.
+
+      A :term:`Node<node>` with an aviso attribute is held from executing until a
+      notification matching the configured listener is received. When a
+      matching notification is received, the node then allowed to execute
+      following a behaviour similar to :term:`trigger` or time dependency e.g.
+      :term:`cron`).
+
+      `Only one aviso attribute is allowed per node`, and each attribute is
+      defined by the following properties:
+
+        - :code:`name`, an identifier
+        - :code:`listener`, the configuration for the Aviso listener
+        - :code:`url`, the base location of the Aviso server
+        - :code:`schema`, the location of the Aviso schema used to evaluate the notifications
+        - :code:`polling`, the value (in seconds) used to periodically contact the Aviso server
+        - :code:`auth`, the location to the Aviso authentication credentials file
+
+      The value of the properties :code:`url`, :code:`schema`, :code:`polling`,
+      and :code:`auth` can be composed of :term:`Variables<variable>`. When
+      these properties are not provided, the following default values are used:
+
+        - :code:`%ECF_AVISO_URL%`, for :code:`url`
+        - :code:`%ECF_AVISO_SCHEMA%`, for :code:`schema`
+        - :code:`%ECF_AVISO_POLLING%`, for :code:`polling`
+        - :code:`%ECF_AVISO_AUTH%`, for :code:`auth`
+
+      .. important::
+
+         The variables :code:`ECF_AVISO_*` are not automatically provided at
+         server level, and must be defined at :term:`Suite<suite>` level by
+         the user.
+
+      Each aviso attribute implies that a background thread is spawned whenever
+      the associated :term:`node` is (re)queued. This background thread is
+      responsible for polling the Aviso server, and periodically processing the
+      latest notifications.
+
    check point 
       The check point file is like the :term:`suite definition`, but includes all the state information.
       
@@ -1317,7 +1357,49 @@
            - :token:`meter`
 
       Meters can be referenced in :term:`trigger` and :term:`complete expression` expressions.
-      
+
+   mirror
+      A mirror is an attribute of a :term:`Node<node>` (typically a :term:`Task<task>`),
+      and allows to synchronise the status of a node on a remote ecFlow server.
+
+      A :term:`Node<node>` with a mirror attribute will have its status periodically
+      synchronized with the :term:`status` of a node on a remote ecFlow server.
+      The synchronised status can be used to trigger the execution of local nodes.
+
+      .. note::
+
+        Synchronised tasks don't need to be provided with :code:`.ecf` files
+        on the local ecFlow server, as the execution of a :term:`Task<task>`
+        with a mirror attribute does not happen under the responsibility of the
+        local ecFlow server.
+
+        Operations to execute synchronised Tasks have been disabled from the :term:`ecflow_ui`.
+
+      `Only one mirror attribute is allowed per node`, and each attribute is
+      defined by the following properties:
+
+        - :code:`name`, an identifier
+        - :code:`remote_path`, the path of the node on the remote ecFlow server
+        - :code:`remote_host`, the remote ecFlow server host
+        - :code:`remote_port`, the remote ecFlow server port
+        - :code:`ssl`, to connect to the ecFlow server using SSL
+        - :code:`polling`, the value (in seconds) used to periodically contact the remote ecFlow server
+        - :code:`auth`, the location to the Mirror authentication credentials file
+
+      The value of the properties :code:`remote_host`, :code:`remote_port`, :code:`polling`,
+      and :code:`auth` can be composed of :term:`Variables<variable>`. When
+      these properties are not provided, the following default values are used:
+
+        - :code:`%ECF_MIRROR_REMOTE_HOST%`, for :code:`remote_host`
+        - :code:`%ECF_MIRROR_REMOTE_PORT%`, for :code:`remote_port`
+        - :code:`%ECF_MIRROR_REMOTE_POLLING%`, for :code:`polling`
+        - :code:`%ECF_MIRROR_REMOTE_AUTH%`, for :code:`auth`
+
+      Each mirror attribute implies that a background thread is spawned whenever
+      the ecFlow server is :term:`running<server states>`. This background thread is
+      responsible for polling the remote ecFlow server, and periodically
+      synchronise node status.
+
    node
       :term:`suite`, :term:`family` and :term:`task` form a hierarchy.
       Where a :term:`suite` serves as the root of the hierarchy. 
diff -pruN 5.12.4-1/docs/python_api/AvisoAttr.rst 5.13.0-1/docs/python_api/AvisoAttr.rst
--- 5.12.4-1/docs/python_api/AvisoAttr.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/python_api/AvisoAttr.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+ecflow.AvisoAttr
+////////////////
+
+
+.. py:class:: AvisoAttr
+   :module: ecflow
+
+   Bases: :py:class:`~Boost.Python.instance`
+
+An :term:`aviso` attribute, assigned to a :term:`node`, represents an external trigger holding the node queued untilan Aviso notification matching the attribute configuration is detected.
+
+Although :term:`aviso` attributes can be set at any level (Suite, Family, Task), it only makes sense to assign aviso attributes to tasks, and only one aviso attribute per node is allowed.
+
+
+Constructor::
+
+   AvisoAttr(name, listener, ...)
+      string name: The Aviso attribute name
+      string listener: The Aviso listener configuration (in JSON format)
+      string url: The URL used to contact the Aviso server
+      string schema: The path to the Aviso schema
+      string polling: The polling interval used to contact the Aviso server
+      string auth: The path to the Aviso Authentication credentials
+
+
+Usage:
+
+.. code-block:: python
+
+   t1 = Task('t1',
+             AvisoAttr('name', '{...}', 'http://aviso.com', '60', '/path/to/auth'))
+
+   t2 = Task('t2')
+   t2.add_aviso('name', '{...}', 'http://aviso.com', '60', '/path/to/auth')
+
+
+.. py:method:: AvisoAttr.auth( (AvisoAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the path to Authentication credentials used to contact the Aviso server
+
+
+.. py:method:: AvisoAttr.listener( (AvisoAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the Aviso listener configuration
+
+
+.. py:method:: AvisoAttr.name( (AvisoAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the name of the Aviso attribute
+
+
+.. py:method:: AvisoAttr.polling( (AvisoAttr)arg1) -> str :
+   :module: ecflow
+
+Returns polling interval used to contact the Aviso server
+
+
+.. py:method:: AvisoAttr.schema( (AvisoAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the path to the schema used to contact the Aviso server
+
+
+.. py:method:: AvisoAttr.url( (AvisoAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the URL used to contact the Aviso server
+
diff -pruN 5.12.4-1/docs/python_api/FlagType.rst 5.13.0-1/docs/python_api/FlagType.rst
--- 5.12.4-1/docs/python_api/FlagType.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/python_api/FlagType.rst	2024-06-20 10:11:46.000000000 +0000
@@ -98,7 +98,7 @@ Flags store state associated with a node
 
 .. py:attribute:: FlagType.names
    :module: ecflow
-   :value: {'archived': ecflow.FlagType.archived, 'byrule': ecflow.FlagType.byrule, 'checkpt_error': ecflow.FlagType.checkpt_error, 'edit_failed': ecflow.FlagType.edit_failed, 'force_abort': ecflow.FlagType.force_abort, 'jobcmd_failed': ecflow.FlagType.jobcmd_failed, 'killcmd_failed': ecflow.FlagType.killcmd_failed, 'killed': ecflow.FlagType.killed, 'late': ecflow.FlagType.late, 'locked': ecflow.FlagType.locked, 'log_error': ecflow.FlagType.log_error, 'message': ecflow.FlagType.message, 'no_reque': ecflow.FlagType.no_reque, 'no_script': ecflow.FlagType.no_script, 'not_set': ecflow.FlagType.not_set, 'queuelimit': ecflow.FlagType.queuelimit, 'restored': ecflow.FlagType.restored, 'sigterm': ecflow.FlagType.sigterm, 'status': ecflow.FlagType.status, 'statuscmd_failed': ecflow.FlagType.statuscmd_failed, 'task_aborted': ecflow.FlagType.task_aborted, 'threshold': ecflow.FlagType.threshold, 'user_edit': ecflow.FlagType.user_edit, 'wait': ecflow.FlagType.wait, 'zombie': ecflow.FlagType.zombie}
+   :value: {'archived': ecflow.FlagType.archived, 'byrule': ecflow.FlagType.byrule, 'checkpt_error': ecflow.FlagType.checkpt_error, 'edit_failed': ecflow.FlagType.edit_failed, 'force_abort': ecflow.FlagType.force_abort, 'jobcmd_failed': ecflow.FlagType.jobcmd_failed, 'killcmd_failed': ecflow.FlagType.killcmd_failed, 'killed': ecflow.FlagType.killed, 'late': ecflow.FlagType.late, 'locked': ecflow.FlagType.locked, 'log_error': ecflow.FlagType.log_error, 'message': ecflow.FlagType.message, 'no_reque': ecflow.FlagType.no_reque, 'no_script': ecflow.FlagType.no_script, 'not_set': ecflow.FlagType.not_set, 'queuelimit': ecflow.FlagType.queuelimit, 'remote_error': ecflow.FlagType.remote_error, 'restored': ecflow.FlagType.restored, 'sigterm': ecflow.FlagType.sigterm, 'status': ecflow.FlagType.status, 'statuscmd_failed': ecflow.FlagType.statuscmd_failed, 'task_aborted': ecflow.FlagType.task_aborted, 'threshold': ecflow.FlagType.threshold, 'user_edit': ecflow.FlagType.user_edit, 'wait': ecflow.FlagType.wait, 'zombie': ecflow.FlagType.zombie}
 
 
 .. py:attribute:: FlagType.no_reque
@@ -121,6 +121,11 @@ Flags store state associated with a node
    :value: ecflow.FlagType.queuelimit
 
 
+.. py:attribute:: FlagType.remote_error
+   :module: ecflow
+   :value: ecflow.FlagType.remote_error
+
+
 .. py:attribute:: FlagType.restored
    :module: ecflow
    :value: ecflow.FlagType.restored
@@ -158,7 +163,7 @@ Flags store state associated with a node
 
 .. py:attribute:: FlagType.values
    :module: ecflow
-   :value: {0: ecflow.FlagType.force_abort, 1: ecflow.FlagType.user_edit, 2: ecflow.FlagType.task_aborted, 3: ecflow.FlagType.edit_failed, 4: ecflow.FlagType.jobcmd_failed, 5: ecflow.FlagType.no_script, 6: ecflow.FlagType.killed, 7: ecflow.FlagType.late, 8: ecflow.FlagType.message, 9: ecflow.FlagType.byrule, 10: ecflow.FlagType.queuelimit, 11: ecflow.FlagType.wait, 12: ecflow.FlagType.locked, 13: ecflow.FlagType.zombie, 14: ecflow.FlagType.no_reque, 15: ecflow.FlagType.archived, 16: ecflow.FlagType.restored, 17: ecflow.FlagType.threshold, 18: ecflow.FlagType.sigterm, 19: ecflow.FlagType.not_set, 20: ecflow.FlagType.log_error, 21: ecflow.FlagType.checkpt_error, 22: ecflow.FlagType.killcmd_failed, 23: ecflow.FlagType.statuscmd_failed, 24: ecflow.FlagType.status}
+   :value: {0: ecflow.FlagType.force_abort, 1: ecflow.FlagType.user_edit, 2: ecflow.FlagType.task_aborted, 3: ecflow.FlagType.edit_failed, 4: ecflow.FlagType.jobcmd_failed, 5: ecflow.FlagType.no_script, 6: ecflow.FlagType.killed, 7: ecflow.FlagType.late, 8: ecflow.FlagType.message, 9: ecflow.FlagType.byrule, 10: ecflow.FlagType.queuelimit, 11: ecflow.FlagType.wait, 12: ecflow.FlagType.locked, 13: ecflow.FlagType.zombie, 14: ecflow.FlagType.no_reque, 15: ecflow.FlagType.archived, 16: ecflow.FlagType.restored, 17: ecflow.FlagType.threshold, 18: ecflow.FlagType.sigterm, 19: ecflow.FlagType.not_set, 20: ecflow.FlagType.log_error, 21: ecflow.FlagType.checkpt_error, 22: ecflow.FlagType.killcmd_failed, 23: ecflow.FlagType.statuscmd_failed, 24: ecflow.FlagType.status, 25: ecflow.FlagType.remote_error}
 
 
 .. py:attribute:: FlagType.wait
diff -pruN 5.12.4-1/docs/python_api/MirrorAttr.rst 5.13.0-1/docs/python_api/MirrorAttr.rst
--- 5.12.4-1/docs/python_api/MirrorAttr.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/python_api/MirrorAttr.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,78 @@
+ecflow.MirrorAttr
+/////////////////
+
+
+.. py:class:: MirrorAttr
+   :module: ecflow
+
+   Bases: :py:class:`~Boost.Python.instance`
+
+A :term:`mirror` attribute, assigned to a :term:`node`, enables establishing an external link and locally replicate the state of a node executing on a remote ecFlow server.
+
+Although :term:`mirror` attributes can be set at any level (Suite, Family, Task), it only makes sense to assign mirror attributes to Tasks, and only one mirror attribute per node is allowed.
+
+
+Constructor::
+
+   MirrorAttr(name, remote_path, ...)
+      string name: The Mirror attribute name
+      string remote_path: The path on the remote ecFlow server to the node being replicated
+      string remote_host: The host of the remote ecFlow server
+      string remote_port: The port of the remote ecFlow server
+      string polling: The polling interval used to contact the remote ecFlow server
+      Bool ssl: `true`, when using SSL to contact the remote ecFlow server; `false`, otherwise
+      string auth: The path to the Mirror Authentication credentials
+
+
+Usage:
+
+.. code-block:: python
+
+   t1 = Task('t1',
+             MirrorAttr('name', '/remote/task', 'remote-ecflow', '3141', '60', True, '/path/to/auth'))
+
+   t2 = Task('t2')
+   t2.add_aviso('name', '/remote/task', 'remote-ecflow', '3141', '60', True, '/path/to/auth')
+
+
+.. py:method:: MirrorAttr.auth( (MirrorAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the path to Authentication credentials used to contact the remote ecFlow server
+
+
+.. py:method:: MirrorAttr.name( (MirrorAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the name of the Mirror attribute
+
+
+.. py:method:: MirrorAttr.polling( (MirrorAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the polling interval used to contact the remove ecFlow server
+
+
+.. py:method:: MirrorAttr.remote_host( (MirrorAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the host of the remote ecFlow server
+
+
+.. py:method:: MirrorAttr.remote_path( (MirrorAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the path on the remote ecFlow server
+
+
+.. py:method:: MirrorAttr.remote_port( (MirrorAttr)arg1) -> str :
+   :module: ecflow
+
+Returns the port of the remote ecFlow server
+
+
+.. py:method:: MirrorAttr.ssl( (MirrorAttr)arg1) -> bool :
+   :module: ecflow
+
+Returns a boolean, where true means that SSL is enabled
+
diff -pruN 5.12.4-1/docs/python_api/Node.rst 5.13.0-1/docs/python_api/Node.rst
--- 5.12.4-1/docs/python_api/Node.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/python_api/Node.rst	2024-06-20 10:11:46.000000000 +0000
@@ -200,6 +200,13 @@ Add a `autorestore` attribute. See :py:c
 add_autorestore( (Node)arg1, (list)arg2) -> Node
 
 
+.. py:method:: Node.add_aviso( (Node)arg1, (AvisoAttr)arg2) -> Node :
+   :module: ecflow
+
+Adds an :term:`aviso` to a :term:`node`. See :py:class:`ecflow.Aviso`
+    
+
+
 .. py:method:: Node.add_complete( (Node)arg1, (str)arg2) -> Node :
    :module: ecflow
 
@@ -533,6 +540,13 @@ Add a :term:`meter`. See :py:class:`ecfl
 add_meter( (Node)arg1, (str)arg2, (int)arg3, (int)arg4 [, (int)arg5]) -> Node
 
 
+.. py:method:: Node.add_mirror( (Node)arg1, (MirrorAttr)arg2) -> Node :
+   :module: ecflow
+
+Adds a :term:`mirror` to a :term:`node`. See :py:class:`ecflow.Mirror`
+    
+
+
 .. py:method:: Node.add_part_complete( (Node)arg1, (PartExpression)arg2) -> Node :
    :module: ecflow
 
@@ -978,6 +992,12 @@ Usage:
               ZombieAttr(ZombieType.ecf, child_list, ZombieUserActionType.fail))
 
 
+.. py:property:: Node.avisos
+   :module: ecflow
+
+Returns a list of :term:`aviso`\ s
+
+
 .. py:method:: Node.change_complete( (Node)arg1, (str)arg2) -> None
    :module: ecflow
 
@@ -1292,6 +1312,12 @@ Returns a list of :term:`limit`\ s
 Returns a list of :term:`meter`\ s
 
 
+.. py:property:: Node.mirrors
+   :module: ecflow
+
+Returns a list of :term:`mirror`\ s
+
+
 .. py:method:: Node.name( (Node)arg1) -> str
    :module: ecflow
 
diff -pruN 5.12.4-1/docs/release_notes/index.rst 5.13.0-1/docs/release_notes/index.rst
--- 5.12.4-1/docs/release_notes/index.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/release_notes/index.rst	2024-06-20 10:11:46.000000000 +0000
@@ -4,6 +4,7 @@ Release notes
 .. toctree::
     :maxdepth: 1
 
+    version_5.13
     version_5.12
     version_5.11
     version_5.10
diff -pruN 5.12.4-1/docs/release_notes/version_5.13.rst 5.13.0-1/docs/release_notes/version_5.13.rst
--- 5.12.4-1/docs/release_notes/version_5.13.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/release_notes/version_5.13.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+.. _version_5.13:
+
+Version 5.13 updates
+////////////////////
+
+.. role:: jiraissue
+   :class: hidden
+
+
+Version 5.13.0
+==============
+
+* `Released <https://confluence.ecmwf.int/display/ECFLOW/Releases>`__\  on 2024-06-19
+
+General
+-------
+
+- **New Feature** enabled support for Aviso notifications :jiraissue:`ECFLOW-1931`
+- **New Feature** enabled synchronisation of Node status between ecFlow servers :jiraissue:`ECFLOW-1931`
+- **Improvement** improved structure/naming of ecFlow internal sources :jiraissue:`ECFLOW-1943`
diff -pruN 5.12.4-1/docs/ug/cookbook/how_to_mirror_a_remote_task_status.rst 5.13.0-1/docs/ug/cookbook/how_to_mirror_a_remote_task_status.rst
--- 5.12.4-1/docs/ug/cookbook/how_to_mirror_a_remote_task_status.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/ug/cookbook/how_to_mirror_a_remote_task_status.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,70 @@
+.. _how_to_mirror_a_remote_task_status:
+
+How to mirror a remote Task status?
+-----------------------------------
+
+The following instructions describe the necessary steps to use the ability to
+synchronise the status of a :term:`task` between a `remote` ecFlow server
+and a `local` ecFlow server. The `remote` server is responsible for actually
+executing the task, while the `local` server synchronizes the status of a
+particular task, in order to trigger the execution of dependent tasks.
+
+The deployment of this feature has the following requirements:
+ - `local` ecFlow 5.13+, to host the dependent task(s)
+ - `remote` ecFlow 5+, to host the remote task
+ - Authentication credentials, stored as JSON file
+
+Setup the ecFlow Server
+^^^^^^^^^^^^^^^^^^^^^^^
+
+Deploy the `remote` ecFlow server, as per the :ref:`regular instructions<starting_the_ecflow_server>`
+and specifying username/password access configuration.
+
+Deploy the Authentication credentials so that the JSON file is accessible
+to the `local` ecFlow server. Launch the server.
+
+Consider using SSL encription for the communication between ecFlow server and
+client.
+
+
+Define the Suite with a `mirrored` Task
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+On the :term:`suite` definition file, create a :term:`task` (which will mirror
+the remote task status) and assign it a :term:`mirror` attribute. The mirror
+attribute must specify the path of the remote node, and the remote server
+connection details. Using the mirrored task, other tasks can use triggers to
+execute when the remote task becomes complete.
+
+Follow the recommended practice of defining ecFlow :term:`variables<variable>`
+at :term:`suite` level:
+
+ - ECF_MIRROR_REMOTE_HOST
+ - ECF_MIRROR_REMOTE_PORT
+ - ECF_MIRROR_REMOTE_POLLING
+ - ECF_MIRROR_REMOTE_AUTH
+
+**Example 1**: Example suite definition with mirror attributes
+
+  .. code-block:: shell
+
+    suite s
+      edit ECF_MIRROR_REMOTE_HOST 'remotehost'
+      edit ECF_MIRROR_REMOTE_PORT '3456'
+      edit ECF_MIRROR_REMOTE_POLLING '120'
+      edit ECF_MIRROR_REMOTE_AUTH '/path/to/mirror.auth'
+      family f
+        task Task
+          mirror --name A --remote_path /s1/f1/t1 --remote_host %ECF_MIRROR_REMOTE_HOST% --remote_port %ECF_MIRROR_REMOTE_PORT% --polling %ECF_MIRROR_REMOTE_POLLING% --ssl
+        task Dependent
+          trigger Task == complete
+      endfamily
+    endsuite
+
+Deploy the Suite with a `mirrored` Task
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+Load the suite definition containing the :term:`mirror` attribute.
+
+Whenever the ecFlow server is in `RUNNING` state, the synchronisation between
+`remote` and `local` servers is enabled automatically.
diff -pruN 5.12.4-1/docs/ug/cookbook/how_to_trigger_a_task_based_on_aviso_notification.rst 5.13.0-1/docs/ug/cookbook/how_to_trigger_a_task_based_on_aviso_notification.rst
--- 5.12.4-1/docs/ug/cookbook/how_to_trigger_a_task_based_on_aviso_notification.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/ug/cookbook/how_to_trigger_a_task_based_on_aviso_notification.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,65 @@
+.. _how_to_trigger_a_task_based_on_aviso_notification:
+
+How to trigger a Task based on Aviso notification?
+--------------------------------------------------
+
+The following instructions describe the necessary steps to use the ability to
+trigger a :term:`task` based on an Aviso notification. The intended task must
+be assigned an :term:`aviso` attribute, which provides the configuration to
+periodically poll the Aviso server, and execution only happens when the
+a matching Aviso notification is processed.
+
+The deployment of this feature has the following requirements:
+ - ecFlow 5.13+, to host the Aviso dependent task(s)
+ - Aviso event listener schema
+ - Authentication credentials, stored as JSON file
+
+Setup the ecFlow Server
+^^^^^^^^^^^^^^^^^^^^^^^
+
+Deploy the Authentication credentials and Aviso event listener schema files so
+that these files are accessible to the ecFlow server. Launch the server, as per
+the :ref:`regular instructions<starting_the_ecflow_server>`.
+
+Define a Suite with an `Aviso` dependent Task
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+On the :term:`suite` definition file, create a :term:`task` and assign it an
+:term:`aviso` attribute.
+
+The :term:`aviso` attribute must specify the base URL to contact the Aviso server,
+and the remote server connection details. Using the mirrored task, other tasks can use triggers to execute
+when the remote task becomes complete.
+
+Follow the recommended practice of defining ecFlow :term:`variables<variable>` at :term:`suite` level:
+
+ - ECF_AVISO_URL
+ - ECF_AVISO_SCHEMA
+ - ECF_AVISO_POLLING
+ - ECF_AVISO_AUTH
+
+**Example 1**: Example suite definition with mirror attributes
+
+  .. code-block:: shell
+
+    suite s
+      edit ECF_AVISO_URL 'http://aviso:2379'
+      edit ECF_AVISO_SCHEMA '/path/to/event_listener_schema.json'
+      edit ECF_AVISO_POLLING '120'
+      edit ECF_AVISO_AUTH '/path/to/aviso.auth'
+      family f
+        task Task
+          aviso --name A --listener '{ "event": "mars", "request": { "step": 0 } }' --url %ECF_AVISO_URL% --schema %ECF_AVISO_SCHEMA% --auth %ECF_AVISO_AUTH% --polling %ECF_AVISO_POLLING%
+      endfamily
+    endsuite
+
+Define a Suite with an `Aviso` dependent Task
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+Load the suite definition containing the :term:`aviso` attribute.
+
+Whenever a task assigned with an :term:`aviso` attribute is (re)queued,
+the Aviso will start to be periodically poll. The task is held from execution
+until a notification matching the provided listener is found.
+Once the task is allowed to execute the periodic polling is stopped, until the
+task is requeued again.
diff -pruN 5.12.4-1/docs/ug/cookbook/index.rst 5.13.0-1/docs/ug/cookbook/index.rst
--- 5.12.4-1/docs/ug/cookbook/index.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/ug/cookbook/index.rst	2024-06-20 10:11:46.000000000 +0000
@@ -7,7 +7,6 @@
 Cookbook
 ============
 
-
 This cookbook will provide real examples of using the ecFlow :ref:`python_api`.
 
 **Contents**
@@ -38,5 +37,5 @@ This cookbook will provide real examples
    native_python_task
    one_script_do_it_all
    python_client_for_fault_tolerance
-   
-   
+   how_to_mirror_a_remote_task_status
+   how_to_trigger_a_task_based_on_aviso_notification
diff -pruN 5.12.4-1/docs/ug/user_manual/definition_file_grammar.rst 5.13.0-1/docs/ug/user_manual/definition_file_grammar.rst
--- 5.12.4-1/docs/ug/user_manual/definition_file_grammar.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/ug/user_manual/definition_file_grammar.rst	2024-06-20 10:11:46.000000000 +0000
@@ -29,10 +29,13 @@ Definition file grammar
     family: "family" >> `familyName` >> !`leaf_ecf` >> *(`task` | `family`) 
           : >> `endfamily`
     task: "task"  >> `taskName`  >> `leaf_ecf`  >> !endtask
-    leaf_ecf: *( `variable` | `trigger` | `time` | `today` | 
-            : `date` | `day` | `defstatus` | `complete` | `inlimit` |
-            : `label` | `event` | `late` | `limit` | `meter` | `repeat` | 
-            : `cron` | `autocancel` | `zombie` )
+    leaf_ecf: *( `variable` | `trigger` | `time` | `today` |
+            :   `date` | `day` | `defstatus` | `complete` | `inlimit` |
+            :   `label` | `event` | `late` | `limit` | `meter` | `repeat` |
+            :   `cron` | `autocancel` | `zombie`
+            : )
+            : | `aviso`
+            : | `mirror`
     clock: "clock" >> ( "real"| "hybrid" ) >> 
          : ( ( `clock_date` >> !(`hh_mm` | int ) ) | (`hh_mm` | int )) 
          : >> +`nextline`
@@ -40,6 +43,23 @@ Definition file grammar
     complete: "complete" >> `expression` >> +`nextline`
     variable: "edit" >> `identifier` >> `varvalue` >> +`nextline`
     label: "label" >> `identifier` >> `quotedstring`  >> +`nextline`
+    aviso: "aviso" >>
+         :   *( "--name" >> `identifier`
+         :     | "--listener" >> "'" >> `jsonstring` >> "'"
+         :     | "--url" >> ( `varvalue` | `string` )
+         :     | "--polling" >> (`varvalue` | +(integer))
+         :     | "--schema" >> ( `varvalue` | `string` )
+         :     | "--auth" >> ( `varvalue` | `string` )
+         :   )
+    mirror: "mirror" >>
+          :   *( "--name" >> `identifier`
+          :     | "--remote_path" >> `string`
+          :     | "--remote_host" >> ( `varvalue` | `string` )
+          :     | "--remote_port" >> ( `varvalue` | `string` )
+          :     | "--polling" >> (`varvalue` | +(integer))
+          :     | "--auth" >> ( `varvalue` | `string` )
+          :     | --ssl
+          :   )
     time: "time" >> !'+ >> (`timeseries` | `two_int_p` >> 
         : “:” `two_int_p`) >> +`nextline`
     today: "today" >> !'+ >> (`timeseries` | `two_int_p` >> 
@@ -119,7 +139,7 @@ Definition file grammar
     dotpath: ‘.’  >> +( ‘/’  >> `identifier` )
     identifier: (alpha_numeric | ‘_’)  >> *(alpha_numeric | ‘_’)
     nodePath: `absolutepath` | `dotdotpath` | `dotpath`
-    expression: printable chars >> !’\’ >> `nextline`
+    expression: `printable_chars` >> !’\’ >> `nextline`
     int_p: integer
     two_int_p: 2 digit integer
     theYear: 4 digit integer
@@ -128,3 +148,6 @@ Definition file grammar
            : "T" >> `two_int_p` >> `two_int_p` >> `two_int_p`
     duration: `int_p` >> ":" >> `two_int_p` >> ":" >> `two_int_p`
     newline: \n
+    string: `printable_chars` >> *(`printable_chars`)
+    jsonstring : __ as per JSON format specification __
+    printable_chars : "a-zA-Z"
diff -pruN 5.12.4-1/docs/ug/user_manual/node_attribute_overview.rst 5.13.0-1/docs/ug/user_manual/node_attribute_overview.rst
--- 5.12.4-1/docs/ug/user_manual/node_attribute_overview.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/ug/user_manual/node_attribute_overview.rst	2024-06-20 10:11:46.000000000 +0000
@@ -15,165 +15,183 @@ Node attribute overview
      - Use in trigger
      - Process/Control
      - Structural
-   * - :term:`repeat`
+   * - :term:`aviso`
      - ❎
-     -  
-     - 
+     - ❎
+     -
+     -
+     -
+     -
+     -
+     -
+   * - :term:`autocancel`
+     -
+     -
+     -
+     -
+     -
      -
      -
      - ❎
+   * - :term:`clock`
+     -
+     -
      -
      -
-   * - :term:`cron`
      - ❎
-     - ❎ 
-     - 
+     - ❎
      -
      -
-     - 
+   * - :term:`complete`
      -
+     - ❎
      -
-   * - :term:`time` / :term:`today`
+     -
+     -
+     - N/A
+     -
+     -
+   * - :term:`cron`
+     - ❎
      - ❎
-     - ❎ 
-     - 
      -
      -
-     - 
+     -
+     -
      -
      -
    * - :term:`date`
      - ❎
-     - ❎ 
-     - 
+     - ❎
+     -
+     -
      -
      -
-     - 
      -
      -
    * - :term:`day`
-     - 
-     - ❎ 
-     - 
      -
+     - ❎
+     -
+     -
+     -
+     -
+     -
+     -
+   * - :term:`defstatus`
      -
-     - 
      -
      -
-   * - :term:`clock`
-     - 
-     -  
-     - 
      -
-     - ❎
      - ❎
      -
      -
-   * - :term:`variable`
-     - 
-     -  
-     - 
+     -
+   * - :term:`event`
+     -
+     -
+     -
      - ❎
      -
      - ❎
      -
      -
-   * - :term:`defstatus`
-     - 
-     -  
-     - 
+   * - :term:`inlimit`
      -
      - ❎
-     - 
      -
      -
-   * - :term:`event`
-     - 
-     -  
-     - 
+     -
+     -
+     -
+     -
+   * - :term:`label`
+     -
+     -
+     - ❎
      - ❎
      -
+     -
+     -
+     -
+   * - :term:`late`
+     -
+     -
      - ❎
      -
      -
-   * - :term:`meter`
-     - 
-     -  
-     - 
      - ❎
      -
+     -
+   * - :term:`limit`
+     -
      - ❎
      -
      -
-   * - :term:`label`
-     - 
-     -  
-     - ❎ 
+     -
      - ❎
      -
-     - 
+     -
+   * - :term:`meter`
+     -
      -
      -
-   * - :term:`trigger`
-     - 
      - ❎
-     - 
      -
+     - ❎
      -
-     - N/A
      -
+   * - :term:`mirror`
      -
-   * - :term:`complete`
-     - 
      - ❎
-     - 
      -
      -
-     - N/A
      -
      -
-   * - :term:`limit`
-     - 
+     -
+     -
+   * - :term:`repeat`
      - ❎
+     -  
      - 
      -
      -
      - ❎
      -
      -
-   * - :term:`inlimit`
-     - 
+   * - :term:`time` / :term:`today`
      - ❎
+     - ❎ 
      - 
      -
      -
      - 
      -
      -
-   * - :term:`late`
-     - 
-     - 
+   * - :term:`trigger`
+     -
      - ❎
      -
      -
-     - ❎
      -
+     - N/A
      -
-   * - :term:`zombie`
-     - 
+     -
+   * - :term:`variable`
      - 
+     -  
      - 
+     - ❎
      -
-     -
-     - 
      - ❎
      -
-   * - :term:`autocancel`
-     - 
      -
+   * - :term:`zombie`
+     - 
+     - 
      - 
      -
      -
      - 
-     -
      - ❎
+     -
diff -pruN 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/attributes/index.rst 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/attributes/index.rst
--- 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/attributes/index.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/attributes/index.rst	2024-06-20 10:11:46.000000000 +0000
@@ -1,7 +1,7 @@
 .. _attributes:
 
-Attributes
-////////////
+Other Attributes
+////////////////
 
 This section describes commands that can be used to give attributes to
 nodes in a suite.
@@ -17,4 +17,3 @@ nodes in a suite.
    extern
    late
    repeat_for_loop
-
diff -pruN 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/external/aviso.rst 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/external/aviso.rst
--- 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/external/aviso.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/external/aviso.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+.. _text_based_def_aviso:
+
+aviso
+/////
+
+This defines an :term:`aviso` attribute, and thus a node dependency on an Aviso
+notification. The options defining the attribute can be provided in any order.
+
+.. code-block:: shell
+
+    task t1
+      aviso --name A --listener '{ ... }' --url http://aviso.ecmwf.int/ --schema /path/to/schema.json --polling 300 --auth /path/to/auth.json
+
+    task t2
+      aviso --name B --listener '{ ... }'
+        # when not provided, the following default options are used
+        #     --url %ECF_AVISO_URL%
+        #     --schema %ECF_AVISO_SCHEMA%
+        #     --auth %ECF_AVISO_AUTH%
+        #     --polling %ECF_AVISO_POLLING%
+
+Notice that the :code:`--listener` option must be surrounded by single quotes,
+and is composed as a single line `JSON`. The `JSON` must define two fields:
+
+ - :code:`event`, specifies the type of Aviso event
+ - :code:`request`, specifies a dictionary with the parameters used to check for matches of Aviso notifications
+
+The following are some examples:
+
+.. code-block:: shell
+
+    '{ "event": "dissemination", "request": { "destination": "abc" } }'
+
+    '{ "event": "mars", "request": { "class": "od", "expver": "0001", "domain": "g", "stream": "abcd", "step": 0 } }'
+
+The Authentication credentials, provided via option :code:`--auth`, are
+provided in a `JSON` file with the following content:
+
+.. code-block:: json
+
+    {
+      "url": "http://host.int:1234",
+      "key": "*******************************************************************",
+      "email": "user@host.int"
+    }
diff -pruN 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/external/index.rst 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/external/index.rst
--- 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/external/index.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/external/index.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+.. _external_dependencies:
+
+External Dependencies
+/////////////////////
+
+In addition to attributes that allow defining the dependencies mentioned in
+:ref:`dependencies`, ecFlow is able to specify dependencies based on external
+entities, and thus allow "local" nodes to be triggered by remote events:
+
+   - notifications disseminated by an Aviso server
+   - status changes on remote ecFlow
+
+The following sections present in detail the different external dependencies
+currently supported.
+
+.. toctree::
+   :maxdepth: 1
+
+   aviso
+   mirror
diff -pruN 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/external/mirror.rst 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/external/mirror.rst
--- 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/external/mirror.rst	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/external/mirror.rst	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,33 @@
+.. _text_based_def_mirror:
+
+mirror
+//////
+
+This defines a :term:`mirror` attribute, which synchronizes the status of a
+:term:`node` between a local and a remote ecFlow server. The options defining
+the attribute can be provided in any order.
+
+.. code-block:: shell
+
+    task t1
+      mirror --name A --remote_path /s/f/tA --remote_host host --remote_port 3141 --polling 20 --ssl --auth /path/to/auth.json
+
+    task t2
+      aviso --name B --remote_path /s/f/tB
+        # when not provided, the following default options are used
+        #     --remote_host %ECF_MIRROR_REMOTE_HOST%
+        #     --remote_port %ECF_MIRROR_REMOTE_PORT%
+        #     --polling %ECF_MIRROR_POLLING%
+        #     --auth %ECF_MIRROR_AUTH%
+
+The Authentication credentials, provided via option :code:`--auth`, are
+provided in a `JSON` file with the following content:
+
+.. code-block:: json
+
+    {
+      "url": "http://host.int:1234",
+      "username": "user",
+      "password": "************",
+      "email": "user@host.int"
+    }
diff -pruN 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/index.rst 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/index.rst
--- 5.12.4-1/docs/ug/user_manual/text_based_suite_definition/index.rst	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/docs/ug/user_manual/text_based_suite_definition/index.rst	2024-06-20 10:11:46.000000000 +0000
@@ -56,3 +56,4 @@ suite-definition file easier. There are
    suite_definition_file_format/index.rst
    dependencies/index.rst
    attributes/index.rst
+   external/index.rst
diff -pruN 5.12.4-1/libs/CMakeLists.txt 5.13.0-1/libs/CMakeLists.txt
--- 5.12.4-1/libs/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,603 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+configure_file(
+  core/src/ecflow/core/ecflow_version.h.in
+  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_version.h)
+configure_file(
+  core/src/ecflow/core/ecflow_source_build_dir.h.in
+  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_source_build_dir.h)
+
+set(srcs
+  # Attribute -- Headers
+  attribute/src/ecflow/attribute/AutoArchiveAttr.hpp
+  attribute/src/ecflow/attribute/AutoCancelAttr.hpp
+  attribute/src/ecflow/attribute/ClockAttr.hpp
+  attribute/src/ecflow/attribute/CronAttr.hpp
+  attribute/src/ecflow/attribute/DateAttr.hpp
+  attribute/src/ecflow/attribute/DayAttr.hpp
+  attribute/src/ecflow/attribute/GenericAttr.hpp
+  attribute/src/ecflow/attribute/LateAttr.hpp
+  attribute/src/ecflow/attribute/NodeAttr.hpp
+  attribute/src/ecflow/attribute/QueueAttr.hpp
+  attribute/src/ecflow/attribute/RepeatAttr.hpp
+  attribute/src/ecflow/attribute/TimeAttr.hpp
+  attribute/src/ecflow/attribute/TodayAttr.hpp
+  attribute/src/ecflow/attribute/Variable.hpp
+  attribute/src/ecflow/attribute/VerifyAttr.hpp
+  attribute/src/ecflow/attribute/Zombie.hpp
+  attribute/src/ecflow/attribute/ZombieAttr.hpp
+  # Attribute -- Sources
+  attribute/src/ecflow/attribute/AutoArchiveAttr.cpp
+  attribute/src/ecflow/attribute/AutoCancelAttr.cpp
+  attribute/src/ecflow/attribute/ClockAttr.cpp
+  attribute/src/ecflow/attribute/CronAttr.cpp
+  attribute/src/ecflow/attribute/DateAttr.cpp
+  attribute/src/ecflow/attribute/DayAttr.cpp
+  attribute/src/ecflow/attribute/GenericAttr.cpp
+  attribute/src/ecflow/attribute/LateAttr.cpp
+  attribute/src/ecflow/attribute/NodeAttr.cpp
+  attribute/src/ecflow/attribute/QueueAttr.cpp
+  attribute/src/ecflow/attribute/RepeatAttr.cpp
+  attribute/src/ecflow/attribute/TimeAttr.cpp
+  attribute/src/ecflow/attribute/TodayAttr.cpp
+  attribute/src/ecflow/attribute/Variable.cpp
+  attribute/src/ecflow/attribute/VerifyAttr.cpp
+  attribute/src/ecflow/attribute/Zombie.cpp
+  attribute/src/ecflow/attribute/ZombieAttr.cpp
+
+  # Base -- Headers
+  base/src/ecflow/base/AbstractClientEnv.hpp
+  base/src/ecflow/base/AbstractServer.hpp
+  base/src/ecflow/base/Client.hpp
+  base/src/ecflow/base/ClientOptionsParser.hpp
+  base/src/ecflow/base/ClientToServerRequest.hpp
+  base/src/ecflow/base/Cmd.hpp
+  base/src/ecflow/base/Connection.hpp
+  base/src/ecflow/base/Gnuplot.hpp
+  base/src/ecflow/base/ServerReply.hpp
+  base/src/ecflow/base/ServerToClientResponse.hpp
+  base/src/ecflow/base/Stats.hpp
+  base/src/ecflow/base/WhyCmd.hpp
+  base/src/ecflow/base/ZombieCtrl.hpp
+  $<$<BOOL:${OPENSSL_FOUND}>:base/src/ecflow/base/Openssl.hpp>
+  $<$<BOOL:${OPENSSL_FOUND}>:base/src/ecflow/base/ssl_connection.hpp>
+  $<$<BOOL:${OPENSSL_FOUND}>:base/src/ecflow/base/SslClient.hpp>
+  base/src/ecflow/base/cts/ClientToServerCmd.hpp
+  base/src/ecflow/base/cts/CtsCmdRegistry.hpp
+  base/src/ecflow/base/cts/EditHistoryMgr.hpp
+  base/src/ecflow/base/cts/task/AbortCmd.hpp
+  base/src/ecflow/base/cts/task/CompleteCmd.hpp
+  base/src/ecflow/base/cts/task/CtsWaitCmd.hpp
+  base/src/ecflow/base/cts/task/EventCmd.hpp
+  base/src/ecflow/base/cts/task/InitCmd.hpp
+  base/src/ecflow/base/cts/task/LabelCmd.hpp
+  base/src/ecflow/base/cts/task/MeterCmd.hpp
+  base/src/ecflow/base/cts/task/QueueCmd.hpp
+  base/src/ecflow/base/cts/task/TaskApi.hpp
+  base/src/ecflow/base/cts/task/TaskCmd.hpp
+  base/src/ecflow/base/cts/user/AlterCmd.hpp
+  base/src/ecflow/base/cts/user/BeginCmd.hpp
+  base/src/ecflow/base/cts/user/CFileCmd.hpp
+  base/src/ecflow/base/cts/user/CheckPtCmd.hpp
+  base/src/ecflow/base/cts/user/ClientHandleCmd.hpp
+  base/src/ecflow/base/cts/user/CSyncCmd.hpp
+  base/src/ecflow/base/cts/user/CtsApi.hpp
+  base/src/ecflow/base/cts/user/CtsCmd.hpp
+  base/src/ecflow/base/cts/user/CtsNodeCmd.hpp
+  base/src/ecflow/base/cts/user/DeleteCmd.hpp
+  base/src/ecflow/base/cts/user/EditScriptCmd.hpp
+  base/src/ecflow/base/cts/user/ForceCmd.hpp
+  base/src/ecflow/base/cts/user/FreeDepCmd.hpp
+  base/src/ecflow/base/cts/user/GroupCTSCmd.hpp
+  base/src/ecflow/base/cts/user/LoadDefsCmd.hpp
+  base/src/ecflow/base/cts/user/LogCmd.hpp
+  base/src/ecflow/base/cts/user/LogMessageCmd.hpp
+  base/src/ecflow/base/cts/user/MoveCmd.hpp
+  base/src/ecflow/base/cts/user/OrderNodeCmd.hpp
+  base/src/ecflow/base/cts/user/PathsCmd.hpp
+  base/src/ecflow/base/cts/user/PlugCmd.hpp
+  base/src/ecflow/base/cts/user/QueryCmd.hpp
+  base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp
+  base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp
+  base/src/ecflow/base/cts/user/RunNodeCmd.hpp
+  base/src/ecflow/base/cts/user/ServerVersionCmd.hpp
+  base/src/ecflow/base/cts/user/ShowCmd.hpp
+  base/src/ecflow/base/cts/user/UserCmd.hpp
+  base/src/ecflow/base/cts/user/ZombieCmd.hpp
+  base/src/ecflow/base/stc/BlockClientZombieCmd.hpp
+  base/src/ecflow/base/stc/DefsCache.hpp
+  base/src/ecflow/base/stc/DefsCmd.hpp
+  base/src/ecflow/base/stc/ErrorCmd.hpp
+  base/src/ecflow/base/stc/GroupSTCCmd.hpp
+  base/src/ecflow/base/stc/PreAllocatedReply.hpp
+  base/src/ecflow/base/stc/SClientHandleCmd.hpp
+  base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp
+  base/src/ecflow/base/stc/SNewsCmd.hpp
+  base/src/ecflow/base/stc/SNodeCmd.hpp
+  base/src/ecflow/base/stc/SServerLoadCmd.hpp
+  base/src/ecflow/base/stc/SStatsCmd.hpp
+  base/src/ecflow/base/stc/SStringCmd.hpp
+  base/src/ecflow/base/stc/SStringVecCmd.hpp
+  base/src/ecflow/base/stc/SSuitesCmd.hpp
+  base/src/ecflow/base/stc/SSyncCmd.hpp
+  base/src/ecflow/base/stc/ServerToClientCmd.hpp
+  base/src/ecflow/base/stc/StcCmd.hpp
+  base/src/ecflow/base/stc/ZombieGetCmd.hpp
+  # Base -- Sources
+  base/src/ecflow/base/Client.cpp
+  base/src/ecflow/base/ClientOptionsParser.cpp
+  base/src/ecflow/base/ClientToServerRequest.cpp
+  base/src/ecflow/base/Connection.cpp
+  base/src/ecflow/base/Gnuplot.cpp
+  base/src/ecflow/base/ServerReply.cpp
+  base/src/ecflow/base/ServerToClientResponse.cpp
+  base/src/ecflow/base/Stats.cpp
+  base/src/ecflow/base/WhyCmd.cpp
+  base/src/ecflow/base/ZombieCtrl.cpp
+  $<$<BOOL:${OPENSSL_FOUND}>:base/src/ecflow/base/Openssl.cpp>
+  $<$<BOOL:${OPENSSL_FOUND}>:base/src/ecflow/base/ssl_connection.cpp>
+  $<$<BOOL:${OPENSSL_FOUND}>:base/src/ecflow/base/SslClient.cpp>
+  base/src/ecflow/base/cts/ClientToServerCmd.cpp
+  base/src/ecflow/base/cts/CtsCmdRegistry.cpp
+  base/src/ecflow/base/cts/EditHistoryMgr.cpp
+  base/src/ecflow/base/cts/task/AbortCmd.cpp
+  base/src/ecflow/base/cts/task/CompleteCmd.cpp
+  base/src/ecflow/base/cts/task/CtsWaitCmd.cpp
+  base/src/ecflow/base/cts/task/EventCmd.cpp
+  base/src/ecflow/base/cts/task/InitCmd.cpp
+  base/src/ecflow/base/cts/task/LabelCmd.cpp
+  base/src/ecflow/base/cts/task/MeterCmd.cpp
+  base/src/ecflow/base/cts/task/QueueCmd.cpp
+  base/src/ecflow/base/cts/task/TaskApi.cpp
+  base/src/ecflow/base/cts/task/TaskCmd.cpp
+  base/src/ecflow/base/cts/user/AlterCmd.cpp
+  base/src/ecflow/base/cts/user/BeginCmd.cpp
+  base/src/ecflow/base/cts/user/CFileCmd.cpp
+  base/src/ecflow/base/cts/user/CSyncCmd.cpp
+  base/src/ecflow/base/cts/user/CheckPtCmd.cpp
+  base/src/ecflow/base/cts/user/ClientHandleCmd.cpp
+  base/src/ecflow/base/cts/user/CtsApi.cpp
+  base/src/ecflow/base/cts/user/CtsCmd.cpp
+  base/src/ecflow/base/cts/user/CtsNodeCmd.cpp
+  base/src/ecflow/base/cts/user/DeleteCmd.cpp
+  base/src/ecflow/base/cts/user/EditScriptCmd.cpp
+  base/src/ecflow/base/cts/user/ForceCmd.cpp
+  base/src/ecflow/base/cts/user/FreeDepCmd.cpp
+  base/src/ecflow/base/cts/user/GroupCTSCmd.cpp
+  base/src/ecflow/base/cts/user/LoadDefsCmd.cpp
+  base/src/ecflow/base/cts/user/LogCmd.cpp
+  base/src/ecflow/base/cts/user/LogMessageCmd.cpp
+  base/src/ecflow/base/cts/user/MoveCmd.cpp
+  base/src/ecflow/base/cts/user/OrderNodeCmd.cpp
+  base/src/ecflow/base/cts/user/PathsCmd.cpp
+  base/src/ecflow/base/cts/user/PlugCmd.cpp
+  base/src/ecflow/base/cts/user/QueryCmd.cpp
+  base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp
+  base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp
+  base/src/ecflow/base/cts/user/RunNodeCmd.cpp
+  base/src/ecflow/base/cts/user/ServerVersionCmd.cpp
+  base/src/ecflow/base/cts/user/ShowCmd.cpp
+  base/src/ecflow/base/cts/user/UserCmd.cpp
+  base/src/ecflow/base/cts/user/ZombieCmd.cpp
+  base/src/ecflow/base/stc/BlockClientZombieCmd.cpp
+  base/src/ecflow/base/stc/DefsCache.cpp
+  base/src/ecflow/base/stc/DefsCmd.cpp
+  base/src/ecflow/base/stc/ErrorCmd.cpp
+  base/src/ecflow/base/stc/GroupSTCCmd.cpp
+  base/src/ecflow/base/stc/PreAllocatedReply.cpp
+  base/src/ecflow/base/stc/SClientHandleCmd.cpp
+  base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp
+  base/src/ecflow/base/stc/SNewsCmd.cpp
+  base/src/ecflow/base/stc/SNodeCmd.cpp
+  base/src/ecflow/base/stc/SServerLoadCmd.cpp
+  base/src/ecflow/base/stc/SStatsCmd.cpp
+  base/src/ecflow/base/stc/SStringCmd.cpp
+  base/src/ecflow/base/stc/SStringVecCmd.cpp
+  base/src/ecflow/base/stc/SSuitesCmd.cpp
+  base/src/ecflow/base/stc/SSyncCmd.cpp
+  base/src/ecflow/base/stc/ServerToClientCmd.cpp
+  base/src/ecflow/base/stc/StcCmd.cpp
+  base/src/ecflow/base/stc/ZombieGetCmd.cpp
+
+  # Client -- Headers
+  client/src/ecflow/client/ClientCmdCache.hpp
+  client/src/ecflow/client/ClientEnvironment.hpp
+  client/src/ecflow/client/ClientInvoker.hpp
+  client/src/ecflow/client/ClientOptions.hpp
+  client/src/ecflow/client/Help.hpp
+  client/src/ecflow/client/Rtt.hpp
+  client/src/ecflow/client/UrlCmd.hpp
+  # Client -- Sources
+  client/src/ecflow/client/ClientCmdCache.cpp
+  client/src/ecflow/client/Rtt.cpp
+  client/src/ecflow/client/ClientEnvironment.cpp
+  client/src/ecflow/client/ClientInvoker.cpp
+  client/src/ecflow/client/Help.cpp
+  client/src/ecflow/client/Rtt.cpp
+  client/src/ecflow/client/ClientOptions.cpp
+  client/src/ecflow/client/UrlCmd.cpp
+
+  # Core -- Headers
+  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_version.h
+  ${CMAKE_BINARY_DIR}/generated/src/ecflow/core/ecflow_source_build_dir.h
+  core/src/ecflow/core/AssertTimer.hpp
+  core/src/ecflow/core/Cal.hpp
+  core/src/ecflow/core/Calendar.hpp
+  core/src/ecflow/core/CalendarUpdateParams.hpp
+  core/src/ecflow/core/CheckPt.hpp
+  core/src/ecflow/core/Child.hpp
+  core/src/ecflow/core/Chrono.hpp
+  core/src/ecflow/core/CommandLine.hpp
+  core/src/ecflow/core/DState.hpp
+  core/src/ecflow/core/DebugPerf.hpp
+  core/src/ecflow/core/DurationTimer.hpp
+  core/src/ecflow/core/Ecf.hpp
+  core/src/ecflow/core/EcfPortLock.hpp
+  core/src/ecflow/core/Extract.hpp
+  core/src/ecflow/core/File.hpp
+  core/src/ecflow/core/File_r.hpp
+  core/src/ecflow/core/Filesystem.hpp
+  core/src/ecflow/core/Host.hpp
+  core/src/ecflow/core/Indentor.hpp
+  core/src/ecflow/core/Log.hpp
+  core/src/ecflow/core/LogVerification.hpp
+  core/src/ecflow/core/Message.hpp
+  core/src/ecflow/core/NOrder.hpp
+  core/src/ecflow/core/NState.hpp
+  core/src/ecflow/core/NodePath.hpp
+  core/src/ecflow/core/Overload.hpp
+  core/src/ecflow/core/Passwd.hpp
+  core/src/ecflow/core/PasswdFile.hpp
+  core/src/ecflow/core/PasswordEncryption.hpp
+  core/src/ecflow/core/Pid.hpp
+  core/src/ecflow/core/PrintStyle.hpp
+  core/src/ecflow/core/SState.hpp
+  core/src/ecflow/core/Serialization.hpp
+  core/src/ecflow/core/Stl.hpp
+  core/src/ecflow/core/Str.hpp
+  core/src/ecflow/core/StringSplitter.hpp
+  core/src/ecflow/core/TimeSeries.hpp
+  core/src/ecflow/core/TimeSlot.hpp
+  core/src/ecflow/core/TimeStamp.hpp
+  core/src/ecflow/core/User.hpp
+  core/src/ecflow/core/Version.hpp
+  core/src/ecflow/core/WhiteListFile.hpp
+  core/src/ecflow/core/cereal_boost_time.hpp
+  core/src/ecflow/core/cereal_optional_nvp.hpp
+  core/src/ecflow/core/perf_timer.hpp
+  core/src/ecflow/core/exceptions/Exceptions.hpp
+  # Core -- Sources
+  core/src/ecflow/core/AssertTimer.cpp
+  core/src/ecflow/core/Cal.cpp
+  core/src/ecflow/core/Calendar.cpp
+  core/src/ecflow/core/Child.cpp
+  core/src/ecflow/core/Chrono.cpp
+  core/src/ecflow/core/CommandLine.cpp
+  core/src/ecflow/core/DState.cpp
+  core/src/ecflow/core/DurationTimer.cpp
+  core/src/ecflow/core/Ecf.cpp
+  core/src/ecflow/core/Extract.cpp
+  core/src/ecflow/core/File.cpp
+  core/src/ecflow/core/File_r.cpp
+  core/src/ecflow/core/Filesystem.cpp
+  core/src/ecflow/core/Host.cpp
+  core/src/ecflow/core/Indentor.cpp
+  core/src/ecflow/core/Log.cpp
+  core/src/ecflow/core/LogVerification.cpp
+  core/src/ecflow/core/NOrder.cpp
+  core/src/ecflow/core/NState.cpp
+  core/src/ecflow/core/NodePath.cpp
+  core/src/ecflow/core/Passwd.cpp
+  core/src/ecflow/core/PasswdFile.cpp
+  core/src/ecflow/core/Pid.cpp
+  core/src/ecflow/core/PrintStyle.cpp
+  core/src/ecflow/core/SState.cpp
+  core/src/ecflow/core/Str.cpp
+  core/src/ecflow/core/StringSplitter.cpp
+  core/src/ecflow/core/TimeSeries.cpp
+  core/src/ecflow/core/TimeSlot.cpp
+  core/src/ecflow/core/TimeStamp.cpp
+  core/src/ecflow/core/User.cpp
+  core/src/ecflow/core/Version.cpp
+  core/src/ecflow/core/WhiteListFile.cpp
+
+  # Node -- Headers
+  node/src/ecflow/node/AbstractObserver.hpp
+  node/src/ecflow/node/Alias.hpp
+  node/src/ecflow/node/Aspect.hpp
+  node/src/ecflow/node/Attr.hpp
+  node/src/ecflow/node/AutoRestoreAttr.hpp
+  node/src/ecflow/node/AvisoAttr.hpp
+  node/src/ecflow/node/ClientSuiteMgr.hpp
+  node/src/ecflow/node/ClientSuites.hpp
+  node/src/ecflow/node/CmdContext.hpp
+  node/src/ecflow/node/Defs.hpp
+  node/src/ecflow/node/DefsDelta.hpp
+  node/src/ecflow/node/DefsTreeVisitor.hpp
+  node/src/ecflow/node/EcfFile.hpp
+  node/src/ecflow/node/ExprAst.hpp
+  node/src/ecflow/node/ExprAstVisitor.hpp
+  node/src/ecflow/node/ExprDuplicate.hpp
+  node/src/ecflow/node/ExprParser.hpp
+  node/src/ecflow/node/Expression.hpp
+  node/src/ecflow/node/Family.hpp
+  node/src/ecflow/node/Flag.hpp
+  node/src/ecflow/node/InLimit.hpp
+  node/src/ecflow/node/InLimitMgr.hpp
+  node/src/ecflow/node/JobCreationCtrl.hpp
+  node/src/ecflow/node/JobProfiler.hpp
+  node/src/ecflow/node/Jobs.hpp
+  node/src/ecflow/node/JobsParam.hpp
+  node/src/ecflow/node/Limit.hpp
+  node/src/ecflow/node/LimitFwd.hpp
+  node/src/ecflow/node/Memento.hpp
+  node/src/ecflow/node/MirrorAttr.hpp
+  node/src/ecflow/node/MiscAttrs.hpp
+  node/src/ecflow/node/Node.hpp
+  node/src/ecflow/node/NodeContainer.hpp
+  node/src/ecflow/node/NodeFwd.hpp
+  node/src/ecflow/node/NodeState.hpp
+  node/src/ecflow/node/NodeStats.hpp
+  node/src/ecflow/node/NodeTreeVisitor.hpp
+  node/src/ecflow/node/Operations.hpp
+  node/src/ecflow/node/ResolveExternsVisitor.hpp
+  node/src/ecflow/node/ServerState.hpp
+  node/src/ecflow/node/Signal.hpp
+  node/src/ecflow/node/Submittable.hpp
+  node/src/ecflow/node/Suite.hpp
+  node/src/ecflow/node/SuiteChanged.hpp
+  node/src/ecflow/node/System.hpp
+  node/src/ecflow/node/Task.hpp
+  node/src/ecflow/node/TaskScriptGenerator.hpp
+  node/src/ecflow/node/move_peer.hpp
+  node/src/ecflow/node/formatter/AvisoFormatter.hpp
+  node/src/ecflow/node/formatter/Format.hpp
+  node/src/ecflow/node/formatter/Formatter.hpp
+  node/src/ecflow/node/formatter/MirrorFormatter.hpp
+  node/src/ecflow/node/parser/AutoArchiveParser.hpp
+  node/src/ecflow/node/parser/AutoCancelParser.hpp
+  node/src/ecflow/node/parser/AutoRestoreParser.hpp
+  node/src/ecflow/node/parser/AvisoParser.hpp
+  node/src/ecflow/node/parser/CalendarParser.hpp
+  node/src/ecflow/node/parser/ClockParser.hpp
+  node/src/ecflow/node/parser/CronParser.hpp
+  node/src/ecflow/node/parser/DateParser.hpp
+  node/src/ecflow/node/parser/DayParser.hpp
+  node/src/ecflow/node/parser/DefsParser.hpp
+  node/src/ecflow/node/parser/DefsStateParser.hpp
+  node/src/ecflow/node/parser/DefsStatusParser.hpp
+  node/src/ecflow/node/parser/DefsStructureParser.hpp
+  node/src/ecflow/node/parser/EventParser.hpp
+  node/src/ecflow/node/parser/ExternParser.hpp
+  node/src/ecflow/node/parser/GenericParser.hpp
+  node/src/ecflow/node/parser/InlimitParser.hpp
+  node/src/ecflow/node/parser/LabelParser.hpp
+  node/src/ecflow/node/parser/LateParser.hpp
+  node/src/ecflow/node/parser/LimitParser.hpp
+  node/src/ecflow/node/parser/MeterParser.hpp
+  node/src/ecflow/node/parser/MirrorParser.cpp
+  node/src/ecflow/node/parser/Parser.hpp
+  node/src/ecflow/node/parser/QueueParser.hpp
+  node/src/ecflow/node/parser/RepeatParser.hpp
+  node/src/ecflow/node/parser/TimeParser.hpp
+  node/src/ecflow/node/parser/TodayParser.hpp
+  node/src/ecflow/node/parser/TriggerParser.hpp
+  node/src/ecflow/node/parser/VariableParser.hpp
+  node/src/ecflow/node/parser/VerifyParser.hpp
+  node/src/ecflow/node/parser/ZombieAttrParser.hpp
+  # Node -- Sources
+  node/src/ecflow/node/Alias.cpp
+  node/src/ecflow/node/Attr.cpp
+  node/src/ecflow/node/AutoRestoreAttr.cpp
+  node/src/ecflow/node/AvisoAttr.cpp
+  node/src/ecflow/node/ClientSuiteMgr.cpp
+  node/src/ecflow/node/ClientSuites.cpp
+  node/src/ecflow/node/CmdContext.cpp
+  node/src/ecflow/node/Defs.cpp
+  node/src/ecflow/node/DefsDelta.cpp
+  node/src/ecflow/node/EcfFile.cpp
+  node/src/ecflow/node/ExprAst.cpp
+  node/src/ecflow/node/ExprAstVisitor.cpp
+  node/src/ecflow/node/ExprDuplicate.cpp
+  node/src/ecflow/node/ExprParser.cpp
+  node/src/ecflow/node/Expression.cpp
+  node/src/ecflow/node/Family.cpp
+  node/src/ecflow/node/Flag.cpp
+  node/src/ecflow/node/InLimit.cpp
+  node/src/ecflow/node/InLimitMgr.cpp
+  node/src/ecflow/node/JobCreationCtrl.cpp
+  node/src/ecflow/node/JobProfiler.cpp
+  node/src/ecflow/node/Jobs.cpp
+  node/src/ecflow/node/JobsParam.cpp
+  node/src/ecflow/node/Limit.cpp
+  node/src/ecflow/node/Memento.cpp
+  node/src/ecflow/node/MirrorAttr.cpp
+  node/src/ecflow/node/MiscAttrs.cpp
+  node/src/ecflow/node/Node.cpp
+  node/src/ecflow/node/NodeAdd.cpp
+  node/src/ecflow/node/NodeChange.cpp
+  node/src/ecflow/node/NodeContainer.cpp
+  node/src/ecflow/node/NodeDelete.cpp
+  node/src/ecflow/node/NodeFind.cpp
+  node/src/ecflow/node/NodeMemento.cpp
+  node/src/ecflow/node/NodeStats.cpp
+  node/src/ecflow/node/NodeTime.cpp
+  node/src/ecflow/node/NodeTreeVisitor.cpp
+  node/src/ecflow/node/ResolveExternsVisitor.cpp
+  node/src/ecflow/node/ServerState.cpp
+  node/src/ecflow/node/Signal.cpp
+  node/src/ecflow/node/Submittable.cpp
+  node/src/ecflow/node/Suite.cpp
+  node/src/ecflow/node/SuiteChanged.cpp
+  node/src/ecflow/node/System.cpp
+  node/src/ecflow/node/Task.cpp
+  node/src/ecflow/node/TaskScriptGenerator.cpp
+  node/src/ecflow/node/parser/AutoArchiveParser.cpp
+  node/src/ecflow/node/parser/AutoCancelParser.cpp
+  node/src/ecflow/node/parser/AutoRestoreParser.cpp
+  node/src/ecflow/node/parser/AvisoParser.cpp
+  node/src/ecflow/node/parser/CalendarParser.cpp
+  node/src/ecflow/node/parser/ClockParser.cpp
+  node/src/ecflow/node/parser/CronParser.cpp
+  node/src/ecflow/node/parser/DateParser.cpp
+  node/src/ecflow/node/parser/DayParser.cpp
+  node/src/ecflow/node/parser/DefsParser.cpp
+  node/src/ecflow/node/parser/DefsStateParser.cpp
+  node/src/ecflow/node/parser/DefsStatusParser.cpp
+  node/src/ecflow/node/parser/DefsStructureParser.cpp
+  node/src/ecflow/node/parser/EventParser.cpp
+  node/src/ecflow/node/parser/ExternParser.cpp
+  node/src/ecflow/node/parser/GenericParser.cpp
+  node/src/ecflow/node/parser/InlimitParser.cpp
+  node/src/ecflow/node/parser/LabelParser.cpp
+  node/src/ecflow/node/parser/LateParser.cpp
+  node/src/ecflow/node/parser/LimitParser.cpp
+  node/src/ecflow/node/parser/MeterParser.cpp
+  node/src/ecflow/node/parser/MirrorParser.cpp
+  node/src/ecflow/node/parser/Parser.cpp
+  node/src/ecflow/node/parser/QueueParser.cpp
+  node/src/ecflow/node/parser/RepeatParser.cpp
+  node/src/ecflow/node/parser/TimeParser.cpp
+  node/src/ecflow/node/parser/TodayParser.cpp
+  node/src/ecflow/node/parser/TriggerParser.cpp
+  node/src/ecflow/node/parser/VariableParser.cpp
+  node/src/ecflow/node/parser/VerifyParser.cpp
+  node/src/ecflow/node/parser/ZombieAttrParser.cpp
+
+  # Server -- Headers
+  server/src/ecflow/server/BaseServer.hpp
+  server/src/ecflow/server/CheckPtSaver.hpp
+  server/src/ecflow/server/NodeTreeTraverser.hpp
+  server/src/ecflow/server/PeriodicScheduler.hpp
+  server/src/ecflow/server/Server.hpp
+  server/src/ecflow/server/ServerEnvironment.hpp
+  server/src/ecflow/server/ServerOptions.hpp
+  server/src/ecflow/server/SslServer.hpp
+  server/src/ecflow/server/SslTcpServer.hpp
+  server/src/ecflow/server/TcpBaseServer.hpp
+  server/src/ecflow/server/TcpServer.hpp
+  $<$<BOOL:${OPENSSL_FOUND}>:server/src/ecflow/server/SslServer.hpp>
+  $<$<BOOL:${OPENSSL_FOUND}>:server/src/ecflow/server/SslTcpServer.hpp>
+  # Server -- Sources
+  server/src/ecflow/server/BaseServer.cpp
+  server/src/ecflow/server/CheckPtSaver.cpp
+  server/src/ecflow/server/NodeTreeTraverser.cpp
+  server/src/ecflow/server/PeriodicScheduler.cpp
+  server/src/ecflow/server/Server.cpp
+  server/src/ecflow/server/ServerEnvironment.cpp
+  server/src/ecflow/server/ServerOptions.cpp
+  server/src/ecflow/server/TcpBaseServer.cpp
+  server/src/ecflow/server/TcpServer.cpp
+  $<$<BOOL:${OPENSSL_FOUND}>:server/src/ecflow/server/SslServer.cpp>
+  $<$<BOOL:${OPENSSL_FOUND}>:server/src/ecflow/server/SslTcpServer.cpp>
+
+  # Service -- Headers
+  service/src/ecflow/service/auth/Credentials.hpp
+  service/src/ecflow/service/aviso/Aviso.hpp
+  service/src/ecflow/service/aviso/AvisoService.hpp
+  service/src/ecflow/service/aviso/etcd/Client.hpp
+  service/src/ecflow/service/aviso/etcd/Range.hpp
+  service/src/ecflow/service/executor/PeriodicTaskExecutor.hpp
+  service/src/ecflow/service/mirror/Mirror.hpp
+  service/src/ecflow/service/mirror/MirrorClient.hpp
+  service/src/ecflow/service/mirror/MirrorService.hpp
+  service/src/ecflow/service/Controller.hpp
+  service/src/ecflow/service/Log.hpp
+  service/src/ecflow/service/Registry.hpp
+  # Service -- Sources
+  service/src/ecflow/service/auth/Credentials.cpp
+  service/src/ecflow/service/aviso/Aviso.cpp
+  service/src/ecflow/service/aviso/AvisoService.cpp
+  service/src/ecflow/service/aviso/etcd/Range.cpp
+  service/src/ecflow/service/aviso/etcd/Client.cpp
+  service/src/ecflow/service/mirror/Mirror.cpp
+  service/src/ecflow/service/mirror/MirrorClient.cpp
+  service/src/ecflow/service/mirror/MirrorService.cpp
+  service/src/ecflow/service/Controller.cpp
+  service/src/ecflow/service/Registry.cpp
+
+  # UDP -- Headers
+  udp/src/ecflow/udp/ClientAPI.hpp
+  udp/src/ecflow/udp/RequestHandler.hpp
+  udp/src/ecflow/udp/Trace.hpp
+  udp/src/ecflow/udp/UDPServer.hpp
+  udp/src/ecflow/udp/UDPServerEnvironment.hpp
+  udp/src/ecflow/udp/UDPServerOptions.hpp
+  # UDP -- Sources
+  udp/src/ecflow/udp/ClientAPI.cpp
+  udp/src/ecflow/udp/RequestHandler.cpp
+  udp/src/ecflow/udp/Trace.cpp
+  udp/src/ecflow/udp/UDPServerEnvironment.cpp
+  udp/src/ecflow/udp/UDPServerOptions.cpp
+)
+
+
+ecbuild_add_library(
+  TARGET
+  ecflow_all
+  NOINSTALL
+  TYPE STATIC
+  SOURCES
+  ${srcs}
+  PUBLIC_INCLUDES
+    attribute/src
+    base/src
+    client/src
+    core/src
+    node/src
+    service/src
+    server/src
+    udp/src
+    ${CMAKE_BINARY_DIR}/generated/src
+  PUBLIC_LIBS
+    nlohmann::json
+    cereal::cereal # this needs to be public as it appears in public header files used downstream
+    httplib::httplib
+    $<$<VERSION_LESS:${Boost_VERSION},1.69.0>:Boost::system>
+    Boost::filesystem
+    Boost::date_time
+    Boost::program_options
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    $<$<NOT:$<BOOL:${APPLE}>>:crypt>
+    Threads::Threads
+  DEFINITIONS
+    CMAKE
+)
+target_clangformat(ecflow_all)
+
+
+add_subdirectory(core)
+add_subdirectory(service)
+add_subdirectory(attribute)
+add_subdirectory(node)
+add_subdirectory(base)
+add_subdirectory(simulator)
+add_subdirectory(client)
+
+if (ENABLE_SERVER)
+  add_subdirectory(server)
+  add_subdirectory(test)
+endif ()
+
+if (ENABLE_PYTHON)
+  if (ENABLE_PYTHON_PTR_REGISTER)
+    add_definitions(-DECF_ENABLE_PYTHON_PTR_REGISTER)
+  endif ()
+  add_subdirectory(pyext)
+endif ()
+
+if (ENABLE_HTTP)
+  add_subdirectory(rest)
+endif ()
+
+if (ENABLE_UDP)
+  add_subdirectory(udp)
+endif ()
diff -pruN 5.12.4-1/libs/attribute/CMakeLists.txt 5.13.0-1/libs/attribute/CMakeLists.txt
--- 5.12.4-1/libs/attribute/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+set(test_srcs
+  # Sources
+  test/TestAttributes_main.cpp
+  test/TestAttrSerialization.cpp
+  test/TestCron.cpp
+  test/TestDateAttr.cpp
+  test/TestDayAttr.cpp
+  test/TestLabel.cpp
+  test/TestLateAttr.cpp
+  test/TestMigration.cpp
+  test/TestRepeat.cpp
+  test/TestSizeOf.cpp
+  test/TestTimeAttr.cpp
+  test/TestTodayAttr.cpp
+  test/TestVariable.cpp
+  test/TestVariableMap.cpp
+  test/TestZombieAttr.cpp
+)
+
+ecbuild_add_test(
+  TARGET
+    u_attributes
+  LABELS
+    unit
+    nightly
+  SOURCES
+    ${test_srcs}
+  INCLUDES
+    ../core/test
+  LIBS
+    ecflow_all
+  TEST_DEPENDS
+    u_core
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+)
+target_clangformat(u_attributes
+  CONDITION ENABLE_TESTS
+)
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,124 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+#ifdef DEBUG
+    #include <boost/date_time/posix_time/time_formatters.hpp>
+#endif
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+namespace ecf {
+
+void AutoArchiveAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += "\n";
+}
+
+std::string AutoArchiveAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void AutoArchiveAttr::write(std::string& ret) const {
+    ret += "autoarchive ";
+    if (days_) {
+        ret += ecf::convert_to<std::string>(time_.hour() / 24);
+        if (idle_)
+            ret += " -i";
+        return;
+    }
+    if (relative_)
+        ret += "+";
+    time_.print(ret);
+    if (idle_)
+        ret += " -i";
+}
+
+bool AutoArchiveAttr::operator==(const AutoArchiveAttr& rhs) const {
+    if (relative_ != rhs.relative_)
+        return false;
+    if (days_ != rhs.days_)
+        return false;
+    if (idle_ != rhs.idle_)
+        return false;
+    return time_.operator==(rhs.time_);
+}
+
+bool AutoArchiveAttr::isFree(
+    const ecf::Calendar& calendar,
+    const std::pair<NState, boost::posix_time::time_duration>& last_state_and_change_duration) const {
+    //                                                               suiteTime()
+    //  suiteDurationAtComplete        autoarchive time              calendar duration
+    //        |                             |                             |
+    //        V                             V                             V
+    // ----------------------------------------------------------------------------------> time
+    //        ^                                                           ^
+    //        |--------elapsed time---------------------------------------|
+    //
+    //
+
+    bool is_valid_state = false;
+    if (last_state_and_change_duration.first == NState::COMPLETE)
+        is_valid_state = true;
+    if (idle_) {
+        if (last_state_and_change_duration.first == NState::QUEUED)
+            is_valid_state = true;
+        if (last_state_and_change_duration.first == NState::ABORTED)
+            is_valid_state = true;
+    }
+    if (!is_valid_state) {
+        return false;
+    }
+
+    if (relative_) {
+        time_duration time_elapsed = calendar.duration() - last_state_and_change_duration.second;
+        LOG_ASSERT(!time_elapsed.is_negative(), "should always be positive or some things gone wrong");
+        if (time_elapsed >= time_.duration()) {
+            return true;
+        }
+    }
+    else {
+        // real time
+        // #ifdef DEBUG
+        //     cout << "real time time_(" << to_simple_string(time_.duration())
+        //          << ") calendar.suiteTime().time_of_day(" << to_simple_string(calendar.suiteTime().time_of_day()) <<
+        //          ")\n";
+        // #endif
+        if (calendar.suiteTime().time_of_day() >= time_.duration()) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+template <class Archive>
+void AutoArchiveAttr::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(time_));
+    CEREAL_OPTIONAL_NVP(ar, relative_, [this]() { return !relative_; }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, days_, [this]() { return days_; });          // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, idle_, [this]() { return idle_; });          // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(AutoArchiveAttr);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoArchiveAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_AutoArchiveAttr_HPP
+#define ecflow_attribute_AutoArchiveAttr_HPP
+
+#include <cstdint>
+
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/TimeSlot.hpp"
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+namespace ecf {
+
+// Use compiler ,  destructor, assignment, copy constructor
+class AutoArchiveAttr {
+public:
+    AutoArchiveAttr() = default;
+    AutoArchiveAttr(int hour, int minute, bool relative, bool idle = false)
+        : time_(hour, minute),
+          relative_(relative),
+          idle_(idle) {}
+    AutoArchiveAttr(const TimeSlot& ts, bool relative, bool idle = false)
+        : time_(ts),
+          relative_(relative),
+          idle_(idle) {}
+    explicit AutoArchiveAttr(int days, bool idle = false) : time_(TimeSlot(days * 24, 0)), days_(true), idle_(idle) {}
+
+    void print(std::string&) const;
+    bool operator==(const AutoArchiveAttr& rhs) const;
+    bool operator<(const AutoArchiveAttr& rhs) const { return time_ < rhs.time(); }
+    bool isFree(const ecf::Calendar&,
+                const std::pair<NState, boost::posix_time::time_duration>& last_state_and_change_duration) const;
+
+    std::string toString() const;
+
+    const TimeSlot& time() const { return time_; }
+    bool relative() const { return relative_; }
+    bool days() const { return days_; }
+    bool idle() const { return idle_; }
+
+private:
+    void write(std::string&) const;
+
+private:
+    TimeSlot time_;
+    bool relative_{true};
+    bool days_{false};
+    bool idle_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_attribute_AutoArchiveAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,103 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+#ifdef DEBUG
+    #include <boost/date_time/posix_time/time_formatters.hpp>
+#endif
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+namespace ecf {
+
+void AutoCancelAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += "\n";
+}
+
+std::string AutoCancelAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void AutoCancelAttr::write(std::string& ret) const {
+    ret += "autocancel ";
+    if (days_) {
+        ret += ecf::convert_to<std::string>(time_.hour() / 24);
+        return;
+    }
+
+    if (relative_)
+        ret += "+";
+    time_.print(ret);
+}
+
+bool AutoCancelAttr::operator==(const AutoCancelAttr& rhs) const {
+    if (relative_ != rhs.relative_)
+        return false;
+    if (days_ != rhs.days_)
+        return false;
+    return time_.operator==(rhs.time_);
+}
+
+bool AutoCancelAttr::isFree(const ecf::Calendar& calendar,
+                            const boost::posix_time::time_duration& suiteDurationAtComplete) const {
+    //                                                               suiteTime()
+    //  suiteDurationAtComplete        autocancel time               calendar duration
+    //        |                             |                             |
+    //        V                             V                             V
+    // ----------------------------------------------------------------------------------> time
+    //        ^                                                           ^
+    //        |--------elapsed time---------------------------------------|
+    //
+    //
+
+    if (relative_) {
+        time_duration timeElapsedAfterComplete = calendar.duration() - suiteDurationAtComplete;
+        LOG_ASSERT(!timeElapsedAfterComplete.is_negative(), "should always be positive or some things gone wrong");
+        if (timeElapsedAfterComplete >= time_.duration()) {
+            return true;
+        }
+    }
+    else {
+        // real time
+        // #ifdef DEBUG
+        //		cout << "real time time_(" << to_simple_string(time_.duration())
+        //		     << ") calendar.suiteTime().time_of_day(" <<
+        // to_simple_string(calendar.suiteTime().time_of_day()) << ")\n"; #endif
+        if (calendar.suiteTime().time_of_day() >= time_.duration()) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+template <class Archive>
+void AutoCancelAttr::serialize(Archive& ar, std::uint32_t const /*version*/) {
+    ar(CEREAL_NVP(time_));
+    CEREAL_OPTIONAL_NVP(ar, relative_, [this]() { return !relative_; }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, days_, [this]() { return days_; });          // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(AutoCancelAttr);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/AutoCancelAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,58 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_AutoCancelAttr_HPP
+#define ecflow_attribute_AutoCancelAttr_HPP
+
+#include <cstdint>
+
+#include "ecflow/core/TimeSlot.hpp"
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+namespace ecf {
+
+// Use compiler ,  destructor, assignment, copy constructor
+class AutoCancelAttr {
+public:
+    AutoCancelAttr() = default;
+    AutoCancelAttr(int hour, int minute, bool relative) : time_(hour, minute), relative_(relative) {}
+    AutoCancelAttr(const TimeSlot& ts, bool relative) : time_(ts), relative_(relative) {}
+    explicit AutoCancelAttr(int days) : time_(TimeSlot(days * 24, 0)), days_(true) {}
+
+    void print(std::string&) const;
+    bool operator==(const AutoCancelAttr& rhs) const;
+    bool operator<(const AutoCancelAttr& rhs) const { return time_ < rhs.time(); }
+    bool isFree(const ecf::Calendar&, const boost::posix_time::time_duration& suiteDurationAtComplete) const;
+
+    std::string toString() const;
+
+    const TimeSlot& time() const { return time_; }
+    bool relative() const { return relative_; }
+    bool days() const { return days_; }
+
+private:
+    void write(std::string& ret) const;
+
+private:
+    TimeSlot time_;
+    bool relative_{true};
+    bool days_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_attribute_AutoCancelAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/ClockAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/ClockAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/ClockAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/ClockAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,221 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/ClockAttr.hpp"
+
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+//==========================================================================================
+
+ClockAttr::ClockAttr(const boost::posix_time::ptime& time, bool hybrid, bool positiveGain)
+    : gain_(0),
+      state_change_no_(Ecf::incr_state_change_no()),
+      hybrid_(hybrid),
+      positiveGain_(positiveGain) {
+    boost::gregorian::date theDate = time.date();
+    day_                           = theDate.day();
+    month_                         = theDate.month();
+    year_                          = theDate.year();
+
+    tm t  = to_tm(time);
+    gain_ = t.tm_hour * 3600 + t.tm_min * 60 + t.tm_sec;
+}
+
+ClockAttr::ClockAttr(int day, int month, int year, bool hybrid)
+    : gain_(0),
+      day_(day),
+      month_(month),
+      year_(year),
+      state_change_no_(Ecf::incr_state_change_no()),
+      hybrid_(hybrid) {
+    // Will throw std::out_of_range exception
+    DateAttr::checkDate(day, month, year, false /* for calendars we don't allow wild carding */);
+}
+
+ClockAttr::ClockAttr(bool hybrid) : state_change_no_(Ecf::incr_state_change_no()), hybrid_(hybrid) {
+}
+
+void ClockAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += "\n";
+}
+
+std::string ClockAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void ClockAttr::write(std::string& ss) const {
+    if (!end_clock_) {
+        ss += "clock ";
+        if (hybrid_)
+            ss += "hybrid ";
+        else
+            ss += "real ";
+    }
+    else {
+        ss += "endclock ";
+    }
+
+    if (day_ != 0) {
+        ss += ecf::convert_to<std::string>(day_);
+        ss += ".";
+        ss += ecf::convert_to<std::string>(month_);
+        ss += ".";
+        ss += ecf::convert_to<std::string>(year_);
+        ss += " ";
+    }
+
+    if (gain_ != 0) {
+        if (positiveGain_)
+            ss += "+";
+        ss += ecf::convert_to<std::string>(gain_);
+    }
+}
+
+bool ClockAttr::operator==(const ClockAttr& rhs) const {
+    if (hybrid_ != rhs.hybrid_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "hybrid_ != rhs.hybrid_\n";
+        }
+#endif
+        return false;
+    }
+
+    if (day_ != rhs.day_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "day(" << day_ << ") != rhs.day(" << rhs.day_ << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (month_ != rhs.month_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "month_(" << month_ << ") != rhs.month_(" << rhs.month_ << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (year_ != rhs.year_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "year_(" << year_ << ") != rhs.year_(" << rhs.year_ << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (gain_ != rhs.gain_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "gain_(" << gain_ << ") != rhs.gain_(" << rhs.gain_ << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (positiveGain_ != rhs.positiveGain_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "positiveGain_(" << positiveGain_ << ") != rhs.positiveGain_(" << rhs.positiveGain_ << ")\n";
+        }
+#endif
+        return false;
+    }
+
+    return true;
+}
+
+void ClockAttr::date(int day, int month, int year) {
+    // Will throw std::out_of_range exception
+    DateAttr::checkDate(day, month, year, false /* for calendars we don't allow wild carding */);
+    day_             = day;
+    month_           = month;
+    year_            = year;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ClockAttr::set_gain(int hour, int min, bool positiveGain) {
+    positiveGain_    = positiveGain;
+    gain_            = (hour * 3600) + min * 60;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ClockAttr::set_gain_in_seconds(long theGain, bool positiveGain) {
+    positiveGain_    = positiveGain;
+    gain_            = theGain;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ClockAttr::hybrid(bool f) {
+    hybrid_          = f;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ClockAttr::sync() {
+    // When begin_calendar() is called we will sync with computer clock.
+    positiveGain_    = false;
+    gain_            = 0;
+    day_             = 0;
+    month_           = 0;
+    year_            = 0;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ClockAttr::init_calendar(ecf::Calendar& calendar) {
+    Calendar::Clock_t clockType = (hybrid_) ? Calendar::HYBRID : Calendar::REAL;
+    calendar.init(clockType);
+}
+
+void ClockAttr::begin_calendar(ecf::Calendar& calendar) const {
+    calendar.begin(ptime());
+}
+
+boost::posix_time::ptime ClockAttr::ptime() const {
+    if (day_ != 0) {
+        // Use the date given. ie we start from midnight on the given day + gain.
+        boost::gregorian::date theDate(year_, month_, day_);
+        return {theDate, seconds(gain_)};
+    }
+
+    // Get the local time, second level resolution, based on the time zone settings of the computer.
+    boost::posix_time::ptime the_time(Calendar::second_clock_time());
+    the_time += seconds(gain_);
+    return the_time;
+}
+
+template <class Archive>
+void ClockAttr::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(hybrid_));
+    CEREAL_OPTIONAL_NVP(ar, positiveGain_, [this]() { return positiveGain_; });
+    CEREAL_OPTIONAL_NVP(ar, gain_, [this]() { return gain_ != 0; });
+    CEREAL_OPTIONAL_NVP(ar, day_, [this]() { return day_ != 0; });
+    CEREAL_OPTIONAL_NVP(ar, month_, [this]() { return month_ != 0; });
+    CEREAL_OPTIONAL_NVP(ar, year_, [this]() { return year_ != 0; });
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(ClockAttr);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/ClockAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/ClockAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/ClockAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/ClockAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,93 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_ClockAttr_HPP
+#define ecflow_attribute_ClockAttr_HPP
+
+#include <cstdint>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+namespace cereal {
+class access;
+}
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+/// The clock attribute is defined on the suite ONLY
+/// Use default copy constructor and assignment operator, destructor
+/// The clock attribute is used to initialise the calendar object
+/// **********************************************************************
+/// In the OLD sms the date is actually used as a gain factor(well at least
+/// according to the user/reference manual), in the ec-flow
+/// a date, is a date. i.e. it allows us to start a suite in the past.
+///
+/// The Constructor will update the State change number, since it can be added
+/// by the AlterCmd. in the Client Context, state change number is not incremented
+/// ************************************************************************
+///
+class ClockAttr {
+public:
+    /// The following constructor is used for test only. It allows us to
+    /// create a clock attribute initialised with given date and time
+    explicit ClockAttr(const boost::posix_time::ptime&, bool hybrid = false, bool positiveGain = true);
+    ClockAttr(int day, int month, int year, bool hybrid = false);
+    explicit ClockAttr(bool hybrid = false);
+
+    void print(std::string&) const;
+    bool operator==(const ClockAttr& rhs) const;
+
+    void date(int day, int month, int year);
+    void set_gain(int hour, int min, bool positiveGain = true);
+    void set_gain_in_seconds(long theGain, bool positiveGain = true);
+
+    void hybrid(bool f);
+    void set_end_clock() { end_clock_ = true; }
+
+    // clear local attributes so, than when we re-queue suite, we sync with computer clock
+    void sync();
+
+    void init_calendar(ecf::Calendar&);
+    void begin_calendar(ecf::Calendar&) const;
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    // access
+    int day() const { return day_; }
+    int month() const { return month_; }
+    int year() const { return year_; }
+    long gain() const { return gain_; }
+    bool positive_gain() const { return positiveGain_; }
+    bool hybrid() const { return hybrid_; }
+    std::string toString() const;
+    boost::posix_time::ptime ptime() const;
+
+private:
+    void write(std::string& os) const;
+
+private:
+    long gain_{0}; // in seconds
+    int day_{0};
+    int month_{0};
+    int year_{0};
+
+    unsigned int state_change_no_; // *not* persisted, only used on server side
+    bool hybrid_{false};
+    bool positiveGain_{false};
+    bool end_clock_{false}; // *NOT* persisted, used for end clock, simulator only
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_attribute_ClockAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/CronAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/CronAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/CronAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/CronAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,892 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/CronAttr.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
+#include <boost/token_functions.hpp>
+#include <boost/tokenizer.hpp>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+// #define DEBUG_CRON_ATTR 1
+// #define DEBUG_CRON_PARSING 1
+// #define DEBUG_CRON_SIM 1
+
+namespace ecf {
+
+CronAttr::CronAttr() = default;
+
+CronAttr::CronAttr(const std::string& str) {
+    if (str.empty())
+        throw std::runtime_error("CronAttr::CronAttr : empty string passed");
+    std::vector<std::string> tokens;
+    Str::split(str, tokens);
+    if (tokens.empty())
+        throw std::runtime_error("CronAttr::CronAttr : incorrect time string ?");
+
+    size_t index = 0;
+    timeSeries_  = TimeSeries::create(index, tokens, false /*parse_state*/);
+}
+
+void CronAttr::addWeekDays(const std::vector<int>& w) {
+    weekDays_ = w;
+    for (int day : weekDays_) {
+        if (day < 0 || day > 6) {
+            std::stringstream ss;
+            ss << "Invalid range for day(" << day << ") of the week expected range is 0==Sun to 6==Sat";
+            throw std::out_of_range(ss.str());
+        }
+        auto result = std::find(std::begin(last_week_days_of_month_), std::end(last_week_days_of_month_), day);
+        if (result != std::end(last_week_days_of_month_)) {
+            std::stringstream ss;
+            ss << "Duplicate day(" << day << ") of the week also found in last week day of the month";
+            throw std::runtime_error(ss.str());
+        }
+    }
+}
+void CronAttr::add_last_week_days_of_month(const std::vector<int>& w) {
+    last_week_days_of_month_ = w;
+    for (int day : last_week_days_of_month_) {
+        if (day < 0 || day > 6) {
+            std::stringstream ss;
+            ss << "Invalid range for day(" << day << ") of the week expected range is 0==Sun to 6==Sat";
+            throw std::out_of_range(ss.str());
+        }
+        auto result = std::find(std::begin(weekDays_), std::end(weekDays_), day);
+        if (result != std::end(weekDays_)) {
+            std::stringstream ss;
+            ss << "Duplicate last week day (" << day << ") of the month also found in week day";
+            throw std::runtime_error(ss.str());
+        }
+    }
+}
+
+void CronAttr::addDaysOfMonth(const std::vector<int>& d) {
+    daysOfMonth_ = d;
+    for (int day_of_month : daysOfMonth_) {
+        if (day_of_month < 1 || day_of_month > 31) {
+            std::stringstream ss;
+            ss << "Invalid range for day of month(" << day_of_month << ") expected range is  1-31";
+            throw std::out_of_range(ss.str());
+        }
+    }
+}
+
+void CronAttr::addMonths(const std::vector<int>& m) {
+    months_ = m;
+    for (int month : months_) {
+        if (month < 1 || month > 12) {
+            std::stringstream ss;
+            ss << "Invalid range for month(" << month << ")  expected range is 1==Jan to 12==Dec";
+            throw std::out_of_range(ss.str());
+        }
+    }
+}
+
+void CronAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        timeSeries_.write_state(os, free_);
+    }
+    os += "\n";
+}
+
+std::string CronAttr::name() const {
+    std::string ret;
+    write(ret);
+    timeSeries_.write_state_for_gui(ret, free_);
+    return ret;
+}
+
+std::string CronAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void CronAttr::write(std::string& ret) const {
+    ret += "cron ";
+    if (!weekDays_.empty()) {
+        ret += "-w ";
+        for (size_t i = 0; i < weekDays_.size(); ++i) {
+            ret += ecf::convert_to<std::string>(weekDays_[i]);
+            if (i != weekDays_.size() - 1)
+                ret += ",";
+        }
+        if (last_week_days_of_month_.empty())
+            ret += " ";
+        else
+            ret += ",";
+    }
+    if (!last_week_days_of_month_.empty()) {
+        if (weekDays_.empty())
+            ret += "-w ";
+        for (size_t i = 0; i < last_week_days_of_month_.size(); ++i) {
+            ret += ecf::convert_to<std::string>(last_week_days_of_month_[i]);
+            ret += 'L';
+            if (i != last_week_days_of_month_.size() - 1)
+                ret += ",";
+        }
+        ret += " ";
+    }
+
+    if (!daysOfMonth_.empty()) {
+        ret += "-d ";
+        for (size_t i = 0; i < daysOfMonth_.size(); ++i) {
+            ret += ecf::convert_to<std::string>(daysOfMonth_[i]);
+            if (i != daysOfMonth_.size() - 1)
+                ret += ",";
+        }
+        if (!last_day_of_month_)
+            ret += " ";
+    }
+    if (last_day_of_month_) {
+        if (daysOfMonth_.empty())
+            ret += "-d L ";
+        else
+            ret += ",L ";
+    }
+
+    if (!months_.empty()) {
+        ret += "-m ";
+        for (size_t i = 0; i < months_.size(); ++i) {
+            ret += ecf::convert_to<std::string>(months_[i]);
+            if (i != months_.size() - 1)
+                ret += ",";
+        }
+        ret += " ";
+    }
+
+    timeSeries_.write(ret); // no new line added, up to caller
+}
+
+std::string CronAttr::dump() const {
+    std::stringstream ss;
+    ss << toString();
+    if (free_)
+        ss << " (free)";
+    else
+        ss << " (holding)";
+    return ss.str();
+}
+
+bool CronAttr::operator==(const CronAttr& rhs) const {
+    if (free_ != rhs.free_) {
+        return false;
+    }
+    if (last_day_of_month_ != rhs.last_day_of_month_)
+        return false;
+    if (weekDays_ != rhs.weekDays_)
+        return false;
+    if (last_week_days_of_month_ != rhs.last_week_days_of_month_)
+        return false;
+    if (daysOfMonth_ != rhs.daysOfMonth_)
+        return false;
+    if (months_ != rhs.months_)
+        return false;
+    return timeSeries_.operator==(rhs.timeSeries_);
+}
+bool CronAttr::structureEquals(const CronAttr& rhs) const {
+    if (last_day_of_month_ != rhs.last_day_of_month_)
+        return false;
+    if (weekDays_ != rhs.weekDays_)
+        return false;
+    if (daysOfMonth_ != rhs.daysOfMonth_)
+        return false;
+    if (last_week_days_of_month_ != rhs.last_week_days_of_month_)
+        return false;
+    if (months_ != rhs.months_)
+        return false;
+    return timeSeries_.structureEquals(rhs.timeSeries_);
+}
+
+void CronAttr::calendarChanged(const ecf::Calendar& c) {
+    // ensure this called first , since we need always update for relative duration ECFLOW-1648
+    // This assumes that calendarChanged will set TimeSeries::isValid = true, at day change
+    if (timeSeries_.calendarChanged(c)) {
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+
+    if (free_) {
+        return;
+    }
+
+    // Once a cron is free, it stays free until re-queue
+    if (isFree(c)) {
+        setFree();
+    }
+    // A cron is always re-queable, hence we use isFree to control when it can actually run.
+}
+
+void CronAttr::resetRelativeDuration() {
+    if (timeSeries_.resetRelativeDuration()) {
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+}
+
+void CronAttr::setFree() {
+    free_            = true;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "CronAttr::setFree()\n";
+#endif
+}
+
+void CronAttr::clearFree() {
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "CronAttr::clearFree()\n";
+#endif
+}
+
+void CronAttr::miss_next_time_slot() {
+    // A cron attribute with a single time slot is repeated indefinitely hence always re-queues
+    timeSeries_.miss_next_time_slot();
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+// **************************************************************************************
+// FOR DEBUG THIS IS THE MAIN FUNCTION, AS THIS DECIDES WHETHER WE CONTINE OR STOP
+// **************************************************************************************
+bool CronAttr::checkForRequeue(const ecf::Calendar& calendar) const {
+    // checkForRequeue is called when a task/family has reach the complete state
+    // This simple checks if node should be put in re-queued state
+    // A cron is always re-queable
+
+    // Hence: In order to use this it should be used in conjunction with a
+    // with a parent node that has complete  expression, (& maybe a dummy task)
+    // This will allow its use with a parent repeat somewhere in the hierarchy
+    return true;
+}
+
+bool CronAttr::validForHybrid(const ecf::Calendar& calendar) const {
+    if (timeSeries_.hasIncrement()) {
+        if (last_day_of_month_)
+            return false; // relies on day change
+        if (!months_.empty())
+            return false; // relies on day change
+        if (!daysOfMonth_.empty())
+            return false; // relies on day change
+        if (!weekDays_.empty()) {
+            if (weekDays_.size() != 1)
+                return false; // relies on day change
+            return (weekDays_[0] == calendar.day_of_week());
+        }
+
+        // cron 10:00 20:00 01:00  // valid for hybrid ?
+        return true;
+    }
+
+    // A time series that does not have an increment runs indefinitely and hence relies on day change
+    // cron 23:00
+    return false;
+}
+
+bool CronAttr::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
+    // This will logically AND all the times
+    if (isFree(c))
+        return false;
+
+    // We are here because:
+    //  1/ Not on a valid time slot in the time series
+    //  *OR*
+    //  2/ Logical *AND* of day of week, day of month, or month returned false
+    theReasonWhy += "is cron dependent";
+
+    // Lets say that the time series was NOT free.
+    // First check if week day, day of month, month, matches
+    if (is_day_of_week_day_of_month_and_month_free(c)) {
+
+        if (timeSeries_.is_valid()) {
+
+            // This can apply to single and series
+            boost::posix_time::time_duration calendar_time = timeSeries_.duration(c);
+            if (calendar_time < timeSeries_.start().duration()) {
+                timeSeries_.why(c, theReasonWhy);
+                return true;
+            }
+
+            // calendar_time >= timeSeries_.start().duration()
+            if (timeSeries_.hasIncrement()) {
+                if (calendar_time < timeSeries_.finish().duration()) {
+                    timeSeries_.why(c, theReasonWhy);
+                    return true;
+                }
+            }
+        }
+        // calendar_time >= timeSeries_.start().duration() && calendar_time >= timeSeries_.finish().duration()
+        // past the end of time slot, find next valid date
+    }
+
+    // take into account, user can use run/force complete to miss time slots
+    bool do_a_requeue = timeSeries_.requeueable(c);
+    if (do_a_requeue && weekDays_.empty() && daysOfMonth_.empty() && months_.empty()) {
+        TimeSlot the_next_time_slot = timeSeries_.compute_next_time_slot(c);
+        if (the_next_time_slot.isNULL()) {
+            theReasonWhy += " ( *re-queue* to run at this time ";
+        }
+        else {
+            theReasonWhy += " ( *re-queue* to run at ";
+            theReasonWhy += the_next_time_slot.toString();
+        }
+
+        theReasonWhy += ", otherwise next run is at ";
+    }
+    else {
+        theReasonWhy += " ( next run is at ";
+    }
+
+    // Find the *NEXT* date that matches, and use the first time slot
+    boost::gregorian::date the_next_date = next_date(c);
+    theReasonWhy += timeSeries_.start().toString();
+    theReasonWhy += " ";
+    theReasonWhy += to_simple_string(the_next_date);
+
+    std::stringstream ss;
+    TimeSlot currentTime = TimeSlot(timeSeries_.duration(c));
+    ss << ", current time ";
+    if (timeSeries_.relative())
+        ss << "+";
+    ss << currentTime.toString() << " " << to_simple_string(c.date()) << " )";
+    theReasonWhy += ss.str();
+    return true;
+}
+
+void CronAttr::reset_only() {
+    clearFree();
+    timeSeries_.reset_only();
+}
+
+void CronAttr::reset(const ecf::Calendar& c) {
+    clearFree();
+    timeSeries_.reset(c);
+}
+
+void CronAttr::requeue(const ecf::Calendar& c, bool reset_next_time_slot) {
+    clearFree();
+    timeSeries_.requeue(c, reset_next_time_slot);
+}
+
+bool CronAttr::isFree(const ecf::Calendar& c) const {
+    // The FreeDepCmd can be used to free the crons,
+    if (free_) {
+        return true;
+    }
+
+    if (!timeSeries_.isFree(c))
+        return false;
+
+    // Ok time series is Free
+
+    // ********************************************************************
+    // IMPORTANT: when we have multiple week days, days of month and months
+    // Then we are *ONLY* free, if *ALL* are free, i.e we need AND behaviour
+    // ********************************************************************
+    return is_day_of_week_day_of_month_and_month_free(c);
+}
+
+bool CronAttr::is_day_of_week_day_of_month_and_month_free(const ecf::Calendar& c) const {
+#ifdef DEBUG_CRON_SIM
+    cout << toString() << "  cal : " << to_simple_string(c.date()) << " c.day_of_week:" << c.day_of_week()
+         << " c.day_of_month:" << c.day_of_month();
+    cout.flush();
+#endif
+
+    bool the_week_day_matches =
+        weekDays_.empty() && last_week_days_of_month_.empty(); // week day matches if no week days
+    bool the_day_of_month_matches = daysOfMonth_.empty();      // day of month if no days of month
+    bool the_month_matches        = months_.empty();           // month matches if no months
+
+    if (!weekDays_.empty())
+        the_week_day_matches = week_day_matches(c.day_of_week());
+    if (!the_week_day_matches && !last_week_days_of_month_.empty())
+        the_week_day_matches = last_week_day_of_month_matches(c);
+
+    if (!daysOfMonth_.empty() || last_day_of_month_)
+        the_day_of_month_matches = day_of_month_matches(c.day_of_month(), c);
+    if (!months_.empty())
+        the_month_matches = month_matches(c.month());
+
+    // Remember we *AND* across -w, -d, -m or *OR* for each element in -w, -d,-m
+    bool matches = false;
+    if (daysOfMonth_.empty() && !last_day_of_month_ && months_.empty()) {
+        // cron -w 0L 10:00    # run on the last sunday of each month
+        matches = the_week_day_matches; // only week day,
+    }
+    else {
+        matches = the_week_day_matches && the_day_of_month_matches && the_month_matches;
+    }
+
+#ifdef DEBUG_CRON_SIM
+    if (matches) {
+        cout << " *MATCHES*";
+    }
+    cout << "\n";
+#endif
+
+    return matches;
+}
+
+bool CronAttr::week_day_matches(int theDayOfWeek) const {
+    for (int theWeekDay : weekDays_) {
+        if (theDayOfWeek == theWeekDay)
+            return true;
+    }
+    return false;
+}
+
+bool CronAttr::last_week_day_of_month_matches(const ecf::Calendar& c) const {
+    int cal_day_of_week                                                     = c.day_of_week();
+    boost::gregorian::date last_day_of_month                                = c.date().end_of_month();
+    boost::gregorian::date_duration diff_current_date_and_last_day_of_month = last_day_of_month - c.date();
+
+    for (int cron_last_week_day_of_month : last_week_days_of_month_) {
+        if (cal_day_of_week == cron_last_week_day_of_month) {
+
+            if (diff_current_date_and_last_day_of_month.days() < 7) {
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+bool CronAttr::day_of_month_matches(int theDayOfMonth, const ecf::Calendar& c) const {
+    for (int dayOfMonth : daysOfMonth_) {
+        if (theDayOfMonth == dayOfMonth)
+            return true;
+    }
+    if (last_day_of_month_) {
+        return c.date() == c.date().end_of_month();
+    }
+    return false;
+}
+
+bool CronAttr::month_matches(int theMonth) const {
+    for (int month : months_) {
+        if (theMonth == month)
+            return true;
+    }
+    return false;
+}
+
+//------------------------------------------------------------------
+
+bool CronAttr::checkInvariants(std::string& errormsg) const {
+    return timeSeries_.checkInvariants(errormsg);
+}
+
+//--------------------------------------------------------------
+
+boost::gregorian::date CronAttr::next_date(const ecf::Calendar& calendar) const {
+    // Find the next date that matches, day of week, day of year, and month
+    // that is greater than todays date. This *ASSUMES* day of week, day of month,
+    // and month is *ANDED* together
+    boost::gregorian::date_duration one_day(1);
+    boost::gregorian::date future_date = calendar.date(); // todays date
+
+#ifdef DEBUG_CRON_SIM
+    cout << "cron : " << toString() << "\n";
+    cout << "future_date start : " << to_simple_string(future_date) << "\n";
+#endif
+    future_date += one_day; // add one day, so its in the future
+
+    while (true) {
+
+        bool week_day_matches                   = weekDays_.empty();                // week day matches if no week days
+        bool the_last_week_day_of_month_matches = last_week_days_of_month_.empty(); // matches if EMPTY
+        bool day_of_month_matches               = daysOfMonth_.empty();             // day of month if no days of month
+        bool month_matches                      = months_.empty();                  // month matches if no months
+        if (daysOfMonth_.empty() && last_day_of_month_)
+            day_of_month_matches = false;
+
+        // deal with case where we have: cron -w 0,1
+        for (int weekDay : weekDays_) {
+            if (future_date.day_of_week().as_number() == weekDay) {
+                week_day_matches = true;
+                break;
+            }
+        }
+        // *IMPORTANT* the days in weekDays_ and last_week_days_of_month_ can *NOT* overlap.
+        for (int weekDay : last_week_days_of_month_) {
+            if (future_date.day_of_week().as_number() == weekDay) {
+                boost::gregorian::date_duration diff = future_date - future_date.end_of_month();
+                if (diff.days() < 7) {
+                    the_last_week_day_of_month_matches = true;
+                }
+                break;
+            }
+        }
+
+        // deal with case where we have: cron  -d 14,15,16,L  # L means last day of month
+        if (!daysOfMonth_.empty() || last_day_of_month_) {
+            for (int d : daysOfMonth_) {
+                if (future_date.day() == d) {
+                    day_of_month_matches = true;
+                    break;
+                }
+            }
+            if (last_day_of_month_ && future_date == future_date.end_of_month()) {
+                day_of_month_matches = true;
+            }
+        }
+
+        // deal with case where we have: cron -w 0,1 -d 14,15,16 -m 8, 9
+        for (int month : months_) {
+            if (future_date.month() == month) {
+                month_matches = true;
+                break;
+            }
+        }
+
+        // if it all matches, then return the future day
+        // Remember we *AND* across -w, -d, -m or *OR* for each element in -w, -d,-m
+        if ((week_day_matches || the_last_week_day_of_month_matches) && day_of_month_matches && month_matches) {
+            break; // return future_date, replaced with break to  keep HPUX compiler happy
+                   // otherwise it complains that return at the end of the function is
+                   // unreachable
+        }
+
+        future_date += one_day;
+#ifdef DEBUG_CRON_SIM
+        cout << "future_date " << to_simple_string(future_date) << "\n";
+#endif
+    }
+    return future_date; // should never happen, i.e we can find future date that matches
+}
+
+//=========================================================================================================
+// code for parsing a cron:
+
+static bool isComment(const std::string& token) {
+    if (token.find("#") == std::string::npos)
+        return false;
+    return true;
+}
+
+static bool isTimeSpec(const std::string& token) {
+    if (token.find(Str::COLON()) == std::string::npos)
+        return false;
+    return true;
+}
+
+static bool isOption(const std::string& token) {
+    if (token.find("-w") != std::string::npos)
+        return true;
+    if (token.find("-d") != std::string::npos)
+        return true;
+    if (token.find("-m") != std::string::npos)
+        return true;
+    return false;
+}
+
+static std::string nextToken(size_t& index, const std::vector<std::string>& lineTokens) {
+    assert(index < lineTokens.size());
+    index++;
+    if (index < lineTokens.size()) {
+#ifdef DEBUG_CRON_PARSING
+        cerr << "nextToken lineTokens[" << index << "] = " << lineTokens[index] << "\n";
+#endif
+        return lineTokens[index];
+    }
+#ifdef DEBUG_CRON_PARSING
+    cerr << "nextToken empty \n";
+#endif
+    return string();
+}
+
+std::string extract_list(size_t& index, const std::vector<std::string>& lineTokens) {
+    // cron -w 0,1L,2L,3 -d 1,12,14,L   -m 5,6,7,8   10:00 20:00 01:00
+    assert(index < lineTokens.size());
+
+    // Collate the list of integers, these may have been separated by spaces
+    // since we stop on option or time spec, the top level code should decrement index
+    std::string theIntList;
+    while (index < lineTokens.size() && (!isOption(lineTokens[index]) || !isTimeSpec(lineTokens[index]))) {
+        string theNextToken = nextToken(index, lineTokens);
+        if (theNextToken.empty())
+            break;
+        if (isOption(theNextToken))
+            break;
+        if (isTimeSpec(theNextToken))
+            break;
+        theIntList += theNextToken;
+    }
+#ifdef DEBUG_CRON_PARSING
+    cerr << "theIntList = " << theIntList << "\n";
+#endif
+    return theIntList;
+}
+
+std::vector<int> extract_month(size_t& index, const std::vector<std::string>& lineTokens, const std::string& option) {
+    // cron -w 0,1L,2L,3 -d 1,12,14,L   -m 5,6,7,8   10:00 20:00 01:00
+    assert(index < lineTokens.size());
+
+    // Collate the list of integers, these may have been separated by spaces
+    // since we stop on option or time spec, the top level code should decrement index
+    std::string theIntList = extract_list(index, lineTokens);
+
+    // should have 0,1,2,3
+    std::vector<int> theIntVec;
+    char_separator<char> sep(",", nullptr, boost::drop_empty_tokens);
+    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
+    tokenizer theTokenizer(theIntList, sep);
+
+    for (tokenizer::iterator beg = theTokenizer.begin(); beg != theTokenizer.end(); ++beg) {
+        string theIntToken = *beg;
+        ecf::algorithm::trim(theIntToken);
+        if (theIntToken.empty())
+            continue;
+
+        try {
+            auto theInt = ecf::convert_to<int>(theIntToken);
+            theIntVec.push_back(theInt);
+        }
+        catch (const ecf::bad_conversion&) {
+            std::stringstream ss;
+            ss << "Invalid cron option: " << option;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    return theIntVec;
+}
+
+void extract_days_of_week(size_t& index,
+                          const std::vector<std::string>& lineTokens,
+                          const std::string& option,
+                          std::vector<int>& days_of_week,
+                          std::vector<int>& last_week_days_of_month) {
+    // cron -w 0,1L,2L,3 10:00 20:00 01:00
+    assert(index < lineTokens.size());
+
+    // Collate the list of integers, these may have been separated by spaces
+    // since we stop on option or time spec, the top level code should decrement index
+    std::string theIntList = extract_list(index, lineTokens);
+
+    // should have 0,1,2,3,4L
+    char_separator<char> sep(",", nullptr, boost::drop_empty_tokens);
+    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
+    tokenizer theTokenizer(theIntList, sep);
+
+    for (tokenizer::iterator beg = theTokenizer.begin(); beg != theTokenizer.end(); ++beg) {
+        string theIntToken = *beg;
+        ecf::algorithm::trim(theIntToken);
+        if (theIntToken.empty())
+            continue;
+
+        try {
+            if (theIntToken.size() == 2) {
+                if (theIntToken[1] != 'L') {
+                    std::stringstream ss;
+                    ss << "Invalid cron option: " << option << " " << theIntToken;
+                    throw std::runtime_error(ss.str());
+                }
+                auto theInt = ecf::convert_to<int>(theIntToken[0]);
+                last_week_days_of_month.push_back(theInt);
+            }
+            else {
+                auto theInt = ecf::convert_to<int>(theIntToken);
+                days_of_week.push_back(theInt);
+            }
+        }
+        catch (const ecf::bad_conversion&) {
+            std::stringstream ss;
+            ss << "Invalid cron option: " << option;
+            throw std::runtime_error(ss.str());
+        }
+    }
+}
+
+void extract_days_of_month(size_t& index,
+                           const std::vector<std::string>& lineTokens,
+                           const std::string& option,
+                           std::vector<int>& days_of_month,
+                           bool& last_day_of_month) {
+    // cron -d 1,12,14,L 10:00 20:00 01:00
+
+    assert(index < lineTokens.size());
+
+    // Collate the list of integers, these may have been separated by spaces
+    // since we stop on option or time spec, the top level code should decrement index
+    std::string theIntList = extract_list(index, lineTokens);
+
+    // should have 0,1,2,3,4L
+    char_separator<char> sep(",", nullptr, boost::drop_empty_tokens);
+    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
+    tokenizer theTokenizer(theIntList, sep);
+
+    for (tokenizer::iterator beg = theTokenizer.begin(); beg != theTokenizer.end(); ++beg) {
+        string theIntToken = *beg;
+        ecf::algorithm::trim(theIntToken);
+        if (theIntToken.empty())
+            continue;
+
+        try {
+            if (theIntToken == "L")
+                last_day_of_month = true;
+            else {
+                auto theInt = ecf::convert_to<int>(theIntToken);
+                days_of_month.push_back(theInt);
+            }
+        }
+        catch (const ecf::bad_conversion&) {
+            std::stringstream ss;
+            ss << "Invalid cron option: " << option;
+            throw std::runtime_error(ss.str());
+        }
+    }
+}
+
+void extractOption(CronAttr& cronAttr, size_t& index, const std::vector<std::string>& lineTokens) {
+    assert(index < lineTokens.size());
+    if (lineTokens[index] == "-w") {
+        std::vector<int> days_of_week;
+        std::vector<int> last_week_days_of_month;
+        extract_days_of_week(index, lineTokens, "week days", days_of_week, last_week_days_of_month);
+
+        cronAttr.addWeekDays(days_of_week);
+        cronAttr.add_last_week_days_of_month(last_week_days_of_month);
+    }
+    else if (lineTokens[index] == "-d") {
+        std::vector<int> days_of_month;
+        bool last_day_of_month = false;
+        extract_days_of_month(index, lineTokens, "Days of the month", days_of_month, last_day_of_month);
+
+        cronAttr.addDaysOfMonth(days_of_month);
+        if (last_day_of_month)
+            cronAttr.add_last_day_of_month();
+    }
+    else if (lineTokens[index] == "-m") {
+        cronAttr.addMonths(extract_month(index, lineTokens, "Months"));
+    }
+    else
+        throw std::runtime_error("extractOption: Invalid cron option :" + lineTokens[index]);
+}
+
+void CronAttr::parse(CronAttr& cronAttr, const std::vector<std::string>& lineTokens, size_t index, bool parse_state) {
+    // cron 23:00                 # run every day at 23:00
+    // cron 10:00 20:00 01:00     # run every hour between 10am and 8pm
+    // cron -w 0,1 10:00          # run every sunday and monday at 10am
+    // cron -d 10,11,12 12:00     # run 10th, 11th and 12th of each month at noon
+    // cron -m 1,2,3 12:00        # run on Jan,Feb and March every day at noon.
+    // cron -w 0 -m 5,6,7,8 10:00 20:00 01:00 # run every sunday, between May-Aug, every hour between 10am and 8pm
+    // cron -w 0,1,2L -d 5,6,L  23:00 # run every sunday,monday, and last tuesday of the month, 5,6 on month, and *last*
+    // day of month @11 pm
+
+    // make *sure* a time spec is specified
+    bool time_spec_specified = false;
+    size_t line_tokens_size  = lineTokens.size();
+    while (index < line_tokens_size) {
+
+        const std::string& token = lineTokens[index];
+#ifdef DEBUG_CRON_PARSING
+        cerr << "CronAttr::doParse " << token << "\n";
+#endif
+
+        if (isOption(token)) {
+#ifdef DEBUG_CRON_PARSING
+            cerr << "CronAttr::doParse isOption \n";
+#endif
+            extractOption(cronAttr, index, lineTokens);
+            index--; // since we did a look ahead
+        }
+        else if (!time_spec_specified && isTimeSpec(token)) {
+#ifdef DEBUG_CRON_PARSING
+            cerr << "CronAttr::doParse isTimeSpec \n";
+#endif
+            // index is passed by *reference*, and used skip over time series
+            cronAttr.addTimeSeries(TimeSeries::create(index, lineTokens, parse_state));
+            time_spec_specified = true;
+            if (parse_state) {
+                //  if index is on the comment, back track, so that we can add cron state( free)
+                if (index < line_tokens_size && lineTokens[index] == "#") {
+                    index--;
+                }
+            }
+            else
+                break; // need to read state after comment
+        }
+        else if (isComment(token)) {
+            // cron -m 1,2,3 12:00        # free
+            if (parse_state && index + 1 < line_tokens_size) {
+                if (lineTokens[index + 1] == "free") {
+                    cronAttr.setFree();
+                }
+            }
+            break;
+        }
+        index++;
+    }
+
+    if (!time_spec_specified) {
+        throw std::runtime_error("Invalid cron, no time specified");
+    }
+
+#ifdef DEBUG_CRON_PARSING
+    cronAttr.print(cerr);
+    cerr << "\n";
+#endif
+}
+
+CronAttr CronAttr::create(const std::string& cronString) {
+    std::vector<std::string> lineTokens;
+    Str::split(cronString, lineTokens);
+
+    CronAttr theCronAttr;
+    if (lineTokens.empty()) {
+        return theCronAttr;
+    }
+
+    // adjust the index
+    size_t index = 0;
+    if (lineTokens[0] == "cron") {
+        index = 1;
+    }
+
+    parse(theCronAttr, lineTokens, index);
+    return theCronAttr;
+}
+
+template <class Archive>
+void CronAttr::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(timeSeries_));
+    CEREAL_OPTIONAL_NVP(ar, weekDays_, [this]() { return !weekDays_.empty(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(
+        ar, last_week_days_of_month_, [this]() { return !last_week_days_of_month_.empty(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, daysOfMonth_, [this]() { return !daysOfMonth_.empty(); });         // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, months_, [this]() { return !months_.empty(); });                   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; });                                // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, last_day_of_month_, [this]() { return last_day_of_month_; });      // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, w_, [this]() { return w_ != 0; });                                 // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(CronAttr);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/CronAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/CronAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/CronAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/CronAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,140 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_CronAttr_HPP
+#define ecflow_attribute_CronAttr_HPP
+
+#include "ecflow/core/TimeSeries.hpp"
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+namespace ecf {
+
+// *****************************************************************
+// A cron attribute with a single time slot is repeated indefinitely
+// ******************************************************************
+// Use compiler ,  destructor, assignment, copy constructor,
+class CronAttr {
+public:
+    CronAttr();
+    explicit CronAttr(const std::string& time_series);
+    CronAttr(const TimeSlot& s, const TimeSlot& f, const TimeSlot& i) : timeSeries_(s, f, i) {}
+    explicit CronAttr(const TimeSeries& ts) : timeSeries_(ts) {}
+    CronAttr(int h, int m, bool relative = false) : timeSeries_(h, m, relative) {}
+
+    void print(std::string&) const;
+    bool operator==(const CronAttr& rhs) const;
+    bool operator<(const CronAttr& rhs) const { return timeSeries_ < rhs.timeSeries_; }
+    bool structureEquals(const CronAttr& rhs) const;
+
+    void addWeekDays(const std::vector<int>& w);
+    void add_last_week_days_of_month(const std::vector<int>& w);
+    void addDaysOfMonth(const std::vector<int>& d);
+    void add_last_day_of_month() { last_day_of_month_ = true; }
+    void addMonths(const std::vector<int>& m);
+
+    void addTimeSeries(const TimeSlot& s, const TimeSlot& f, const TimeSlot& i) { timeSeries_ = TimeSeries(s, f, i); }
+    void addTimeSeries(const TimeSeries& ts) { timeSeries_ = ts; }
+    void add_time_series(int h, int m, bool relative = false) { timeSeries_ = TimeSeries(h, m, relative); }
+
+    // Once a cron is free its stays free, until re-queue is called
+    void calendarChanged(const ecf::Calendar& c); // can set attribute free
+    void resetRelativeDuration();
+
+    void reset_only();
+    void reset(const ecf::Calendar& c);
+    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true);
+
+    void miss_next_time_slot();
+    void setFree(); // ensures that isFree() always returns true
+    bool isSetFree() const { return free_; }
+    bool isFree(const ecf::Calendar&) const;
+    bool checkForRequeue(const ecf::Calendar&) const;
+    bool validForHybrid(const ecf::Calendar&) const;
+    bool why(const ecf::Calendar&, std::string& theReasonWhy) const;
+    bool last_day_of_the_month() const { return last_day_of_month_; }
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    // Note: changes in state of timeSeries_, i.e affect the equality operator (used in test)
+    //       must be captured. i.e things like relative duration & next_time_slot are
+    //       reported by the Why command, & hence need to be synced.
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    bool checkInvariants(std::string& errormsg) const;
+
+    // Query:
+    const TimeSeries& time() const { return timeSeries_; }
+    const TimeSeries& time_series() const { return timeSeries_; }
+    bool last_day_of_month() const { return last_day_of_month_; }
+    std::vector<int>::const_iterator week_days_begin() const { return weekDays_.begin(); }
+    std::vector<int>::const_iterator week_days_end() const { return weekDays_.end(); }
+    std::vector<int>::const_iterator last_week_days_of_month_begin() const { return last_week_days_of_month_.begin(); }
+    std::vector<int>::const_iterator last_week_days_end_of_month_end() const { return last_week_days_of_month_.end(); }
+    std::vector<int>::const_iterator days_of_month_begin() const { return daysOfMonth_.begin(); }
+    std::vector<int>::const_iterator days_of_month_end() const { return daysOfMonth_.end(); }
+    std::vector<int>::const_iterator months_begin() const { return months_.begin(); }
+    std::vector<int>::const_iterator months_end() const { return months_.end(); }
+
+    std::string name() const; // for display/gui
+    std::string toString() const;
+    std::string dump() const;
+
+    /// parse the line tokens an create a cron attribute. Can throw std::runtime_error
+    /// The index parameter allows us to parse:
+    /// cron -w 0,1 10:00      // index = 1
+    /// -w 0,1 10:00           // index = 0
+    /// Expect to parse:
+    /// 	cron 23:00                 # run every day at 23:00
+    /// 	cron 10:00 20:00 01:00     # run every hour between 10am and 8pm
+    ///   cron -w 0,1 10:00          # run every sunday and monday at 10am
+    ///   cron -w 0,1L  10:00        # run every sunday and last monday of the month at 10am
+    ///   cron -d 10,11,12 12:00     # run 10th, 11th and 12th of each month at noon
+    ///   cron -d 10,L     12:00     # run 10th, and last day of the month at noon
+    /// 	cron -m 1,2,3 12:00        # run on Jan,Feb and March every day at noon.
+    ///   cron -w 0   -m 5,6,7,8 10:00 20:00 01:00 # run every sunday, between May-Aug, every hour between 10am and 8pm
+    ///   cron -d 1,L -m 5,6,7,8 10:00 20:00 01:00 # run on first and last day of month, between May-Aug, every hour
+    ///   between 10am and 8pm
+    static void parse(CronAttr&, const std::vector<std::string>& lineTokens, size_t index, bool parse_state = false);
+    static CronAttr create(const std::string& cronString);
+
+private:
+    void write(std::string&) const;
+
+private:
+    void clearFree(); // resets the free flag
+    bool is_day_of_week_day_of_month_and_month_free(const ecf::Calendar&) const;
+
+    bool week_day_matches(int) const;
+    bool last_week_day_of_month_matches(const ecf::Calendar&) const;
+    bool day_of_month_matches(int, const ecf::Calendar& c) const;
+    bool month_matches(int) const;
+
+    boost::gregorian::date next_date(const ecf::Calendar& calendar) const;
+
+    TimeSeries timeSeries_;
+    std::vector<int> weekDays_;
+    std::vector<int> last_week_days_of_month_;
+    std::vector<int> daysOfMonth_;
+    std::vector<int> months_;
+    unsigned int w_{0};               // NOT implemented, weekday nearest the given day of the month 15W
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool last_day_of_month_{false};
+    bool free_{false}; // persisted for use by why() on client side
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_attribute_CronAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/DateAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/DateAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/DateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/DateAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,400 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/DateAttr.hpp"
+
+#include <ostream>
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+//==========================================================================================
+
+DateAttr::DateAttr(int day, int month, int year) : day_(day), month_(month), year_(year) {
+    checkDate(day_, month_, year_, true /* allow wild cards */);
+}
+
+DateAttr::DateAttr(const std::string& str) {
+    DateAttr::getDate(str, day_, month_, year_);
+    checkDate(day_, month_, year_, true /* allow wild cards */);
+}
+
+bool DateAttr::operator<(const DateAttr& rhs) const {
+    if (year_ < rhs.year_)
+        return true;
+    if (year_ == rhs.year_) {
+        if (month_ < rhs.month_)
+            return true;
+        if (month_ == rhs.month_) {
+            return day_ < rhs.day_;
+        }
+    }
+    return false;
+}
+
+void DateAttr::checkDate(int day, int month, int year, bool allow_wild_cards) {
+    if (allow_wild_cards) {
+        if (day != 0 && (day < 1 || day > 31)) {
+            throw std::out_of_range(
+                "Invalid Date(day,month,year) : the day >= 0 and day < 31, where 0 means wild card ");
+        }
+        if (month != 0 && (month < 1 || month > 12)) {
+            throw std::out_of_range(
+                "Invalid Date(day,month,year): the month >=0 and month <= 12, where 0 means wild card");
+        }
+        if (year < 0) {
+            throw std::out_of_range("Invalid Date(day,month,year): the year >=0, where 0 means wild card");
+        }
+    }
+    else {
+        if (day < 1 || day > 31) {
+            throw std::out_of_range("Invalid date attribute : the day >= 1 and day < 31");
+        }
+        if (month < 1 || month > 12) {
+            throw std::out_of_range("Invalid date attribute: the month >=1 and month <= 12");
+        }
+        if (year <= 0) {
+            throw std::out_of_range("Invalid date attribute: the year >0");
+        }
+    }
+
+    if (day != 0 && month != 0 && year != 0) {
+
+        // let boost validate the date
+        boost::gregorian::date theDate(year, month, day);
+    }
+}
+
+void DateAttr::calendarChanged(const ecf::Calendar& c, bool clear_at_midnight) {
+    // See ECFLOW-337 versus ECFLOW-1550
+    if (c.dayChanged()) {
+        if (clear_at_midnight)
+            clearFree();
+    }
+
+    if (free_) {
+        return;
+    }
+
+    if (is_free(c)) {
+        setFree();
+    }
+}
+
+void DateAttr::reset() {
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void DateAttr::requeue() {
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void DateAttr::setFree() {
+    free_            = true;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "DateAttr::setFree()\n";
+#endif
+}
+
+void DateAttr::clearFree() {
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "DateAttr::clearFree()\n";
+#endif
+}
+
+bool DateAttr::isFree(const ecf::Calendar& calendar) const {
+    // The FreeDepCmd can be used to free the dates,
+    if (free_) {
+        return true;
+    }
+    return is_free(calendar);
+}
+
+bool DateAttr::is_free(const ecf::Calendar& calendar) const {
+    bool dayMatches   = true;
+    bool monthMatches = true;
+    bool yearMatches  = true;
+    if (day_ != 0)
+        dayMatches = calendar.day_of_month() == day_;
+    if (month_ != 0)
+        monthMatches = calendar.month() == month_;
+    if (year_ != 0)
+        yearMatches = calendar.year() == year_;
+
+    return (dayMatches && monthMatches && yearMatches);
+}
+
+bool DateAttr::checkForRequeue(const ecf::Calendar& calendar) const {
+    // if calendar is hybrid, we can't re-queue
+    if (calendar.hybrid()) {
+        return false;
+    }
+
+    // checkForRequeue is called when we are deciding whether to re-queue the node.
+    // If this date is in the future, they we should re-queue
+    if (day_ != 0 && month_ != 0 && year_ != 0) {
+        date theDate(year_, month_, day_);
+        if (theDate > calendar.date()) {
+            // #ifdef DEBUG
+            //			cout << toString() << "   > " << " calendar date " << to_simple_string( calendar.date())
+            //<<
+            //"\n"; #endif
+            return true;
+        }
+        return false;
+    }
+
+    bool futureDayMatches   = true;
+    bool futureMonthMatches = true;
+    bool futureYearMatches  = true;
+    if (day_ != 0)
+        futureDayMatches = day_ > calendar.day_of_month();
+    if (month_ != 0)
+        futureMonthMatches = month_ > calendar.month();
+    if (year_ != 0)
+        futureYearMatches = year_ > calendar.year();
+
+    // #ifdef DEBUG
+    //   	if ( futureDayMatches ) {
+    //  		cout << "futureDayMatches " << toString() << " > " << calendar.day_of_month() << "\n";
+    //  	}
+    //	if ( futureMonthMatches ) {
+    //  		cout << "futureMonthMatches " << toString() << " > " << calendar.month() << "\n";
+    //  	}
+    //	if ( futureYearMatches ) {
+    //  		cout << "futureYearMatches " << toString() << " > " << calendar.year() << "\n";
+    //  	}
+    // #endif
+
+    return (futureDayMatches || futureMonthMatches || futureYearMatches);
+}
+
+bool DateAttr::validForHybrid(const ecf::Calendar& calendar) const {
+    if (day_ == 0)
+        return false; // relies on day change i.e. date *.10.2009
+    if (month_ == 0)
+        return false; // relies on day change i.e. date 12.*.2009
+    if (year_ == 0)
+        return false; // relies on day change i.e. date 12.10.*
+
+    // if the date matches exactly for today
+    return (day_ == calendar.day_of_month() && month_ == calendar.month() && year_ == calendar.year());
+}
+
+bool DateAttr::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
+    if (isFree(c))
+        return false;
+
+    std::stringstream ss;
+    ss << " is date dependent ( next run on " << to_simple_string(next_matching_date(c)) << " the current date is ";
+    ss << c.day_of_month() << "/" << c.month() << "/" << c.year() << " )";
+    theReasonWhy += ss.str();
+    return true;
+}
+
+void DateAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        if (free_) {
+            os += " # free";
+        }
+    }
+    os += "\n";
+}
+
+std::string DateAttr::name() const {
+    std::string os;
+    write(os);
+    if (free_) {
+        os += " # free";
+    }
+    return os;
+}
+
+std::string DateAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void DateAttr::write(std::string& ret) const {
+    ret += "date ";
+    if (day_ == 0)
+        ret += "*.";
+    else {
+        ret += ecf::convert_to<std::string>(day_);
+        ret += ".";
+    }
+
+    if (month_ == 0)
+        ret += "*.";
+    else {
+        ret += ecf::convert_to<std::string>(month_);
+        ret += ".";
+    }
+
+    if (year_ == 0)
+        ret += "*";
+    else
+        ret += ecf::convert_to<std::string>(year_);
+}
+
+std::string DateAttr::dump() const {
+    std::stringstream ss;
+    ss << toString();
+    if (free_)
+        ss << " (free)";
+    else
+        ss << " (holding)";
+    return ss.str();
+}
+
+bool DateAttr::operator==(const DateAttr& rhs) const {
+    if (free_ != rhs.free_) {
+        return false;
+    }
+    return structureEquals(rhs);
+}
+bool DateAttr::structureEquals(const DateAttr& rhs) const {
+    if (day_ != rhs.day_)
+        return false;
+    if (month_ != rhs.month_)
+        return false;
+    if (year_ != rhs.year_)
+        return false;
+    return true;
+}
+
+DateAttr DateAttr::create(const std::string& dateString) {
+    int day = -1, month = -1, year = -1;
+    getDate(dateString, day, month, year);
+    return {day, month, year};
+}
+
+DateAttr DateAttr::create(const std::vector<std::string>& lineTokens, bool read_state) {
+    //  date 15.11.2009 # free   // with PersistStyle::STATE & MIGRATE
+    //  date 15.*.*     #
+    //  date *.1.*
+
+    //   for(size_t i =0; i < lineTokens.size() ; i++) {
+    //      cout << "lineTokens[" << i << "] = '" << lineTokens[i] << "'\n";
+    //   }
+
+    DateAttr date = DateAttr::create(lineTokens[1]);
+    if (read_state) {
+        for (size_t i = 3; i < lineTokens.size(); i++) {
+            if (lineTokens[i] == "free")
+                date.setFree();
+        }
+    }
+    return date;
+}
+
+void DateAttr::getDate(const std::string& date, int& day, int& month, int& year) {
+    size_t firstDotPos = date.find_first_of('.');
+    size_t lastDotPos  = date.find_first_of('.', firstDotPos + 1);
+    if (firstDotPos == std::string::npos)
+        throw std::runtime_error("DateAttr::getDate Invalid date missing first dot :" + date);
+    if (lastDotPos == std::string::npos)
+        throw std::runtime_error("DateAttr::getDate: Invalid date missing second dot :" + date);
+    if (firstDotPos == lastDotPos)
+        throw std::runtime_error("DateAttr::getDate: Invalid date :" + date);
+
+    std::string theDay   = date.substr(0, firstDotPos);
+    std::string theMonth = date.substr(firstDotPos + 1, (lastDotPos - firstDotPos) - 1);
+    std::string theYear  = date.substr(lastDotPos + 1);
+
+    if (theDay == "*")
+        day = 0;
+    else {
+        day = Extract::theInt(theDay, "DateAttr::getDate: Invalid day :" + date);
+        if (day < 1 || day > 31)
+            throw std::runtime_error("DateAttr::getDate: Invalid clock date: " + date);
+    }
+
+    if (theMonth == "*")
+        month = 0;
+    else {
+        month = Extract::theInt(theMonth, "DateAttr::getDate: Invalid month :" + date);
+        if (month < 1 || month > 12)
+            throw std::runtime_error("DateAttr::getDate Invalid clock date: " + date);
+    }
+
+    if (theYear == "*")
+        year = 0;
+    else
+        year = Extract::theInt(theYear, "DateAttr::getDate: Invalid year :" + date);
+
+    if (day == -1 || month == -1 || year == -1)
+        throw std::runtime_error("DateAttr::getDate: Invalid clock date:" + date);
+
+    // let boost validate the date
+    if (day != 0 && month != 0 && year != 0) {
+
+        boost::gregorian::date theDate(year, month, day);
+    }
+
+    //	cerr << " DateParser::getDate date=" << date << " day=" << day << " month=" << month << " year=" << year <<
+    //"\n";
+}
+
+boost::gregorian::date DateAttr::next_matching_date(const ecf::Calendar& c) const {
+    boost::gregorian::date next_matching_date = c.date(); // todays date
+
+    boost::gregorian::date_duration one_day(1);
+
+    bool day_matches   = (day_ == 0) ? true : false;
+    bool month_matches = (month_ == 0) ? true : false;
+    bool year_matches  = (year_ == 0) ? true : false;
+    ;
+
+    for (int i = 0; i < 365; i++) {
+        next_matching_date += one_day;
+        if (day_ != 0 && next_matching_date.day() == day_)
+            day_matches = true;
+        if (month_ != 0 && next_matching_date.month() == month_)
+            month_matches = true;
+        if (year_ != 0 && next_matching_date.year() == year_)
+            year_matches = true;
+        if (day_matches && month_matches && year_matches) {
+            return next_matching_date;
+        }
+    }
+    return c.date();
+}
+
+template <class Archive>
+void DateAttr::serialize(Archive& ar) {
+    ar(CEREAL_NVP(day_), CEREAL_NVP(month_), CEREAL_NVP(year_));
+    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE(DateAttr);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/DateAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/DateAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/DateAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/DateAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,102 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_DateAttr_HPP
+#define ecflow_attribute_DateAttr_HPP
+
+///
+/// \note calendarChanged() once a Date is free, it stays free. It relies on parent cron/repeat to re-queue
+///
+
+#include <string>
+#include <vector>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+namespace cereal {
+class access;
+}
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+// Use default copy constructor, assignment operator, destructor
+// Value of 0 for day,month,year means *, i.e. means any value
+class DateAttr {
+public:
+    DateAttr(int day, int month, int year); // will throw std::out_of_range for if invalid date
+    explicit DateAttr(const std::string&);  // will throw std::runtime_error for if invalid date
+    DateAttr() = default;                   // for serialisation
+    explicit DateAttr(const boost::gregorian::date& date)
+        : day_(date.day()),
+          month_(date.month()),
+          year_(date.year()) {} // for test
+
+    void print(std::string&) const;
+    bool operator==(const DateAttr& rhs) const;
+    bool operator<(const DateAttr& rhs) const;
+    bool structureEquals(const DateAttr& rhs) const;
+
+    void reset();
+    void requeue();
+
+    void setFree();   // ensures that isFree() always returns true
+    void clearFree(); // resets the free flag
+    bool isSetFree() const { return free_; }
+    void calendarChanged(const ecf::Calendar& c, bool clear_at_midnight = true); // can set attribute free
+    bool isFree(const ecf::Calendar&) const;
+    bool checkForRequeue(const ecf::Calendar&) const;
+    bool validForHybrid(const ecf::Calendar&) const;
+    bool why(const ecf::Calendar&, std::string& theReasonWhy) const;
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    std::string name() const; // for display/gui only
+    std::string toString() const;
+    std::string dump() const;
+
+    /// Check the date, will throw std::out_of_range or derivative if invalid
+    static void checkDate(int day, int month, int year, bool allow_wild_cards);
+
+    /// Extract the date, if return integer is zero, date was of the *, i.e. any day,month,year
+    /// will throw std::runtime_error for parse errors
+    /// expect:
+    ///    15.11.2009
+    ///    15.*.*
+    ///    *.1.*
+    static void getDate(const std::string& date, int& day, int& month, int& year);
+    static DateAttr create(const std::string& dateString);
+    static DateAttr create(const std::vector<std::string>& lineTokens, bool read_state);
+
+    boost::gregorian::date next_matching_date(const ecf::Calendar&) const;
+
+    // access
+    int day() const { return day_; }
+    int month() const { return month_; }
+    int year() const { return year_; }
+
+    bool is_free(const ecf::Calendar&) const; // ignores free_
+private:
+    void write(std::string&) const;
+
+private:
+    int day_{0};
+    int month_{0};
+    int year_{0};
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool free_{false};                // persisted for use by why() on client side
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_attribute_DateAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/DayAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/DayAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/DayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/DayAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,557 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/DayAttr.hpp"
+
+#include <cassert>
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/cereal_boost_time.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+
+// #define DEBUG_DAYS 1
+
+//===============================================================================
+
+static const char* theDay(DayAttr::Day_t day) {
+    switch (day) {
+        case DayAttr::SUNDAY:
+            return "sunday";
+            break;
+        case DayAttr::MONDAY:
+            return "monday";
+            break;
+        case DayAttr::TUESDAY:
+            return "tuesday";
+            break;
+        case DayAttr::WEDNESDAY:
+            return "wednesday";
+            break;
+        case DayAttr::THURSDAY:
+            return "thursday";
+            break;
+        case DayAttr::FRIDAY:
+            return "friday";
+            break;
+        case DayAttr::SATURDAY:
+            return "saturday";
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    return nullptr;
+}
+
+//===============================================================================
+
+void DayAttr::calendarChanged(const ecf::Calendar& c, bool clear_at_midnight) {
+    // See ECFLOW-337
+    //	repeat ....
+    //    family start
+    //      family 0
+    //        time 10:00
+    //        day monday        # if there was no c.dayChanged(), then after re-queue, & before midnight Monday is still
+    //        free. task dummy        # hence we will end up also running on Tuesday at 10:00
+    //          complete 1==1
+    //          trigger 0==1
+    //
+    //  ECFLOW-1550            # If children of a family with day/date are still active/submitted/queued, then don't
+    //  clear at midnight. repeat ....            # This is only applicable for NodeContainers, for task with day/date
+    //  always CLEAR at midnight
+    //	family f1
+    //	   day monday
+    //	   time 23:00
+    //	   task t1             # Task t1 took longer than 1 hour
+    //	   task t2             # allow task t2 to continue to the next day, i.e clear_at_midnight = False
+    //	      trigger t1 == complete
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::calendarChanged " << dump() << " clear_at_midnight " << clear_at_midnight
+         << " calendar:" << c.suite_time_str() << "\n";
+#endif
+    if (expired_) {
+        // ********* TREAT this Day Attribute as deleted ECFLOW-128 **********
+        return;
+    }
+
+    if (c.dayChanged()) {
+        if (clear_at_midnight) {
+            clearFree();
+#ifdef DEBUG_DAYS
+            cout << " DayAttr::calendarChanged MIDNIGHT " << dump() << " calendar:" << c.suite_time_str() << "\n";
+#endif
+        }
+    }
+
+    if (free_) {
+        return;
+    }
+
+    if (is_free(c)) {
+        setFree();
+#ifdef DEBUG_DAYS
+        cout << " DayAttr::calendarChanged SET FREE " << dump() << " calendar:" << c.suite_time_str() << "\n";
+#endif
+    }
+}
+
+void DayAttr::reset() {
+    expired_         = false;
+    free_            = false;
+    date_            = boost::gregorian::date();
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::reset :" << dump() << "\n";
+#endif
+}
+
+void DayAttr::handle_migration(const ecf::Calendar& c) {
+    // <TODO> temp once in Bologna, and when ecflow4 no longer used.
+    if (date_.is_special()) {
+        if (!c.is_special()) {
+            date_ = matching_date(c);
+        }
+    }
+}
+
+void DayAttr::reset(const ecf::Calendar& c) {
+    reset();
+    date_ = matching_date(c);
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::reset(calendar) :" << dump() << " calendar:" << c.suite_time_str() << "\n";
+#endif
+}
+
+void DayAttr::requeue_time() {
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::requeue " << dump() << "\n";
+#endif
+
+    if (expired_) {
+        // ********* TREAT this Day Attribute as deleted **********
+#ifdef DEBUG_DAYS
+        cout << " DayAttr::requeue_time " << dump() << " EXPIRED(do nothing) returning\n";
+#endif
+        return;
+    }
+
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void DayAttr::requeue_manual(const ecf::Calendar& c) {
+    reset();
+    date_ = matching_date(c);
+
+#ifdef DEBUG_DAYS
+    cout << "  DayAttr::requeue_manual(calendar) " << dump() << " calendar:" << c.suite_time_str() << "\n";
+#endif
+}
+
+void DayAttr::requeue_repeat_increment(const ecf::Calendar& c) {
+    reset();
+    date_ = next_matching_date(c);
+
+#ifdef DEBUG_DAYS
+    cout << "  DayAttr::requeue_repeat_increment(calendar) " << dump() << " calendar:" << c.suite_time_str() << "\n";
+#endif
+}
+
+bool DayAttr::isFree(const ecf::Calendar& c) const {
+    if (expired_) {
+        // ********* TREAT this Day Attribute as deleted **********
+#ifdef DEBUG_DAYS
+        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " HOLDING due to EXPIRED flag\n";
+#endif
+        return false;
+    }
+
+    // The FreeDepCmd can be used to free the dates,
+    if (free_) {
+#ifdef DEBUG_DAYS
+        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " FREE free_ = TRUE\n";
+#endif
+        return true;
+    }
+
+    bool res = is_free(c);
+
+#ifdef DEBUG_DAYS
+    if (res)
+        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " date is FREE\n";
+    else
+        cout << " DayAttr::isFree " << dump() << " calendar:" << c.suite_time_str() << " date is HOLDING\n";
+#endif
+    return res;
+}
+
+bool DayAttr::is_free(const ecf::Calendar& c) const {
+    return (c.date() == date_);
+}
+
+void DayAttr::setFree() {
+    free_            = true;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::setFree() " << dump() << "\n";
+#endif
+}
+
+void DayAttr::clearFree() {
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::clearFree() " << dump() << "\n";
+#endif
+}
+
+void DayAttr::set_expired() {
+    expired_         = true;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::set_expired() " << dump() << "\n";
+#endif
+}
+
+void DayAttr::clear_expired() {
+    expired_         = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::clear_expired() " << dump() << "\n";
+#endif
+}
+
+void DayAttr::check_for_expiration(const ecf::Calendar& c) {
+#ifdef DEBUG_DAYS
+    cout << "DayAttr::check_for_expiration " << dump() << " calendar:" << c.suite_time_str() << "\n";
+#endif
+    // This function is called when a Node has COMPLETED. Avoid running again on same day date <= calendar, expire the
+    // date Note: time attribute, they get handled before. i.e allowing multiple re-queues on the same date This
+    // function *MUST* be called before checkForRequeue.
+
+    if (date_.is_special()) {
+        // migration 4->5, or 5->5 from checkpoint
+        date_ = matching_date(c);
+    }
+
+    if (day_ == c.day_of_week()) {
+        set_expired();
+        return;
+    }
+
+    if (date_ <= c.date()) {
+        set_expired();
+    }
+}
+
+bool DayAttr::checkForRequeue(const ecf::Calendar& c) const {
+    if (expired_) {
+#ifdef DEBUG_DAYS
+        cout << " DayAttr::check_for_requeue ALREADY EXPIRED " << dump() << " calendar:" << c.suite_time_str()
+             << "  HOLDING <<<<<<<<<<<<\n";
+#endif
+        return false;
+    }
+
+    // if calendar is hybrid, we can't requeue
+    if (c.hybrid()) {
+        return false;
+    }
+
+    // checkForRequeue is called when we are deciding whether to re-queue the node
+    // Hence we *MUST* have completed. Also crons,time,today have all returned false.
+    // *IF* this date is in the future, they we should re-queue
+
+    assert(!date_.is_special());
+
+    bool future_date = (date_ > c.date());
+
+#ifdef DEBUG_DAYS
+    cout << " DayAttr::check_for_requeue " << dump() << " calendar:" << c.suite_time_str() << " returning "
+         << future_day << " ************\n";
+#endif
+    return future_date;
+}
+
+bool DayAttr::validForHybrid(const ecf::Calendar& calendar) const {
+    return isFree(calendar);
+}
+
+bool DayAttr::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
+    if (isFree(c))
+        return false;
+
+    theReasonWhy += " is day dependent ( next run on ";
+    theReasonWhy += theDay(day_);
+    theReasonWhy += " ";
+    if (date_.is_special())
+        theReasonWhy += to_simple_string(next_matching_date(c));
+    else
+        theReasonWhy += to_simple_string(date_);
+    theReasonWhy += " the current day is ";
+    theReasonWhy += theDay(static_cast<DayAttr::Day_t>(c.day_of_week()));
+    theReasonWhy += " )";
+    return true;
+}
+
+void DayAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        bool added_hash = false;
+        if (free_) {
+            os += " # free";
+            added_hash = true;
+        }
+        if (expired_) {
+            if (added_hash)
+                os += " expired";
+            else
+                os += " # expired";
+            added_hash = true;
+        }
+
+        if (added_hash) {
+            os += " date:";
+            os += to_simple_string(date_);
+        }
+        else {
+            os += " # date:";
+            os += to_simple_string(date_);
+        }
+    }
+    os += "\n";
+}
+
+std::string DayAttr::name() const {
+    // for display/GUI only
+    std::string os;
+    write(os);
+    bool added_hash = false;
+
+    if (expired_) {
+        os += " # expired";
+        added_hash = true;
+    }
+    else {
+        if (free_) {
+            os += " # free";
+            added_hash = true;
+        }
+    }
+
+    if (added_hash) {
+        os += " ";
+        os += to_simple_string(date_);
+    }
+    else {
+        os += " # ";
+        os += to_simple_string(date_);
+    }
+
+    return os;
+}
+
+std::string DayAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void DayAttr::write(std::string& ret) const {
+    ret += "day ";
+    ret += theDay(day_);
+}
+
+std::string DayAttr::dump() const {
+    std::stringstream ss;
+    ss << toString();
+    if (free_)
+        ss << " (free)";
+    if (expired_)
+        ss << " (expired)";
+    ss << " " << to_simple_string(date_);
+    return ss.str();
+}
+
+bool DayAttr::operator==(const DayAttr& rhs) const {
+    if (free_ != rhs.free_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "DayAttr::operator== free_ != rhs.free_   (free_:" << free_ << " rhs.free_:" << rhs.free_
+                      << ") " << dump() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (expired_ != rhs.expired_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "DayAttr::operator== expired_ != rhs.expired_   (expired_:" << expired_
+                      << " rhs.expired_:" << rhs.expired_ << ") " << dump() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (date_ != rhs.date_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "DayAttr::operator== date_ != rhs.date_   (date_:" << date_ << " rhs.date_:" << rhs.date_
+                      << ") " << dump() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    return structureEquals(rhs);
+}
+
+bool DayAttr::structureEquals(const DayAttr& rhs) const {
+    return (day_ == rhs.day_);
+}
+
+DayAttr DayAttr::create(const std::string& dayStr) {
+    return DayAttr(getDay(dayStr));
+}
+
+DayAttr DayAttr::create(const std::vector<std::string>& lineTokens, bool read_state) {
+    if (lineTokens.size() < 2) {
+        throw std::runtime_error("DayAttr::create date tokens to short :");
+    }
+
+    //   for(size_t i =0; i < lineTokens.size() ; i++) {
+    //      cout << "lineTokens[" << i << "] = '" << lineTokens[i] << "'\n";
+    //   }
+
+    // day monday  # free expired date:****
+    // day monday  # expired
+    DayAttr day = DayAttr::create(lineTokens[1]);
+
+    // state
+    if (read_state) {
+        day.read_state(lineTokens);
+    }
+    return day;
+}
+
+void DayAttr::read_state(const std::vector<std::string>& lineTokens) {
+    std::string date;
+
+    for (size_t i = 3; i < lineTokens.size(); i++) {
+        if (lineTokens[i] == "free")
+            free_ = true;
+        else if (lineTokens[i] == "expired")
+            expired_ = true;
+        else if (lineTokens[i].find("date:") != std::string::npos) {
+            if (!Extract::split_get_second(lineTokens[i], date))
+                throw std::runtime_error("DayAttr::read_state failed: (date:)");
+            // when a date_ is special date = not-a-date-time\n"
+            if (date.find("not") == std::string::npos) {
+                date_ = from_simple_string(date);
+            }
+        }
+    }
+}
+
+DayAttr::Day_t DayAttr::getDay(const std::string& day) {
+    if (day == "monday")
+        return DayAttr::MONDAY;
+    if (day == "tuesday")
+        return DayAttr::TUESDAY;
+    if (day == "wednesday")
+        return DayAttr::WEDNESDAY;
+    if (day == "thursday")
+        return DayAttr::THURSDAY;
+    if (day == "friday")
+        return DayAttr::FRIDAY;
+    if (day == "saturday")
+        return DayAttr::SATURDAY;
+    if (day == "sunday")
+        return DayAttr::SUNDAY;
+
+    std::stringstream ss;
+    ss << "Invalid day(" << day
+       << ") specification expected one of [monday,tuesday,wednesday,thursday,friday,saturday,sunday]: ";
+    throw std::runtime_error(ss.str());
+
+    return DayAttr::SUNDAY;
+}
+
+std::vector<std::string> DayAttr::allDays() {
+    std::vector<std::string> vec;
+    vec.reserve(7);
+    vec.emplace_back("monday");
+    vec.emplace_back("tuesday");
+    vec.emplace_back("wednesday");
+    vec.emplace_back("thursday");
+    vec.emplace_back("friday");
+    vec.emplace_back("saturday");
+    vec.emplace_back("sunday");
+    return vec;
+}
+
+boost::gregorian::date DayAttr::matching_date(const ecf::Calendar& c) const {
+    boost::gregorian::date_duration one_day(1);
+    boost::gregorian::date matching_date = c.date(); // todays date
+
+    for (int i = 0; i < 7; i++) {
+        if (matching_date.day_of_week().as_number() == day_) {
+            return matching_date;
+        }
+        matching_date += one_day;
+    }
+    assert(false); // no matching day ?s
+    return c.date();
+}
+
+boost::gregorian::date DayAttr::next_matching_date(const ecf::Calendar& c) const {
+    boost::gregorian::date_duration one_day(1);
+    boost::gregorian::date the_next_matching_date = c.date(); // todays date
+
+    for (int i = 0; i < 7; i++) {
+        the_next_matching_date += one_day;
+        if (the_next_matching_date.day_of_week().as_number() == day_) {
+            return the_next_matching_date;
+        }
+    }
+    assert(false);
+    return c.date();
+}
+
+template <class Archive>
+void DayAttr::serialize(Archive& ar) {
+    ar(CEREAL_NVP(day_));
+    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, expired_, [this]() {
+        return expired_;
+    }); // conditionally save, new to ecflow 5.4.0, should be ignored by old clients. see tests
+    CEREAL_OPTIONAL_NVP(ar, date_, [this]() {
+        return !date_.is_special();
+    }); // conditionally save, new to ecflow 5.5.0, should be ignored by old clients. see tests
+}
+CEREAL_TEMPLATE_SPECIALIZE(DayAttr);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/DayAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/DayAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/DayAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/DayAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,132 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_DayAttr_HPP
+#define ecflow_attribute_DayAttr_HPP
+
+#include <vector>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+namespace cereal {
+class access;
+}
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+// Use default copy constructor, assignment operator, destructor
+class DayAttr {
+public:
+    enum Day_t { SUNDAY = 0, MONDAY = 1, TUESDAY = 2, WEDNESDAY = 3, THURSDAY = 4, FRIDAY = 5, SATURDAY = 6 };
+    DayAttr() = default;
+    explicit DayAttr(Day_t day) : day_(day) {}
+    explicit DayAttr(const std::string& str) : day_(DayAttr::getDay(str)) {}
+    explicit DayAttr(const boost::gregorian::date& date)
+        : day_(static_cast<DayAttr::Day_t>(date.day_of_week().as_number())),
+          date_(date) {}
+
+    void print(std::string&) const;
+    bool operator==(const DayAttr& rhs) const;
+    bool operator<(const DayAttr& rhs) const { return day_ < rhs.day_; }
+    bool structureEquals(const DayAttr& rhs) const;
+
+    /// called when definition is restored from a file/checkpoint. handle reset of date_
+    void handle_migration(const ecf::Calendar&);
+
+    // called at begin time.
+    void reset();
+    void reset(const ecf::Calendar& c);
+
+    // called when we need a reque based on a time attribute. Should *NOT* clear expired flag.
+    void requeue_time();
+
+    // called when re-queing because of:
+    //    - automatic re-queue due to repeat increment
+    //    - manual re-queue
+    // Clears expired flag, and sets day attribute to a next matching *FUTURE* day or current day
+    void requeue_manual(const ecf::Calendar& c);           // can match today if today is match day
+    void requeue_repeat_increment(const ecf::Calendar& c); // match *FUTURE* day
+
+    // Called after a node has completed, if calendar day corresponds to *THIS* day. *Expire* it
+    // This should be called just before: checkForRequeue.
+    // This day attribute should be treated as being deleted. returns false from
+    //  - isFree()          stops re-queue on expired day
+    //  - calendarChanged() stops clearing of free.
+    // Expired flag is RESET only by:
+    //    - void requeue_manual(const ecf::Calendar& c);
+    //    - void requeue_repeat_increment(const ecf::Calendar& c);
+    void check_for_expiration(const ecf::Calendar&);
+
+    // We must use a real date, using enum is not sufficient as in ecflow4
+    //     0,1,2,3,4,5,6
+    //     ^           ^
+    //    sunday      saturday
+    // old/buggy: check_for_requeue() { return (day_ > calendar.day_of_week() );}
+    // The old check for re-queue would determine if this day is in the future, with reference to calendar day.
+    // Hence day_(Saturday) is would always re-queue, day_(Sunday) is would never re-queue
+    // When multiple days were involved, it would get even more buggier.
+    // By using a real date, we fix the issue, the real date is updated during manual re-queue, or automatically vi
+    // repeat increment.
+    bool checkForRequeue(const ecf::Calendar&) const;
+
+    void setFree(); // ensures that isFree() always returns true
+    bool isSetFree() const { return free_; }
+    void calendarChanged(const ecf::Calendar& c, bool clear_at_midnight = true); // can set attribute free
+    bool isFree(const ecf::Calendar&) const;
+    bool validForHybrid(const ecf::Calendar&) const;
+    bool why(const ecf::Calendar&, std::string& theReasonWhy) const;
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    std::string name() const; // for display/gui only
+    std::string toString() const;
+    std::string dump() const;
+
+    // return the days, if input is not valid will throw a runtime_error
+    static DayAttr create(const std::string& dayStr);
+    static DayAttr create(const std::vector<std::string>& lineTokens, bool read_state);
+    static DayAttr::Day_t getDay(const std::string&);
+
+    static std::vector<std::string> allDays();
+
+    // access
+    DayAttr::Day_t day() const { return day_; }
+    const boost::gregorian::date& date() const { return date_; }
+
+    boost::gregorian::date next_matching_date(const ecf::Calendar& c) const;
+
+    void set_expired(); // ********* TREAT this Day Attribute as deleted **********
+    bool expired() const { return expired_; }
+
+    void read_state(const std::vector<std::string>& lineTokens);
+
+private:
+    void clearFree(); // resets the free flag
+    void clear_expired();
+    bool is_free(const ecf::Calendar&) const; // ignores free_
+    boost::gregorian::date matching_date(const ecf::Calendar& c) const;
+    void write(std::string&) const;
+
+private:
+    DayAttr::Day_t day_{DayAttr::SUNDAY};
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool free_{false};                // persisted for use by why() on client side
+    bool expired_{false};             // added for ecflow 5.4.0
+
+    boost::gregorian::date date_; // corresponding to day_
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_attribute_DayAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/GenericAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/GenericAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/GenericAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/GenericAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/GenericAttr.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace ecf;
+using namespace boost;
+using namespace std;
+
+const GenericAttr& GenericAttr::EMPTY() {
+    static const GenericAttr GENERICATTR = GenericAttr();
+    return GENERICATTR;
+}
+
+GenericAttr::GenericAttr(const std::string& name, const std::vector<std::string>& values)
+    : name_(name),
+      values_(values) {
+    string msg;
+    if (!Str::valid_name(name, msg)) {
+        throw std::runtime_error("GenericAttr::GenericAttr : Invalid generic name : " + msg);
+    }
+}
+
+GenericAttr::GenericAttr(const std::string& name) : name_(name) {
+    string msg;
+    if (!Str::valid_name(name, msg)) {
+        throw std::runtime_error("GenericAttr::GenericAttr : Invalid generic name : " + msg);
+    }
+}
+
+bool GenericAttr::operator==(const GenericAttr& rhs) const {
+    if (name_ != rhs.name_)
+        return false;
+    if (values_ != rhs.values_)
+        return false;
+    return true;
+}
+
+void GenericAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += "\n";
+}
+
+std::string GenericAttr::to_string() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void GenericAttr::write(std::string& ret) const {
+    ret += "generic ";
+    ret += name_;
+    for (const auto& value : values_) {
+        ret += " ";
+        ret += value;
+    }
+}
+
+template <class Archive>
+void GenericAttr::serialize(Archive& ar) {
+    ar(CEREAL_NVP(name_), CEREAL_NVP(values_));
+}
+CEREAL_TEMPLATE_SPECIALIZE(GenericAttr);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/GenericAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/GenericAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/GenericAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/GenericAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_GenericAttr_HPP
+#define ecflow_attribute_GenericAttr_HPP
+
+#include <string>
+#include <vector>
+namespace cereal {
+class access;
+}
+
+// Class GenericAttr:
+// Use compiler , generated destructor, assignment, copy constructor
+// GenericAttr does *not* have any changeable state
+class GenericAttr {
+public:
+    GenericAttr(const std::string& name, const std::vector<std::string>& values);
+    explicit GenericAttr(const std::string& name);
+    GenericAttr() = default;
+
+    bool operator==(const GenericAttr& rhs) const;
+    bool operator<(const GenericAttr& rhs) const { return name_ < rhs.name(); }
+    void print(std::string&) const;
+    bool empty() const { return name_.empty(); }
+
+    const std::string& name() const { return name_; }
+    const std::vector<std::string>& values() const { return values_; }
+
+    std::vector<std::string>::const_iterator values_begin() const { return values_.begin(); } // for python
+    std::vector<std::string>::const_iterator values_end() const { return values_.end(); }     // for python
+
+    std::string to_string() const;
+
+    // Added to support return by reference
+    static const GenericAttr& EMPTY();
+
+private:
+    void write(std::string& ret) const;
+
+private:
+    std::string name_;
+    std::vector<std::string> values_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_attribute_GenericAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/LateAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/LateAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/LateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/LateAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,269 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/LateAttr.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+namespace ecf {
+
+LateAttr::LateAttr() = default;
+
+void LateAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        if (isLate_)
+            os += " # late";
+    }
+    os += "\n";
+}
+
+std::string LateAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void LateAttr::write(std::string& ret) const {
+    ret += "late";
+    if (!s_.isNULL()) {
+        ret += " -s +";
+        s_.write(ret);
+    }
+    if (!a_.isNULL()) {
+        ret += " -a ";
+        a_.write(ret);
+    }
+    if (!c_.isNULL()) {
+        ret += " -c ";
+        if (c_is_rel_)
+            ret += "+";
+        c_.write(ret);
+    }
+}
+
+bool LateAttr::operator==(const LateAttr& rhs) const {
+    if (c_is_rel_ != rhs.c_is_rel_)
+        return false;
+    if (s_ != rhs.s_)
+        return false;
+    if (a_ != rhs.a_)
+        return false;
+    if (c_ != rhs.c_)
+        return false;
+    if (isLate_ != rhs.isLate_)
+        return false;
+    return true;
+}
+
+bool LateAttr::isNull() const {
+    return (s_.isNULL() && a_.isNULL() && c_.isNULL());
+}
+
+void LateAttr::checkForLateness(const std::pair<NState, boost::posix_time::time_duration>& state,
+                                const ecf::Calendar& calendar) {
+    if (isLate_ || isNull()) {
+        return;
+    }
+    if (check_for_lateness(state, calendar)) {
+        setLate(true);
+    }
+}
+
+bool LateAttr::check_for_lateness(const std::pair<NState, boost::posix_time::time_duration>& state,
+                                  const ecf::Calendar& calendar) const {
+    if (isNull())
+        return false;
+
+    if (state.first == NState::SUBMITTED || state.first == NState::QUEUED) {
+
+        // Submitted is always relative, ASSUME this means relative to suite start
+        if (state.first == NState::SUBMITTED && !s_.isNULL()) {
+
+            // ECFLOW-322
+            // The late attr check for being late in submitted state, is always *RELATIVE*
+            // Previously we had:
+            //
+            //       if ( calendar.duration() >= s_.duration()  ) {
+            //          setLate(true);
+            //          return;
+            //       }
+            // This is incorrect since calendar.duration() is essentially duration until
+            // the last call to Calendar::init() i.e suite duration time. Hence late was
+            // set straight away.
+            //
+            // to check for submitted, we need the duration *after* state went into submitted state
+            // state.second is when state went SUBMITTED, relative to suite start
+            boost::posix_time::time_duration time_in_submitted_state = calendar.duration() - state.second;
+            if (time_in_submitted_state >= s_.duration()) {
+                return true;
+            }
+        }
+
+        // In Submitted or queued state, check for active, in REAL time
+        if (!a_.isNULL() && calendar.suiteTime().time_of_day() >= a_.duration()) {
+            return true;
+        }
+    }
+    else if (state.first == NState::ACTIVE && !c_.isNULL()) {
+        if (c_is_rel_) {
+            // to check for complete, we need the duration when state went into active state
+            // state.second is when state went ACTIVE, relative to suite start
+            boost::posix_time::time_duration runtime = calendar.duration() - state.second;
+            if (runtime >= c_.duration()) {
+                return true;
+            }
+        }
+        else {
+            // Real time
+            if (calendar.suiteTime().time_of_day() >= c_.duration()) {
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+void LateAttr::setLate(bool f) {
+    if (f != isLate_) {
+        // minimise changes to state_change_no_
+        isLate_          = f;
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "LateAttr::setLate changed=" << (f != isLate_) << "\n";
+#endif
+}
+
+void LateAttr::override_with(LateAttr* in_late) {
+    if (in_late) {
+        if (!in_late->submitted().isNULL())
+            s_ = in_late->submitted();
+        if (!in_late->active().isNULL())
+            a_ = in_late->active();
+        if (!in_late->complete().isNULL())
+            c_ = in_late->complete();
+        c_is_rel_ = in_late->complete_is_relative();
+
+        // DO NOT override isLate_, because if the parent is late, we do not want *ALL* children to be set late
+        // isLate_ = in_late->isLate();
+    }
+}
+
+void LateAttr::parse(LateAttr& lateAttr,
+                     const std::string& line,
+                     const std::vector<std::string>& lineTokens,
+                     size_t index) {
+    // late -s +00:15  -a  20:00  -c +02:00     #The option can be in any order
+    //  0   1    2      3   4     5     6        7     8     9  10 11 12  13
+    // late -s +00:15  -c +02:00                # not all options are needed
+    //  0    1   2      3   4                   5
+
+    assert(lateAttr.isNull());
+
+    size_t line_token_size = lineTokens.size();
+    for (size_t i = index; i < line_token_size; i += 1) {
+        if (lineTokens[i][0] == '#')
+            break;
+
+        if (lineTokens[i] == "-s") {
+            if (!lateAttr.submitted().isNULL())
+                throw std::runtime_error("LateParser::doParse: Invalid late, submitted specified twice :" + line);
+            if (i + 1 < line_token_size) {
+                int hour = -1;
+                int min  = -1;
+                TimeSeries::getTime(lineTokens[i + 1], hour, min);
+                lateAttr.addSubmitted(TimeSlot(hour, min));
+                i++;
+            }
+            else
+                throw std::runtime_error("LateParser::doParse: Invalid late, submitted time not specified :" + line);
+        }
+        else if (lineTokens[i] == "-a") {
+            if (!lateAttr.active().isNULL())
+                throw std::runtime_error("LateParser::doParse: Invalid late, active specified twice :" + line);
+            if (i + 1 < line_token_size) {
+                int hour = -1;
+                int min  = -1;
+                TimeSeries::getTime(lineTokens[i + 1], hour, min);
+                lateAttr.addActive(TimeSlot(hour, min));
+                i++;
+            }
+            else
+                throw std::runtime_error("LateParser::doParse: Invalid late, active time not specified :" + line);
+        }
+        else if (lineTokens[i] == "-c") {
+            if (!lateAttr.complete().isNULL())
+                throw std::runtime_error("LateParser::doParse: Invalid late, complete specified twice :" + line);
+            if (i + 1 < line_token_size) {
+                int hour      = -1;
+                int min       = -1;
+                bool relative = TimeSeries::getTime(lineTokens[i + 1], hour, min);
+                lateAttr.addComplete(TimeSlot(hour, min), relative);
+                i++;
+            }
+            else
+                throw std::runtime_error("LateParser::doParse: Invalid late, active time not specified :" + line);
+        }
+        else
+            throw std::runtime_error("LateParser::doParse:5: Invalid late :" + line);
+    }
+
+    if (lateAttr.isNull()) {
+        throw std::runtime_error("LateParser::doParse:6: Invalid late :" + line);
+    }
+}
+
+LateAttr LateAttr::create(const std::string& lateString) {
+    std::vector<std::string> lineTokens;
+    Str::split(lateString, lineTokens);
+
+    if (lineTokens.empty()) {
+        throw std::runtime_error("LateParser::create: empty string no late specified ?" + lateString);
+    }
+
+    // adjust the index
+    size_t index = 0;
+    if (lineTokens[0] == "late") {
+        index = 1;
+    }
+
+    LateAttr lateAttr;
+    parse(lateAttr, lateString, lineTokens, index);
+    return lateAttr;
+}
+
+template <class Archive>
+void LateAttr::serialize(Archive& ar) {
+    CEREAL_OPTIONAL_NVP(ar, s_, [this]() { return !s_.isNULL(); });
+    CEREAL_OPTIONAL_NVP(ar, a_, [this]() { return !a_.isNULL(); });
+    CEREAL_OPTIONAL_NVP(ar, c_, [this]() { return !c_.isNULL(); });
+    CEREAL_OPTIONAL_NVP(ar, c_is_rel_, [this]() { return c_is_rel_; });
+    CEREAL_OPTIONAL_NVP(ar, isLate_, [this]() { return isLate_; });
+}
+CEREAL_TEMPLATE_SPECIALIZE(LateAttr);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/LateAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/LateAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/LateAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/LateAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,123 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_LateAttr_HPP
+#define ecflow_attribute_LateAttr_HPP
+
+#include <string>
+#include <utility> // for pair
+#include <vector>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/core/TimeSlot.hpp"
+
+class NState;
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+namespace ecf {
+/// ========================================================================
+/// Use compiler,  destructor, assignment, copy constructor,
+///
+/// ************************************************************************
+/// late attribute: Only applies to a task, it can be set on suite/family
+///                 but this is treated as an inherited attribute.
+///                 late attribute lower down the hierarchy overrides it.
+/// ************************************************************************
+/// The late late attribute will not work correctly when the suites clock
+/// start and stops with the server. Since the late relies on real time
+/// for some of its functionality.
+/// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
+///               relative, so + is simple ignored, if present. If the node stays submitted
+///               longer than the time specified, the late flag is set
+/// -a Active   : The time of day the node must have become active (format hh:mm). If the node
+///               is still queued or submitted, the late flag is set
+/// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
+///               taken from the time the node became active, otherwise node must be complete by
+///               the time given.
+/// ========================================================================
+class LateAttr {
+public:
+    LateAttr();
+
+    void print(std::string&) const;
+    bool operator==(const LateAttr& rhs) const;
+
+    void addSubmitted(const TimeSlot& s) { s_ = s; }
+    void add_submitted(int hour, int minute) { s_ = TimeSlot(hour, minute); }
+    void addActive(const TimeSlot& s) { a_ = s; }
+    void add_active(int hour, int minute) { a_ = TimeSlot(hour, minute); }
+    void addComplete(const TimeSlot& s, bool relative) {
+        c_        = s;
+        c_is_rel_ = relative;
+    }
+    void add_complete(int hour, int minute, bool relative) {
+        c_        = TimeSlot(hour, minute);
+        c_is_rel_ = relative;
+    }
+
+    const TimeSlot& submitted() const { return s_; }
+    const TimeSlot& active() const { return a_; }
+    const TimeSlot& complete() const { return c_; }
+    bool complete_is_relative() const { return c_is_rel_; }
+
+    /// i.e no time structs specified
+    bool isNull() const;
+
+    /// Given the state and time of state change, and calendar work out if we are late
+    /// if we are sets the late flag
+    void checkForLateness(const std::pair<NState, boost::posix_time::time_duration>& state, const ecf::Calendar& c);
+    bool check_for_lateness(const std::pair<NState, boost::posix_time::time_duration>& state,
+                            const ecf::Calendar& c) const;
+
+    ///  To be used by GUI to inform used that a node is late
+    bool isLate() const { return isLate_; }
+
+    /// To be called at begin and re-queue time
+    void reset() { setLate(false); }
+
+    // Overide this late attributes with the settings form the input.
+    void override_with(LateAttr*);
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    /// set flag to be late
+    void setLate(bool f);
+
+    std::string toString() const;
+    std::string name() const { return toString(); }
+
+    static void parse(LateAttr&, const std::string& line, const std::vector<std::string>& lineTokens, size_t index);
+    static LateAttr create(const std::string& lateString);
+
+private:
+    void write(std::string&) const;
+
+private:
+    TimeSlot s_; // relative by default
+    TimeSlot a_;
+    TimeSlot c_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool c_is_rel_{false};
+    bool isLate_{false};
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_attribute_LateAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/NodeAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/NodeAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/NodeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/NodeAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,512 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/NodeAttr.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+const std::string& Event::SET() {
+    static const std::string SET = "set";
+    return SET;
+}
+const std::string& Event::CLEAR() {
+    static const std::string CLEAR = "clear";
+    return CLEAR;
+}
+const Event& Event::EMPTY() {
+    static const Event EVENT = Event();
+    return EVENT;
+}
+const Meter& Meter::EMPTY() {
+    static const Meter METER = Meter();
+    return METER;
+}
+const Label& Label::EMPTY() {
+    static const Label LABEL = Label();
+    return LABEL;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////
+
+Event::Event(int number, const std::string& eventName, bool iv, bool check_name)
+    : n_(eventName),
+      number_(number),
+      v_(iv),
+      iv_(iv) {
+    if (!eventName.empty() && check_name) {
+        string msg;
+        if (!Str::valid_name(eventName, msg)) {
+            throw std::runtime_error("Event::Event: Invalid event name : " + msg);
+        }
+    }
+}
+
+Event::Event(const std::string& eventName, bool iv) : n_(eventName), v_(iv), iv_(iv) {
+    if (eventName.empty()) {
+        throw std::runtime_error("Event::Event: Invalid event name : name must be specified if no number supplied");
+    }
+
+    // If the eventName is a integer, then treat it as such, by setting number_ and clearing n_
+    // This was added after migration failed, since *python* api allowed:
+    //       ta.add_event(1);
+    //       ta.add_event("1");
+    // and when we called ecflow_client --migrate/--get it generated
+    //       event 1
+    //       event 1
+    // which then did *not* load.
+    //
+    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
+    if (eventName.find_first_of(Str::NUMERIC()) == 0) {
+        try {
+            number_ = ecf::convert_to<int>(eventName);
+            n_.clear();
+            return;
+        }
+        catch (const ecf::bad_conversion&) {
+            // cast failed, a real string, carry on
+        }
+    }
+
+    string msg;
+    if (!Str::valid_name(eventName, msg)) {
+        throw std::runtime_error("Event::Event: Invalid event name : " + msg);
+    }
+}
+
+void Event::set_value(bool b) {
+    v_               = b;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Event::set_value\n";
+#endif
+}
+
+std::string Event::name_or_number() const {
+    if (n_.empty()) {
+        std::stringstream ss;
+        ss << number_;
+        return ss.str();
+    }
+    return n_;
+}
+
+bool Event::operator<(const Event& rhs) const {
+    if (!n_.empty() && !rhs.name().empty()) {
+        return n_ < rhs.name();
+    }
+    if (n_.empty() && rhs.name().empty()) {
+        return number_ < rhs.number();
+    }
+    return name_or_number() < rhs.name_or_number();
+}
+
+bool Event::operator==(const Event& rhs) const {
+    if (v_ != rhs.v_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "v_ != rhs.v_   (v_:" << v_ << " rhs.v_:" << rhs.v_ << ") " << toString() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (number_ != rhs.number_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "number_ != rhs.number_   (number_:" << number_ << " rhs.number_:" << rhs.number_ << ") "
+                      << toString() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (n_ != rhs.n_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "n_ != rhs.n_  (n_:" << n_ << " rhs.n_:" << rhs.n_ << ") " << toString() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (iv_ != rhs.iv_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "iv_ != rhs.iv_   (iv_:" << iv_ << " rhs.iv_:" << rhs.iv_ << ") " << toString() << "\n";
+        }
+#endif
+        return false;
+    }
+    return true;
+}
+
+bool Event::compare(const Event& rhs) const {
+    if (number_ != rhs.number_) {
+        return false;
+    }
+    if (n_ != rhs.n_) {
+        return false;
+    }
+    return true;
+}
+
+void Event::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        if (iv_ != v_) { // initial value and value differ
+            if (v_) {
+                os += " # ";
+                os += Event::SET();
+            }
+            else {
+                os += " # ";
+                os += Event::CLEAR();
+            }
+        }
+    }
+    os += "\n";
+}
+
+std::string Event::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void Event::write(std::string& ret) const {
+    ret += "event ";
+    if (number_ == std::numeric_limits<int>::max())
+        ret += n_;
+    else {
+        ret += ecf::convert_to<std::string>(number_);
+        ret += " ";
+        ret += n_;
+    }
+
+    if (iv_)
+        ret += " set"; // initial value
+}
+
+std::string Event::dump() const {
+    std::stringstream ss;
+    ss << toString() << " value(" << v_ << ")  used(" << used_ << ")";
+    return ss.str();
+}
+
+bool Event::isValidState(const std::string& state) {
+    if (state == Event::SET())
+        return true;
+    if (state == Event::CLEAR())
+        return true;
+    return false;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////
+
+Meter::Meter(const std::string& name, int min, int max, int colorChange, int value, bool check)
+    : min_(min),
+      max_(max),
+      v_(value),
+      cc_(colorChange),
+      n_(name) {
+    if (check) {
+        if (!Str::valid_name(name)) {
+            throw std::runtime_error("Meter::Meter: Invalid Meter name: " + name);
+        }
+    }
+
+    if (min > max)
+        throw std::out_of_range("Meter::Meter: Invalid Meter(name,min,max,color_change) : min must be less than max");
+
+    if (colorChange == std::numeric_limits<int>::max()) {
+        cc_ = max_;
+    }
+
+    if (value == std::numeric_limits<int>::max()) {
+        v_ = min_;
+    }
+
+    if (cc_ < min || cc_ > max) {
+        std::stringstream ss;
+        ss << "Meter::Meter: Invalid Meter(name,min,max,color_change) color_change(" << cc_ << ") must be between min("
+           << min_ << ") and max(" << max_ << ")";
+        throw std::out_of_range(ss.str());
+    }
+}
+
+void Meter::set_value(int v) {
+
+    if (!isValidValue(v)) {
+        std::stringstream ss;
+        ss << "Meter::set_value(int): The meter(" << n_ << ") value must be in the range[" << min() << "->" << max()
+           << "] but found '" << v << "'";
+        throw std::runtime_error(ss.str());
+    }
+
+    v_               = v;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Meter::set_value\n";
+#endif
+}
+
+bool Meter::operator==(const Meter& rhs) const {
+    if (v_ != rhs.v_) {
+        return false;
+    }
+    if (min_ != rhs.min_) {
+        return false;
+    }
+    if (max_ != rhs.max_) {
+        return false;
+    }
+    if (cc_ != rhs.cc_) {
+        return false;
+    }
+    if (n_ != rhs.n_) {
+        return false;
+    }
+    return true;
+}
+
+void Meter::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        if (v_ != min_) {
+            os += " # ";
+            os += ecf::convert_to<std::string>(v_);
+        }
+    }
+    os += "\n";
+}
+
+std::string Meter::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void Meter::write(std::string& ret) const {
+    ret += "meter ";
+    ret += n_;
+    ret += " ";
+    ret += ecf::convert_to<std::string>(min_);
+    ret += " ";
+    ret += ecf::convert_to<std::string>(max_);
+    ret += " ";
+    ret += ecf::convert_to<std::string>(cc_);
+}
+
+std::string Meter::dump() const {
+    std::stringstream ss;
+    ss << "meter " << n_ << " min(" << min_ << ") max (" << max_ << ") colorChange(" << cc_ << ") value(" << v_
+       << ") used(" << used_ << ")";
+    return ss.str();
+}
+
+/////////////////////////////////////////////////////////////////////////////////////////////
+
+Label::Label(const std::string& name, const std::string& value, const std::string& new_value, bool check_name)
+    : n_(name),
+      v_(value),
+      new_v_(new_value),
+      state_change_no_(0) {
+    if (check_name && !Str::valid_name(n_)) {
+        throw std::runtime_error("Label::Label: Invalid Label name :" + n_);
+    }
+}
+
+void Label::print(std::string& os) const {
+
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        if (!new_v_.empty()) {
+            if (new_v_.find("\n") == std::string::npos) {
+                os += " # \"";
+                os += new_v_;
+                os += "\"";
+            }
+            else {
+                std::string value = new_v_;
+                Str::replaceall(value, "\n", "\\n");
+                os += " # \"";
+                os += value;
+                os += "\"";
+            }
+        }
+    }
+    os += "\n";
+}
+
+std::string Label::toString() const {
+    // parsing always STRIPS the quotes, hence add them back
+    std::string ret;
+    ret.reserve(n_.size() + v_.size() + 10);
+    write(ret);
+    return ret;
+}
+
+void Label::write(std::string& ret) const {
+    // parsing always STRIPS the quotes, hence add them back
+    ret += "label ";
+    ret += n_;
+    ret += " \"";
+    if (v_.find("\n") == std::string::npos)
+        ret += v_;
+    else {
+        // replace \n, otherwise re-parse will fail
+        std::string value = v_;
+        Str::replaceall(value, "\n", "\\n");
+        ret += value;
+    }
+    ret += "\"";
+}
+
+std::string Label::dump() const {
+    std::stringstream ss;
+    ss << toString() << " : \"" << new_v_ << "\"";
+    return ss.str();
+}
+
+void Label::set_new_value(const std::string& l) {
+    new_v_           = l;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Label::set_new_value\n";
+#endif
+}
+
+void Label::reset() {
+    new_v_.clear();
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Label::reset()\n";
+#endif
+}
+
+void Label::parse(const std::string& line, std::vector<std::string>& lineTokens, bool parse_state) {
+    parse(line, lineTokens, parse_state, n_, v_, new_v_);
+}
+
+void Label::parse(const std::string& line,
+                  std::vector<std::string>& lineTokens,
+                  bool parse_state,
+                  std::string& the_name,
+                  std::string& the_value,
+                  std::string& the_new_value) {
+    size_t line_token_size = lineTokens.size();
+    if (line_token_size < 3)
+        throw std::runtime_error("Label::parse: Invalid label :" + line);
+
+    the_name = lineTokens[1];
+
+    // parsing will always STRIP single or double quotes, print will add double quotes
+    // label simple_label 'ecgems'
+    if (line_token_size == 3) {
+        Str::removeQuotes(lineTokens[2]);
+        Str::removeSingleQuotes(lineTokens[2]);
+        the_value = lineTokens[2];
+        if (the_value.find("\\n") != std::string::npos) {
+            Str::replaceall(the_value, "\\n", "\n");
+        }
+    }
+    else {
+
+        // label complex_label "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # fred
+        // label simple_label "fred" #  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"
+        std::string value;
+        value.reserve(line.size());
+        for (size_t i = 2; i < line_token_size; ++i) {
+            if (lineTokens[i].at(0) == '#')
+                break;
+            if (i != 2)
+                value += " ";
+            value += lineTokens[i];
+        }
+
+        Str::removeQuotes(value);
+        Str::removeSingleQuotes(value);
+        the_value = value;
+        if (the_value.find("\\n") != std::string::npos) {
+            Str::replaceall(the_value, "\\n", "\n");
+        }
+
+        // state
+        if (parse_state) {
+            // label name "value" # "new  value"
+            bool comment_fnd                 = false;
+            size_t first_quote_after_comment = 0;
+            size_t last_quote_after_comment  = 0;
+            for (size_t i = line.size() - 1; i > 0; i--) {
+                if (line[i] == '#') {
+                    comment_fnd = true;
+                    break;
+                }
+                if (line[i] == '"') {
+                    if (last_quote_after_comment == 0)
+                        last_quote_after_comment = i;
+                    first_quote_after_comment = i;
+                }
+            }
+            if (comment_fnd && first_quote_after_comment != last_quote_after_comment) {
+                std::string new_value = line.substr(first_quote_after_comment + 1,
+                                                    last_quote_after_comment - first_quote_after_comment - 1);
+                // std::cout << "new label = '" << new_value << "'\n";
+                the_new_value = new_value;
+
+                if (the_new_value.find("\\n") != std::string::npos) {
+                    Str::replaceall(the_new_value, "\\n", "\n");
+                }
+            }
+        }
+    }
+}
+
+template <class Archive>
+void Label::serialize(Archive& ar) {
+    ar(CEREAL_NVP(n_));
+    CEREAL_OPTIONAL_NVP(ar, v_, [this]() { return !v_.empty(); });
+    CEREAL_OPTIONAL_NVP(ar, new_v_, [this]() { return !new_v_.empty(); }); // conditionally save
+}
+
+template <class Archive>
+void Event::serialize(Archive& ar) {
+    CEREAL_OPTIONAL_NVP(ar, n_, [this]() { return !n_.empty(); });
+    CEREAL_OPTIONAL_NVP(ar, number_, [this]() { return number_ != std::numeric_limits<int>::max(); });
+    CEREAL_OPTIONAL_NVP(ar, v_, [this]() { return v_; });
+    CEREAL_OPTIONAL_NVP(ar, iv_, [this]() { return iv_; });
+}
+
+template <class Archive>
+void Meter::serialize(Archive& ar) {
+    ar(CEREAL_NVP(min_), CEREAL_NVP(max_), CEREAL_NVP(v_), CEREAL_NVP(n_), CEREAL_NVP(cc_));
+}
+
+CEREAL_TEMPLATE_SPECIALIZE(Label);
+CEREAL_TEMPLATE_SPECIALIZE(Event);
+CEREAL_TEMPLATE_SPECIALIZE(Meter);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/NodeAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/NodeAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/NodeAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/NodeAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,199 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_NodeAttr_HPP
+#define ecflow_attribute_NodeAttr_HPP
+
+#include <limits> // for std::numeric_limits<int>::max()
+#include <string>
+#include <vector>
+
+#include <boost/operators.hpp>
+
+namespace cereal {
+class access;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////
+// Class Label:
+// Use compiler , generated destructor, assignment,  copy constructor
+class Label : public boost::equality_comparable<Label> {
+public:
+    Label(const std::string& name, const std::string& value, const std::string& new_value = "", bool check_name = true);
+    Label() = default;
+
+    void print(std::string&) const;
+    const std::string& name() const { return n_; }
+    const std::string& value() const { return v_; }
+    const std::string& new_value() const { return new_v_; }
+    void set_new_value(const std::string& new_label);
+    void reset();
+    bool empty() const { return n_.empty(); }
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    // 2 kinds of equality, structure and state
+    friend bool operator==(const Label& lhs, const Label& rhs) {
+        if (lhs.n_ != rhs.n_) {
+            // std::cout << "lhs.n_ '" << lhs.n_ << "' != rhs.n_ '" << rhs.n_ << "'\n";
+            return false;
+        }
+        if (lhs.new_v_ != rhs.new_v_) {
+            // std::cout << "lhs.new_v_ '" << lhs.new_v_ << "' != rhs.new_v_ '" << rhs.new_v_ << "'\n";
+            return false;
+        }
+        if (lhs.v_ != rhs.v_) {
+            // std::cout << "lhs.v_ '" << lhs.v_ << "' != rhs.v_ '" << rhs.v_ << "'\n";
+            return false;
+        }
+        return true;
+    }
+    bool operator<(const Label& rhs) const { return n_ < rhs.name(); }
+
+    std::string toString() const;
+    std::string dump() const;
+
+    void parse(const std::string& line, std::vector<std::string>& lineTokens, bool parse_state);
+    static void parse(const std::string& line,
+                      std::vector<std::string>& lineTokens,
+                      bool parse_state,
+                      std::string&,
+                      std::string&,
+                      std::string&);
+    static const Label& EMPTY(); // Added to support return by reference
+
+private:
+    void write(std::string&) const;
+
+private:
+    std::string n_;
+    std::string v_;
+    std::string new_v_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+// Class Event:
+// events with the number 007 are the same as 7.
+// Use compiler , generated destructor, assignment, copy constructor
+//
+// Don't use -1, to represent that no number was specified, as on
+// AIX portable binary archive can't cope with this
+// use std::numeric_limits<int>::max()
+class Event {
+public:
+    explicit Event(int number, const std::string& eventName = "", bool initial_val = false, bool check_name = true);
+    explicit Event(const std::string& eventName, bool initial_val = false);
+    Event() = default;
+
+    std::string name_or_number() const; // if name present return, else return number
+    const std::string& name() const { return n_; }
+    void print(std::string&) const;
+    bool value() const { return v_; }
+    void reset() { set_value(iv_); }
+    bool empty() const { return (n_.empty() && number_ == std::numeric_limits<int>::max()); }
+    void set_initial_value(bool iv) { iv_ = iv; }
+    bool initial_value() const { return iv_; }
+
+    int number() const { return number_; }
+    bool operator==(const Event& rhs) const;
+    bool operator<(const Event& rhs) const;
+    bool compare(const Event& rhs) const; // two events the same if name/number the same, ignores state
+    void set_value(bool b);               // updates state_change_no_
+    bool usedInTrigger() const { return used_; }
+    void usedInTrigger(bool b) { used_ = b; }
+
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    std::string toString() const;
+    std::string dump() const;
+
+    static bool isValidState(const std::string&); // return true for "set" | "clear"
+    static const std::string& SET();
+    static const std::string& CLEAR();
+    static const Event& EMPTY(); // Added to support return by reference
+
+private:
+    void write(std::string&) const;
+
+private:
+    std::string n_;
+    int number_{std::numeric_limits<int>::max()};
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool v_{false};
+    bool iv_{false};   // initial value ECFLOW-1526
+    bool used_{false}; // used by the simulator not persisted
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+// Class Meter:
+// Use compiler , generated destructor, assignment, copy constructor
+// For this class we don't check the value member for the equality functionality
+// Can have negative min/max however max >= min, and color change should be in the
+// range min-max
+class Meter {
+public:
+    Meter(const std::string& name,
+          int min,
+          int max,
+          int colorChange = std::numeric_limits<int>::max(),
+          int value       = std::numeric_limits<int>::max(),
+          bool check      = true);
+    Meter() = default;
+
+    void print(std::string&) const;
+    void reset() { set_value(min_); }
+    void set_value(int v); // can throw throw std::runtime_error if out of range
+    bool empty() const { return n_.empty(); }
+
+    const std::string& name() const { return n_; }
+    int value() const { return v_; }
+    int min() const { return min_; }
+    int max() const { return max_; }
+    int colorChange() const { return cc_; }
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    bool operator==(const Meter& rhs) const;
+    bool operator<(const Meter& rhs) const { return n_ < rhs.name(); }
+
+    bool usedInTrigger() const { return used_; }
+    void usedInTrigger(bool b) { used_ = b; }
+    std::string toString() const;
+    std::string dump() const;
+
+    static const Meter& EMPTY(); // Added to support return by reference
+
+private:
+    void write(std::string&) const;
+    bool isValidValue(int v) const { return (v >= min_ && v <= max_); }
+
+    int min_{0};
+    int max_{0};
+    int v_{0};                        // value
+    int cc_{0};                       // Colour change, used by gui ?
+    std::string n_;                   // name
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool used_{false};                // used by the simulator not persisted
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_attribute_NodeAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/QueueAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/QueueAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/QueueAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/QueueAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,297 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/QueueAttr.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+/////////////////////////////////////////////////////////////////////////////////////////////
+
+const QueueAttr& QueueAttr::EMPTY() {
+    static const QueueAttr queueAttr = QueueAttr();
+    return queueAttr;
+}
+QueueAttr& QueueAttr::EMPTY1() {
+    static QueueAttr queueAttr = QueueAttr();
+    return queueAttr;
+}
+
+QueueAttr::QueueAttr(const std::string& name, const std::vector<std::string>& theQueue)
+    : theQueue_(theQueue),
+      name_(name) {
+    string msg;
+    if (!Str::valid_name(name, msg)) {
+        throw std::runtime_error("QueueAttr::QueueAttr: Invalid queue name : " + msg);
+    }
+    if (theQueue.empty()) {
+        throw std::runtime_error("QueueAttr::QueueAttr: No queue items specified");
+    }
+    for (size_t i = 0; i < theQueue.size(); i++)
+        state_vec_.push_back(NState::QUEUED);
+}
+
+QueueAttr::~QueueAttr() = default;
+
+void QueueAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        os += " # ";
+        os += ecf::convert_to<std::string>(currentIndex_);
+        for (auto i : state_vec_) {
+            os += " ";
+            os += NState::toString(i);
+        }
+    }
+    os += "\n";
+}
+
+bool QueueAttr::operator==(const QueueAttr& rhs) const {
+    if (name_ != rhs.name_)
+        return false;
+    if (theQueue_ != rhs.theQueue_)
+        return false;
+    if (state_vec_ != rhs.state_vec_)
+        return false;
+    if (currentIndex_ != rhs.currentIndex_)
+        return false;
+    return true;
+}
+
+std::string QueueAttr::value() const {
+    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theQueue_.size())) {
+        return theQueue_[currentIndex_];
+    }
+    return "<NULL>";
+}
+
+int QueueAttr::index_or_value() const {
+    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theQueue_.size())) {
+        try {
+            return ecf::convert_to<int>(theQueue_[currentIndex_]);
+        }
+        catch (ecf::bad_conversion&) {
+            // Ignore and return currentIndex_
+        }
+    }
+    return currentIndex_;
+}
+
+NState::State QueueAttr::state(const std::string& step) const {
+    for (size_t i = 0; i < theQueue_.size(); i++) {
+        if (step == theQueue_[i]) {
+            if (i >= state_vec_.size())
+                throw std::runtime_error("QueueAttr::state: index out of range");
+            return state_vec_[i];
+        }
+    }
+    throw std::runtime_error("QueueAttr::state: could not find step " + step);
+    return NState::UNKNOWN;
+}
+
+void QueueAttr::requeue() {
+    currentIndex_ = 0;
+    for (auto& i : state_vec_)
+        i = NState::QUEUED;
+    incr_state_change_no();
+}
+
+std::string QueueAttr::active() {
+    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theQueue_.size())) {
+        state_vec_[currentIndex_] = NState::ACTIVE;
+        std::string ret           = theQueue_[currentIndex_];
+        currentIndex_++;
+        incr_state_change_no();
+        return ret;
+    }
+    return "<NULL>";
+}
+
+void QueueAttr::complete(const std::string& step) {
+    for (size_t i = 0; i < theQueue_.size(); i++) {
+        if (step == theQueue_[i]) {
+            state_vec_[i] = NState::COMPLETE;
+            incr_state_change_no();
+            return;
+        }
+    }
+    std::stringstream ss;
+    ss << "QueueAttr::complete: Could not find " << step << " in queue " << name_;
+    throw std::runtime_error(ss.str());
+}
+
+void QueueAttr::aborted(const std::string& step) {
+    for (size_t i = 0; i < theQueue_.size(); i++) {
+        if (step == theQueue_[i]) {
+            state_vec_[i] = NState::ABORTED;
+            incr_state_change_no();
+            return;
+        }
+    }
+    std::stringstream ss;
+    ss << "QueueAttr::aborted: Could not find " << step << " in queue " << name_;
+    throw std::runtime_error(ss.str());
+}
+
+std::string QueueAttr::no_of_aborted() const {
+    int count = 0;
+    for (auto i : state_vec_) {
+        if (i == NState::ABORTED)
+            count++;
+    }
+    if (count != 0)
+        return ecf::convert_to<std::string>(count);
+    return std::string();
+}
+
+void QueueAttr::reset_index_to_first_queued_or_aborted() {
+    for (size_t i = 0; i < state_vec_.size(); i++) {
+        if (state_vec_[i] == NState::QUEUED || state_vec_[i] == NState::ABORTED) {
+            currentIndex_ = i;
+            incr_state_change_no();
+            break;
+        }
+    }
+}
+
+std::string QueueAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void QueueAttr::write(std::string& ret) const {
+    ret += "queue ";
+    ret += name_;
+    for (const auto& i : theQueue_) {
+        ret += " ";
+        ret += i;
+    }
+}
+
+std::string QueueAttr::dump() const {
+    std::stringstream ss;
+    ss << toString() << " # " << currentIndex_;
+    for (auto i : state_vec_)
+        ss << " " << i;
+    return ss.str();
+}
+
+void QueueAttr::incr_state_change_no() {
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void QueueAttr::parse(QueueAttr& queAttr,
+                      const std::string& line,
+                      std::vector<std::string>& lineTokens,
+                      bool parse_state) {
+    size_t line_tokens_size = lineTokens.size();
+    if (line_tokens_size < 3) {
+        std::stringstream ss;
+        ss << "QueueAttr::parse: expected at least 3 tokens, found " << line_tokens_size << " on line:" << line << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // queue name "first" "second" "last" #   current_index state state state
+    //   0     1     2        3       4   5   6
+    queAttr.set_name(lineTokens[1]);
+
+    std::vector<std::string> theEnums;
+    theEnums.reserve(line_tokens_size);
+    for (size_t i = 2; i < line_tokens_size; i++) {
+        std::string theEnum = lineTokens[i];
+        if (theEnum[0] == '#')
+            break;
+        Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
+        Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
+        theEnums.push_back(theEnum);
+    }
+    if (theEnums.empty())
+        throw std::runtime_error("queue: has no values " + line);
+
+    int index = 0;
+    std::vector<NState::State> state_vec;
+
+    if (parse_state) {
+        // queue VARIABLE a b c d # index active complete aborted queued
+        for (size_t i = 3; i < line_tokens_size; i++) {
+            if (lineTokens[i] == "#" && i + 1 < line_tokens_size) {
+                i++;
+                index = Extract::theInt(lineTokens[i], "QueueAttr::parse, could not extract index");
+                i++;
+                for (; i < line_tokens_size; i++) {
+                    NState::State state = NState::toState(lineTokens[i]);
+                    state_vec.push_back(state);
+                }
+                break;
+            }
+        }
+    }
+
+    queAttr.set_queue(theEnums, index, state_vec);
+}
+
+void QueueAttr::set_queue(const std::vector<std::string>& theQueue,
+                          int index,
+                          const std::vector<NState::State>& state_vec) {
+    if (theQueue.empty())
+        throw std::runtime_error("QueueAttr::set_queue: No queue items specified");
+
+    if (!state_vec.empty()) {
+        if (state_vec.size() != theQueue.size()) {
+            std::stringstream ss;
+            ss << "QueueAttr::set_state: for queue " << name_ << " size " << theQueue.size()
+               << " does not match state size " << state_vec.size();
+            throw std::runtime_error(ss.str());
+        }
+        state_vec_ = state_vec;
+    }
+    else {
+        for (size_t i = 0; i < theQueue.size(); i++)
+            state_vec_.push_back(NState::QUEUED);
+    }
+
+    currentIndex_ = index;
+    theQueue_     = theQueue;
+}
+
+void QueueAttr::set_state_vec(const std::vector<NState::State>& state_vec) {
+    state_vec_ = state_vec;
+    if (theQueue_.size() != state_vec_.size()) {
+        std::cout << "QueueAttr::set_state_vec: for queue " << name_ << " queue size " << theQueue_.size()
+                  << " not equal to state_vec size " << state_vec_.size() << "\n";
+    }
+}
+
+void QueueAttr::set_name(const std::string& name) {
+    string msg;
+    if (!Str::valid_name(name, msg)) {
+        throw std::runtime_error("QueueAttr::set_name: Invalid queue name : " + msg);
+    }
+    name_ = name;
+}
+
+template <class Archive>
+void QueueAttr::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(theQueue_), CEREAL_NVP(state_vec_), CEREAL_NVP(name_), CEREAL_NVP(currentIndex_));
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(QueueAttr);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/QueueAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/QueueAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/QueueAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/QueueAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_QueueAttr_HPP
+#define ecflow_attribute_QueueAttr_HPP
+
+#include <cstdint>
+
+#include "ecflow/core/NState.hpp"
+
+/////////////////////////////////////////////////////////////////////////
+class QueueAttr {
+public:
+    QueueAttr(const std::string& name, const std::vector<std::string>& theQueue);
+    QueueAttr() = default;
+    ~QueueAttr();
+
+    void print(std::string&) const;
+    bool operator==(const QueueAttr& rhs) const;
+    bool operator<(const QueueAttr& rhs) const { return name_ < rhs.name(); }
+
+    /// Accessor
+    const std::string& name() const { return name_; }
+    std::string value() const;
+    int index_or_value() const;
+    int index() const { return currentIndex_; }
+    bool empty() const { return name_.empty(); }
+    const std::vector<std::string>& list() const { return theQueue_; }
+    const std::vector<NState::State>& state_vec() const { return state_vec_; }
+    NState::State state(const std::string& step) const;
+
+    std::string toString() const;
+    std::string dump() const;
+
+    // Mutators
+    void requeue();
+
+    std::string active();                   // return current index and value, make active, increment index
+    void complete(const std::string& step); // step is more index:value
+    void aborted(const std::string& step);
+    std::string no_of_aborted() const;
+    void reset_index_to_first_queued_or_aborted();
+
+    void set_used_in_trigger(bool f) { used_in_trigger_ = f; } // used by simulator only
+    bool used_in_trigger() const { return used_in_trigger_; }
+
+    static void parse(QueueAttr&, const std::string& line, std::vector<std::string>& lineTokens, bool parse_state);
+    void set_name(const std::string& name);
+    void set_queue(const std::vector<std::string>& theQueue, int index, const std::vector<NState::State>& state_vec);
+    void set_state_vec(const std::vector<NState::State>& state_vec);
+    void set_index(int index) { currentIndex_ = index; };
+
+    // Added to support return by reference
+    static const QueueAttr& EMPTY();
+    static QueueAttr& EMPTY1();
+
+    unsigned int state_change_no() const { return state_change_no_; }
+
+private:
+    void incr_state_change_no();
+    void write(std::string&) const;
+
+private:
+    std::vector<std::string> theQueue_;
+    std::vector<NState::State> state_vec_;
+    std::string name_;
+    int currentIndex_{0};
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool used_in_trigger_{false};     // *not* persisted, used by simulator only
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_attribute_QueueAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/RepeatAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/RepeatAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/RepeatAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/RepeatAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1855 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/RepeatAttr.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include <boost/date_time.hpp>
+#include <boost/date_time/posix_time/time_parsers.hpp>
+
+#include "ecflow/core/Cal.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+const Repeat& Repeat::EMPTY() {
+    static const Repeat REPEAT = Repeat();
+    return REPEAT;
+}
+
+//=========================================================================
+
+Repeat::Repeat() = default;
+Repeat::Repeat(const RepeatDate& r) : type_(std::make_unique<RepeatDate>(r)) {
+}
+Repeat::Repeat(const RepeatDateTime& r) : type_(std::make_unique<RepeatDateTime>(r)) {
+}
+Repeat::Repeat(const RepeatDateList& r) : type_(std::make_unique<RepeatDateList>(r)) {
+}
+Repeat::Repeat(const RepeatInteger& r) : type_(std::make_unique<RepeatInteger>(r)) {
+}
+Repeat::Repeat(const RepeatEnumerated& r) : type_(std::make_unique<RepeatEnumerated>(r)) {
+}
+Repeat::Repeat(const RepeatString& r) : type_(std::make_unique<RepeatString>(r)) {
+}
+Repeat::Repeat(const RepeatDay& r) : type_(std::make_unique<RepeatDay>(r)) {
+}
+
+Repeat::~Repeat() = default;
+
+Repeat::Repeat(const Repeat& rhs) {
+    if (rhs.type_) {
+        type_.reset(rhs.type_->clone());
+    }
+}
+
+Repeat& Repeat::operator=(const Repeat& rhs) {
+    type_.reset(nullptr);
+    if (rhs.type_) {
+        type_.reset(rhs.type_->clone());
+    }
+    return *this;
+}
+
+Repeat& Repeat::operator=(Repeat&& rhs) {
+    type_ = std::move(rhs.type_); // since rhs.type_ is a unique_ptr no need to set rhs.type_ to NULL
+    return *this;
+}
+
+bool Repeat::operator==(const Repeat& rhs) const {
+    if (!type_ && rhs.type_)
+        return false;
+    if (type_ && !rhs.type_)
+        return false;
+    if (!type_ && !rhs.type_)
+        return true;
+    return type_->compare(rhs.type_.get());
+}
+
+const std::string& Repeat::name() const {
+    return (type_.get()) ? type_->name() : Str::EMPTY();
+}
+
+void Repeat::print(std::string& os) const {
+    if (type_) {
+        Indentor in;
+        Indentor::indent(os);
+        write(os);
+        os += "\n";
+    }
+}
+
+// =========================================================================
+RepeatBase::~RepeatBase() = default;
+
+void RepeatBase::incr_state_change_no() {
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "RepeatBase::incr_state_change_no()\n";
+#endif
+}
+
+void RepeatBase::update_repeat_genvar() const {
+    // **** reset name since generated variables are not persisted
+    var_.set_name(name_);
+
+    // valueAsString() use the last_valid_value() which should always be in range.
+    // Note repeat::value() can be on e past the last valid value, at expiration of Repeat loop
+    //      However Repeat::last_valid_value() will just return the last valid value.
+    var_.set_value(valueAsString());
+}
+
+std::string RepeatBase::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+// =============================================================
+
+RepeatDate::RepeatDate(const std::string& variable, int start, int end, int delta /* always in days*/
+                       )
+    : RepeatBase(variable),
+      start_(start),
+      end_(end),
+      delta_(delta),
+      value_(start) {
+    if (!Str::valid_name(variable)) {
+        throw std::runtime_error("RepeatDate::RepeatDate: Invalid name: " + variable);
+    }
+
+    if (delta == 0) {
+        std::stringstream ss;
+        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+        throw std::runtime_error("Invalid Repeat date: the delta cannot be zero" + ss.str());
+    }
+
+    std::string theStart = ecf::convert_to<std::string>(start);
+    if (theStart.size() != 8) {
+        std::stringstream ss;
+        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+        throw std::runtime_error("Invalid Repeat date: The start is not a valid date. Please use yyyymmdd format." +
+                                 ss.str());
+    }
+    std::string theEnd = ecf::convert_to<std::string>(end);
+    if (theEnd.size() != 8) {
+        std::stringstream ss;
+        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+        throw std::runtime_error("Invalid Repeat date: The end is not a valid date. Please use yyyymmdd format." +
+                                 ss.str());
+    }
+
+    if (delta_ > 0) {
+        // assert end => start
+        if (!(end >= start)) {
+            std::stringstream ss;
+            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+            throw std::runtime_error(
+                "Invalid Repeat date: The end must be greater than the start date, when delta is positive " + ss.str());
+        }
+    }
+    else {
+        // assert start >= end
+        if (!(start >= end)) {
+            std::stringstream ss;
+            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+            throw std::runtime_error(
+                "Invalid Repeat date: The start must be greater than the end date, when delta is negative " + ss.str());
+        }
+    }
+
+    // Use date lib to check YMD
+    try {
+        (void)boost::gregorian::date(from_undelimited_string(theStart));
+        (void)boost::gregorian::date(from_undelimited_string(theEnd));
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+        throw std::runtime_error("Invalid Repeat date: The start/end is not a valid date." + ss.str());
+    }
+}
+
+void RepeatDate::gen_variables(std::vector<Variable>& vec) const {
+    vec.push_back(yyyy_);
+    vec.push_back(mm_);
+    vec.push_back(dom_);
+    vec.push_back(dow_);
+    vec.push_back(julian_);
+    RepeatBase::gen_variables(vec);
+}
+
+const Variable& RepeatDate::find_gen_variable(const std::string& name) const {
+    if (name == name_)
+        return var_;
+    if (name == julian_.name())
+        return julian_;
+    if (name == dow_.name())
+        return dow_;
+    if (name == dom_.name())
+        return dom_;
+    if (name == mm_.name())
+        return mm_;
+    if (name == yyyy_.name())
+        return yyyy_;
+    return Variable::EMPTY();
+}
+
+void RepeatDate::update_repeat_genvar() const {
+    RepeatBase::update_repeat_genvar();
+
+    yyyy_.set_name(name_ + "_YYYY");
+    yyyy_.set_value("<invalid>");
+    mm_.set_name(name_ + "_MM");
+    mm_.set_value("<invalid>");
+    dom_.set_name(name_ + "_DD");
+    dom_.set_value("<invalid>");
+    dow_.set_name(name_ + "_DOW");
+    dom_.set_value("<invalid>");
+    julian_.set_name(name_ + "_JULIAN");
+    julian_.set_value("<invalid>");
+
+    yyyy_.set_name(name_ + "_YYYY");
+    mm_.set_name(name_ + "_MM");
+    dom_.set_name(name_ + "_DD");
+    dow_.set_name(name_ + "_DOW");
+    julian_.set_name(name_ + "_JULIAN");
+
+    update_repeat_genvar_value();
+}
+
+void RepeatDate::update_repeat_genvar_value() const {
+    std::string date_as_string = valueAsString();
+    if (valid()) {
+        try {
+            boost::gregorian::date the_date(from_undelimited_string(date_as_string));
+            if (the_date.is_special()) {
+                std::stringstream ss;
+                ss << "RepeatDate::update_repeat_genvar(): invalid current date: " << date_as_string << " is_special";
+                log(Log::ERR, ss.str());
+                return;
+            }
+            // int day_of_year  = the_date.day_of_year();
+            int day_of_week  = the_date.day_of_week().as_number();
+            int day_of_month = the_date.day();
+            int month        = the_date.month();
+            int year         = the_date.year();
+
+            yyyy_.set_value(ecf::convert_to<std::string>(year));
+            mm_.set_value(ecf::convert_to<std::string>(month));
+            dom_.set_value(ecf::convert_to<std::string>(day_of_month));
+            dow_.set_value(ecf::convert_to<std::string>(day_of_week));
+
+            long last_value = last_valid_value();
+            long julian     = Cal::date_to_julian(last_value);
+            julian_.set_value(ecf::convert_to<std::string>(julian));
+        }
+        catch (std::exception& e) {
+            std::stringstream ss;
+            ss << "RepeatDate::update_repeat_genvar_value : " << toString() << "\n The current date(" << date_as_string
+               << ") is not valid";
+            log(Log::ERR, ss.str());
+            return;
+        }
+    }
+}
+
+bool RepeatDate::compare(RepeatBase* rb) const {
+    auto* rhs = dynamic_cast<RepeatDate*>(rb);
+    if (!rhs)
+        return false;
+    return operator==(*rhs);
+}
+
+void RepeatDate::setToLastValue() {
+    set_value(end_);
+}
+
+long RepeatDate::last_valid_value() const {
+    return valid_value(value_);
+}
+
+long RepeatDate::valid_value(long value) const {
+    if (delta_ > 0) {
+        if (value < start_)
+            return start_;
+        if (value > end_)
+            return end_;
+        return value;
+    }
+    if (value > start_)
+        return start_;
+    if (value < end_)
+        return end_;
+    return value;
+}
+
+long RepeatDate::last_valid_value_minus(int val) const {
+    long last_value = last_valid_value();
+    long julian     = Cal::date_to_julian(last_value);
+    julian -= val;
+    return Cal::julian_to_date(julian);
+}
+
+long RepeatDate::last_valid_value_plus(int val) const {
+    long last_value = last_valid_value();
+    long julian     = Cal::date_to_julian(last_value);
+    julian += val;
+    return Cal::julian_to_date(julian);
+}
+
+void RepeatDate::reset() {
+    set_value(start_);
+}
+
+void RepeatDate::write(std::string& ret) const {
+    ret += "repeat date ";
+    ret += name_;
+    ret += " ";
+    ret += ecf::convert_to<std::string>(start_);
+    ret += " ";
+    ret += ecf::convert_to<std::string>(end_);
+    ret += " ";
+    ret += ecf::convert_to<std::string>(delta_);
+
+    if (!PrintStyle::defsStyle() && (value_ != start_)) {
+        ret += " # ";
+        ret += ecf::convert_to<std::string>(value_);
+    }
+}
+
+std::string RepeatDate::dump() const {
+    std::stringstream ss;
+    ss << toString() << " value(" << value_ << ")";
+    return ss.str();
+}
+
+bool RepeatDate::operator==(const RepeatDate& rhs) const {
+    if (name_ != rhs.name_) {
+        return false;
+    }
+    if (start_ != rhs.start_) {
+        return false;
+    }
+    if (end_ != rhs.end_) {
+        return false;
+    }
+    if (delta_ != rhs.delta_) {
+        return false;
+    }
+    if (value_ != rhs.value_) {
+        return false;
+    }
+    return true;
+}
+
+std::string RepeatDate::valueAsString() const {
+    /// will throw an ecf::bad_conversion if value is not convertible to a string
+    try {
+        return ecf::convert_to<std::string>(last_valid_value());
+    }
+    catch (const ecf::bad_conversion&) {
+        LOG_ASSERT(false, "RepeatDate::valueAsString(): could not convert value " << value_ << " to a string");
+    }
+    return string();
+}
+
+std::string RepeatDate::value_as_string(int index) const {
+    /// will throw an ecf::bad_conversion if value is not convertible to a string
+    try {
+        return ecf::convert_to<std::string>(index);
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+    return string();
+}
+
+std::string RepeatDate::next_value_as_string() const {
+    long val = last_valid_value();
+
+    long julian = Cal::date_to_julian(val);
+    julian += delta_;
+    val = Cal::julian_to_date(julian);
+
+    try {
+        return ecf::convert_to<std::string>(valid_value(val));
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+    return string();
+}
+
+std::string RepeatDate::prev_value_as_string() const {
+    long val = last_valid_value();
+
+    long julian = Cal::date_to_julian(val);
+    julian -= delta_;
+    val = Cal::julian_to_date(julian);
+
+    try {
+        return ecf::convert_to<std::string>(valid_value(val));
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+    return string();
+}
+
+void RepeatDate::increment() {
+    long julian = Cal::date_to_julian(value_);
+    julian += delta_;
+    set_value(Cal::julian_to_date(julian));
+}
+
+void RepeatDate::change(const std::string& newdate) {
+    if (newdate.size() != 8) {
+        std::stringstream ss;
+        ss << "RepeatDate::change: " << toString()
+           << " The new date is not valid, expected 8 characters in yyyymmdd format but found " << newdate;
+        throw std::runtime_error(ss.str());
+    }
+
+    long the_new_date = 0;
+    try {
+        the_new_date = ecf::convert_to<long>(newdate);
+    }
+    catch (const ecf::bad_conversion&) {
+        std::stringstream ss;
+        ss << "RepeatDate::change: " << toString() << " The new date(" << newdate << ") is not convertible to an long";
+        throw std::runtime_error(ss.str());
+    }
+
+    // Use date lib to check YMD
+    try {
+        (void)boost::gregorian::date(from_undelimited_string(newdate));
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "RepeatDate::change: " << toString() << " The new date(" << newdate << ") is not valid";
+        throw std::runtime_error(ss.str());
+    }
+
+    changeValue(the_new_date);
+}
+
+void RepeatDate::changeValue(long the_new_date) {
+    if (delta_ > 0) {
+        if (the_new_date < start_ || the_new_date > end_) {
+            std::stringstream ss;
+            ss << "RepeatDate::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
+               << " : " << end_ << "] but found " << the_new_date;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else {
+        if (the_new_date > start_ || the_new_date < end_) {
+            std::stringstream ss;
+            ss << "RepeatDate::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
+               << " : " << end_ << "] but found " << the_new_date;
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    // Check new value is in step. ECFLOW-325 repeat date 7
+    long julian_new_date = Cal::date_to_julian(the_new_date);
+    long julian_start    = Cal::date_to_julian(start_);
+    long diff            = julian_new_date - julian_start;
+    if (diff % delta_ != 0) {
+        std::stringstream ss;
+        ss << "RepeatDate::changeValue: " << toString() << "\nThe new date " << the_new_date
+           << " is not in line with the delta/step";
+        throw std::runtime_error(ss.str());
+    }
+
+    set_value(the_new_date);
+}
+
+void RepeatDate::set_value(long the_new_date) {
+    // Note: the node is incremented one past, the last value
+    // In Node we increment() then check for validity
+    // hence the_new_value may be outside of the valid range.
+    // This can be seen when do a incremental sync,
+    // *hence* allow memento to copy the value as is.
+    value_ = the_new_date;
+    update_repeat_genvar_value();
+    incr_state_change_no();
+}
+
+// =============================================================
+
+RepeatDateTime::RepeatDateTime(const std::string& variable,
+                               const std::string& start,
+                               const std::string& end,
+                               const std::string& delta)
+    : RepeatDateTime(variable, Instant::parse(start), Instant::parse(end), Duration::parse(delta)) {
+}
+
+RepeatDateTime::RepeatDateTime(const std::string& variable, Instant start, Instant end, Duration delta)
+    : RepeatBase(variable),
+      start_(start),
+      end_(end),
+      delta_(delta),
+      value_(start) {
+    if (!Str::valid_name(variable)) {
+        throw std::runtime_error("RepeatDateTime::RepeatDateTime: Invalid name: " + variable);
+    }
+
+    if (delta == Duration{std::chrono::seconds{0}}) {
+        std::stringstream ss;
+        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+        throw std::runtime_error("Invalid Repeat datetime: the delta cannot be zero" + ss.str());
+    }
+
+    auto theStart = boost::lexical_cast<std::string>(start);
+    if (theStart.size() != 15) {
+        std::stringstream ss;
+        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+        throw std::runtime_error(
+            "Invalid Repeat datetime: The start is not a valid date+time. Please use yyyymmddTMMHHSS format." +
+            ss.str());
+    }
+    auto theEnd = boost::lexical_cast<std::string>(end);
+    if (theEnd.size() != 15) {
+        std::stringstream ss;
+        ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+        throw std::runtime_error(
+            "Invalid Repeat datetime: The end is not a valid date+time. Please use yyyymmddTHHMMSS format." + ss.str());
+    }
+
+    if (delta_ > Duration{std::chrono::seconds{0}}) {
+        // assert end => start
+        if (!(end >= start)) {
+            std::stringstream ss;
+            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+            throw std::runtime_error(
+                "Invalid Repeat datetime: The end must be greater than the start date+time, when delta is positive " +
+                ss.str());
+        }
+    }
+    else {
+        // assert start >= end
+        if (!(start >= end)) {
+            std::stringstream ss;
+            ss << "repeat " << variable << " " << start << " " << end << " " << delta;
+            throw std::runtime_error(
+                "Invalid Repeat datetime: The start must be greater than the end date+time, when delta is negative " +
+                ss.str());
+        }
+    }
+}
+
+void RepeatDateTime::gen_variables(std::vector<Variable>& vec) const {
+    for (const auto& entry : generated_) {
+        vec.push_back(entry);
+    }
+    RepeatBase::gen_variables(vec);
+}
+
+const Variable& RepeatDateTime::find_gen_variable(const std::string& name) const {
+    if (name == name_) {
+        return var_;
+    }
+    for (const auto& entry : generated_) {
+        if (entry.name() == name) {
+            return entry;
+        }
+    }
+    return Variable::EMPTY();
+}
+
+void RepeatDateTime::update_repeat_genvar() const {
+    RepeatBase::update_repeat_genvar();
+
+    // Reset variables values
+    generated_.set_value("<invalid>");
+
+    update_repeat_genvar_value();
+}
+
+void RepeatDateTime::update_repeat_genvar_value() const {
+    std::string date_as_string = valueAsString();
+    if (valid()) {
+        try {
+            auto dt = boost::posix_time::from_iso_string(date_as_string);
+            // Using boost posix_time/gregorian, since C++17 still doesn't include calendar types.
+
+            auto d = dt.date();
+            // Date
+            generated_[name_ + "_DATE"].set_value(boost::gregorian::to_iso_string(d));
+            // Date Components
+            generated_[name_ + "_YYYY"].set_value(std::to_string(d.year()));
+            generated_[name_ + "_MM"].set_value(std::to_string(d.month()));
+            generated_[name_ + "_DD"].set_value(std::to_string(d.day()));
+            generated_[name_ + "_JULIAN"].set_value(std::to_string(d.julian_day()));
+
+            auto t = dt.time_of_day();
+            // Time
+            generated_[name_ + "_TIME"].set_value(boost::posix_time::to_iso_string(t));
+            // Time Components
+            generated_[name_ + "_HOURS"].set_value(std::to_string(t.hours()));
+            generated_[name_ + "_MINUTES"].set_value(std::to_string(t.minutes()));
+            generated_[name_ + "_SECONDS"].set_value(std::to_string(t.seconds()));
+        }
+        catch (std::exception& e) {
+            std::stringstream ss;
+            ss << "RepeatDateTime::update_repeat_genvar_value : " << toString() << "\n The current date("
+               << date_as_string << ") is not valid";
+            log(Log::ERR, ss.str());
+            return;
+        }
+    }
+}
+
+bool RepeatDateTime::compare(RepeatBase* rb) const {
+    auto* rhs = dynamic_cast<RepeatDateTime*>(rb);
+    if (!rhs)
+        return false;
+    return operator==(*rhs);
+}
+
+void RepeatDateTime::setToLastValue() {
+    set_value(coerce_from_instant(end_));
+}
+
+long RepeatDateTime::last_valid_value() const {
+    Instant valid = valid_value(value_);
+    return coerce_from_instant(valid);
+}
+
+Instant RepeatDateTime::valid_value(const Instant& value) const {
+    if (delta_ > Duration{std::chrono::seconds{0}}) {
+        if (value < start_)
+            return start_;
+        if (value > end_)
+            return end_;
+        return value;
+    }
+    if (value > start_)
+        return start_;
+    if (value < end_)
+        return end_;
+    return value;
+}
+
+long RepeatDateTime::last_valid_value_minus(int val) const {
+    Instant last_value    = coerce_to_instant(last_valid_value());
+    Instant updated_value = last_value - Duration{std::chrono::seconds{val}};
+    return coerce_from_instant(updated_value);
+}
+
+long RepeatDateTime::last_valid_value_plus(int val) const {
+    Instant last_value    = coerce_to_instant(last_valid_value());
+    Instant updated_value = last_value + Duration{std::chrono::seconds{val}};
+    return coerce_from_instant(updated_value);
+}
+
+void RepeatDateTime::reset() {
+    set_value(ecf::coerce_from_instant(start_));
+}
+
+void RepeatDateTime::write(std::string& ret) const {
+    ret += "repeat datetime ";
+    ret += name_;
+    ret += " ";
+    ret += boost::lexical_cast<std::string>(start_);
+    ret += " ";
+    ret += boost::lexical_cast<std::string>(end_);
+    ret += " ";
+    ret += boost::lexical_cast<std::string>(delta_);
+
+    if (!PrintStyle::defsStyle() && (value_ != start_)) {
+        ret += " # ";
+        ret += boost::lexical_cast<std::string>(value_);
+    }
+}
+
+std::string RepeatDateTime::dump() const {
+    std::stringstream ss;
+    ss << toString() << " value(" << value_ << ")";
+    return ss.str();
+}
+
+bool RepeatDateTime::operator==(const RepeatDateTime& rhs) const {
+    if (name_ != rhs.name_) {
+        return false;
+    }
+    if (start_ != rhs.start_) {
+        return false;
+    }
+    if (end_ != rhs.end_) {
+        return false;
+    }
+    if (delta_ != rhs.delta_) {
+        return false;
+    }
+    if (value_ != rhs.value_) {
+        return false;
+    }
+    return true;
+}
+
+std::string RepeatDateTime::valueAsString() const {
+    /// will throw a boost::bad_lexical_cast& if value is not convertible to a string
+    try {
+        long value      = last_valid_value();
+        Instant instant = coerce_to_instant(value);
+        return boost::lexical_cast<std::string>(instant);
+    }
+    catch (boost::bad_lexical_cast&) {
+        LOG_ASSERT(false, "RepeatDateTime::valueAsString(): could not convert value " << value_ << " to a string");
+    }
+    return {};
+}
+
+std::string RepeatDateTime::value_as_string(int index) const {
+    /// will throw a boost::bad_lexical_cast& if value is not convertible to a string
+    try {
+        return boost::lexical_cast<std::string>(index);
+    }
+    catch (boost::bad_lexical_cast&) {
+    }
+    return {};
+}
+
+std::string RepeatDateTime::next_value_as_string() const {
+    Instant next = coerce_to_instant(last_valid_value()) + delta_;
+
+    try {
+        return boost::lexical_cast<std::string>(valid_value(next));
+    }
+    catch (boost::bad_lexical_cast&) {
+    }
+    return {};
+}
+
+std::string RepeatDateTime::prev_value_as_string() const {
+    Instant previous = coerce_to_instant(last_valid_value()) - delta_;
+
+    try {
+        return boost::lexical_cast<std::string>(valid_value(previous));
+    }
+    catch (boost::bad_lexical_cast&) {
+    }
+    return {};
+}
+
+void RepeatDateTime::increment() {
+    auto new_value = value_ + delta_;
+    set_value(ecf::coerce_from_instant(new_value));
+}
+
+void RepeatDateTime::change(const std::string& newdate) {
+
+    long the_new_date;
+    try {
+        auto instant = Instant::parse(newdate);
+        the_new_date = ecf::coerce_from_instant(instant);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "RepeatDateTime::change: " << toString() << " The new date(" << newdate << ") is not valid";
+        throw std::runtime_error(ss.str());
+    }
+
+    changeValue(the_new_date);
+}
+
+void RepeatDateTime::changeValue(long the_new_date) {
+
+    auto new_date = ecf::coerce_to_instant(the_new_date);
+    if (delta_ > Duration{std::chrono::seconds{0}}) {
+        if (new_date < start_ || new_date > end_) {
+            std::stringstream ss;
+            ss << "RepeatDateTime::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
+               << " : " << end_ << "] but found " << new_date;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else {
+        if (new_date > start_ || new_date < end_) {
+            std::stringstream ss;
+            ss << "RepeatDateTime::changeValue: " << toString() << "\nThe new date should be in the range[" << start_
+               << " : " << end_ << "] but found " << the_new_date;
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    // Ensure that new value is in step
+    auto diff = new_date - start_;
+    if (diff.as_seconds().count() % delta_.as_seconds().count() != 0) {
+        std::stringstream ss;
+        ss << "RepeatDateTime::changeValue: " << toString() << "\nThe new date " << the_new_date
+           << " is not in line with the delta/step";
+        throw std::runtime_error(ss.str());
+    }
+
+    set_value(the_new_date);
+}
+
+void RepeatDateTime::set_value(long the_new_date) {
+    // Note: the node is incremented one past, the last value
+    // In Node we increment() then check for validity
+    // hence the_new_value may be outside of the valid range.
+    // This can be seen when do a incremental sync,
+    // *hence* allow memento to copy the value as is.
+    value_ = coerce_to_instant(the_new_date);
+    update_repeat_genvar_value();
+    incr_state_change_no();
+}
+
+//======================================================================================
+
+RepeatDateList::RepeatDateList(const std::string& variable, const std::vector<int>& l)
+    : RepeatBase(variable),
+      list_(l) {
+    if (!Str::valid_name(variable)) {
+        throw std::runtime_error("RepeatDateList: Invalid name: " + variable);
+    }
+    if (list_.empty())
+        throw std::runtime_error("RepeatDateList: " + variable + " is empty");
+
+    for (int i : list_) {
+        std::string date_i = ecf::convert_to<std::string>(i);
+        if (date_i.size() != 8) {
+            std::stringstream ss;
+            ss << "Invalid Repeat datelist : " << variable << " the date " << i
+               << " is not valid. Please use yyyymmdd format.";
+            throw std::runtime_error("Invalid Repeat datelist " + ss.str());
+        }
+
+        try {
+            (void)boost::gregorian::date(from_undelimited_string(date_i));
+        }
+        catch (std::exception& e) {
+            std::stringstream ss;
+            ss << "Invalid Repeat datelist : " << variable << " the date " << i
+               << " is not valid. Please use yyyymmdd format.";
+            throw std::runtime_error("Invalid Repeat datelist " + ss.str());
+        }
+    }
+}
+
+void RepeatDateList::gen_variables(std::vector<Variable>& vec) const {
+    vec.push_back(yyyy_);
+    vec.push_back(mm_);
+    vec.push_back(dom_);
+    vec.push_back(dow_);
+    vec.push_back(julian_);
+    RepeatBase::gen_variables(vec);
+}
+
+const Variable& RepeatDateList::find_gen_variable(const std::string& name) const {
+    if (name == name_)
+        return var_;
+    if (name == yyyy_.name())
+        return yyyy_;
+    if (name == mm_.name())
+        return mm_;
+    if (name == dom_.name())
+        return dom_;
+    if (name == dow_.name())
+        return dow_;
+    if (name == julian_.name())
+        return julian_;
+    return Variable::EMPTY();
+}
+
+void RepeatDateList::update_repeat_genvar() const {
+    RepeatBase::update_repeat_genvar();
+
+    yyyy_.set_name(name_ + "_YYYY");
+    yyyy_.set_value("<invalid>");
+    mm_.set_name(name_ + "_MM");
+    mm_.set_value("<invalid>");
+    dom_.set_name(name_ + "_DD");
+    dom_.set_value("<invalid>");
+    dow_.set_name(name_ + "_DOW");
+    dom_.set_value("<invalid>");
+    julian_.set_name(name_ + "_JULIAN");
+    julian_.set_value("<invalid>");
+
+    update_repeat_genvar_value();
+}
+
+void RepeatDateList::update_repeat_genvar_value() const {
+    if (valid()) {
+        std::string date_as_string = valueAsString();
+        try {
+            boost::gregorian::date the_date(from_undelimited_string(date_as_string));
+            if (the_date.is_special()) {
+                std::stringstream ss;
+                ss << "RepeatDateList::update_repeat_genvar_value(): " << toString()
+                   << "\n invalid current date: " << date_as_string << " is special ";
+                log(Log::ERR, ss.str());
+                return;
+            }
+
+            // int day_of_year  = the_date.day_of_year();
+            int day_of_week  = the_date.day_of_week().as_number();
+            int day_of_month = the_date.day();
+            int month        = the_date.month();
+            int year         = the_date.year();
+
+            yyyy_.set_value(ecf::convert_to<std::string>(year));
+            mm_.set_value(ecf::convert_to<std::string>(month));
+            dom_.set_value(ecf::convert_to<std::string>(day_of_month));
+            dow_.set_value(ecf::convert_to<std::string>(day_of_week));
+
+            long last_value = last_valid_value();
+            long julian     = Cal::date_to_julian(last_value);
+            julian_.set_value(ecf::convert_to<std::string>(julian));
+        }
+        catch (std::exception& e) {
+            std::stringstream ss;
+            ss << "RepeatDateList::update_repeat_genvar_value(): " << toString()
+               << "\n invalid current date: " << date_as_string;
+            log(Log::ERR, ss.str());
+        }
+    }
+}
+
+int RepeatDateList::start() const {
+    if (list_.empty())
+        return 0;
+    return list_[0];
+}
+int RepeatDateList::end() const {
+    if (list_.empty())
+        return 0;
+    return list_[list_.size() - 1];
+}
+
+bool RepeatDateList::compare(RepeatBase* rb) const {
+    auto* rhs = dynamic_cast<RepeatDateList*>(rb);
+    if (!rhs)
+        return false;
+    return operator==(*rhs);
+}
+
+void RepeatDateList::write(std::string& ret) const {
+    ret += "repeat datelist ";
+    ret += name_;
+    for (int date : list_) {
+        ret += " \"";
+        ret += ecf::convert_to<std::string>(date);
+        ret += "\"";
+    }
+    if (!PrintStyle::defsStyle() && (currentIndex_ != 0)) {
+        ret += " # ";
+        ret += ecf::convert_to<std::string>(currentIndex_);
+    }
+}
+
+std::string RepeatDateList::dump() const {
+    std::stringstream ss;
+    ss << toString() << " ordinal-value(" << value() << ") value-as-string(" << valueAsString() << ")";
+    return ss.str();
+}
+
+void RepeatDateList::reset() {
+    set_value(0);
+}
+
+void RepeatDateList::increment() {
+    set_value(currentIndex_ + 1);
+}
+
+long RepeatDateList::value() const {
+    if (list_.empty())
+        return 0;
+
+    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(list_.size())) {
+        return list_[currentIndex_];
+    }
+    return 0;
+}
+
+long RepeatDateList::last_valid_value() const {
+    if (list_.empty())
+        return 0;
+
+    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(list_.size())) {
+        return list_[currentIndex_];
+    }
+    if (currentIndex_ < 0)
+        return list_[0];
+    if (currentIndex_ >= static_cast<int>(list_.size()))
+        return list_[list_.size() - 1];
+    return 0;
+}
+
+long RepeatDateList::last_valid_value_minus(int val) const {
+    long last_value = last_valid_value();
+    if (last_value == 0)
+        return 0;
+
+    long julian = Cal::date_to_julian(last_value);
+    julian -= val;
+    return Cal::julian_to_date(julian);
+}
+
+long RepeatDateList::last_valid_value_plus(int val) const {
+    long last_value = last_valid_value();
+    if (last_value == 0)
+        return 0;
+
+    long julian = Cal::date_to_julian(last_value);
+    julian += val;
+    return Cal::julian_to_date(julian);
+}
+
+void RepeatDateList::setToLastValue() {
+    if (list_.empty())
+        return;
+    set_value(static_cast<int>(list_.size() - 1));
+}
+
+std::string RepeatDateList::valueAsString() const {
+    return ecf::convert_to<std::string>(last_valid_value());
+}
+
+std::string RepeatDateList::value_as_string(int index) const {
+    if (list_.empty())
+        return string("0");
+    if (index >= 0 && index < static_cast<int>(list_.size())) {
+        return ecf::convert_to<std::string>(list_[index]);
+    }
+    if (index < 0)
+        return ecf::convert_to<std::string>(list_[0]);
+    if (index >= static_cast<int>(list_.size()))
+        return ecf::convert_to<std::string>(list_[list_.size() - 1]);
+    return std::string();
+}
+
+std::string RepeatDateList::next_value_as_string() const {
+    if (list_.empty())
+        return string("0");
+
+    int index = currentIndex_;
+    index++;
+    return value_as_string(index);
+}
+
+std::string RepeatDateList::prev_value_as_string() const {
+    if (list_.empty())
+        return string("0");
+
+    int index = currentIndex_;
+    index--;
+    return value_as_string(index);
+}
+
+void RepeatDateList::change(const std::string& newValue) {
+    // See if if matches one of the dates
+    int new_val = 0;
+    try {
+        new_val = ecf::convert_to<int>(newValue);
+    }
+    catch (...) {
+        std::stringstream ss;
+        ss << "RepeatDateList::change: " << toString() << "\nThe new value " << newValue
+           << " is must be convertible to integer, and correspond to an existing value\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    for (size_t i = 0; i < list_.size(); i++) {
+        if (list_[i] == new_val) {
+            set_value(i);
+            return;
+        }
+    }
+
+    std::stringstream ss;
+    ss << "RepeatDateList::change: " << toString() << "\nThe new value " << newValue
+       << " is not a valid member of the date list\n";
+    throw std::runtime_error(ss.str());
+}
+
+void RepeatDateList::changeValue(long the_new_index) {
+    if (list_.empty())
+        return;
+
+    if (the_new_index < 0 || the_new_index >= static_cast<int>(list_.size())) {
+        std::stringstream ss;
+        ss << "RepeatDateList::changeValue:" << toString() << "\nThe new value '" << the_new_index
+           << "' is not a valid index ";
+        ss << "expected range[0-" << list_.size() - 1 << "] but found '" << the_new_index << "'";
+        throw std::runtime_error(ss.str());
+    }
+    set_value(the_new_index);
+}
+
+void RepeatDateList::set_value(long the_new_index) {
+    if (list_.empty())
+        return;
+
+    // Note: the node is incremented one past, the last value
+    // In Node we increment() then check for validity
+    // hence the_new_value may be outside of the valid range.
+    // This can be seen when do a incremental sync,
+    // *hence* allow memento to copy the value as is.
+    currentIndex_ = the_new_index;
+    update_repeat_genvar_value();
+    incr_state_change_no();
+}
+
+bool RepeatDateList::operator==(const RepeatDateList& rhs) const {
+    if (name_ != rhs.name_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatDateList::operator==( name_(" << name_ << ") != rhs.name_(" << rhs.name_ << "))\n";
+        }
+#endif
+        return false;
+    }
+    if (list_ != rhs.list_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatDateList::operator==( list_ != rhs.list_ )\n";
+        }
+#endif
+        return false;
+    }
+    if (currentIndex_ != rhs.currentIndex_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatDateList::operator==( currentIndex_(" << currentIndex_ << ") != rhs.currentIndex_("
+                      << rhs.currentIndex_ << "))\n";
+        }
+#endif
+        return false;
+    }
+    return true;
+}
+
+//======================================================================================
+
+RepeatInteger::RepeatInteger(const std::string& variable, int start, int end, int delta)
+    : RepeatBase(variable),
+      start_(start),
+      end_(end),
+      delta_(delta),
+      value_(start) {
+    // cout << toString() << "\n";
+    if (!Str::valid_name(variable)) {
+        throw std::runtime_error("RepeatInteger: Invalid name: " + variable);
+    }
+}
+RepeatInteger::RepeatInteger() = default;
+
+bool RepeatInteger::compare(RepeatBase* rb) const {
+    auto* rhs = dynamic_cast<RepeatInteger*>(rb);
+    if (!rhs)
+        return false;
+    return operator==(*rhs);
+}
+
+void RepeatInteger::reset() {
+    value_ = start_;
+    incr_state_change_no();
+}
+
+long RepeatInteger::last_valid_value() const {
+    return valid_value(value_);
+}
+
+long RepeatInteger::valid_value(long value) const {
+    if (delta_ > 0) {
+        if (value < start_)
+            return start_;
+        if (value > end_)
+            return end_;
+        return value;
+    }
+    if (value > start_)
+        return start_;
+    if (value < end_)
+        return end_;
+    return value;
+}
+
+void RepeatInteger::increment() {
+    value_ += delta_;
+    incr_state_change_no();
+}
+
+void RepeatInteger::change(const std::string& newValue) {
+    long the_new_value = 0;
+    try {
+        the_new_value = ecf::convert_to<long>(newValue);
+    }
+    catch (const ecf::bad_conversion&) {
+        std::stringstream ss;
+        ss << "RepeatInteger::change:" << toString() << " The new value(" << newValue
+           << ") is not convertible to an long";
+        throw std::runtime_error(ss.str());
+    }
+    changeValue(the_new_value);
+}
+
+void RepeatInteger::changeValue(long the_new_value) {
+    if (delta_ > 0) {
+        if (the_new_value < start_ || the_new_value > end_) {
+            std::stringstream ss;
+            ss << "RepeatInteger::changeValue:" << toString() << ". The new value should be in the range[" << start_
+               << "-" << end_ << "] but found " << the_new_value;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else {
+        if (the_new_value > start_ || the_new_value < end_) {
+            std::stringstream ss;
+            ss << "RepeatInteger::changeValue:" << toString() << ". The new value should be in the range[" << start_
+               << "-" << end_ << "] but found " << the_new_value;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    set_value(the_new_value);
+}
+
+void RepeatInteger::set_value(long the_new_value) {
+    // To be used by Memento only. as it does no checking
+    // Note: the node is incremented one past, the last value
+    // In Node we increment() then check for validity
+    // hence the_new_value may be outside of the valid range.
+    // This can be seen when do a incremental sync,
+    // *hence* allow memento to copy the value as is.
+    value_ = the_new_value;
+    incr_state_change_no();
+}
+
+void RepeatInteger::setToLastValue() {
+    value_ = end_;
+    incr_state_change_no();
+}
+
+void RepeatInteger::write(std::string& ret) const {
+    ret += "repeat integer ";
+    ret += name_;
+    ret += " ";
+    ret += ecf::convert_to<std::string>(start_);
+    ret += " ";
+    ret += ecf::convert_to<std::string>(end_);
+    if (delta_ != 1) {
+        ret += " ";
+        ret += ecf::convert_to<std::string>(delta_);
+    }
+
+    if (!PrintStyle::defsStyle() && (value_ != start_)) {
+        ret += " # ";
+        ret += ecf::convert_to<std::string>(value_);
+    }
+}
+
+std::string RepeatInteger::dump() const {
+    std::stringstream ss;
+    ss << toString() << " value(" << value_ << ")";
+    return ss.str();
+}
+
+bool RepeatInteger::operator==(const RepeatInteger& rhs) const {
+    if (name_ != rhs.name_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatInteger::operator==( name_(" << name_ << ") != rhs.name_(" << rhs.name_ << "))"
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (start_ != rhs.start_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatInteger::operator==( start_(" << start_ << ") != rhs.start_(" << rhs.start_ << "))"
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (end_ != rhs.end_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatInteger::operator==( end_(" << end_ << ") != rhs.end_(" << rhs.end_ << "))"
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (delta_ != rhs.delta_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatInteger::operator==( delta_(" << delta_ << ") != rhs.delta_(" << rhs.delta_ << "))"
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (value_ != rhs.value_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatInteger::operator==( value_(" << value_ << ") != rhs.value_(" << rhs.value_ << "))"
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    return true;
+}
+
+std::string RepeatInteger::valueAsString() const {
+    /// will throw an ecf::bad_conversion if value is not convertible to a string
+    try {
+        return ecf::convert_to<std::string>(last_valid_value());
+    }
+    catch (const ecf::bad_conversion&) {
+        LOG_ASSERT(false, "");
+    }
+    return string();
+}
+
+std::string RepeatInteger::value_as_string(int index) const {
+    /// will throw an ecf::bad_conversion if value is not convertible to a string
+    try {
+        return ecf::convert_to<std::string>(index);
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+    return string();
+}
+
+std::string RepeatInteger::next_value_as_string() const {
+    long val = last_valid_value();
+    val += delta_;
+    try {
+        return ecf::convert_to<std::string>(valid_value(val));
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+    return string();
+}
+
+std::string RepeatInteger::prev_value_as_string() const {
+    long val = last_valid_value();
+    val -= delta_;
+    try {
+        return ecf::convert_to<std::string>(valid_value(val));
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+    return string();
+}
+
+//======================================================================================
+
+RepeatEnumerated::RepeatEnumerated(const std::string& variable, const std::vector<std::string>& theEnums)
+    : RepeatBase(variable),
+      theEnums_(theEnums) {
+    if (!Str::valid_name(variable)) {
+        throw std::runtime_error("RepeatEnumerated: Invalid name: " + variable);
+    }
+    if (theEnums.empty()) {
+        throw std::runtime_error("RepeatEnumerated: " + variable + " is empty");
+    }
+}
+
+int RepeatEnumerated::end() const {
+    if (theEnums_.empty())
+        return 0;
+    return static_cast<int>(theEnums_.size() - 1);
+}
+
+bool RepeatEnumerated::compare(RepeatBase* rb) const {
+    auto* rhs = dynamic_cast<RepeatEnumerated*>(rb);
+    if (!rhs)
+        return false;
+    return operator==(*rhs);
+}
+
+void RepeatEnumerated::write(std::string& ret) const {
+    ret += "repeat enumerated ";
+    ret += name_;
+    for (const string& s : theEnums_) {
+        ret += " \"";
+        ret += s;
+        ret += "\"";
+    }
+    if (!PrintStyle::defsStyle() && (currentIndex_ != 0)) {
+        ret += " # ";
+        ret += ecf::convert_to<std::string>(currentIndex_);
+    }
+}
+
+std::string RepeatEnumerated::dump() const {
+    std::stringstream ss;
+    ss << toString() << " ordinal-value(" << value() << ")   value-as-string(" << valueAsString() << ")";
+    return ss.str();
+}
+
+void RepeatEnumerated::reset() {
+    currentIndex_ = 0;
+    incr_state_change_no();
+}
+
+void RepeatEnumerated::increment() {
+    currentIndex_++;
+    incr_state_change_no();
+}
+
+long RepeatEnumerated::value() const {
+    if (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theEnums_.size())) {
+        try {
+            return ecf::convert_to<int>(theEnums_[currentIndex_]);
+        }
+        catch (const ecf::bad_conversion&) {
+            // Ignore and return currentIndex_
+        }
+    }
+    return currentIndex_;
+}
+
+long RepeatEnumerated::last_valid_value() const {
+    if (!theEnums_.empty()) {
+        if (currentIndex_ < 0) {
+            try {
+                return ecf::convert_to<int>(theEnums_[0]);
+            }
+            catch (const ecf::bad_conversion&) { /* Ignore and return first index */
+            }
+            return 0;
+        }
+        if (currentIndex_ >= static_cast<int>(theEnums_.size())) {
+
+            try {
+                return ecf::convert_to<int>(theEnums_[theEnums_.size() - 1]);
+            }
+            catch (const ecf::bad_conversion&) { /* Ignore and return last index */
+            }
+            return static_cast<long>(theEnums_.size() - 1);
+        }
+
+        // return current value as integer or as index
+        return value();
+    }
+    return 0;
+}
+
+void RepeatEnumerated::setToLastValue() {
+    currentIndex_ = static_cast<int>(theEnums_.size() - 1);
+    if (currentIndex_ < 0)
+        currentIndex_ = 0;
+    incr_state_change_no();
+}
+
+std::string RepeatEnumerated::valueAsString() const {
+    // This must always return a valid value
+    if (!theEnums_.empty()) {
+
+        // Returns the last valid value
+        if (currentIndex_ < 0)
+            return theEnums_[0]; // return first
+
+        if (currentIndex_ >= static_cast<int>(theEnums_.size())) {
+            return theEnums_[theEnums_.size() - 1]; // return last
+        }
+
+        return theEnums_[currentIndex_];
+    }
+    return std::string();
+}
+
+std::string RepeatEnumerated::value_as_string(int index) const {
+    if (index >= 0 && index < static_cast<int>(theEnums_.size())) {
+        return theEnums_[index];
+    }
+    return std::string();
+}
+
+std::string RepeatEnumerated::next_value_as_string() const {
+    if (theEnums_.empty())
+        return string();
+
+    int index = currentIndex_;
+    index++;
+    if (index < 0)
+        return theEnums_[0]; // return first
+    if (index >= static_cast<int>(theEnums_.size()))
+        return theEnums_[theEnums_.size() - 1]; // return last
+    return theEnums_[index];
+}
+
+std::string RepeatEnumerated::prev_value_as_string() const {
+    if (theEnums_.empty())
+        return string();
+
+    int index = currentIndex_;
+    index--;
+    if (index < 0)
+        return theEnums_[0]; // return first
+    if (index >= static_cast<int>(theEnums_.size()))
+        return theEnums_[theEnums_.size() - 1]; // return last
+    return theEnums_[index];
+}
+
+void RepeatEnumerated::change(const std::string& newValue) {
+    // See if if matches one of the enums
+    for (size_t i = 0; i < theEnums_.size(); i++) {
+        if (theEnums_[i] == newValue) {
+            currentIndex_ = i;
+            incr_state_change_no();
+            return;
+        }
+    }
+
+    // If the value is convertible to an integer, treat as an index
+    try {
+        auto the_new_value = ecf::convert_to<long>(newValue);
+        changeValue(the_new_value); // can throw if out of range
+        return;
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+
+    std::stringstream ss;
+    ss << "RepeatEnumerated::change:" << toString() << "\nThe new value " << newValue
+       << " is not a valid index or a member of the enumerated list\n";
+    throw std::runtime_error(ss.str());
+}
+
+void RepeatEnumerated::changeValue(long the_new_value) {
+    if (the_new_value < 0 || the_new_value >= static_cast<int>(theEnums_.size())) {
+        std::stringstream ss;
+        ss << "RepeatEnumerated::changeValue:" << toString() << "\nThe new value '" << the_new_value
+           << "' is not a valid index ";
+        ss << "expected range[0-" << theEnums_.size() - 1 << "] but found '" << the_new_value << "'";
+        throw std::runtime_error(ss.str());
+    }
+    set_value(the_new_value);
+}
+
+void RepeatEnumerated::set_value(long the_new_value) {
+    // Note: the node is incremented one past, the last value
+    // In Node we increment() then check for validity
+    // hence the_new_value may be outside of the valid range.
+    // This can be seen when do a incremental sync,
+    // *hence* allow memento to copy the value as is.
+    currentIndex_ = the_new_value;
+    incr_state_change_no();
+}
+
+bool RepeatEnumerated::operator==(const RepeatEnumerated& rhs) const {
+    if (name_ != rhs.name_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatEnumerated::operator==( name_(" << name_ << ") != rhs.name_(" << rhs.name_ << "))\n";
+        }
+#endif
+        return false;
+    }
+    if (theEnums_ != rhs.theEnums_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatEnumerated::operator==( theEnums_ != rhs.theEnums_ )\n";
+        }
+#endif
+        return false;
+    }
+    if (currentIndex_ != rhs.currentIndex_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "RepeatEnumerated::operator==( currentIndex_(" << currentIndex_ << ") != rhs.currentIndex_("
+                      << rhs.currentIndex_ << "))\n";
+        }
+#endif
+        return false;
+    }
+    return true;
+}
+
+//======================================================================================
+
+RepeatString::RepeatString(const std::string& variable, const std::vector<std::string>& theEnums)
+    : RepeatBase(variable),
+      theStrings_(theEnums) {
+    if (!Str::valid_name(variable)) {
+        throw std::runtime_error("RepeatString:: Invalid name: " + variable);
+    }
+    if (theEnums.empty()) {
+        throw std::runtime_error("RepeatString : " + variable + " is empty");
+    }
+}
+
+int RepeatString::end() const {
+    if (theStrings_.empty())
+        return 0;
+    return static_cast<int>(theStrings_.size() - 1);
+}
+
+bool RepeatString::compare(RepeatBase* rb) const {
+    auto* rhs = dynamic_cast<RepeatString*>(rb);
+    if (!rhs)
+        return false;
+    return operator==(*rhs);
+}
+
+void RepeatString::write(std::string& ret) const {
+    ret += "repeat string ";
+    ret += name_;
+    for (const string& s : theStrings_) {
+        ret += " \"";
+        ret += s;
+        ret += "\"";
+    }
+    if (!PrintStyle::defsStyle() && (currentIndex_ != 0)) {
+        ret += " # ";
+        ret += ecf::convert_to<std::string>(value());
+    }
+}
+
+std::string RepeatString::dump() const {
+    std::stringstream ss;
+    ss << toString() << " ordinal-value(" << value() << ")   value-as-string(" << valueAsString() << ")";
+    return ss.str();
+}
+
+void RepeatString::reset() {
+    currentIndex_ = 0;
+    incr_state_change_no();
+}
+
+long RepeatString::last_valid_value() const {
+    if (!theStrings_.empty()) {
+        if (currentIndex_ < 0)
+            return 0;
+        if (currentIndex_ >= static_cast<int>(theStrings_.size()))
+            return static_cast<long>(theStrings_.size() - 1);
+        return currentIndex_;
+    }
+    return 0;
+}
+
+std::string RepeatString::next_value_as_string() const {
+    if (!theStrings_.empty()) {
+        int index = currentIndex_;
+        index++;
+        if (index < 0)
+            return theStrings_[0]; // return first
+        if (index >= static_cast<int>(theStrings_.size()))
+            return theStrings_[theStrings_.size() - 1]; // return last
+        return theStrings_[index];
+    }
+    return string();
+}
+
+std::string RepeatString::prev_value_as_string() const {
+    if (!theStrings_.empty()) {
+        int index = currentIndex_;
+        index--;
+        if (index < 0)
+            return theStrings_[0]; // return first
+        if (index >= static_cast<int>(theStrings_.size()))
+            return theStrings_[theStrings_.size() - 1]; // return last
+        return theStrings_[index];
+    }
+    return string();
+}
+
+void RepeatString::increment() {
+    currentIndex_++;
+    incr_state_change_no();
+}
+
+void RepeatString::setToLastValue() {
+    currentIndex_ = static_cast<int>(theStrings_.size() - 1);
+    if (currentIndex_ < 0)
+        currentIndex_ = 0;
+    incr_state_change_no();
+}
+
+std::string RepeatString::valueAsString() const {
+    if (!theStrings_.empty())
+        return theStrings_[last_valid_value()];
+    return std::string();
+}
+
+std::string RepeatString::value_as_string(int index) const {
+    if (index >= 0 && index < static_cast<int>(theStrings_.size())) {
+        return theStrings_[index];
+    }
+    return std::string();
+}
+
+void RepeatString::change(const std::string& newValue) {
+    // See if if matches one of the strings
+    for (size_t i = 0; i < theStrings_.size(); i++) {
+        if (theStrings_[i] == newValue) {
+            currentIndex_ = i;
+            incr_state_change_no();
+            return;
+        }
+    }
+
+    // If the value is convertible to an integer, treat as an index
+    try {
+        long the_new_value = ecf::convert_to<int>(newValue);
+        changeValue(the_new_value);
+        return;
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+
+    std::stringstream ss;
+    ss << "RepeatString::change: " << toString() << "\nThe new value " << newValue
+       << " is not a valid index or member of the string list";
+    throw std::runtime_error(ss.str());
+}
+
+void RepeatString::changeValue(long the_new_value) {
+    if (the_new_value < 0 || the_new_value >= static_cast<int>(theStrings_.size())) {
+        std::stringstream ss;
+        ss << "RepeatString::change: " << toString() << " The new the integer " << the_new_value
+           << " is not a valid index ";
+        ss << "expected range[0-" << theStrings_.size() - 1 << "]'";
+        throw std::runtime_error(ss.str());
+    }
+    set_value(the_new_value);
+}
+
+void RepeatString::set_value(long the_new_value) {
+    // Note: the node is incremented one past, the last value
+    // In Node we increment() then check for validity
+    // hence the_new_value may be outside of the valid range.
+    // This can be seen when do a incremental sync,
+    // *hence* allow memento to copy the value as is.
+    currentIndex_ = the_new_value;
+    incr_state_change_no();
+}
+
+bool RepeatString::operator==(const RepeatString& rhs) const {
+    if (name_ != rhs.name_) {
+        return false;
+    }
+    if (theStrings_ != rhs.theStrings_) {
+        return false;
+    }
+    if (currentIndex_ != rhs.currentIndex_) {
+        return false;
+    }
+    return true;
+}
+
+//=======================================================================================
+
+bool RepeatDay::compare(RepeatBase* rb) const {
+    auto* rhs = dynamic_cast<RepeatDay*>(rb);
+    if (!rhs)
+        return false;
+    return operator==(*rhs);
+}
+
+void RepeatDay::write(std::string& ret) const {
+    ret += "repeat day ";
+    ret += ecf::convert_to<std::string>(step_);
+}
+
+std::string RepeatDay::dump() const {
+    return toString();
+}
+
+bool RepeatDay::operator==(const RepeatDay& rhs) const {
+    if (step_ != rhs.step_) {
+        return false;
+    }
+    return true;
+}
+// =========================================================================================
+
+template <class Archive>
+void RepeatBase::serialize(Archive& ar) {
+    ar(CEREAL_NVP(name_));
+}
+
+template <class Archive>
+void RepeatDate::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<RepeatBase>(this),
+       CEREAL_NVP(start_),
+       CEREAL_NVP(end_),
+       CEREAL_NVP(delta_),
+       CEREAL_NVP(value_));
+}
+
+template <class Archive>
+void RepeatDateTime::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<RepeatBase>(this),
+       CEREAL_NVP(start_),
+       CEREAL_NVP(end_),
+       CEREAL_NVP(delta_),
+       CEREAL_NVP(value_));
+}
+
+template <class Archive>
+void RepeatInteger::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<RepeatBase>(this),
+       CEREAL_NVP(start_),
+       CEREAL_NVP(end_),
+       CEREAL_NVP(delta_),
+       CEREAL_NVP(value_));
+}
+
+template <class Archive>
+void RepeatEnumerated::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(theEnums_), CEREAL_NVP(currentIndex_));
+}
+
+template <class Archive>
+void RepeatDateList::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(list_), CEREAL_NVP(currentIndex_));
+}
+
+template <class Archive>
+void RepeatString::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(theStrings_), CEREAL_NVP(currentIndex_));
+}
+
+template <class Archive>
+void RepeatDay::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<RepeatBase>(this), CEREAL_NVP(step_));
+}
+
+template <class Archive>
+void Repeat::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(type_));
+}
+
+CEREAL_TEMPLATE_SPECIALIZE(RepeatBase);
+CEREAL_TEMPLATE_SPECIALIZE_V(RepeatDate);
+CEREAL_TEMPLATE_SPECIALIZE_V(RepeatDateList);
+CEREAL_TEMPLATE_SPECIALIZE_V(RepeatInteger);
+CEREAL_TEMPLATE_SPECIALIZE_V(RepeatEnumerated);
+CEREAL_TEMPLATE_SPECIALIZE_V(RepeatString);
+CEREAL_TEMPLATE_SPECIALIZE_V(RepeatDay);
+CEREAL_TEMPLATE_SPECIALIZE_V(Repeat);
+
+CEREAL_REGISTER_TYPE(RepeatDate)
+CEREAL_REGISTER_TYPE(RepeatDateList)
+CEREAL_REGISTER_TYPE(RepeatInteger)
+CEREAL_REGISTER_TYPE(RepeatEnumerated)
+CEREAL_REGISTER_TYPE(RepeatString)
+CEREAL_REGISTER_TYPE(RepeatDay)
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/RepeatAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/RepeatAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/RepeatAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/RepeatAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,723 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_RepeatAttr_HPP
+#define ecflow_attribute_RepeatAttr_HPP
+
+///
+/// \brief Repeat Attribute. Please note that for repeat string, enumeration
+///        the positional index is used for evaluation.
+///
+/// Simulation: Simulation must not affect the real job submission in the server.
+///   o Infinite repeats cause problems with simulation, hence we have
+///     a mechanism to stop this, when reset is called, via server this is disabled
+///
+
+#include <cstdint>
+#include <iomanip>
+#include <iostream>
+#include <memory>
+#include <sstream>
+#include <vector>
+
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/core/Chrono.hpp"
+
+/////////////////////////////////////////////////////////////////////////
+// Node can only have one repeat.
+//
+class RepeatBase {
+public:
+    explicit RepeatBase(const std::string& name) : name_(name) {}
+    RepeatBase() = default;
+    virtual ~RepeatBase();
+
+    /// make non virtual so that it can be in-lined. Called millions of times
+    const std::string& name() const { return name_; }
+    virtual int start() const = 0;
+    virtual int end() const   = 0;
+    virtual int step() const  = 0;
+
+    // Handle generated variables
+    virtual void gen_variables(std::vector<Variable>& vec) const { vec.push_back(var_); }
+    virtual const Variable& find_gen_variable(const std::string& name) const {
+        return name == name_ ? var_ : Variable::EMPTY();
+    }
+    virtual void update_repeat_genvar() const;
+
+    // After Repeat expiration the last call to increment() can cause
+    // value to be beyond the last valid value
+    // Depending on the kind of repeat the returned can be value or the current index
+    // RepeatDate       -> value
+    // RepeatDateTime   -> value
+    // RepeatDateList   -> value
+    // RepeatString     -> index into array of strings
+    // RepeatInteger    -> value
+    // RepeatEnumerated -> index | value return value at index if cast-able to integer, otherwise return index ******
+    // RepeatDay        -> value
+    virtual long value() const = 0;
+
+    // Depending on the kind of repeat the returned can be value or *current* index
+    // RepeatDate       -> value
+    // RepeatDateTime   -> value
+    // RepeatDateList   -> value
+    // RepeatString     -> index  ( will always return a index)
+    // RepeatInteger    -> value
+    // RepeatEnumerated -> index  ( will always return a index)
+    // RepeatDay        -> value
+    virtual long index_or_value() const = 0;
+    virtual void increment()            = 0;
+
+    // returns a value with in the range start/end
+    // Hence at Repeat expiration will return value associated with end()
+    virtual long last_valid_value() const = 0;
+    virtual long last_valid_value_minus(int val) const { return last_valid_value() - val; }
+    virtual long last_valid_value_plus(int val) const { return last_valid_value() + val; }
+
+    virtual RepeatBase* clone() const                    = 0;
+    virtual bool compare(RepeatBase*) const              = 0;
+    virtual bool valid() const                           = 0;
+    virtual void setToLastValue()                        = 0;
+    virtual std::string valueAsString() const            = 0; // uses last_valid_value
+    virtual std::string value_as_string(int index) const = 0; // used in test only
+    virtual std::string next_value_as_string() const     = 0;
+    virtual std::string prev_value_as_string() const     = 0;
+    virtual void reset()                                 = 0;
+    virtual void change(const std::string& newValue)     = 0; // can throw std::runtime_error
+    virtual void changeValue(long newValue)              = 0; // can throw std::runtime_error
+    virtual void set_value(long new_value_or_index)      = 0; // will NOT throw, allows any value
+    std::string toString() const;
+    virtual void write(std::string&) const = 0;
+    virtual std::string dump() const       = 0;
+
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    /// Simulator functions:
+    virtual bool isInfinite() const = 0;
+
+    virtual bool is_repeat_day() const { return false; }
+
+    virtual bool isDate() const { return false; }
+    virtual bool isDateTime() const { return false; }
+    virtual bool isDateList() const { return false; }
+    virtual bool isInteger() const { return false; }
+    virtual bool isEnumerated() const { return false; }
+    virtual bool isString() const { return false; }
+    virtual bool isDay() const { return false; }
+
+protected:
+    void incr_state_change_no();
+
+    mutable Variable var_; // *not* persisted
+    std::string name_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+///
+/// The date has no meaning in a physical sense, only used as a for loop over dates
+class RepeatDate final : public RepeatBase {
+public:
+    RepeatDate(const std::string& variable, int start, int end, int delta = 1 /* always in days*/);
+    RepeatDate() = default;
+
+    void gen_variables(std::vector<Variable>& vec) const override;
+    const Variable& find_gen_variable(const std::string& name) const override;
+    void update_repeat_genvar() const override;
+
+    int start() const override { return start_; }
+    int end() const override { return end_; }
+    int step() const override { return delta_; }
+    long value() const override { return value_; }
+    long index_or_value() const override { return value_; }
+    long last_valid_value() const override;
+    long last_valid_value_minus(int value) const override;
+    long last_valid_value_plus(int value) const override;
+
+    void delta(int d) { delta_ = d; }
+    bool operator==(const RepeatDate& rhs) const;
+    bool operator<(const RepeatDate& rhs) const { return name() < rhs.name(); }
+
+    RepeatDate* clone() const override { return new RepeatDate(name_, start_, end_, delta_, value_); }
+    bool compare(RepeatBase*) const override;
+    bool valid() const override { return (delta_ > 0) ? (value_ <= end_) : (value_ >= end_); }
+    std::string valueAsString() const override;
+    std::string value_as_string(int index) const override;
+    std::string next_value_as_string() const override;
+    std::string prev_value_as_string() const override;
+
+    void setToLastValue() override;
+    void reset() override;
+    void increment() override;
+    void change(const std::string& newValue) override; // can throw std::runtime_error
+    void changeValue(long newValue) override;          // can throw std::runtime_error
+    void set_value(long newValue) override;            // will NOT throw, allows any value
+
+    void write(std::string&) const override;
+
+    std::string dump() const override;
+    bool isDate() const override { return true; }
+
+    /// Simulator functions:
+    bool isInfinite() const override { return false; }
+
+private:
+    long valid_value(long value) const;
+
+    RepeatDate(const std::string& name, int start, int end, int delta, long value)
+        : RepeatBase(name),
+          start_(start),
+          end_(end),
+          delta_(delta),
+          value_(value) {}
+
+    void update_repeat_genvar_value() const;
+
+private:
+    int start_{0};
+    int end_{0};
+    int delta_{0};
+    long value_{0};
+
+    mutable Variable yyyy_;   // *not* persisted
+    mutable Variable mm_;     // *not* persisted
+    mutable Variable dom_;    // *not* persisted
+    mutable Variable dow_;    // *not* persisted
+    mutable Variable julian_; // *not* persisted
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class RepeatDateTime final : public RepeatBase {
+public:
+    RepeatDateTime(const std::string& variable,
+                   const std::string& start,
+                   const std::string& end,
+                   const std::string& delta = "24:00:00");
+    RepeatDateTime(const std::string& variable, ecf::Instant start, ecf::Instant end, ecf::Duration delta);
+    RepeatDateTime() = default;
+
+    void gen_variables(std::vector<Variable>& vec) const override;
+    const Variable& find_gen_variable(const std::string& name) const override;
+    void update_repeat_genvar() const override;
+
+    const ecf::Instant& start_instant() const { return start_; }
+    const ecf::Instant& end_instant() const { return end_; }
+    const ecf::Duration& step_duration() const { return delta_; }
+    const ecf::Instant& value_instant() const { return value_; }
+
+    int start() const override { return coerce_from_instant(start_); }
+    int end() const override { return coerce_from_instant(end_); }
+    int step() const override { return delta_.as_seconds().count(); }
+    long value() const override { return coerce_from_instant(value_); }
+    long index_or_value() const override { return coerce_from_instant(value_); }
+    long last_valid_value() const override;
+    long last_valid_value_minus(int value) const override;
+    long last_valid_value_plus(int value) const override;
+
+    void delta(const ecf::Duration& d) { delta_ = d; }
+    bool operator==(const RepeatDateTime& rhs) const;
+    bool operator<(const RepeatDateTime& rhs) const { return name() < rhs.name(); }
+
+    RepeatDateTime* clone() const override { return new RepeatDateTime(name_, start_, end_, delta_, value_); }
+    bool compare(RepeatBase*) const override;
+    bool valid() const override {
+        return (delta_ > ecf::Duration{std::chrono::seconds{0}}) ? (value_ <= end_) : (value_ >= end_);
+    }
+    std::string valueAsString() const override;
+    std::string value_as_string(int index) const override;
+    std::string next_value_as_string() const override;
+    std::string prev_value_as_string() const override;
+
+    void setToLastValue() override;
+    void reset() override;
+    void increment() override;
+    void change(const std::string& newValue) override; // can throw std::runtime_error
+    void changeValue(long newValue) override;          // can throw std::runtime_error
+    void set_value(long newValue) override;            // will NOT throw, allows any value
+
+    void write(std::string&) const override;
+
+    std::string dump() const override;
+    bool isDateTime() const override { return true; }
+
+    /// Simulator functions:
+    bool isInfinite() const override { return false; }
+
+private:
+    ecf::Instant valid_value(const ecf::Instant& value) const;
+
+    RepeatDateTime(const std::string& name,
+                   ecf::Instant start,
+                   ecf::Instant end,
+                   ecf::Duration delta,
+                   ecf::Instant value)
+        : RepeatBase(name),
+          start_(start),
+          end_(end),
+          delta_(delta),
+          value_(value) {}
+
+    void update_repeat_genvar_value() const;
+
+private:
+    ecf::Instant start_;
+    ecf::Instant end_;
+    ecf::Duration delta_;
+    ecf::Instant value_;
+
+    // *not* persisted
+    mutable VariableMap generated_{
+        // clang-format off
+        // Date
+        Variable(name_ + "_DATE", "<invalid>"),
+        // Date Components
+        Variable(name_ + "_YYYY", "<invalid>"),
+        Variable(name_ + "_MM", "<invalid>"),
+        Variable(name_ + "_DD", "<invalid>"),
+        Variable(name_ + "_JULIAN", "<invalid>"),
+        // Time
+        Variable(name_ + "_TIME", "<invalid>"),
+        // Time Components4
+        Variable(name_ + "_HOURS", "<invalid>"),
+        Variable(name_ + "_MINUTES", "<invalid>"),
+        Variable(name_ + "_SECONDS", "<invalid>")
+        // clang-format on
+    };
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class RepeatDateList final : public RepeatBase {
+public:
+    RepeatDateList(const std::string& variable, const std::vector<int>&); // will throw for empty list
+    RepeatDateList() = default;
+
+    void gen_variables(std::vector<Variable>& vec) const override;
+    const Variable& find_gen_variable(const std::string& name) const override;
+    void update_repeat_genvar() const override;
+
+    bool operator==(const RepeatDateList& rhs) const;
+    bool operator<(const RepeatDateList& rhs) const { return name() < rhs.name(); }
+
+    int start() const override;
+    int end() const override;
+    int step() const override { return 1; }
+    long value() const override; // return value at index   otherwise return 0
+    long index_or_value() const override { return currentIndex_; }
+    long last_valid_value() const override;
+    long last_valid_value_minus(int value) const override;
+    long last_valid_value_plus(int value) const override;
+
+    RepeatBase* clone() const override { return new RepeatDateList(name_, list_, currentIndex_); }
+    bool compare(RepeatBase*) const override;
+    bool valid() const override { return (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(list_.size())); }
+    std::string valueAsString() const override;
+    std::string value_as_string(int index) const override;
+    std::string next_value_as_string() const override;
+    std::string prev_value_as_string() const override;
+
+    void setToLastValue() override;
+    void reset() override;
+    void increment() override;
+    void change(const std::string& newValue) override; // can throw std::runtime_error
+    void changeValue(long newValue) override;          // can throw std::runtime_error
+    void set_value(long newValue) override;            // will NOT throw, allows any value
+    void write(std::string&) const override;
+    std::string dump() const override;
+    bool isDateList() const override { return true; }
+    int indexNum() const { return static_cast<int>(list_.size()); }
+
+    /// Simulator functions:
+    bool isInfinite() const override { return false; }
+
+private:
+    RepeatDateList(const std::string& variable, const std::vector<int>& l, int index)
+        : RepeatBase(variable),
+          currentIndex_(index),
+          list_(l) {}
+
+    void update_repeat_genvar_value() const;
+
+private:
+    int currentIndex_{0};
+    std::vector<int> list_;
+
+    mutable Variable yyyy_;   // *not* persisted
+    mutable Variable mm_;     // *not* persisted
+    mutable Variable dom_;    // *not* persisted
+    mutable Variable dow_;    // *not* persisted
+    mutable Variable julian_; // *not* persisted
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class RepeatInteger final : public RepeatBase {
+public:
+    RepeatInteger(const std::string& variable, int start, int end, int delta = 1);
+    RepeatInteger();
+
+    bool operator==(const RepeatInteger& rhs) const;
+    bool operator<(const RepeatInteger& rhs) const { return name() < rhs.name(); }
+
+    int start() const override { return start_; }
+    int end() const override { return end_; }
+    int step() const override { return delta_; }
+    long value() const override { return value_; }
+    long index_or_value() const override { return value_; }
+    long last_valid_value() const override;
+
+    RepeatInteger* clone() const override { return new RepeatInteger(name_, start_, end_, delta_, value_); }
+    bool compare(RepeatBase*) const override;
+    bool valid() const override { return (delta_ > 0) ? (value_ <= end_) : (value_ >= end_); }
+    std::string valueAsString() const override;
+    std::string value_as_string(int index) const override;
+    std::string next_value_as_string() const override;
+    std::string prev_value_as_string() const override;
+    void setToLastValue() override;
+    void reset() override;
+    void increment() override;
+    void change(const std::string& newValue) override; // can throw std::runtime_error
+    void changeValue(long newValue) override;          // can throw std::runtime_error
+    void set_value(long newValue) override;            // will NOT throw, allows any value
+    void write(std::string&) const override;
+    std::string dump() const override;
+    bool isInteger() const override { return true; }
+
+    /// Simulator functions:
+    bool isInfinite() const override { return false; }
+
+private:
+    long valid_value(long value) const;
+
+    RepeatInteger(const std::string& name, int start, int end, int delta, long value)
+        : RepeatBase(name),
+          start_(start),
+          end_(end),
+          delta_(delta),
+          value_(value) {}
+
+private:
+    int start_{0};
+    int end_{0};
+    int delta_{0};
+    long value_{0};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+// Note:: Difference between RepeatEnumerated and  RepeatString, is that
+// RepeatEnumerated::value() will return the value at the index if cast-able to integer,
+// whereas RepeatString::value() will always return the index.
+class RepeatEnumerated final : public RepeatBase {
+public:
+    RepeatEnumerated(const std::string& variable, const std::vector<std::string>& theEnums);
+    RepeatEnumerated() = default;
+
+    bool operator==(const RepeatEnumerated& rhs) const;
+    bool operator<(const RepeatEnumerated& rhs) const { return name() < rhs.name(); }
+
+    int start() const override { return 0; }
+    int end() const override;
+    int step() const override { return 1; }
+    long value() const override; // return value at index if cast-able to integer, otherwise return index
+    long index_or_value() const override { return currentIndex_; }
+    long last_valid_value() const override;
+
+    RepeatBase* clone() const override { return new RepeatEnumerated(name_, theEnums_, currentIndex_); }
+    bool compare(RepeatBase*) const override;
+    bool valid() const override { return (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theEnums_.size())); }
+    std::string valueAsString() const override;
+    std::string value_as_string(int index) const override;
+    std::string next_value_as_string() const override;
+    std::string prev_value_as_string() const override;
+
+    void setToLastValue() override;
+    void reset() override;
+    void increment() override;
+    void change(const std::string& newValue) override; // can throw std::runtime_error
+    void changeValue(long newValue) override;          // can throw std::runtime_error
+    void set_value(long newValue) override;            // will NOT throw, allows any value
+    void write(std::string&) const override;
+    std::string dump() const override;
+    bool isEnumerated() const override { return true; }
+    int indexNum() const { return static_cast<int>(theEnums_.size()); }
+
+    /// Simulator functions:
+    bool isInfinite() const override { return false; }
+
+private:
+    RepeatEnumerated(const std::string& variable, const std::vector<std::string>& theEnums, int index)
+        : RepeatBase(variable),
+          currentIndex_(index),
+          theEnums_(theEnums) {}
+
+private:
+    int currentIndex_{0};
+    std::vector<std::string> theEnums_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class RepeatString final : public RepeatBase {
+public:
+    RepeatString(const std::string& variable, const std::vector<std::string>& theEnums);
+    RepeatString() = default;
+
+    bool operator==(const RepeatString& rhs) const;
+    bool operator<(const RepeatString& rhs) const { return name() < rhs.name(); }
+
+    int start() const override { return 0; }
+    int end() const override;
+    int step() const override { return 1; }
+    long value() const override { return currentIndex_; }
+    long index_or_value() const override { return currentIndex_; }
+    long last_valid_value() const override; // returns the index
+
+    RepeatBase* clone() const override { return new RepeatString(name_, theStrings_, currentIndex_); }
+    bool compare(RepeatBase*) const override;
+    bool valid() const override { return (currentIndex_ >= 0 && currentIndex_ < static_cast<int>(theStrings_.size())); }
+    std::string valueAsString() const override;
+    std::string value_as_string(int index) const override;
+    std::string next_value_as_string() const override;
+    std::string prev_value_as_string() const override;
+
+    void setToLastValue() override;
+    void reset() override;
+    void increment() override;
+    void change(const std::string& newValue) override; // can throw std::runtime_error
+    void changeValue(long newValue) override;          // can throw std::runtime_error
+    void set_value(long newValue) override;            // will NOT throw, allows any value
+    void write(std::string&) const override;
+    std::string dump() const override;
+    bool isString() const override { return true; }
+    int indexNum() const { return static_cast<int>(theStrings_.size()); }
+
+    /// Simulator functions:
+    bool isInfinite() const override { return false; }
+
+private:
+    RepeatString(const std::string& variable, const std::vector<std::string>& theEnums, int index)
+        : RepeatBase(variable),
+          currentIndex_(index),
+          theStrings_(theEnums) {}
+
+private:
+    int currentIndex_{0};
+    std::vector<std::string> theStrings_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+/// The current repeat day is not that well defined or deterministic.
+///  **** Currently I have not come across any suites that use an end-date ****
+///   o If the suite has defined a real clock
+///     then number of repeats is deterministic
+///     However if the end-date is less than suite clock this should be reported as error
+///   o Currently under the hybrid clock the date is not updated, this raises
+///     a whole lot of issues. (We don't wont a separate calendar, just for this).
+///   o If there is _no_ suite clock, then we must use the current day
+///     now the number of repeats  varies, and if end-date is less than the current
+///     day we need to report an error
+///  Its not clear what behaviour is required here, hence I will not implement
+///  the end-date functionality. Until there is clear requirement is this area.
+///  end-date will be treated as a parser error.
+///  The minimum deterministic functionality here is to implement the infinite
+///  repeat that has no end date
+///
+/// RepeatDay do not really have a name: However we need maintain invariant that all NON-empty repeats
+/// have a name. Hence the name will be as day
+/// Note: this applies to the clone as well
+class RepeatDay final : public RepeatBase {
+public:
+    RepeatDay() : RepeatBase("day") {}
+
+    // Enable implicit conversion from integer
+    RepeatDay(int step) : RepeatBase("day"), step_(step) {}
+
+    bool operator==(const RepeatDay& rhs) const;
+    bool operator<(const RepeatDay& rhs) const { return step_ < rhs.step(); }
+
+    int start() const override { return 0; }
+    int end() const override { return 0; }
+    int step() const override { return step_; }
+    void increment() override { /* do nothing */
+    }
+    long value() const override { return step_; }
+    long index_or_value() const override { return step_; }
+    long last_valid_value() const override { return step_; }
+
+    RepeatBase* clone() const override { return new RepeatDay(step_, valid_); }
+    bool compare(RepeatBase*) const override;
+    bool valid() const override { return valid_; }
+    std::string valueAsString() const override { return std::string(); };
+    std::string value_as_string(int) const override { return std::string(); }
+    std::string next_value_as_string() const override { return std::string(); }
+    std::string prev_value_as_string() const override { return std::string(); }
+
+    void setToLastValue() override { /* do nothing  ?? */
+    }
+    void reset() override { valid_ = true; }
+    void change(const std::string& /*newValue*/) override { /* do nothing */
+    }
+    void changeValue(long /*newValue*/) override { /* do nothing */
+    }
+    void set_value(long /*newValue*/) override { /* do nothing */
+    }
+    void write(std::string&) const override;
+    std::string dump() const override;
+    bool isDay() const override { return true; }
+
+    /// Simulator functions:
+    bool isInfinite() const override { return true; }
+
+    bool is_repeat_day() const override { return true; }
+
+private:
+    RepeatDay(int step, bool valid) : RepeatBase("day"), step_(step), valid_(valid) {}
+
+private:
+    int step_{1};
+    bool valid_{true}; // not persisted since only used in simulator
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class Repeat {
+public:
+    Repeat(); // for serialisation
+
+    // Enable implicit conversion to Repeat
+    Repeat(const RepeatDate&);
+    Repeat(const RepeatDateTime&);
+    Repeat(const RepeatDateList&);
+    Repeat(const RepeatInteger&);
+    Repeat(const RepeatEnumerated&);
+    Repeat(const RepeatString&);
+    Repeat(const RepeatDay&);
+
+    // Enable copy semantics
+    Repeat(const Repeat&);
+    Repeat& operator=(const Repeat& rhs);
+
+    // Enable move semantics
+    Repeat(Repeat&& rhs) : type_(std::move(rhs.type_)) {}
+    Repeat& operator=(Repeat&& rhs);
+
+    ~Repeat();
+
+    bool operator==(const Repeat& rhs) const;
+    bool operator<(const Repeat& rhs) const { return name() < rhs.name(); }
+
+    bool empty() const { return (type_) ? false : true; }
+    void clear() { type_.reset(nullptr); }
+
+    const std::string& name() const;
+
+    void gen_variables(std::vector<Variable>& vec) const {
+        if (type_)
+            type_->gen_variables(vec);
+    }
+    const Variable& find_gen_variable(const std::string& name) const {
+        return (type_) ? type_->find_gen_variable(name) : Variable::EMPTY();
+    }
+    void update_repeat_genvar() const {
+        if (type_)
+            type_->update_repeat_genvar();
+    }
+
+    int start() const { return (type_) ? type_->start() : 0; }
+    int end() const { return (type_) ? type_->end() : 0; }
+    int step() const { return (type_) ? type_->step() : 0; }
+    long value() const { return (type_) ? type_->value() : 0; }
+    long index_or_value() const { return (type_) ? type_->index_or_value() : 0; }
+    long last_valid_value() const { return (type_) ? type_->last_valid_value() : 0; }
+    long last_valid_value_minus(int val) const { return (type_) ? type_->last_valid_value_minus(val) : -val; }
+    long last_valid_value_plus(int val) const { return (type_) ? type_->last_valid_value_plus(val) : val; }
+
+    void print(std::string& os) const;
+    bool valid() const { return (type_) ? type_->valid() : false; }
+    void setToLastValue() {
+        if (type_)
+            type_->setToLastValue();
+    }
+    std::string valueAsString() const { return (type_) ? type_->valueAsString() : std::string(); }
+    std::string value_as_string(int index) const { return (type_) ? type_->value_as_string(index) : std::string(); }
+    std::string next_value_as_string() const { return (type_) ? type_->next_value_as_string() : std::string(); }
+    std::string prev_value_as_string() const { return (type_) ? type_->prev_value_as_string() : std::string(); }
+
+    void reset() {
+        if (type_)
+            type_->reset();
+    }
+    void increment() {
+        if (type_)
+            type_->increment();
+    }
+    void change(const std::string& newValue) {
+        if (type_)
+            type_->change(newValue);
+    }
+    void changeValue(long newValue) {
+        if (type_)
+            type_->changeValue(newValue);
+    }
+    void set_value(long newValue) {
+        if (type_)
+            type_->set_value(newValue);
+    }
+    std::string toString() const { return (type_) ? type_->toString() : std::string(); }
+    std::string dump() const { return (type_) ? type_->dump() : std::string(); } // additional state
+    unsigned int state_change_no() const { return (type_) ? type_->state_change_no() : 0; }
+
+    /// simulator functions:
+    bool isInfinite() const { return (type_) ? type_->isInfinite() : false; }
+
+    // Allows Repeat's to be returned by reference
+    static const Repeat& EMPTY();
+
+    bool is_repeat_day() const { return (type_) ? type_->is_repeat_day() : false; }
+
+    /// Expose base for the GUI only, use with caution
+    RepeatBase* repeatBase() const { return type_.get(); }
+
+private:
+    void write(std::string& ret) const {
+        if (type_)
+            type_->write(ret);
+    }
+
+private:
+    std::unique_ptr<RepeatBase> type_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_attribute_RepeatAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/TimeAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/TimeAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/TimeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/TimeAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,253 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/TimeAttr.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/attribute/DateAttr.hpp" // Used in Why
+#include "ecflow/attribute/DayAttr.hpp"  // Used in Why
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+namespace ecf {
+
+TimeAttr::TimeAttr(const std::string& str) : state_change_no_(0) {
+    if (str.empty())
+        throw std::runtime_error("Time::Time: empty string passed");
+    std::vector<std::string> tokens;
+    Str::split(str, tokens);
+    if (tokens.empty())
+        throw std::runtime_error("Time::Time: incorrect time string ?");
+
+    size_t index = 0;
+    ts_          = TimeSeries::create(index, tokens, false /*parse_state*/);
+}
+
+void TimeAttr::calendarChanged(const ecf::Calendar& c) {
+    // ensure this called first , since we need always update for relative duration. ECFLOW-1648
+    if (ts_.calendarChanged(c)) {
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+    //   log(Log::DBG,"TimeAttr::calendarChanged(1) " + dump()); // ECFLOW-1648
+
+    if (free_) {
+        return;
+    }
+
+    // For a time series, we rely on the re queue to reset makeFree
+    if (isFree(c)) {
+        setFree();
+    }
+    //   log(Log::DBG,"TimeAttr::calendarChanged(2) " + dump()); // ECFLOW-1648
+}
+
+void TimeAttr::resetRelativeDuration() {
+    if (ts_.resetRelativeDuration()) {
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+}
+
+void TimeAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        ts_.write_state(os, free_);
+    }
+    os += "\n";
+}
+
+std::string TimeAttr::name() const {
+    std::string ret;
+    write(ret);
+    ts_.write_state_for_gui(ret, free_);
+    return ret;
+}
+
+std::string TimeAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void TimeAttr::write(std::string& ret) const {
+    ret += "time ";
+    ts_.write(ret);
+}
+
+std::string TimeAttr::dump() const {
+    std::stringstream ss;
+    ss << "time ";
+
+    if (free_)
+        ss << "(free) ";
+    else
+        ss << "(holding) ";
+
+    ss << ts_.dump();
+
+    return ss.str();
+}
+
+bool TimeAttr::operator==(const TimeAttr& rhs) const {
+    if (free_ != rhs.free_) {
+        return false;
+    }
+    return ts_.operator==(rhs.ts_);
+}
+
+bool TimeAttr::structureEquals(const TimeAttr& rhs) const {
+    return ts_.structureEquals(rhs.ts_);
+}
+
+bool TimeAttr::isFree(const ecf::Calendar& calendar) const {
+    // The FreeDepCmd can be used to free the time,
+    if (free_) {
+        return true;
+    }
+    return is_free(calendar);
+}
+
+bool TimeAttr::is_free(const ecf::Calendar& calendar) const {
+    return ts_.isFree(calendar);
+}
+
+void TimeAttr::setFree() {
+    free_            = true;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "TimeAttr::setFree()\n";
+#endif
+}
+
+void TimeAttr::clearFree() {
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "TimeAttr::clearFree()\n";
+#endif
+}
+
+void TimeAttr::miss_next_time_slot() {
+    ts_.miss_next_time_slot();
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+bool TimeAttr::why(const ecf::Calendar& c,
+                   const std::vector<DayAttr>& days,
+                   const std::vector<DateAttr>& dates,
+                   std::string& theReasonWhy) const {
+    if (isFree(c))
+        return false;
+    theReasonWhy += "is time ";
+    if (!days.empty())
+        theReasonWhy += "and day ";
+    if (!dates.empty())
+        theReasonWhy += "and date ";
+    theReasonWhy += "dependent";
+
+    // Check to see if time has expired, if has not, then report why
+    if (ts_.is_valid()) {
+        // This can apply to single and series
+        boost::posix_time::time_duration calendar_time = ts_.duration(c);
+        if (calendar_time < ts_.start().duration()) {
+            ts_.why(c, theReasonWhy);
+            return true;
+        }
+
+        // calendar_time >= ts_.start().duration()
+        if (ts_.hasIncrement()) {
+            if (calendar_time < ts_.finish().duration()) {
+                ts_.why(c, theReasonWhy);
+                return true;
+            }
+        }
+        // calendar_time >= ts_.start().duration() && calendar_time >= ts_.finish().duration()
+        // past the end of time slot, hence this should not hold job generation,
+    }
+
+    // the time has expired
+    theReasonWhy += " ( '";
+    theReasonWhy += toString();
+    theReasonWhy += "' has expired,";
+
+    // take into account, user can use run/force complete to miss time slots
+    bool do_a_requeue = ts_.requeueable(c);
+    if (do_a_requeue) {
+        TimeSlot the_next_time_slot = ts_.compute_next_time_slot(c);
+        if (the_next_time_slot.isNULL() || !ts_.hasIncrement()) {
+            theReasonWhy += " *re-queue* to run at this time";
+        }
+        else {
+            theReasonWhy += " *re-queue* to run at ";
+            theReasonWhy += the_next_time_slot.toString();
+        }
+    }
+    else {
+        if (ts_.relative()) {
+            theReasonWhy += " please *re-queue*, to reset the relative duration";
+        }
+        else {
+            boost::gregorian::date the_min_next_date;
+
+            if (!days.empty() || !dates.empty()) {
+                for (const auto& day : days) {
+                    boost::gregorian::date the_next_matching_date = day.next_matching_date(c);
+                    if (the_min_next_date.is_special())
+                        the_min_next_date = the_next_matching_date;
+                    if (the_next_matching_date < the_min_next_date)
+                        the_min_next_date = the_next_matching_date;
+                }
+                for (const auto& date : dates) {
+                    boost::gregorian::date the_next_matching_date = date.next_matching_date(c);
+                    if (the_min_next_date.is_special())
+                        the_min_next_date = the_next_matching_date;
+                    if (the_next_matching_date < the_min_next_date)
+                        the_min_next_date = the_next_matching_date;
+                }
+
+                theReasonWhy += " next run at ";
+            }
+            else {
+                boost::gregorian::date_duration one_day(1);
+                the_min_next_date = c.date(); // todays date
+                the_min_next_date += one_day; // add one day, so its in the future
+                theReasonWhy += " next run tomorrow at ";
+            }
+
+            theReasonWhy += ts_.start().toString();
+            theReasonWhy += " ";
+            theReasonWhy += to_simple_string(the_min_next_date);
+        }
+    }
+    theReasonWhy += " )";
+
+    return true;
+}
+
+template <class Archive>
+void TimeAttr::serialize(Archive& ar) {
+    ar(CEREAL_NVP(ts_));
+
+    // Only persisted for testing, see usage of isSetFree()
+    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE(TimeAttr);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/TimeAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/TimeAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/TimeAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/TimeAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,142 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_TimeAttr_HPP
+#define ecflow_attribute_TimeAttr_HPP
+
+///
+/// \brief isFree is called when a node is queued. If it returns true, Task can be submitted
+/// checkForReque: is called when a node has completed, and need to determine if it should run again.
+/// These are different/orthogonal concerns.
+/// There is a *separate* issue of whether nodes should be queued when a node is *manually*
+///    a/ Set complete
+///    b/ Runs and then completes
+///
+/// For a *single* time slot we can't requeue.
+/// Hence we checkForReque that takes as parameters max/min time slots, so we **treat**
+/// Multiple single slot as a series.
+///
+///                                               isFree:hhhhhhhhhhhhhhhhh
+///                                               Begin:
+///                                               V
+/// checkForReque:rrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh   10:00
+/// checkForReque:rrrrrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhh   11:00
+/// checkForReque:rrrrrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhh   for both 10:00 and 11:000 together
+///       isFree:hhhhhhhhhhhhhhhhffffffffffffffffffffffffffffffffffff   *once* free we stay free (single slot *only*)
+///       begin :                |                           |
+///        V                     |                           |
+/// Time   ======================0============0==============0=============
+///                            10:00        11:00              Midnight
+///
+///                                                     isFree:hhhhhhhhhhhhhhhhhh
+///                                                      V
+///   CheckForReque:rrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
+///          isFree:hhhhhhhFhhhhFhhhhFhhhhFhhhhFhhhhFhhhhhhhhhhhhhhhhhhhhhhhhhhhh
+///            V           |    |    |    |    |    |        |
+/// Time   ================o====|====|====|====|====0========0====================
+///                      10:00  1    2    3    4  15:00    Midnight
+///
+/// If the job starts at 10:00 but takes more than 1 hour, then it will miss the 11:00 slot
+/// and will have to start at 12:00
+///
+
+#include "ecflow/core/TimeSeries.hpp"
+
+class DateAttr; // Used in Why
+class DayAttr;  // Used in Why
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+namespace ecf {
+
+// Use compiler ,  destructor, assignment, copy constructor,
+class TimeAttr {
+public:
+    explicit TimeAttr(const std::string&);
+    TimeAttr() = default;
+    TimeAttr(int hour, int minute, bool relative = false) : ts_(hour, minute, relative) {}
+    explicit TimeAttr(const TimeSlot& t, bool relative = false) : ts_(t, relative) {}
+    explicit TimeAttr(const TimeSeries& ts) : ts_(ts) {}
+    TimeAttr(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative = false)
+        : ts_(start, finish, incr, relative) {}
+
+    void print(std::string&) const;
+    bool operator==(const TimeAttr& rhs) const;
+    bool operator<(const TimeAttr& rhs) const { return ts_ < rhs.ts_; }
+    bool structureEquals(const TimeAttr& rhs) const;
+
+    /// This can set attribute as free, once free its stays free, until re-queue/reset
+    void calendarChanged(const ecf::Calendar& c); // can set attribute free
+    void resetRelativeDuration();
+
+    void reset_only() {
+        clearFree();
+        ts_.reset_only();
+    }
+    void reset(const ecf::Calendar& c) {
+        clearFree();
+        ts_.reset(c);
+    } // updates state_change_no_
+    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true) {
+        clearFree();
+        ts_.requeue(c, reset_next_time_slot);
+    } // updates state_change_no_
+
+    void miss_next_time_slot(); // updates state_change_no_
+    void setFree();             // ensures that isFree() always returns true, updates state_change_no_
+    bool isSetFree() const { return free_; }
+    bool isFree(const ecf::Calendar&) const;
+    bool checkForRequeue(const ecf::Calendar& c,
+                         const TimeSlot& the_min,
+                         const TimeSlot& the_max,
+                         bool cmd_context = false) const {
+        return ts_.checkForRequeue(c, the_min, the_max, cmd_context);
+    }
+    void min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const { ts_.min_max_time_slots(the_min, the_max); }
+    bool why(const ecf::Calendar&,
+             const std::vector<DayAttr>&,
+             const std::vector<DateAttr>&,
+             std::string& theReasonWhy) const;
+
+    bool checkInvariants(std::string& errormsg) const { return ts_.checkInvariants(errormsg); }
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    // Note: changes in state of ts_, i.e affect the equality operator (used in test)
+    //       must be captured. i.e things like relative duration & next_time_slot are
+    //       reported by the Why command, & hence need to be synced.
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    std::string name() const; // for display/gui
+    std::string toString() const;
+    void write(std::string&) const;
+    std::string dump() const;
+
+    // access
+    const TimeSeries& time_series() const { return ts_; }
+
+private:
+    void clearFree();                         // resets the free flag, updates state_change_no_
+    bool is_free(const ecf::Calendar&) const; // ignores free_
+
+private:
+    TimeSeries ts_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool free_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_attribute_TimeAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/TodayAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/TodayAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/TodayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/TodayAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,252 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/TodayAttr.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/attribute/DateAttr.hpp" // Used in Why
+#include "ecflow/attribute/DayAttr.hpp"  // Used in Why
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+TodayAttr::TodayAttr(const std::string& str) {
+    if (str.empty())
+        throw std::runtime_error("Today::Today: empty string passed");
+    std::vector<std::string> tokens;
+    Str::split(str, tokens);
+    if (tokens.empty())
+        throw std::runtime_error("Today::Today: incorrect time string ?");
+
+    size_t index = 0;
+    ts_          = TimeSeries::create(index, tokens, false /*parse_state*/);
+}
+
+void TodayAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        ts_.write_state(os, free_);
+    }
+    os += "\n";
+}
+
+std::string TodayAttr::name() const {
+    std::string ret;
+    write(ret);
+    ts_.write_state_for_gui(ret, free_);
+    return ret;
+}
+
+std::string TodayAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void TodayAttr::write(std::string& ret) const {
+    ret += "today ";
+    ts_.write(ret);
+}
+
+std::string TodayAttr::dump() const {
+    std::stringstream ss;
+    ss << "today ";
+
+    if (PrintStyle::getStyle() == PrintStyle::STATE) {
+        if (free_)
+            ss << "(free) ";
+        else
+            ss << "(holding) ";
+    }
+
+    ss << ts_.dump();
+
+    return ss.str();
+}
+
+bool TodayAttr::operator==(const TodayAttr& rhs) const {
+    if (free_ != rhs.free_) {
+        return false;
+    }
+    return ts_.operator==(rhs.ts_);
+}
+
+bool TodayAttr::structureEquals(const TodayAttr& rhs) const {
+    return ts_.structureEquals(rhs.ts_);
+}
+
+void TodayAttr::miss_next_time_slot() {
+    ts_.miss_next_time_slot();
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void TodayAttr::setFree() {
+    free_            = true;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void TodayAttr::clearFree() {
+    free_            = false;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void TodayAttr::calendarChanged(const ecf::Calendar& c) {
+    // ensure this called first , since we need always update for relative duration ECFLOW-1648
+    if (ts_.calendarChanged(c)) {
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+
+    if (free_) {
+        return;
+    }
+
+    // For a time series, we rely on the re queue to reset makeFree
+    if (isFree(c)) {
+        setFree();
+    }
+}
+
+void TodayAttr::resetRelativeDuration() {
+    if (ts_.resetRelativeDuration()) {
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+}
+
+bool TodayAttr::isFree(const ecf::Calendar& calendar) const {
+    // The FreeDepCmd can be used to free the today,
+    if (free_) {
+        return true;
+    }
+    return is_free(calendar);
+}
+
+bool TodayAttr::is_free(const ecf::Calendar& calendar) const {
+    if (!ts_.hasIncrement()) {
+        if (ts_.duration(calendar) > ts_.start().duration()) {
+            return true;
+        }
+    }
+
+    // For time series(/range), this  is already handle by ts_
+    // If timer expired return false. otherwise must match one time slot in the range/series
+    return ts_.isFree(calendar);
+}
+
+bool TodayAttr::why(const ecf::Calendar& c,
+                    const std::vector<DayAttr>& days,
+                    const std::vector<DateAttr>& dates,
+                    std::string& theReasonWhy) const {
+    if (isFree(c))
+        return false;
+    theReasonWhy += "is today ";
+    if (!days.empty())
+        theReasonWhy += "and day ";
+    if (!dates.empty())
+        theReasonWhy += "and date ";
+    theReasonWhy += "dependent";
+
+    // Check to see if time has expired, if has not, then report why
+    if (ts_.is_valid()) {
+        // This can apply to single and series
+        boost::posix_time::time_duration calendar_time = ts_.duration(c);
+        if (calendar_time < ts_.start().duration()) {
+            ts_.why(c, theReasonWhy);
+            return true;
+        }
+
+        // calendar_time >= ts_.start().duration()
+        if (ts_.hasIncrement()) {
+            if (calendar_time < ts_.finish().duration()) {
+                ts_.why(c, theReasonWhy);
+                return true;
+            }
+        }
+        // calendar_time >= ts_.start().duration() && calendar_time >= ts_.finish().duration()
+        // past the end of time slot, hence this should not hold job generation,
+    }
+
+    // the today has expired,
+    theReasonWhy += " ( '";
+    theReasonWhy += toString();
+    theReasonWhy += "' has expired,";
+
+    // take into account, user can use run/force complete to miss time slots
+    bool do_a_requeue = ts_.requeueable(c);
+    if (do_a_requeue) {
+        TimeSlot the_next_time_slot = ts_.compute_next_time_slot(c);
+        if (the_next_time_slot.isNULL() || !ts_.hasIncrement()) {
+            theReasonWhy += " *re-queue* to run at this time";
+        }
+        else {
+            theReasonWhy += " *re-queue* to run at";
+            theReasonWhy += the_next_time_slot.toString();
+        }
+    }
+    else {
+        if (ts_.relative()) {
+            theReasonWhy += " please *re-queue*, to reset the relative duration";
+        }
+        else {
+            boost::gregorian::date the_min_next_date;
+
+            if (!days.empty() || !dates.empty()) {
+                for (auto day : days) {
+                    boost::gregorian::date the_next_matching_date = day.next_matching_date(c);
+                    if (the_min_next_date.is_special())
+                        the_min_next_date = the_next_matching_date;
+                    if (the_next_matching_date < the_min_next_date)
+                        the_min_next_date = the_next_matching_date;
+                }
+                for (const auto& i : dates) {
+                    boost::gregorian::date the_next_matching_date = i.next_matching_date(c);
+                    if (the_min_next_date.is_special())
+                        the_min_next_date = the_next_matching_date;
+                    if (the_next_matching_date < the_min_next_date)
+                        the_min_next_date = the_next_matching_date;
+                }
+
+                theReasonWhy += " next run at ";
+            }
+            else {
+                boost::gregorian::date_duration one_day(1);
+                the_min_next_date = c.date(); // todays date
+                the_min_next_date += one_day; // add one day, so its in the future
+                theReasonWhy += " next run tomorrow at ";
+            }
+
+            theReasonWhy += ts_.start().toString();
+            theReasonWhy += " ";
+            theReasonWhy += to_simple_string(the_min_next_date);
+        }
+    }
+    theReasonWhy += " )";
+
+    return true;
+}
+
+template <class Archive>
+void TodayAttr::serialize(Archive& ar) {
+    ar(CEREAL_NVP(ts_));
+    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE(TodayAttr);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/TodayAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/TodayAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/TodayAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/TodayAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,192 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_TodayAttr_HPP
+#define ecflow_attribute_TodayAttr_HPP
+
+///
+/// \brief The Today attribute is heavily tied to the begin command
+///
+/// Real Clock:
+///   1/ Suite Begin time > Today time
+///      If the suite 'begin' time is past the time given for today
+///      the node is free to run.
+///   2/ Suite Begin time < Today Time
+///      The node will 'hold' until current time > today time
+///   3/ Suite time, has passed midnight(next day)
+///      then today command will permanently hold the node
+///   4/ Under Real/hybrid clocks today will hold node after
+///      current is past last today time.
+///
+/// Take the following example when we have a single time slot:
+///     today 10:00
+///                                                isFree:-----free-----
+///                                                 begin:
+///                                                 V
+/// checkForReque:rrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
+///         isFree:hhhhhhhhhhhhhhhh|fffffffffffffffffffffffffffffffffffffff  *once* free we stay free (single slot
+///         *only*) begin:
+///          V
+///   Today  ======================0=====================0=================
+///                               10:00              Midnight
+///
+///   Difference between time and today. If begin is started after the time slot
+///   then the node is free to re-run
+///
+/// When we have a today time series:
+///     today 10:00 20:00 01:00
+///
+///  *** If the begin time is past 10:00  in the case above then the
+///  *** node should is free to run once. However for a range its different
+///  *** if suite begin time is past 20:00 then the node is held.
+///
+///  At 10am the Node is free, when node completes, it is re-queued
+///  At 11am the Node is free, when node completes, it is re-queued
+///  ....
+///  At 20pm the Node is free, when node completes, it is *NOT* re-queued.
+///
+/// isFree is called when a node is queued. if it returns true, Task can be submitted
+/// checkForReque: is called when a node has completed, and need to determine if it should run again.
+/// These are different/orthogonal concerns.
+/// There is a *separate* issue of whether nodes should be queued when a node is *manually*
+///    a/ Set complete
+///    b/ Runs and then completes
+///
+/// For a *single* time slot we can't requeue.
+/// ****However we could have a set of time slots *****
+///
+///                                               isFree:ffffffffffffffff
+///                                               Begin:
+///                                               V
+/// checkForReque:hhhhhhhhhhhhhhhhhrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
+///       isFree:hhhhhhhhhhhhhhhh|fffffffffffffffffffffffffffffffffffffff
+///       begin :
+///        V
+/// Today  ======================0========0===========0====================
+///                            10:00    11:00      Midnight
+///                                                     isFree:hhhhhhhhhhhhhhhhhh
+///                                                      V
+///   CheckForReque:hhhhhhhrrrrrrrrrrrrrrrrrrrrrrrrrhhhhhhhhhhhhhhhhhhhhhhhhhhhhh
+///          isFree:hhhhhhhFhhhhFhhhhFhhhhFhhhhFhhhhFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
+///            V           |    |    |    |    |    |        |
+/// Today  ================o====|====|====|====|====0========0====================
+///                      10:00  1    2    3    4  15:00    Midnight
+///
+/// If the job starts at 10:00 but takes more than 1 hour, then it will miss the 11:00 slot
+/// and will have to start at 12:00
+///
+
+#include "ecflow/core/TimeSeries.hpp"
+
+class DateAttr; // Used in Why
+class DayAttr;  // Used in Why
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+namespace ecf {
+
+// Use compiler ,  destructor, assignment, copy constructor
+class TodayAttr {
+public:
+    explicit TodayAttr(const std::string&);
+    TodayAttr() = default;
+    TodayAttr(int hour, int minute, bool relative = false) : ts_(hour, minute, relative) {}
+    explicit TodayAttr(const TimeSlot& t, bool relative = false) : ts_(t, relative) {}
+    explicit TodayAttr(const TimeSeries& ts) : ts_(ts) {}
+    TodayAttr(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative = false)
+        : ts_(start, finish, incr, relative) {}
+
+    void print(std::string&) const;
+    bool operator==(const TodayAttr& rhs) const;
+    bool operator<(const TodayAttr& rhs) const { return ts_ < rhs.ts_; }
+    bool structureEquals(const TodayAttr& rhs) const;
+
+    /// This can set attribute as free, once free its stays free, until re-queue/reset
+    void calendarChanged(const ecf::Calendar& c);
+    void resetRelativeDuration();
+
+    void reset_only() {
+        clearFree();
+        ts_.reset_only();
+    }
+    void reset(const ecf::Calendar& c) {
+        clearFree();
+        ts_.reset(c);
+    } // updates state_change_no_
+    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true) {
+        clearFree();
+        ts_.requeue(c, reset_next_time_slot);
+    } // updates state_change_no_
+
+    void miss_next_time_slot(); // updates state_change_no_
+    void setFree();             // ensures that isFree() always returns true, updates state_change_no_
+    bool isSetFree() const { return free_; }
+
+    // This is used when we have a *single* today attribute
+    //  single-slot   is free, if calendar time >= today_time
+    //  (range)       is free, if calendar time == (one of the time ranges)
+    bool isFree(const ecf::Calendar&) const;
+
+    // This is used when we have a *multiple* today attribute
+    // (single | range) is free, if calendar time == (one of the time ranges)
+    // if timer *expired* returns false
+    //     task t1
+    //        today 09:00
+    //        today 10:00
+    // If current times is 11:00, then we will return false.
+    // since both 09:00 and 10:00 have expired
+    // Multiple single today, should behave like a today with a range.
+    bool isFreeMultipleContext(const ecf::Calendar& c) const { return ts_.isFree(c); }
+
+    bool checkForRequeue(const ecf::Calendar& c,
+                         const TimeSlot& the_min,
+                         const TimeSlot& the_max,
+                         bool cmd_context = false) const {
+        return ts_.checkForRequeue(c, the_min, the_max, cmd_context);
+    }
+    void min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const { ts_.min_max_time_slots(the_min, the_max); }
+    bool why(const ecf::Calendar&,
+             const std::vector<DayAttr>&,
+             const std::vector<DateAttr>&,
+             std::string& theReasonWhy) const;
+    bool checkInvariants(std::string& errormsg) const { return ts_.checkInvariants(errormsg); }
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    // Note: changes in state of ts_, i.e affect the equality operator (used in test)
+    //       must be captured. i.e things like relative duration & next_time_slot are
+    //       reported by the Why command, & hence need to be synced.
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    std::string name() const; // for display/GUI
+    std::string toString() const;
+    void write(std::string&) const;
+    std::string dump() const;
+
+    // access
+    const TimeSeries& time_series() const { return ts_; }
+
+private:
+    void clearFree();                         // resets the free flag, updates state_change_no_
+    bool is_free(const ecf::Calendar&) const; // ignores free_
+
+private:
+    TimeSeries ts_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool free_{false};                // persisted for use by why() on client side && for state changes
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_attribute_TodayAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/Variable.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/Variable.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/Variable.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/Variable.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,138 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/Variable.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// init static's
+const Variable& Variable::EMPTY() {
+    static const Variable VARIABLE = Variable();
+    return VARIABLE;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////
+
+Variable::Variable(const std::string& name, const std::string& value) : n_(name), v_(value) {
+    std::string msg;
+    if (!Str::valid_name(name, msg)) {
+        throw std::runtime_error("Variable::Variable: Invalid Variable name: " + msg);
+    }
+}
+
+void Variable::set_name(const std::string& v) {
+    std::string msg;
+    if (!Str::valid_name(v, msg)) {
+        throw std::runtime_error("Variable::set_name: Invalid Variable name: " + msg);
+    }
+    n_ = v;
+}
+
+int Variable::value() const {
+    // see if the value is convertible to a integer
+    return Str::to_int(v_, 0 /* value to return if conversion fails*/);
+}
+
+bool Variable::operator==(const Variable& rhs) const {
+    if (v_ != rhs.v_)
+        return false;
+    if (n_ != rhs.n_)
+        return false;
+    return true;
+}
+
+void Variable::print(std::string& os) const {
+    // see notes in VariableParser.h
+    //               Hence we do the following:
+    //                  a/ On parsing always remove quotes ie single or double
+    //                  b/ On serialising always add single quotes
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += "\n";
+}
+
+void Variable::print_server_variable(std::string& os) const {
+    // see notes in VariableParser.h
+    //               Hence we do the following:
+    //                  a/ On parsing always remove quotes ie single or double
+    //                  b/ On serialising always add single quotes
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += " # server\n";
+}
+
+void Variable::print_generated(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    os += "# ";
+    write(os);
+    os += "\n";
+}
+
+std::string Variable::toString() const {
+    std::string ret;
+    ret.reserve(n_.size() + v_.size() + 8);
+    write(ret);
+    return ret;
+}
+
+void Variable::write(std::string& ret) const {
+    ret += "edit ";
+    ret += n_;
+    ret += " '";
+    if (v_.find("\n") == std::string::npos)
+        ret += v_;
+    else {
+        // replace \n, otherwise re-parse will fail
+        std::string value = v_;
+        Str::replaceall(value, "\n", "\\n");
+        ret += value;
+    }
+    ret += "'";
+}
+
+std::string Variable::dump() const {
+    std::stringstream ss;
+    ss << toString() << " value(" << value() << ")";
+    return ss.str();
+}
+
+template <class Archive>
+void Variable::serialize(Archive& ar) {
+    ar(CEREAL_NVP(n_), CEREAL_NVP(v_));
+}
+CEREAL_TEMPLATE_SPECIALIZE(Variable);
+
+/*
+ * VariableMap
+ * *********** */
+
+void VariableMap::set_value(const std::string& value) {
+    for (auto& variable : variables_) {
+        variable.set_value(value);
+    }
+}
+
+Variable& VariableMap::operator[](const std::string& name) {
+    if (auto found = index_.find(name); found != std::end(index_)) {
+        return variables_[found->second];
+    }
+    throw std::runtime_error("Variable not found in Map");
+}
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/Variable.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/Variable.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/Variable.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/Variable.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_Variable_HPP
+#define ecflow_attribute_Variable_HPP
+
+#include <string>
+#include <vector>
+
+#include <unordered_map>
+
+namespace cereal {
+class access;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////
+// Class Variable:
+// Use compiler , generated destructor, assignment,  copy constructor
+class Variable {
+public:
+    // This constructor added as an optimisation to avoid, checking variable names.
+    // i.e the generated variables, and created by the default constructors of Suite/Family/Task etc
+    // These are called during serialisation, hence to avoid checking generated names, we know are valid
+    // use this constructor. The bool is used as a dummy argument, so that we call the right constructor
+    Variable(const std::string& name, const std::string& value, bool /*check_names_dummy*/) : n_(name), v_(value) {}
+    Variable(const std::string& name, const std::string& value);
+    Variable() = default;
+
+    const std::string& name() const { return n_; }
+    void print(std::string&) const;
+    void print_server_variable(std::string&) const;
+    void print_generated(std::string&) const;
+    bool empty() const { return n_.empty(); }
+
+    void set_value(const std::string& v) { v_ = v; }
+    const std::string& theValue() const { return v_; }
+    int value() const;
+
+    void set_name(const std::string& v);
+    std::string& value_by_ref() { return v_; }
+
+    bool operator==(const Variable& rhs) const;
+    bool operator<(const Variable& rhs) const { return n_ < rhs.name(); }
+    std::string toString() const;
+    std::string dump() const;
+
+    // Added to support return by reference
+    static const Variable& EMPTY();
+
+private:
+    void write(std::string&) const;
+
+private:
+    std::string n_;
+    std::string v_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+class VariableMap {
+public:
+    using storage_t = std::vector<Variable>;
+    using index_t   = std::unordered_map<std::string, size_t>;
+
+    template <typename... VARIABLES>
+    explicit VariableMap(const VARIABLES... variables) : variables_{variables...} {
+        // Fill index
+        for (size_t i = 0; i < variables_.size(); ++i) {
+            index_.insert(std::make_pair(variables_[i].name(), i));
+        }
+    }
+
+    [[nodiscard]] storage_t::iterator begin() { return variables_.begin(); }
+    [[nodiscard]] storage_t::const_iterator begin() const { return variables_.begin(); }
+    [[nodiscard]] storage_t::iterator end() { return variables_.end(); }
+    [[nodiscard]] storage_t::const_iterator end() const { return variables_.end(); }
+
+    [[nodiscard]] bool empty() const { return variables_.empty(); }
+    [[nodiscard]] size_t size() const { return variables_.size(); }
+
+    void set_value(const std::string& value);
+
+    [[nodiscard]] Variable& operator[](const std::string& name);
+
+private:
+    storage_t variables_;
+    index_t index_;
+};
+
+#endif /* ecflow_attribute_Variable_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/VerifyAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/VerifyAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/VerifyAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/VerifyAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,79 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/VerifyAttr.hpp"
+
+#include <sstream>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace ecf;
+
+bool VerifyAttr::operator==(const VerifyAttr& rhs) const {
+    if (state_ != rhs.state_)
+        return false;
+    if (expected_ != rhs.expected_)
+        return false;
+    return true;
+}
+
+void VerifyAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    os += toString();
+    if (!PrintStyle::defsStyle()) {
+        os += " # ";
+        os += ecf::convert_to<std::string>(actual_);
+    }
+    os += "\n";
+}
+
+void VerifyAttr::incrementActual() {
+    actual_++;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "VerifyAttr::incrementActual()\n";
+#endif
+}
+
+void VerifyAttr::reset() {
+    actual_          = 0;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "VerifyAttr::reset()\n";
+#endif
+}
+
+std::string VerifyAttr::toString() const {
+    std::stringstream ss;
+    ss << "verify " << NState::toString(state_) << Str::COLON() << expected_;
+    return ss.str();
+}
+
+std::string VerifyAttr::dump() const {
+    std::stringstream ss;
+    ss << "verify " << NState::toString(state_) << Str::COLON() << expected_;
+    ss << " actual(" << actual_ << ")";
+    return ss.str();
+}
+
+template <class Archive>
+void VerifyAttr::serialize(Archive& ar) {
+    ar(CEREAL_NVP(state_), CEREAL_NVP(expected_), CEREAL_NVP(actual_));
+}
+CEREAL_TEMPLATE_SPECIALIZE(VerifyAttr);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/VerifyAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/VerifyAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/VerifyAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/VerifyAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_VerifyAttr_HPP
+#define ecflow_attribute_VerifyAttr_HPP
+
+#include "ecflow/core/NState.hpp"
+
+// Class VerifyAttr:
+// This class is only used for testing/verification purposes. It allows us to
+// embed expected number of states, within the definition file and so
+// reduce the need for golden log files.
+// Use compiler , generated destructor, assignment, copy constructor
+class VerifyAttr {
+public:
+    VerifyAttr(NState::State state, int expected, int actual = 0)
+        : state_(state),
+          expected_(expected),
+          actual_(actual),
+          state_change_no_(0) {}
+    VerifyAttr() = default;
+
+    bool operator==(const VerifyAttr& rhs) const;
+    void print(std::string&) const;
+
+    NState::State state() const { return state_; }
+    int expected() const { return expected_; }
+    int actual() const { return actual_; }
+    void incrementActual();
+    void reset();
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    std::string toString() const;
+    std::string dump() const;
+
+private:
+    NState::State state_{NState::UNKNOWN};
+    int expected_{0};
+    int actual_{0};
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_attribute_VerifyAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/Zombie.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/Zombie.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/Zombie.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/Zombie.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,383 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/Zombie.hpp"
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// support return by reference
+const Zombie& Zombie::EMPTY() {
+    static const Zombie ZOMBIE = Zombie();
+    return ZOMBIE;
+}
+Zombie& Zombie::EMPTY_() {
+    static Zombie ZOMBIE = Zombie();
+    return ZOMBIE;
+}
+
+Zombie::Zombie(ecf::Child::ZombieType zombie_type,
+               ecf::Child::CmdType cmd,
+               const ZombieAttr& attr,
+               const std::string& pathToTask,
+               const std::string& jobsPassword,
+               const std::string& process_or_remote_id,
+               int try_no,
+               const std::string& host,
+               const std::string& user_cmd)
+    : try_no_(try_no),
+      zombie_type_(zombie_type),
+      last_child_cmd_(cmd),
+      path_to_task_(pathToTask),
+      jobs_password_(jobsPassword),
+      process_or_remote_id_(process_or_remote_id),
+      user_cmd_(user_cmd),
+      host_(host),
+      attr_(attr),
+      creation_time_(Calendar::second_clock_time()) {
+}
+
+Zombie::Zombie() = default;
+
+bool Zombie::operator==(const Zombie& rhs) const { // for python interface only
+    if (zombie_type_ != rhs.zombie_type_)
+        return false;
+    if (user_action_ != rhs.user_action_)
+        return false;
+    if (try_no_ != rhs.try_no_)
+        return false;
+    if (duration_ != rhs.duration_)
+        return false;
+    if (calls_ != rhs.calls_)
+        return false;
+    if (last_child_cmd_ != rhs.last_child_cmd_)
+        return false;
+    if (path_to_task_ != rhs.path_to_task_)
+        return false;
+    if (jobs_password_ != rhs.jobs_password_)
+        return false;
+    if (process_or_remote_id_ != rhs.process_or_remote_id_)
+        return false;
+    if (user_cmd_ != rhs.user_cmd_)
+        return false;
+    if (host_ != rhs.host_)
+        return false;
+    if (user_action_set_ != rhs.user_action_set_)
+        return false;
+    if (!(attr_ == rhs.attr_))
+        return false;
+    return true;
+}
+
+std::string Zombie::to_string() const { // for python interface only
+    std::vector<Zombie> vec;
+    vec.push_back(*this);
+    return Zombie::pretty_print(vec, 1);
+}
+
+std::string Zombie::type_str() const {
+    return Child::to_string(zombie_type_);
+}
+
+ecf::User::Action Zombie::user_action() const {
+    // User action needs to take into account, last child command and setting on attr_
+    if (fob())
+        return User::FOB;
+    else if (block())
+        return User::BLOCK;
+    else if (fail())
+        return User::FAIL;
+    else if (remove())
+        return User::REMOVE;
+    else if (kill())
+        return User::KILL;
+    else if (adopt())
+        return User::ADOPT;
+
+    return User::BLOCK; // the default action
+}
+
+std::string Zombie::user_action_str() const {
+    std::string ret;
+    if (manual_user_action())
+        ret = "manual-";
+    else
+        ret = "auto-";
+    ret += User::to_string(user_action());
+    return ret;
+}
+
+/// accessors
+bool Zombie::fob() const {
+    if (user_action_set_)
+        return user_action_ == User::FOB;
+    return attr_.fob(last_child_cmd_);
+}
+bool Zombie::fail() const {
+    if (user_action_set_)
+        return user_action_ == User::FAIL;
+    return attr_.fail(last_child_cmd_);
+}
+bool Zombie::adopt() const {
+    if (user_action_set_)
+        return user_action_ == User::ADOPT;
+    return attr_.adopt(last_child_cmd_);
+}
+bool Zombie::block() const {
+    if (user_action_set_)
+        return user_action_ == User::BLOCK;
+    return attr_.block(last_child_cmd_);
+}
+bool Zombie::remove() const {
+    if (user_action_set_)
+        return user_action_ == User::REMOVE;
+    return attr_.remove(last_child_cmd_);
+}
+bool Zombie::kill() const {
+    if (user_action_set_)
+        return user_action_ == User::KILL;
+    return attr_.kill(last_child_cmd_);
+}
+
+int Zombie::allowed_age() const {
+    return attr_.zombie_lifetime();
+}
+
+void Zombie::set_fob() {
+    user_action_     = User::FOB;
+    user_action_set_ = true;
+}
+void Zombie::set_fail() {
+    user_action_     = User::FAIL;
+    user_action_set_ = true;
+}
+void Zombie::set_adopt() {
+    user_action_     = User::ADOPT;
+    user_action_set_ = true;
+}
+void Zombie::set_block() {
+    user_action_     = User::BLOCK;
+    user_action_set_ = true;
+}
+void Zombie::set_kill() {
+    user_action_     = User::KILL;
+    user_action_set_ = true;
+}
+
+std::ostream& operator<<(std::ostream& os, const Zombie& z) {
+    os << z.path_to_task() << " ";
+    os << z.type_str() << " ";
+    os << z.duration() << " ";
+    os << z.jobs_password() << " ";
+    os << z.process_or_remote_id() << "<pid> ";
+    os << z.try_no() << " ";
+    os << "calls(" << z.calls() << ") ";
+    os << z.user_action_str();
+    os << " ";
+    os << Child::to_string(z.last_child_cmd());
+    return os;
+}
+
+std::string Zombie::explanation() const {
+    std::string ecf_pid_expl        = "PID miss-match, password matches. Job scheduled twice. Check submitter";
+    std::string ecf_pid_passwd_expl = "Both PID and password miss-match. Re-queue & submit of active job?";
+    std::string ecf_passwd_expl     = "Password miss-match, PID matches, system has re-cycled PID or hacked job file?";
+    std::string ecf_expl            = "Two init commands or task complete or aborted but receives another child cmd";
+    std::string ecf_user            = "Created by user action(";
+    std::string ecf_path            = "Task not found. Nodes replaced whilst jobs were running";
+    std::string exp;
+
+    switch (zombie_type_) {
+        case Child::USER:
+            exp = ecf_user;
+            exp += user_cmd_;
+            exp += ")";
+            break;
+        case Child::PATH:
+            exp = ecf_path;
+            break;
+        case Child::ECF:
+            exp = ecf_expl;
+            break;
+        case Child::ECF_PID:
+            exp = ecf_pid_expl;
+            break;
+        case Child::ECF_PID_PASSWD:
+            exp = ecf_pid_passwd_expl;
+            break;
+        case Child::ECF_PASSWD:
+            exp = ecf_passwd_expl;
+            break;
+        case Child::NOT_SET:
+            break;
+    }
+
+    return exp;
+}
+
+std::string Zombie::pretty_print(const std::vector<Zombie>& zombies, int indent) {
+    std::stringstream ss;
+    std::vector<std::string> list;
+    pretty_print(zombies, list, indent);
+    for (const auto& i : list) {
+        ss << i << "\n";
+    }
+    return ss.str();
+}
+
+void Zombie::pretty_print(const std::vector<Zombie>& zombies, std::vector<std::string>& list, int indent) {
+    string path("task-path");
+    string type("type");
+    string password("password");
+    string rid("pid");
+    string duration("age(s)");
+    string calls("calls");
+    string try_no("try_no");
+    string user_action("action");
+    string child_type("child");
+    string host("host");
+    string explanation("explanation");
+
+    size_t path_width        = path.size();
+    size_t type_width        = type.size();
+    size_t duration_width    = duration.size();
+    size_t password_width    = password.size();
+    size_t tryno_width       = try_no.size();
+    size_t rid_width         = rid.size();
+    size_t user_action_width = user_action.size(); // max of FOB,FAIL,ADOPT,BLOCK,REMOVE + (manual- | auto- )
+    size_t child_type_width  = child_type.size();
+    size_t calls_width       = calls.size();
+    size_t host_width        = host.size();
+    size_t explanation_width = explanation.size();
+
+    std::string ecf_pid_expl        = "PID miss-match, password matches. Job scheduled twice. Check submitter";
+    std::string ecf_pid_passwd_expl = "Both PID and password miss-match. Re-queue & submit of active job?";
+    std::string ecf_passwd_expl     = "Password miss-match, PID matches, system has re-cycled PID or hacked job file?";
+    std::string ecf_expl            = "Two init commands or task complete or aborted but receives another child cmd";
+    std::string ecf_user            = "Created by user action(";
+    std::string ecf_path            = "Task not found. Nodes replaced whilst jobs were running";
+    std::string exp;
+
+    for (const Zombie& z : zombies) {
+        path_width              = std::max(path_width, z.path_to_task().size());
+        type_width              = std::max(type_width, z.type_str().size());
+        password_width          = std::max(password_width, z.jobs_password().size());
+        rid_width               = std::max(rid_width, z.process_or_remote_id().size());
+        std::string no_of_calls = ecf::convert_to<std::string>(z.calls());
+        calls_width             = std::max(calls_width, no_of_calls.size());
+        host_width              = std::max(host_width, z.host().size());
+
+        std::string try_no_int = ecf::convert_to<std::string>(z.try_no());
+        tryno_width            = std::max(tryno_width, try_no_int.size());
+        child_type_width       = std::max(child_type_width, Child::to_string(z.last_child_cmd()).size());
+        user_action_width      = std::max(user_action_width, z.user_action_str().size());
+
+        switch (z.type()) {
+            case Child::USER:
+                exp = ecf_user;
+                exp += z.user_cmd();
+                exp += ")";
+                break;
+            case Child::PATH:
+                exp = ecf_path;
+                break;
+            case Child::ECF:
+                exp = ecf_expl;
+                break;
+            case Child::ECF_PID:
+                exp = ecf_pid_expl;
+                break;
+            case Child::ECF_PID_PASSWD:
+                exp = ecf_pid_passwd_expl;
+                break;
+            case Child::ECF_PASSWD:
+                exp = ecf_passwd_expl;
+                break;
+            case Child::NOT_SET:
+                break;
+        }
+        explanation_width = std::max(explanation_width, exp.size());
+    }
+
+    {
+        std::stringstream ss;
+        if (indent != 0)
+            for (int i = 0; i < indent; i++)
+                ss << " ";
+        ss << left << setw(path_width) << path << " " << setw(type_width) << type << " " << setw(duration_width)
+           << duration << " " << setw(password_width) << password << " " << setw(rid_width) << rid << " "
+           << setw(tryno_width) << try_no << " " << setw(user_action_width) << user_action << " "
+           << setw(child_type_width) << child_type << " " << setw(calls_width) << calls << " " << setw(host_width)
+           << host << " " << setw(explanation_width) << explanation;
+        list.push_back(ss.str());
+    }
+
+    for (const Zombie& z : zombies) {
+        std::stringstream ss;
+        if (indent != 0)
+            for (int i = 0; i < indent; i++)
+                ss << " ";
+
+        switch (z.type()) {
+            case Child::USER:
+                exp = ecf_user;
+                exp += z.user_cmd();
+                exp += ")";
+                break;
+            case Child::PATH:
+                exp = ecf_path;
+                break;
+            case Child::ECF:
+                exp = ecf_expl;
+                break;
+            case Child::ECF_PID:
+                exp = ecf_pid_expl;
+                break;
+            case Child::ECF_PID_PASSWD:
+                exp = ecf_pid_passwd_expl;
+                break;
+            case Child::ECF_PASSWD:
+                exp = ecf_passwd_expl;
+                break;
+            case Child::NOT_SET:
+                break;
+        }
+
+        ss << left << setw(path_width) << z.path_to_task() << " " << setw(type_width) << z.type_str() << " "
+           << setw(duration_width) << z.duration() << " " << setw(password_width) << z.jobs_password() << " "
+           << setw(rid_width) << z.process_or_remote_id() << " " << setw(tryno_width) << z.try_no() << " "
+           << setw(user_action_width) << z.user_action_str() << " " << setw(child_type_width)
+           << Child::to_string(z.last_child_cmd()) << " " << setw(calls_width) << z.calls() << " " << setw(host_width)
+           << z.host() << " " << setw(explanation_width) << exp;
+        list.push_back(ss.str());
+    }
+}
+
+template <class Archive>
+void Zombie::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(user_action_),
+       CEREAL_NVP(try_no_),
+       CEREAL_NVP(duration_),
+       CEREAL_NVP(calls_),
+       CEREAL_NVP(zombie_type_),
+       CEREAL_NVP(last_child_cmd_),
+       CEREAL_NVP(path_to_task_),
+       CEREAL_NVP(jobs_password_),
+       CEREAL_NVP(process_or_remote_id_),
+       CEREAL_NVP(user_cmd_),
+       CEREAL_NVP(host_),
+       CEREAL_NVP(attr_),
+       CEREAL_NVP(user_action_set_));
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(Zombie);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/Zombie.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/Zombie.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/Zombie.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/Zombie.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,157 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_Zombie_HPP
+#define ecflow_attribute_Zombie_HPP
+
+///
+/// \brief Holds the zombie structure
+///
+/// WE have 3 structures:
+///      Jobs(path,password,process_id)
+///      Complications ONLY init command provides process_id.
+///      Task(path,password,process_id)
+///      Zombie(path,password,process_id)
+/// Issues:
+///   At the extreme we can have *2* Jobs running at one go. Typically user commands
+///   that have a force parameter, will create 'user' zombies.
+///   ** the command can be invoked at any time, i.e we could invoke
+///   ** the user command, whilst the task is in SUBMITTED state
+///   ** This will go through and create user zombie. However at this stage we have *NO* process_id
+///   ** since the job has not started. Zombie(path,password)
+///   When the Task init command is called, we get given a process_id.
+///   ** HOWEVER ** need to determine if this is from the real child cmd or from the zombie
+///   ** We search zombie list, and compare zombies, by path and password
+///   ** if a match is found, we update the zombie id.
+///
+///   IMPORTANT:: Automated test:
+///               If a child command provides just path and password, this is *NOT*
+///               enough information to disambiguate a zombie from a real job.
+///               To work around this the job file has been updated to add ECF_RID=$$
+///
+///   IMPORTANT:: For command line interface we just have the task path.
+///               i,e we don't want to expose password, and user will not easily
+///               know the process or remote id. Hence we will make do with the
+///               task path. We just find the first zombie, and act up on it
+///
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/core/Child.hpp"
+
+/// Use default copy constructor ,assignment operator and destructor
+class Zombie {
+public:
+    Zombie(ecf::Child::ZombieType zombie_type,      // The kind of zombie
+           ecf::Child::CmdType child_cmd,           // The Child command, that lead to this zombie
+           const ZombieAttr& attr,                  // will hold Action if set on node tree
+           const std::string& pathToTask,           // from child ipc
+           const std::string& jobsPassword,         // from child ipc
+           const std::string& process_or_remote_id, // from child ipc
+           int try_no,
+           const std::string& host,         // The host where the client was invoked
+           const std::string& user_cmd = "" // user cmd that created this zombie
+    );
+    Zombie();
+
+    bool operator==(const Zombie& rhs) const; // for python only
+    std::string to_string() const;            // for python only
+
+    /// accessors
+    // distinguish between manual and automatic user action. manual take precedence
+    bool manual_user_action() const { return user_action_set_; }
+    bool fob() const;
+    bool fail() const;
+    bool adopt() const;
+    bool block() const;
+    bool remove() const;
+    bool kill() const;
+
+    ecf::Child::ZombieType type() const { return zombie_type_; }
+    ecf::Child::CmdType last_child_cmd() const { return last_child_cmd_; }
+    const ZombieAttr& attr() const { return attr_; }
+    int calls() const { return calls_; }
+
+    std::string type_str() const;
+    const std::string& jobs_password() const { return jobs_password_; }
+    const std::string& path_to_task() const { return path_to_task_; }
+    const std::string& process_or_remote_id() const { return process_or_remote_id_; }
+    const std::string& user_cmd() const { return user_cmd_; }
+    const std::string& host() const { return host_; }
+    int try_no() const { return try_no_; }
+    int duration() const { return duration_; }
+    ecf::User::Action user_action() const;
+    std::string user_action_str() const;
+    std::string explanation() const;
+
+    const boost::posix_time::ptime& creation_time() const { return creation_time_; }
+
+    bool empty() const { return path_to_task_.empty(); }
+
+    /// returns in seconds the age the zombie is allowed to live
+    /// Server typically checks every 60 seconds, hence this is lowest valid value that has effect
+    int allowed_age() const;
+
+    /// mutators
+    void set_attr(const ZombieAttr& attr) { attr_ = attr; }
+    void set_process_or_remote_id(const std::string& s) { process_or_remote_id_ = s; }
+    void set_last_child_cmd(ecf::Child::CmdType c) { last_child_cmd_ = c; } // user cmd that created this zombie
+    void set_host(const std::string& h) { host_ = h; }                      // The host where client/zombie was created
+    void set_type(ecf::Child::ZombieType zt) { zombie_type_ = zt; }
+
+    /// User action must take precedence over Zombie attribute settings on node tree
+    ///
+    /// Note: user_action to remove zombie is immediate hence no need to for set_remove()
+    ///       Whereas for the other we want to store the action so that when next child
+    ///       command communicate with the server, the action is applied.
+    void set_duration(int d) { duration_ = d; }
+    void set_fob();
+    void set_fail();
+    void set_adopt();
+    void set_block();
+    void set_kill();
+
+    void increment_calls() { calls_++; }
+
+    // write to standard out a title and list of zombies
+    static std::string pretty_print(const std::vector<Zombie>& zombies, int indent = 0);
+    static void pretty_print(const std::vector<Zombie>& zombies, std::vector<std::string>& list, int indent = 0);
+
+    // MISC:
+    // Added to support return by reference
+    static const Zombie& EMPTY();
+    static Zombie& EMPTY_();
+
+private:
+    ecf::User::Action user_action_{ecf::User::BLOCK};      // [ fob, fail, remove, adopt, block, kill ]
+    int try_no_{0};                                        // task try number, set on construction
+    int duration_{0};                                      // How long zombie been alive
+    int calls_{0};                                         // Number of times we have communicated with server.
+    ecf::Child::ZombieType zombie_type_{ecf::Child::USER}; // [ ecf, ecf_pid, ecf_pid_passwd, ecf_passwd, path, user ]
+    ecf::Child::CmdType last_child_cmd_{
+        ecf::Child::INIT};                   // [ init | event | meter | label | wait | queue | abort | complete ]
+    std::string path_to_task_;               // set on construction
+    std::string jobs_password_;              // set on construction
+    std::string process_or_remote_id_;       // set on construction
+    std::string user_cmd_;                   // user cmd that created this zombie, empty otherwise
+    std::string host_;                       // The client host name
+    ZombieAttr attr_;                        // Default or attribute obtained from node tree.
+    boost::posix_time::ptime creation_time_; // When zombie was created. Needed to control lifetime
+    bool user_action_set_{false};            // Differentiate manual from automated, response, manual take precedence
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+std::ostream& operator<<(std::ostream& os, const Zombie&);
+
+#endif /* ecflow_attribute_Zombie_HPP */
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/ZombieAttr.cpp 5.13.0-1/libs/attribute/src/ecflow/attribute/ZombieAttr.cpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/ZombieAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/ZombieAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,311 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/attribute/ZombieAttr.hpp"
+
+#include <cassert>
+#include <stdexcept>
+
+#include <boost/tokenizer.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace ecf;
+using namespace boost;
+using namespace std;
+
+const ZombieAttr& ZombieAttr::EMPTY() {
+    static const ZombieAttr ZOMBIEATTR = ZombieAttr();
+    return ZOMBIEATTR;
+}
+
+// Constructor ==============================================================================
+ZombieAttr::ZombieAttr(ecf::Child::ZombieType t,
+                       const std::vector<ecf::Child::CmdType>& c,
+                       ecf::User::Action a,
+                       int zombie_lifetime)
+    : child_cmds_(c),
+      zombie_type_(t),
+      action_(a),
+      zombie_lifetime_(zombie_lifetime) {
+    /// Server typically checks every 60 seconds, hence this is lowest valid value for
+    if (zombie_lifetime_ <= 0) {
+        // default constructor. Set defaults
+        switch (zombie_type_) {
+            case Child::USER:
+                zombie_lifetime_ = default_user_zombie_life_time();
+                break;
+            case Child::PATH:
+                zombie_lifetime_ = default_path_zombie_life_time();
+                break;
+            case Child::ECF:
+                zombie_lifetime_ = default_ecf_zombie_life_time();
+                break;
+            case Child::ECF_PID:
+                zombie_lifetime_ = default_ecf_zombie_life_time();
+                break;
+            case Child::ECF_PID_PASSWD:
+                zombie_lifetime_ = default_ecf_zombie_life_time();
+                break;
+            case Child::ECF_PASSWD:
+                zombie_lifetime_ = default_ecf_zombie_life_time();
+                break;
+            case Child::NOT_SET:
+                assert(false);
+                break;
+        }
+    }
+    else if (zombie_lifetime_ < minimum_zombie_life_time()) {
+        zombie_lifetime_ = minimum_zombie_life_time();
+    }
+}
+
+bool ZombieAttr::operator==(const ZombieAttr& rhs) const {
+    if (child_cmds_ != rhs.child_cmds_)
+        return false;
+    if (zombie_type_ != rhs.zombie_type_)
+        return false;
+    if (action_ != rhs.action_)
+        return false;
+    if (zombie_lifetime_ != rhs.zombie_lifetime_)
+        return false;
+    return true;
+}
+
+void ZombieAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += "\n";
+}
+
+std::string ZombieAttr::toString() const {
+    /// format is  zombie_type : child_cmds(optional) : action : zombie_lifetime_(optional)
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void ZombieAttr::write(std::string& ret) const {
+    /// format is  zombie_type : child_cmds(optional) : action : zombie_lifetime_(optional)
+    ret += "zombie ";
+    ret += Child::to_string(zombie_type_);
+    ret += Str::COLON();
+    ret += User::to_string(action_);
+    ret += Str::COLON();
+    ret += Child::to_string(child_cmds_);
+    ret += Str::COLON();
+    ret += ecf::convert_to<std::string>(zombie_lifetime_);
+}
+
+bool ZombieAttr::fob(ecf::Child::CmdType child_cmd) const {
+    if (action_ != User::FOB)
+        return false;
+    if (child_cmds_.empty())
+        return true;
+
+    // If we have child commands specified, then the action is only applicable for that child cmd
+    // for all other child cmds we block
+    for (auto i : child_cmds_) {
+        if (i == child_cmd) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool ZombieAttr::fail(ecf::Child::CmdType child_cmd) const {
+    if (action_ != User::FAIL)
+        return false;
+    if (child_cmds_.empty())
+        return true;
+
+    // If we have child commands specified, then the action is only applicable for that child cmd
+    // for all other child cmds we block
+    for (auto i : child_cmds_) {
+        if (i == child_cmd) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool ZombieAttr::adopt(ecf::Child::CmdType child_cmd) const {
+    if (action_ != User::ADOPT)
+        return false;
+    if (child_cmds_.empty())
+        return true;
+
+    // If we have child commands specified, then the action is only applicable for that child cmd
+    // for all other child cmds we block
+    for (auto i : child_cmds_) {
+        if (i == child_cmd) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool ZombieAttr::remove(ecf::Child::CmdType child_cmd) const {
+    if (action_ != User::REMOVE)
+        return false;
+    if (child_cmds_.empty())
+        return true;
+
+    // If we have child commands specified, then the action is only applicable for that child cmd
+    // for all other child cmds we block
+    for (auto i : child_cmds_) {
+        if (i == child_cmd) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool ZombieAttr::block(ecf::Child::CmdType child_cmd) const {
+    if (action_ != User::BLOCK)
+        return false;
+    if (child_cmds_.empty())
+        return true;
+
+    // If we have child commands specified, then the action is only applicable for that child cmd
+    // for all other child cmds we block
+    for (auto i : child_cmds_) {
+        if (i == child_cmd) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool ZombieAttr::kill(ecf::Child::CmdType child_cmd) const {
+    if (action_ != User::KILL)
+        return false;
+    if (child_cmds_.empty())
+        return true;
+
+    // If we have child commands specified, then the action is only applicable for that child cmd
+    // for all other child cmds we block
+    for (auto i : child_cmds_) {
+        if (i == child_cmd) {
+            return true;
+        }
+    }
+    return false;
+}
+
+ZombieAttr ZombieAttr::create(const std::string& string_to_parse) {
+    /// Use boost tokenizer instead of Str::split, as it allows preservation of empty tokens
+    char_separator<char> sep(":", "", boost::keep_empty_tokens);
+    typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
+    tokenizer tokenise(string_to_parse, sep);
+    std::vector<std::string> tokens;
+    std::copy(tokenise.begin(), tokenise.end(), back_inserter(tokens));
+    if (tokens.size() < 2)
+        throw std::runtime_error("ZombieAttr::create failed: Invalid zombie type " + string_to_parse);
+
+    /// expects <zombie_type>:<user_action>:child_cmds:zombie_lifetime
+    string str_zombie_type;
+    string action_str;
+    string child_cmds;
+    string lifetime;
+    size_t tokens_size = tokens.size();
+    for (size_t i = 0; i < tokens_size; i++) {
+        // cout << "   token " << i << ": '" << tokens[i] << "'\n";
+        if (i == 0) {
+            str_zombie_type = tokens[i];
+            continue;
+        }
+        if (i == 1) {
+            action_str = tokens[i];
+            continue;
+        }
+        if (i == 2) {
+            child_cmds = tokens[i];
+            continue;
+        }
+        if (i == 3) {
+            lifetime = tokens[i];
+            continue;
+        }
+        throw std::runtime_error("ZombieAttr::create failed: Invalid zombie tokens " + string_to_parse);
+    }
+    // std::cout << "   zombie_type = " << str_zombie_type << "   user_action = " << action_str <<  "   child_cmds = "
+    // << child_cmds<< "   zombie_lifetime = " << lifetime << "\n";
+
+    if (!Child::valid_zombie_type(str_zombie_type))
+        throw std::runtime_error("ZombieAttr::create failed: Invalid zombie type, expected one of [ user | ecf | "
+                                 "ecf_pid | ecf_pid_passed | ecf_passwd | path ] but found " +
+                                 str_zombie_type + string(":") + string_to_parse);
+
+    if (!action_str.empty() && !User::valid_user_action(action_str)) {
+        throw std::runtime_error("ZombieAttr::create failed: Invalid user action, expected one of [ fob | fail | "
+                                 "remove | block | adopt | kill ] but found " +
+                                 action_str + string(":") + string_to_parse);
+    }
+
+    if (!child_cmds.empty() && !Child::valid_child_cmds(child_cmds)) {
+        throw std::runtime_error("ZombieAttr::create failed: Invalid child type, expected one or more of [ "
+                                 "init,event,meter,label,wait,queue,abort,complete] but found " +
+                                 tokens[2] + string(":") + string_to_parse);
+    }
+
+    int zombie_lifetime = -1;
+    if (!lifetime.empty()) {
+        try {
+            zombie_lifetime = ecf::convert_to<int>(lifetime);
+        }
+        catch (const ecf::bad_conversion&) {
+            throw std::runtime_error("ZombieAttr::create failed: Zombie life time must be convertible to an integer " +
+                                     lifetime + string(":") + string_to_parse);
+        }
+    }
+
+    if (action_str.empty() && zombie_lifetime == -1)
+        throw std::runtime_error(
+            "ZombieAttr::create failed: User Action(fob,fail,remove,adopt,block) or lifetime must be specified: " +
+            string_to_parse);
+
+    Child::ZombieType zombie_type   = Child::zombie_type(str_zombie_type);
+    User::Action action             = User::user_action(action_str);
+    vector<Child::CmdType> childVec = Child::child_cmds(child_cmds);
+
+    /// If zombie_lifetime is still -1 constructor will reset to standard defaults
+    return ZombieAttr(zombie_type, childVec, action, zombie_lifetime);
+}
+
+ZombieAttr ZombieAttr::get_default_attr(ecf::Child::ZombieType zt) {
+    switch (zt) {
+        case Child::USER:
+            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_user_zombie_life_time());
+        case Child::PATH:
+            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_path_zombie_life_time());
+        case Child::ECF:
+            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
+        case Child::ECF_PID:
+            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
+        case Child::ECF_PID_PASSWD:
+            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
+        case Child::ECF_PASSWD:
+            return ZombieAttr(zt, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
+        case Child::NOT_SET:
+            break;
+    }
+    return ZombieAttr(Child::ECF, std::vector<ecf::Child::CmdType>(), User::BLOCK, default_ecf_zombie_life_time());
+}
+
+template <class Archive>
+void ZombieAttr::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(child_cmds_), CEREAL_NVP(zombie_type_), CEREAL_NVP(action_), CEREAL_NVP(zombie_lifetime_));
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(ZombieAttr);
diff -pruN 5.12.4-1/libs/attribute/src/ecflow/attribute/ZombieAttr.hpp 5.13.0-1/libs/attribute/src/ecflow/attribute/ZombieAttr.hpp
--- 5.12.4-1/libs/attribute/src/ecflow/attribute/ZombieAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/src/ecflow/attribute/ZombieAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_attribute_ZombieAttr_HPP
+#define ecflow_attribute_ZombieAttr_HPP
+
+#include <cstdint>
+
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/User.hpp"
+
+namespace cereal {
+class access;
+}
+
+// Class ZombieAttr:
+// Use compiler , generated destructor, assignment, copy constructor
+// ZombieAttr does *not* have any changeable state
+class ZombieAttr {
+public:
+    ZombieAttr(ecf::Child::ZombieType t,
+               const std::vector<ecf::Child::CmdType>& c,
+               ecf::User::Action a,
+               int zombie_lifetime = 0);
+    ZombieAttr() = default;
+
+    bool operator==(const ZombieAttr& rhs) const;
+    void print(std::string&) const;
+    bool empty() const { return zombie_type_ == ecf::Child::NOT_SET; }
+
+    ecf::Child::ZombieType zombie_type() const { return zombie_type_; }
+    ecf::User::Action action() const { return action_; }
+    int zombie_lifetime() const { return zombie_lifetime_; }
+    const std::vector<ecf::Child::CmdType>& child_cmds() const { return child_cmds_; }
+
+    std::vector<ecf::Child::CmdType>::const_iterator child_begin() const { return child_cmds_.begin(); } // for python
+    std::vector<ecf::Child::CmdType>::const_iterator child_end() const { return child_cmds_.end(); }     // for python
+
+    std::string toString() const;
+
+    bool fob(ecf::Child::CmdType) const;
+    bool fail(ecf::Child::CmdType) const;
+    bool adopt(ecf::Child::CmdType) const;
+    bool block(ecf::Child::CmdType) const;
+    bool remove(ecf::Child::CmdType) const;
+    bool kill(ecf::Child::CmdType) const;
+
+    /// Create from a string. Will throw std::runtime_error of parse errors
+    /// expects <zombie_type>:<user_action>:child_cmds:zombie_lifetime
+    static ZombieAttr create(const std::string& str);
+
+    // Added to support return by reference
+    static const ZombieAttr& EMPTY();
+
+    // Provide the default behaviour
+    static ZombieAttr get_default_attr(ecf::Child::ZombieType);
+
+    static int default_ecf_zombie_life_time() { return 3600; }
+    static int default_user_zombie_life_time() { return 300; }
+    static int default_path_zombie_life_time() { return 900; }
+    static int minimum_zombie_life_time() { return 60; }
+
+private:
+    void write(std::string&) const;
+
+private:
+    std::vector<ecf::Child::CmdType> child_cmds_;             // init, event, meter,label, complete
+    ecf::Child::ZombieType zombie_type_{ecf::Child::NOT_SET}; // User,path or ecf
+    ecf::User::Action action_{ecf::User::BLOCK};              // fob, fail,remove, adopt, block, kill
+    int zombie_lifetime_{0};                                  // How long zombie lives in server
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_attribute_ZombieAttr_HPP */
diff -pruN 5.12.4-1/libs/attribute/test/TestAttrSerialization.cpp 5.13.0-1/libs/attribute/test/TestAttrSerialization.cpp
--- 5.12.4-1/libs/attribute/test/TestAttrSerialization.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestAttrSerialization.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,339 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestSerialisation.hpp"
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/ClockAttr.hpp"
+#include "ecflow/attribute/CronAttr.hpp"
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/attribute/RepeatAttr.hpp"
+#include "ecflow/attribute/TimeAttr.hpp"
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/core/Calendar.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+// Globals used throughout the test
+static std::string fileName = "test.txt";
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_AttrSerialization)
+
+BOOST_AUTO_TEST_CASE(test_AttrDefaultConstructor_serialisation) {
+    cout << "ANattr:: ...test_AttrDefaultConstructor_serialisation \n";
+
+    doSaveAndRestore<VerifyAttr>(fileName);
+    doSaveAndRestore<TodayAttr>(fileName);
+    doSaveAndRestore<TimeAttr>(fileName);
+    doSaveAndRestore<RepeatDate>(fileName);
+    doSaveAndRestore<RepeatDateList>(fileName);
+    doSaveAndRestore<RepeatInteger>(fileName);
+    doSaveAndRestore<RepeatEnumerated>(fileName);
+    doSaveAndRestore<RepeatString>(fileName);
+    doSaveAndRestore<LateAttr>(fileName);
+    doSaveAndRestore<DayAttr>(fileName);
+    doSaveAndRestore<DateAttr>(fileName);
+    doSaveAndRestore<CronAttr>(fileName);
+    doSaveAndRestore<ClockAttr>(fileName);
+    doSaveAndRestore<AutoCancelAttr>(fileName);
+    doSaveAndRestore<AutoArchiveAttr>(fileName);
+    doSaveAndRestore<Label>(fileName);
+    doSaveAndRestore<Variable>(fileName);
+    doSaveAndRestore<Event>(fileName);
+    doSaveAndRestore<Meter>(fileName);
+    doSaveAndRestore<ZombieAttr>(fileName);
+    doSaveAndRestore<QueueAttr>(fileName);
+    doSaveAndRestore<GenericAttr>(fileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_VerifyAttr_serialisation) {
+    cout << "ANattr:: ...test_VerifyAttr_serialisation \n";
+    VerifyAttr saved(NState::COMPLETE, 10);
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_TodayAttr_serialisation) {
+    cout << "ANattr:: ...test_TodayAttr_serialisation \n";
+    {
+        TodayAttr saved(TimeSlot(10, 12));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        TodayAttr saved(TimeSlot(0, 0), TimeSlot(10, 12), TimeSlot(1, 0));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        TodayAttr saved(TimeSeries(TimeSlot(10, 12)));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        TodayAttr saved(TimeSeries(TimeSlot(10, 12)));
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_TimeAttr_serialisation) {
+    cout << "ANattr:: ...test_TimeAttr_serialisation \n";
+    {
+        TimeAttr saved(TimeSlot(10, 12));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        TimeAttr saved(TimeSlot(0, 0), TimeSlot(10, 12), TimeSlot(1, 0));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        TimeAttr saved(TimeSeries(TimeSlot(10, 12)));
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_RepeatAttr_serialisation) {
+    cout << "ANattr:: ...test_RepeatAttr_serialisation \n";
+    {
+        RepeatDate saved("varname", 20101210, 20101230, 3);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        RepeatDateList saved("varname", {19990101, 19990103});
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        RepeatInteger saved("varname", 0, 10, 1);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        std::vector<std::string> theVec;
+        theVec.emplace_back("a");
+        theVec.emplace_back("b");
+        RepeatEnumerated saved = RepeatEnumerated("varname", theVec);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        std::vector<std::string> theVec;
+        theVec.emplace_back("a");
+        RepeatString saved = RepeatString("varname", theVec);
+        doSaveAndRestore(fileName, saved);
+    }
+
+    {
+        Repeat saved(RepeatDate("varname", 20101210, 20101230, 3));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        Repeat saved(RepeatDateList("varname", {19990101, 19990103}));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        Repeat saved(RepeatInteger("varname", 0, 10, 1));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        std::vector<std::string> theVec;
+        theVec.emplace_back("a");
+        theVec.emplace_back("b");
+        Repeat saved(RepeatEnumerated("varname", theVec));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        std::vector<std::string> theVec;
+        theVec.emplace_back("a");
+        Repeat saved(RepeatString("varname", theVec));
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_LateAttr_serialisation) {
+    cout << "ANattr:: ...test_LateAttr_serialisation \n";
+    LateAttr saved;
+    saved.addSubmitted(TimeSlot(10, 12));
+    saved.addActive(TimeSlot(10, 12));
+    saved.addComplete(TimeSlot(10, 12), true);
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_DayAttr_serialisation) {
+    cout << "ANattr:: ...test_DayAttr_serialisation\n";
+    std::vector<DayAttr::Day_t> dvec;
+    dvec.push_back(DayAttr::SUNDAY);
+    dvec.push_back(DayAttr::MONDAY);
+    dvec.push_back(DayAttr::TUESDAY);
+    dvec.push_back(DayAttr::WEDNESDAY);
+    dvec.push_back(DayAttr::THURSDAY);
+    dvec.push_back(DayAttr::FRIDAY);
+    dvec.push_back(DayAttr::SATURDAY);
+    for (auto& d : dvec) {
+        DayAttr saved(d);
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_DateAttr_serialisation) {
+    cout << "ANattr:: ...test_DateAttr_serialisation\n";
+    DateAttr saved(1, 1, 2010);
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_CronAttr_serialisation) {
+    cout << "ANattr:: ...test_CronAttr_serialisation\n";
+    CronAttr saved;
+    std::vector<int> weekDays;
+    weekDays.push_back(1);
+    weekDays.push_back(2);
+    std::vector<int> daysOfMonth;
+    daysOfMonth.push_back(1);
+    daysOfMonth.push_back(2);
+    std::vector<int> months;
+    months.push_back(1);
+    months.push_back(2);
+    saved.addWeekDays(weekDays);
+    saved.addDaysOfMonth(daysOfMonth);
+    saved.addMonths(months);
+    saved.addTimeSeries(TimeSlot(0, 0), TimeSlot(20, 0), TimeSlot(0, 1));
+
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_ClockAttr_serialisation) {
+    cout << "ANattr:: ...test_ClockAttr_serialisation\n";
+    {
+        ClockAttr saved(false);
+        saved.date(1, 1, 2009);
+        saved.set_gain_in_seconds(3600);
+
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        ClockAttr saved(Calendar::second_clock_time());
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_AutoCancelAttr_serialisation) {
+    cout << "ANattr:: ...test_AutoCancelAttr_serialisation\n";
+    {
+        AutoCancelAttr saved(100);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        AutoCancelAttr saved(TimeSlot(12, 10), true);
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_AutoArchiveAttr_serialisation) {
+    cout << "ANattr:: ...test_AutoArchiveAttr_serialisation\n";
+    {
+        AutoArchiveAttr saved(100);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        AutoArchiveAttr saved(100, true /*idle*/);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        AutoArchiveAttr saved(TimeSlot(12, 10), true, false /*idle*/);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        AutoArchiveAttr saved(TimeSlot(12, 10), true, true /*idle*/);
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_Label_serialisation) {
+    cout << "ANattr:: ...test_Label_serialisation\n";
+    {
+        Label saved("labelName", "some text");
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_Variable_serialisation) {
+    cout << "ANattr:: ...test_Variable_serialisation\n";
+    Variable saved("varname", "var value 123 12 =");
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_Event_serialisation) {
+    cout << "ANattr:: ...test_Event_serialisation\n";
+    {
+        Event saved(3);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        Event saved(10 + 1, "event_name");
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        Event saved(12, "event_name", true /*init value*/);
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        Event saved(12, "event_name", false /*init value*/);
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_Meter_serialisation) {
+    cout << "ANattr:: ...test_Meter_serialisation\n";
+    Meter saved("meter", 0, 20, 20);
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_queue_serialisation) {
+    cout << "ANattr:: ...test_queue_serialisation\n";
+    std::vector<std::string> queue_items;
+    queue_items.emplace_back("a");
+    queue_items.emplace_back("b");
+    QueueAttr saved("queue", queue_items);
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_generic_serialisation) {
+    cout << "ANattr:: ...test_generic_serialisation\n";
+    std::vector<std::string> queue_items;
+    queue_items.emplace_back("a");
+    queue_items.emplace_back("b");
+    GenericAttr saved("gen1", queue_items);
+    doSaveAndRestore(fileName, saved);
+}
+
+BOOST_AUTO_TEST_CASE(test_zombie_attr_serialisation) {
+    cout << "ANattr:: ...test_zombie_attr_serialisation\n";
+
+    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
+
+    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
+    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::FAIL, 10));
+    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::BLOCK, 10));
+    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::REMOVE, 10));
+    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::KILL, 10));
+    doSaveAndRestore(fileName, ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::ADOPT, 10));
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestAttributes_main.cpp 5.13.0-1/libs/attribute/test/TestAttributes_main.cpp
--- 5.12.4-1/libs/attribute/test/TestAttributes_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestAttributes_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Attributes
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/attribute/test/TestCron.cpp 5.13.0-1/libs/attribute/test/TestCron.cpp
--- 5.12.4-1/libs/attribute/test/TestCron.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestCron.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,623 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/CronAttr.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_Cron)
+
+BOOST_AUTO_TEST_CASE(test_cron_parsing) {
+    cout << "ANattr:: ...test_cron_parsing\n";
+    TimeSlot start(10, 10);
+    TimeSlot finish(23, 10);
+    TimeSlot incr(0, 1);
+
+    {
+        CronAttr cron;
+        CronAttr parsedCron;
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+    }
+    {
+        CronAttr cron;
+        cron.add_time_series(10, 10, false);
+        CronAttr cron1(10, 10, false);
+        CronAttr parsedCron = CronAttr::create("cron 10:10");
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
+                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
+    }
+    {
+        CronAttr cron;
+        cron.add_time_series(10, 10, true);
+        CronAttr cron1(10, 10, true);
+        CronAttr parsedCron = CronAttr::create("cron +10:10");
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
+                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
+    }
+    {
+        CronAttr cron;
+        cron.addTimeSeries(start, finish, incr);
+        CronAttr cron1(start, finish, incr);
+        CronAttr parsedCron = CronAttr::create("cron 10:10 23:10 00:01");
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
+                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
+    }
+
+    {
+        std::vector<int> week_days{0, 1, 2, 3, 4, 5, 6};
+        CronAttr cron;
+        cron.addWeekDays(week_days);
+        cron.add_time_series(10, 10, true);
+
+        CronAttr cron1(10, 10, true);
+        cron1.addWeekDays(week_days);
+
+        std::string cron_str = "cron -w 0,1,2,3,4,5,6 +10:10";
+        CronAttr parsedCron  = CronAttr::create(cron_str);
+        BOOST_CHECK_MESSAGE(parsedCron.toString() == cron_str,
+                            "Expected " << cron_str << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
+                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
+    }
+    {
+        std::vector<int> week_days{0, 1, 2, 3, 4, 5, 6};
+        CronAttr cron;
+        cron.add_last_week_days_of_month(week_days);
+        cron.add_time_series(10, 10, true);
+
+        std::string cron_str = "cron -w 0L,1L,2L,3L,4L,5L,6L +10:10";
+        CronAttr parsedCron  = CronAttr::create(cron_str);
+        BOOST_CHECK_MESSAGE(parsedCron.toString() == cron_str,
+                            "Expected " << cron_str << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+    }
+    {
+        std::vector<int> week_days{0, 1, 2};
+        std::vector<int> last_week_days_of_month{3, 4, 5, 6};
+        CronAttr cron;
+        cron.addWeekDays(week_days);
+        cron.add_last_week_days_of_month(last_week_days_of_month);
+        cron.add_time_series(10, 10, true);
+
+        std::string cron_str = "cron -w 0,1,2,3L,4L,5L,6L +10:10";
+        CronAttr parsedCron  = CronAttr::create(cron_str);
+        BOOST_CHECK_MESSAGE(parsedCron.toString() == cron_str,
+                            "Expected " << cron_str << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+    }
+    {
+        std::vector<int> week_days{0, 1, 2};
+        std::vector<int> last_week_days_of_month{3, 4};
+        CronAttr cron;
+        cron.addWeekDays(week_days);
+        cron.add_last_week_days_of_month(last_week_days_of_month);
+        cron.add_time_series(10, 10, true);
+
+        try {
+            CronAttr parsedCron = CronAttr::create("cron -w 0,1,2,0L,1L,2L +10:10");
+            BOOST_CHECK_MESSAGE(false,
+                                "Expected exception for " << parsedCron.toString() << " cron " << cron.toString());
+        }
+        catch (...) {
+        }
+    }
+
+    {
+        std::vector<int> days_of_month{1, 3, 4, 5, 6, 24, 25};
+        CronAttr cron;
+        cron.addDaysOfMonth(days_of_month);
+        cron.add_last_day_of_month();
+        cron.add_time_series(10, 10, true);
+
+        CronAttr cron1(10, 10, true);
+        cron1.addDaysOfMonth(days_of_month);
+        cron1.add_last_day_of_month();
+
+        CronAttr parsedCron  = CronAttr::create("cron -d L,1,3,4,5,6,24,25 +10:10");
+        CronAttr parsedCron2 = CronAttr::create("cron -d 1,3,4,5,6,24,25,L +10:10");
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron2.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron2.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
+                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
+    }
+
+    std::vector<int> months{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+    {
+        CronAttr cron;
+        cron.addMonths(months);
+        cron.add_time_series(10, 10, true);
+
+        CronAttr cron1(10, 10, true);
+        cron1.addMonths(months);
+
+        CronAttr parsedCron = CronAttr::create("cron -m 1,2,3,4,5,6,7,8,9,10,11,12 +10:10");
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
+                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
+    }
+
+    {
+        std::vector<int> week_days{0, 1, 2};
+        std::vector<int> last_week_days_of_month{3, 4, 5, 6};
+        std::vector<int> days_of_month{1, 3, 4, 5, 6, 24, 25};
+
+        CronAttr cron;
+        cron.addWeekDays(week_days);
+        cron.add_last_week_days_of_month(last_week_days_of_month);
+        cron.addDaysOfMonth(days_of_month);
+        cron.addMonths(months);
+        cron.add_last_day_of_month();
+        cron.addTimeSeries(start, finish, incr);
+
+        CronAttr cron1(start, finish, incr);
+        cron1.addWeekDays(week_days);
+        cron1.add_last_week_days_of_month(last_week_days_of_month);
+        cron1.addDaysOfMonth(days_of_month);
+        cron1.addMonths(months);
+        cron1.add_last_day_of_month();
+
+        CronAttr parsedCron = CronAttr::create(
+            "cron -w 0,1,2,3L,4L,5L,6L -d 1,3,4,5,6,24,L,25 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:10 23:10 00:01");
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron),
+                            "Expected " << cron.toString() << " but found " << parsedCron.toString());
+        BOOST_CHECK_MESSAGE(parsedCron.structureEquals(cron1),
+                            "Expected " << cron1.toString() << " but found " << parsedCron.toString());
+    }
+
+    {
+        std::vector<std::string> cron_vec{
+            "cron -w 0,1,2,3L,4L,5L,6L -d 1,3,4,5,6,24,L,25 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:10 23:10 00:01",
+            "cron -w 0L,1L,2L,3L,4L,5L,6L -d 1,L 23:00"};
+        for (const auto& cron : cron_vec) {
+            try {
+                CronAttr parsedCron = CronAttr::create(cron);
+            }
+            catch (...) {
+                BOOST_CHECK_MESSAGE(false, "Could not parse " << cron);
+            }
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_cron_state_parsing) {
+    cout << "ANattr:: ...test_cron_state_parsing\n";
+
+    size_t index = 1; // to get over the cron
+    {
+        std::string line = "cron 04:30 # isValid:false";
+        std::vector<std::string> lineTokens;
+        Str::split(line, lineTokens);
+        bool parse_state = true;
+        CronAttr parsed_cronAttr;
+        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
+
+        CronAttr expected;
+        TimeSeries series(4, 30);
+        series.set_isValid(false); // to match isValid:false
+        expected.addTimeSeries(series);
+        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
+                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
+                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
+    }
+
+    {
+        std::string line = "cron 04:30 # free isValid:false";
+        std::vector<std::string> lineTokens;
+        Str::split(line, lineTokens);
+        bool parse_state = true;
+        CronAttr parsed_cronAttr;
+        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
+
+        CronAttr expected;
+        TimeSeries series(4, 30);
+        series.set_isValid(false); // to match isValid:false
+        expected.addTimeSeries(series);
+        expected.setFree();
+        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
+                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
+                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
+    }
+
+    {
+        std::string line = "cron 00:01 23:59 01:00 # nextTimeSlot/12:01";
+        std::vector<std::string> lineTokens;
+        Str::split(line, lineTokens);
+        bool parse_state = true;
+        CronAttr parsed_cronAttr;
+        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
+
+        CronAttr expected;
+        TimeSlot start(0, 1);
+        TimeSlot finish(23, 59);
+        TimeSlot incr(1, 0);
+        TimeSeries series(start, finish, incr);
+        series.set_next_time_slot(TimeSlot(12, 1));
+        expected.addTimeSeries(series);
+        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
+                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
+                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
+    }
+
+    {
+        std::string line = "cron 00:01 23:59 01:00 # free nextTimeSlot/12:01";
+        std::vector<std::string> lineTokens;
+        Str::split(line, lineTokens);
+        bool parse_state = true;
+        CronAttr parsed_cronAttr;
+        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
+
+        CronAttr expected;
+        TimeSlot start(0, 1);
+        TimeSlot finish(23, 59);
+        TimeSlot incr(1, 0);
+        TimeSeries series(start, finish, incr);
+        series.set_next_time_slot(TimeSlot(12, 1));
+        expected.addTimeSeries(series);
+        expected.setFree();
+        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
+                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
+                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
+    }
+    {
+        std::string line = "cron 00:00 18:00 06:00 # isValid:false nextTimeSlot/24:00";
+        std::vector<std::string> lineTokens;
+        Str::split(line, lineTokens);
+        bool parse_state = true;
+        CronAttr parsed_cronAttr;
+        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
+
+        CronAttr expected;
+        TimeSlot start(0, 0);
+        TimeSlot finish(18, 0);
+        TimeSlot incr(6, 0);
+        TimeSeries series(start, finish, incr);
+        series.set_next_time_slot(TimeSlot(24, 0));
+        series.set_isValid(false); // to match isValid:false
+        expected.addTimeSeries(series);
+        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
+                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
+                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
+    }
+
+    {
+        // ECFLOW-1693
+        // Could not parse 'cron +00:00 23:59 00:01 # isValid:false nextTimeSlot/523:40' around line number 654
+        std::string line = "cron +00:00 23:59 00:01 # isValid:false nextTimeSlot/523:40";
+        std::vector<std::string> lineTokens;
+        Str::split(line, lineTokens);
+        bool parse_state = true;
+        CronAttr parsed_cronAttr;
+        CronAttr::parse(parsed_cronAttr, lineTokens, index, parse_state);
+
+        CronAttr expected;
+        TimeSlot start(0, 0);
+        TimeSlot finish(23, 59);
+        TimeSlot incr(0, 1);
+        TimeSeries series(start, finish, incr, true);
+        series.set_next_time_slot(TimeSlot(523, 40));
+        series.set_isValid(false); // to match isValid:false
+        expected.addTimeSeries(series);
+        BOOST_CHECK_MESSAGE(parsed_cronAttr == expected,
+                            "Expected " << expected.dump() << " : " << expected.time().dump() << " but found "
+                                        << parsed_cronAttr.dump() << " : " << parsed_cronAttr.time().dump());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_cron_once_free_stays_free) {
+    cout << "ANattr:: ...test_cron_once_free_stays_free\n";
+
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
+    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
+
+    CronAttr timeSeries;
+    timeSeries.addTimeSeries(timeSeriesX);
+    CronAttr timeSeries2;
+    timeSeries2.addTimeSeries(timeSeries2X);
+    CronAttr timeSeries3;
+    timeSeries3.addTimeSeries(timeSeries3X);
+    CronAttr timeSeries4;
+    timeSeries4.addTimeSeries(timeSeries4X);
+
+    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
+    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
+    timeSeries.time_series().free_slots(timeSeries_free_slots);
+    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
+    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
+                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
+                                                      << timeSeries_free_slots.size());
+    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
+                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
+                                                     << timeSeries_free_slots.size());
+
+    bool day_changed = false; // after midnight make sure we keep day_changed
+    for (int m = 1; m < 96; m++) {
+        calendar.update(time_duration(minutes(30)));
+        if (!day_changed) {
+            day_changed = calendar.dayChanged();
+        }
+        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
+        // cout << time << " day_changed(" << day_changed << ")\n";
+
+        timeSeries.calendarChanged(calendar);
+        timeSeries2.calendarChanged(calendar);
+        timeSeries3.calendarChanged(calendar);
+        timeSeries4.calendarChanged(calendar);
+
+        // cron should always reque regardless of time series
+        BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar),
+                            timeSeries.toString() << " checkForRequeue should be true at time " << time);
+        BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar),
+                            timeSeries2.toString() << " checkForRequeue should be true at time " << time);
+        BOOST_CHECK_MESSAGE(timeSeries3.checkForRequeue(calendar),
+                            timeSeries3.toString() << " checkForRequeue should be true at time " << time);
+        BOOST_CHECK_MESSAGE(timeSeries4.checkForRequeue(calendar),
+                            timeSeries4.toString() << " checkForRequeue should be true at time " << time);
+
+        // **********************************************************************************
+        // When a cron (regardless of whether its single slot or time series) is free, it stays free,
+        // until explicitly re-queued,
+        // ***********************************************************************************
+
+        if (time < timeSeries.time_series().start().duration()) {
+            if (!day_changed)
+                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should NOT be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be free at time " << time);
+        }
+        else if (time >= timeSeries.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                timeSeries.toString() << " should be free at time " << time);
+        }
+
+        if (time < timeSeries2.time_series().start().duration()) {
+            if (!day_changed)
+                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should NOT be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be free at time " << time);
+        }
+        else if (time >= timeSeries2.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                timeSeries2.toString() << " should be free at time " << time);
+        }
+
+        if (!day_changed) {
+            if (time == timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " should be free at time " << time);
+            }
+            else if (time > timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " isFree, once free should stay free at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                timeSeries3.toString() << " should be free at time after day change " << time);
+        }
+
+        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
+        // repeat/cron)
+        if (!day_changed) {
+            if (time == timeSeries4.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                    timeSeries4.toString() << " should be free at time " << time);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
+                                    timeSeries4.toString()
+                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                timeSeries4.toString()
+                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_cron_time_series) {
+    cout << "ANattr:: ...test_cron_time_series\n";
+
+    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
+    // test time attr isFree(), and checkForRequeue
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
+    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
+
+    CronAttr timeSeries;
+    timeSeries.addTimeSeries(timeSeriesX);
+    CronAttr timeSeries2;
+    timeSeries2.addTimeSeries(timeSeries2X);
+    CronAttr timeSeries3;
+    timeSeries3.addTimeSeries(timeSeries3X);
+    CronAttr timeSeries4;
+    timeSeries4.addTimeSeries(timeSeries4X);
+
+    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
+    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
+    timeSeries.time_series().free_slots(timeSeries_free_slots);
+    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
+    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
+                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
+                                                      << timeSeries_free_slots.size());
+    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
+                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
+                                                     << timeSeries_free_slots.size());
+
+    bool day_changed = false; // after midnight make sure we keep day_changed
+    for (int m = 1; m < 96; m++) {
+        calendar.update(time_duration(minutes(30)));
+        if (!day_changed) {
+            day_changed = calendar.dayChanged();
+        }
+        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
+        //      cout << time << " day_changed(" << day_changed << ")\n";
+
+        timeSeries.calendarChanged(calendar);
+        timeSeries2.calendarChanged(calendar);
+        timeSeries3.calendarChanged(calendar);
+        timeSeries4.calendarChanged(calendar);
+
+        // cron should always reque regardless of time series
+        BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar),
+                            timeSeries.toString() << " checkForRequeue should be true at time " << time);
+        BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar),
+                            timeSeries2.toString() << " checkForRequeue should be true at time " << time);
+        BOOST_CHECK_MESSAGE(timeSeries3.checkForRequeue(calendar),
+                            timeSeries3.toString() << " checkForRequeue should be true at time " << time);
+        BOOST_CHECK_MESSAGE(timeSeries4.checkForRequeue(calendar),
+                            timeSeries4.toString() << " checkForRequeue should be true at time " << time);
+
+        // **********************************************************************************
+        // When a cron (regardless of whether its single slot or time series) is free, it stays free
+        // However in order to test crons with time series, we will re-queue ate the end of this loop
+        // ***********************************************************************************
+
+        if (time < timeSeries.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                timeSeries.toString() << " should NOT be free at time " << time);
+        }
+        else if (time >= timeSeries.time_series().start().duration() &&
+                 time <= timeSeries.time_series().finish().duration()) {
+
+            bool matches_free_slot = false;
+            for (const auto& timeSeries_free_slot : timeSeries_free_slots) {
+                if (time == timeSeries_free_slot) {
+                    matches_free_slot = true;
+                    break;
+                }
+            }
+            if (matches_free_slot)
+                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be fail at time " << time);
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                timeSeries.toString() << " should be holding at time " << time);
+        }
+
+        if (time < timeSeries2.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                timeSeries2.toString() << " should NOT be free at time " << time);
+        }
+        else if (time >= timeSeries2.time_series().start().duration() &&
+                 time <= timeSeries2.time_series().finish().duration()) {
+
+            bool matches_free_slot = false;
+            for (const auto& timeSeries2_free_slot : timeSeries2_free_slots) {
+                if (time == timeSeries2_free_slot) {
+                    matches_free_slot = true;
+                    break;
+                }
+            }
+            if (matches_free_slot)
+                BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should be fail at time " << time);
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                timeSeries2.toString() << " should be holding at time " << time);
+        }
+
+        // Single slot, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
+        // repeat/cron)
+        if (!day_changed) {
+            if (time == timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " should be free at time " << time);
+            }
+            else if (time > timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " isFree, once free should stay free at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                timeSeries3.toString() << " should be free at time after day change " << time);
+        }
+
+        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
+        // repeat/cron)
+        if (!day_changed) {
+            if (time == timeSeries4.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                    timeSeries4.toString() << " should be free at time " << time);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
+                                    timeSeries4.toString()
+                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                timeSeries4.toString()
+                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
+        }
+
+        // Typically when a cron is free, it stays free, until it is re-queued
+        // However in order to test isFree for cron with time inetrvals, we need to re-queue
+        timeSeries.requeue(calendar);
+        timeSeries2.requeue(calendar);
+
+        // Do not requeue cron 00, and cron 15, so that we can check for free
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestDateAttr.cpp 5.13.0-1/libs/attribute/test/TestDateAttr.cpp
--- 5.12.4-1/libs/attribute/test/TestDateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestDateAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,123 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_DateAttr)
+
+BOOST_AUTO_TEST_CASE(test_date) {
+    cout << "ANattr:: ...test_date\n";
+    {
+        DateAttr empty;
+        DateAttr empty2;
+        BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
+        BOOST_CHECK_MESSAGE(empty.day() == 0 && empty.month() == 0 && empty.year() == 0, "");
+    }
+    {
+        for (int day = 0; day < 28; day++) {
+            for (int month = 0; month < 13; month++) {
+                int year = 2017;
+                if (month == 0)
+                    year = 0;
+                std::stringstream ss;
+                if (day == 0)
+                    ss << "*";
+                else
+                    ss << day;
+                ss << ".";
+                if (month == 0)
+                    ss << "*";
+                else
+                    ss << month;
+                ss << ".";
+                if (year == 0)
+                    ss << "*";
+                else
+                    ss << year;
+
+                DateAttr date1(day, month, year);
+                DateAttr date2(ss.str());
+                BOOST_CHECK_MESSAGE(date1 == date2, "Equality failed");
+                BOOST_CHECK_MESSAGE(date1.name() == date2.name(), "name failed");
+            }
+        }
+    }
+}
+
+static DateAttr print_and_parse_attr(DateAttr& date) {
+
+    PrintStyle style(PrintStyle::MIGRATE);
+    std::string output;
+    date.print(output);
+    output.erase(output.begin() + output.size() - 1); // remove trailing newline
+
+    std::vector<std::string> tokens;
+    Str::split_orig(output, tokens);
+
+    return DateAttr::create(tokens, true /*read state*/);
+}
+
+BOOST_AUTO_TEST_CASE(test_date_parsing) {
+
+    cout << "ANattr:: ...test_date_parsing\n";
+    {
+        DateAttr date("12.12.2019");
+        date.setFree();
+        DateAttr parsed_date = print_and_parse_attr(date);
+
+        BOOST_CHECK_MESSAGE(date == parsed_date,
+                            "Parse failed expected " << date.dump() << " but found " << parsed_date.dump());
+    }
+    {
+        DateAttr date("12.12.2019");
+        date.setFree();
+        DateAttr parsed_date = print_and_parse_attr(date);
+
+        BOOST_CHECK_MESSAGE(date == parsed_date,
+                            "Parse failed expected " << date.dump() << " but found " << parsed_date.dump());
+    }
+    {
+        DateAttr date("12.12.2019");
+        DateAttr parsed_date = print_and_parse_attr(date);
+
+        BOOST_CHECK_MESSAGE(date == parsed_date,
+                            "Parse failed expected " << date.dump() << " but found " << parsed_date.dump());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_date_errors) {
+    cout << "ANattr:: ...test_date_errors\n";
+    {
+        BOOST_REQUIRE_THROW(DateAttr("-1.2.*"), std::runtime_error);
+        BOOST_REQUIRE_THROW(DateAttr("32.2.*"), std::runtime_error);
+        BOOST_REQUIRE_THROW(DateAttr("1.-1.*"), std::runtime_error);
+        BOOST_REQUIRE_THROW(DateAttr("1.13.*"), std::runtime_error);
+        BOOST_REQUIRE_THROW(DateAttr("1.13.-1"), std::runtime_error);
+        BOOST_REQUIRE_THROW(DateAttr("1.13.99999999"), std::runtime_error);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestDayAttr.cpp 5.13.0-1/libs/attribute/test/TestDayAttr.cpp
--- 5.12.4-1/libs/attribute/test/TestDayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestDayAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,171 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_DayAttr)
+
+BOOST_AUTO_TEST_CASE(test_day_attr) {
+    cout << "ANattr:: ...test_day_attr\n";
+
+    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
+    // test time attr isFree(), and checkForRequeue
+    Calendar calendar;
+    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
+
+    // Represent a day within a week (range 0==Sun to 6==Sat)
+    BOOST_CHECK_MESSAGE(calendar.day_of_week() == 2, " Expected tuesday(2) but found " << calendar.day_of_week());
+
+    DayAttr day(DayAttr::WEDNESDAY);
+    day.reset(calendar);
+
+    // int day_changed = 0; // after midnight make sure we keep day_changed
+    // day_changed = 0;  tuesday
+    // day_changed = 1;  wednesday
+    // day_changed = 3;  thursday
+    for (int m = 1; m < 96; m++) {
+        calendar.update(time_duration(hours(1)));
+        // if (calendar.dayChanged())
+        //     day_changed++;
+
+        // cout << " day_changed(" << day_changed << ") calendar.day_of_week() = " <<  calendar.day_of_week() << "\n";
+
+        day.calendarChanged(calendar);
+
+        if (day.date() < calendar.date()) {
+            BOOST_CHECK_MESSAGE(!day.isFree(calendar),
+                                day.toString() << " is free should fail at day " << calendar.day_of_week());
+            BOOST_CHECK_MESSAGE(!day.checkForRequeue(calendar),
+                                day.toString() << " checkForRequeue should return false for a single day "
+                                               << calendar.day_of_week());
+        }
+        else if (day.date() == calendar.date()) {
+            BOOST_CHECK_MESSAGE(day.isFree(calendar),
+                                day.toString() << " is free should pass at day " << calendar.day_of_week());
+            BOOST_CHECK_MESSAGE(!day.checkForRequeue(calendar),
+                                day.toString() << " checkForRequeue should fail at " << calendar.day_of_week());
+        }
+        else {
+            BOOST_CHECK_MESSAGE(day.date() > calendar.date(), "");
+            BOOST_CHECK_MESSAGE(!day.isFree(calendar),
+                                day.toString() << " is free should pass at day " << calendar.day_of_week());
+            BOOST_CHECK_MESSAGE(day.checkForRequeue(calendar),
+                                day.toString() << " checkForRequeue should fail at " << calendar.day_of_week());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_day_attr_constructor) {
+    cout << "ANattr:: ...test_day_attr_constructor \n";
+    {
+        DayAttr day;
+        BOOST_CHECK_MESSAGE(day.day() == DayAttr::SUNDAY, "");
+        BOOST_CHECK_MESSAGE(day.state_change_no() == 0, "");
+        BOOST_CHECK_MESSAGE(day.isSetFree() == false, "");
+    }
+    {
+        DayAttr day(DayAttr::WEDNESDAY);
+        BOOST_CHECK_MESSAGE(day.day() == DayAttr::WEDNESDAY, "");
+        BOOST_CHECK_MESSAGE(day.state_change_no() == 0, "");
+        BOOST_CHECK_MESSAGE(day.isSetFree() == false, "");
+    }
+    {
+        DayAttr day("monday");
+        BOOST_CHECK_MESSAGE(day.day() == DayAttr::MONDAY, "");
+        BOOST_CHECK_MESSAGE(day.state_change_no() == 0, "");
+        BOOST_CHECK_MESSAGE(day.isSetFree() == false, "");
+    }
+}
+
+static DayAttr print_and_parse_attr(DayAttr& day) {
+
+    PrintStyle style(PrintStyle::MIGRATE);
+    std::string output;
+    day.print(output);
+    output.erase(output.begin() + output.size() - 1); // remove trailing newline
+
+    std::vector<std::string> tokens;
+    Str::split_orig(output, tokens);
+
+    return DayAttr::create(tokens, true /*read state*/);
+}
+
+BOOST_AUTO_TEST_CASE(test_day_parsing) {
+
+    cout << "ANattr:: ...test_day_parsing\n";
+    {
+        DayAttr day(DayAttr::WEDNESDAY);
+        day.setFree();
+        DayAttr parsed_day = print_and_parse_attr(day);
+
+        BOOST_CHECK_MESSAGE(day == parsed_day,
+                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
+    }
+    {
+        DayAttr day(DayAttr::WEDNESDAY);
+        day.setFree();
+        DayAttr parsed_day = print_and_parse_attr(day);
+
+        BOOST_CHECK_MESSAGE(day == parsed_day,
+                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
+    }
+    {
+        DayAttr day(DayAttr::WEDNESDAY);
+        DayAttr parsed_day = print_and_parse_attr(day);
+
+        BOOST_CHECK_MESSAGE(day == parsed_day,
+                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
+    }
+    {
+        Calendar calendar;
+        calendar.init(ptime(date(2020, 6, 26), minutes(0)), Calendar::REAL); // friday
+
+        DayAttr day(calendar.date());
+
+        DayAttr parsed_day = print_and_parse_attr(day);
+        BOOST_CHECK_MESSAGE(day == parsed_day,
+                            "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
+    }
+    {
+        Calendar c;
+        c.init(ptime(date(2020, 6, 26), minutes(0)), Calendar::REAL); // friday
+
+        boost::gregorian::date_duration one_day(1);
+        boost::gregorian::date next_day = c.date(); // todays date
+
+        for (int i = 0; i < 7; i++) {
+            next_day += one_day;
+
+            DayAttr day(next_day);
+            DayAttr parsed_day = print_and_parse_attr(day);
+            BOOST_CHECK_MESSAGE(day == parsed_day,
+                                "Parse failed expected " << day.dump() << " but found " << parsed_day.dump());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestLabel.cpp 5.13.0-1/libs/attribute/test/TestLabel.cpp
--- 5.12.4-1/libs/attribute/test/TestLabel.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestLabel.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_Label)
+
+BOOST_AUTO_TEST_CASE(test_label_parsing) {
+    cout << "ANattr:: ...test_label_parsing\n";
+    {
+        std::string line = "label name \"value\"";
+        std::vector<string> linetokens;
+        Str::split(line, linetokens);
+
+        Label label;
+        label.parse(line, linetokens, false);
+
+        Label expected("name", "value");
+        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
+        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
+                            "Expected " << expected.dump() << " but found " << label.dump());
+    }
+    {
+        std::string line = R"(label name "value\nvalue")";
+        std::vector<string> linetokens;
+        Str::split(line, linetokens);
+
+        Label label;
+        label.parse(line, linetokens, false);
+
+        Label expected("name", "value\nvalue");
+        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
+        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
+                            "Expected " << expected.dump() << " but found " << label.dump());
+    }
+    {
+        std::string line = "label name \"value that is multiple token !!!! 23445 !^ & * ( )\"";
+        std::vector<string> linetokens;
+        Str::split(line, linetokens);
+
+        Label label;
+        label.parse(line, linetokens, false);
+
+        Label expected("name", "value that is multiple token !!!! 23445 !^ & * ( )");
+        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
+        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
+                            "Expected " << expected.dump() << " but found " << label.dump());
+    }
+    {
+        std::string line = R"(label name "value\n that\n is\n multiple\n token\n and\n new\n \nlines")";
+        std::vector<string> linetokens;
+        Str::split(line, linetokens);
+
+        Label label;
+        label.parse(line, linetokens, false);
+
+        Label expected("name", "value\n that\n is\n multiple\n token\n and\n new\n \nlines");
+        BOOST_CHECK_MESSAGE(label == expected, "Expected " << expected.toString() << " but found " << label.toString());
+        BOOST_CHECK_MESSAGE(label.dump() == expected.dump(),
+                            "Expected " << expected.dump() << " but found " << label.dump());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestLateAttr.cpp 5.13.0-1/libs/attribute/test/TestLateAttr.cpp
--- 5.12.4-1/libs/attribute/test/TestLateAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestLateAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,312 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/date_time/posix_time/time_formatters.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/NState.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_LateAttr)
+
+BOOST_AUTO_TEST_CASE(test_late_attr_submitted) {
+    cout << "ANattr:: ...test_late_attr_submitted\n";
+
+    // REF: ECFLOW-322
+    Calendar calendar;
+    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
+
+    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
+    ///               relative, so + is simple ignored, if present. If the node stays submitted
+    ///               longer than the time specified, the late flag is set
+    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
+    ///               is still queued or submitted, the late flag is set
+    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
+    ///               taken from the time the node became active, otherwise node must be complete by
+    ///               the time given.
+    ecf::LateAttr lateAttr;
+    lateAttr.addSubmitted(ecf::TimeSlot(0, 4));
+
+    calendar.update(time_duration(minutes(1)));
+    calendar.update(time_duration(minutes(1)));
+    calendar.update(time_duration(minutes(1)));
+    calendar.update(time_duration(minutes(1)));
+    calendar.update(time_duration(minutes(1)));
+
+    // set submitted state at 00:05:00
+    // cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
+    std::pair<NState, boost::posix_time::time_duration> state =
+        std::make_pair(NState(NState::SUBMITTED), calendar.duration());
+
+    // after four minutes in submitted state, we should be late
+    for (int m = 1; m < 10; m++) {
+        calendar.update(time_duration(minutes(1)));
+        // cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+
+        lateAttr.checkForLateness(state, calendar);
+        // if (lateAttr.isLate()) {
+        //    cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+        // }
+
+        if (m >= 4) {
+            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
+                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_late_attr_active) {
+    cout << "ANattr:: ...test_late_attr_active\n";
+
+    Calendar calendar;
+    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
+
+    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
+    ///               relative, so + is simple ignored, if present. If the node stays submitted
+    ///               longer than the time specified, the late flag is set
+    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
+    ///               is still queued or submitted, the late flag is set
+    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
+    ///               taken from the time the node became active, otherwise node must be complete by
+    ///               the time given.
+
+    ecf::LateAttr lateAttr;
+    lateAttr.addActive(ecf::TimeSlot(10, 0));
+
+    // set submitted state at 00:00:00
+    // cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
+    std::pair<NState, boost::posix_time::time_duration> state =
+        std::make_pair(NState(NState::SUBMITTED), calendar.duration());
+
+    // after 10 hours we, if we are not active, we should be late
+    for (int m = 1; m < 23; m++) {
+        calendar.update(time_duration(hours(1)));
+        // cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+
+        lateAttr.checkForLateness(state, calendar);
+        //      if (lateAttr.isLate()) {
+        //         cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+        //      }
+
+        if (m >= 10) {
+            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
+                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_late_attr_complete_relative) {
+    cout << "ANattr:: ...test_late_attr_complete_relative\n";
+
+    Calendar calendar;
+    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
+
+    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
+    ///               relative, so + is simple ignored, if present. If the node stays submitted
+    ///               longer than the time specified, the late flag is set
+    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
+    ///               is still queued or submitted, the late flag is set
+    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
+    ///               taken from the time the node became active, otherwise node must be complete by
+    ///               the time given.
+
+    ecf::LateAttr lateAttr;
+    lateAttr.addComplete(ecf::TimeSlot(0, 15), true);
+
+    // set active state at 00:00:00
+    //   cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
+    std::pair<NState, boost::posix_time::time_duration> state =
+        std::make_pair(NState(NState::ACTIVE), calendar.duration());
+
+    // after 15 minutes relative, if we are not complete, we should be late
+    for (int m = 1; m < 23; m++) {
+        calendar.update(time_duration(minutes(1)));
+        //      cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+
+        lateAttr.checkForLateness(state, calendar);
+        //      if (lateAttr.isLate()) {
+        //         cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+        //      }
+
+        if (m >= 15) {
+            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
+                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_late_attr_complete_real) {
+    cout << "ANattr:: ...test_late_attr_complete_real\n";
+
+    Calendar calendar;
+    calendar.init(ptime(date(2013, 7, 9), minutes(0)), Calendar::REAL); // tuesday
+
+    /// -s submitted: The time node can stay submitted (format [+]hh:mm). submitted is always
+    ///               relative, so + is simple ignored, if present. If the node stays submitted
+    ///               longer than the time specified, the late flag is set
+    /// -a Active   : The time of day the node must have become active (format hh:mm). If the node
+    ///               is still queued or submitted, the late flag is set
+    /// -c Complete : The time node must become complete (format {+}hh:mm). If relative, time is
+    ///               taken from the time the node became active, otherwise node must be complete by
+    ///               the time given.
+
+    ecf::LateAttr lateAttr;
+    lateAttr.addComplete(ecf::TimeSlot(3, 0), false);
+
+    // set active state at 00:00:00
+    //   cout << "start:" << to_simple_string(calendar.suiteTime()) << "\n";
+    std::pair<NState, boost::posix_time::time_duration> state =
+        std::make_pair(NState(NState::ACTIVE), calendar.duration());
+
+    // after 3 hours we, if we are not complete, we should be late
+    for (int m = 1; m < 7; m++) {
+
+        calendar.update(time_duration(hours(1)));
+        //      cout << "m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+
+        lateAttr.checkForLateness(state, calendar);
+        //      if (lateAttr.isLate()) {
+        //         cout << "late at m=" << m << " " << to_simple_string(calendar.suiteTime()) << "\n";
+        //      }
+
+        if (m >= 3) {
+            BOOST_CHECK_MESSAGE(lateAttr.isLate(),
+                                " expected to be late at " << to_simple_string(calendar.suiteTime()));
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_late_parsing) {
+    cout << "ANattr:: ...test_late_parsing\n";
+    TimeSlot start(10, 10);
+    TimeSlot finish(23, 10);
+    {
+        LateAttr late;
+        LateAttr parsedlate;
+        BOOST_CHECK_MESSAGE(late == parsedlate,
+                            "Expected " << late.toString() << " but found " << parsedlate.toString());
+    }
+    {
+        LateAttr late;
+        late.addSubmitted(start);
+        LateAttr parsedLate = LateAttr::create("late -s 10:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+        parsedLate = LateAttr::create("-s 10:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+    }
+    {
+        LateAttr late;
+        late.addActive(finish);
+        LateAttr parsedLate = LateAttr::create("late -a 23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+        parsedLate = LateAttr::create("-a 23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+    }
+    {
+        LateAttr late;
+        late.addComplete(finish, false);
+        LateAttr parsedLate = LateAttr::create("late -c 23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+        parsedLate = LateAttr::create("-c 23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+    }
+    {
+        LateAttr late;
+        late.addComplete(finish, true);
+        LateAttr parsedLate = LateAttr::create("late -c +23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+        parsedLate = LateAttr::create("-c +23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+    }
+    {
+        LateAttr late;
+        late.addComplete(finish, true);
+        LateAttr parsedLate = LateAttr::create("late -c +23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+        parsedLate = LateAttr::create("-c +23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+    }
+    {
+        LateAttr late;
+        late.addSubmitted(start);
+        late.addActive(finish);
+        late.addComplete(finish, true);
+        LateAttr parsedLate = LateAttr::create("late -s 10:10 -a 23:10 -c +23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+        parsedLate = LateAttr::create("-s 10:10 -a 23:10 -c +23:10");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+    }
+    {
+        LateAttr late;
+        late.addSubmitted(start);
+        late.addActive(finish);
+        late.addComplete(finish, true);
+        LateAttr parsedLate = LateAttr::create("late -c +23:10 -s 10:10 -a 23:10 ");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+        parsedLate = LateAttr::create("-c +23:10 -s 10:10 -a 23:10 ");
+        BOOST_CHECK_MESSAGE(late == parsedLate,
+                            "Expected " << late.toString() << " but found " << parsedLate.toString());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_late_parsing_errors) {
+    cout << "ANattr:: ...test_late_parsing_errors\n";
+    BOOST_REQUIRE_THROW((void)LateAttr::create(""), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late 10:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -s 100:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -s 10:107"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("10:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -a"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("-a"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("-c"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("-s"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c -s 10:10 -a 23:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -s -a 23:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:105 -s 10:10 -a 23:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -c +23:10 -s 10:10 -a 23:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -s 10:10 -a 23:10 -a 23:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c +23:10 -s 10:10  -s 10:10 -a 23:10"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late -c -s -a"), std::runtime_error);
+    BOOST_REQUIRE_THROW((void)LateAttr::create("late +23:10 10:10 23:10"), std::runtime_error);
+
+    BOOST_CHECK_THROW((void)LateAttr::create("late  -a 23:11 -c"), std::runtime_error);
+    BOOST_CHECK_THROW((void)LateAttr::create("late -c +23:10 -s 10:10 -a"), std::runtime_error);
+    BOOST_CHECK_THROW((void)LateAttr::create("late -c +23:10 -s 10:10 -a 11:11 -s"), std::runtime_error);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestMigration.cpp 5.13.0-1/libs/attribute/test/TestMigration.cpp
--- 5.12.4-1/libs/attribute/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestMigration.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,345 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestSerialisation.hpp"
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/ClockAttr.hpp"
+#include "ecflow/attribute/CronAttr.hpp"
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/attribute/RepeatAttr.hpp"
+#include "ecflow/attribute/TimeAttr.hpp"
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/TimeSlot.hpp"
+#include "ecflow/core/cereal_boost_time.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+// #define UPDATE_TESTS 1
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_Migration)
+
+// These test are used for future release. They help to ensure that we have
+// backward compatibility.i.e future release can open file, created by an earlier release
+//
+BOOST_AUTO_TEST_CASE(test_migration_restore_def_con) {
+    cout << "ANattr:: ...test_migration_restore_def_con\n";
+
+    std::string file_name =
+        File::test_data("libs/attribute/test/data/migration/default_constructor_1_2_2/", "libs/attribute");
+    // BOOST_CHECK_MESSAGE(File::createDirectories(file_name ),"Could not create directory " << file_name);
+
+    // Create migration data
+#ifdef UPDATE_TESTS
+    doSave(file_name + "VerifyAttr", VerifyAttr());
+    doSave(file_name + "TodayAttr", TodayAttr());
+    doSave(file_name + "TimeAttr", TimeAttr());
+    doSave(file_name + "RepeatDate", RepeatDate());
+    doSave(file_name + "RepeatDateList", RepeatDateList());
+    doSave(file_name + "RepeatInteger", RepeatInteger());
+    doSave(file_name + "RepeatEnumerated", RepeatEnumerated());
+    doSave(file_name + "RepeatString", RepeatString());
+    doSave(file_name + "LateAttr", LateAttr());
+    doSave(file_name + "DayAttr", DayAttr());
+    doSave(file_name + "DateAttr", DateAttr());
+    doSave(file_name + "CronAttr", CronAttr());
+    doSave(file_name + "ClockAttr", ClockAttr());
+    doSave(file_name + "AutoCancelAttr", AutoCancelAttr());
+    doSave(file_name + "AutoArchiveAttr", AutoArchiveAttr());
+    doSave(file_name + "Label", Label());
+    doSave(file_name + "Variable", Variable());
+    doSave(file_name + "Event", Event());
+    doSave(file_name + "Meter", Meter());
+    doSave(file_name + "ZombieAttr", ZombieAttr());
+    doSave(file_name + "QueueAttr", QueueAttr());
+    doSave(file_name + "GenericAttr", GenericAttr());
+#endif
+
+    do_restore<VerifyAttr>(file_name + "VerifyAttr", VerifyAttr());
+    do_restore<TodayAttr>(file_name + "TodayAttr", TodayAttr());
+    do_restore<TimeAttr>(file_name + "TimeAttr", TimeAttr());
+    do_restore<RepeatDate>(file_name + "RepeatDate", RepeatDate());
+    do_restore<RepeatDateList>(file_name + "RepeatDateList", RepeatDateList());
+    do_restore<RepeatInteger>(file_name + "RepeatInteger", RepeatInteger());
+    do_restore<RepeatEnumerated>(file_name + "RepeatEnumerated", RepeatEnumerated());
+    do_restore<RepeatString>(file_name + "RepeatString", RepeatString());
+    do_restore<LateAttr>(file_name + "LateAttr", LateAttr());
+    do_restore<DayAttr>(file_name + "DayAttr", DayAttr());
+    do_restore<DateAttr>(file_name + "DateAttr", DateAttr());
+    do_restore<CronAttr>(file_name + "CronAttr", CronAttr());
+    do_restore<AutoCancelAttr>(file_name + "AutoCancelAttr", AutoCancelAttr());
+    do_restore<AutoArchiveAttr>(file_name + "AutoArchiveAttr", AutoArchiveAttr());
+    do_restore<Label>(file_name + "Label", Label());
+    do_restore<Variable>(file_name + "Variable", Variable());
+    do_restore<Event>(file_name + "Event", Event());
+    do_restore<Meter>(file_name + "Meter", Meter());
+    do_restore<ZombieAttr>(file_name + "ZombieAttr", ZombieAttr());
+    do_restore<QueueAttr>(file_name + "QueueAttr", QueueAttr());
+    do_restore<GenericAttr>(file_name + "GenericAttr", GenericAttr());
+}
+
+BOOST_AUTO_TEST_CASE(test_migration_restore) {
+    cout << "ANattr:: ...test_migration_restore\n";
+
+    std::string file_name = File::test_data("libs/attribute/test/data/migration/1_2_2/", "libs/attribute");
+    // BOOST_CHECK_MESSAGE(File::createDirectories(file_name ),"Could not create directory " << file_name);
+
+    std::vector<std::string> theVec;
+    theVec.emplace_back("a");
+    theVec.emplace_back("b");
+    LateAttr lateattr;
+    lateattr.addSubmitted(TimeSlot(10, 12));
+    lateattr.addActive(TimeSlot(10, 12));
+    lateattr.addComplete(TimeSlot(10, 12), true);
+
+    CronAttr cron_attr;
+    std::vector<int> weekDays;
+    weekDays.push_back(1);
+    weekDays.push_back(2);
+    std::vector<int> daysOfMonth;
+    daysOfMonth.push_back(1);
+    daysOfMonth.push_back(2);
+    std::vector<int> months;
+    months.push_back(1);
+    months.push_back(2);
+    cron_attr.addWeekDays(weekDays);
+    cron_attr.addDaysOfMonth(daysOfMonth);
+    cron_attr.addMonths(months);
+    cron_attr.addTimeSeries(TimeSlot(0, 0), TimeSlot(20, 0), TimeSlot(0, 1));
+
+    ClockAttr clock_attr(false);
+    clock_attr.date(1, 1, 2009);
+    clock_attr.set_gain_in_seconds(3600);
+
+    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
+
+    Label label("name", "value");
+    label.set_new_value("new_value");
+
+#ifdef UPDATE_TESTS
+    // Create migration data
+    doSave(file_name + "VerifyAttr", VerifyAttr(NState::COMPLETE, 3));
+    doSave(file_name + "TodayAttr", TodayAttr(10, 12));
+    doSave(file_name + "TimeAttr", TimeAttr(10, 12));
+    doSave(file_name + "RepeatDate", RepeatDate("date", 20110112, 20110115));
+    doSave(file_name + "RepeatDateList", RepeatDateList("datelist", {19990101, 19990102}));
+    doSave(file_name + "RepeatInteger", RepeatInteger("integer", 0, 100, 2));
+    doSave(file_name + "RepeatEnumerated", RepeatEnumerated("enum", theVec));
+    doSave(file_name + "RepeatString", RepeatString("string", theVec));
+    doSave(file_name + "LateAttr", lateattr);
+    doSave(file_name + "DayAttr", DayAttr(DayAttr::MONDAY));
+    doSave(file_name + "DateAttr", DateAttr(12, 12, 2012));
+    doSave(file_name + "CronAttr", cron_attr);
+    doSave(file_name + "ClockAttr", clock_attr);
+    doSave(file_name + "AutoCancelAttr", AutoCancelAttr(100));
+    doSave(file_name + "AutoCancelAttr_1", AutoCancelAttr(TimeSlot(10, 12), true));
+    doSave(file_name + "AutoArchiveAttr", AutoArchiveAttr(100));
+    doSave(file_name + "AutoArchiveAttr_1", AutoArchiveAttr(TimeSlot(10, 12), true));
+    doSave(file_name + "Label", label);
+    //   doSave(file_name + "Limit",limit);
+    doSave(file_name + "Variable", Variable("var_name", "var_value"));
+    doSave(file_name + "Event_1", Event(1));
+    doSave(file_name + "Event_2", Event("event"));
+    doSave(file_name + "Event_3", Event(1, "event", true));
+    doSave(file_name + "Meter", Meter("meter", 10, 100, 100));
+    doSave(file_name + "ZombieAttr", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB));
+    doSave(file_name + "ZombieAttr1", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 500));
+    doSave(file_name + "QueueAttr", QueueAttr("queue", theVec));
+    doSave(file_name + "GenericAttr", GenericAttr("gen1", theVec));
+#endif
+
+    do_restore<VerifyAttr>(file_name + "VerifyAttr", VerifyAttr(NState::COMPLETE, 3));
+    do_restore<TodayAttr>(file_name + "TodayAttr", TodayAttr(10, 12));
+    do_restore<TimeAttr>(file_name + "TimeAttr", TimeAttr(10, 12));
+    do_restore<RepeatDate>(file_name + "RepeatDate", RepeatDate("date", 20110112, 20110115));
+    do_restore<RepeatDateList>(file_name + "RepeatDateList", RepeatDateList("datelist", {19990101, 19990102}));
+    do_restore<RepeatInteger>(file_name + "RepeatInteger", RepeatInteger("integer", 0, 100, 2));
+    do_restore<RepeatEnumerated>(file_name + "RepeatEnumerated", RepeatEnumerated("enum", theVec));
+    do_restore<RepeatString>(file_name + "RepeatString", RepeatString("string", theVec));
+    do_restore<LateAttr>(file_name + "LateAttr", lateattr);
+    do_restore<DayAttr>(file_name + "DayAttr", DayAttr(DayAttr::MONDAY));
+    do_restore<DateAttr>(file_name + "DateAttr", DateAttr(12, 12, 2012));
+    do_restore<CronAttr>(file_name + "CronAttr", cron_attr);
+    do_restore<ClockAttr>(file_name + "ClockAttr", clock_attr);
+    do_restore<AutoCancelAttr>(file_name + "AutoCancelAttr", AutoCancelAttr(100));
+    do_restore<AutoCancelAttr>(file_name + "AutoCancelAttr_1", AutoCancelAttr(TimeSlot(10, 12), true));
+    do_restore<AutoArchiveAttr>(file_name + "AutoArchiveAttr", AutoArchiveAttr(100));
+    do_restore<AutoArchiveAttr>(file_name + "AutoArchiveAttr_1", AutoArchiveAttr(TimeSlot(10, 12), true));
+    do_restore<Label>(file_name + "Label", label);
+    do_restore<Variable>(file_name + "Variable", Variable("var_name", "var_value"));
+    do_restore<Event>(file_name + "Event_1", Event(1));
+    do_restore<Event>(file_name + "Event_2", Event(string("event")));
+    do_restore<Event>(file_name + "Event_3", Event(1, string("event"), true));
+    do_restore<Meter>(file_name + "Meter", Meter("meter", 10, 100, 100));
+    do_restore<ZombieAttr>(file_name + "ZombieAttr", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB));
+    do_restore<ZombieAttr>(file_name + "ZombieAttr1", ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 500));
+    do_restore<QueueAttr>(file_name + "QueueAttr", QueueAttr("queue", theVec));
+    do_restore<GenericAttr>(file_name + "GenericAttr", GenericAttr("gen1", theVec));
+}
+
+// The following test shows that CEREAL ignores new data members it does not recognise.
+// This allows new data members, which will be ignored by the old client.
+// OLD server to NEW Client(GUI), will not be a problem, since the the new data members are conditional.
+// In ecflow 5.4.0/5.5.0 we added a new data members to the DayAttribute class.
+// This test shows that when NEW SERVER send DayAttr to OLD Client(GUI), this new data member is ignored.
+namespace version_old {
+class DayAttr {
+public:
+    enum Day_t { SUNDAY = 0, MONDAY = 1, TUESDAY = 2, WEDNESDAY = 3, THURSDAY = 4, FRIDAY = 5, SATURDAY = 6 };
+    DayAttr() = default;
+    explicit DayAttr(Day_t day) : day_(day) {}
+    bool operator==(const DayAttr& rhs) const { return day_ == rhs.day() && free_ == rhs.free(); }
+
+    DayAttr::Day_t day() const { return day_; }
+    bool free() const { return free_; }
+    void set_free() { free_ = true; }
+
+private:
+    DayAttr::Day_t day_{DayAttr::SUNDAY};
+    bool free_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar) {
+        ar(CEREAL_NVP(day_));
+        CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
+    }
+};
+} // namespace version_old
+
+namespace version_new_data_member {
+class DayAttr {
+public:
+    enum Day_t { SUNDAY = 0, MONDAY = 1, TUESDAY = 2, WEDNESDAY = 3, THURSDAY = 4, FRIDAY = 5, SATURDAY = 6 };
+    DayAttr() = default;
+    explicit DayAttr(Day_t day) : day_(day) {}
+    bool operator==(const DayAttr& rhs) const {
+        return day_ == rhs.day_ && expired_ == rhs.expired() && free_ == rhs.free() && date_ == rhs.date_;
+    }
+
+    DayAttr::Day_t day() const { return day_; }
+    bool expired() const { return expired_; }
+    bool free() const { return free_; }
+    boost::gregorian::date date() const { return date_; }
+
+    void set_free() { free_ = true; }
+    void set_expired() { expired_ = true; }
+    void set_date(boost::gregorian::date date) { date_ = std::move(date); }
+
+private:
+    DayAttr::Day_t day_{DayAttr::SUNDAY};
+    bool free_{false};
+    bool expired_{false};         // new data member 5.4.0
+    boost::gregorian::date date_; // new data member 5.5.0
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar) {
+        ar(CEREAL_NVP(day_));
+        CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; });       // conditionally save
+        CEREAL_OPTIONAL_NVP(ar, expired_, [this]() { return expired_; }); // conditionally save
+        CEREAL_OPTIONAL_NVP(
+            ar, date_, [this]() { return !date_.is_special(); }); // conditionally save, new to ecflow 5.5.0,
+    }
+};
+} // namespace version_new_data_member
+
+BOOST_AUTO_TEST_CASE(test_day_migration) {
+    cout << "ANattr:: ...test_day_migration\n";
+    // OLD -> NEW  i.e OLD SERVER --> NEW CLIENT
+    {
+        const version_old::DayAttr t = version_old::DayAttr();
+        ecf::save("test_day_migration", t);
+    }
+    {
+        version_new_data_member::DayAttr t;
+        ecf::restore("test_day_migration", t);
+        BOOST_CHECK_MESSAGE(t == version_new_data_member::DayAttr(), "Should be the same");
+    }
+
+    // NEW->OLD  i.e NEW SERVER --> OLD CLIENT
+    // IMPORTANT: This shows that CEREAL ignore data members is does NOT RECOGNIZE.
+    {
+        version_new_data_member::DayAttr def;
+        ecf::save("test_day_migration_def", def);
+
+        version_new_data_member::DayAttr def_free;
+        def_free.set_free();
+        ecf::save("test_day_migration_free", def_free);
+
+        version_new_data_member::DayAttr def_expired;
+        def_expired.set_expired();
+        ecf::save("test_day_migration_expired", def_expired);
+
+        version_new_data_member::DayAttr def_free_and_expired;
+        def_free_and_expired.set_expired();
+        def_free_and_expired.set_free();
+        ecf::save("test_day_migration_free_and_expired", def_free_and_expired);
+
+        version_new_data_member::DayAttr def_free_expired_date;
+        def_free_expired_date.set_expired();
+        def_free_expired_date.set_free();
+        def_free_expired_date.set_date(boost::gregorian::date(2020, 06, 28)); // sunday
+        ecf::save("test_day_migration_free_expired_date", def_free_expired_date);
+    }
+    {
+        version_old::DayAttr def = version_old::DayAttr();
+        ecf::restore("test_day_migration_def", def);
+        BOOST_CHECK_MESSAGE(def == version_old::DayAttr(), "Should be the same");
+
+        version_old::DayAttr def_free = version_old::DayAttr();
+        ecf::restore("test_day_migration_free", def_free);
+        version_old::DayAttr cdef_free;
+        cdef_free.set_free();
+        BOOST_CHECK_MESSAGE(def_free == cdef_free, "Should be the same");
+
+        version_old::DayAttr def_expired = version_old::DayAttr();
+        ecf::restore("test_day_migration_expired", def_expired);
+        BOOST_CHECK_MESSAGE(def_expired == version_old::DayAttr(), "No expired, should be same as default");
+
+        version_old::DayAttr def_free_and_expired = version_old::DayAttr();
+        ecf::restore("test_day_migration_free_and_expired", def_free_and_expired);
+        BOOST_CHECK_MESSAGE(def_free_and_expired == cdef_free, "No expired,But free should be set,Should be the same");
+
+        version_old::DayAttr def_free_expired_date = version_old::DayAttr();
+        ecf::restore("test_day_migration_free_expired_date", def_free_expired_date);
+        BOOST_CHECK_MESSAGE(def_free_and_expired == cdef_free,
+                            "No expired,No date,But free should be set,Should be the same");
+    }
+
+    // remove the generated filea, comment out to debug.
+    fs::remove("test_day_migration");
+    fs::remove("test_day_migration_def");
+    fs::remove("test_day_migration_free");
+    fs::remove("test_day_migration_expired");
+    fs::remove("test_day_migration_free_and_expired");
+    fs::remove("test_day_migration_free_expired_date");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestRepeat.cpp 5.13.0-1/libs/attribute/test/TestRepeat.cpp
--- 5.12.4-1/libs/attribute/test/TestRepeat.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestRepeat.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1220 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/RepeatAttr.hpp"
+#include "ecflow/core/Cal.hpp"
+#include "ecflow/core/Converter.hpp"
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+static const std::vector<std::string> stringList = {std::string("a"), std::string("b"), std::string("c")};
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_Repeat)
+
+/*
+ * Test Suite: ::test_repeat
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat)
+
+BOOST_AUTO_TEST_CASE(invariants) {
+    cout << "ANattr:: ...TestRepeat::invariants\n";
+
+    // Test the invariant that non-empty repeat must have a name
+    Repeat empty;
+    Repeat empty2;
+    BOOST_CHECK_MESSAGE(empty.empty(), "Construction");
+    BOOST_CHECK_MESSAGE(empty.name().empty(), "Construction");
+    BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
+}
+
+BOOST_AUTO_TEST_CASE(construction) {
+    cout << "ANattr:: ...TestRepeat::construction\n";
+
+    Repeat empty;
+
+    Repeat another(empty);
+    BOOST_CHECK_MESSAGE(another == empty, "Copy construction failed");
+
+    BOOST_CHECK_MESSAGE(empty.name() == string(), " empty  failed");
+    BOOST_CHECK_MESSAGE(empty.valid() == false, " empty  failed");
+    BOOST_CHECK_MESSAGE(empty.value() == 0, " empty  failed");
+    empty.setToLastValue();
+    BOOST_CHECK_MESSAGE(empty.valueAsString() == string(), " empty  failed");
+    empty.reset();
+    empty.increment();
+    empty.change("fred");
+    BOOST_CHECK_MESSAGE(empty.valueAsString() == string(), " empty  failed");
+    empty.changeValue(10);
+    BOOST_CHECK_MESSAGE(empty.valueAsString() == string(), " empty  failed");
+    BOOST_CHECK_MESSAGE(empty.isInfinite() == false, " empty  failed");
+    BOOST_CHECK_MESSAGE(empty.toString() == string(), " empty  failed");
+    BOOST_CHECK_MESSAGE(empty.state_change_no() == 0, " empty  failed");
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat
+
+/*
+ * Test Suite: ::test_repeat_datelist
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat_datelist)
+
+BOOST_AUTO_TEST_CASE(invariants) {
+    cout << "ANattr:: ...test_repeat_datelist::invariants\n";
+
+    {
+        Repeat rep(RepeatDateList("YMD", {20190929, 20190131}));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.start() == 20190929, "Start should be 20190929");
+        BOOST_CHECK_MESSAGE(rep.end() == 20190131, "end should be 20190131");
+        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
+        BOOST_CHECK_MESSAGE(rep.value() == 20190929, "value should be 20190929");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190929, "last_valid_value should be 20190929");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20190929", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20190131", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20190929", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value_minus(1) == 20190928,
+                            "expected 20190928 but found " << rep.last_valid_value_minus(1));
+        BOOST_CHECK_MESSAGE(rep.last_valid_value_plus(1) == 20190930,
+                            "expected 20190930 but found " << rep.last_valid_value_minus(1));
+        BOOST_CHECK_MESSAGE(rep.last_valid_value_plus(2) == 20191001,
+                            "expected 20191001 but found " << rep.last_valid_value_minus(1));
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(cloned.name() == "YMD", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.start() == 20190929, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.end() == 20190131, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.value() == 20190929, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "20190929", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 20190929, "last_valid_value should be 20190929");
+        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "20190131", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "20190929", "not as expected");
+
+        RepeatDateList empty;
+        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
+        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
+        BOOST_CHECK_MESSAGE(empty.step() == 1, "step should be 1");
+        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
+        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
+        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
+        BOOST_CHECK_MESSAGE(empty.valueAsString() == "0", "expected 0 but found " << empty.valueAsString());
+        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "0",
+                            "expected 0 but found " << empty.next_value_as_string());
+        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "0",
+                            "expected 0 but found " << empty.prev_value_as_string());
+    }
+    {
+        Repeat rep(RepeatDateList("YMD", {20190929, 20190131}));
+        BOOST_CHECK_MESSAGE(rep.start() == 20190929, "Start should be 20190929");
+        BOOST_CHECK_MESSAGE(rep.end() == 20190131, "end should be  20190131");
+        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
+        BOOST_CHECK_MESSAGE(rep.value() == 20190929, "value should be 20190929");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190929, "last valid value should be 20190929");
+        rep.increment();
+        BOOST_CHECK_MESSAGE(rep.valid(), "RepeatDateList should be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 20190131, "value should be 20190131 ");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190131, "last_valid_value should be 20190131 ");
+        rep.increment();
+        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDateList should not be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 0, "expected 0 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20190131,
+                            "expected 20190131 but found " << rep.last_valid_value());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat_datelist
+
+/*
+ * Test Suite: ::test_repeat_date
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat_date)
+
+BOOST_AUTO_TEST_CASE(invariants) {
+    cout << "ANattr:: ...test_repeat_date::invariants\n";
+
+    {
+        Repeat rep(RepeatDate("YMD", 20090916, 20090930, 1));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.end() == 20090930, "end should be 20090930");
+        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
+        BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090916", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090917", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090916", "not as expected");
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(cloned.name() == "YMD", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.start() == 20090916, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.end() == 20090930, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.value() == 20090916, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "20090916", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 20090916, "last_valid_value should be 20090916");
+        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "20090917", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "20090916", "not as expected");
+
+        RepeatDate empty;
+        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
+        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
+        BOOST_CHECK_MESSAGE(empty.step() == 0, "step should be 0");
+        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
+        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
+        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
+        BOOST_CHECK_MESSAGE(empty.valueAsString() == "0", "expected 0 but found " << empty.valueAsString());
+        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "0",
+                            "expected 0 but found " << empty.next_value_as_string());
+        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "0",
+                            "expected 0 but found " << empty.prev_value_as_string());
+    }
+    {
+        Repeat rep(RepeatDate("YMD", 20090930, 20090916, -1));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.start() == 20090930, "Start should be 20090930");
+        BOOST_CHECK_MESSAGE(rep.end() == 20090916, "end should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.step() == -1, "step should be -1");
+        BOOST_CHECK_MESSAGE(rep.value() == 20090930, "value should be 20090930");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090930, "last_valid_value should be 20090930");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090930", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090929",
+                            "expected 20090929 but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090930",
+                            "expected 20090930 but found " << rep.prev_value_as_string());
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(cloned.name() == "YMD", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.start() == 20090930, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.end() == 20090916, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.step() == -1, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.value() == 20090930, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "20090930", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 20090930, "last_valid_value should be 20090930");
+    }
+    {
+        Repeat rep(RepeatDate("YMD", 20090916, 20090916, 1));
+        BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.end() == 20090916, "end should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
+        BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "delta should be 20090916");
+        rep.increment();
+        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDate should not be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 20090917, "value should be 20090917");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
+    }
+    {
+        Repeat rep(RepeatDate("YMD", 20090916, 20090916, -1));
+        BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.end() == 20090916, "end should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.step() == -1, "step should be -1");
+        BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
+        rep.increment();
+        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDate should not be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 20090915, "value should be 20090915");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(construction) {
+    cout << "ANattr:: ...test_repeat_date::construction\n";
+
+    Repeat empty;
+    {
+        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
+        Repeat l2(RepeatDate("YMD", 20090916, 20090930, 1));
+        BOOST_CHECK_MESSAGE(!l1.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(!l2.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
+        BOOST_CHECK_MESSAGE(!(l1 == empty), "Equality failed");
+
+        Repeat l1a(RepeatDate("YMD", 20090930, 20090916, -1));
+        Repeat l2a(RepeatDate("YMD", 20090930, 20090916, -1));
+        BOOST_CHECK_MESSAGE(!l1a.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(!l2a.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(l1a == l2a, "Equality failed");
+        BOOST_CHECK_MESSAGE(!(l1a == empty), "Equality failed");
+
+        l1.clear();
+        l2.clear();
+
+        BOOST_CHECK_MESSAGE(l1 == empty, "Clear failed");
+        BOOST_CHECK_MESSAGE(l2 == empty, "Clear failed");
+    }
+
+    {
+        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
+        Repeat l2;
+        l2 = l1;
+        BOOST_CHECK_MESSAGE(l1 == l2, "Assignment failed");
+
+        l2 = empty;
+        BOOST_CHECK_MESSAGE(l2 == empty, "Assignment failed");
+    }
+
+    {
+        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
+        Repeat l2 = l1;
+        BOOST_CHECK_MESSAGE(l1 == l2, "Copy construction failed");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(move_semantics) {
+    cout << "ANattr:: ...test_repeat_date::move_semantics\n";
+
+    {
+        Repeat x;
+        BOOST_CHECK_MESSAGE(x.empty(), "Construction failed");
+
+        Repeat l1(RepeatDate("YMD", 20090916, 20090930, 1));
+        x = l1;
+        BOOST_CHECK_MESSAGE(!x.empty(), "copy assignment failed");
+        BOOST_CHECK_MESSAGE(x == l1, "Equality failed, after copy assignment");
+        x = std::move(l1);
+        BOOST_CHECK_MESSAGE(!x.empty(), "move assignment failed");
+        BOOST_CHECK_MESSAGE(l1.empty(), "move assignment failed");
+    }
+    {
+        Repeat r1(RepeatDate("YMD", 20090916, 20090930, 1));
+        Repeat r2 = Repeat(r1); // copy construction
+        BOOST_CHECK_MESSAGE(!r1.empty(), " copy construction failed");
+        BOOST_CHECK_MESSAGE(!r2.empty(), " copy construction failed");
+        BOOST_CHECK_MESSAGE(r1 == r2, "Equality failed, after copy construction");
+
+        Repeat r3 = Repeat(std::move(r1)); // move construction
+        BOOST_CHECK_MESSAGE(r1.empty(), "move construction failed");
+        BOOST_CHECK_MESSAGE(r2 == r3, "Equality failed, after move construction");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(last_value) {
+    cout << "ANattr:: ...test_repeat_date::last_value \n";
+
+    {
+        Repeat rep(RepeatDate("YMD", 20090916, 20090930, 1));
+        rep.update_repeat_genvar();
+        const Variable& gen_var = rep.find_gen_variable("YMD_JULIAN");
+        int old_value           = gen_var.value();
+        rep.setToLastValue();
+        int new_value = gen_var.value();
+
+        BOOST_CHECK_MESSAGE(rep.value() == 20090930,
+                            "Set to last value did not work, expected 20090930 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090930",
+                            "Set to last value did not work, expected '20090930' but found " << rep.valueAsString());
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090930",
+                            "next_value_as_string() did not work, expected 20090930 but found "
+                                << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090929",
+                            "prev_value_as_string() did not work, expected 20090929 but found "
+                                << rep.prev_value_as_string());
+        BOOST_CHECK_MESSAGE(old_value != new_value, "Expected to update the generated variables ");
+    }
+    {
+        Repeat rep(RepeatDate("YMD", 20090930, 20090916, -1));
+        rep.setToLastValue();
+        BOOST_CHECK_MESSAGE(rep.value() == 20090916,
+                            "Set to last value did not work, expected 20090916 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20090916",
+                            "Set to last value did not work, expected '20090916' but found " << rep.valueAsString());
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20090916",
+                            "next_value_as_string() did not work, expected 20090916 but found "
+                                << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20090917",
+                            "prev_value_as_string() did not work, expected 20090917 but found "
+                                << rep.prev_value_as_string());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(increment) {
+    cout << "ANattr:: ...test_repeat_date::increment \n";
+
+    {
+        Repeat rep(RepeatDate("YMD", 20090916, 20090920, 1));
+        rep.update_repeat_genvar();
+        const Variable& gen_var  = rep.find_gen_variable("YMD_JULIAN");
+        const Variable& gen_var2 = rep.find_gen_variable("YMD_DOW");
+        int old_value            = gen_var.value();
+        int old_value2           = gen_var2.value();
+
+        while (rep.valid()) {
+            rep.increment();
+        }
+
+        BOOST_CHECK_MESSAGE(rep.value() == 20090921, "expected 20090921 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090920,
+                            "expected 20090920 but found " << rep.last_valid_value());
+        BOOST_CHECK_MESSAGE(old_value != gen_var.value(), "Expected generated variables to change on increment");
+        BOOST_CHECK_MESSAGE(old_value2 != gen_var2.value(), "Expected generated variables to change on increment");
+
+        rep.reset();
+        BOOST_CHECK_MESSAGE(old_value = gen_var.value(), "Expected generated variables to be the same after reset");
+        BOOST_CHECK_MESSAGE(old_value2 = gen_var2.value(), "Expected generated variables to be the same after reset");
+    }
+    {
+        Repeat rep(RepeatDate("YMD", 20090920, 20090916, -1));
+        while (rep.valid()) {
+            rep.increment();
+        }
+        BOOST_CHECK_MESSAGE(rep.value() == 20090915, "expected 20090915 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916,
+                            "expected 20090916 but found " << rep.last_valid_value());
+    }
+    {
+        Repeat rep(RepeatDate("YMD", 20150514, 20150730, 7));
+        while (rep.valid()) {
+            rep.increment();
+            // cout << "YMD: " << rep.value() << "\n";
+        }
+        BOOST_CHECK_MESSAGE(rep.value() == 20150806, "expected 20150806 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20150730,
+                            "expected 20150730 but found " << rep.last_valid_value());
+    }
+    {
+        Repeat rep(RepeatDate("YMD", 20150730, 20150514, -7));
+        while (rep.valid()) {
+            rep.increment();
+            // cout << "YMD: " << rep.value() << "\n";
+        }
+        BOOST_CHECK_MESSAGE(rep.value() == 20150507, "expected 20150507 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20150514,
+                            "expected 20150514 but found " << rep.last_valid_value());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(handling_errors) {
+    cout << "ANattr:: ...test_repeat_date:handling_errors \n";
+
+    BOOST_REQUIRE_THROW(RepeatDate("", 20090916, 20090920, 1), std::runtime_error);
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 200909161, 20090920, 1), std::runtime_error); // start > 8
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 200909201, 1), std::runtime_error); // end > 8
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090016, 200909201, 1), std::runtime_error); // invalid start month
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090900, 20090920, 1), std::runtime_error);  // invalid start day
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090020, 1), std::runtime_error);  // invalid end month
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090900, 1), std::runtime_error);  // invalid end day
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090920, 0), std::runtime_error);  // delta cannot be zero
+
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090920, 20090916, 1),
+                        std::runtime_error); //  start day > end day, and delta > 0
+    BOOST_REQUIRE_THROW(RepeatDate("YMD", 20090916, 20090920, -1),
+                        std::runtime_error); //  start day < end day, and delta < 0
+
+    RepeatDate date("YMD", 20150514, 20150730, 7);
+    BOOST_REQUIRE_THROW(date.changeValue(20150513), std::runtime_error); // outside of range
+    BOOST_REQUIRE_THROW(date.changeValue(20150731), std::runtime_error); // outside of range
+    BOOST_REQUIRE_THROW(date.changeValue(20150801), std::runtime_error); // outside of range
+
+    BOOST_REQUIRE_THROW(date.changeValue(20150515), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150516), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150517), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150518), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150519), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150520), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150522), std::runtime_error); // not a valid step
+
+    RepeatDate date1("YMD", 20150730, 20150514, -7);
+    BOOST_REQUIRE_THROW(date1.changeValue(20150731), std::runtime_error); // outside of range
+    BOOST_REQUIRE_THROW(date1.changeValue(20150813), std::runtime_error); // outside of range
+    BOOST_REQUIRE_THROW(date1.changeValue(20150513), std::runtime_error); // outside of range
+    BOOST_REQUIRE_THROW(date1.changeValue(20150413), std::runtime_error); // outside of range
+
+    BOOST_REQUIRE_THROW(date.changeValue(20150729), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150728), std::runtime_error); // not a valid step
+    BOOST_REQUIRE_THROW(date.changeValue(20150515), std::runtime_error); // not a valid step
+}
+
+BOOST_AUTO_TEST_CASE(change_value) {
+    cout << "ANattr:: ...test_repeat_date::change_value \n";
+    {
+        Repeat rep2(RepeatDate("YMD", 20150514, 20150730, 7));
+        Repeat rep(RepeatDate("YMD", 20150514, 20150730, 7));
+        BOOST_CHECK_MESSAGE(rep.valid(), "expected valid at start ");
+
+        while (rep.valid()) {
+            rep2.change(boost::lexical_cast<std::string>(rep.value()));
+            BOOST_CHECK_MESSAGE(rep.value() == rep2.value(),
+                                "expected same value, but found " << rep.value() << "  " << rep2.value());
+            rep.increment();
+        }
+    }
+    {
+        Repeat rep2(RepeatDate("YMD", 20150730, 20150514, -7));
+        Repeat rep(RepeatDate("YMD", 20150730, 20150514, -7));
+        BOOST_CHECK_MESSAGE(rep.valid(), "expected valid at start ");
+
+        while (rep.valid()) {
+            rep2.change(boost::lexical_cast<std::string>(rep.value()));
+            BOOST_CHECK_MESSAGE(rep.value() == rep2.value(),
+                                "expected same value, but found " << rep.value() << "  " << rep2.value());
+            rep.increment();
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(generated_variables) {
+    cout << "ANattr:: ...test_repeat_date::generated_variables\n";
+
+    Repeat rep(RepeatDate("YMD", 20090916, 20090930, 1));
+    BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+    BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+    BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
+    BOOST_CHECK_MESSAGE(rep.start() == 20090916, "Start should be 20090916");
+    BOOST_CHECK_MESSAGE(rep.end() == 20090930, "end should be 20090930");
+    BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
+    BOOST_CHECK_MESSAGE(rep.value() == 20090916, "value should be 20090916");
+    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20090916, "last_valid_value should be 20090916");
+    rep.update_repeat_genvar();
+    std::vector<Variable> vec;
+    rep.gen_variables(vec);
+    BOOST_CHECK_MESSAGE(vec.size() == 6, "expected 6 generated variables but found " << vec.size());
+
+    {
+        const Variable& var = rep.find_gen_variable("YMD");
+        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
+        BOOST_CHECK_MESSAGE(var.theValue() == "20090916", "expected year to be 20090916  but found " << var.theValue());
+    }
+
+    {
+        const Variable& var = rep.find_gen_variable("YMD_YYYY");
+        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
+        BOOST_CHECK_MESSAGE(var.theValue() == "2009", "expected year to be 2009  but found " << var.theValue());
+    }
+
+    {
+        const Variable& var = rep.find_gen_variable("YMD_MM");
+        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_MM");
+        BOOST_CHECK_MESSAGE(var.theValue() == "9", "expected month to be 9  but found " << var.theValue());
+    }
+
+    {
+        const Variable& var = rep.find_gen_variable("YMD_DD");
+        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DD");
+        BOOST_CHECK_MESSAGE(var.theValue() == "16", "expected day of month to be 16 but found " << var.theValue());
+    }
+
+    {
+        const Variable& var = rep.find_gen_variable("YMD_DOW");
+        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DOW");
+        BOOST_CHECK_MESSAGE(var.theValue() == "3", "expected day of week to be 3 but found " << var.theValue());
+    }
+
+    {
+        const Variable& var = rep.find_gen_variable("YMD_JULIAN");
+        BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_JULIAN");
+        std::string expected = ecf::convert_to<std::string>(Cal::date_to_julian(20090916));
+        BOOST_CHECK_MESSAGE(var.theValue() == expected, "expected " << expected << " but found " << var.theValue());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(more_generated_variables) {
+    cout << "ANattr:: ...test_repeat_date::more_generated_variables\n";
+
+    int start = 20161231;
+    int end   = 20170106;
+    Repeat rep(RepeatDate("YMD", start, end, 1));
+    BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+    BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+    BOOST_CHECK_MESSAGE(rep.name() == "YMD", "name not as expected");
+    BOOST_CHECK_MESSAGE(rep.start() == start, "Start should be " << start);
+    BOOST_CHECK_MESSAGE(rep.end() == end, "end should be " << end << " but found " << rep.end());
+    BOOST_CHECK_MESSAGE(rep.step() == 1, "step should be 1");
+    BOOST_CHECK_MESSAGE(rep.value() == start, "value should be " << start << " but found " << rep.value());
+    BOOST_CHECK_MESSAGE(rep.last_valid_value() == start,
+                        "last_valid_value should be " << start << " but found " << rep.last_valid_value());
+
+    std::vector<std::string> expected_YMD;
+    expected_YMD.emplace_back("20161231");
+    expected_YMD.emplace_back("20170101");
+    expected_YMD.emplace_back("20170102");
+    expected_YMD.emplace_back("20170103");
+    expected_YMD.emplace_back("20170104");
+    expected_YMD.emplace_back("20170105");
+    expected_YMD.emplace_back("20170106");
+
+    std::vector<std::string> expected_year;
+    expected_year.emplace_back("2016");
+    expected_year.emplace_back("2017");
+    expected_year.emplace_back("2017");
+    expected_year.emplace_back("2017");
+    expected_year.emplace_back("2017");
+    expected_year.emplace_back("2017");
+    expected_year.emplace_back("2017");
+
+    std::vector<std::string> expected_MM;
+    expected_MM.emplace_back("12");
+    expected_MM.emplace_back("1");
+    expected_MM.emplace_back("1");
+    expected_MM.emplace_back("1");
+    expected_MM.emplace_back("1");
+    expected_MM.emplace_back("1");
+    expected_MM.emplace_back("1");
+
+    std::vector<std::string> expected_day_of_month;
+    expected_day_of_month.emplace_back("31");
+    expected_day_of_month.emplace_back("1");
+    expected_day_of_month.emplace_back("2");
+    expected_day_of_month.emplace_back("3");
+    expected_day_of_month.emplace_back("4");
+    expected_day_of_month.emplace_back("5");
+    expected_day_of_month.emplace_back("6");
+
+    std::vector<std::string> expected_day_of_week;
+    expected_day_of_week.emplace_back("6");
+    expected_day_of_week.emplace_back("0");
+    expected_day_of_week.emplace_back("1");
+    expected_day_of_week.emplace_back("2");
+    expected_day_of_week.emplace_back("3");
+    expected_day_of_week.emplace_back("4");
+    expected_day_of_week.emplace_back("5");
+
+    std::vector<std::string> expected_julian;
+    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20161231)));
+    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170101)));
+    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170102)));
+    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170103)));
+    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170104)));
+    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170105)));
+    expected_julian.push_back(ecf::convert_to<std::string>(Cal::date_to_julian(20170106)));
+
+    for (int i = 0; i < 7; i++) {
+
+        rep.update_repeat_genvar();
+        std::vector<Variable> vec;
+        rep.gen_variables(vec);
+        BOOST_CHECK_MESSAGE(vec.size() == 6, "expected 6 generated variables but found " << vec.size());
+
+        {
+            const Variable& var = rep.find_gen_variable("YMD");
+            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
+            BOOST_CHECK_MESSAGE(var.theValue() == expected_YMD[i],
+                                "expected YMD " << expected_YMD[i] << " but found " << var.theValue());
+        }
+
+        {
+            const Variable& var = rep.find_gen_variable("YMD_YYYY");
+            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_YYYY");
+            BOOST_CHECK_MESSAGE(var.theValue() == expected_year[i],
+                                "expected year to be " << expected_year[i] << " but found " << var.theValue());
+        }
+
+        {
+            const Variable& var = rep.find_gen_variable("YMD_MM");
+            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_MM");
+            BOOST_CHECK_MESSAGE(var.theValue() == expected_MM[i],
+                                "expected month to be " << expected_MM[i] << " but found " << var.theValue());
+        }
+
+        {
+            const Variable& var = rep.find_gen_variable("YMD_DD");
+            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DD");
+            BOOST_CHECK_MESSAGE(var.theValue() == expected_day_of_month[i],
+                                "expected day of month to be " << expected_day_of_month[i] << " but found "
+                                                               << var.theValue());
+        }
+
+        {
+            const Variable& var = rep.find_gen_variable("YMD_DOW");
+            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_DOW");
+            BOOST_CHECK_MESSAGE(var.theValue() == expected_day_of_week[i],
+                                "expected day of week to be " << expected_day_of_week[i] << " but found "
+                                                              << var.theValue());
+        }
+
+        {
+            const Variable& var = rep.find_gen_variable("YMD_JULIAN");
+            BOOST_CHECK_MESSAGE(!var.empty(), "Did not find generated variable YMD_JULIAN");
+            BOOST_CHECK_MESSAGE(var.theValue() == expected_julian[i],
+                                "expected " << expected_julian[i] << " but found " << var.theValue());
+        }
+
+        rep.increment();
+    }
+}
+
+BOOST_AUTO_TEST_CASE(convert_xref_to_boost_date) {
+    cout << "ANattr:: ...test_repeat_date::convert_xref_to_boost_date \n";
+
+    auto check_date = [](int start, int end, int delta) {
+        boost::gregorian::date bdate(from_undelimited_string(boost::lexical_cast<std::string>(start)));
+
+        Repeat rep(RepeatDate("YMD", start, end, delta));
+        Repeat rep2(RepeatDate("YMD", start, end, delta));
+        while (rep.valid()) {
+
+            // xref repeat date with boost date, essentially checking bdate with rep
+            string str_value = boost::lexical_cast<std::string>(rep.value());
+            boost::gregorian::date date2(from_undelimited_string(str_value));
+            BOOST_CHECK_MESSAGE(bdate == date2, "expected same value, but found " << bdate << "  " << date2);
+
+            // check change value
+            rep2.change(str_value);
+            BOOST_CHECK_MESSAGE(rep.value() == rep2.value(),
+                                "expected same value, but found " << rep.value() << "  " << rep2.value());
+
+            // increment repeat and boost date
+            rep.increment();
+            bdate += days(delta);
+        }
+    };
+
+    check_date(19800101, 20621231, 1);
+    check_date(19800101, 20621231, 7);
+    check_date(20621231, 19800101, -7);
+    check_date(20150514, 20150730, 7);
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat_date
+
+/*
+ * Test Suite: ::test_repeat_datetime
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat_datetime)
+
+BOOST_AUTO_TEST_CASE(invariants) {
+    cout << "ANattr:: ...test_repeat_datetime::invariants\n";
+
+    {
+        Repeat rep(RepeatDateTime("DT", "19700101T000001", "19700102T000001", "24:00:00"));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "DT", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.start() == 1, "Start should be 1");
+        BOOST_CHECK_MESSAGE(rep.end() == 86401, "end should be 86401");
+        BOOST_CHECK_MESSAGE(rep.step() == 86400, "step should be 1");
+        BOOST_CHECK_MESSAGE(rep.value() == 1, "value should be 1");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 1, "last_valid_value should be 1");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "19700101T000001", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "19700102T000001", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "19700101T000001", "not as expected");
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(cloned.name() == "DT", "name not as expected");
+        BOOST_CHECK_MESSAGE(cloned.start() == 1, "Start should be 1");
+        BOOST_CHECK_MESSAGE(cloned.end() == 86401, "end should be 86401");
+        BOOST_CHECK_MESSAGE(cloned.step() == 86400, "step should be 1");
+        BOOST_CHECK_MESSAGE(cloned.value() == 1, "value should be 1");
+        BOOST_CHECK_MESSAGE(cloned.last_valid_value() == 1, "last_valid_value should be 1");
+        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "19700101T000001", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "19700102T000001", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "19700101T000001", "not as expected");
+
+        RepeatDateTime empty;
+        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
+        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
+        BOOST_CHECK_MESSAGE(empty.step() == 0, "step should be 0");
+        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
+        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
+        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
+        BOOST_CHECK_MESSAGE(empty.valueAsString() == "19700101T000000",
+                            "expected 19700101T000000 but found " << empty.valueAsString());
+        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "19700101T000000",
+                            "expected 19700101T000000 but found " << empty.next_value_as_string());
+        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "19700101T000000",
+                            "expected 19700101T000000 but found " << empty.prev_value_as_string());
+    }
+    {
+        Repeat rep(RepeatDateTime("DT", "19700102T000001", "19700101T000000", "-24:00:00"));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "DT", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.start() == 86401, "Start should be 86401 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.end() == 0, "end should be 0 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.step() == -86400, "step should be -86400");
+        BOOST_CHECK_MESSAGE(rep.value() == 86401, "value should be 86401 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86401,
+                            "last_valid_value should be 86401 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "19700102T000001", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "19700101T000001",
+                            "expected 19700101T000001 but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "19700102T000001",
+                            "expected 19700102T000001 but found " << rep.prev_value_as_string());
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(rep.name() == "DT", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.start() == 86401, "Start should be 86401 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.end() == 0, "end should be 0 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.step() == -86400, "step should be -86400");
+        BOOST_CHECK_MESSAGE(rep.value() == 86401, "value should be 86401 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86401,
+                            "last_valid_value should be 86401 (seconds since 19700101T000000)");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "19700102T000001", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "19700101T000001",
+                            "expected 19700101T000001 but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "19700102T000001",
+                            "expected 19700102T000001 but found " << rep.prev_value_as_string());
+    }
+    {
+        Repeat rep(RepeatDateTime("DT", "19700101T000001", "19700102T000000", "24:00:00"));
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 1, "last_valid_value should be 1");
+        rep.increment();
+        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDateTime should not be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 86401, "value should be 86401");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86400, "last_valid_value should be 1");
+    }
+    {
+        Repeat rep(RepeatDateTime("DT", "19700102T000000", "19700101T000001", "-24:00:00"));
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 86400, "last_valid_value should be 86400");
+        rep.increment();
+        BOOST_CHECK_MESSAGE(!rep.valid(), "RepeatDateTime should not be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 0, "value should be 0");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 1, "last_valid_value should be 86400");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat_datetime
+
+/*
+ * Test Suite: ::test_repeat_enumerated
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat_enumerated)
+
+BOOST_AUTO_TEST_CASE(invariants) {
+    cout << "ANattr:: ...test_repeat_enumerated::invariants\n";
+
+    const std::vector<std::string> stringList = {std::string("a"), std::string("b"), std::string("c")};
+
+    {
+        Repeat rep(RepeatEnumerated("AEnum", stringList));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "AEnum", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "a", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "b", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "a", "not as expected");
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(cloned.name() == "AEnum", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.start() == 0, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.value() == 0, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "a", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "b", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "a", "not as expected");
+
+        RepeatEnumerated empty;
+        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
+        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
+        BOOST_CHECK_MESSAGE(empty.step() == 1, "default step should be 1");
+        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
+        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
+        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
+        BOOST_CHECK_MESSAGE(empty.valueAsString() == "", "not as expected");
+        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "", "not as expected");
+        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "", "not as expected");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(construction) {
+    cout << "ANattr:: ...TestRepeatEnumerated::construction\n";
+
+    Repeat empty;
+    {
+        Repeat la(RepeatEnumerated("AEnum", stringList));
+        Repeat lb(RepeatEnumerated("AEnum", stringList));
+        BOOST_CHECK_MESSAGE(!la.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(!lb.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(la == lb, "Equality failed");
+        BOOST_CHECK_MESSAGE(!(la == empty), "Equality failed");
+
+        la.clear();
+        lb.clear();
+
+        BOOST_CHECK_MESSAGE(la == empty, "Clear failed");
+        BOOST_CHECK_MESSAGE(lb == empty, "Clear failed");
+    }
+    {
+        Repeat la(RepeatEnumerated("AEnum", stringList));
+        Repeat lb;
+        lb = la;
+        BOOST_CHECK_MESSAGE(la == lb, "Assignment failed");
+    }
+    {
+        Repeat la(RepeatEnumerated("AEnum", stringList));
+        Repeat lb = la;
+        BOOST_CHECK_MESSAGE(la == lb, "Copy construction failed");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(last_value) {
+    cout << "ANattr:: ...test_repeat_enumerated::last_value \n";
+
+    Repeat rep(RepeatEnumerated("AEnum", stringList));
+    rep.setToLastValue();
+    BOOST_CHECK_MESSAGE(rep.value() == 2, "Set to last value did not work, expected 2 but found " << rep.value());
+    BOOST_CHECK_MESSAGE(rep.valueAsString() == "c",
+                        "Set to last value did not work, expected 'c' but found " << rep.valueAsString());
+    BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "a", " Expected 'a' but found " << rep.value_as_string(0));
+    BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "b", " Expected 'b' but found " << rep.value_as_string(1));
+    BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "c", " Expected 'c' but found " << rep.value_as_string(2));
+    BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "c",
+                        "next_value_as_string() did not work, expected c but found " << rep.next_value_as_string());
+    BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "b",
+                        "prev_value_as_string() did not work, expected b but found " << rep.prev_value_as_string());
+}
+
+BOOST_AUTO_TEST_CASE(increment) {
+    cout << "ANattr:: ...test_repeat_enumerated::increment \n";
+
+    Repeat rep(RepeatEnumerated("AEnum", stringList));
+    while (rep.valid()) {
+        rep.increment();
+    }
+    BOOST_CHECK_MESSAGE(rep.value() == 3, " Expected 3 but found " << rep.value());
+    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 2, " Expected 2 but found " << rep.last_valid_value());
+}
+
+BOOST_AUTO_TEST_CASE(more_increment) {
+    cout << "ANattr:: ...test_repeat_enumerated::more_increment\n";
+
+    using namespace std::string_literals;
+
+    const std::vector<std::string> stringList = {"20130101"s, "20130102"s, "20130103"s};
+
+    {
+        Repeat rep(RepeatEnumerated("AEnum", stringList));
+        // Note: valueAsString should return string at the last valid index
+
+        BOOST_CHECK_MESSAGE(rep.valid(), "Expected rep to be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 20130101, " Expected 20130101 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130101,
+                            " Expected 20130101 but found " << rep.last_valid_value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130101",
+                            " Expected '20130101' but found " << rep.valueAsString());
+        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "20130101",
+                            " Expected '20130101' but found " << rep.value_as_string(0));
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20130102",
+                            " Expected '20130102' but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20130101",
+                            " Expected '20130101' but found " << rep.prev_value_as_string());
+
+        rep.increment();
+        BOOST_CHECK_MESSAGE(rep.valid(), "Expected rep to be valid");
+        BOOST_CHECK_MESSAGE(rep.value() == 20130102, " Expected 20130102 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130102,
+                            " Expected 20130102 but found " << rep.last_valid_value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130102",
+                            " Expected '20130102' but found " << rep.valueAsString());
+        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "20130102",
+                            " Expected '20130102' but found " << rep.value_as_string(1));
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20130103",
+                            " Expected '20130103' but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20130101",
+                            " Expected '20130101' but found " << rep.prev_value_as_string());
+
+        rep.increment();
+        BOOST_CHECK_MESSAGE(rep.value() == 20130103, " Expected 20130103 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130103,
+                            " Expected 20130103 but found " << rep.last_valid_value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130103",
+                            " Expected '20130103' but found " << rep.valueAsString());
+        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "20130103",
+                            " Expected '20130103' but found " << rep.value_as_string(2));
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "20130103",
+                            " Expected '20130103' but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "20130102",
+                            " Expected '20130102' but found " << rep.prev_value_as_string());
+
+        rep.increment();
+        BOOST_CHECK_MESSAGE(!rep.valid(), "Expected rep to be in-valid");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130103,
+                            " Expected 20130103 but found " << rep.last_valid_value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130103",
+                            " Expected '20130103' but found " << rep.valueAsString());
+
+        rep.increment();
+        BOOST_CHECK_MESSAGE(!rep.valid(), "Expected rep to be in-valid");
+        BOOST_CHECK_MESSAGE(rep.last_valid_value() == 20130103,
+                            " Expected 20130103 but found " << rep.last_valid_value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "20130103",
+                            " Expected '20130103' but found " << rep.valueAsString());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(handling_errors) {
+    cout << "ANattr:: ...test_repeat_enumerated::handling_errors \n";
+
+    const std::vector<std::string> empty;
+    const std::vector<std::string> stringList = {"a", "b"};
+
+    BOOST_REQUIRE_THROW(RepeatEnumerated("", stringList), std::runtime_error);  // empty name
+    BOOST_REQUIRE_THROW(RepeatEnumerated(" ", stringList), std::runtime_error); // empty name
+    BOOST_REQUIRE_THROW(RepeatEnumerated("*", stringList), std::runtime_error); // illegal name
+    BOOST_REQUIRE_THROW(RepeatEnumerated("AEnum", empty), std::runtime_error);  // empty enumerations
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat_enumerated
+
+/*
+ * Test Suite: ::test_repeat_integer
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat_integer)
+
+BOOST_AUTO_TEST_CASE(invariants) {
+    cout << "ANattr:: ...test_repeat_integer::invariants\n";
+
+    {
+        Repeat rep(RepeatInteger("rep", 0, 100, 1));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "rep", "name not as expected");
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "0", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "1", "not as expected");
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "0", "not as expected");
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(cloned.name() == "rep", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.start() == 0, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.end() == 100, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.step() == 1, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.value() == 0, "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.valueAsString() == "0", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.next_value_as_string() == "1", "not as expected");
+        BOOST_CHECK_MESSAGE(cloned.prev_value_as_string() == "0", "not as expected");
+
+        RepeatInteger empty;
+        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
+        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
+        BOOST_CHECK_MESSAGE(empty.step() == 0, "default step should be 0 but found" << empty.step());
+        BOOST_CHECK_MESSAGE(empty.value() == 0, "delta should be 0");
+        BOOST_CHECK_MESSAGE(empty.name().empty(), "name should be empty");
+        BOOST_CHECK_MESSAGE(empty.name() == "", "name not as expected");
+        BOOST_CHECK_MESSAGE(empty.valueAsString() == "0", "not as expected");
+        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "0", "not as expected");
+        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "0", "not as expected");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(construction) {
+    cout << "ANattr:: ...test_repeat_integer::construction\n";
+
+    Repeat empty;
+
+    {
+        Repeat l1(RepeatInteger("rep", 0, 100, 1));
+        Repeat l2(RepeatInteger("rep", 0, 100, 1));
+        BOOST_CHECK_MESSAGE(!l1.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(!l2.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
+        BOOST_CHECK_MESSAGE(!(l1 == empty), "Equality failed");
+
+        l1.clear();
+        l2.clear();
+
+        BOOST_CHECK_MESSAGE(l1 == empty, "Clear failed");
+        BOOST_CHECK_MESSAGE(l2 == empty, "Clear failed");
+    }
+
+    {
+        Repeat l1(RepeatInteger("rep", 0, 100, 1));
+        Repeat lf;
+        lf = l1;
+        BOOST_CHECK_MESSAGE(l1 == lf, "Assignment failed");
+    }
+
+    {
+        Repeat l1(RepeatInteger("rep", 0, 100, 1));
+        Repeat lf = l1;
+        BOOST_CHECK_MESSAGE(l1 == lf, "Copy construction failed");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(last_value) {
+    cout << "ANattr:: ...test_repeat_integer::last_value \n";
+
+    {
+        Repeat rep(RepeatInteger("integer", 0, 10, 1));
+        rep.setToLastValue();
+        BOOST_CHECK_MESSAGE(rep.value() == 10, "Set to last value did not work, expected 10 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "0", " Expected '0' but found " << rep.value_as_string(0));
+        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "1", " Expected '1' but found " << rep.value_as_string(1));
+        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "2", " Expected '2' but found " << rep.value_as_string(2));
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "10",
+                            "next_value_as_string() did not work, expected 10 but found "
+                                << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "9",
+                            "prev_value_as_string() did not work, expected 9 but found " << rep.prev_value_as_string());
+    }
+    {
+        Repeat rep(RepeatInteger("integer", 10, 0, -1));
+        rep.setToLastValue();
+        BOOST_CHECK_MESSAGE(rep.value() == 0, "Set to last value did not work, expected 0 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "0", " Expected '0' but found " << rep.value_as_string(0));
+        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "1", " Expected '1' but found " << rep.value_as_string(1));
+        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "2", " Expected '2' but found " << rep.value_as_string(2));
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "0",
+                            "next_value_as_string() did not work, expected 0 but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "1",
+                            "prev_value_as_string() did not work, expected 1 but found " << rep.prev_value_as_string());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(increment) {
+    cout << "ANattr:: ...test_repeat_integer::increment \n";
+
+    Repeat rep(RepeatInteger("integer", 0, 10, 1));
+    while (rep.valid()) {
+        rep.increment();
+    }
+    BOOST_CHECK_MESSAGE(rep.value() == 11, " Expected 11 but found " << rep.value());
+    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 10, " Expected 10 but found " << rep.last_valid_value());
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat_integer
+
+/*
+ * Test Suite: ::test_repeat_day
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat_day)
+
+BOOST_AUTO_TEST_CASE(invariants) {
+    cout << "ANattr:: ...test_repeat_day::invariants\n";
+
+    {
+        Repeat rep(RepeatDay(2));
+        BOOST_CHECK_MESSAGE(!rep.empty(), " Repeat should not be empty");
+        BOOST_CHECK_MESSAGE(!rep.name().empty(), "name should not be empty");
+        BOOST_CHECK_MESSAGE(rep.name() == "day", "name not as expected");
+
+        Repeat cloned = Repeat(rep);
+        BOOST_CHECK_MESSAGE(cloned == rep, "Equality failed");
+        BOOST_CHECK_MESSAGE(cloned.name() == "day", "name not as expected");
+        BOOST_CHECK_MESSAGE(cloned.step() == 2, "step not as expected");
+
+        RepeatDay empty;
+        BOOST_CHECK_MESSAGE(empty.start() == 0, "Start should be 0");
+        BOOST_CHECK_MESSAGE(empty.end() == 0, "end should be 0");
+        BOOST_CHECK_MESSAGE(empty.step() == 1, "default step should be 0 but found " << empty.step());
+        BOOST_CHECK_MESSAGE(empty.value() == 1, "value should be 0 but found " << empty.value());
+        BOOST_CHECK_MESSAGE(empty.name() == "day", "name not as expected");
+        BOOST_CHECK_MESSAGE(empty.valueAsString() == "", "not as expected");
+        BOOST_CHECK_MESSAGE(empty.next_value_as_string() == "", "not as expected");
+        BOOST_CHECK_MESSAGE(empty.prev_value_as_string() == "", "not as expected");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat_day
+
+/*
+ * Test Suite: ::test_repeat_string
+ * ************************************************************ */
+
+BOOST_AUTO_TEST_SUITE(test_repeat_string)
+
+BOOST_AUTO_TEST_CASE(construction) {
+    cout << "ANattr:: ...test_repeat_string::construction\n";
+
+    Repeat empty;
+
+    {
+        Repeat l1(RepeatString("RepeatString", stringList));
+        Repeat l2(RepeatString("RepeatString", stringList));
+        BOOST_CHECK_MESSAGE(!l1.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(!l2.empty(), "Construction failed");
+        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
+        BOOST_CHECK_MESSAGE(!(l2 == empty), "Equality failed");
+
+        l1.clear();
+        l2.clear();
+
+        BOOST_CHECK_MESSAGE(l1 == empty, "Clear failed");
+        BOOST_CHECK_MESSAGE(l2 == empty, "Clear failed");
+    }
+
+    {
+        Repeat l1(RepeatString("RepeatString", stringList));
+        Repeat l2;
+        l2 = l1;
+        BOOST_CHECK_MESSAGE(l1 == l2, "Assignment failed");
+    }
+
+    {
+        Repeat l1(RepeatString("RepeatString", stringList));
+        Repeat l2 = l1;
+        BOOST_CHECK_MESSAGE(l1 == l2, "Copy construction failed");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(last_value) {
+    cout << "ANattr:: ...test_repeat_string::last_value \n";
+
+    {
+        Repeat rep(RepeatString("Str", stringList));
+        rep.setToLastValue();
+        BOOST_CHECK_MESSAGE(rep.value() == 2, "Set to last value did not work, expected 2 but found " << rep.value());
+        BOOST_CHECK_MESSAGE(rep.valueAsString() == "c",
+                            "Set to last value did not work, expected 'c' but found " << rep.valueAsString());
+        BOOST_CHECK_MESSAGE(rep.value_as_string(0) == "a", " Expected 'a' but found " << rep.value_as_string(0));
+        BOOST_CHECK_MESSAGE(rep.value_as_string(1) == "b", " Expected 'b' but found " << rep.value_as_string(1));
+        BOOST_CHECK_MESSAGE(rep.value_as_string(2) == "c", " Expected 'c' but found " << rep.value_as_string(2));
+        BOOST_CHECK_MESSAGE(rep.next_value_as_string() == "c",
+                            "next_value_as_string() did not work, expected c but found " << rep.next_value_as_string());
+        BOOST_CHECK_MESSAGE(rep.prev_value_as_string() == "b",
+                            "prev_value_as_string() did not work, expected b but found " << rep.prev_value_as_string());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(increment) {
+    cout << "ANattr:: ...test_repeat_string::increment \n";
+
+    Repeat rep(RepeatString("Str", stringList));
+    while (rep.valid()) {
+        rep.increment();
+    }
+    BOOST_CHECK_MESSAGE(rep.value() == 3, " Expected 3 but found " << rep.value());
+    BOOST_CHECK_MESSAGE(rep.last_valid_value() == 2, " Expected 2 but found " << rep.last_valid_value());
+}
+
+BOOST_AUTO_TEST_CASE(handling_errors) {
+    cout << "ANattr:: ...test_repeat_string::handling_errors \n";
+
+    const std::vector<std::string> empty;
+    const std::vector<std::string> stringList = {"a", "b"};
+
+    BOOST_REQUIRE_THROW(RepeatString("", stringList), std::runtime_error);          // empty name
+    BOOST_REQUIRE_THROW(RepeatString(" ", stringList), std::runtime_error);         // empty name
+    BOOST_REQUIRE_THROW(RepeatString("!£$%^&*()", stringList), std::runtime_error); // illegal name
+    BOOST_REQUIRE_THROW(RepeatString("AEnum", empty), std::runtime_error);          // empty string list
+}
+
+BOOST_AUTO_TEST_SUITE_END() // test_repeat_string
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestSizeOf.cpp 5.13.0-1/libs/attribute/test/TestSizeOf.cpp
--- 5.12.4-1/libs/attribute/test/TestSizeOf.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestSizeOf.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace boost;
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_SizeOf)
+
+BOOST_AUTO_TEST_CASE(test_size_of) {
+    cout << "ACore:: ...test_size_of\n";
+    cout << "   sizeof(std::ofstream)      " << sizeof(std::ofstream) << "\n";
+    cout << "   sizeof(std::string)        " << sizeof(std::string) << "\n";
+    cout << "   sizeof(vector<int>)        " << sizeof(std::vector<int>) << "\n";
+    cout << "   sizeof(vector<string>)     " << sizeof(vector<string>) << "\n";
+    cout << "   sizeof(std::weak_ptr<int>) " << sizeof(std::weak_ptr<int>) << "\n";
+    cout << "   sizeof(nullptr)            " << sizeof(nullptr) << "\n";
+    cout << "   sizeof(unique_ptr)         " << sizeof(unique_ptr<int>) << "\n";
+    cout << "   sizeof(double)             " << sizeof(double) << "\n";
+    cout << "   sizeof(long)               " << sizeof(long) << "\n";
+    cout << "   sizeof(int)                " << sizeof(int) << "\n";
+    cout << "   sizeof(unsigned int)       " << sizeof(unsigned int) << "\n";
+    cout << "   sizeof(bool)               " << sizeof(bool) << "\n";
+    cout << "   sizeof(TimeSeries)         " << sizeof(ecf::TimeSeries) << "\n";
+    cout << "   sizeof(DayAttr)            " << sizeof(DayAttr) << "\n";
+
+    BOOST_CHECK_MESSAGE(true, "Dummy");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestTimeAttr.cpp 5.13.0-1/libs/attribute/test/TestTimeAttr.cpp
--- 5.12.4-1/libs/attribute/test/TestTimeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestTimeAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,450 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/date_time/posix_time/time_formatters.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/TimeAttr.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_TimeAttr)
+
+BOOST_AUTO_TEST_CASE(test_time_string_constrcutor) {
+    cout << "ANattr:: ...test_time_string_constrcutor\n";
+    {
+        TimeAttr time("+00:30");
+        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
+                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
+                                time.time_series().relative(),
+                            "Error in time constructor");
+    }
+    {
+        TimeAttr time("12:30");
+        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 12 && time.time_series().start().minute() == 30 &&
+                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
+                                !time.time_series().relative(),
+                            "Error in time constructor");
+    }
+    {
+        TimeAttr time("+00:30 11:30 00:01");
+        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
+                                time.time_series().finish().hour() == 11 &&
+                                time.time_series().finish().minute() == 30 && time.time_series().incr().hour() == 0 &&
+                                time.time_series().incr().minute() == 1 && time.time_series().relative(),
+                            "Error in time constructor");
+    }
+    {
+        BOOST_REQUIRE_THROW(TimeAttr(""), std::runtime_error);
+        BOOST_REQUIRE_THROW(TimeAttr(" "), std::runtime_error);
+        BOOST_REQUIRE_THROW(TimeAttr("sdsdsdsd"), std::runtime_error);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_attr) {
+    cout << "ANattr:: ...test_time_attr\n";
+
+    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
+    // test time attr isFree(), and checkForRequeue
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series. Need to sync hour with suite time
+    // at hour 1, suite time should also be 01:00, for test to work
+    //
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr    1:00
+    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
+    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
+
+    TimeSlot t1_min, t1_max, t2_min, t2_max, t3_min, t3_max, t4_min, t4_max;
+    timeSeriesX.min_max_time_slots(t1_min, t1_max);
+    timeSeries2X.min_max_time_slots(t2_min, t2_max);
+    timeSeries3X.min_max_time_slots(t3_min, t3_max);
+    timeSeries4X.min_max_time_slots(t4_min, t4_max);
+    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(20, 0), "Not as expected");
+    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(11, 0) && t2_max == TimeSlot(15, 0), "Not as expected");
+    BOOST_CHECK_MESSAGE(t3_min == TimeSlot(15, 0) && t3_max == TimeSlot(15, 0), "Not as expected");
+    BOOST_CHECK_MESSAGE(t4_min == TimeSlot(0, 0) && t4_max == TimeSlot(0, 0), "Not as expected");
+
+    TimeAttr timeSeries(timeSeriesX);
+    TimeAttr timeSeries2(timeSeries2X);
+    TimeAttr timeSeries3(timeSeries3X);
+    TimeAttr timeSeries4(timeSeries4X);
+
+    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
+    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
+    timeSeries.time_series().free_slots(timeSeries_free_slots);
+    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
+    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
+                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
+                                                      << timeSeries_free_slots.size());
+    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
+                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
+                                                     << timeSeries_free_slots.size());
+    //   cout << "time " << timeSeries.toString() << " free slots:";
+    //   for(size_t i = 0; i < timeSeries_free_slots.size(); i++)  cout << timeSeries_free_slots[i] << " ";
+    //   cout << "\n";
+
+    // follow normal process
+    timeSeries.reset(calendar);
+    timeSeries2.reset(calendar);
+    timeSeries3.reset(calendar);
+    timeSeries4.reset(calendar);
+
+    bool cmd_context = true;
+    bool day_changed = false; // after midnight make sure we keep day_changed
+    for (int m = 1; m < 96; m++) {
+        calendar.update(time_duration(minutes(30)));
+        if (!day_changed)
+            day_changed = calendar.dayChanged();
+
+        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
+        // cout << time << " day_changed(" << day_changed << ")\n";
+
+        timeSeries.calendarChanged(calendar);
+        timeSeries2.calendarChanged(calendar);
+        timeSeries3.calendarChanged(calendar);
+        timeSeries4.calendarChanged(calendar);
+
+        // cout << to_simple_string(calendar.suiteTime()) << "\n";
+
+        if (calendar.dayChanged()) {
+            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                " expected " << timeSeries.toString() << " checkForRequeue to fail at "
+                                             << to_simple_string(calendar.suiteTime()));
+            BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max, cmd_context),
+                                " expected " << timeSeries.toString() << " checkForRequeue to pass at "
+                                             << to_simple_string(calendar.suiteTime()));
+        }
+        else if (time < timeSeries.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                timeSeries.toString() << " should NOT be free at time " << time);
+            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                timeSeries.toString() << " checkForRequeue should fail at " << time);
+            BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max, cmd_context),
+                                timeSeries.toString() << " checkForRequeue should pass at " << time);
+        }
+        else if (time >= timeSeries.time_series().start().duration() &&
+                 time <= timeSeries.time_series().finish().duration()) {
+
+            bool matches_free_slot = false;
+            for (const auto& timeSeries_free_slot : timeSeries_free_slots) {
+                if (time == timeSeries_free_slot) {
+                    matches_free_slot = true;
+                    break;
+                }
+            }
+            if (matches_free_slot)
+                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be fail at time " << time);
+
+            /// At the last hour checkForRequeue should return false; This ensures that value will
+            /// not get incremented and so, should leave node in the complete state.
+            if (time < timeSeries.time_series().finish().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries.toString() << " checkForRequeue should be free at time " << time);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries.toString() << "checkForRequeue should Not free at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                timeSeries.toString() << " should be holding at time " << time);
+            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                timeSeries.toString() << " should fail at " << time);
+        }
+
+        if (calendar.dayChanged()) {
+            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
+                                             << to_simple_string(calendar.suiteTime()));
+        }
+        else if (time < timeSeries2.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                timeSeries2.toString() << " should NOT be free at time " << time);
+            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                timeSeries2.toString() << " checkForRequeue should pass at " << time);
+        }
+        else if (time >= timeSeries2.time_series().start().duration() &&
+                 time <= timeSeries2.time_series().finish().duration()) {
+
+            bool matches_free_slot = false;
+            for (const auto& timeSeries2_free_slot : timeSeries2_free_slots) {
+                if (time == timeSeries2_free_slot) {
+                    matches_free_slot = true;
+                    break;
+                }
+            }
+            if (matches_free_slot)
+                BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should be fail at time " << time);
+
+            /// At the last time checkForRequeue should return false; This ensures that value will
+            /// not get incremented and so, should leave node in the complete state.
+            if (time < timeSeries2.time_series().finish().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    timeSeries2.toString() << " checkForRequeue should be free at time " << time);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    timeSeries2.toString() << "checkForRequeue should Not free at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                timeSeries2.toString() << " should be holding at time " << time);
+            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                timeSeries2.toString() << " should fail at " << time);
+        }
+
+        // Single slot, Once a single slot is Free it *stays* free until explicitly requeued, (i.e by parent
+        // repeat/cron)
+        if (!day_changed) {
+            if (time < timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(!timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " should be fail at time " << time);
+            }
+            else if (time == timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " should be free at time " << time);
+            }
+            else if (time > timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " isFree should pass at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                timeSeries3.toString() << " should be free at time after day change" << time);
+        }
+        BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(calendar, t3_min, t3_max),
+                            timeSeries3.toString() << " checkForRequeue should fail at " << time);
+
+        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
+        // repeat/cron)
+        if (!day_changed) {
+            if (time == timeSeries4.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                    timeSeries4.toString() << " should be free at time " << time);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
+                                    timeSeries4.toString()
+                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                timeSeries4.toString()
+                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
+        }
+        BOOST_CHECK_MESSAGE(!timeSeries4.checkForRequeue(calendar, t4_min, t4_max),
+                            timeSeries4.toString() << " checkForRequeue should fail at " << time);
+
+        // Typically when a time is free, it stays free, until it is re-queued
+        // However in order to test isFree for time with time intervals, we need to re-queue
+        timeSeries.requeue(calendar);
+        timeSeries2.requeue(calendar);
+
+        // Do not requeue time 00, and time 15, so that we can check for free
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_once_free_stays_free) {
+    cout << "ANattr:: ...test_time_once_free_stays_free\n";
+
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
+    TimeSeries timeSeries4X(TimeSlot(0, 0), false /* relative */);
+
+    TimeAttr timeSeries(timeSeriesX);
+    TimeAttr timeSeries2(timeSeries2X);
+    TimeAttr timeSeries3(timeSeries3X);
+    TimeAttr timeSeries4(timeSeries4X);
+
+    bool day_changed = false; // after midnight make sure we keep day_changed
+    for (int m = 1; m < 96; m++) {
+        calendar.update(time_duration(minutes(30)));
+        if (!day_changed) {
+            day_changed = calendar.dayChanged();
+        }
+        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
+        // cout << time << " day_changed(" << day_changed << ")\n";
+
+        timeSeries.calendarChanged(calendar);
+        timeSeries2.calendarChanged(calendar);
+        timeSeries3.calendarChanged(calendar);
+        timeSeries4.calendarChanged(calendar);
+
+        // **********************************************************************************
+        // When a time (regardless of whether its single slot or time series) is free, it stays free,
+        // until explicitly re-queued,
+        // ***********************************************************************************
+
+        if (time < timeSeries.time_series().start().duration()) {
+            if (!day_changed)
+                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should NOT be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be free at time " << time);
+        }
+        else if (time >= timeSeries.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                timeSeries.toString() << " should be free at time " << time);
+        }
+
+        if (time < timeSeries2.time_series().start().duration()) {
+            if (!day_changed)
+                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should NOT be free at time " << time);
+            else
+                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be free at time " << time);
+        }
+        else if (time >= timeSeries2.time_series().start().duration()) {
+            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                timeSeries2.toString() << " should be free at time " << time);
+        }
+
+        if (!day_changed) {
+            if (time == timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " should be free at time " << time);
+            }
+            else if (time > timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " isFree, once free should stay free at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                timeSeries3.toString() << " should be free at time after day change " << time);
+        }
+
+        // single slot at midnight, Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent
+        // repeat/cron)
+        if (!day_changed) {
+            if (time == timeSeries4.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                    timeSeries4.toString() << " should be free at time " << time);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries4.isFree(calendar),
+                                    timeSeries4.toString()
+                                        << " day_changed(" << day_changed << ")  isFree should fail at time " << time);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(timeSeries4.isFree(calendar),
+                                timeSeries4.toString()
+                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_attr_multiples) {
+    cout << "ANattr:: ...test_time_attr_multiples\n";
+
+    // See TimeAttr.hpp for rules concerning isFree() and checkForReque()
+    // test time attr isFree(), and checkForRequeue
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    TimeSeries timeSeries1530(TimeSlot(15, 30), false /* relative */);
+    TimeSeries timeSeries1630(TimeSlot(16, 30), false /* relative */);
+    TimeSeries timeSeries2030(TimeSlot(20, 30), false /* relative */);
+
+    TimeSlot t1_min, t1_max;
+    timeSeries1530.min_max_time_slots(t1_min, t1_max);
+    timeSeries1630.min_max_time_slots(t1_min, t1_max);
+    timeSeries2030.min_max_time_slots(t1_min, t1_max);
+    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(15, 30) && t1_max == TimeSlot(20, 30), "Not as expected");
+
+    TimeAttr timeSeries(timeSeries1530);
+    TimeAttr timeSeries2(timeSeries1630);
+    TimeAttr timeSeries3(timeSeries2030);
+
+    bool day_changed = false; // after midnight make sure we keep day_changed
+    for (int m = 1; m < 96; m++) {
+        calendar.update(time_duration(minutes(30)));
+        if (!day_changed) {
+            day_changed = calendar.dayChanged();
+        }
+        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
+        //      cout << time << " day_changed(" << day_changed << ")\n";
+
+        timeSeries.calendarChanged(calendar);
+        timeSeries2.calendarChanged(calendar);
+        timeSeries3.calendarChanged(calendar);
+
+        if (!day_changed) {
+            if (time >= t1_min.duration() && time < t1_max.duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries.toString() << " checkForRequeue should pass at " << time);
+                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries2.toString() << " checkForRequeue should pass at " << time);
+                BOOST_CHECK_MESSAGE(timeSeries3.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries3.toString() << " checkForRequeue should pass at " << time);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries.toString() << " checkForRequeue should fail at " << time);
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries2.toString() << " checkForRequeue should fail at " << time);
+                BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries3.toString() << " checkForRequeue should fail at " << time);
+            }
+        }
+        else {
+            // Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent repeat/cron)
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                timeSeries.toString()
+                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
+            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                timeSeries2.toString()
+                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
+            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                timeSeries2.toString()
+                                    << " day_changed(" << day_changed << ")  isFree should pass at time " << time);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestTodayAttr.cpp 5.13.0-1/libs/attribute/test/TestTodayAttr.cpp
--- 5.12.4-1/libs/attribute/test/TestTodayAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestTodayAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,244 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_TodayAttr)
+
+BOOST_AUTO_TEST_CASE(test_today_string_constrcutor) {
+    cout << "ANattr:: ...test_today_string_constrcutor\n";
+    {
+        TodayAttr time("+00:30");
+        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
+                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
+                                time.time_series().relative(),
+                            "Error in today constructor");
+    }
+    {
+        TodayAttr time("12:30");
+        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 12 && time.time_series().start().minute() == 30 &&
+                                time.time_series().finish().isNULL() && time.time_series().incr().isNULL() &&
+                                !time.time_series().relative(),
+                            "Error in today constructor");
+    }
+    {
+        TodayAttr time("+00:30 11:30 00:01");
+        BOOST_CHECK_MESSAGE(time.time_series().start().hour() == 0 && time.time_series().start().minute() == 30 &&
+                                time.time_series().finish().hour() == 11 &&
+                                time.time_series().finish().minute() == 30 && time.time_series().incr().hour() == 0 &&
+                                time.time_series().incr().minute() == 1 && time.time_series().relative(),
+                            "Error in today constructor");
+    }
+    {
+        BOOST_REQUIRE_THROW(TodayAttr(""), std::runtime_error);
+        BOOST_REQUIRE_THROW(TodayAttr(" "), std::runtime_error);
+        BOOST_REQUIRE_THROW(TodayAttr("sdsdsdsd"), std::runtime_error);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_today_attr) {
+    cout << "ANattr:: ...test_today_attr\n";
+
+    // See TodayAttr.hpp for rules concerning isFree() and checkForReque()
+    // test today attr isFree(), and checkForRequeue
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series. Need to sync hour with suite time
+    // at hour 1, suite time should also be 01:00, for test to work
+    //
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr    1:00
+    TimeSeries timeSeriesX(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries2X(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), false /* relative */);
+    TimeSeries timeSeries3X(TimeSlot(15, 0), false /* relative */);
+
+    TimeSlot t1_min, t1_max, t2_min, t2_max, t3_min, t3_max;
+    timeSeriesX.min_max_time_slots(t1_min, t1_max);
+    timeSeries2X.min_max_time_slots(t2_min, t2_max);
+    timeSeries3X.min_max_time_slots(t3_min, t3_max);
+    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(20, 0), "Not as expected");
+    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(11, 0) && t2_max == TimeSlot(15, 0), "Not as expected");
+    BOOST_CHECK_MESSAGE(t3_min == TimeSlot(15, 0) && t3_max == TimeSlot(15, 0), "Not as expected");
+
+    TodayAttr timeSeries(timeSeriesX);
+    TodayAttr timeSeries2(timeSeries2X);
+    TodayAttr timeSeries3(timeSeries3X);
+
+    std::vector<boost::posix_time::time_duration> timeSeries_free_slots;
+    std::vector<boost::posix_time::time_duration> timeSeries2_free_slots;
+    timeSeries.time_series().free_slots(timeSeries_free_slots);
+    timeSeries2.time_series().free_slots(timeSeries2_free_slots);
+    BOOST_CHECK_MESSAGE(timeSeries_free_slots.size() == 11,
+                        "Expected 11 free slots for " << timeSeries.toString() << " but found "
+                                                      << timeSeries_free_slots.size());
+    BOOST_CHECK_MESSAGE(timeSeries2_free_slots.size() == 5,
+                        "Expected 5 free slots for " << timeSeries2.toString() << " but found "
+                                                     << timeSeries_free_slots.size());
+
+    // follow normal process
+    timeSeries.reset(calendar);
+    timeSeries2.reset(calendar);
+    timeSeries3.reset(calendar);
+
+    bool cmd_context = true;
+    bool day_changed = false; // after midnight make sure we keep day_changed
+    for (int m = 1; m < 96; m++) {
+        calendar.update(time_duration(minutes(30)));
+        if (!day_changed) {
+            day_changed = calendar.dayChanged();
+        }
+        boost::posix_time::time_duration time = calendar.suiteTime().time_of_day();
+        //      cout << time << " day_changed(" << day_changed << ")\n";
+
+        timeSeries.calendarChanged(calendar);
+        timeSeries2.calendarChanged(calendar);
+        timeSeries3.calendarChanged(calendar);
+
+        if (!day_changed) {
+
+            if (time < timeSeries.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should NOT be free at time " << time);
+                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries.toString() << " should pass at " << time);
+                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max, cmd_context),
+                                    timeSeries.toString() << " should pass at " << time);
+            }
+            else if (time >= timeSeries.time_series().start().duration() &&
+                     time <= timeSeries.time_series().finish().duration()) {
+
+                bool matches_free_slot = false;
+                for (const auto& timeSeries_free_slot : timeSeries_free_slots) {
+                    if (time == timeSeries_free_slot) {
+                        matches_free_slot = true;
+                        break;
+                    }
+                }
+                // no else branch since once today is free it stays free, unti re-queue
+                if (matches_free_slot)
+                    BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                        timeSeries.toString() << " should be free at time " << time);
+
+                /// At the last time checkForRequeue should return false; This ensures that value will
+                /// not get incremented and so, should leave node in the complete state.
+                if (time < timeSeries.time_series().finish().duration()) {
+                    BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                        timeSeries.toString() << " checkForRequeue should be free at time " << time);
+                }
+                else {
+                    BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                        timeSeries.toString() << "checkForRequeue should Not free at time " << time);
+                }
+            }
+            else {
+                // After end time, a Today Attr should be free to run.
+                BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                    timeSeries.toString() << " should be free at time " << time);
+                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    timeSeries.toString() << " should fail at " << time);
+            }
+        }
+        else {
+            // Once a today time series is free, it stays free
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                timeSeries.toString() << " should be free at time " << time);
+        }
+
+        if (!day_changed) {
+            if (time < timeSeries2.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(!timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should NOT be free at time " << time);
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    timeSeries2.toString() << " should pass at " << time);
+            }
+            else if (time >= timeSeries2.time_series().start().duration() &&
+                     time <= timeSeries2.time_series().finish().duration()) {
+
+                bool matches_free_slot = false;
+                for (const auto& timeSeries2_free_slot : timeSeries2_free_slots) {
+                    if (time == timeSeries2_free_slot) {
+                        matches_free_slot = true;
+                        break;
+                    }
+                }
+                if (matches_free_slot)
+                    BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                        timeSeries2.toString() << " should be free at time " << time);
+
+                /// At the last time checkForRequeue should return false; This ensures that value will
+                /// not get incremented and so, should leave node in the complete state.
+                if (time < timeSeries2.time_series().finish().duration()) {
+                    BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                        timeSeries2.toString() << " checkForRequeue should be free at time " << time);
+                }
+                else {
+                    BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                        timeSeries2.toString() << "checkForRequeue should Not free at time " << time);
+                }
+            }
+            else {
+                // After end time, a Today Attr should be free to run.
+                BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                    timeSeries2.toString() << " should be holding at time " << time);
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    timeSeries2.toString() << " should fail at " << time);
+            }
+        }
+        else {
+            // Once a today time series is free, it stays free
+            BOOST_CHECK_MESSAGE(timeSeries2.isFree(calendar),
+                                timeSeries2.toString() << " should be holding at time " << time);
+        }
+
+        // Single slot
+        if (!day_changed) {
+            if (time == timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " should be free at time " << time);
+            }
+            else if (time < timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(!timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " isFree should fail at time " << time);
+            }
+            else if (time > timeSeries3.time_series().start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                    timeSeries3.toString() << " isFree should fail at time " << time);
+            }
+        }
+        else {
+            // Once a single slot if Free it *stays* free until explicitly requeued, (i.e by parent repeat/cron)
+            BOOST_CHECK_MESSAGE(timeSeries3.isFree(calendar),
+                                timeSeries3.toString() << " isFree should fail at time " << time);
+        }
+        BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(calendar, t3_min, t3_max),
+                            timeSeries3.toString() << " checkForRequeue should fail at " << time);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestVariable.cpp 5.13.0-1/libs/attribute/test/TestVariable.cpp
--- 5.12.4-1/libs/attribute/test/TestVariable.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestVariable.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,103 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdio>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/Variable.hpp"
+
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_Variable)
+
+BOOST_AUTO_TEST_CASE(test_multi_line_variable_values) {
+    cout << "ANattr:: ...test_multi_line_variable_values\n";
+
+    {
+        Variable var("name", "value");
+        BOOST_CHECK_MESSAGE(var.name() == "name", "name not as expected");
+        BOOST_CHECK_MESSAGE(var.theValue() == "value", "value not as expected");
+
+        std::string expected = "edit name 'value'";
+        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
+    }
+    {
+        Variable var("name", "");
+        std::string expected = "edit name ''";
+        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
+    }
+    {
+        Variable var("name", "value\n");
+        std::string expected = "edit name 'value\\n'";
+        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
+    }
+    {
+        Variable var("name", "val1\nxxx\nval2");
+        std::string expected = "edit name 'val1\\nxxx\\nval2'";
+        BOOST_CHECK_MESSAGE(var.toString() == expected, "expected " << expected << " but found " << var.toString());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_variable_value) {
+    cout << "ANattr:: ...test_variable_value\n";
+
+    std::vector<std::string> values;
+    values.emplace_back("sdsd");
+    values.emplace_back("0fred0");
+    values.emplace_back("fted");
+    values.emplace_back("%value%");
+    values.emplace_back("a");
+    values.emplace_back("");
+    values.emplace_back("0");
+    values.emplace_back("00");
+    values.emplace_back("000");
+    values.emplace_back("0000");
+    values.emplace_back("0000000000000");
+    for (const auto& value : values) {
+        Variable var("name", "");
+        var.set_value(value);
+        BOOST_CHECK_MESSAGE(var.value() == 0, "expected 0 but found " << var.value() << " for " << value);
+    }
+
+    {
+        Variable var("name", "0100");
+        BOOST_CHECK_MESSAGE(var.value() == 100, "expected 100 but found " << var.value());
+    }
+    {
+        Variable var("name", "0001");
+        BOOST_CHECK_MESSAGE(var.value() == 1, "expected 1 but found " << var.value());
+    }
+    {
+        Variable var("name", "2359");
+        BOOST_CHECK_MESSAGE(var.value() == 2359, "expected 2359 but found " << var.value());
+    }
+
+    // make sure time is convertible to an integer
+    constexpr int buff_size = 255;
+    char smstime[buff_size];
+    for (int h = 0; h < 24; h++) {
+        for (int m = 1; m < 60; m++) {
+            int output_written = snprintf(smstime, buff_size, "%02d%02d", h, m);
+            BOOST_CHECK_MESSAGE(output_written == 4, " expected size 4 but found " << output_written);
+            Variable var("name", "");
+            var.set_value(smstime);
+            int value = stoi(string(smstime));
+            BOOST_CHECK_MESSAGE(var.value() == value, "expected " << value << " but found " << var.value());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestVariableMap.cpp 5.13.0-1/libs/attribute/test/TestVariableMap.cpp
--- 5.12.4-1/libs/attribute/test/TestVariableMap.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestVariableMap.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+/*
+ * Copyright 2023- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/Variable.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_VariableMap)
+
+BOOST_AUTO_TEST_CASE(test_variablemap_is_able_to_create_empty_variable_map) {
+    VariableMap empty;
+
+    BOOST_CHECK(empty.empty());
+    BOOST_CHECK(empty.size() == 0);
+}
+
+BOOST_AUTO_TEST_CASE(test_variablemap_is_able_to_create_variable_map) {
+    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
+
+    BOOST_CHECK(!variables.empty());
+    BOOST_CHECK(variables.size() == 3);
+}
+
+BOOST_AUTO_TEST_CASE(test_variablemap_is_able_set_value_to_all_variables_in_variable_map) {
+    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
+
+    std::string value = "some large value just for precaution!";
+    // set value of all variables
+    variables.set_value(value);
+
+    for (const auto& variable : variables) {
+        BOOST_CHECK(variable.theValue() == value);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_variablemap_is_able_to_access_variable_in_variable_map) {
+    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
+
+    const Variable& variable = variables["n1"];
+
+    BOOST_CHECK(variable.name() == "n1");
+    BOOST_CHECK(variable.theValue() == "v1");
+}
+
+BOOST_AUTO_TEST_CASE(test_variablemap_throws_when_accessing_inexistent_variable_in_variable_map) {
+    VariableMap variables{Variable("n1", "v1"), Variable("n2", "v2"), Variable("n3", "v3")};
+
+    Variable found;
+    BOOST_CHECK_EXCEPTION(
+        found = variables["nX"], std::runtime_error, [](const std::runtime_error& e) { return true; });
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/TestZombieAttr.cpp 5.13.0-1/libs/attribute/test/TestZombieAttr.cpp
--- 5.12.4-1/libs/attribute/test/TestZombieAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/TestZombieAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,131 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/ZombieAttr.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Attributes)
+
+BOOST_AUTO_TEST_SUITE(T_ZombieAttr)
+
+BOOST_AUTO_TEST_CASE(test_zombie_attr) {
+    cout << "ANattr:: ...test_zombie_attr\n";
+    {
+        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL);
+        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
+                            "expected " << ZombieAttr::default_ecf_zombie_life_time() << " but got "
+                                        << ecf.zombie_lifetime());
+
+        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL);
+        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
+                            "Zombie life time not as expected");
+
+        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL);
+        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
+                            "Zombie life time not as expected");
+    }
+    {
+        int zombie_life_time = 0;
+        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
+                            "Zombie life time not as expected");
+
+        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
+                            "Zombie life time not as expected");
+
+        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
+                            "Zombie life time not as expected");
+    }
+    {
+        int zombie_life_time = -1;
+        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
+                            "Zombie life time not as expected");
+
+        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
+                            "Zombie life time not as expected");
+
+        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
+                            "Zombie life time not as expected");
+    }
+    {
+        int zombie_life_time = 29;
+        ZombieAttr ecf(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(ecf.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
+                            "Zombie life time not as expected");
+
+        ZombieAttr user(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(user.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
+                            "Zombie life time not as expected");
+
+        ZombieAttr path(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FAIL, zombie_life_time);
+        BOOST_CHECK_MESSAGE(path.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
+                            "Zombie life time not as expected");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_zombie_attr_parsing) {
+    cout << "ANattr:: ...test_zombie_attr_parsing\n";
+    {
+        ZombieAttr zombie = ZombieAttr::create("user:fob::");
+        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::USER, "Type not as expected");
+        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FOB, "action not as expected");
+        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::default_user_zombie_life_time(),
+                            "Zombie life time not as expected");
+        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
+    }
+    {
+        ZombieAttr zombie = ZombieAttr::create("ecf:fail::");
+        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::ECF, "Type not as expected");
+        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FAIL, "action not as expected");
+        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::default_ecf_zombie_life_time(),
+                            "Zombie life time not as expected");
+        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
+    }
+    {
+        ZombieAttr zombie = ZombieAttr::create("path:fail::");
+        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::PATH, "Type not as expected");
+        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FAIL, "action not as expected");
+        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::default_path_zombie_life_time(),
+                            "Zombie life time not as expected");
+        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
+    }
+
+    {
+        ZombieAttr zombie = ZombieAttr::create("user:fob::29");
+        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::USER, "Type not as expected");
+        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FOB, "action not as expected");
+        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
+                            "Zombie life time < 60, should default to 60");
+        BOOST_CHECK_MESSAGE(zombie.child_cmds().empty(), "Expected no children");
+    }
+    {
+        ZombieAttr zombie = ZombieAttr::create("user:fob:init:29");
+        BOOST_CHECK_MESSAGE(zombie.zombie_type() == ecf::Child::USER, "Type not as expected");
+        BOOST_CHECK_MESSAGE(zombie.action() == ecf::User::FOB, "action not as expected");
+        BOOST_CHECK_MESSAGE(zombie.zombie_lifetime() == ZombieAttr::minimum_zombie_life_time(),
+                            "Zombie life time < 60, should default to 60");
+        BOOST_CHECK_MESSAGE(zombie.child_cmds().size() == 1, "Expected one child");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf15AutoArchiveAttrE":{"cereal_class_version":0,"time_":{"h_":2400,"m_":0},"days_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr_1 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr_1
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr_1	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoArchiveAttr_1	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf15AutoArchiveAttrE":{"cereal_class_version":0,"time_":{"h_":10,"m_":12}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf14AutoCancelAttrE":{"cereal_class_version":0,"time_":{"h_":2400,"m_":0},"days_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr_1 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr_1
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr_1	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/AutoCancelAttr_1	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf14AutoCancelAttrE":{"cereal_class_version":0,"time_":{"h_":10,"m_":12}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/ClockAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/ClockAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/ClockAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/ClockAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"9ClockAttr":{"cereal_class_version":0,"hybrid_":false,"positiveGain_":true,"gain_":3600,"day_":1,"month_":1,"year_":2009}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/CronAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/CronAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/CronAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/CronAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8CronAttrE":{"cereal_class_version":0,"timeSeries_":{"cereal_class_version":0,"start_":{"h_":0,"m_":0},"finish_":{"h_":20,"m_":0},"incr_":{"h_":0,"m_":1}},"weekDays_":[1,2],"daysOfMonth_":[1,2],"months_":[1,2]}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/DateAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/DateAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/DateAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/DateAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"8DateAttr":{"day_":12,"month_":12,"year_":2012}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/DayAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/DayAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/DayAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/DayAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"7DayAttr":{"day_":1}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Event_1 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Event_1
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Event_1	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Event_1	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Event":{"number_":1}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Event_2 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Event_2
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Event_2	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Event_2	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Event":{"n_":"event"}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Event_3 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Event_3
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Event_3	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Event_3	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Event":{"n_":"event","number_":1,"v_":true,"iv_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/GenericAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/GenericAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/GenericAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/GenericAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"11GenericAttr":{"name_":"gen1","values_":["a","b"]}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Label 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Label
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Label	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Label	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Label":{"n_":"name","v_":"value","new_v_":"new_value"}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/LateAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/LateAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/LateAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/LateAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8LateAttrE":{"s_":{"h_":10,"m_":12},"a_":{"h_":10,"m_":12},"c_":{"h_":10,"m_":12},"c_is_rel_":true}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Meter 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Meter
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Meter	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Meter	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Meter":{"min_":10,"max_":100,"v_":10,"n_":"meter","cc_":100}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/QueueAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/QueueAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/QueueAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/QueueAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"9QueueAttr":{"cereal_class_version":0,"theQueue_":["a","b"],"state_vec_":[2,2],"name_":"queue","currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatDate 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatDate
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatDate	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatDate	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"10RepeatDate":{"cereal_class_version":0,"value0":{"name_":"date"},"start_":20110112,"end_":20110115,"delta_":1,"value_":20110112}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatDateList 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatDateList
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatDateList	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatDateList	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"14RepeatDateList":{"cereal_class_version":0,"value0":{"name_":"datelist"},"list_":[19990101,19990102],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatEnumerated 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatEnumerated
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatEnumerated	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatEnumerated	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"16RepeatEnumerated":{"cereal_class_version":0,"value0":{"name_":"enum"},"theEnums_":["a","b"],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatInteger 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatInteger
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatInteger	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatInteger	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"13RepeatInteger":{"cereal_class_version":0,"value0":{"name_":"integer"},"start_":0,"end_":100,"delta_":2,"value_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatString 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatString
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/RepeatString	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/RepeatString	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"12RepeatString":{"cereal_class_version":0,"value0":{"name_":"string"},"theStrings_":["a","b"],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/TimeAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/TimeAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/TimeAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/TimeAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8TimeAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":10,"m_":12}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/TodayAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/TodayAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/TodayAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/TodayAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf9TodayAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":10,"m_":12}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Variable 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Variable
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/Variable	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/Variable	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"8Variable":{"n_":"var_name","v_":"var_value"}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/VerifyAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/VerifyAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/VerifyAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/VerifyAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"10VerifyAttr":{"state_":1,"expected_":3,"actual_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr 5.13.0-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"10ZombieAttr":{"cereal_class_version":0,"child_cmds_":[0,1,2,3,4,5,6,7],"zombie_type_":0,"action_":0,"zombie_lifetime_":300}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr1 5.13.0-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr1
--- 5.12.4-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr1	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/1_2_2/ZombieAttr1	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"10ZombieAttr":{"cereal_class_version":0,"child_cmds_":[0,1,2,3,4,5,6,7],"zombie_type_":0,"action_":0,"zombie_lifetime_":500}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoArchiveAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf15AutoArchiveAttrE":{"cereal_class_version":0,"time_":{"h_":-1,"m_":-1}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoCancelAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoCancelAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoCancelAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/AutoCancelAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf14AutoCancelAttrE":{"cereal_class_version":0,"time_":{"h_":-1,"m_":-1}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ClockAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ClockAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ClockAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ClockAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"9ClockAttr":{"cereal_class_version":0,"hybrid_":false}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/CronAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/CronAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/CronAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/CronAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8CronAttrE":{"cereal_class_version":0,"timeSeries_":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DateAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DateAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DateAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DateAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"8DateAttr":{"day_":0,"month_":0,"year_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DayAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DayAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DayAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/DayAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"7DayAttr":{"day_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Event 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Event
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Event	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Event	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Event":{}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/GenericAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/GenericAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/GenericAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/GenericAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"11GenericAttr":{"name_":"","values_":[]}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Label 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Label
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Label	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Label	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Label":{"n_":""}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/LateAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/LateAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/LateAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/LateAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8LateAttrE":{}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Meter 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Meter
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Meter	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Meter	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Meter":{"min_":0,"max_":0,"v_":0,"n_":"","cc_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/QueueAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/QueueAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/QueueAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/QueueAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"9QueueAttr":{"cereal_class_version":0,"theQueue_":[],"state_vec_":[],"name_":"","currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDate 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDate
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDate	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDate	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"10RepeatDate":{"cereal_class_version":0,"value0":{"name_":""},"start_":0,"end_":0,"delta_":0,"value_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDateList 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDateList
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDateList	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatDateList	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"14RepeatDateList":{"cereal_class_version":0,"value0":{"name_":""},"list_":[],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatEnumerated 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatEnumerated
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatEnumerated	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatEnumerated	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"16RepeatEnumerated":{"cereal_class_version":0,"value0":{"name_":""},"theEnums_":[],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatInteger 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatInteger
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatInteger	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatInteger	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"13RepeatInteger":{"cereal_class_version":0,"value0":{"name_":""},"start_":0,"end_":0,"delta_":0,"value_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatString 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatString
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatString	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/RepeatString	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"12RepeatString":{"cereal_class_version":0,"value0":{"name_":""},"theStrings_":[],"currentIndex_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TimeAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TimeAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TimeAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TimeAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8TimeAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TodayAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TodayAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TodayAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/TodayAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf9TodayAttrE":{"ts_":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Variable 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Variable
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Variable	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/Variable	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"8Variable":{"n_":"","v_":""}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/VerifyAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/VerifyAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/VerifyAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/VerifyAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"10VerifyAttr":{"state_":0,"expected_":0,"actual_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ZombieAttr 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ZombieAttr
--- 5.12.4-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ZombieAttr	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/attribute/test/data/migration/default_constructor_1_2_2/ZombieAttr	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"10ZombieAttr":{"cereal_class_version":0,"child_cmds_":[],"zombie_type_":6,"action_":4,"zombie_lifetime_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/base/CMakeLists.txt 5.13.0-1/libs/base/CMakeLists.txt
--- 5.12.4-1/libs/base/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,82 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+set(test_srcs
+  # Headers
+  test/MockServer.hpp
+  test/TestHelper.hpp
+  # Sources
+  test/TestAlterCmd.cpp
+  test/TestArchiveAndRestoreCmd.cpp
+  test/TestBase_main.cpp # test entry point
+  test/TestClientHandleCmd.cpp
+  test/TestCmd.cpp
+  test/TestDeleteNodeCmd.cpp
+  test/TestForceCmd.cpp
+  test/TestFreeDepCmd.cpp
+  test/TestInLimitAndLimit.cpp
+  test/TestLogCmd.cpp
+  test/TestMeterCmd.cpp
+  test/TestProgramOptions.cpp
+  test/TestQueryCmd.cpp
+  test/TestQueueCmd.cpp
+  test/TestRequest.cpp
+  test/TestRequeueNodeCmd.cpp
+  test/TestResolveDependencies.cpp
+  test/TestSpecificIssues.cpp
+  test/TestSSyncCmd.cpp
+  test/TestSSyncCmdOrder.cpp
+  test/TestSSyncCmd_CH1.cpp
+  test/TestStatsCmd.cpp
+)
+
+ecbuild_add_test(
+  TARGET
+    u_base
+  LABELS
+    unit nightly
+  SOURCES
+    ${test_srcs}
+  INCLUDES
+    ../node/test
+  LIBS
+    ecflow_all
+    Threads::Threads
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+  TEST_DEPENDS
+    u_parser
+)
+target_clangformat(u_base
+  CONDITION ENABLE_TESTS
+)
+
+# The following is not technically a test (as it makes no checks),
+# but a tool to measure the time it takes to generate a job file
+if (ENABLE_ALL_TESTS)
+  set(test_srcs
+    # Sources
+    test/TestJobGenPerf.cpp
+  )
+
+  ecbuild_add_test(
+    TARGET
+      p_job_gen
+    LABELS
+      performance
+    SOURCES
+      ${test_srcs}
+    LIBS
+      ecflow_all
+      Threads::Threads
+  )
+  target_clangformat(p_job_gen
+    CONDITION ENABLE_TESTS
+  )
+endif()
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/AbstractClientEnv.hpp 5.13.0-1/libs/base/src/ecflow/base/AbstractClientEnv.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/AbstractClientEnv.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/AbstractClientEnv.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_AbstractClientEnv_HPP
+#define ecflow_base_AbstractClientEnv_HPP
+
+#include <string>
+#include <vector>
+
+///
+/// \brief This class is used to represent the client environment to the cmds
+///
+/// This abstraction ONLY covers aspects that are required, to _CREATE_
+/// the client command/request that is to be sent to the server
+/// The key theme is that we can define a new client to server command
+/// in one place. i.e it allows the functionality, command line arguments,
+/// parsing of the arguments, can all be done in the command class itself
+/// If the command requires any additional arguments from the client environment
+/// they should be added to this class, and the implementation in the derived class
+///
+
+class AbstractClientEnv {
+protected:
+    AbstractClientEnv() = default;
+
+public:
+    AbstractClientEnv(const AbstractClientEnv&)                  = delete;
+    const AbstractClientEnv& operator=(const AbstractClientEnv&) = delete;
+
+    virtual ~AbstractClientEnv() = default;
+
+    virtual void set_cli(bool f) = 0;
+    virtual bool get_cli() const = 0;
+
+    /// For all tasks/child based commands we require taskPath and password and optional Remote ID
+    /// When the jobs use a queueing system the remote id (ECF_RID) is used to
+    /// aid killing of jobs.(typically zombies)
+    virtual bool checkTaskPathAndPassword(std::string& errorMsg) const = 0;
+    virtual const std::string& task_path() const                       = 0;
+    virtual int task_try_no() const                                    = 0;
+    virtual const std::string& jobs_password() const                   = 0;
+    virtual const std::string& process_or_remote_id() const            = 0;
+
+    /// For test allow env variable to be set on defs, i.e. allow us to inject ECF_CLIENT to defs
+    virtual const std::vector<std::pair<std::string, std::string>>& env() const = 0;
+
+    /// Allow ping to set the host:port
+    virtual void set_host_port(const std::string& host, const std::string& port) = 0;
+
+    /// return the current host
+    virtual const std::string& host() const = 0;
+
+    /// returns the port number
+    virtual const std::string& port() const = 0;
+
+    /// debug client, when environment variable ECF_CLIENT_DEBUG is set.
+    virtual bool debug() const = 0;
+
+    /// Returns the user password read from the password file.
+    /// This value is cached, so we only read passwd file once
+    /// When the password is read in we crypt the password, using user name as a salt.
+    virtual const std::string& get_custom_user_password(const std::string& user) const = 0;
+    virtual const std::string& get_user_password(const std::string& user) const        = 0;
+    virtual void clear_user_password() = 0; // force password check again
+
+    // returns a user specified user name. When this is used a password must be provided
+    virtual const std::string& get_user_name() const = 0;
+    virtual void set_user_name(const std::string&)   = 0;
+    // set password is needed when user is authenticated from an http server call: in this case
+    // the password is given in the url (or some other means), so it will not be read from a local file
+    virtual void set_password(const std::string&) = 0;
+
+    /// Some commands work on construction. to avoid this under test. Call set_test
+    /// i.e Command like CtsCmd::SERVER_LOAD can be client side only, in which case
+    /// when testing the client interface we want to avoid opening the log file.
+    virtual void set_test()         = 0;
+    virtual bool under_test() const = 0;
+};
+
+#endif /* ecflow_base_AbstractClientEnv_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/AbstractServer.hpp 5.13.0-1/libs/base/src/ecflow/base/AbstractServer.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/AbstractServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/AbstractServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,213 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_AbstractServer_HPP
+#define ecflow_base_AbstractServer_HPP
+
+#include <atomic>
+#include <memory>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/base/Stats.hpp"
+#include "ecflow/base/ZombieCtrl.hpp"
+#include "ecflow/core/CheckPt.hpp"
+#include "ecflow/core/SState.hpp"
+#include "ecflow/core/Str.hpp"
+
+class Defs;
+
+/// This class is provided so that the cmd can issue requests to the server
+/// without depending on the server implementation
+///
+class AbstractServer {
+public:
+    virtual ~AbstractServer() = default;
+
+    /// Returns an NON empty string if server is ssl enabled.
+    /// 0/ "1 : enabled : uses shared ssl certificates";
+    /// 0/ "  : enabled : uses server/port specific ssl certificates";
+    virtual const std::string& ssl() const { return ecf::Str::EMPTY(); }
+
+    /// returns the current state of the server
+    /// The following table shows the effect of state, on server behaviour:
+    ///
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    virtual SState::State state() const = 0;
+
+    /// returns the server host and port number
+    virtual std::pair<std::string, std::string> hostPort() const = 0;
+
+    /// returns the defs held by the server. This should always exist. ECFLOW-182
+    virtual defs_ptr defs() const = 0;
+
+    /// Update the defs help by the server. This allows multiple suites to loaded
+    /// into the server. Note the input defs will be drained of its suites/externs as they
+    /// will get transferred to the server. If the server already has suites of the same
+    /// name, then an error message is created. This can be overridden with the force option
+    virtual void updateDefs(defs_ptr, bool force) = 0;
+
+    /// Remove all suites,externs,client handles, ready for a new start
+    virtual void clear_defs() = 0;
+
+    /// Forces the defs file in the server to be written to disk *IF* no args provided.
+    /// Otherwise updated mode OR check_pt interval OR check pt alarm
+    virtual bool checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
+                             int check_pt_interval        = 0,
+                             int check_pt_save_time_alarm = 0) = 0;
+
+    /// Ask the server to restore the  defs from the checkpt file. If that fails the back check pt is tried
+    virtual void restore_defs_from_checkpt() = 0;
+
+    /// This function should be called, when the node tree changes state
+    virtual void nodeTreeStateChanged() = 0;
+
+    /// returns true if the server allows task communication
+    /// Task-->server communication is stopped by halted()
+    virtual bool allowTaskCommunication() const = 0;
+
+    /// Stops job scheduling. Check point is enabled. (i,e if we were previously halted)
+    /// However any client request can still communicate with the server
+    /// Does NOT affect check pointing. Since any request can make changes to node tree
+    /// Places server in SHUTDOWN state.
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    virtual void shutdown() = 0;
+
+    /// Stop job scheduling *AND*  task communication with server. Failed task request are logged
+    /// Hence nodes can be stuck in submitted/active states.
+    /// Task based command will continue attempting, communication with the server for up to 24hrs.
+    ///
+    /// When the server is halted, we do *NOT* do any further check pointing
+    /// In a typical operational scenario where we have a home, and backup servers.
+    /// The checkpoint file is copied to the backup servers periodically (via a task)
+    /// hence we want to preserve the state of the last checkpoint. By prevent any state
+    /// changes to the node tree.
+    ///
+    /// Hence halted(), will completely stop the server. Server will only respond
+    /// to user requests. (tasks requests are blocked)
+    /// Places server in HALTED state.
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    virtual void halted() = 0;
+
+    /// Start scheduling tasks and respond to all requests. Check pointing is enabled
+    /// Places server in RUNNING state.
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    virtual void restart() = 0;
+
+    /// Ask the server to reload file the hold list of users and their access rights
+    /// The white list file is specified by the environment variable ECF_LISTS
+    /// This allows/disallows user access on the live server
+    /// Return true if file is reloaded ok, else false and error message if:
+    /// 	a/ File does not exist
+    ///  	b/ File is empty
+    ///  	c/ Errors in parsing file
+    /// If errors arise the exist user still stay in affect
+    virtual bool reloadWhiteListFile(std::string& errorMsg) = 0;
+
+    virtual bool reloadPasswdFile(std::string& errorMsg)       = 0;
+    virtual bool reloadCustomPasswdFile(std::string& errorMsg) = 0;
+
+    /// There are several kinds of authentications:
+    ///     a/ None
+    ///     b/ List mode.   ASCII file based on ECF_LISTS is defined. referred as white list file
+    ///     c/ Secure mode. ASCII file based ECF_PASSWD is defined. Referred to as black list file
+    //
+    /// Returns true if the given user has access to the server, false otherwise
+    virtual bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) = 0;
+    virtual bool authenticateReadAccess(const std::string& user,
+                                        bool custom_user,
+                                        const std::string& passwd,
+                                        const std::string& path)                                              = 0;
+    virtual bool authenticateReadAccess(const std::string& user,
+                                        bool custom_user,
+                                        const std::string& passwd,
+                                        const std::vector<std::string>& paths)                                = 0;
+
+    /// Returns true if user has matching write access privileges.
+    virtual bool authenticateWriteAccess(const std::string& user)                                        = 0;
+    virtual bool authenticateWriteAccess(const std::string& user, const std::string& path)               = 0;
+    virtual bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) = 0;
+
+    /// Shutdown the server and let 'user' has have exclusive lock on it.
+    /// If the lock succeeds return true, (This will end up calling the shutdown()
+    /// command on the server). If already locked does nothing and return's false
+    virtual bool lock(const std::string& user) = 0;
+
+    /// Unlock's the server., and restarts job scheduling
+    virtual void unlock() = 0;
+
+    /// Return the user that has exclusive lock, else an empty string
+    virtual const std::string& lockedUser() const = 0;
+
+    /// Return Controller for zombies
+    ZombieCtrl& zombie_ctrl() { return zombie_ctrl_; }
+
+    /// returns the statistical class
+    Stats& stats() { return stats_; }
+
+    /// Call to update the number of request, & returns stats
+    Stats& update_stats() {
+        stats_.update();
+        return stats_;
+    }
+
+    /// Update for number of requests per second
+    void update_stats(int poll_interval) { stats_.update_stats(poll_interval); }
+
+    // Instead of immediate node tree traversal at the end of child command
+    // we use 'increment_job_generation_count' to defer job generation to server
+    // The server will check job generation count at poll time.
+    // This approach radically reduces the number of times we traverse the node tree
+    // and hence improves server throughput.
+    void increment_job_generation_count() { job_gen_count_++; }
+    void reset_job_generation_count() { job_gen_count_ = 0; }
+    int get_job_generation_count() const { return job_gen_count_; }
+
+    /// This job generation is special, in that it will time out, job generation time >= next poll.
+    /// This can be called at the end of a *USER* command(force,alter,requeue,etc), hence time_now may be >=
+    /// next_poll_time If this is the case, we will defer job generation
+    virtual void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
+                                                     bool user_cmd_context) const = 0;
+
+    /// returns the number of seconds at which we should check time dependencies
+    /// this includes evaluating trigger dependencies and submit the corresponding jobs.
+    /// This is set at 60 seconds. But will vary for debug/test purposes only.
+    /// For Testing the state change queued->submitted->active duration < submitJobsInterval
+    /// If this state change happens at the job submission boundary then
+    /// time series can get a skew.
+    virtual int poll_interval() const = 0;
+
+    /// enable and disable debug output from the server
+    virtual void debug_server_on()  = 0;
+    virtual void debug_server_off() = 0;
+    virtual bool debug() const      = 0;
+
+protected:
+    AbstractServer() = default;
+
+private:
+    ZombieCtrl zombie_ctrl_;
+    Stats stats_;
+    std::atomic<int> job_gen_count_{0};
+};
+
+#endif /* ecflow_base_AbstractServer_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Client.cpp 5.13.0-1/libs/base/src/ecflow/base/Client.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/Client.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Client.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,353 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/Client.hpp"
+
+#include <iostream>
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/base/stc/StcCmd.hpp"
+
+#ifdef DEBUG_PERF
+    #include "ecflow/core/DebugPerf.hpp"
+#endif
+
+// #define DEBUG_CLIENT 1;
+#ifdef DEBUG_CLIENT
+    #include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
+#endif
+
+/// The timeout will typically happen when the server has died, but socket is still open
+/// If we do not have a timeout, it will hang indefinitely
+
+/// Constructor starts the asynchronous connect operation.
+Client::Client(boost::asio::io_service& io_service,
+               Cmd_ptr cmd_ptr,
+               const std::string& host,
+               const std::string& port,
+               int timeout)
+    : stopped_(false),
+      host_(host),
+      port_(port),
+      connection_(io_service),
+      deadline_(io_service),
+      timeout_(timeout) {
+    /// Avoid sending a NULL request to the server
+    if (!cmd_ptr.get())
+        throw std::runtime_error("Client::Client: No request specified !");
+
+    // The timeout can be set externally for testing, however when its not set the timeout is obtained from the command
+    // Vary the timeout, according to the command, hence loading the definition has longer timeout than ping
+    if (0 == timeout_) {
+        timeout_ = cmd_ptr->timeout();
+    }
+
+#ifdef DEBUG_CLIENT
+    std::cout << "   Client::Client() timeout(" << timeout_ << ") " << host_ << ":" << port_ << " ";
+    cmd_ptr->print(std::cout);
+    std::cout << std::endl;
+#endif
+
+    outbound_request_.set_cmd(cmd_ptr);
+
+    // Host name resolution is performed using a resolver, where host and service
+    // names(or ports) are looked up and converted into one or more end points
+    boost::asio::ip::tcp::resolver resolver(io_service);
+    boost::asio::ip::tcp::resolver::query query(host_, port_);
+    boost::asio::ip::tcp::resolver::iterator endpoint_iterator = resolver.resolve(query);
+
+    // The list of end points obtained could contain both IPv4 and IPv6 end points,
+    // so a program may try each of them until it finds one that works.
+    // This keeps the Client program independent of a specific IP version.
+    start(endpoint_iterator);
+}
+
+Client::~Client() {
+#ifdef DEBUG_CLIENT
+    std::cout << "   Client::~Client(): connection_.socket().is_open()=" << connection_.socket().is_open() << std::endl;
+#endif
+}
+
+/// Private ==============================================================================
+
+// This function terminates all the actors to shut down the connection. It
+// may be called by the user of the client class, or by the class itself in
+// response to graceful termination or an unrecoverable error.
+void Client::start(boost::asio::ip::tcp::resolver::iterator endpoint_iter) {
+    // Start the connect actor.
+    start_connect(endpoint_iter);
+
+    // Start the deadline actor. You will note that we're not setting any
+    // particular deadline here. Instead, the connect and input actors will
+    // update the deadline prior to each asynchronous operation.
+    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
+}
+
+bool Client::start_connect(boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
+    if (endpoint_iterator != boost::asio::ip::tcp::resolver::iterator()) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   Client::start_connect: Trying " << endpoint_iterator->endpoint() << "..." << std::endl;
+#endif
+
+        // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that
+        // were cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or
+        // will soon be executed. If it returns 1 then the wait handler was successfully cancelled.
+
+        // Set a deadline for the connect operation.
+        deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
+
+        boost::asio::ip::tcp::endpoint endpoint = *endpoint_iterator;
+        connection_.socket_ll().async_connect(endpoint,
+                                              [this, endpoint_iterator](const boost::system::error_code& error) {
+                                                  this->handle_connect(error, endpoint_iterator);
+                                              });
+    }
+    else {
+        // ran out of end points
+        return false;
+    }
+    return true;
+}
+
+void Client::handle_connect(const boost::system::error_code& e,
+                            boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
+#ifdef DEBUG_CLIENT
+    std::cout << "   Client::handle_connect stopped_=" << stopped_ << std::endl;
+#endif
+
+    if (stopped_)
+        return;
+
+    // The async_connect() function automatically opens the socket at the start
+    // of the asynchronous operation. If the socket is closed at this time then
+    // the timeout handler must have run first.
+    if (!connection_.socket_ll().is_open()) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   Client::handle_connect: *Connect timeout*:  Trying next end point" << std::endl;
+#endif
+        // Try the next available end point.
+        if (!start_connect(++endpoint_iterator)) {
+            // Ran out of end points, An error occurred
+            stop();
+            std::stringstream ss;
+            if (e)
+                ss << "Client::handle_connect: Ran out of end points : connection error( " << e.message()
+                   << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
+            else
+                ss << "Client::handle_connect: Ran out of end points : connection error for request( "
+                   << outbound_request_ << " ) on " << host_ << ":" << port_;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else if (e) {
+
+#ifdef DEBUG_CLIENT
+        std::cout << "   Client::handle_connect Connect error: " << e.message() << " . Trying next end point"
+                  << std::endl;
+#endif
+
+        // Some kind of error. We need to close the socket used in the previous connection attempt
+        // before starting a new one.
+        connection_.socket_ll().close();
+
+        // Try the next end point.
+        if (!start_connect(++endpoint_iterator)) {
+            // Ran out of end points. An error occurred.
+            stop();
+            std::stringstream ss;
+            ss << "Client::handle_connect: Ran out of end points: connection error( " << e.message()
+               << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else {
+#ifdef DEBUG_CLIENT
+        std::cout << "   Client::handle_connect **Successfully** established connection to the server: Sending Out "
+                     "bound request = "
+                  << outbound_request_ << std::endl;
+#endif
+
+        // **Successfully** established connection to the server
+        // Start operation to *SEND* a request to the server
+        start_write();
+    }
+}
+
+void Client::start_write() {
+    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
+    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
+    // executed. If it returns 1 then the wait handler was successfully cancelled.
+
+    // Set a deadline for the write operation.
+    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
+
+    connection_.async_write(outbound_request_,
+                            [this](const boost::system::error_code& error) { this->handle_write(error); });
+}
+
+void Client::handle_write(const boost::system::error_code& e) {
+#ifdef DEBUG_CLIENT
+    std::cout << "   Client::handle_write stopped_ = " << stopped_ << std::endl;
+#endif
+    if (stopped_)
+        return;
+
+    if (!e) {
+
+#ifdef DEBUG_CLIENT
+        std::cout << "   Client::handle_write OK: Check for server reply" << std::endl;
+#endif
+        // Check to see if the server was happy with our request.
+        // If all is OK, the server may choose not to reply(cuts down on network traffic)
+        // In which case handle_read will get a End of File error.
+        start_read();
+    }
+    else {
+
+        // An error occurred.
+        stop();
+
+        std::stringstream ss;
+        ss << "Client::handle_write: error (" << e.message() << " ) for request( " << outbound_request_ << " ) on "
+           << host_ << ":" << port_;
+        throw std::runtime_error(ss.str());
+    }
+
+    // Nothing to do. The socket will be closed automatically when the last
+    // reference to the connection object goes away.
+}
+
+void Client::start_read() {
+    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
+    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
+    // executed. If it returns 1 then the wait handler was successfully cancelled.
+
+    // Set a deadline for the read operation.
+    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
+
+    connection_.async_read(inbound_response_,
+                           [this](const boost::system::error_code& error) { this->handle_read(error); });
+}
+
+void Client::handle_read(const boost::system::error_code& e) {
+#ifdef DEBUG_CLIENT
+    std::cout << "   Client::handle_read stopped_ = " << stopped_ << std::endl;
+#endif
+    if (stopped_)
+        return;
+
+    // close socket, & cancel timer.
+    stop();
+
+    if (!e) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   Client::handle_read OK \n";
+        std::cout << "      outbound_request_ = " << outbound_request_ << "\n";
+        std::cout << "      inbound_response_ = " << inbound_response_ << "\n";
+#endif
+        /// ***********************************************************
+        /// ClientInvoker will call back, to handle_server_response.
+        /// ***********************************************************
+        // Successfully handled request
+    }
+    else {
+        //
+        // A connection error occurred. EOF
+        //   - In cases where ( to cut down network traffic),
+        //     the server does a shutdown/closes the socket without replying we will get End of File error.
+        //   - if we have a NONSSL client talking to SSL server, the SSL server will not reply, we will get End of File
+        //   error.
+        //
+        // i.e. client requests a response from the server, and it does not reply(or replies with shutdown/close)
+        // In both cases we will treat as an error
+
+        if (e.value() == boost::asio::error::eof) {
+#ifdef DEBUG_CLIENT
+            std::cout << "   Client::handle_read: End of File (server did not reply or mixing ssl and non-ssl)"
+                      << std::endl;
+#endif
+            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::END_OF_FILE));
+            return;
+        }
+
+        // If we get back Invalid argument. It means server could *NOT* decode client message. Equally client could not
+        // decode server reply
+        //   - Could be boost version of client/server are incompatible
+        //   - 4 series ecflow cannot talk to 5 series ecflow or vice versa
+        // We treat this specially
+        if (e.value() == boost::asio::error::invalid_argument) {
+#ifdef DEBUG_CLIENT
+            std::cout
+                << "   Client::handle_read: Server replied with invalid argument (i.e could not decode client message) "
+                << std::endl;
+#endif
+            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::INVALID_ARGUMENT));
+            return;
+        }
+
+        std::stringstream ss;
+        ss << "Client::handle_read: connection error( " << e.message() << " ) for request( " << outbound_request_
+           << " ) on " << host_ << ":" << port_;
+        throw std::runtime_error(ss.str());
+    }
+
+    // Since we are not starting a new operation the io_service will run out of
+    // work to do and the Client will exit.
+}
+
+void Client::stop() {
+    stopped_ = true;
+    connection_.socket_ll().close();
+    deadline_.cancel();
+}
+
+/// Handle completion of a write operation.
+/// Handle completion of a read operation.
+bool Client::handle_server_response(ServerReply& server_reply, bool debug) const {
+#ifdef DEBUG_PERF
+    ecf::ScopedDurationTimer timer("  Client::handle_server_response");
+#endif
+    if (debug)
+        std::cout << "  Client::handle_server_response" << std::endl;
+    server_reply.set_host_port(host_, port_); // client context, needed by some commands, ie. SServerLoadCmd
+    return inbound_response_.handle_server_response(server_reply, outbound_request_.get_cmd(), debug);
+}
+
+void Client::check_deadline() {
+#ifdef DEBUG_CLIENT
+    std::cout << "   Client::check_deadline stopped_=" << stopped_ << " expires("
+              << to_simple_string(deadline_.expires_at()) << ") time now("
+              << to_simple_string(boost::asio::deadline_timer::traits_type::now()) << ")" << std::endl;
+#endif
+    if (stopped_)
+        return;
+
+    // Check whether the deadline has passed. We compare the deadline against
+    // the current time since a new asynchronous operation may have moved the
+    // deadline before this actor had a chance to run.
+    if (deadline_.expires_at() <= boost::asio::deadline_timer::traits_type::now()) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   Client::check_deadline timed out" << std::endl;
+#endif
+
+        // The deadline has passed. The socket is closed so that any outstanding
+        // asynchronous operations are cancelled.
+        stop();
+
+        std::stringstream ss;
+        ss << "Client::check_deadline: timed out after " << timeout_ << " seconds for request( " << outbound_request_
+           << " ) on " << host_ << ":" << port_;
+        throw std::runtime_error(ss.str());
+    }
+
+    // Put the actor back to sleep.
+    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Client.hpp 5.13.0-1/libs/base/src/ecflow/base/Client.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/Client.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Client.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_Client_HPP
+#define ecflow_base_Client_HPP
+
+#include <boost/asio.hpp>
+
+#include "ecflow/base/ClientToServerRequest.hpp"
+#include "ecflow/base/Connection.hpp"
+#include "ecflow/base/ServerToClientResponse.hpp"
+
+///
+/// \brief  This class acts as the client part. ( in client/server architecture)
+///
+/// \note The plug command can move a node to another server hence the server
+/// itself will NEED to ACT as a client. This is why client lives in Base and
+/// not the Client project
+///
+
+class Client {
+public:
+    /// Constructor starts the asynchronous connect operation.
+    Client(boost::asio::io_service& io_service,
+           Cmd_ptr cmd_ptr,
+           const std::string& host,
+           const std::string& port,
+           int timout = 0);
+    ~Client();
+
+    /// Client side, get the server response, handles reply from server
+    /// Returns true if all is ok, else false if further client action is required
+    /// will throw std::runtime_error for errors
+    bool handle_server_response(ServerReply&, bool debug) const;
+
+private:
+    void start(boost::asio::ip::tcp::resolver::iterator);
+    void stop();
+    void check_deadline();
+
+    bool start_connect(boost::asio::ip::tcp::resolver::iterator);
+    void start_write();
+    void start_read();
+
+    /// Handle completion of a connect operation.
+    void handle_connect(const boost::system::error_code& e, boost::asio::ip::tcp::resolver::iterator endpoint_iterator);
+
+    /// Handle completion of a read operation.
+    void handle_read(const boost::system::error_code& e);
+
+    /// Handle completion of a write operation
+    void handle_write(const boost::system::error_code& e);
+
+private:
+    bool stopped_;
+    std::string host_;                        /// the servers name
+    std::string port_;                        /// the port on the server
+    connection connection_;                   /// The connection to the server.
+    ClientToServerRequest outbound_request_;  /// The request we will send to the server
+    ServerToClientResponse inbound_response_; /// The response we get back from the server
+
+    boost::asio::deadline_timer deadline_;
+
+    //    connect        : timeout_ second
+    //    send request   : timeout_ second
+    //    receive reply  : timeout_ second
+    // Default value of 0 means take the timeout from the command
+    int timeout_;
+};
+
+#endif /* ecflow_base_Client_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ClientOptionsParser.cpp 5.13.0-1/libs/base/src/ecflow/base/ClientOptionsParser.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/ClientOptionsParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ClientOptionsParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,207 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/ClientOptionsParser.hpp"
+
+#include "ecflow/core/Str.hpp"
+
+namespace ecf {
+
+namespace {
+
+bool is_valid_path(const std::string& path) {
+    return !path.empty() && path[0] == '/';
+}
+
+void parse_option(ClientOptionsParser::option_t& option,
+                  ClientOptionsParser::option_set_t& processed_options,
+                  ClientOptionsParser::arguments_set_t& args) {
+    // We must consider two forms of options:
+    //     1) --<option> <arg1>
+    //     2) --<option>=<arg1>
+
+    if (auto found = args[0].find('='); found == std::string::npos) {
+        // In case form 1) is used, we discard the '--<option>'
+        args.erase(args.begin());
+        if (args.empty()) {
+            // This means that the option doesn't actually have a value (i.e. acts as a flag) and we simply return
+            return;
+        }
+        // store the 'arg1'
+        option.value.push_back(args.front());
+        option.original_tokens.push_back(args.front());
+    }
+    else {
+        // Otherwise, form 2) is used, and the first positional value must be
+        // taken by tokenizing the option '--<option>=<arg1>'
+        std::string arg = args[0].substr(found + 1);
+        option.value.push_back(arg);
+        option.original_tokens.push_back(arg);
+    }
+    // Discard the option at the front
+    args.erase(args.begin());
+}
+
+template <typename PREDICATE>
+void parse_positional_arguments(
+    ClientOptionsParser::option_t& option,
+    ClientOptionsParser::option_set_t& processed_options,
+    ClientOptionsParser::arguments_set_t& args,
+    size_t maximum_positional_args,
+    PREDICATE predicate = [](const std::string&) { return true; }) {
+
+    // Collect up to N positional arguments, that satisfy the predicate
+    for (size_t i = 0; i < maximum_positional_args && !args.empty(); ++i) {
+        // Take each of the positional values as an option value
+        std::string& arg = args.front();
+        // Once we find the first argument that doesn't satify the predicate,
+        // we stop collecting arguments
+        if (!predicate(arg)) {
+            break;
+        }
+        option.value.push_back(arg);
+        option.original_tokens.push_back(arg);
+
+        // Remove the argument value
+        args.erase(args.begin());
+    }
+}
+
+void parse_positional_arguments(ClientOptionsParser::option_t& option,
+                                ClientOptionsParser::option_set_t& processed_options,
+                                ClientOptionsParser::arguments_set_t& args,
+                                size_t maximum_positional_args) {
+
+    // Collect up to N positional arguments
+    parse_positional_arguments(
+        option, processed_options, args, maximum_positional_args, [](const std::string&) { return true; });
+}
+
+void parse_alter(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
+
+    // *** Important! ***
+    // This custom handler is needed to ensure that the "--alter" option
+    // special value parameters are handled correctly. For example,
+    // values starting with --, such as "--hello".
+    //
+    // The custom handling will consider that 5+ positional values (not
+    // to be confused with positional arguments) are provided with the
+    // --alter option, as per one of the following forms:
+    //     1) --alter arg1 arg2 arg3 (arg4) path [path [path [...]]]
+    //     2) --alter=arg1 arg2 arg3 (arg4) path [path [path [...]]]
+
+    ClientOptionsParser::option_t alter{std::string{"alter"}, {}};
+
+    // This effectively always collects an argument (i.e. the operation)
+    parse_option(alter, processed_options, args);
+
+    // Collect up to 4 positional arguments, that are not paths
+    parse_positional_arguments(
+        alter, processed_options, args, 4, [](const std::string& arg) { return !is_valid_path(arg); });
+
+    // Collect remaining positional arguments, that are paths
+    parse_positional_arguments(
+        alter, processed_options, args, std::numeric_limits<size_t>::max(), [](const std::string& arg) {
+            return is_valid_path(arg);
+        });
+
+    processed_options.push_back(alter);
+}
+
+void parse_label(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
+
+    // *** Important! ***
+    // This custom handler is needed to ensure that the "--label" option
+    // special value parameters are handled correctly. For example,
+    // values starting with -, such as "-j64".
+    //
+    // The custom handling will consider that 2 positional values (not
+    // to be confused with positional arguments) are provided with the
+    // --label option, as per one of the following forms:
+    //     1) --label arg1 arg2
+    //     2) --label=arg1 arg2
+
+    ClientOptionsParser::option_t label{std::string{"label"}, {}};
+
+    // This effectively always collects an argument (i.e. the label name)
+    parse_option(label, processed_options, args);
+
+    // Collect 1 positional argument (i.e. the label value)
+    parse_positional_arguments(label, processed_options, args, 1);
+
+    processed_options.push_back(label);
+}
+
+void parse_meter(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
+
+    // *** Important! ***
+    // This custom handler is needed to ensure that the "--meter" option
+    // special value parameters are handled correctly. For example,
+    // values starting with -, such as "-1".
+    //
+    // The custom handling will consider that 2 positional values (not
+    // to be confused with positional arguments) are provided with the
+    // --label option, as per one of the following forms:
+    //     1) --label arg1 arg2
+    //     2) --label=arg1 arg2
+
+    ClientOptionsParser::option_t meter{std::string{"meter"}, {}};
+
+    // This effectively always collects an argument (i.e. the meter name)
+    parse_option(meter, processed_options, args);
+
+    // Collect 1 positional argument (i.e. the meter value)
+    parse_positional_arguments(meter, processed_options, args, 1);
+
+    processed_options.push_back(meter);
+}
+
+void parse_abort(ClientOptionsParser::option_set_t& processed_options, ClientOptionsParser::arguments_set_t& args) {
+
+    // *** Important! ***
+    // This custom handler is needed to ensure that the "--abort" option
+    // special value parameters are handled correctly. For example,
+    // values starting with -, such as "--some reason--".
+    //
+    // The custom handling will consider that 2 positional values (not
+    // to be confused with positional arguments) are provided with the
+    // --label option, as per one of the following forms:
+    //     1) --label arg1 arg2
+    //     2) --label=arg1 arg2
+
+    ClientOptionsParser::option_t abort{std::string{"abort"}, {}};
+
+    // This effectively always collects an argument (i.e. the reason text)
+    parse_option(abort, processed_options, args);
+
+    processed_options.push_back(abort);
+}
+
+} // namespace
+
+ClientOptionsParser::option_set_t ClientOptionsParser::operator()(ClientOptionsParser::arguments_set_t& args) {
+    option_set_t processed_options;
+
+    if (ecf::algorithm::starts_with(args[0], "--alter")) {
+        parse_alter(processed_options, args);
+    }
+    else if (ecf::algorithm::starts_with(args[0], "--label")) {
+        parse_label(processed_options, args);
+    }
+    else if (ecf::algorithm::starts_with(args[0], "--meter")) {
+        parse_meter(processed_options, args);
+    }
+    else if (ecf::algorithm::starts_with(args[0], "--abort")) {
+        parse_abort(processed_options, args);
+    }
+    return processed_options;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ClientOptionsParser.hpp 5.13.0-1/libs/base/src/ecflow/base/ClientOptionsParser.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/ClientOptionsParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ClientOptionsParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_ClientOptionsParser_HPP
+#define ecflow_base_ClientOptionsParser_HPP
+
+#include <string>
+#include <vector>
+
+#include <boost/program_options.hpp>
+
+namespace ecf {
+
+struct ClientOptionsParser
+{
+    using option_t        = boost::program_options::option;
+    using option_set_t    = std::vector<option_t>;
+    using arguments_set_t = std::vector<std::string>;
+
+    option_set_t operator()(arguments_set_t& args);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_base_ClientOptionsParser_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ClientToServerRequest.cpp 5.13.0-1/libs/base/src/ecflow/base/ClientToServerRequest.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/ClientToServerRequest.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ClientToServerRequest.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/ClientToServerRequest.hpp"
+
+#include <stdexcept>
+
+using namespace std;
+
+STC_Cmd_ptr ClientToServerRequest::handleRequest(AbstractServer* as) const {
+    if (cmd_.get()) {
+        return cmd_->handleRequest(as);
+    }
+
+    /// means programming error somewhere
+    throw std::runtime_error("ClientToServerRequest::handleRequest: Cannot send a NULL request to the server !");
+}
+
+std::ostream& ClientToServerRequest::print(std::ostream& os) const {
+    if (cmd_.get()) {
+        os << cmd_->print_short(); // avoid printing hundreds of paths in the command
+        return os;
+    }
+    return os << "NULL request";
+}
+
+bool ClientToServerRequest::operator==(const ClientToServerRequest& rhs) const {
+    if (!cmd_.get() && !rhs.cmd_.get()) {
+        return true;
+    }
+    if (cmd_.get() && !rhs.cmd_.get()) {
+        return false;
+    }
+    if (!cmd_.get() && rhs.cmd_.get()) {
+        return false;
+    }
+    return (cmd_->equals(rhs.cmd_.get()));
+}
+
+std::ostream& operator<<(std::ostream& os, const ClientToServerRequest& d) {
+    return d.print(os);
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ClientToServerRequest.hpp 5.13.0-1/libs/base/src/ecflow/base/ClientToServerRequest.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/ClientToServerRequest.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ClientToServerRequest.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,61 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_ClientToServerRequest_HPP
+#define ecflow_base_ClientToServerRequest_HPP
+
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+
+// Base class for client to server requesting.
+// This class is used in the IPC messaging from  client to server.
+class ClientToServerRequest {
+public:
+    ClientToServerRequest()                             = default;
+    ClientToServerRequest(const ClientToServerRequest&) = delete;
+    ~ClientToServerRequest()                            = default;
+
+    ClientToServerRequest& operator=(const ClientToServerRequest&) = delete;
+
+    void set_cmd(const Cmd_ptr& cmd) {
+        cmd_ = cmd;
+        cmd_->setup_user_authentification();
+    }
+    Cmd_ptr get_cmd() const { return cmd_; }
+
+    /// This is called in the server only, to handle the quest.
+    STC_Cmd_ptr handleRequest(AbstractServer*) const;
+
+    std::ostream& print(std::ostream& os) const;
+
+    bool getRequest() const { return (cmd_.get()) ? cmd_->get_cmd() : false; }
+    bool terminateRequest() const { return (cmd_.get()) ? cmd_->terminate_cmd() : false; }
+    bool groupRequest() const { return (cmd_.get()) ? cmd_->group_cmd() : false; }
+
+    void cleanup() {
+        if (cmd_.get())
+            cmd_->cleanup();
+    } // reclaim memory *AFTER* command has run
+
+    /// Used by boost test, to verify persistence
+    bool operator==(const ClientToServerRequest& rhs) const;
+
+private:
+    Cmd_ptr cmd_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar) {
+        ar(CEREAL_NVP(cmd_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ClientToServerRequest& d);
+
+#endif /* ecflow_base_ClientToServerRequest_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Cmd.hpp 5.13.0-1/libs/base/src/ecflow/base/Cmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/Cmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Cmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_Cmd_HPP
+#define ecflow_base_Cmd_HPP
+
+#include <memory>
+
+class ClientToServerCmd;
+class ServerToClientCmd;
+class ServerReply;
+
+typedef std::shared_ptr<ClientToServerCmd> Cmd_ptr;
+typedef std::shared_ptr<ServerToClientCmd> STC_Cmd_ptr;
+
+#endif /* ecflow_base_Cmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Connection.cpp 5.13.0-1/libs/base/src/ecflow/base/Connection.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/Connection.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Connection.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/Connection.hpp"
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Log.hpp"
+
+connection::~connection() {
+#ifdef DEBUG_CONNECTION
+    if (Ecf::server())
+        std::cout << "SERVER: Connection::~connection  socket_.is_open() = " << socket_.is_open() << "\n\n";
+    else
+        std::cout << "CLIENT: Connection::~connection  socket_.is_open() = " << socket_.is_open() << "\n\n";
+#endif
+}
+
+connection::connection(boost::asio::io_service& io_service) : socket_(io_service) {
+#ifdef DEBUG_CONNECTION
+    if (Ecf::server())
+        std::cout << "SERVER: Connection::connection\n";
+    else
+        std::cout << "CLIENT: Connection::connection\n";
+#endif
+}
+
+void connection::log_error(const char* msg) {
+    const char* in_context = ", in client";
+    if (Ecf::server())
+        in_context = ", in server";
+    ecf::LogToCout logToCout;
+    LOG(ecf::Log::ERR, msg << in_context);
+}
+
+void connection::log_archive_error(const char* msg, const std::exception& ae, const std::string& data) {
+    const char* in_context = ", in client";
+    if (Ecf::server())
+        in_context = ", in server";
+    ecf::LogToCout logToCout;
+    LOG(ecf::Log::ERR, msg << ae.what() << in_context << " data:\n" << data);
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Connection.hpp 5.13.0-1/libs/base/src/ecflow/base/Connection.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/Connection.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Connection.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,221 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_Connection_HPP
+#define ecflow_base_Connection_HPP
+
+///
+/// \brief Serves as the connection between client server
+///
+/// \note If you change this file then ssl_connection.hpp may also need changing
+///
+
+#if defined(HPUX)
+    #include <sys/select.h> // hp-ux uses pselect
+#endif
+
+#include <iomanip>
+#include <memory>
+#include <sstream>
+
+#include <boost/asio.hpp>
+
+#include "ecflow/core/Serialization.hpp"
+
+// #define DEBUG_CONNECTION 1
+#ifdef DEBUG_CONNECTION
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+/// The connection class provides serialisation primitives on top of a socket.
+/**
+ * Each message sent using this class consists of:
+ * @li An 8-byte header containing the length of the serialized data in
+ * hexadecimal.
+ * @li The serialized data.
+ */
+class connection {
+public:
+    ~connection();
+
+    explicit connection(boost::asio::io_service& io_service);
+    boost::asio::ip::tcp::socket& socket() { return socket_; }
+    boost::asio::ip::tcp::socket& socket_ll() { return socket_; }
+
+    /// Asynchronously write a data structure to the socket.
+    template <typename T, typename Handler>
+    void async_write(const T& t, Handler handler) {
+
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: Connection::async_write\n";
+        else
+            std::cout << "CLIENT: Connection::async_write\n";
+        std::cout << "   Serialise the data first so we know how large it is\n";
+#endif
+        // Serialise the data first so we know how large it is.
+        try {
+            ecf::save_as_string(outbound_data_, t);
+        }
+        catch (const std::exception& ae) {
+            // Unable to decode data. Something went wrong, inform the caller.
+            log_archive_error("Connection::async_write, exception ", ae, outbound_data_);
+            boost::asio::post(socket_.get_executor(), [handler]() { handler(boost::asio::error::invalid_argument); });
+            return;
+        }
+
+#ifdef DEBUG_CONNECTION
+        std::cout << "   Format the header:\n";
+#endif
+        // Format the header.
+        std::ostringstream header_stream;
+        header_stream << std::setw(header_length) << std::hex << outbound_data_.size();
+        if (!header_stream || header_stream.str().size() != header_length) {
+            // Something went wrong, inform the caller.
+            log_error("Connection::async_write, could not format header");
+            boost::asio::post(socket_.get_executor(), [handler]() { handler(boost::asio::error::invalid_argument); });
+            return;
+        }
+        outbound_header_ = header_stream.str();
+
+#ifdef DEBUG_CONNECTION
+        std::cout << "   Write the HEADER and serialised DATA to the socket\n";
+        std::cout << "   outbound_header_.size(" << outbound_header_.size() << ")\n";
+        std::cout << "   outbound_header_:'" << outbound_header_ << "' # this is the size in hex\n";
+        std::cout << "   outbound_data_.size(" << outbound_data_.size() << ")\n";
+        std::cout << "   hdr+data:'" << outbound_header_ << outbound_data_ << "'\n";
+#endif
+        // Write the serialized data to the socket. We use "gather-write" to send
+        // both the header and the data in a single write operation.
+        std::vector<boost::asio::const_buffer> buffers;
+        buffers.reserve(2);
+        buffers.emplace_back(boost::asio::buffer(outbound_header_));
+        buffers.emplace_back(boost::asio::buffer(outbound_data_));
+        boost::asio::async_write(
+            socket_, buffers, [handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
+                handler(error);
+            });
+
+#ifdef DEBUG_CONNECTION
+        std::cout << "   END\n";
+#endif
+    }
+
+    /// Asynchronously read a data structure from the socket.
+    template <typename T, typename Handler>
+    void async_read(T& t, Handler handler) {
+
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: Connection::async_read\n";
+        else
+            std::cout << "CLIENT: Connection::async_read\n";
+#endif
+
+        // Issue a read operation to read exactly the number of bytes in a header
+        boost::asio::async_read(
+            socket_,
+            boost::asio::buffer(inbound_header_),
+            [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
+                this->handle_read_header(error, t, handler);
+            });
+    }
+
+private:
+    /// Handle a completed read of a message header.
+    template <typename T, typename Handler>
+    void handle_read_header(const boost::system::error_code& e, T& t, Handler handler) {
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: Connection::handle_read_header\n";
+        else
+            std::cout << "CLIENT: Connection::handle_read_header\n";
+        std::cout << "   header:'" << std::string(inbound_header_, header_length)
+                  << "'  # this size of payload in hex\n";
+#endif
+        if (e) {
+            handler(e);
+        }
+        else {
+            // Determine the length of the serialized data.
+            std::istringstream is(std::string(inbound_header_, header_length));
+            std::size_t inbound_data_size = 0;
+            if (!(is >> std::hex >> inbound_data_size)) {
+
+                // Header doesn't seem to be valid. Inform the caller.
+                std::string err =
+                    "Connection::handle_read_header: invalid header : " + std::string(inbound_header_, header_length);
+                log_error(err.c_str());
+                handler(boost::asio::error::invalid_argument);
+                return;
+            }
+
+            // Start an asynchronous call to receive the data.
+            inbound_data_.resize(inbound_data_size);
+            boost::asio::async_read(
+                socket_,
+                boost::asio::buffer(inbound_data_),
+                [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
+                    this->handle_read_data(error, t, handler);
+                });
+        }
+    }
+
+    /// Handle a completed read of message data.
+    template <typename T, typename Handler>
+    void handle_read_data(const boost::system::error_code& e, T& t, Handler handler) {
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: Connection::handle_read_data\n";
+        else
+            std::cout << "CLIENT: Connection::handle_read_data\n";
+#endif
+
+        if (e) {
+            handler(e);
+        }
+        else {
+            // Extract the data structure from the data just received.
+            std::string archive_data(&inbound_data_[0], inbound_data_.size());
+            try {
+#ifdef DEBUG_CONNECTION
+                std::cout << "   inbound_data_.size(" << inbound_data_.size() << ") typeid(" << typeid(t).name()
+                          << ")\n";
+                std::cout << "   '" << archive_data << "'\n";
+#endif
+                ecf::restore_from_string(archive_data, t);
+            }
+            catch (std::exception& e) {
+                log_archive_error("Connection::handle_read_data, Unable to decode data :", e, archive_data);
+                handler(boost::asio::error::invalid_argument);
+                return;
+            }
+
+            // Inform caller that data has been received ok.
+            handler(e);
+        }
+    }
+
+private:
+    static void log_error(const char* msg);
+    static void log_archive_error(const char* msg, const std::exception& ae, const std::string& data);
+
+private:
+    boost::asio::ip::tcp::socket socket_; /// The underlying socket.
+    std::string outbound_header_;         /// Holds an out-bound header.
+    std::string outbound_data_;           /// Holds the out-bound data.
+    enum { header_length = 8 };           /// The size of a fixed length header.
+    char inbound_header_[header_length];  /// Holds an in-bound header.
+    std::vector<char> inbound_data_;      /// Holds the in-bound data.
+};
+
+typedef std::shared_ptr<connection> connection_ptr;
+
+#endif /* ecflow_base_Connection_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Gnuplot.cpp 5.13.0-1/libs/base/src/ecflow/base/Gnuplot.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/Gnuplot.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Gnuplot.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,394 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/Gnuplot.hpp"
+
+#include <cassert>
+#include <iostream>
+#include <sstream>
+#include <stdexcept>
+#include <vector>
+
+#include <sys/stat.h> // for chmod
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/File_r.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/NodePath.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+Gnuplot::Gnuplot(const std::string& log_file,
+                 const std::string& host,
+                 const std::string& port,
+                 size_t no_of_suites_to_plot)
+    : log_file_(log_file),
+      host_(host),
+      port_(port),
+      no_of_suites_to_plot_(no_of_suites_to_plot) {
+    if (!fs::exists(log_file)) {
+        std::stringstream ss;
+        ss << "Gnuplot::Gnuplot: The log file " << log_file << " does not exist\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string path_to_gnuplot = File::which("gnuplot");
+    if (path_to_gnuplot.empty()) {
+        std::stringstream ss;
+        ss << "Gnuplot::Gnuplot: could not find gnuplot on $PATH.";
+        throw std::runtime_error(ss.str());
+    }
+}
+
+void Gnuplot::show_server_load() const {
+    std::string gnuplot_dat_file    = host_.prefix_host_and_port(port_, "gnuplot.dat");
+    std::string gnuplot_script_file = host_.prefix_host_and_port(port_, "gnuplot.script");
+
+    // The vector index is the order in which suites are found, this will be used to place the suite in the correct
+    // column
+    std::vector<SuiteLoad> suite_vec;
+    std::string gnuplot_file = create_gnuplot_file(suite_vec, gnuplot_dat_file);
+    std::string gnuplot_script =
+        create_gnuplot_script(gnuplot_file, suite_vec, no_of_suites_to_plot_, gnuplot_script_file);
+
+    // make the gnuplot_script file executable
+    if (chmod(gnuplot_script.c_str(), 0755) != 0) {
+        std::stringstream ss;
+        ss << "Gnuplot::show_server_load: Could not make gnu script file " << gnuplot_script
+           << "  executable by using chmod";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string execute_gnuplot = "gnuplot " + gnuplot_script;
+    ::system(execute_gnuplot.c_str());
+}
+
+std::string Gnuplot::create_gnuplot_file(std::vector<SuiteLoad>& suite_vec, const std::string& temp_file) const {
+    /// Will read the log file and create a new file that can be used as input to gnuplot
+    /// We will collate each request/cmd to the server made over a second.
+    /// There are two kinds of commands:
+    ///   o User Commands: these start with --
+    ///   o Child Command: these start with chd:
+    /// All child commands specify a path and hence suite, whereas for user commands this is optional
+    /// We will trap all use of paths, so that we can show which suites are contributing to the server load
+    /// This will be done for 4 suites
+    ///
+    /// Will convert: FROM:
+    ///   XXX:[HH:MM:SS D.M.YYYY] chd:init [+additional information]
+    ///   XXX:[HH:MM:SS D.M.YYYY] --begin  [+additional information]
+    /// -------------: TO:
+    ///    1         2         3             4              5            6        7       8         9       10
+    ///  HH:MM:SS D.M.YYYY request/sec  child_request  users_requests  suite_0 suite_1  suite_2  suite_3  suite_n
+
+    /// The log file can be massive > 50Mb
+    File_r log_file(log_file_);
+    if (!log_file.ok())
+        throw std::runtime_error("Gnuplot::prepare_for_gnuplot: Could not open log file " + log_file_);
+
+    /// Create a new file that can be used with gnuplot. This has to be column based
+    std::ofstream gnuplot_file(temp_file.c_str());
+    if (!gnuplot_file) {
+        throw std::runtime_error("Gnuplot::prepare_for_gnuplot: Could not open output file: " + temp_file);
+    }
+
+    gnuplot_file << "#time    date     total-request child user suite_0  suite_1 suite_2  suite_3  suite_n\n";
+
+    std::vector<std::string> new_time_stamp;
+    std::vector<std::string> old_time_stamp;
+    size_t child_requests_per_second   = 0;
+    size_t user_request_per_second     = 0;
+    unsigned int plot_data_line_number = 0;
+    string line;
+    while (log_file.good()) {
+        log_file.getline(line); // default delimiter is /n
+
+        // The log file format we are interested is :
+        // 0             1         2            3
+        // MSG:[HH:MM:SS D.M.YYYY] chd:fullname [path +additional information]
+        // MSG:[HH:MM:SS D.M.YYYY] --begin      [args | path(optional) ]    :<user>
+
+        /// We are only interested in Commands (i.e MSG:), and not state changes
+        if (line.empty())
+            continue;
+        if (line[0] != 'M')
+            continue;
+        std::string::size_type msg_pos = line.find("MSG:");
+        if (msg_pos != 0)
+            continue;
+
+        bool child_cmd = false;
+        bool user_cmd  = false;
+        if (line.find(Str::CHILD_CMD()) != std::string::npos)
+            child_cmd = true;
+        else if (line.find(Str::USER_CMD()) != std::string::npos)
+            user_cmd = true;
+        if (!child_cmd && !user_cmd)
+            continue;
+
+        new_time_stamp.clear();
+        {
+            /// MSG:[HH:MM:SS D.M.YYYY] chd:fullname [+additional information] ---> HH:MM:SS D.M.YYYY
+            /// EXTRACT the date
+            string::size_type first_open_bracket = line.find('[');
+            if (first_open_bracket == std::string::npos) {
+                std::cout << line << "\n";
+                assert(false);
+                continue;
+            }
+            line.erase(0, first_open_bracket + 1);
+
+            string::size_type first_closed_bracket = line.find(']');
+            if (first_closed_bracket == std::string::npos) {
+                std::cout << line << "\n";
+                assert(false);
+                continue;
+            }
+            std::string time_stamp = line.substr(0, first_closed_bracket);
+
+            Str::split(time_stamp, new_time_stamp);
+            if (new_time_stamp.size() != 2)
+                continue;
+
+            line.erase(0, first_closed_bracket + 1);
+        }
+
+        // Should be just left with " chd:<child command> " or " --<user command>, since we have remove time stamp
+        // #ifdef DEBUG
+        //       std::cout << line << "\n";
+        // #endif
+
+        if (old_time_stamp.empty()) {
+            if (child_cmd)
+                child_requests_per_second++;
+            else
+                user_request_per_second++;
+
+            // Extract path if any, to determine the suite most contributing to server load
+            size_t column_index   = 0;
+            bool suite_path_found = extract_suite_path(line, child_cmd, suite_vec, column_index);
+            if (suite_path_found)
+                assert(suite_vec[column_index].request_per_second_ <=
+                       (child_requests_per_second + user_request_per_second));
+        }
+        else if (old_time_stamp[0] == new_time_stamp[0]) { // HH:MM:SS == HH:MM:SS
+            if (child_cmd)
+                child_requests_per_second++;
+            else
+                user_request_per_second++;
+
+            size_t column_index   = 0;
+            bool suite_path_found = extract_suite_path(line, child_cmd, suite_vec, column_index);
+            if (suite_path_found)
+                assert(suite_vec[column_index].request_per_second_ <=
+                       (child_requests_per_second + user_request_per_second));
+        }
+        else {
+            /// Start of *NEW* time,
+            /// write the *OLD* time line should contain time date without []
+            ///    1         2         3             4              5            6        7      8       9       10
+            ///  HH:MM:SS D.M.YYYY total_request child_request  users_requests suite_0 suite_1 suite_2 suite_3 suite_n
+            plot_data_line_number++;
+            gnuplot_file << old_time_stamp[0] << " " << old_time_stamp[1] << " "
+                         << (child_requests_per_second + user_request_per_second) << " " << child_requests_per_second
+                         << " " << user_request_per_second << " ";
+            for (auto& i : suite_vec) {
+                gnuplot_file << i.request_per_second_ << " ";
+            }
+            gnuplot_file << "\n";
+
+            // clear request per second
+            child_requests_per_second = 0;
+            user_request_per_second   = 0;
+            for (auto& i : suite_vec) {
+                i.request_per_second_ = 0;
+            }
+
+            // start of *new* time
+            if (child_cmd)
+                child_requests_per_second++;
+            else
+                user_request_per_second++;
+
+            size_t column_index   = 0;
+            bool suite_path_found = extract_suite_path(line, child_cmd, suite_vec, column_index);
+            if (suite_path_found)
+                assert(suite_vec[column_index].request_per_second_ <=
+                       (child_requests_per_second + user_request_per_second));
+        }
+
+        old_time_stamp = new_time_stamp;
+    }
+
+    if (plot_data_line_number < 3) {
+        throw std::runtime_error("Gnuplot::prepare_for_gnuplot: Log file empty or not enough data for plot\n");
+    }
+    return temp_file;
+}
+
+std::string Gnuplot::create_gnuplot_script(const std::string& path_to_file,
+                                           const std::vector<SuiteLoad>& suite_vec,
+                                           size_t no_of_suites_to_plot,
+                                           const std::string& script) const {
+    /// Create the gnuplot script file for rendering the graph
+    std::ofstream gnuplot_script(script.c_str());
+    if (!gnuplot_script) {
+        throw std::runtime_error("Gnuplot::create_gnuplot_script: Could not open output file: " + script);
+    }
+
+    gnuplot_script << "set term png\n";
+    gnuplot_script << "set output \"" << host_.name() << "." << port_ << ".png\"\n";
+
+    gnuplot_script << "set autoscale                          # scale axes automatically\n";
+    gnuplot_script << "set xtic auto rotate                   # set xtics automatically\n";
+    gnuplot_script << "set ytic auto                          # set ytics automatically\n";
+    //   gnuplot_script << "set origin 0,0.08                      # offset y, so that rotated xtics don't truncate,
+    //   However cause title to disappear\n";
+    gnuplot_script << "set title \"Server request per second\"\n";
+    gnuplot_script << "set x2label \"time/min\" textcolor lt 3\n";
+    gnuplot_script << "set ylabel \"requests\"\n";
+    gnuplot_script << "set xdata time\n";
+    gnuplot_script << "set grid                             # show grid\n";
+    gnuplot_script << "set timefmt \"%H:%M:%S %d.%m.%Y\"\n";
+
+    // # LINE COLORS, STYLES
+    // # type 'test' to see the colors and point types available.
+    // # Differs from x11 to postscript
+    // # lt chooses a particular line type: -1=black 1=red 2=grn 3=blue 4=purple 5=aqua 6=brn 7=orange 8=light-brn
+    // # lt must be specified before pt for colored points
+    // # for postscipt -1=normal, 1=grey, 2=dashed, 3=hashed, 4=dot, 5=dot-dash
+    // # lw chooses a line width 1=normal, can use 0.8, 0.3, 1.5, 3, etc.
+    // # ls chooses a line style
+
+    ///    1         2         3             4              5            6        7       8         9       n
+    ///  HH:MM:SS D.M.YYYY total_request child_request  users_requests suite_0 suite_1  suite_2  suite_3  suite_n
+
+    // determine which suite columns to plot based on server load
+    std::vector<SuiteLoad> suite_vec_copy = suite_vec;
+
+    //   cout << "sort vector according to load\n";
+    std::sort(suite_vec_copy.begin(), suite_vec_copy.end(), [](const SuiteLoad& a, const SuiteLoad& b) {
+        return a.total_request_per_second_ > b.total_request_per_second_;
+    });
+    //   for(size_t i = 0; i < suite_vec_copy.size(); i++) {
+    //      cout << " " << suite_vec_copy[i].first << " " << suite_vec_copy[i].second << "\n";
+    //   }
+
+    //   cout << "get top loaded suites\n";
+    std::vector<std::string> suites;
+    for (size_t i = 0; i < suite_vec_copy.size() && i < no_of_suites_to_plot; i++) {
+        suites.push_back(suite_vec_copy[i].suite_name_);
+    }
+    //   std::copy(suites.begin(), suites.end(), std::ostream_iterator <std::string> (std::cout, "\n"));
+
+    //   cout << "now determine which columns the top suites belong to, **THIS** time <int> indicates column\n";
+    std::vector<std::pair<std::string, int>> ordered_suites;
+    for (size_t column = 0; column < suite_vec.size(); column++) {
+        for (auto& suite : suites) {
+            if (suite == suite_vec[column].suite_name_) {
+                ordered_suites.emplace_back(suite, column);
+            }
+        }
+    }
+    //   for(size_t i = 0; i < ordered_suites.size(); i++) {
+    //      cout << " " << ordered_suites[i].first << " " << ordered_suites[i].second << "\n";
+    //   }
+
+    gnuplot_script << "plot \"" << path_to_file << R"(" using 1:4 title "child" with lines, ")" << path_to_file
+                   << R"(" using 1:5 title "user" with lines, ")" << path_to_file
+                   << R"(" using 1:3 smooth bezier title "total-load" with lines lt 3)";
+    if (!ordered_suites.empty())
+        gnuplot_script << ",";
+    else
+        gnuplot_script << "\n";
+    for (size_t i = 0; i < ordered_suites.size(); i++) {
+        gnuplot_script << "\"" << path_to_file << "\" using 1:" << (6 + ordered_suites[i].second)
+                       << " smooth bezier title \"" << ordered_suites[i].first << "\" with lines";
+        if (i == ordered_suites.size() - 1)
+            gnuplot_script << "\n";
+        else
+            gnuplot_script << ",";
+    }
+
+    //   gnuplot_script << "pause -1 \"Hit any key to continue\"\n\n";
+
+    return script;
+}
+
+bool Gnuplot::extract_suite_path(const std::string& line,
+                                 bool child_cmd,
+                                 std::vector<SuiteLoad>& suite_vec,
+                                 size_t& column_index // 0 based
+) {
+    // line should either
+    //  chd:<childcommand> path
+    //  --<user command)   path<optional> :<user>
+    size_t forward_slash = line.find('/');
+    if (forward_slash != std::string::npos) {
+
+        std::string path;
+        if (child_cmd) {
+
+            // For labels ignore paths in the label part
+            // MSG:[14:55:04 17.10.2013] chd:label progress 'core/nodeattr/nodeAParser'
+            // /suite/build/cray/cray_gnu/build_release/test
+            if (line.find("chd:label") != std::string::npos) {
+                size_t last_tick = line.rfind("'");
+                if (last_tick != std::string::npos) {
+                    size_t the_forward_slash = line.find('/', last_tick);
+                    if (the_forward_slash != std::string::npos) {
+                        forward_slash = the_forward_slash;
+                    }
+                }
+            }
+            path = line.substr(forward_slash);
+        }
+        else {
+            // Ignore the --news command, they dont have a path, hence i.e to ignore line like:
+            //  MSG:[09:36:05 22.10.2013] --news=1 36506 6  :ma0 [server handle(36508,7) server(36508,7)
+            //                     : *Large* scale changes (new handle or suites added/removed) :NEWS]
+            //   the /removed was being interpreted as a suite
+            if (line.find("--news") != std::string::npos)
+                return false;
+        }
+
+        // find the space after the path
+        size_t space_pos = line.find(" ", forward_slash);
+        if (space_pos != std::string::npos && space_pos > forward_slash) {
+            path = line.substr(forward_slash, space_pos - forward_slash);
+        }
+
+        if (!path.empty()) {
+
+            std::vector<std::string> theNodeNames;
+            theNodeNames.reserve(4);
+            NodePath::split(path, theNodeNames);
+            if (!theNodeNames.empty()) {
+                for (size_t n = 0; n < suite_vec.size(); n++) {
+                    if (suite_vec[n].suite_name_ == theNodeNames[0]) {
+                        suite_vec[n].request_per_second_++;
+                        suite_vec[n].total_request_per_second_++;
+                        column_index = n;
+                        return true;
+                    }
+                }
+
+                suite_vec.emplace_back(theNodeNames[0]);
+                column_index = suite_vec.size() - 1;
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Gnuplot.hpp 5.13.0-1/libs/base/src/ecflow/base/Gnuplot.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/Gnuplot.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Gnuplot.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,81 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_Gnuplot_HPP
+#define ecflow_base_Gnuplot_HPP
+
+#include <string>
+#include <vector>
+
+#include "ecflow/core/Host.hpp"
+
+///
+/// \brief Encompasses functionality for plotting server load
+///
+
+namespace ecf {
+
+class Gnuplot {
+public:
+    Gnuplot()               = delete;
+    Gnuplot(const Gnuplot&) = delete;
+    Gnuplot(const std::string& log_file,
+            const std::string& host,
+            const std::string& port,
+            size_t no_of_suites_to_plot = 5);
+
+    Gnuplot& operator=(const Gnuplot&) = delete;
+
+    /// parse the log file and show gnuplot of server load
+    /// Include the suite most contributing to the load
+    /// generates two files
+    ///    o <host>.<port>.gnuplot.dat
+    ///    o <host>.<port>.gnuplot.script
+    void show_server_load() const;
+
+private:
+    std::string log_file_;
+    Host host_;
+    std::string port_;
+    size_t no_of_suites_to_plot_;
+
+private:
+    struct SuiteLoad
+    {
+        explicit SuiteLoad(const std::string& name)
+            : suite_name_(name),
+              request_per_second_(1),
+              total_request_per_second_(1) {}
+
+        std::string suite_name_;
+        size_t request_per_second_;
+        size_t total_request_per_second_;
+    };
+
+    /// Returns that path to file created by this function.
+    /// The create file is to be used by gnuplot to show the server load.
+    ///  Can throw exceptions
+    std::string create_gnuplot_file(std::vector<SuiteLoad>& suite_vec, const std::string& input_data) const;
+
+    /// returns the path to the gnuplot script
+    std::string create_gnuplot_script(const std::string& path_to_file,
+                                      const std::vector<SuiteLoad>& suite_vec,
+                                      size_t no_of_suites_to_plot,
+                                      const std::string& script) const;
+
+    static bool extract_suite_path(const std::string& line,
+                                   bool child_cmd,
+                                   std::vector<SuiteLoad>& suite_vec,
+                                   size_t& column_index // 0 based
+    );
+};
+} // namespace ecf
+
+#endif /* ecflow_base_Gnuplot_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Openssl.cpp 5.13.0-1/libs/base/src/ecflow/base/Openssl.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/Openssl.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Openssl.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,293 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/Openssl.hpp"
+
+#include <cassert>
+#include <cstdlib> // getenv
+#include <stdexcept>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+std::string Openssl::info() const {
+    if (ssl_ == "1")
+        return "1 : enabled : uses shared ssl certificates";
+    return ssl_ + " : enabled : uses server/port specific ssl certificates";
+}
+
+bool Openssl::enable_no_throw(std::string host, const std::string& port, const std::string& ecf_ssl_env) {
+    if (host == Str::LOCALHOST())
+        host = Host().name();
+
+    //   if (Ecf::server()) cout << "Openssl::enable(SERVER) ---> input host:" << host << " port:" << port << " ECF_SSL
+    //   = " << ecf_ssl_env << "\n"; else               cout << "Openssl::enable(CLIENT) ---> input host:" << host << "
+    //   port:" << port << " ECF_SSL = " << ecf_ssl_env << "\n";
+
+    if (ecf_ssl_env.empty() || ecf_ssl_env == "1") {
+        // LOOK for      $HOME/.ecflowrc/ssl/server.crt
+        // THEN LOOK for $HOME/.ecflowrc/ssl/<host>.<port>.crt
+        // Look for the certificate that HAVE to exist on both client and server. i.e Self signed certificate (CRT)
+        // Needed for testing, avoid <host>.<port>.crt when ports numbers are auto generated
+        ssl_ = "1";
+        if (!fs::exists(crt())) { // crt() uses ssl_
+
+            // More specific per server. But we take an extra hit on file access.
+            ssl_ = host;
+            ssl_ += ".";
+            ssl_ += port;
+            if (!fs::exists(crt())) { // crt() uses ssl_
+                ssl_.clear();
+                return false;
+            }
+        }
+    }
+    else {
+        ssl_ = host;
+        ssl_ += ".";
+        ssl_ += port;
+        if (!fs::exists(crt())) { // crt() uses ssl_
+            ssl_.clear();
+            return false;
+        }
+    }
+    // cout << "Openssl::enable input ssl_:'" << ssl_ << "'\n";
+    return true;
+}
+
+void Openssl::enable(std::string host, const std::string& port) {
+    if (host == Str::LOCALHOST())
+        host = Host().name();
+
+    if (!enable_no_throw(host, port)) {
+        std::stringstream ss;
+        ss << "Openssl::enable: Error: Expected to find the self signed certificate file(CRT) server.crt or " << host
+           << "." << port << ".crt in $HOME/.ecflowrc/ssl";
+        throw std::runtime_error(ss.str());
+    }
+}
+
+void Openssl::enable_if_defined(std::string host, const std::string& port) {
+    char* ecf_ssl = getenv("ECF_SSL");
+    if (ecf_ssl) {
+        std::string ecf_ssl_env = ecf_ssl;
+
+        if (host == Str::LOCALHOST())
+            host = Host().name();
+
+        if (!enable_no_throw(host, port, ecf_ssl_env)) {
+            std::stringstream ss;
+            if (ecf_ssl_env == "1") {
+                ss << "Openssl::enable: Error: Expected to find the self signed certificate file(CRT) server.crt *OR* "
+                   << host << "." << port << ".crt in $HOME/.ecflowrc/ssl when ECF_SSL=1";
+            }
+            else {
+                ss << "Openssl::enable: Error: Expected to find the self signed certificate file(CRT) " << host << "."
+                   << port << ".crt in $HOME/.ecflowrc/ssl when ECF_SSL=" << host << "." << port;
+            }
+            throw std::runtime_error(ss.str());
+        }
+    }
+}
+
+boost::asio::ssl::context& Openssl::context() {
+    assert(ssl_context_);
+    return *ssl_context_;
+}
+
+void Openssl::init_for_server() {
+    //   std::cout << " Openssl::init_for_server  host :" << host_ << "@" << port_ << "\n";
+    //   std::cout << " Openssl::init_for_server ssl_:'" << ssl_ << "'\n";
+    if (enabled()) {
+        check_server_certificates();
+
+        ssl_context_ = std::make_unique<boost::asio::ssl::context>(boost::asio::ssl::context::sslv23);
+        ssl_context_->set_options(boost::asio::ssl::context::default_workarounds | boost::asio::ssl::context::no_sslv2 |
+                                  boost::asio::ssl::context::single_dh_use);
+        // this must be done before loading any keys. as below
+        ssl_context_->set_password_callback(
+            [this](std::size_t size, boost::asio::ssl::context_base::password_purpose purpose) {
+                return this->get_password();
+            });
+        ssl_context_->use_certificate_chain_file(crt());
+        ssl_context_->use_private_key_file(key(), boost::asio::ssl::context::pem);
+        ssl_context_->use_tmp_dh_file(pem());
+    }
+}
+
+void Openssl::init_for_client() {
+    //   std::cout << " Openssl::init_for_client host :" << host_ << "@" << port_ << "\n";
+    if (!init_for_client_ && enabled()) {
+        init_for_client_ = true;
+
+        ssl_context_ = std::make_unique<boost::asio::ssl::context>(boost::asio::ssl::context::sslv23);
+        ssl_context_->load_verify_file(crt());
+    }
+}
+
+std::string Openssl::get_password() const {
+    // std::cout << "Openssl::get_password()\n";
+    std::string passwd_file = passwd();
+    if (fs::exists(passwd_file)) {
+        std::string contents;
+        if (ecf::File::open(passwd_file, contents)) {
+            // remove /n added by editor.
+            if (!contents.empty() && contents[contents.size() - 1] == '\n')
+                contents.erase(contents.begin() + contents.size() - 1);
+            // std::cout << "Server::get_password() passwd('" << contents << "')\n";
+            return contents;
+        }
+        else {
+            std::stringstream ss;
+            ss << "Server::get_password file " << passwd_file << " exists, but can't be opened (" << strerror(errno)
+               << ")";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    // std::cout << "Server::get_password() passwd('test')\n";
+    return "test";
+}
+
+std::string Openssl::certificates_dir() const {
+    std::string home_path = getenv("HOME");
+    home_path += "/.ecflowrc/ssl/";
+    return home_path;
+}
+
+std::string Openssl::pem() const {
+    std::string str = certificates_dir();
+    if (ssl_ == "1") {
+        // assume 2048-bit dh key, but accept 1024-bit for
+        // backwards-compatibility (note: openssl might
+        // not accept it, depending on the version used)
+        str += "dh2048.pem";
+
+        if (!fs::exists(str)) {
+            return certificates_dir() + "dh1024.pem";
+        }
+        return str;
+    }
+
+    str += ssl_;
+    str += ".pem";
+    return str;
+}
+
+std::string Openssl::crt() const {
+    std::string str = certificates_dir();
+    if (ssl_ == "1") {
+        str += "server.crt";
+        return str;
+    }
+    str += ssl_;
+    str += ".crt";
+    return str;
+}
+
+std::string Openssl::key() const {
+    std::string str = certificates_dir();
+    if (ssl_ == "1") {
+        str += "server.key";
+        return str;
+    }
+    str += ssl_;
+    str += ".key";
+    return str;
+}
+
+std::string Openssl::passwd() const {
+    std::string str = certificates_dir();
+    if (ssl_ == "1") {
+        str += "server.passwd";
+        return str;
+    }
+    str += ssl_;
+    str += ".passwd";
+    return str;
+}
+
+const char* Openssl::ssl_info() {
+    return "ecFlow client and server are SSL enabled. To use SSL choose between:\n"
+           "  1. export ECF_SSL=1              # search for server.crt otherwise <host>.<port>.crt\n"
+           "  2. export ECF_SSL=<host>.<port>  # Use server specific certificates <host>.<port>.***\n"
+           "  3. use --ssl           # argument on ecflow_client/ecflow_server, same as option 1.\n"
+           "                         # Typically ssl server can be started with ecflow_start.sh -s\n"
+           "  4. Client.enable_ssl() # for python client\n\n"
+           "ecFlow expects the certificates to be in directory $HOME/.ecflowrc/ssl\n"
+           "The certificates can be shared if you have multiple servers running on\n"
+           "the same machine. In this case use ECF_SSL=1, then\n"
+           "ecflow_server expects the following files in $HOME/.ecflowrc/ssl\n\n"
+           "   - dh2048.pem\n"
+           "   - server.crt\n"
+           "   - server.key\n"
+           "   - server.passwd (optional) if this exists it must contain the pass phrase used to create server.key\n\n"
+           "ecflow_client expects the following files in : $HOME/.ecflowrc/ssl\n\n"
+           "   - server.crt (this must be the same as server)\n\n"
+           "Alternatively you can have different setting for each server ECF_SSL=<host>.<port>\n"
+           "Then server expect files of the type:\n\n"
+           "   - <host>.<port>.pem\n"
+           "   - <host>.<port>.crt\n"
+           "   - <host>.<port>.key\n"
+           "   - <host>.<port>.passwd (optional)\n\n"
+           "and client expect files of the type:\n\n"
+           "   - <host>.<port>.crt  # as before this must be same as the server\n\n"
+           "The server/client will automatically check existence of both variants,\n"
+           "but will give preference to NON <host>.<port>.*** variants first, when ECF_SSL=1\n"
+           "The following steps, show you how to create the certificate files.\n"
+           "This may need to be adapted if you want to use <host>.<port>.***\n\n"
+           "- Generate a password protected private key. This will request a pass phrase.\n"
+           "  This key is a 1024 bit RSA key which is encrypted using Triple-DES and stored\n"
+           "  in a PEM format so that it is readable as ASCII text\n\n"
+           "     > openssl genrsa -des3 -out server.key 1024   # Password protected private key\n"
+           "- Additional security.\n"
+           "  If you want additional security, create a file called 'server.passwd' and add the pass phrase to the "
+           "file.\n"
+           "  Then set the file permission so that file is only readable by the server process.\n"
+           "  Or you can choose to remove password requirement. In that case we don't need server.passwd file.\n\n"
+           "     > cp server.key server.key.secure\n"
+           "     > openssl rsa -in server.key.secure -out server.key  # remove password requirement\n"
+           "- Sign certificate with private key (self signed certificate).Generate Certificate Signing Request(CSR).\n"
+           "  This will prompt with a number of questions.\n"
+           "  However please ensure 'common name' matches the host where your server is going to run.\n\n"
+           "     > openssl req -new -key server.key -out server.csr # Generate Certificate Signing Request(CSR)\n"
+           "- Generate a self signed certificate CRT, by using the CSR and private key.\n\n"
+           "     > openssl x509 -req -days 3650 -in server.csr -signkey server.key -out server.crt\n\n"
+           "- Generate dhparam file. ecFlow expects 2048 key.\n"
+           "     > openssl dhparam -out dh2048.pem 2048";
+}
+
+void Openssl::check_server_certificates() const {
+    //   cout << "Openssl::check_server_certificates: ssl'" << ssl_ << "'\n";
+
+    {
+        string server_key = key();
+        if (!fs::exists(server_key))
+            throw std::runtime_error("Error: The password protected private server key file '" + server_key +
+                                     "' does not exist\n\n" + ssl_info());
+    }
+    {
+        string server_pem = pem();
+        if (!fs::exists(server_pem))
+            throw std::runtime_error("Error: The dhparam file(pem) '" + server_pem + "' does not exist\n\n" +
+                                     ssl_info());
+    }
+}
+
+std::ostream& operator<<(std::ostream& os, const ecf::Openssl& ssl) {
+    ssl.print(os);
+    return os;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Openssl.hpp 5.13.0-1/libs/base/src/ecflow/base/Openssl.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/Openssl.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Openssl.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,79 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_Openssl_HPP
+#define ecflow_base_Openssl_HPP
+
+#include <memory>
+#include <ostream>
+#include <string>
+
+#include <boost/asio/ssl.hpp>
+
+namespace ecf {
+
+class Openssl {
+public:
+    Openssl(const Openssl&)                  = delete;
+    const Openssl& operator=(const Openssl&) = delete;
+
+    /// There is no SSL protocol version named SSLv23.
+    /// The SSLv23_method() API and its variants choose SSLv2, SSLv3, or TLSv1 for compatibility with the peer
+    /// Consider the incompatibility among the SSL/TLS versions when you develop
+    /// SSL client/server applications. For example, a TLSv1 server cannot understand
+    /// a client-hello message from an SSLv2 or SSLv3 client.
+    /// The SSLv2 client/server recognises messages from only an SSLv2 peer.
+    /// The SSLv23_method() API and its variants may be used when the compatibility with the peer is important.
+    /// An SSL server with the SSLv23 method can understand any of the SSLv2, SSLv3, and TLSv1 hello messages.
+    /// However, the SSL client using the SSLv23 method cannot establish connection with the SSL server
+    ///  with the SSLv3/TLSv1 method because SSLv2 hello message is sent by the client
+    Openssl() = default;
+
+    const std::string& ssl() const { return ssl_; }
+    bool enabled() const { return !ssl_.empty(); }
+
+    bool enable_no_throw(std::string host,
+                         const std::string& port,
+                         const std::string& ecf_ssl_env = "");         // returns false if cannot enable
+    void enable(std::string host, const std::string& port);            // Can throw if certificate (CRT) are missing
+    void enable_if_defined(std::string host, const std::string& port); // Can throw if certificate (CRT) are missing
+    void disable() { ssl_.clear(); }                                   // override environment setting for ECF_SSL
+
+    void init_for_server();
+    void init_for_client();
+
+    boost::asio::ssl::context& context();
+
+    static const char* ssl_info();
+    void print(std::ostream& os) const { os << ssl_; }
+    std::string info() const;
+
+private:
+    void check_server_certificates() const;
+    void load_verify_file(boost::asio::ssl::context&); /// load server.crt file into the ssl context
+    std::string certificates_dir() const;              /// Directory where ssl certificates are held
+    std::string get_password() const;
+
+    std::string pem() const;
+    std::string crt() const;
+    std::string key() const;
+    std::string passwd() const;
+
+private:
+    std::string ssl_;                                        // Non empty if ssl has been enabled
+    std::unique_ptr<boost::asio::ssl::context> ssl_context_; // create on demand, otherwise non-ssl context takes a hit.
+    bool init_for_client_{false};
+};
+
+std::ostream& operator<<(std::ostream& os, const ecf::Openssl&);
+
+} // namespace ecf
+
+#endif /* ecflow_base_Openssl_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ServerReply.cpp 5.13.0-1/libs/base/src/ecflow/base/ServerReply.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/ServerReply.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ServerReply.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,34 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/ServerReply.hpp"
+
+/// *Note* server_reply_.client_handle_ is kept until the next call to register a new client_handle
+/// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+void ServerReply::clear_for_invoke(bool command_line_interface) {
+    // std::cout << "ServerReply::clear_for_invoke\n";
+    cli_                          = command_line_interface;
+    in_sync_                      = false;
+    full_sync_                    = false;
+    news_                         = ServerReply::NO_NEWS;
+    block_client_on_home_server_  = false;
+    block_client_server_halted_   = false;
+    block_client_zombie_detected_ = false;
+    invalid_argument_             = false;
+    eof_                          = false;
+    host_.clear();
+    port_.clear();
+    error_msg_.clear();
+    str_.clear();
+    zombies_.clear();
+    str_vec_.clear();
+    client_handle_suites_.clear();
+    changed_nodes_.clear();
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ServerReply.hpp 5.13.0-1/libs/base/src/ecflow/base/ServerReply.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/ServerReply.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ServerReply.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,155 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_ServerReply_HPP
+#define ecflow_base_ServerReply_HPP
+
+#include "ecflow/attribute/Zombie.hpp"
+#include "ecflow/base/Stats.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+/// This class is used to hold the replies back from the server
+/// *Note* server_reply_.client_handle_ is kept until the next call to register a new client_handle
+/// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+
+class ServerReply {
+public:
+    ServerReply(const ServerReply&)                  = delete;
+    const ServerReply& operator=(const ServerReply&) = delete;
+
+    enum News_t { NO_NEWS, NEWS, DO_FULL_SYNC };
+    ServerReply() = default;
+
+    /// *Note* server_reply_.client_handle_ is kept until the next call to register a new client_handle
+    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+    /// and reset everything else
+    void clear_for_invoke(bool command_line_interface); // true if calling from command line
+
+    /// task based replies
+    bool block_client_on_home_server() const { return block_client_on_home_server_; }
+    void set_block_client_on_home_server() { block_client_on_home_server_ = true; }
+
+    bool block_client_server_halted() const { return block_client_server_halted_; }
+    void set_block_client_server_halted() { block_client_server_halted_ = true; }
+
+    bool block_client_zombie_detected() const { return block_client_zombie_detected_; }
+    void set_block_client_zombie_detected() { block_client_zombie_detected_ = true; }
+
+    bool invalid_argument() const { return invalid_argument_; }
+    void set_invalid_argument() { invalid_argument_ = true; }
+
+    bool eof() const { return eof_; }
+    void set_eof() { eof_ = true; }
+
+    void set_host_port(const std::string& host, const std::string& port) {
+        host_ = host;
+        port_ = port;
+    }
+    const std::string& host() const { return host_; }
+    const std::string& port() const { return port_; }
+
+    bool client_request_failed() const { return !error_msg_.empty(); }
+    void set_error_msg(const std::string& e) { error_msg_ = e; }
+    const std::string& error_msg() const { return error_msg_; }
+    std::string& get_error_msg() { return error_msg_; }
+
+    const std::vector<Zombie>& zombies() const { return zombies_; }
+    void set_zombies(const std::vector<Zombie>& z) { zombies_ = z; }
+
+    /// For uses with the suites cmd, or any other command that needs a vector of strings form server
+    const std::vector<std::string>& get_string_vec() const { return str_vec_; }
+    void set_string_vec(const std::vector<std::string>& z) { str_vec_ = z; }
+
+    const std::vector<std::pair<unsigned int, std::vector<std::string>>>& get_client_handle_suites() const {
+        return client_handle_suites_;
+    }
+    void set_client_handle_suites(const std::vector<std::pair<unsigned int, std::vector<std::string>>>& s) {
+        client_handle_suites_ = s;
+    }
+
+    /// Only valid when the client requested the CFileCmd or log file from the server
+    /// Other times this will be empty.
+    const std::string& get_string() const { return str_; }
+    void set_string(const std::string& f) { str_ = f; }
+
+    /// Only valid when Stats command called.
+    const Stats& stats() const { return stats_; }
+    void set_stats(const Stats& s) { stats_ = s; }
+
+    /// Return true if client is using Command Level Interface. Set via clear_for_invoke()
+    bool cli() const { return cli_; }
+
+    /// Only valid after a call to sync()
+    /// in_sync() should be called after call to sync() Returns true if client defs is now in_sync with server
+    bool in_sync() const { return in_sync_; }
+    void set_sync(bool b) { in_sync_ = b; }
+
+    /// The SSyncCmd will set if we have a full sync(ie retrieved full node tree from server) or incremental sync
+    bool full_sync() const { return full_sync_; }
+    void set_full_sync(bool f) { full_sync_ = f; }
+
+    /// Only valid after a call to news()
+    /// return true if the server has changed
+    News_t get_news() const { return news_; }
+    void set_news(News_t n) { news_ = n; }
+
+    /// Only valid when the client requested the defs node tree from the server
+    /// The defs *WILL* be retained until the next call to get the server defs
+    /// **Hence is NOT reset in clear_for_invoke()
+    defs_ptr client_defs() const { return client_defs_; }
+    void set_client_defs(defs_ptr d) { client_defs_ = d; }
+
+    /// Only valid when the client requested the node from the server
+    /// The node *WILL* be retained until the next call to get the node
+    /// **Hence is NOT reset in clear_for_invoke()
+    node_ptr client_node() const { return client_node_; }
+    void set_client_node(node_ptr d) { client_node_ = d; }
+
+    /// A client handle of value 0 is not valid. Created in the server
+    /// We should keep a reference to the client handle, for use with client handle commands
+    /// **Hence is NOT reset in clear_for_invoke()
+    void set_client_handle(int handle) { client_handle_ = handle; }
+    int client_handle() const { return client_handle_; }
+
+    // During incremental sync, record list of changed nodes, used by python api
+    std::vector<std::string>& changed_nodes() { return changed_nodes_; }
+
+private:
+    friend class SSyncCmd;
+
+    std::string host_;                       // clear at the start of invoke
+    std::string port_;                       // clear at the start of invoke
+    std::string str_;                        // clear at the start of invoke
+    std::string error_msg_;                  // clear at the start of invoke
+    std::vector<Zombie> zombies_;            // clear at the start of invoke
+    std::vector<std::string> str_vec_;       // clear at the start of invoke
+    std::vector<std::string> changed_nodes_; // clear at the start of invoke
+    std::vector<std::pair<unsigned int, std::vector<std::string>>>
+        client_handle_suites_; // clear at the start of invoke
+    Stats stats_;              // Used for test only, ideally need to clear
+
+    defs_ptr client_defs_; // server reply stored as the client side defs, kept locally
+    node_ptr client_node_; // server reply stored as the client side node, kept locally
+
+    int client_handle_{0}; // set locally when suites are registered, and kept for reference
+    News_t news_{NO_NEWS}; // clear at the start of invoke
+
+    bool cli_{false};
+    bool in_sync_{false};                      // clear at the start of invoke
+    bool full_sync_{false};                    // clear at the start of invoke
+    bool block_client_on_home_server_{false};  // clear at the start of invoke
+    bool block_client_server_halted_{false};   // clear at the start of invoke
+    bool block_client_zombie_detected_{false}; // clear at the start of invoke
+    bool delete_all_{false};                   // clear at the start of invoke
+    bool invalid_argument_{false};             // clear at the start of invoke
+    bool eof_{false};                          // clear at the start of invoke
+};
+
+#endif /* ecflow_base_ServerReply_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ServerToClientResponse.cpp 5.13.0-1/libs/base/src/ecflow/base/ServerToClientResponse.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/ServerToClientResponse.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ServerToClientResponse.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,62 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/ServerToClientResponse.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/base/ClientToServerRequest.hpp" // for throw
+
+using namespace std;
+using namespace ecf;
+
+bool ServerToClientResponse::handle_server_response(ServerReply& r, Cmd_ptr cts_cmd, bool debug) const {
+    /// Called in client context: see ClientInvoker
+    if (stc_cmd_.get()) {
+        return stc_cmd_->handle_server_response(r, cts_cmd, debug);
+    }
+
+    /// ClientToServerRequest::handleRequest returned a NULL pointer stc_cmd_.
+    std::string ss;
+    ss += "ServerToClientResponse::handle_server_response: ";
+    if (cts_cmd.get()) {
+        ss += "Client request ";
+        ss += cts_cmd->print_short();
+        ss += " failed. ";
+    }
+    ss += "Server replied with a NULL message\n";
+    throw std::runtime_error(ss);
+}
+
+std::ostream& ServerToClientResponse::print(std::ostream& os) const {
+    if (stc_cmd_.get()) {
+        os << stc_cmd_->print();
+        return os;
+    }
+    return os << "NULL ServerToClientResponse";
+}
+
+bool ServerToClientResponse::operator==(const ServerToClientResponse& rhs) const {
+    if (!stc_cmd_.get() && !rhs.stc_cmd_.get()) {
+        return true;
+    }
+    if (stc_cmd_.get() && !rhs.stc_cmd_.get()) {
+        return false;
+    }
+    if (!stc_cmd_.get() && rhs.stc_cmd_.get()) {
+        return false;
+    }
+    return (stc_cmd_->equals(rhs.stc_cmd_.get()));
+}
+
+std::ostream& operator<<(std::ostream& os, const ServerToClientResponse& d) {
+    return d.print(os);
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ServerToClientResponse.hpp 5.13.0-1/libs/base/src/ecflow/base/ServerToClientResponse.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/ServerToClientResponse.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ServerToClientResponse.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_ServerToClientResponse_HPP
+#define ecflow_base_ServerToClientResponse_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+// Base class for server to client requesting. This class is used in the IPC messaging between
+// server and client
+class ServerToClientResponse {
+public:
+    ServerToClientResponse()                              = default;
+    ServerToClientResponse(const ServerToClientResponse&) = delete;
+    explicit ServerToClientResponse(const STC_Cmd_ptr& cmd) : stc_cmd_(cmd) {}
+    ~ServerToClientResponse() = default;
+
+    ServerToClientResponse& operator=(const ServerToClientResponse&) = delete;
+
+    STC_Cmd_ptr get_cmd() const { return stc_cmd_; }
+    void set_cmd(const STC_Cmd_ptr& cmd) { stc_cmd_ = cmd; }
+
+    std::ostream& print(std::ostream& os) const;
+
+    void cleanup() {
+        if (stc_cmd_.get())
+            stc_cmd_->cleanup();
+    } // reclaim memory *AFTER* command has run
+
+    /// Handle the response from the server. On the client side
+    /// return true IF and ONLY IF client response was ok, if further client action required return false
+    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const;
+
+    /// Used by boost test, to verify persistence
+    bool operator==(const ServerToClientResponse& rhs) const;
+
+private:
+    STC_Cmd_ptr stc_cmd_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar) {
+        ar(CEREAL_NVP(stc_cmd_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ServerToClientResponse& d);
+
+#endif /* ecflow_base_ServerToClientResponse_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/SslClient.cpp 5.13.0-1/libs/base/src/ecflow/base/SslClient.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/SslClient.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/SslClient.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,382 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/SslClient.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/stc/ErrorCmd.hpp"
+#include "ecflow/base/stc/StcCmd.hpp"
+
+// #define DEBUG_CLIENT 1;
+
+#ifdef DEBUG_CLIENT
+    #include <iostream>
+
+    #include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
+#endif
+
+/// The timeout will typically happen when the server has died, but socket is still open
+/// If we do not have a timeout, it will hang indefinitely
+
+/// Constructor starts the asynchronous connect operation.
+SslClient::SslClient(boost::asio::io_service& io_service,
+                     boost::asio::ssl::context& context,
+                     Cmd_ptr cmd_ptr,
+                     const std::string& host,
+                     const std::string& port,
+                     int timeout)
+    : stopped_(false),
+      host_(host),
+      port_(port),
+      connection_(io_service, context),
+      deadline_(io_service),
+      timeout_(timeout) {
+    /// Avoid sending a NULL request to the server
+    if (!cmd_ptr.get())
+        throw std::runtime_error("SslClient::SslClient: No request specified !");
+
+    // The timeout can be set externally for testing, however when its not set the timeout is obtained from the command
+    // Vary the timeout, according to the command, hence loading the definition has longer timeout than ping
+    if (0 == timeout_) {
+        timeout_ = cmd_ptr->timeout();
+    }
+
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::SslClient() timeout(" << timeout_ << ") " << host_ << ":" << port_ << " ";
+    std::string output;
+    cmd_ptr->print(output);
+    std::cout << output << std::endl;
+#endif
+
+    outbound_request_.set_cmd(cmd_ptr);
+
+    // Host name resolution is performed using a resolver, where host and service
+    // names(or ports) are looked up and converted into one or more end points
+    boost::asio::ip::tcp::resolver resolver(io_service);
+    boost::asio::ip::tcp::resolver::query query(host_, port_);
+    boost::asio::ip::tcp::resolver::iterator endpoint_iterator = resolver.resolve(query);
+
+    // The list of end points obtained could contain both IPv4 and IPv6 end points,
+    // so a program may try each of them until it finds one that works.
+    // This keeps the SslClient program independent of a specific IP version.
+    start(endpoint_iterator);
+}
+
+SslClient::~SslClient() {
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::~SslClient(): connection_.socket().is_open()=" << connection_.socket_ll().is_open()
+              << std::endl;
+#endif
+}
+
+/// Private ==============================================================================
+
+// This function terminates all the actors to shut down the connection. It
+// may be called by the user of the client class, or by the class itself in
+// response to graceful termination or an unrecoverable error.
+void SslClient::start(boost::asio::ip::tcp::resolver::iterator endpoint_iter) {
+    // Start the connect actor.
+    start_connect(endpoint_iter);
+
+    // Start the deadline actor. You will note that we're not setting any
+    // particular deadline here. Instead, the connect and input actors will
+    // update the deadline prior to each asynchronous operation.
+    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
+}
+
+bool SslClient::start_connect(boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
+    if (endpoint_iterator != boost::asio::ip::tcp::resolver::iterator()) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   SslClient::start_connect: Trying " << endpoint_iterator->endpoint() << "..." << std::endl;
+#endif
+
+        // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that
+        // were cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or
+        // will soon be executed. If it returns 1 then the wait handler was successfully cancelled.
+
+        // Set a deadline for the connect operation.
+        deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
+
+        boost::asio::ip::tcp::endpoint endpoint = *endpoint_iterator;
+        connection_.socket_ll().async_connect(endpoint,
+                                              [this, endpoint_iterator](const boost::system::error_code& error) {
+                                                  this->handle_connect(error, endpoint_iterator);
+                                              });
+    }
+    else {
+        // ran out of end points
+        return false;
+    }
+    return true;
+}
+
+void SslClient::handle_connect(const boost::system::error_code& e,
+                               boost::asio::ip::tcp::resolver::iterator endpoint_iterator) {
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::handle_connect stopped_=" << stopped_ << std::endl;
+#endif
+
+    if (stopped_)
+        return;
+
+    // The async_connect() function automatically opens the socket at the start
+    // of the asynchronous operation. If the socket is closed at this time then
+    // the timeout handler must have run first.
+    if (!connection_.socket_ll().is_open()) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   SslClient::handle_connect: *Connect timeout*:  Trying next end point" << std::endl;
+#endif
+        // Try the next available end point.
+        if (!start_connect(++endpoint_iterator)) {
+            // Ran out of end points, An error occurred
+            stop();
+            std::stringstream ss;
+            if (e)
+                ss << "SslClient::handle_connect: Ran out of end points : connection error( " << e.message()
+                   << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
+            else
+                ss << "SslClient::handle_connect: Ran out of end points : connection error for request( "
+                   << outbound_request_ << " ) on " << host_ << ":" << port_;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else if (e) {
+
+#ifdef DEBUG_CLIENT
+        std::cout << "   SslClient::handle_connect Connect error: " << e.message() << " . Trying next end point"
+                  << std::endl;
+#endif
+
+        // Some kind of error. We need to close the socket used in the previous connection attempt
+        // before starting a new one.
+        connection_.socket_ll().close();
+
+        // Try the next end point.
+        if (!start_connect(++endpoint_iterator)) {
+            // Ran out of end points. An error occurred.
+            stop();
+            std::stringstream ss;
+            ss << "SslClient::handle_connect: Ran out of end points: connection error( " << e.message()
+               << " ) for request( " << outbound_request_ << " ) on " << host_ << ":" << port_;
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else {
+#ifdef DEBUG_CLIENT
+        std::cout << "   SslClient::handle_connect **Successfully** established connection to the server: Sending Out "
+                     "bound request = "
+                  << outbound_request_ << std::endl;
+#endif
+
+        // **Successfully** established connection to the server
+        start_handshake();
+    }
+}
+
+void SslClient::start_handshake() {
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::start_handshake " << outbound_request_ << std::endl;
+#endif
+    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
+    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
+    // executed. If it returns 1 then the wait handler was successfully cancelled. Set a deadline for the write
+    // operation.
+    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
+
+    connection_.socket().async_handshake(boost::asio::ssl::stream_base::client,
+                                         [this](const boost::system::error_code& e) { handle_handshake(e); });
+}
+
+void SslClient::handle_handshake(const boost::system::error_code& e) {
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::handle_handshake " << std::endl;
+#endif
+    if (!e) {
+        start_write();
+    }
+    else {
+        // An error occurred.
+        stop();
+
+        std::stringstream ss;
+        ss << "SslClient::handle_handshake: error(" << e.message() << ") on " << host_ << ":" << port_
+           << " possibly non-ssl server";
+        inbound_response_.set_cmd(std::make_shared<ErrorCmd>(ss.str()));
+    }
+}
+
+void SslClient::start_write() {
+    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
+    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
+    // executed. If it returns 1 then the wait handler was successfully cancelled.
+
+    // Set a deadline for the write operation.
+    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
+
+    connection_.async_write(outbound_request_,
+                            [this](const boost::system::error_code& error) { this->handle_write(error); });
+}
+
+void SslClient::handle_write(const boost::system::error_code& e) {
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::handle_write stopped_ = " << stopped_ << std::endl;
+#endif
+    if (stopped_)
+        return;
+
+    if (!e) {
+
+#ifdef DEBUG_CLIENT
+        std::cout << "   SslClient::handle_write OK: Check for server reply" << std::endl;
+#endif
+        // Check to see if the server was happy with our request.
+        // If all is OK, the server may choose not to reply(cuts down on network traffic)
+        // In which case handle_read will get a End of File error.
+        start_read();
+    }
+    else {
+
+        // An error occurred.
+        stop();
+
+        std::stringstream ss;
+        ss << "SslClient::handle_write: error (" << e.message() << " ) for request( " << outbound_request_ << " ) on "
+           << host_ << ":" << port_;
+        throw std::runtime_error(ss.str());
+    }
+
+    // Nothing to do. The socket will be closed automatically when the last
+    // reference to the connection object goes away.
+}
+
+void SslClient::start_read() {
+    // expires_from_now cancels any pending asynchronous waits, and returns the number of asynchronous waits that were
+    // cancelled. If it returns 0 then you were too late and the wait handler has already been executed, or will soon be
+    // executed. If it returns 1 then the wait handler was successfully cancelled.
+
+    // Set a deadline for the read operation.
+    deadline_.expires_from_now(boost::posix_time::seconds(timeout_));
+
+    connection_.async_read(inbound_response_,
+                           [this](const boost::system::error_code& error) { this->handle_read(error); });
+}
+
+void SslClient::handle_read(const boost::system::error_code& e) {
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::handle_read stopped_ = " << stopped_ << std::endl;
+#endif
+    if (stopped_)
+        return;
+
+    // close socket, & cancel timer.
+    stop();
+
+    if (!e) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   SslClient::handle_read OK \n";
+        std::cout << "      outbound_request_ = " << outbound_request_ << "\n";
+        std::cout << "      inbound_response_ = " << inbound_response_ << "\n";
+#endif
+        /// ***********************************************************
+        /// ClientInvoker will call back, to handle_server_response.
+        /// ***********************************************************
+        // Successfully handled request
+    }
+    else {
+        //
+        // A connection error occurred. EOF
+        //   - In cases where ( to cut down network traffic),
+        //     the server does a shutdown/closes the socket without replying we will get End of File error.
+        //   - if we have a NONSSL client talking to SSL server, the SSL server will not reply, we will get End of File
+        //   error.
+        //
+        // i.e. client requests a response from the server, and it does not reply(or replies with shutdown/close)
+        // In both cases we will treat as an error
+
+        if (e.value() == boost::asio::error::eof) {
+#ifdef DEBUG_CLIENT
+            std::cout << "   Client::handle_read: End of File (server did not reply or mixing ssl and non-ssl)"
+                      << std::endl;
+#endif
+            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::END_OF_FILE));
+            return;
+        }
+
+        // If we get back Invalid argument. It means server could *NOT* decode client message. Equally client could not
+        // decode server reply
+        //   - Could be boost version of client/server are incompatible
+        //   - 4 series ecflow cannot talk to 5 series ecflow or vice versa
+        // We treat this specially
+        if (e.value() == boost::asio::error::invalid_argument) {
+#ifdef DEBUG_CLIENT
+            std::cout
+                << "   Client::handle_read: Server replied with invalid argument (i.e could not decode client message) "
+                << std::endl;
+#endif
+            inbound_response_.set_cmd(std::make_shared<StcCmd>(StcCmd::INVALID_ARGUMENT));
+            return;
+        }
+
+        std::stringstream ss;
+        ss << "Client::handle_read: connection error( " << e.message() << " ) for request( " << outbound_request_
+           << " ) on " << host_ << ":" << port_;
+        throw std::runtime_error(ss.str());
+    }
+
+    // Since we are not starting a new operation the io_service will run out of
+    // work to do and the Client will exit.
+}
+
+void SslClient::stop() {
+    stopped_ = true;
+    connection_.socket_ll().close();
+    deadline_.cancel();
+}
+
+/// Handle completion of a write operation.
+/// Handle completion of a read operation.
+bool SslClient::handle_server_response(ServerReply& server_reply, bool debug) const {
+    if (debug)
+        std::cout << "  SslClient::handle_server_response" << std::endl;
+    server_reply.set_host_port(host_, port_); // client context, needed by some commands, ie. SServerLoadCmd
+    return inbound_response_.handle_server_response(server_reply, outbound_request_.get_cmd(), debug);
+}
+
+void SslClient::check_deadline() {
+#ifdef DEBUG_CLIENT
+    std::cout << "   SslClient::check_deadline stopped_=" << stopped_ << " expires("
+              << to_simple_string(deadline_.expires_at()) << ") time now("
+              << to_simple_string(boost::asio::deadline_timer::traits_type::now()) << ")" << std::endl;
+#endif
+    if (stopped_)
+        return;
+
+    // Check whether the deadline has passed. We compare the deadline against
+    // the current time since a new asynchronous operation may have moved the
+    // deadline before this actor had a chance to run.
+    if (deadline_.expires_at() <= boost::asio::deadline_timer::traits_type::now()) {
+#ifdef DEBUG_CLIENT
+        std::cout << "   SslClient::check_deadline timed out" << std::endl;
+#endif
+
+        // The deadline has passed. The socket is closed so that any outstanding
+        // asynchronous operations are cancelled.
+        stop();
+
+        std::stringstream ss;
+        ss << "SslClient::check_deadline: timed out after " << timeout_ << " seconds for request( " << outbound_request_
+           << " ) on " << host_ << ":" << port_;
+        throw std::runtime_error(ss.str());
+    }
+
+    // Put the actor back to sleep.
+    deadline_.async_wait([this](const boost::system::error_code&) { check_deadline(); });
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/SslClient.hpp 5.13.0-1/libs/base/src/ecflow/base/SslClient.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/SslClient.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/SslClient.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,80 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_SslClient_HPP
+#define ecflow_base_SslClient_HPP
+
+///
+/// \brief This class acts as the client part. ( in client/server architecture)
+///
+/// \note The plug command can move a node to another server hence the server
+/// itself will NEED to ACT as a client. This is why client lives in Base and
+/// not the Client project
+///
+
+#include "ecflow/base/ClientToServerRequest.hpp"
+#include "ecflow/base/ServerToClientResponse.hpp"
+#include "ecflow/base/ssl_connection.hpp"
+
+class SslClient {
+public:
+    /// Constructor starts the asynchronous connect operation.
+    SslClient(boost::asio::io_service& io_service,
+              boost::asio::ssl::context& context,
+              Cmd_ptr cmd_ptr,
+              const std::string& host,
+              const std::string& port,
+              int timout = 0);
+    ~SslClient();
+
+    /// Client side, get the server response, handles reply from server
+    /// Returns true if all is ok, else false if further client action is required
+    /// will throw std::runtime_error for errors
+    bool handle_server_response(ServerReply&, bool debug) const;
+
+private:
+    void start(boost::asio::ip::tcp::resolver::iterator);
+    void stop();
+    void check_deadline();
+
+    bool start_connect(boost::asio::ip::tcp::resolver::iterator);
+
+    void start_handshake();
+    void handle_handshake(const boost::system::error_code& e);
+    void start_write();
+    void start_read();
+
+    /// Handle completion of a connect operation.
+    void handle_connect(const boost::system::error_code& e, boost::asio::ip::tcp::resolver::iterator endpoint_iterator);
+
+    /// Handle completion of a read operation.
+    void handle_read(const boost::system::error_code& e);
+
+    /// Handle completion of a write operation
+    void handle_write(const boost::system::error_code& e);
+
+private:
+    bool stopped_;
+    std::string host_;                        /// the servers name
+    std::string port_;                        /// the port on the server
+    ssl_connection connection_;               /// The connection to the server.
+    ClientToServerRequest outbound_request_;  /// The request we will send to the server
+    ServerToClientResponse inbound_response_; /// The response we get back from the server
+
+    boost::asio::deadline_timer deadline_;
+
+    //    connect        : timeout_ second
+    //    send request   : timeout_ second
+    //    receive reply  : timeout_ second
+    // Default value of 0 means take the timeout from the command
+    int timeout_;
+};
+
+#endif /* ecflow_base_SslClient_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Stats.cpp 5.13.0-1/libs/base/src/ecflow/base/Stats.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/Stats.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Stats.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,356 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/Stats.hpp"
+
+#include <iomanip>
+#include <sstream>
+
+#include <boost/range/adaptors.hpp>
+
+#include "ecflow/core/SState.hpp"
+
+using namespace std;
+
+Stats::Stats() = default;
+
+void Stats::update_stats(int poll_interval) {
+    // Called at poll time, ie just before node tree traversal
+    request_vec_.emplace_back(request_count_, poll_interval);
+    request_count_ = 0;
+    request_stats_.clear();
+
+    // To avoid excessive memory usage, we store only a limited number of:
+    //  - requests per poll period
+    // Since we're polling every 60 seconds, sample cover the last hour
+    if (request_vec_.size() > 60) {
+        request_vec_.pop_front();
+    }
+}
+
+void Stats::update_for_serialisation() {
+    /// This *ONLY* computes the data when this function is called
+    /// >>> Hence the server load is only valid for last hour <<<
+
+    if (!request_stats_.empty()) {
+        // Found request statistics in 'cache'. Nothing further to do...
+        return;
+    }
+
+    if (request_vec_.empty()) {
+        // No data to create statistics...
+        return;
+    }
+
+    std::stringstream ss;
+    ss << setiosflags(ios::fixed) << setprecision(2);
+
+    int count      = 0;
+    double request = 0.0;
+    double seconds = 0.0;
+    for (const auto& entry : boost::adaptors::reverse(request_vec_)) {
+        count++;
+        request += entry.first;
+        seconds += entry.second;
+        double request_per_second = request / seconds;
+
+        switch (count) {
+            case 5:
+            case 15:
+            case 30:
+            case 60: {
+                ss << " ";
+                [[fallthrough]];
+            }
+            case 1: {
+                ss << request_per_second;
+            }
+            default: {
+                // nothing to do...
+            }
+        }
+    }
+    request_stats_ = ss.str();
+}
+
+void Stats::reset() {
+    checkpt_                   = 0;
+    restore_defs_from_checkpt_ = 0;
+
+    server_version_         = 0;
+    restart_server_         = 0;
+    shutdown_server_        = 0;
+    halt_server_            = 0;
+    reload_white_list_file_ = 0;
+    reload_passwd_file_     = 0;
+    ping_                   = 0;
+    debug_server_on_        = 0;
+    debug_server_off_       = 0;
+    get_defs_               = 0;
+    sync_                   = 0;
+    sync_full_              = 0;
+    sync_clock_             = 0;
+    news_                   = 0;
+
+    node_job_gen_            = 0;
+    node_check_job_gen_only_ = 0;
+    node_delete_             = 0;
+    node_suspend_            = 0;
+    node_resume_             = 0;
+    node_kill_               = 0;
+    node_status_             = 0;
+    node_edit_history_       = 0;
+    node_archive_            = 0;
+    node_restore_            = 0;
+
+    log_cmd_     = 0;
+    log_msg_cmd_ = 0;
+    begin_cmd_   = 0;
+
+    task_init_     = 0;
+    task_complete_ = 0;
+    task_wait_     = 0;
+    task_abort_    = 0;
+    task_event_    = 0;
+    task_meter_    = 0;
+    task_label_    = 0;
+    task_queue_    = 0;
+
+    zombie_fob_    = 0;
+    zombie_fail_   = 0;
+    zombie_adopt_  = 0;
+    zombie_remove_ = 0;
+    zombie_get_    = 0;
+    zombie_block_  = 0;
+    zombie_kill_   = 0;
+
+    requeue_node_ = 0;
+    order_node_   = 0;
+    run_node_     = 0;
+    load_defs_    = 0;
+    replace_      = 0;
+    force_        = 0;
+    free_dep_     = 0;
+    suites_       = 0;
+    edit_script_  = 0;
+
+    alter_cmd_   = 0;
+    ch_cmd_      = 0;
+    file_ecf_    = 0;
+    file_job_    = 0;
+    file_jobout_ = 0;
+    file_cmdout_ = 0;
+    file_manual_ = 0;
+
+    plug_            = 0;
+    move_            = 0;
+    group_cmd_       = 0;
+    server_load_cmd_ = 0;
+    stats_           = 0;
+    check_           = 0;
+    query_           = 0;
+}
+
+static string show_checkpt_mode(ecf::CheckPt::Mode m) {
+    switch (m) {
+        case ecf::CheckPt::NEVER:
+            return "CHECK_NEVER";
+            break;
+        case ecf::CheckPt::ON_TIME:
+            return "CHECK_ON_TIME";
+            break;
+        case ecf::CheckPt::ALWAYS:
+            return "CHECK_ON_ALWAYS";
+            break;
+        case ecf::CheckPt::UNDEFINED:
+            return "UNDEFINED";
+            break;
+    }
+    return std::string();
+}
+
+void Stats::show(std::ostream& os) const {
+    int width = 35;
+    os << "Server statistics\n";
+    os << left << setw(width) << "   Version " << version_ << "\n";
+    os << left << setw(width) << "   Status " << SState::to_string(status_) << "\n";
+    os << left << setw(width) << "   Host " << host_ << "\n";
+    os << left << setw(width) << "   Port " << port_ << "\n";
+    os << left << setw(width) << "   Up since " << up_since_ << "\n";
+    os << left << setw(width) << "   Job sub' interval " << job_sub_interval_ << "s\n";
+    os << left << setw(width) << "   ECF_HOME " << ECF_HOME_ << "\n";
+    os << left << setw(width) << "   ECF_LOG " << ECF_LOG_ << "\n";
+    os << left << setw(width) << "   ECF_CHECK " << ECF_CHECK_ << "\n";
+    os << left << setw(width) << "   ECF_SSL " << ECF_SSL_ << "\n";
+    os << left << setw(width) << "   Check pt interval " << checkpt_interval_ << "s\n";
+    os << left << setw(width) << "   Check pt mode " << show_checkpt_mode(checkpt_mode_) << "\n";
+    os << left << setw(width) << "   Check pt save time alarm " << checkpt_save_time_alarm_ << "s\n";
+    os << left << setw(width) << "   Number of Suites " << no_of_suites_ << "\n";
+    os << left << setw(width) << "   Request/s per 1,5,15,30,60 min " << request_stats_ << "\n";
+
+    if (checkpt_ || restore_defs_from_checkpt_ || server_version_ || restart_server_ || shutdown_server_ ||
+        halt_server_ || ping_ || debug_server_on_ || debug_server_off_ || get_defs_ || sync_ || sync_full_ ||
+        sync_clock_ || news_)
+        os << "\n";
+    if (!locked_by_user_.empty())
+        os << left << setw(width) << "   Locked by user " << locked_by_user_ << "\n";
+    if (checkpt_ != 0)
+        os << left << setw(width) << "   Check points " << checkpt_ << "\n";
+    if (restore_defs_from_checkpt_ != 0)
+        os << left << setw(width) << "   Restore from Check point " << restore_defs_from_checkpt_ << "\n";
+    if (restart_server_ != 0)
+        os << left << setw(width) << "   Restart server " << restart_server_ << "\n";
+    if (shutdown_server_ != 0)
+        os << left << setw(width) << "   Shutdown server " << shutdown_server_ << "\n";
+    if (halt_server_ != 0)
+        os << left << setw(width) << "   Halt server " << halt_server_ << "\n";
+    if (ping_ != 0)
+        os << left << setw(width) << "   Ping " << ping_ << "\n";
+    if (debug_server_on_ != 0)
+        os << left << setw(width) << "   debug server on " << debug_server_on_ << "\n";
+    if (debug_server_off_ != 0)
+        os << left << setw(width) << "   debug server off " << debug_server_off_ << "\n";
+    if (get_defs_ != 0)
+        os << left << setw(width) << "   Get full definition " << get_defs_ << "\n";
+    if (server_version_ != 0)
+        os << left << setw(width) << "   Server version " << server_version_ << "\n";
+    if (sync_ != 0)
+        os << left << setw(width) << "   Sync " << sync_ << "\n";
+    if (sync_full_ != 0)
+        os << left << setw(width) << "   Sync full " << sync_full_ << "\n";
+    if (sync_clock_ != 0)
+        os << left << setw(width) << "   Sync suite clock " << sync_clock_ << "\n";
+    if (news_ != 0)
+        os << left << setw(width) << "   News " << news_ << "\n";
+
+    if (task_init_ || task_complete_ || task_wait_ || task_abort_ || task_event_ || task_meter_ || task_label_ ||
+        task_queue_)
+        os << "\n";
+    if (task_init_ != 0)
+        os << left << setw(width) << "   Task init " << task_init_ << "\n";
+    if (task_complete_ != 0)
+        os << left << setw(width) << "   Task complete " << task_complete_ << "\n";
+    if (task_wait_ != 0)
+        os << left << setw(width) << "   Task wait " << task_wait_ << "\n";
+    if (task_abort_ != 0)
+        os << left << setw(width) << "   Task abort " << task_abort_ << "\n";
+    if (task_event_ != 0)
+        os << left << setw(width) << "   Task event " << task_event_ << "\n";
+    if (task_meter_ != 0)
+        os << left << setw(width) << "   Task meter " << task_meter_ << "\n";
+    if (task_label_ != 0)
+        os << left << setw(width) << "   Task label " << task_label_ << "\n";
+    if (task_queue_ != 0)
+        os << left << setw(width) << "   Task queue " << task_queue_ << "\n";
+
+    if (zombie_fob_ || zombie_fail_ || zombie_adopt_ || zombie_remove_ || zombie_get_ || zombie_block_ || zombie_kill_)
+        os << "\n";
+    if (zombie_fob_ != 0)
+        os << left << setw(width) << "   Zombie fob " << zombie_fob_ << "\n";
+    if (zombie_fail_ != 0)
+        os << left << setw(width) << "   Zombie fail " << zombie_fail_ << "\n";
+    if (zombie_adopt_ != 0)
+        os << left << setw(width) << "   Zombie adopt " << zombie_adopt_ << "\n";
+    if (zombie_remove_ != 0)
+        os << left << setw(width) << "   Zombie remove " << zombie_remove_ << "\n";
+    if (zombie_get_ != 0)
+        os << left << setw(width) << "   Zombie get " << zombie_get_ << "\n";
+    if (zombie_block_ != 0)
+        os << left << setw(width) << "   Zombie block " << zombie_block_ << "\n";
+    if (zombie_kill_ != 0)
+        os << left << setw(width) << "   Zombie kill " << zombie_kill_ << "\n";
+
+    if (load_defs_ || begin_cmd_ || requeue_node_ || node_job_gen_ || node_check_job_gen_only_ || node_delete_ ||
+        node_suspend_ || node_resume_ || node_kill_ || node_status_ || node_edit_history_ || log_cmd_ || log_msg_cmd_ ||
+        order_node_ || run_node_ || replace_ || force_ || free_dep_ || suites_ || edit_script_ || alter_cmd_ ||
+        ch_cmd_ || plug_ || move_ || group_cmd_ || reload_white_list_file_ || server_load_cmd_ || stats_ || check_ ||
+        query_ || reload_passwd_file_ || node_archive_ || node_restore_)
+        os << "\n";
+
+    if (load_defs_ != 0)
+        os << left << setw(width) << "   Load definition " << load_defs_ << "\n";
+    if (begin_cmd_ != 0)
+        os << left << setw(width) << "   Begin " << begin_cmd_ << "\n";
+    if (requeue_node_ != 0)
+        os << left << setw(width) << "   Requeue " << requeue_node_ << "\n";
+    if (node_job_gen_ != 0)
+        os << left << setw(width) << "   Job generation " << node_job_gen_ << "\n";
+    if (node_check_job_gen_only_ != 0)
+        os << left << setw(width) << "   Check Job generation " << node_check_job_gen_only_ << "\n";
+    if (node_delete_ != 0)
+        os << left << setw(width) << "   Node delete " << node_delete_ << "\n";
+    if (node_suspend_ != 0)
+        os << left << setw(width) << "   Node suspend " << node_suspend_ << "\n";
+    if (node_resume_ != 0)
+        os << left << setw(width) << "   Node resume " << node_resume_ << "\n";
+    if (node_kill_ != 0)
+        os << left << setw(width) << "   Node kill " << node_kill_ << "\n";
+    if (node_status_ != 0)
+        os << left << setw(width) << "   Node status " << node_status_ << "\n";
+    if (node_edit_history_ != 0)
+        os << left << setw(width) << "   Node edit history " << node_edit_history_ << "\n";
+    if (node_archive_ != 0)
+        os << left << setw(width) << "   Node archive " << node_archive_ << "\n";
+    if (node_restore_ != 0)
+        os << left << setw(width) << "   Node restore " << node_restore_ << "\n";
+    if (log_cmd_ != 0)
+        os << left << setw(width) << "   Log cmd " << log_cmd_ << "\n";
+    if (log_msg_cmd_ != 0)
+        os << left << setw(width) << "   Log message " << log_msg_cmd_ << "\n";
+    if (order_node_ != 0)
+        os << left << setw(width) << "   Order " << order_node_ << "\n";
+    if (run_node_ != 0)
+        os << left << setw(width) << "   Run " << run_node_ << "\n";
+    if (replace_ != 0)
+        os << left << setw(width) << "   Replace " << replace_ << "\n";
+    if (force_ != 0)
+        os << left << setw(width) << "   Force  " << force_ << "\n";
+    if (free_dep_ != 0)
+        os << left << setw(width) << "   Free dependencies " << free_dep_ << "\n";
+    if (suites_ != 0)
+        os << left << setw(width) << "   Suites " << suites_ << "\n";
+    if (edit_script_ != 0)
+        os << left << setw(width) << "   Edit script " << edit_script_ << "\n";
+    if (alter_cmd_ != 0)
+        os << left << setw(width) << "   Alter " << alter_cmd_ << "\n";
+    if (ch_cmd_ != 0)
+        os << left << setw(width) << "   Client handle " << ch_cmd_ << "\n";
+    if (plug_ != 0)
+        os << left << setw(width) << "   Plug " << plug_ << "\n";
+    if (move_ != 0)
+        os << left << setw(width) << "   Move " << move_ << "\n";
+    if (group_cmd_ != 0)
+        os << left << setw(width) << "   Group " << group_cmd_ << "\n";
+    if (server_load_cmd_ != 0)
+        os << left << setw(width) << "   Server load cmd " << server_load_cmd_ << "\n";
+    if (stats_ != 0)
+        os << left << setw(width) << "   stats cmd " << stats_ << "\n";
+    if (check_ != 0)
+        os << left << setw(width) << "   checks " << check_ << "\n";
+    if (query_ != 0)
+        os << left << setw(width) << "   query " << query_ << "\n";
+    if (reload_white_list_file_ != 0)
+        os << left << setw(width) << "   Reload white list file " << reload_white_list_file_ << "\n";
+    if (reload_passwd_file_ != 0)
+        os << left << setw(width) << "   Reload password file " << reload_passwd_file_ << "\n";
+    if (file_ecf_ || file_job_ || file_jobout_ || file_manual_ || file_cmdout_)
+        os << "\n";
+    if (file_ecf_ != 0)
+        os << left << setw(width) << "   File ECF " << file_ecf_ << "\n";
+    if (file_job_ != 0)
+        os << left << setw(width) << "   File job " << file_job_ << "\n";
+    if (file_jobout_ != 0)
+        os << left << setw(width) << "   File Job out " << file_jobout_ << "\n";
+    if (file_cmdout_ != 0)
+        os << left << setw(width) << "   File Cmd out " << file_cmdout_ << "\n";
+    if (file_manual_ != 0)
+        os << left << setw(width) << "   File manual " << file_manual_ << "\n";
+    os << flush;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/Stats.hpp 5.13.0-1/libs/base/src/ecflow/base/Stats.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/Stats.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/Stats.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,228 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_Stats_HPP
+#define ecflow_base_Stats_HPP
+
+#include <deque>
+#include <string>
+
+#include "ecflow/core/CheckPt.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+/// This class is used to store all statistical data about all the
+/// commands processed by the server. Uses default copy constructor
+struct Stats
+{
+
+    Stats();
+    void show(std::ostream& os = std::cout) const;
+
+    void update() { request_count_++; }
+    void update_stats(int poll_interval);
+    void update_for_serialisation();
+    void reset();
+
+    std::string locked_by_user_;
+    std::string host_;
+    std::string port_;
+    std::string up_since_;
+    std::string version_;
+    std::string request_stats_;
+    std::string ECF_HOME_;
+    std::string ECF_CHECK_;
+    std::string ECF_LOG_;
+    std::string ECF_SSL_{"disabled"};
+
+    int status_{0}; // 0 HALTED, 1 SHUTDOWN, 2 RUNNING
+    int request_count_{0};
+    int job_sub_interval_{0};
+    int checkpt_interval_{0};
+    int checkpt_save_time_alarm_{0};
+    ecf::CheckPt::Mode checkpt_mode_{ecf::CheckPt::UNDEFINED};
+    int no_of_suites_{0};
+
+    unsigned int checkpt_{0};
+    unsigned int restore_defs_from_checkpt_{0};
+
+    unsigned int server_version_{0};
+    unsigned int restart_server_{0};
+    unsigned int shutdown_server_{0};
+    unsigned int halt_server_{0};
+    unsigned int reload_white_list_file_{0};
+    unsigned int reload_passwd_file_{0};
+    unsigned int ping_{0};
+    unsigned int debug_server_on_{0};
+    unsigned int debug_server_off_{0};
+    unsigned int get_defs_{0};
+    unsigned int sync_{0};
+    unsigned int sync_full_{0};
+    unsigned int sync_clock_{0};
+    unsigned int news_{0};
+
+    unsigned int node_job_gen_{0};
+    unsigned int node_check_job_gen_only_{0};
+    unsigned int node_delete_{0};
+    unsigned int node_suspend_{0};
+    unsigned int node_resume_{0};
+    unsigned int node_kill_{0};
+    unsigned int node_status_{0};
+    unsigned int node_edit_history_{0};
+    unsigned int node_archive_{0};
+    unsigned int node_restore_{0};
+
+    unsigned int log_cmd_{0};
+    unsigned int log_msg_cmd_{0};
+    unsigned int begin_cmd_{0};
+
+    unsigned int task_init_{0};
+    unsigned int task_complete_{0};
+    unsigned int task_wait_{0};
+    unsigned int task_abort_{0};
+    unsigned int task_event_{0};
+    unsigned int task_meter_{0};
+    unsigned int task_label_{0};
+    unsigned int task_queue_{0};
+
+    unsigned int zombie_fob_{0};
+    unsigned int zombie_fail_{0};
+    unsigned int zombie_adopt_{0};
+    unsigned int zombie_remove_{0};
+    unsigned int zombie_get_{0};
+    unsigned int zombie_block_{0};
+    unsigned int zombie_kill_{0};
+
+    unsigned int requeue_node_{0};
+    unsigned int order_node_{0};
+    unsigned int run_node_{0};
+    unsigned int load_defs_{0};
+    unsigned int replace_{0};
+    unsigned int force_{0};
+    unsigned int free_dep_{0};
+    unsigned int suites_{0};
+    unsigned int edit_script_{0};
+
+    unsigned int alter_cmd_{0};
+    unsigned int ch_cmd_{0};
+    unsigned int file_ecf_{0};
+    unsigned int file_job_{0};
+    unsigned int file_jobout_{0};
+    unsigned int file_cmdout_{0};
+    unsigned int file_manual_{0};
+
+    unsigned int plug_{0};
+    unsigned int move_{0};
+    unsigned int group_cmd_{0};
+    unsigned int server_load_cmd_{0};
+    unsigned int stats_{0};
+    unsigned int check_{0};
+    unsigned int query_{0};
+
+private:
+    std::deque<std::pair<int, int>> request_vec_; // pair.first =  number of requests, pair.second = poll interval
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar & status_;
+        ar & locked_by_user_;
+        ar & host_;
+        ar & port_;
+        ar & up_since_;
+        ar & version_;
+        ar & job_sub_interval_;
+        ar & checkpt_interval_;
+        ar & checkpt_save_time_alarm_;
+        ar & checkpt_mode_;
+        ar & no_of_suites_;
+        ar & request_stats_;
+        ar & ECF_HOME_;
+        ar & ECF_CHECK_;
+        ar & ECF_LOG_;
+        ar & ECF_SSL_;
+
+        ar & checkpt_;
+
+        ar & server_version_;
+        ar & restart_server_;
+        ar & shutdown_server_;
+        ar & halt_server_;
+        ar & reload_white_list_file_;
+        ar & reload_passwd_file_;
+        ar & ping_;
+        ar & debug_server_on_;
+        ar & debug_server_off_;
+
+        ar & get_defs_;
+        ar & sync_;
+        ar & sync_full_;
+        ar & sync_clock_;
+        ar & news_;
+
+        ar & node_job_gen_;
+        ar & node_check_job_gen_only_;
+        ar & node_delete_;
+        ar & node_suspend_;
+        ar & node_resume_;
+        ar & node_kill_;
+        ar & node_status_;
+        ar & node_edit_history_;
+        ar & node_archive_;
+        ar & node_restore_;
+
+        ar & log_cmd_;
+        ar & log_msg_cmd_;
+        ar & begin_cmd_;
+
+        ar & task_init_;
+        ar & task_complete_;
+        ar & task_wait_;
+        ar & task_abort_;
+        ar & task_event_;
+        ar & task_meter_;
+        ar & task_label_;
+        ar & task_queue_;
+
+        ar & zombie_fob_;
+        ar & zombie_fail_;
+        ar & zombie_adopt_;
+        ar & zombie_remove_;
+        ar & zombie_get_;
+        ar & zombie_block_;
+        ar & zombie_kill_;
+
+        ar & requeue_node_;
+        ar & order_node_;
+        ar & run_node_;
+        ar & load_defs_;
+        ar & replace_;
+        ar & force_;
+        ar & free_dep_;
+        ar & suites_;
+        ar & edit_script_;
+
+        ar & alter_cmd_;
+        ar & ch_cmd_;
+        ar & file_ecf_;
+        ar & file_job_;
+        ar & file_jobout_;
+        ar & file_cmdout_;
+        ar & file_manual_;
+
+        ar & plug_;
+        ar & move_;
+        ar & group_cmd_;
+        ar & server_load_cmd_;
+        ar & stats_;
+        ar & check_;
+        ar & query_;
+    }
+};
+#endif
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/WhyCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/WhyCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/WhyCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/WhyCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,51 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/WhyCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+
+WhyCmd::WhyCmd(defs_ptr defs, const std::string& absNodePath) : defs_(defs) {
+    if (!defs_.get()) {
+        throw std::runtime_error("WhyCmd: The definition parameter is empty");
+    }
+
+    if (!absNodePath.empty()) {
+        node_ = defs_->findAbsNode(absNodePath);
+        if (!node_.get()) {
+            std::string errorMsg = "WhyCmd: The node path parameter '";
+            errorMsg += absNodePath;
+            errorMsg += "' cannot be found.";
+            throw std::runtime_error(errorMsg);
+        }
+    }
+}
+
+std::string WhyCmd::why() const {
+    std::vector<std::string> theReasonWhy;
+    if (node_.get()) {
+        node_->bottom_up_why(theReasonWhy);
+    }
+    else {
+        defs_->top_down_why(theReasonWhy);
+    }
+
+    // Don't add /n on very last item
+    std::string reason;
+    for (size_t i = 0; i < theReasonWhy.size(); ++i) {
+        reason += theReasonWhy[i];
+        if (i != theReasonWhy.size() - 1)
+            reason += "\n";
+    }
+    return reason;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/WhyCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/WhyCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/WhyCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/WhyCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_WhyCmd_HPP
+#define ecflow_base_WhyCmd_HPP
+
+///
+/// \brief Client side command only.
+///
+/// \note Placed in this category, since the server does not need to link with it.
+///
+
+#include <string>
+
+#include "ecflow/node/NodeFwd.hpp"
+
+class WhyCmd {
+public:
+    WhyCmd()              = delete;
+    WhyCmd(const WhyCmd&) = delete;
+    WhyCmd(WhyCmd&&)      = delete;
+
+    WhyCmd(defs_ptr defs, const std::string& absNodePath);
+
+    /// Why the node is not running
+    /// Return a '/n' separated string which lists the reasons why
+    /// the provided node is not active.
+    std::string why() const;
+
+private:
+    defs_ptr defs_;
+    node_ptr node_;
+};
+
+#endif /* ecflow_base_WhyCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ZombieCtrl.cpp 5.13.0-1/libs/base/src/ecflow/base/ZombieCtrl.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/ZombieCtrl.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ZombieCtrl.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,818 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/ZombieCtrl.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost::posix_time;
+
+// #define DEBUG_ZOMBIE  1
+
+/// Zombie creation:
+/// *** ECF  *** Zombies is created with: process(node path, password, pid/rid , try_no) ***
+/// *** PATH *** Zombies is created with: process(node path, password, pid/rid , try_no) ***
+/// *** USER *** Zombies is created with:    TASK(node path, password, pid/rid , try_no) ***
+///
+/// There are several places where we hold path,password,pid/rid,etc
+///                        Task Cmd/
+///            Node Tree   Process(n)   USER Zombie         PATH/ECF Zombie
+///  Path                               same as node tree   same as process
+///  password                           same as node tree   same as process
+///  pid/rid                            same as node tree   same as process
+///  try no                             same as node tree   same as process
+///    ^                    |
+///    | ----adopt-----------
+///
+/// Zombie Finding:
+/// For a given Task, we could have multiple zombie process, i.e. with different password/process id
+/// We can't assume that there is only one zombie process. Hence search/zombie matching
+/// should involve matching with password/process id first and then resort to path matching
+///
+/// Note: Only the init child command is required pass the process id. The other child command may
+//        or may *not* provide this. In the test scenario we do.
+static bool match(const Zombie& z,
+                  const std::string& path_to_task,
+                  const std::string& process_or_remote_id,
+                  const std::string& password);
+
+bool ZombieCtrl::handle_path_zombie(AbstractServer* as,
+                                    const TaskCmd* task_cmd, // The child command
+                                    std::string& action_taken,
+                                    STC_Cmd_ptr& theReply // Reply varies according to User Action
+) {
+#ifdef DEBUG_ZOMBIE
+    std::cout << "   ZombieCtrl::handle_path_zombie:";
+#endif
+    const std::string& path_to_task         = task_cmd->path_to_node();
+    const std::string& jobs_password        = task_cmd->jobs_password();
+    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
+
+    /// *** The ZombieAttr may have added/ deleted via AlterCmd. This allows for dynamic changes
+    /// *no* task, find the closest Zombie attribute up the Node tree, ie attribute could be on family/suite even though
+    /// task has been deleted If none found we resort to default behaviour
+    node_ptr closest_matching_node = as->defs()->find_closest_matching_node(path_to_task);
+#ifdef DEBUG_ZOMBIE
+    if (closest_matching_node.get())
+        std::cout << " closest node found: ";
+#endif
+
+#ifdef DEBUG_ZOMBIE
+    std::cout << " Searching for match over " << zombies_.size() << " zombies :";
+#endif
+    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, jobs_password);
+    if (!theExistingZombie.empty()) {
+        // When NULL is passed for task, we change existing zombie to be of type PATH
+        return handle_existing_zombie(
+            theExistingZombie, nullptr /*task*/, closest_matching_node, task_cmd, action_taken, theReply);
+    }
+
+    /// Create a zombie,
+    /// *** PATH *** Zombies is created with: process path, process password, and process id/rid , process try_no ***
+#ifdef DEBUG_ZOMBIE
+    std::cout << " No matching zombie fnd: Creating Path Zombie: ";
+#endif
+
+    ZombieAttr attr = ZombieAttr::get_default_attr(Child::PATH);
+    if (closest_matching_node.get()) {
+        closest_matching_node->findParentZombie(Child::PATH, attr); // Override default from node tree
+    }
+
+    Zombie new_zombie(Child::PATH,
+                      task_cmd->child_type(),
+                      attr,
+                      path_to_task,
+                      jobs_password,
+                      process_or_remote_id,
+                      task_cmd->try_no(),
+                      task_cmd->hostname());
+    zombies_.emplace_back(new_zombie);
+
+    /// The user action may end deleting the zombie just added. Depends on ZombieAttribute settings
+    return handle_user_actions(new_zombie, nullptr /*task*/, task_cmd, action_taken, theReply);
+}
+
+bool ZombieCtrl::handle_zombie(Submittable* task,       // This NULL for path zombies
+                               const TaskCmd* task_cmd, // The child command
+                               std::string& action_taken,
+                               STC_Cmd_ptr& theReply // Reply varies according to User Action
+) {
+#ifdef DEBUG_ZOMBIE
+    std::cout << "   ZombieCtrl::handle_zombie:";
+#endif
+    const std::string& path_to_task         = task_cmd->path_to_node();
+    const std::string& jobs_password        = task_cmd->jobs_password();
+    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
+
+    /// Mark task as zombie
+    if (task)
+        task->flag().set(ecf::Flag::ZOMBIE);
+
+    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, jobs_password);
+    if (!theExistingZombie.empty()) {
+        return handle_existing_zombie(theExistingZombie, task, node_ptr(), task_cmd, action_taken, theReply);
+    }
+
+    /// Create Zombie:
+    /// *** ECF *** Zombies is created with: process path, process password, and process id/rid , process try_no ***
+    Child::ZombieType zombie_type = Child::ECF;
+    if (task_cmd->pid_missmatch() && task_cmd->password_missmatch())
+        zombie_type = Child::ECF_PID_PASSWD;
+    else if (task_cmd->pid_missmatch())
+        zombie_type = Child::ECF_PID;
+    else if (task_cmd->password_missmatch())
+        zombie_type = Child::ECF_PASSWD;
+    ZombieAttr attr = ZombieAttr::get_default_attr(zombie_type);
+
+    /// Look for any Zombie attribute up node tree, use this to construct & configure zombie
+    if (task)
+        task->findParentZombie(zombie_type, attr);
+
+    /// Handle corner case ,where we have two jobs with different process id, but same password
+    /// Can happen if jobs is started externally, or via test, occasionally
+    ecf::Child::CmdType child_type = task_cmd->child_type();
+    if (child_type == Child::INIT && task && task->state() == NState::ACTIVE) {
+
+        /// Find zombie by path only, and remove it. Re-added again below. With updated, data<<<<
+#ifdef DEBUG_ZOMBIE
+        cout << " >TASK already active:< ";
+#endif
+        size_t zombieVecSize = zombies_.size();
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task) {
+                zombie_type = zombies_[i].type(); // recover the original zombie type
+                zombies_.erase(zombies_.begin() + i);
+#ifdef DEBUG_ZOMBIE
+                cout << " Removing: ";
+#endif
+                break;
+            }
+        }
+    }
+
+#ifdef DEBUG_ZOMBIE
+    std::cout << " Creating ECF Zombie:";
+#endif
+    Zombie new_zombie(zombie_type,
+                      child_type,
+                      attr,
+                      path_to_task,
+                      jobs_password,
+                      process_or_remote_id,
+                      task_cmd->try_no(),
+                      task_cmd->hostname());
+    zombies_.push_back(new_zombie);
+
+    return handle_user_actions(new_zombie, task, task_cmd, action_taken, theReply);
+}
+
+bool ZombieCtrl::handle_existing_zombie(Zombie& theExistingZombie,      // The server already knows about the zombie
+                                        Submittable* task,              // This NULL for path zombies
+                                        node_ptr closest_matching_node, // only defined for path zombies
+                                        const TaskCmd* task_cmd,        // The child command
+                                        std::string& action_taken,      // User action taken
+                                        STC_Cmd_ptr& theReply           // Reply varies according to User Action
+) {
+#ifdef DEBUG_ZOMBIE
+    std::cout << " handle_existing_zombie: ";
+#endif
+    // If we have no task, then change the zombie type to PATH
+    if (!task) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << " : updating zombie type to PATH: ";
+#endif
+        theExistingZombie.set_type(ecf::Child::PATH);
+    }
+
+    /// *** The ZombieAttr may have added/ deleted via AlterCmd. This allows for dynamic changes
+    ZombieAttr attr = ZombieAttr::get_default_attr(theExistingZombie.type());
+    if (closest_matching_node.get()) {
+#ifdef DEBUG_ZOMBIE
+        cout << " Attr found for path zombie(" << attr.toString() << "): ";
+#endif
+        closest_matching_node->findParentZombie(theExistingZombie.type(), attr); // Override default from node tree
+    }
+
+    if (task && task->findParentZombie(theExistingZombie.type(), attr)) { // Override default from node tree
+#ifdef DEBUG_ZOMBIE
+        cout << " Attr found(" << attr.toString() << "): ";
+#endif
+    }
+    theExistingZombie.set_attr(attr);                             // Update attribute stored on the zombie
+    theExistingZombie.set_last_child_cmd(task_cmd->child_type()); // The zombie stores the last child command.
+    if (theExistingZombie.host().empty())
+        theExistingZombie.set_host(task_cmd->hostname());
+    theExistingZombie.increment_calls(); // record how times server handled with zombie
+
+    /// Update the process id, if it is empty on the existing zombie
+    /// *** NOTE**** cannot update process id from task, as that could be an ID from a different JOB,
+    /// ************ Hence zombie matching resorts to path and password matching
+    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
+    if (theExistingZombie.process_or_remote_id().empty() && !process_or_remote_id.empty()) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << "Updating process id(" << process_or_remote_id << "): ";
+#endif
+        theExistingZombie.set_process_or_remote_id(process_or_remote_id);
+    }
+
+    return handle_user_actions(theExistingZombie, task, task_cmd, action_taken, theReply);
+}
+
+bool ZombieCtrl::handle_user_actions(Zombie& theZombie,         // Existing or one we just created
+                                     Submittable* task,         // This is NULL for path zombies
+                                     const TaskCmd* task_cmd,   // The child command
+                                     std::string& action_taken, // User action taken
+                                     STC_Cmd_ptr& theReply      // Reply varies according to User Action
+) {
+    const std::string& path_to_task         = task_cmd->path_to_node();
+    const std::string& process_password     = task_cmd->jobs_password();
+    const std::string& process_or_remote_id = task_cmd->process_or_remote_id();
+
+    if (theZombie.manual_user_action())
+        action_taken = "manual-";
+    else
+        action_taken = "automatic-";
+
+    // *ADOPT* If zombie is set to adopt, copy over password and carry on as >NORMAL< , i.e. we return true
+    if (task && theZombie.adopt()) {
+
+        action_taken += "adopt";
+        /// Zombie was marked to adopt. password copied over, and zombie removed
+        /// *MUST* use the password of the process, and *NOT* the zombie
+        /// Since next time process communicates, it will be *WITH* the process password
+        task->set_jobs_password(process_password);
+        task->set_process_or_remote_id(process_or_remote_id);
+
+        /// Remove the zombie, as its been adopted
+        /// matching by password/process id may fail, hence remove by path
+        bool remove_ok = remove(path_to_task, process_or_remote_id, process_password);
+        if (!remove_ok) {
+            (void)remove_by_path(path_to_task);
+        }
+
+        /// Clear the zombie flag
+        task->flag().clear(ecf::Flag::ZOMBIE);
+
+#ifdef DEBUG_ZOMBIE
+        std::cout << " >>>ADOPT<<< then remove(" << remove_ok << ") ";
+        if (!remove_ok)
+            std::cout << " >>>ERROR<<<< Remove failed ";
+        std::cout << " zombies_.size(" << zombies_.size() << ")\n";
+#endif
+        return true;
+    }
+
+    // *FOB*
+    if (theZombie.fob()) {
+        /// Means return as if everything is OK. hence ClientInvoker will *NOT* block, and job can continue.
+        action_taken += "fob";
+
+        /// On the child COMPLETE/ABORT cmd, remove the zombie:
+        /// *****************************************************************************************
+        /// Since we are returning false, The Task Cmd complete/abort **wont** be able to remove the zombie
+        /// i.e since we want job to continue, *WITHOUT* invoking the dohandeRequest
+        /// *****************************************************************************************
+        if (task_cmd->child_type() == Child::COMPLETE || task_cmd->child_type() == Child::ABORT) {
+
+            bool remove_ok = remove(path_to_task, process_or_remote_id, process_password);
+            if (!remove_ok) {
+                (void)remove_by_path(path_to_task);
+            }
+
+            /// Clear the zombie flag
+            if (task)
+                task->flag().clear(ecf::Flag::ZOMBIE);
+
+#ifdef DEBUG_ZOMBIE
+            std::cout << " child == COMPLETE remove zombie ";
+            if (!remove_ok)
+                std::cout << " >>>ERROR<<<< Remove failed ";
+#endif
+        }
+
+#ifdef DEBUG_ZOMBIE
+        std::cout << " >>>FOB<<< zombies_.size(" << zombies_.size() << ")\n";
+#endif
+        theReply = PreAllocatedReply::ok_cmd();
+        return false;
+    }
+
+    // *FAIL* Ask ClientInvoker *NOT* to block,  *fail* with an error.
+    if (theZombie.fail()) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << " >>>FAIL<<< zombies_.size(" << zombies_.size() << ")\n";
+#endif
+        action_taken += "fail";
+        theReply = PreAllocatedReply::error_cmd("[ authentication failed ] Request set to FAIL via zombie setting");
+        return false;
+    }
+
+    // *KILL* Typically kill is immediate(i.e. via ZombieCmd), However this could have been set via ZombieAttribute
+    if (theZombie.kill()) {
+        // when a task a script is killed(i,e with kill -15), it will typically be trapped
+        // This will then typically call abort. We have a choice:
+        //    a/ If we remove the zombie, the action taken will be lost, when the abort arises, hence default action is
+        //    block b/ Change the action type to be fob, so that the abort does not block c/ Continue killing until
+        //    process terminate. Up to use to remove zombies
+        // Opted for option b/ however we do *NOT* change action type, we just fob
+        if (task) {
+            if (!task->flag().is_set(ecf::Flag::KILLED)) {
+
+                action_taken += "kill & fob";
+
+                // Kill the task, separate process, will typically send kill -15 to script.
+                task->kill(theZombie.process_or_remote_id());
+            }
+            else {
+                action_taken += "kill(already killed, fobing instead)";
+            }
+        }
+        else {
+            action_taken += "kill(no task, fobing instead)";
+        }
+#ifdef DEBUG_ZOMBIE
+        std::cout << " >>>KILL<<< zombies_.size(" << zombies_.size() << ")\n";
+#endif
+        theReply = PreAllocatedReply::ok_cmd(); // do not block the script, fob
+        return false;
+    }
+
+    // *REMOVE* Typically Removal is immediate(i.e. via ZombieCmd), However this could have been set via ZombieAttribute
+    if (theZombie.remove()) {
+        /// Ask ClientInvoker to continue blocking, Zombie may re-appear
+        action_taken += "remove";
+        bool remove_ok = remove(path_to_task, process_or_remote_id, process_password);
+        if (!remove_ok)
+            (void)remove_by_path(path_to_task);
+
+#ifdef DEBUG_ZOMBIE
+        std::cout << " >>>REMOVE<<< zombies_.size(" << zombies_.size() << ") : BLOCKING ";
+        if (!remove_ok)
+            std::cout << " >>>ERROR<<<< Remove failed ";
+#endif
+        theReply = PreAllocatedReply::block_client_zombie_cmd(theZombie.type());
+        return false;
+    }
+
+    // *DEFAULT*:
+    //       Label,event,meter             : fob
+    //       init,complete,abort,queue,wait: block
+    if (task_cmd->child_type() == Child::LABEL || task_cmd->child_type() == Child::EVENT ||
+        task_cmd->child_type() == Child::METER) {
+
+        /// Means return as if everything is OK. hence ClientInvoker will *NOT* block, and job can continue.
+#ifdef DEBUG_ZOMBIE
+        std::cout << ": FOB\n";
+#endif
+        action_taken += "fob";
+        theReply = PreAllocatedReply::ok_cmd();
+        return false;
+    }
+
+#ifdef DEBUG_ZOMBIE
+    std::cout << ": BLOCKING\n";
+#endif
+    // i.e it will make several attempts , and then start contacting servers in the hosts file.
+    action_taken += "block";
+    theReply = PreAllocatedReply::block_client_zombie_cmd(theZombie.type());
+    return false;
+}
+
+void ZombieCtrl::add_user_zombies(const std::vector<Submittable*>& tasks, const std::string& user_cmd) {
+    size_t taskVecSize = tasks.size();
+    for (size_t i = 0; i < taskVecSize; i++) {
+        Submittable* t = tasks[i];
+        if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
+
+            Zombie& theExistingZombie = find(t);
+            if (theExistingZombie.empty()) {
+
+#ifdef DEBUG_ZOMBIE
+                std::cout << "   ZombieCtrl::do_add_user_zombies " << t->absNodePath() << " "
+                          << t->process_or_remote_id() << " " << t->jobsPassword() << "\n";
+#endif
+
+                ZombieAttr attr = ZombieAttr::get_default_attr(Child::USER); // get the default USER zombie attribute
+                t->findParentZombie(Child::USER, attr);                      // Override default from the node tree
+
+                zombies_.emplace_back(Child::USER,
+                                      Child::INIT,
+                                      attr,
+                                      t->absNodePath(),
+                                      t->jobsPassword(),
+                                      t->process_or_remote_id(),
+                                      t->try_no(),
+                                      "",
+                                      user_cmd);
+
+                /// Mark task as zombie for xcdp
+                t->flag().set(ecf::Flag::ZOMBIE);
+            }
+        }
+    }
+}
+
+void ZombieCtrl::add_user_zombies(Node* node, const std::string& user_cmd) {
+    if (!node)
+        return;
+    std::vector<Submittable*> tasks;
+    node->get_all_active_submittables(tasks);
+    add_user_zombies(tasks, user_cmd);
+}
+
+void ZombieCtrl::add_user_zombies(defs_ptr defs, const std::string& user_cmd) {
+    if (!defs.get())
+        return;
+    std::vector<Submittable*> tasks;
+    defs->get_all_active_submittables(tasks);
+    add_user_zombies(tasks, user_cmd);
+}
+
+/// Returns the list of zombies, **updated** with seconds since creation
+void ZombieCtrl::get(std::vector<Zombie>& ret) {
+
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+
+    size_t zombieVecSize = zombies_.size();
+    ret.reserve(zombieVecSize);
+    for (size_t i = 0; i < zombieVecSize; i++) {
+
+        time_duration duration = time_now - zombies_[i].creation_time();
+        zombies_[i].set_duration(duration.total_seconds());
+
+        ret.push_back(zombies_[i]);
+    }
+}
+
+void ZombieCtrl::remove_stale_zombies(const boost::posix_time::ptime& time_now) {
+    for (auto i = zombies_.begin(); i != zombies_.end(); ++i) {
+        time_duration duration = time_now - (*i).creation_time();
+        if (duration.total_seconds() > (*i).allowed_age()) {
+#ifdef DEBUG_ZOMBIE
+            std::cout << "   ZombieCtrl::remove_stale_zombies " << (*i) << "\n";
+#endif
+            zombies_.erase(i--);
+        }
+    }
+}
+
+void ZombieCtrl::fob(const std::string& path_to_task,
+                     const std::string& process_or_remote_id,
+                     const std::string& password) {
+
+    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
+    if (theExistingZombie.empty())
+        return;
+    theExistingZombie.set_fob();
+}
+
+void ZombieCtrl::fobCli(const std::string& path_to_task, Submittable* task) {
+
+    if (task) {
+        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
+        /// If zombie password does *NOT* match then this is the real zombie.
+        size_t zombieVecSize = zombies_.size();
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
+                zombies_[i].set_fob();
+                return;
+            }
+        }
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task &&
+                zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
+                zombies_[i].set_fob();
+                return;
+            }
+        }
+    }
+
+    /// The best we can do
+    Zombie& theExistingZombie = find_by_path(path_to_task);
+    if (theExistingZombie.empty())
+        return;
+    theExistingZombie.set_fob();
+}
+
+void ZombieCtrl::fail(const std::string& path_to_task,
+                      const std::string& process_or_remote_id,
+                      const std::string& password) {
+
+    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
+    if (theExistingZombie.empty())
+        return;
+    theExistingZombie.set_fail();
+}
+
+void ZombieCtrl::failCli(const std::string& path_to_task, Submittable* task) {
+
+    if (task) {
+        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
+        /// If zombie password does *NOT* match then this is the real zombie.
+        size_t zombieVecSize = zombies_.size();
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
+                zombies_[i].set_fail();
+                return;
+            }
+        }
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task &&
+                zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
+                zombies_[i].set_fail();
+                return;
+            }
+        }
+    }
+
+    /// The best we can do
+    Zombie& theExistingZombie = find_by_path(path_to_task);
+    if (theExistingZombie.empty())
+        return;
+    theExistingZombie.set_fail();
+}
+
+void ZombieCtrl::adopt(const std::string& path_to_task,
+                       const std::string& process_or_remote_id,
+                       const std::string& password) {
+
+    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
+    if (theExistingZombie.empty())
+        return;
+    theExistingZombie.set_adopt();
+}
+
+void ZombieCtrl::adoptCli(const std::string& path_to_task, Submittable* task) {
+
+    if (!task) {
+        throw std::runtime_error("ZombieCtrl::adoptCli: Can't adopt zombie, there is no corresponding task!");
+    }
+
+    /// ***************************************************************************************
+    /// IMPORTANT: We should *NEVER* adopt a zombie, when the process id are different
+    /// This can end up, with two process running, Will mess up job output, as well as corruption caused
+    /// but running the same job twice. Better to kill both and re-queue.
+    /// Note: PBS can create two process, i.e same password, different PID's
+    /// ***************************************************************************************
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (zombies_[i].path_to_task() == path_to_task &&
+            zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
+            std::stringstream ss;
+            ss << "ZombieCtrl::adoptCli: Can *not* adopt zombies, where process id are different. Task("
+               << task->process_or_remote_id() << ") zombie(" << zombies_[i].process_or_remote_id()
+               << "). Please kill both process, and re-queue";
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
+    /// If zombie password does *NOT* match then this is the real zombie.
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
+            zombies_[i].set_adopt();
+            return;
+        }
+    }
+}
+
+void ZombieCtrl::block(const std::string& path_to_task,
+                       const std::string& process_or_remote_id,
+                       const std::string& password) {
+
+    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
+    if (theExistingZombie.empty())
+        return;
+    theExistingZombie.set_block();
+}
+
+void ZombieCtrl::blockCli(const std::string& path_to_task, Submittable* task) {
+
+    if (!task) {
+        throw std::runtime_error("ZombieCtrl::blockCli: Can't block zombie, there is no corresponding task for path " +
+                                 path_to_task);
+    }
+    else {
+        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
+        /// If zombie password does *NOT* match then this is the real zombie.
+        size_t zombieVecSize = zombies_.size();
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
+                zombies_[i].set_block();
+                return;
+            }
+        }
+    }
+}
+
+void ZombieCtrl::kill(const std::string& path_to_task,
+                      const std::string& process_or_remote_id,
+                      const std::string& password) {
+
+    Zombie& theExistingZombie = find_zombie(path_to_task, process_or_remote_id, password);
+    if (theExistingZombie.empty())
+        return;
+    theExistingZombie.set_kill();
+}
+
+void ZombieCtrl::killCli(const std::string& path_to_task, Submittable* task) {
+
+    if (!task) {
+        throw std::runtime_error("ZombieCtrl::killCli: Can't kill zombie, there is no corresponding task for path " +
+                                 path_to_task);
+    }
+
+    /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
+    /// If zombie password does *NOT* match then this is the real zombie.
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
+            task->kill(zombies_[i].process_or_remote_id());
+            zombies_[i].set_kill();
+            return;
+        }
+    }
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (zombies_[i].path_to_task() == path_to_task &&
+            zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
+            task->kill(zombies_[i].process_or_remote_id());
+            zombies_[i].set_kill();
+            return;
+        }
+    }
+    /// The best we can do
+    Zombie& theExistingZombie = find_by_path(path_to_task);
+    if (theExistingZombie.empty()) {
+        throw std::runtime_error("ZombieCtrl::killCli: Can't kill, could not locate zombie(and hence pid) for path: " +
+                                 path_to_task);
+    }
+    task->kill(theExistingZombie.process_or_remote_id());
+    theExistingZombie.set_kill();
+    remove_by_path(path_to_task);
+}
+
+/// Called by the child commands, ie complete and abort
+/// Hence remove zombie with matching password/process id ?
+bool ZombieCtrl::remove(Submittable* t) {
+    if (t) {
+        return remove(t->absNodePath(), t->process_or_remote_id(), t->jobsPassword());
+    }
+    return false;
+}
+
+bool ZombieCtrl::remove(const std::string& path_to_task,
+                        const std::string& process_or_remote_id,
+                        const std::string& password) {
+
+    /// Note: Its possible for two separate jobs to have the same password. (submit 1, submit 2) before job1 active,
+    /// password overridden by submit 2 Hence remove needs to at least match process_id
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (match(zombies_[i], path_to_task, process_or_remote_id, password)) {
+            // #ifdef DEBUG_ZOMBIE
+            //			std::cout << "   ZombieCtrl::remove " << zombies_[i] << " \n";
+            // #endif
+            zombies_.erase(zombies_.begin() + i);
+            return true;
+        }
+    }
+    return false;
+}
+
+void ZombieCtrl::removeCli(const std::string& path_to_task, Submittable* task) {
+
+    if (task) {
+        /// Try to determine the real zombie. (not 100% precise) by comparing its password with zombie
+        /// If zombie password does *NOT* match then this is the real zombie.
+        size_t zombieVecSize = zombies_.size();
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task && zombies_[i].jobs_password() != task->jobsPassword()) {
+#ifdef DEBUG_ZOMBIE
+                std::cout << "   ZombieCtrl::removeCli " << zombies_[i] << " \n";
+#endif
+                zombies_.erase(zombies_.begin() + i);
+                return;
+            }
+        }
+        for (size_t i = 0; i < zombieVecSize; i++) {
+            if (zombies_[i].path_to_task() == path_to_task &&
+                zombies_[i].process_or_remote_id() != task->process_or_remote_id()) {
+#ifdef DEBUG_ZOMBIE
+                std::cout << "   ZombieCtrl::removeCli " << zombies_[i] << " \n";
+#endif
+                zombies_.erase(zombies_.begin() + i);
+                return;
+            }
+        }
+    }
+
+    /// The best we can do
+    (void)remove_by_path(path_to_task);
+}
+
+bool ZombieCtrl::remove_by_path(const std::string& path_to_task) {
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (zombies_[i].path_to_task() == path_to_task) {
+#ifdef DEBUG_ZOMBIE
+            std::cout << "   ZombieCtrl::remove_by_path : " << zombies_[i] << " \n";
+#endif
+            zombies_.erase(zombies_.begin() + i);
+            return true;
+        }
+    }
+    return false;
+}
+
+/// Query
+const Zombie& ZombieCtrl::find(const std::string& path_to_task,
+                               const std::string& process_or_remote_id,
+                               const std::string& password) const {
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (match(zombies_[i], path_to_task, process_or_remote_id, password)) {
+            return zombies_[i];
+        }
+    }
+    return Zombie::EMPTY();
+}
+
+//================= private ===================================================================
+
+Zombie& ZombieCtrl::find(Submittable* task) {
+    if (task)
+        return find_zombie(task->absNodePath(), task->process_or_remote_id(), task->jobsPassword());
+    return Zombie::EMPTY_();
+}
+
+const Zombie& ZombieCtrl::find(Submittable* task) const {
+    if (task)
+        return find(task->absNodePath(), task->process_or_remote_id(), task->jobsPassword());
+    return Zombie::EMPTY();
+}
+
+Zombie& ZombieCtrl::find_zombie(const std::string& path_to_task,
+                                const std::string& process_or_remote_id,
+                                const std::string& password) {
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (match(zombies_[i], path_to_task, process_or_remote_id, password)) {
+            return zombies_[i];
+        }
+    }
+    return find_by_path(path_to_task);
+}
+
+bool match(const Zombie& z,
+           const std::string& path_to_task,
+           const std::string& process_or_remote_id,
+           const std::string& password) {
+    ///  Process/remote id only created when task becomes active.
+    if (z.path_to_task() == path_to_task) {
+        if (process_or_remote_id.empty() || z.process_or_remote_id().empty()) {
+            if (z.jobs_password() == password) {
+                return true;
+            }
+        }
+        else if (z.process_or_remote_id() == process_or_remote_id) {
+            return true;
+        }
+    }
+    return false;
+}
+
+Zombie& ZombieCtrl::find_by_path(const std::string& path_to_task) {
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (zombies_[i].path_to_task() == path_to_task) {
+            return zombies_[i];
+        }
+    }
+    return Zombie::EMPTY_();
+}
+
+const Zombie& ZombieCtrl::find_by_path_only(const std::string& path_to_task) const {
+    size_t zombieVecSize = zombies_.size();
+    for (size_t i = 0; i < zombieVecSize; i++) {
+        if (zombies_[i].path_to_task() == path_to_task) {
+            return zombies_[i];
+        }
+    }
+    return Zombie::EMPTY();
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ZombieCtrl.hpp 5.13.0-1/libs/base/src/ecflow/base/ZombieCtrl.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/ZombieCtrl.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ZombieCtrl.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,138 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_ZombieCtrl_HPP
+#define ecflow_base_ZombieCtrl_HPP
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/attribute/Zombie.hpp"
+#include "ecflow/base/Cmd.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+class TaskCmd;
+class AbstractServer;
+
+///
+/// \brief manages the zombies
+///
+
+/// All zombies are auto deleted after a period of time. See Zombie::allowed_age()
+class ZombieCtrl {
+public:
+    ZombieCtrl()                  = default;
+    ZombieCtrl(const ZombieCtrl&) = delete;
+    ZombieCtrl(ZombieCtrl&&)      = delete;
+
+    ZombieCtrl& operator=(const ZombieCtrl&) = delete;
+    ZombieCtrl& operator=(ZombieCtrl&&)      = delete;
+
+    /// Handle the zombie, and return back to the client
+    bool handle_zombie(Submittable*,              // Must be NON NULL
+                       const TaskCmd* task_cmd,   // The child command
+                       std::string& action_taken, // action taken
+                       STC_Cmd_ptr& theReply      // Reply varies according to User Action
+    );
+
+    bool handle_path_zombie(AbstractServer* as,        // Find closest matching node
+                            const TaskCmd* task_cmd,   // The child command
+                            std::string& action_taken, // action taken
+                            STC_Cmd_ptr& theReply      // Reply varies according to User Action
+    );
+
+    /// Find all *Tasks* beneath the input Node, that are in active or submitted states
+    /// We deliberately ignore aliases (This was requested by Axel)
+    /// Then add as 'USER' zombies. This should be called when commands like, delete, requeue,
+    /// run, are using the force option, and will create zombies.
+    void add_user_zombies(Node*, const std::string& user_cmd);
+    void add_user_zombies(defs_ptr, const std::string& user_cmd);
+    void add_user_zombies(const std::vector<Submittable*>& tasks, const std::string& user_cmd);
+
+    /// Returns the list of zombies, **updated** with seconds since creation
+    /// To avoid sending attr to client, we copy over its setting, if in effect
+    void get(std::vector<Zombie>&);
+
+    /// remove all zombies, older than their allowed age
+    /// Server typically checks every 60 seconds
+    void remove_stale_zombies(const boost::posix_time::ptime& time_now);
+
+    /// Will ask the child command to terminate, *without* the child command raising any errors
+    /// Since we can have many child commands(init,event,meter, label,complete) in a job
+    /// This fob must stay around, since we don't know how long the job will last for.
+    /// Will override, fail,recover,remove
+    /// For Command Line Interface only the task_path is provided. Just have to make do.
+    void fob(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
+    void fobCli(const std::string& path_to_task, Submittable*);
+
+    /// Similar to a fob, But will ask the child command to terminate, with an error.
+    /// Typically this will raise a trap in the job file, and hence raise an abort
+    /// However the abort will also be a zombie, and will also be auto-terminated
+    /// Hence the job file must be careful to use 'set -e' to avoid infinite recursion
+    /// Since we can have many child commands(init,event,meter, label,complete) in a job
+    /// This fob must stay around, since we don't know how long the job will last for.
+    /// Will override, fob,recover,remove
+    /// For Command Line Interface only the task_path is provided. Just have to make do.
+    void fail(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
+    void failCli(const std::string& path_to_task, Submittable*);
+
+    /// Find the task node, corresponding to the zombie, and copy over
+    /// the password. Then remove the zombie. Next time the child commands
+    /// communicate with the server, all will be ok
+    /// Will override, fail,fob,remove
+    /// For Command Line Interface only the task_path is provided. Just have to make do.
+    void adopt(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
+    void adoptCli(const std::string& path_to_task, Submittable*);
+    void block(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
+    void blockCli(const std::string& path_to_task, Submittable*);
+    void kill(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
+    void killCli(const std::string& path_to_task, Submittable*);
+
+    /// Remove the zombie corresponding to the Task path. Should only be one
+    /// Since we can have many child commands(init,event,meter, label,complete) in a job
+    /// the zombies may get re-added, should we rember this.
+    /// If path not found does nothing.
+    /// For Command Line Interface only the task_path is provided. Just have to make do.
+    bool remove(Submittable*);
+    bool remove(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
+    void removeCli(const std::string& path_to_task, Submittable*);
+    bool remove_by_path(const std::string& path_to_task);
+
+    /// Query
+    const Zombie&
+    find(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password) const;
+    const Zombie& find_by_path_only(const std::string& path_to_task) const;
+
+private:
+    bool handle_existing_zombie(Zombie&,                        // The server already knows about the zombie
+                                Submittable*,                   // This NULL for path zombies
+                                node_ptr closest_matching_node, // only set for path zombies
+                                const TaskCmd* task_cmd,        // The child command
+                                std::string& action_taken,      // User action taken
+                                STC_Cmd_ptr& theReply           // Reply varies according to User Action
+    );
+
+    bool handle_user_actions(Zombie&,                   // The server already knows about the zombie
+                             Submittable*,              // This NULL for path zombies
+                             const TaskCmd* task_cmd,   // The child command
+                             std::string& action_taken, // User action taken
+                             STC_Cmd_ptr& theReply      // Reply varies according to User Action
+    );
+
+    Zombie&
+    find_zombie(const std::string& path_to_task, const std::string& process_or_remote_id, const std::string& password);
+    Zombie& find(Submittable*);
+    const Zombie& find(Submittable*) const;
+    Zombie& find_by_path(const std::string& path_to_task);
+
+private:
+    std::vector<Zombie> zombies_;
+};
+
+#endif /* ecflow_base_ZombieCtrl_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,228 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+
+#include <iostream>
+#include <stdexcept>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/EditHistoryMgr.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/CmdContext.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace std;
+using namespace boost;
+using namespace ecf;
+
+// #define DEBUG_INVARIANTS 1
+
+ClientToServerCmd::ClientToServerCmd() : cl_host_(Host().name()) {
+}
+
+ClientToServerCmd::~ClientToServerCmd() = default;
+
+bool ClientToServerCmd::equals(ClientToServerCmd* rhs) const {
+    return hostname() == rhs->hostname();
+}
+
+STC_Cmd_ptr ClientToServerCmd::handleRequest(AbstractServer* as) const {
+    // Allow creating of new time stamp, when *not* in a command. i.e during node tree traversal in server
+    CmdContext cmdContext;
+
+    // Automatically flush log file at the end of the command
+    LogFlusher logFlusher;
+
+    // Create the log time stamp once for a given request
+    Log::instance()->cache_time_stamp();
+
+    // LOG the command, *BEFORE* invoking it. (i.e in case server hangs/crashes)
+    // Allow override in the rare cases, where we want to output additional debug
+    // If logging fails set late flag to warn users, ECFLOW-536
+    do_log(as);
+
+#ifdef DEBUG_INVARIANTS
+    LOG_ASSERT(as->defs(), "ClientToServerCmd::handleRequest: Start:  No defs? ");
+    std::string errmsg;
+    if (!as->defs()->checkInvariants(errmsg)) {
+        LOG(Log::ERR, "ClientToServerCmd::handleRequest: PreCondition: Failed invariant checking:" << errmsg);
+    }
+#endif
+
+    // LogTimer timer("ClientToServerCmd::handleRequest");
+    STC_Cmd_ptr halted;
+    if (!authenticate(as, halted)) {
+        assert(halted.get());
+        return halted;
+    }
+
+    // mark edited nodes, with edit history. relies on doHandleRequest to populate edit_history_nodes_/paths
+    // hence must at the same scope level
+    EditHistoryMgr edit_history_mgr(this, as);
+
+    // Handle the request, and return the reply back to the client
+    STC_Cmd_ptr server_to_client_ptr = doHandleRequest(as);
+    if (isWrite() && server_to_client_ptr->ok()) {
+
+        // This can end up, check pointing the defs file
+        as->nodeTreeStateChanged();
+    }
+
+#ifdef DEBUG_INVARIANTS
+    LOG_ASSERT(as->defs(), "ClientToServerCmd::handleRequest: End:  No defs? ");
+    std::string errmsg;
+    if (!as->defs()->checkInvariants(errmsg)) {
+        LOG(Log::ERR, "ClientToServerCmd::handleRequest: PostCondition: Failed invariant checking:" << errmsg);
+    }
+#endif
+
+    return server_to_client_ptr;
+}
+
+void ClientToServerCmd::do_log(AbstractServer* as) const {
+    std::string ss;
+    print(ss);                // Populate the stream with command details:
+    if (!log(Log::MSG, ss)) { // will automatically add end of line
+        // problems with opening or writing to log file, warn users, ECFLOW-536
+        as->defs()->flag().set(ecf::Flag::LOG_ERROR);
+        as->defs()->set_server().add_or_update_user_variables("ECF_LOG_ERROR", Log::instance()->log_error());
+    }
+}
+
+STC_Cmd_ptr ClientToServerCmd::doJobSubmission(AbstractServer* as) {
+    // This function could be called at the end of *USER* command that can change state.
+    //
+    // We could have other tasks/jobs dependent on the state change. i.e end of time series
+    // This will traverse the node tree and resolve dependencies and may force
+    // Other jobs to be generated, due to the state change.
+    // However *** errors in job submission ***, should *NOT* typically abort the command.
+    // Since we will typically just set task to aborted state
+
+    // This job generation will timeout if job generation takes longer than next poll time.
+    as->traverse_node_tree_and_job_generate(Calendar::second_clock_time(), true /* user cmd context */);
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+node_ptr ClientToServerCmd::find_node(Defs* defs, const std::string& absNodepath) const {
+    node_ptr theNode = defs->findAbsNode(absNodepath);
+    if (!theNode.get()) {
+
+        std::string errorMsg = "Cannot find node at path '";
+        errorMsg += absNodepath;
+        errorMsg += "' ";
+        throw std::runtime_error(errorMsg);
+    }
+    return theNode;
+}
+
+void ClientToServerCmd::dumpVecArgs(const char* argOption, const std::vector<std::string>& args) {
+    cout << "  " << argOption;
+    for (size_t i = 0; i < args.size(); i++) {
+        cout << " args[" << i << "]='" << args[i] << "'";
+    }
+    cout << "\n";
+}
+
+node_ptr ClientToServerCmd::find_node_for_edit(Defs* defs, const std::string& absNodepath) const {
+    node_ptr theNode = find_node(defs, absNodepath);
+    add_node_for_edit_history(theNode);
+    return theNode;
+}
+
+node_ptr ClientToServerCmd::find_node_for_edit_no_throw(Defs* defs, const std::string& absNodepath) const {
+    node_ptr theNode = defs->findAbsNode(absNodepath);
+    add_node_for_edit_history(theNode);
+    return theNode;
+}
+
+void ClientToServerCmd::add_node_for_edit_history(Defs* defs, const std::string& absNodepath) const {
+    add_node_for_edit_history(defs->findAbsNode(absNodepath));
+}
+
+void ClientToServerCmd::add_node_for_edit_history(node_ptr the_node) const {
+    if (the_node.get())
+        edit_history_nodes_.push_back(the_node);
+}
+
+void ClientToServerCmd::add_node_path_for_edit_history(const std::string& absNodepath) const {
+    edit_history_node_paths_.push_back(absNodepath);
+}
+
+void ClientToServerCmd::add_edit_history(Defs* defs) const {
+    if (!use_EditHistoryMgr_) {
+        return; // edit history will be added by the command
+    }
+
+    // record all the user edits to the node. Reuse the time stamp cache created in handleRequest()
+    if (edit_history_nodes_.empty() && edit_history_node_paths_.empty()) {
+
+        defs->flag().set(ecf::Flag::MESSAGE);
+        add_edit_history(defs, Str::ROOT_PATH());
+    }
+    else {
+        // edit_history_node_paths_ is only populated by the delete command
+        size_t the_size = edit_history_node_paths_.size();
+        if (the_size != 0)
+            defs->flag().set(ecf::Flag::MESSAGE);
+        for (size_t i = 0; i < the_size; i++) {
+            add_delete_edit_history(defs, edit_history_node_paths_[i]);
+        }
+
+        the_size = edit_history_nodes_.size();
+        for (size_t i = 0; i < the_size; i++) {
+            node_ptr edited_node = edit_history_nodes_[i].lock();
+            if (edited_node.get()) {
+                // Setting the flag will make a state change. But its OK command allows it.
+                // Since we only get called if command can make state changes (isWrite() == true)
+                SuiteChangedPtr suiteChanged(edited_node.get());
+                edited_node->flag().set(ecf::Flag::MESSAGE); // trap state change in suite for sync
+                add_edit_history(defs, edited_node->absNodePath());
+            }
+        }
+    }
+
+    edit_history_nodes_.clear();
+    edit_history_node_paths_.clear();
+}
+
+void ClientToServerCmd::add_edit_history(Defs* defs, const std::string& path) const {
+    // Note: if the cts_cmd_, had thousands of paths, calling  cts_cmd_->print(ss); will append those paths to the
+    //       output, HUGE performance bottle neck, Since we are recording what command was applied to each node
+    //       we ONLY need the single path.
+    //
+    //       The old code hacked around this issue by doing vector<string>().swap(paths_);in handleRequest()
+    //       This caused its own set of problems. JIRA 434
+    // See: Client/bin/gcc-4.8/release/perf_test_large_defs
+
+    // record all the user edits to the node. Reuse the time stamp cache created in handleRequest()
+    std::string ss("MSG:");
+    ss += Log::instance()->get_cached_time_stamp();
+
+    print(ss, path); // custom print
+    defs->add_edit_history(path, ss);
+}
+
+void ClientToServerCmd::add_delete_edit_history(Defs* defs, const std::string& path) const {
+    // History is added to Str::ROOT_PATH(), but the path must show deleted node path
+    std::string ss("MSG:");
+    ss += Log::instance()->get_cached_time_stamp();
+
+    print(ss, path); // custom print
+    defs->add_edit_history(Str::ROOT_PATH(), ss);
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/ClientToServerCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,196 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_ClientToServerCmd_HPP
+#define ecflow_base_cts_ClientToServerCmd_HPP
+
+#include <boost/program_options.hpp>
+
+#include "ecflow/base/Cmd.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+class AbstractServer;
+class AbstractClientEnv;
+class GroupCTSCmd;
+
+///////////////////////////////////////////////////////////////////////////////////
+// Client->Server cmd's
+///////////////////////////////////////////////////////////////////////////////////
+class ClientToServerCmd {
+public:
+    virtual ~ClientToServerCmd();
+
+    /// The host where the client was called
+    const std::string& hostname() const { return cl_host_; }
+
+    /// The second print is for use by EditHistoryMgr when we have commands that take multiple paths
+    /// The EditHistoryMgr records what command was applied to each node. However when logging the
+    /// the command we do not want logs all the paths, for each node.(performance bottleneck
+    /// when dealing with thousands of paths)
+    virtual void print(std::string& os) const = 0;
+    virtual void print(std::string& os, const std::string& /*path*/) const { print(os); }
+
+    /// Print the command without trailing <user>@<host>. Used by Group command, avoids duplicate user@host for each
+    /// child command
+    virtual void print_only(std::string& os) const { return print(os); }
+
+    /// Print with minimal information. Deals with errors report where cmd have thousands of paths. truncate to one
+    /// path. This should *NOT* include trailing <user>@<host>
+    virtual std::string print_short() const {
+        std::string ret;
+        print_only(ret);
+        return ret;
+    }
+
+    virtual bool equals(ClientToServerCmd* rhs) const;
+
+    /// Called by the _server_ to service the client depending on the Command
+    /// The server will pass itself down via the AbstractServer
+    /// The returned Server to Client  command is sent back to the client
+    /// Uses template pattern, it first authenticates request and then calls
+    /// doHandleRequest. This function can throw exceptions. std::runtime_error
+    STC_Cmd_ptr handleRequest(AbstractServer*) const;
+
+    /// After handleRequest() has run, this function can be used reclaim memory
+    virtual void cleanup() {}
+
+    /// Returns true if handleRequest is testable. Only used in TEST
+    virtual bool handleRequestIsTestable() const { return true; }
+
+    /// How long in seconds the client to attempt to send request and get a reply back
+    /// before the request fails. This timeout affects the wait for the outward request
+    /// and inward reply.
+    ///
+    /// The timeout feature allow the client to fail gracefully in the case
+    /// where the server has died/crashed. The timeout will ensure the socket is closed.
+    /// allowing the server to be restarted without getting the address is use error.
+    ///
+    /// NOTE: We also have a timeout in ClientInvoker/ClientEnvironment, *that* is different,
+    ///       as that applies to CHILD/task commands, and control how long we continue
+    ///       to iterate over the hosts files
+    virtual int timeout() const { return 60; }
+
+    /// A command can be read only command or write only command
+    /// A read only command will not change the state of the suites in the server
+    /// A write only command can modify the state of suite in the server
+    /// Used by the server for authentication since only write only users are allowed to edit.
+    virtual bool isWrite() const { return false; /* returning false means read only */ }
+
+    /// Some read only commands under exceptional situation can modify the DEFS.
+    /// i.e if write permission is removed from ECF_HOME then the check_pt command can fail
+    /// in which case if can set flags, Flag::LATE, Flag::CHECKPT_ERROR, Flag::LOG_ERROR to warn the users
+    /// This function is used to avoid unnecessary warning message.
+    virtual bool is_mutable() const { return false; }
+
+    /// Some commands modify the server but do not affect defs. i.e reload white list file,password file
+    /// Other like ClientHandleCmd make edits to defs(well kind off) but are read only.(i.e anyone can call them)
+    /// This return true for those commands that affect the defs, that we need sync on the client side.
+    virtual bool cmd_updates_defs() const { return isWrite(); }
+
+    /// This Must be called for client->server commands.As this is required
+    /// for authentication. *However* task based commands have their own authentication
+    /// mechanism, and don't need setup_user_authentification().
+    virtual void setup_user_authentification(const std::string& user, const std::string& passwd) = 0; // Used by PlugCmd
+    virtual bool setup_user_authentification(AbstractClientEnv&) = 0; // set user and passwd
+    virtual void setup_user_authentification()                   = 0; // if user empty setup.
+
+    /// Allow control over connection to different servers/hosts if the main server is down
+    /// i.e for a getCmd, we do not want to wait 24 hours, trying all the servers
+    /// However for Task based commands like , init,abort,event, meter,complete we
+    /// want this behaviour as it can alter Node tree state and thus affect dependent nodes
+    virtual bool connect_to_different_servers() const { return false; }
+
+    /// The show occurs on the client side
+    virtual PrintStyle::Type_t show_style() const { return PrintStyle::NOTHING; }
+
+    // Other commands
+    virtual bool get_cmd() const { return false; }
+    virtual bool task_cmd() const { return false; }
+    virtual bool terminate_cmd() const { return false; }
+    virtual bool group_cmd() const { return false; }
+    virtual bool ping_cmd() const { return false; }
+    virtual bool why_cmd(std::string&) const { return false; }
+    virtual bool show_cmd() const { return false; }
+    virtual void add_edit_history(Defs*) const;
+
+    // used by group_cmd to postfix syncCmd on all user commands that modify defs
+    virtual void set_client_handle(int /*client_handle*/) {} // used by group_cmd
+    virtual void set_group_cmd(const GroupCTSCmd*) {}
+
+    // CLIENT side Parse and command construction, create can throw std::runtime_error for errors
+    virtual const char* theArg() const                                              = 0; // used for argument parsing
+    virtual void addOption(boost::program_options::options_description& desc) const = 0;
+    virtual void
+    create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const = 0;
+
+protected:
+    ClientToServerCmd();
+
+    /// called by handleRequest, part of the template pattern
+    virtual STC_Cmd_ptr doHandleRequest(AbstractServer*) const = 0;
+
+    /// return true if authentication succeeds, false and STC_Cmd_ptr to return otherwise
+    /// This function is called from doHandleRequest and hence is called
+    /// from within the server. The default implementation will get the current
+    /// user and authenticate with reference to the white list file
+    virtual bool authenticate(AbstractServer*, STC_Cmd_ptr&) const = 0;
+
+    /// Log the command. Must typically be done before call doHandleRequest(), in case of crash/exception
+    /// In rare case allow override. (i.e for additional debug)
+    /// called by handleRequest, part of the template pattern
+    /// If logging fails set late flag to warn users ECFLOW-536
+    virtual void do_log(AbstractServer*) const;
+
+    /// Some commands which cause a change in state, should force an immediate job submission.
+    /// Providing the server is *NOT* shutdown
+    static STC_Cmd_ptr doJobSubmission(AbstractServer* as);
+
+    static void dumpVecArgs(const char* argOption, const std::vector<std::string>& args);
+
+    /// Find the node otherwise throw std:::runtime_error
+    node_ptr find_node(Defs*, const std::string& absNodepath) const;
+
+    /// Find The node for edit, otherwise throw std:::runtime_error
+    /// Will add the node edit history collection
+    node_ptr find_node_for_edit(Defs*, const std::string& absNodepath) const;
+
+    /// Find The node for edit, otherwise return a NULL pointer
+    /// Will add the node edit history collection
+    node_ptr find_node_for_edit_no_throw(Defs*, const std::string& absNodepath) const;
+
+    /// finds the associated node and adds to edit history nodes
+    void add_node_for_edit_history(Defs* as, const std::string& absNodepath) const;
+    void add_node_for_edit_history(node_ptr) const;
+    void add_node_path_for_edit_history(const std::string& absNodepath) const;
+
+    void add_edit_history(Defs*, const std::string& path) const;
+    void add_delete_edit_history(Defs*, const std::string& path) const;
+
+    mutable bool use_EditHistoryMgr_{
+        true}; // sometime quicker to add edit history in command, than using EditHistoryMgr
+private:
+    friend class GroupCTSCmd;
+    friend class EditHistoryMgr;
+    mutable std::vector<weak_node_ptr> edit_history_nodes_;    // NOT persisted
+    mutable std::vector<std::string> edit_history_node_paths_; // NOT persisted, used when deleting
+
+    std::string cl_host_; // The host where the client was called
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(CEREAL_NVP(cl_host_));
+    }
+};
+
+#endif /* ecflow_base_cts_ClientToServerCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,182 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/CtsCmdRegistry.hpp"
+
+#include <memory>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/cts/task/AbortCmd.hpp"
+#include "ecflow/base/cts/task/CompleteCmd.hpp"
+#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
+#include "ecflow/base/cts/task/EventCmd.hpp"
+#include "ecflow/base/cts/task/InitCmd.hpp"
+#include "ecflow/base/cts/task/LabelCmd.hpp"
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+#include "ecflow/base/cts/task/QueueCmd.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/CFileCmd.hpp"
+#include "ecflow/base/cts/user/CSyncCmd.hpp"
+#include "ecflow/base/cts/user/CheckPtCmd.hpp"
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
+#include "ecflow/base/cts/user/DeleteCmd.hpp"
+#include "ecflow/base/cts/user/EditScriptCmd.hpp"
+#include "ecflow/base/cts/user/ForceCmd.hpp"
+#include "ecflow/base/cts/user/FreeDepCmd.hpp"
+#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
+#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
+#include "ecflow/base/cts/user/LogCmd.hpp"
+#include "ecflow/base/cts/user/LogMessageCmd.hpp"
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/cts/user/PlugCmd.hpp"
+#include "ecflow/base/cts/user/QueryCmd.hpp"
+#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/base/cts/user/RunNodeCmd.hpp"
+#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
+#include "ecflow/base/cts/user/ShowCmd.hpp"
+#include "ecflow/base/cts/user/ZombieCmd.hpp"
+
+namespace po = boost::program_options;
+
+CtsCmdRegistry::CtsCmdRegistry(bool addGroupCmd) {
+    // If a new client to server command is added. Make sure to add it here.
+    // Could have used static initialisation' but this is less problematic.
+
+    /// The order dictates how the --help is shown *BUT* Since we traverse this list.
+    /// Place the command which require the fastest response first.
+    vec_.reserve(90);
+
+    vec_.push_back(std::make_shared<CSyncCmd>(CSyncCmd::NEWS, 0, 0, 0));
+    vec_.push_back(std::make_shared<CSyncCmd>(CSyncCmd::SYNC, 0, 0, 0));
+    vec_.push_back(std::make_shared<CSyncCmd>(0)); // SYNC_FULL
+    vec_.push_back(std::make_shared<CSyncCmd>(CSyncCmd::SYNC_CLOCK, 0, 0, 0));
+    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET));
+    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET_STATE));
+    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::MIGRATE));
+    vec_.push_back(std::make_shared<CheckPtCmd>());
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::PING));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RESTORE_DEFS_FROM_CHECKPT));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RESTART_SERVER));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::HALT_SERVER));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::SHUTDOWN_SERVER));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::TERMINATE_SERVER));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RELOAD_WHITE_LIST_FILE));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RELOAD_PASSWD_FILE));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::FORCE_DEP_EVAL));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::STATS));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::STATS_SERVER));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::STATS_RESET));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_ON));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_OFF));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::SERVER_LOAD));
+    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::JOB_GEN));
+    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::CHECK_JOB_GEN_ONLY));
+    vec_.push_back(std::make_shared<DeleteCmd>());
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::SUSPEND));
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::RESUME));
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::KILL));
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::STATUS));
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::CHECK));
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::EDIT_HISTORY));
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::ARCHIVE));
+    vec_.push_back(std::make_shared<PathsCmd>(PathsCmd::RESTORE));
+    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::FOB));
+    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::FAIL));
+    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::ADOPT));
+    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::BLOCK));
+    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::REMOVE));
+    vec_.push_back(std::make_shared<ZombieCmd>(ecf::User::KILL));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::GET_ZOMBIES));
+    vec_.push_back(std::make_shared<CtsCmd>(CtsCmd::SUITES));
+    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::REGISTER));
+    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::DROP));
+    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::DROP_USER));
+    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::ADD));
+    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::REMOVE));
+    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::AUTO_ADD));
+    vec_.push_back(std::make_shared<ClientHandleCmd>(ClientHandleCmd::SUITES));
+    vec_.push_back(std::make_shared<LogCmd>());
+    vec_.push_back(std::make_shared<ServerVersionCmd>());
+    vec_.push_back(std::make_shared<LogMessageCmd>());
+    vec_.push_back(std::make_shared<BeginCmd>());
+    vec_.push_back(std::make_shared<InitCmd>());
+    vec_.push_back(std::make_shared<CompleteCmd>());
+    vec_.push_back(std::make_shared<AbortCmd>());
+    vec_.push_back(std::make_shared<CtsWaitCmd>());
+    vec_.push_back(std::make_shared<EventCmd>());
+    vec_.push_back(std::make_shared<MeterCmd>());
+    vec_.push_back(std::make_shared<LabelCmd>());
+    vec_.push_back(std::make_shared<QueueCmd>());
+    vec_.push_back(std::make_shared<RequeueNodeCmd>());
+    vec_.push_back(std::make_shared<OrderNodeCmd>());
+    vec_.push_back(std::make_shared<RunNodeCmd>());
+    vec_.push_back(std::make_shared<ForceCmd>());
+    vec_.push_back(std::make_shared<FreeDepCmd>());
+    vec_.push_back(std::make_shared<LoadDefsCmd>());
+    vec_.push_back(std::make_shared<ReplaceNodeCmd>());
+    vec_.push_back(std::make_shared<CFileCmd>());
+    vec_.push_back(std::make_shared<EditScriptCmd>());
+    vec_.push_back(std::make_shared<AlterCmd>());
+    vec_.push_back(std::make_shared<QueryCmd>());
+    vec_.push_back(std::make_shared<PlugCmd>());
+    // Note: we deliberately do not add MoveCmd, as it should not appear in the public api
+    //       It is created on the fly by the PlugCmd
+
+    /// Command that can *ONLY* be used in a group command
+    vec_.push_back(std::make_shared<CtsNodeCmd>(CtsNodeCmd::WHY));
+    vec_.push_back(std::make_shared<ShowCmd>());
+    if (addGroupCmd)
+        vec_.push_back(std::make_shared<GroupCTSCmd>());
+}
+
+bool CtsCmdRegistry::parse(Cmd_ptr& cmd,
+                           boost::program_options::variables_map& vm,
+                           AbstractClientEnv* clientEnv) const {
+    for (const auto& registered_cmd : vec_) {
+
+        if (vm.count(registered_cmd->theArg())) {
+
+            if (clientEnv->debug())
+                std::cout << "  CtsCmdRegistry::parse matched with registered command " << registered_cmd->theArg()
+                          << "\n";
+
+            registered_cmd->create(cmd, vm, clientEnv);
+            return true;
+        }
+    }
+
+    return false;
+}
+
+void CtsCmdRegistry::addAllOptions(boost::program_options::options_description& desc) const {
+    addCmdOptions(desc);
+    addHelpOption(desc);
+}
+
+void CtsCmdRegistry::addCmdOptions(boost::program_options::options_description& desc) const {
+    for (const auto& registered_cmd : vec_) {
+        registered_cmd->addOption(desc);
+    }
+}
+
+void CtsCmdRegistry::addHelpOption(boost::program_options::options_description& desc) const {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    desc.add_options()("help,h", po::value<std::string>()->implicit_value(std::string("")), "Produce help message");
+    desc.add_options()("version,v", "Show ecflow client version number, and version of the boost library used");
+    desc.add_options()("debug,d",
+                       "Enables the display of client environment settings and execution details.\n"
+                       "Has the same effect as setting environment variable ECF_DEBUG_CLIENT.");
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/CtsCmdRegistry.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_CtsCmdRegistry_HPP
+#define ecflow_base_cts_CtsCmdRegistry_HPP
+
+#include <vector>
+
+#include <boost/program_options.hpp>
+
+#include "ecflow/base/Cmd.hpp"
+
+class AbstractClientEnv;
+
+///
+/// \brief Registration of all the client to server commands
+///
+/// This allows us to parse the arg associated with commands in this category.
+/// The idea is to keep new commands functionality in one place.
+/// Any new client to server commands that are created must be added to this class.
+///
+
+class CtsCmdRegistry {
+public:
+    CtsCmdRegistry(const CtsCmdRegistry&)                  = delete;
+    const CtsCmdRegistry& operator=(const CtsCmdRegistry&) = delete;
+
+    explicit CtsCmdRegistry(bool addGroupCmd = true);
+
+    /// These option describe the arguments for each of the commands
+    /// They also can be presented to the user via --help option.
+    void addAllOptions(boost::program_options::options_description& desc) const;
+    void addCmdOptions(boost::program_options::options_description& desc) const;
+
+    /// Parse arguments given in 'vm' and use that to create a command
+    /// that will be sent to the server. Will throw std::runtime_error for errors
+    /// Returns true if command line argument specified via 'vm', matches one of the
+    /// registered command.
+    /// *** This allows us to distinguish between where we match with a registered
+    /// *** command, but do *NOT* set Cmd_ptr, ie since its a client specific command
+    /// *** i.e there is no need to send it to the server
+    bool parse(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const;
+
+private:
+    std::vector<Cmd_ptr> vec_;
+
+    void addHelpOption(boost::program_options::options_description& desc) const;
+};
+
+#endif /* ecflow_base_cts_CtsCmdRegistry_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/EditHistoryMgr.hpp"
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace boost;
+using namespace ecf;
+
+EditHistoryMgr::EditHistoryMgr(const ClientToServerCmd* c, AbstractServer* a)
+    : cts_cmd_(c),
+      as_(a),
+      state_change_no_(Ecf::state_change_no()),
+      modify_change_no_(Ecf::modify_change_no()) {
+    assert(cts_cmd_->edit_history_nodes_.empty());
+    assert(cts_cmd_->edit_history_node_paths_.empty());
+}
+
+EditHistoryMgr::~EditHistoryMgr() {
+    // check if state changed
+    if (state_change_no_ != Ecf::state_change_no() || modify_change_no_ != Ecf::modify_change_no()) {
+
+        // Ignore child commands for edit history, where only interested in user commands
+        if (!cts_cmd_->task_cmd()) {
+
+            // *ONLY* record edit history to commands that change the data model
+            // Otherwise we will end up making a data model change for read only commands
+            // If there has been a change in defs state then the command must return true from isWrite
+            if (cts_cmd_->isWrite()) {
+                cts_cmd_->add_edit_history(as_->defs().get());
+            }
+            else {
+                // Read only command, that is making data model changes, oops ?
+                // Can happen with check pt command, when ecf_home can't be written to, (exceptional)
+                // i.e set late flag( when saving takes more the 30 seconds) *OR* Flag::CHECKPT_ERROR | Flag::LOG_ERROR
+                //       even though its read only command. In which case is_mutable() should return true.
+                if (!cts_cmd_->is_mutable()) {
+                    std::string ss;
+                    cts_cmd_->print(ss);
+                    cout << "cmd " << ss << " should return true from isWrite() ******************\n";
+                    cout << "Read only command is making data changes to defs ?????\n";
+                    cout << "Ecf::state_change_no() " << Ecf::state_change_no() << " Ecf::modify_change_no() "
+                         << Ecf::modify_change_no() << "\n";
+                    cout << "state_change_no_       " << state_change_no_ << " modify_change_no_       "
+                         << modify_change_no_ << "\n";
+                    cout.flush();
+                }
+            }
+        }
+    }
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/EditHistoryMgr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_EditHistoryMgr_HPP
+#define ecflow_base_cts_EditHistoryMgr_HPP
+
+class ClientToServerCmd;
+class AbstractServer;
+
+///
+/// \brief This class manages the edit history, for the commands.
+/// It determines if there was a state change, if there was, it adds edit
+/// history to the stored nodes.
+/// Additionally we check that if there was an edit then the command must
+/// return ClientToServerCmd::isWrite() true.
+///
+
+class EditHistoryMgr {
+public:
+    EditHistoryMgr()                      = delete;
+    EditHistoryMgr(const EditHistoryMgr&) = delete;
+    EditHistoryMgr(const ClientToServerCmd*, AbstractServer*);
+    ~EditHistoryMgr();
+
+    EditHistoryMgr& operator=(const EditHistoryMgr&) = delete;
+
+private:
+    const ClientToServerCmd* cts_cmd_;
+    AbstractServer* as_;
+    mutable unsigned int state_change_no_;  // detect state change in defs
+    mutable unsigned int modify_change_no_; // detect state change in defs
+};
+
+#endif /* ecflow_base_cts_EditHistoryMgr_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/AbortCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/AbortCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/AbortCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/AbortCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,134 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/AbortCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+AbortCmd::AbortCmd(const std::string& pathToTask,
+                   const std::string& jobsPassword,
+                   const std::string& process_or_remote_id,
+                   int try_no,
+                   const std::string& reason)
+    : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+      reason_(reason) {
+    if (!reason_.empty()) {
+        // Do not use "\n" | ';' in Submittable::abr_, as this can mess up, --migrate output
+        // Which would then affect --load.
+        Str::replace(reason_, "\n", "");
+        Str::replace(reason_, ";", " ");
+    }
+}
+
+void AbortCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += "abort ";
+    os += path_to_node();
+    os += "  ";
+    os += reason_;
+}
+
+bool AbortCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<AbortCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (reason_ != the_rhs->reason())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+STC_Cmd_ptr AbortCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_abort_++;
+
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+
+    {
+        /// If there is an associated zombie, remove from the list
+        as->zombie_ctrl().remove(submittable_);
+
+        // update suite change numbers before job submission, submittable_ setup during authentication
+        SuiteChanged1 changed(submittable_->suite());
+
+        string theReason = reason_;
+        if (theReason.empty())
+            theReason = "Trap raised in job file";
+
+        submittable_->aborted(theReason); // will set task->set_state(NState::ABORTED);
+    }
+
+    // Do job submission in case any triggers dependent on NState::ABORTED
+    // If task try number is less than ECF_TRIES we attempt to re-submit the job.(ie if still in limit)
+    as->increment_job_generation_count();
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* AbortCmd::arg() {
+    return TaskApi::abortArg();
+}
+const char* AbortCmd::desc() {
+    return "Mark task as aborted. For use in the '.ecf' script file *only*\n"
+           "Hence the context is supplied via environment variables\n"
+           "  arg1 = (optional) string(reason)\n"
+           "         Optionally provide a reason why the abort was raised\n\n"
+           "If this child command is a zombie, then the default action will be to *block*.\n"
+           "The default can be overridden by using zombie attributes.\n"
+           "Otherwise the blocking period is defined by ECF_TIMEOUT.\n\n"
+           "Usage:\n"
+           "  ecflow_client --abort=reasonX";
+}
+
+void AbortCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(AbortCmd::arg(), po::value<string>()->implicit_value(string()), AbortCmd::desc());
+}
+void AbortCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    std::string reason = vm[arg()].as<std::string>();
+
+    if (clientEnv->debug())
+        cout << "  AbortCmd::create " << AbortCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
+             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
+             << clientEnv->task_try_no() << ") reason(" << reason << ")\n";
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("AbortCmd: " + errorMsg);
+    }
+
+    cmd = std::make_shared<AbortCmd>(clientEnv->task_path(),
+                                     clientEnv->jobs_password(),
+                                     clientEnv->process_or_remote_id(),
+                                     clientEnv->task_try_no(),
+                                     reason);
+}
+
+std::ostream& operator<<(std::ostream& os, const AbortCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(AbortCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(AbortCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/AbortCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/AbortCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/AbortCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/AbortCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,54 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_AbortCmd_HPP
+#define ecflow_base_cts_task_AbortCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+
+class AbortCmd final : public TaskCmd {
+public:
+    AbortCmd(const std::string& pathToTask,
+             const std::string& jobsPassword,
+             const std::string& process_or_remote_id,
+             int try_no                = 1,
+             const std::string& reason = "");
+    AbortCmd() : TaskCmd() {}
+
+    const std::string& reason() const { return reason_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::ABORT; }
+
+    std::string reason_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(reason_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const AbortCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(AbortCmd)
+
+#endif /* ecflow_base_cts_task_AbortCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,124 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/CompleteCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+void CompleteCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += "complete ";
+    os += path_to_node();
+    if (!var_to_del_.empty()) {
+        os += " --remove";
+        for (const auto& var_to_del : var_to_del_) {
+            os += " ";
+            os += var_to_del;
+        }
+    }
+}
+
+bool CompleteCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<CompleteCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (var_to_del_ != the_rhs->variables_to_delete())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+STC_Cmd_ptr CompleteCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_complete_++;
+
+    {
+        /// If there is an associated zombie, remove from the list. Must match,
+        /// Do this before task->complete(), since that clears password & process id
+        /// remove(..) uses password/ process id to match the right zombie
+        as->zombie_ctrl().remove(submittable_);
+
+        // update suite change numbers before job submission, submittable_ setup during authentication
+        SuiteChanged1 changed(submittable_->suite());
+        submittable_->complete(); // will set task->set_state(NState::COMPLETE);
+
+        for (const auto& var_to_delete : var_to_del_) {
+            submittable_->delete_variable_no_error(var_to_delete);
+        }
+    }
+
+    // Do job submission in case any triggers dependent on NState::COMPLETE
+    as->increment_job_generation_count();
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* CompleteCmd::arg() {
+    return TaskApi::completeArg();
+}
+const char* CompleteCmd::desc() {
+    return "Mark task as complete. For use in the '.ecf' script file *only*\n"
+           "Hence the context is supplied via environment variables\n\n"
+           "If this child command is a zombie, then the default action will be to *block*.\n"
+           "The default can be overridden by using zombie attributes.\n"
+           "Otherwise the blocking period is defined by ECF_TIMEOUT.\n"
+           "The init command allows variables to be added, and complete command\n"
+           "allows for them to be removed.\n"
+           "  arg1(--remove)(optional) = a list of variables to removed from this task\n\n"
+           "Usage:\n"
+           "  ecflow_client --complete\n"
+           "  ecflow_client --complete --remove name1 name2 # delete variables name1 and name2 on the task";
+}
+
+void CompleteCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(CompleteCmd::arg(), CompleteCmd::desc())(
+        "remove", po::value<vector<string>>()->multitoken(), "remove variables i.e name name2");
+}
+void CompleteCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    if (clientEnv->debug())
+        cout << "  CompleteCmd::create " << CompleteCmd::arg() << " task_path(" << clientEnv->task_path()
+             << ") password(" << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id()
+             << ") try_no(" << clientEnv->task_try_no() << ")\n";
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("CompleteCmd: " + errorMsg);
+    }
+
+    std::vector<std::string> variable_vec;
+    if (vm.count("remove"))
+        variable_vec = vm["remove"].as<vector<string>>();
+
+    cmd = std::make_shared<CompleteCmd>(clientEnv->task_path(),
+                                        clientEnv->jobs_password(),
+                                        clientEnv->process_or_remote_id(),
+                                        clientEnv->task_try_no(),
+                                        variable_vec);
+}
+
+std::ostream& operator<<(std::ostream& os, const CompleteCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(CompleteCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(CompleteCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/CompleteCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_CompleteCmd_HPP
+#define ecflow_base_cts_task_CompleteCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+#include "ecflow/core/cereal_optional_nvp.hpp"
+
+class CompleteCmd final : public TaskCmd {
+public:
+    CompleteCmd(const std::string& pathToTask,
+                const std::string& jobsPassword,
+                const std::string& process_or_remote_id = "",
+                int try_no                              = 1,
+                const std::vector<std::string>& vec     = std::vector<std::string>())
+        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+          var_to_del_(vec) {}
+    CompleteCmd() : TaskCmd() {}
+
+    const std::vector<std::string>& variables_to_delete() const { return var_to_del_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::COMPLETE; }
+
+private:
+    std::vector<std::string> var_to_del_; //  variables to delete on task
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this));
+        CEREAL_OPTIONAL_NVP(ar, var_to_del_, [this]() { return !var_to_del_.empty(); }); // conditionally save
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const CompleteCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(CompleteCmd)
+
+#endif /* ecflow_base_cts_task_CompleteCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,439 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+// #define DEBUG_ZOMBIE 1
+
+bool TaskCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<TaskCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (path_to_submittable_ != the_rhs->path_to_node())
+        return false;
+    if (jobs_password_ != the_rhs->jobs_password())
+        return false;
+    if (process_or_remote_id_ != the_rhs->process_or_remote_id())
+        return false;
+    if (try_no_ != the_rhs->try_no())
+        return false;
+    return ClientToServerCmd::equals(rhs);
+}
+
+// **********************************************************************************
+// IMPORTANT: In the current SMS/ECF only the init child command, passes the
+// process_or_remote_id_, for *ALL* other child commands this is empty.
+// The Automated tests get round this via setting ECF_RID in the header/tail job includes
+// However since this may not be in .sms/.ecf files, we cannot rely on it
+// Hence we need to be able to handle *EMPTY* process_or_remote_id_ for child commands
+//
+//  Task State | Child                      | Log | Explanation
+//  -------------------------------------------------------------------------------------------------------------
+//  SUBMITTED  | child!=INIT                | ERR | Script has child command in back ground, Bug in script, out of order
+//  ACTIVE     | INIT & pid & passwd match  | WAR | two init commands, overloaded server, or 2*init in script, *FOB*.
+//  Forgive ACTIVE     | INIT & pid & passwd !match | ERR | two init commands, Task started again by user. COMPLETE   |
+//  COMPLETE                   | WAR | two complete, zombie, overloaded server. *FOB*, Allow job to complete. Forgive.
+//  COMPLETE   | child != COMPLETE          | ERR | zombie
+//  ABORTED    | ABORTED                    | WAR | two aborted, zombie, overloaded server. *FOB*, allow process to
+//  exit. Forgive ABORTED    | child != ABORTED           | WAR | zombie
+//  -------------------------------------------------------------------------------------------------------------------
+//
+//  zombie type    |   PID   | password | explanation
+//  ---------------------------------------------------------------------------------------------------------------
+//  ECF_PID        |    X    | matches  | PID miss-match, but password matches. Job scheduled twice. Check submitter
+//  ECF_PID_PASSWD |    X    |     X    | Both PID and password miss-match. Re-queue & submit of active job
+//  ECF_PASSWD     | matches |     X    | Password miss-match, PID matches, system has re-cycled PID or hacked job file?
+//  ECF            | matches | matches  | overloaded server,Two init commands or task complete or aborted but receives
+//  another child cmd USER           |    ?    |     ?    | User initiated zombie whilst task was active or submitted,
+//  command is recorded in zombie PATH           |   n/a   |    n/a   | Task not found. Nodes replaced whilst jobs were
+//  running
+//  ----------------------------------------------------------------------------------------------------------------
+bool TaskCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& theReply) const {
+#ifdef DEBUG_ZOMBIE
+    std::cout << "   TaskCmd::authenticate " << Child::to_string(child_type());
+    std::cout << " " << path_to_submittable_ << " " << process_or_remote_id_ << " " << jobs_password_ << " " << try_no_;
+    const Zombie& zombie = as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
+    if (!zombie.empty())
+        std::cout << "  " << zombie;
+    else {
+        const Zombie& zombiep = as->zombie_ctrl().find_by_path_only(path_to_submittable_);
+        if (!zombiep.empty())
+            std::cout << "  find_by_path_only: " << zombiep;
+    }
+#endif
+    /// ***************************************************************************
+    /// Task based cmd have their own authentication mechanism, hence we
+    /// Don't need to call the base class authenticate
+    /// **************************************************************************
+
+    if (!as->allowTaskCommunication()) {
+        // This is not an Error, hence we don't throw exception
+        theReply = PreAllocatedReply::block_client_server_halted_cmd();
+        return false;
+    }
+
+    submittable_ = get_submittable(as);
+    if (!submittable_) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << ": PATH Zombie\n";
+#endif
+        // Create path zombie, if not already created:
+        std::string action_taken;
+        static_cast<void>(as->zombie_ctrl().handle_path_zombie(as, this, action_taken, theReply));
+
+        // distinguish output by using *path*
+        std::stringstream ss;
+        ss << " zombie(*path*) : chd:" << ecf::Child::to_string(child_type()) << " : " << path_to_submittable_ << " : "
+           << process_or_remote_id_ << " : " << jobs_password_ << " : action(" << action_taken << ")";
+        log(Log::ERR, ss.str());
+        return false;
+    }
+
+    // If the CMD *WAS* created with Submittable::DUMMY_JOBS_PASSWORD then we were testing
+    // This will be copied from client to server, hence we want to avoid same check in the
+    // server. when handleRequest is called()
+    // DO NOT place #ifdef DEBUG otherwise test will start failing for the release build
+    if (jobs_password_ == Submittable::DUMMY_JOBS_PASSWORD()) {
+        return true;
+    }
+
+    SuiteChanged1 changed(submittable_->suite());
+
+    /// Check if User wants to explicitly bypass password checking
+    /// This can be done via AlterCmd by adding a variable on the task,  ECF_PASS with value
+    /// Submittable::FREE_JOBS_PASSWORD Note: this *does not* look for the variable up the node tree, only on the task.
+    std::string ecf_pass_value;
+    if (submittable_->findVariableValue(Str::ECF_PASS(), ecf_pass_value)) {
+
+        if (ecf_pass_value == Submittable::FREE_JOBS_PASSWORD()) {
+            submittable_->flag().clear(ecf::Flag::ZOMBIE);
+            return true;
+        }
+    }
+
+    /// Handle corner case ,where we have two jobs with different process id, but same password
+    /// Can happen if jobs is started externally,
+    /// or via test(i.e submit 1,submit 2(force)) before job1 active its password is overridden
+    bool submittable_allready_aborted  = false;
+    bool submittable_allready_active   = false;
+    bool submittable_allready_complete = false;
+    password_missmatch_                = false;
+    pid_missmatch_                     = false;
+
+    /// *** In complete state, the password is empty.
+    if (submittable_->jobsPassword() != jobs_password_) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << ": submittable pass(" << submittable_->jobsPassword() << ") != jobs_password_(" << jobs_password_
+                  << ")";
+#endif
+        password_missmatch_ = true;
+    }
+
+    /// When state is in SUBMITTED, its process/remote_id is EMPTY. It will be set by the INIT child command.
+    /// Hence we can *NOT* mark it as pid_missmatch.
+    ///
+    /// *** See Note above: Not all child commands pass a process_id. ***
+    /// *** Hence this test for zombies is ONLY valid if process sets the process_or_remote_id_ ****
+    /// *** User should really set ECF_RID in the scripts
+    /// *** In submitted state, the pid is empty. hence clear pid_missmatch_ below
+    /// *** In complete state, the pid is empty.  hence clear pid_missmatch_ below
+    if (!submittable_->process_or_remote_id().empty() && !process_or_remote_id_.empty() &&
+        submittable_->process_or_remote_id() != process_or_remote_id_) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << ":task pid(" << submittable_->process_or_remote_id() << ") != process pid("
+                  << process_or_remote_id_ << ")";
+#endif
+        pid_missmatch_ = true;
+    }
+
+    switch (submittable_->state()) {
+        case NState::SUBMITTED: {
+            // The pid on the task will be empty
+            if (child_type() != Child::INIT) {
+                std::stringstream ss;
+                ss << path_to_submittable_
+                   << " When a node is submitted, expected next child command to be INIT but received "
+                   << Child::to_string(child_type());
+                log(Log::ERR, ss.str());
+            }
+            break;
+        }
+
+        case NState::ACTIVE: {
+            if (child_type() == Child::INIT) {
+#ifdef DEBUG_ZOMBIE
+                std::cout << ":(child_type() == Child::INIT) && submittable_->state() == NState::ACTIVE)";
+#endif
+                // *IF* password and pid matches be more forgiving. How can this case arise:
+                // i.e server is heavily overloaded, client calls init, which times out because server is busy
+                // Client then sends init again. In this case rather than treating it as a zombie, we will let it
+                // through providing the password and pid matches.
+                if (!password_missmatch_ && !pid_missmatch_) {
+                    string ret = " [ overloaded || --init*2 ](pid and passwd match) : chd:";
+                    ret += ecf::Child::to_string(child_type());
+                    ret += " : ";
+                    ret += path_to_submittable_;
+                    ret += " : already active : action(fob)";
+                    log(Log::WAR, ret);
+                    theReply = PreAllocatedReply::ok_cmd();
+                    return false;
+                }
+                submittable_allready_active = true;
+            }
+            break;
+        }
+
+        case NState::COMPLETE: {
+#ifdef DEBUG_ZOMBIE
+            std::cout << ": submittable_->state() == NState::COMPLETE)";
+#endif
+            if (child_type() == Child::COMPLETE) {
+                // Note: when a node completes, we clear tasks password and pid, to save memory on checkpt & network
+                // bandwidth (We could choose not to clear, This would allow us to disambiguate between 2/ and 3/
+                // below). HOWEVER:
+                //
+                // How can this situation arise:
+                //   1/ Two calls to --complete  (rare)
+                //   2/ Overloaded server. Client send --complete to server, but it is overload and does not respond,
+                //   the client then
+                //      times out. Server handles the request. When client tries again we get here. (possible)
+                //   3/ Zombie, two separate process. (possible, typically done by user action)
+                //
+                // For all three it should be safe to just fob:
+                //   1/ Two calls to --complete # Be forgiving
+                //   2/ Overloaded server       # The correct course of action
+                //   3/ zombie                  # The zombie has completed anyway, don't bother blocking it
+
+                submittable_->flag().clear(ecf::Flag::ZOMBIE);
+                as->zombie_ctrl().remove_by_path(path_to_submittable_);
+
+                string ret = " [ overloaded || zombie || --complete*2 ] : chd:";
+                ret += ecf::Child::to_string(child_type());
+                ret += " : ";
+                ret += path_to_submittable_;
+                ret += " : already complete : action(fob)";
+                log(Log::WAR, ret);
+                theReply = PreAllocatedReply::ok_cmd();
+                return false;
+            }
+
+            // If Task state is complete, and we receive **any** child command then it is a zombie
+            submittable_allready_complete = true;
+            password_missmatch_           = false;
+            pid_missmatch_                = false;
+            break;
+        }
+
+        case NState::ABORTED: {
+#ifdef DEBUG_ZOMBIE
+            std::cout << ": submittable_->state() == NState::ABORTED)";
+#endif
+
+            if (child_type() == Child::ABORT) {
+
+                if (!password_missmatch_ && !pid_missmatch_) {
+
+                    as->zombie_ctrl().remove(submittable_);
+
+                    string ret = " [ overloaded || --abort*2 ] (pid and passwd match) : chd:";
+                    ret += ecf::Child::to_string(child_type());
+                    ret += " : ";
+                    ret += path_to_submittable_;
+                    ret += " : already aborted : action(fob)";
+                    log(Log::WAR, ret);
+                    theReply = PreAllocatedReply::ok_cmd();
+                    return false;
+                }
+            }
+
+            // If Task state is aborted, and we receive **any** child command then it is a zombie
+            submittable_allready_aborted = true;
+            password_missmatch_          = false;
+            pid_missmatch_               = false;
+            break;
+        }
+        case NState::QUEUED:
+            break; // WTF
+        case NState::UNKNOWN:
+            break; // WTF
+    }
+
+#ifdef DEBUG_ZOMBIE
+    std::cout << "\n";
+#endif
+
+    if (password_missmatch_ || pid_missmatch_ || submittable_allready_active || submittable_allready_complete ||
+        submittable_allready_aborted) {
+        /// If the task has adopted we return true, and carry on as normal
+        std::string action_taken;
+        if (!as->zombie_ctrl().handle_zombie(submittable_, this, action_taken, theReply)) {
+
+            // LOG failure: Include type of zombie.
+            // ** NOTE **: the zombie may have been removed by user actions. i.e if fob and child cmd is abort |
+            // complete, etc
+            std::stringstream ss;
+            ss << " zombie";
+            const Zombie& theZombie =
+                as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
+            if (!theZombie.empty())
+                ss << "(" << theZombie.type_str() << ")";
+
+            ss << " : chd:" << ecf::Child::to_string(child_type());
+            ss << " : " << path_to_submittable_ << "(" << NState::toString(submittable_->state()) << ")";
+            ss << " : " << process_or_remote_id_ << " : " << jobs_password_;
+            if (submittable_allready_active)
+                ss << " : already active";
+            if (submittable_allready_complete)
+                ss << " : already complete";
+            if (submittable_allready_aborted)
+                ss << " : already aborted";
+            if (password_missmatch_)
+                ss << " : passwd != [ task:" << submittable_->jobsPassword() << " child:" << jobs_password_ << " ]";
+            if (pid_missmatch_)
+                ss << " : pid != [ task:" << submittable_->process_or_remote_id() << " child:" << process_or_remote_id_
+                   << " ]";
+            ss << " : action(" << action_taken << ")";
+            log(Log::ERR, ss.str());
+            return false;
+        }
+    }
+    return true;
+}
+
+Submittable* TaskCmd::get_submittable(AbstractServer* as) const {
+    node_ptr node = as->defs()->findAbsNode(path_to_submittable_);
+    if (!node.get()) {
+        return nullptr;
+    }
+
+    return node->isSubmittable();
+}
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+CtsWaitCmd::CtsWaitCmd(const std::string& pathToTask,
+                       const std::string& jobsPassword,
+                       const std::string& process_or_remote_id,
+                       int try_no,
+                       const std::string& expression)
+    : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+      expression_(expression) {
+    // Parse expression to make sure its valid
+    static_cast<void>(Expression::parse(expression, "CtsWaitCmd:")); // will throw for errors
+}
+
+void CtsWaitCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += "wait ";
+    os += expression_;
+    os += " ";
+    os += path_to_node();
+}
+
+bool CtsWaitCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<CtsWaitCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (expression_ != the_rhs->expression())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+STC_Cmd_ptr CtsWaitCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_wait_++;
+
+    SuiteChanged1 changed(submittable_->suite());
+
+    // Parse the expression, should not fail since client should have already check expression parses
+    // The complete expression have been parsed and we have created the abstract syntax tree
+    // We now need CHECK the AST for path nodes, event and meter. repeats,etc.
+    // *** This will also set the Node pointers ***
+    // If the expression references paths that don't exist throw an error
+    // This can be captured in the ecf script, which should then abort the task
+    // Otherwise we will end up blocking indefinitely
+    std::unique_ptr<AstTop> ast =
+        submittable_->parse_and_check_expressions(expression_, true, "CtsWaitCmd:"); // will throw for errors
+
+    // Evaluate the expression
+    if (ast->evaluate()) {
+
+        submittable_->flag().clear(ecf::Flag::WAIT);
+
+        // expression evaluates, return OK
+        return PreAllocatedReply::ok_cmd();
+    }
+
+    submittable_->flag().set(ecf::Flag::WAIT);
+
+    // Block/wait while expression is false
+    return PreAllocatedReply::block_client_on_home_server_cmd();
+}
+
+const char* CtsWaitCmd::arg() {
+    return TaskApi::waitArg();
+}
+const char* CtsWaitCmd::desc() {
+    return "Evaluates an expression, and block while the expression is false.\n"
+           "For use in the '.ecf' file *only*, hence the context is supplied via environment variables\n"
+           "  arg1 = string(expression)\n\n"
+           "Usage:\n"
+           "  ecflow_client --wait=\"/suite/taskx == complete\"";
+}
+
+void CtsWaitCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(CtsWaitCmd::arg(), po::value<string>(), CtsWaitCmd::desc());
+}
+void CtsWaitCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    std::string expression = vm[arg()].as<std::string>();
+
+    if (clientEnv->debug())
+        cout << "  CtsWaitCmd::create " << CtsWaitCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
+             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
+             << clientEnv->task_try_no() << ") expression(" << expression << ")\n";
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("CtsWaitCmd: " + errorMsg);
+    }
+
+    cmd = std::make_shared<CtsWaitCmd>(clientEnv->task_path(),
+                                       clientEnv->jobs_password(),
+                                       clientEnv->process_or_remote_id(),
+                                       clientEnv->task_try_no(),
+                                       expression);
+}
+
+std::ostream& operator<<(std::ostream& os, const CtsWaitCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(CtsWaitCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(CtsWaitCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/CtsWaitCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_CtsWaitCmd_HPP
+#define ecflow_base_cts_task_CtsWaitCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+
+/// A child command that evaluates a expression. If the expression is false.
+/// Then client invoker will block.
+class CtsWaitCmd final : public TaskCmd {
+public:
+    CtsWaitCmd(const std::string& pathToTask,
+               const std::string& jobsPassword,
+               const std::string& process_or_remote_id,
+               int try_no,
+               const std::string& expression);
+    CtsWaitCmd() : TaskCmd() {}
+
+    const std::string& expression() const { return expression_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::WAIT; }
+
+    std::string expression_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(expression_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const CtsWaitCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(CtsWaitCmd)
+
+#endif /* ecflow_base_cts_task_CtsWaitCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/EventCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/EventCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/EventCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/EventCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,141 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/EventCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool EventCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<EventCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (name_ != the_rhs->name())
+        return false;
+    if (value_ != the_rhs->value())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+void EventCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += "event ";
+    os += name_;
+    os += " ";
+    if (value_)
+        os += "1 ";
+    else
+        os += "0 ";
+    os += path_to_node();
+}
+
+STC_Cmd_ptr EventCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_event_++;
+
+    { // update suite change numbers before job submission,  task_ setup during authentication
+        SuiteChanged1 changed(submittable_->suite());
+
+        // The name could either be "string" or an integer either way it should be unique
+        if (!submittable_->set_event(name_, value_)) {
+            std::string ss;
+            ss = "Event request failed as event '";
+            ss += name_;
+            ss += "' does not exist on task ";
+            ss += path_to_node();
+            ecf::log(Log::ERR, ss);
+            return PreAllocatedReply::ok_cmd();
+        }
+    }
+
+    // Do job submission in case any triggers dependent on events
+    as->increment_job_generation_count();
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* EventCmd::arg() {
+    return TaskApi::eventArg();
+}
+const char* EventCmd::desc() {
+    return "Change event. For use in the '.ecf' script file *only*\n"
+           "Hence the context is supplied via environment variables\n"
+           "  arg1(string | int)     = event-name\n\n"
+           "  arg2(string)(optional) = [ set | clear] default value is set\n\n"
+           "If this child command is a zombie, then the default action will be to *fob*,\n"
+           "i.e allow the ecflow client command to complete without an error\n"
+           "The default can be overridden by using zombie attributes.\n\n"
+           "Usage:\n"
+           "  ecflow_client --event=ev       # set the event, default since event initial value is clear\n"
+           "  ecflow_client --event=ev set   # set the event, explicit\n"
+           "  ecflow_client --event=ev clear # clear the event, use when event initial value is set\n";
+}
+
+void EventCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(EventCmd::arg(), po::value<vector<string>>()->multitoken(), EventCmd::desc());
+}
+void EventCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+    std::string event;
+    if (args.size() >= 1)
+        event = args[0];
+
+    bool value = true;
+    if (args.size() == 2) {
+        if (args[1] == "set")
+            value = true;
+        else if (args[1] == "clear")
+            value = false;
+        else {
+            std::stringstream ss;
+            ss << "EventCmd: The second argument must be [ set | clear ] but found " << args[1];
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    if (clientEnv->debug())
+        cout << "  EventCmd::create " << EventCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
+             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
+             << clientEnv->task_try_no() << ") event(" << event << ")"
+             << ") value(" << value << ")\n";
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("EventCmd: " + errorMsg);
+    }
+
+    cmd = std::make_shared<EventCmd>(clientEnv->task_path(),
+                                     clientEnv->jobs_password(),
+                                     clientEnv->process_or_remote_id(),
+                                     clientEnv->task_try_no(),
+                                     event,
+                                     value);
+}
+
+std::ostream& operator<<(std::ostream& os, const EventCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(EventCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(EventCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/EventCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/EventCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/EventCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/EventCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_EventCmd_HPP
+#define ecflow_base_cts_task_EventCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+#include "ecflow/core/cereal_optional_nvp.hpp"
+
+class EventCmd final : public TaskCmd {
+public:
+    EventCmd(const std::string& pathToTask,
+             const std::string& jobsPassword,
+             const std::string& process_or_remote_id,
+             int try_no,
+             const std::string& eventName,
+             bool value = true) // true = set(default), false = clear
+        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+          name_(eventName),
+          value_(value) {}
+    EventCmd() : TaskCmd() {}
+
+    const std::string& name() const { return name_; }
+    bool value() const { return value_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::EVENT; }
+
+private:
+    std::string name_; // the events name
+    bool value_{true}; // true = set(default), false = clear
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(name_));
+        CEREAL_OPTIONAL_NVP(ar, value_, [this]() { return !value_; }); // conditionally save if value is false
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const EventCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(EventCmd)
+
+#endif /* ecflow_base_cts_task_EventCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/InitCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/InitCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/InitCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/InitCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,154 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/InitCmd.hpp"
+
+#include <stdexcept>
+
+#include <cereal/cereal.hpp>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+void InitCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += "init ";
+    os += path_to_node();
+    if (!var_to_add_.empty()) {
+        os += " --add";
+        for (const auto& var_to_add : var_to_add_) {
+            os += " ";
+            os += var_to_add.name();
+            os += "=";
+            os += var_to_add.theValue();
+        }
+    }
+}
+
+bool InitCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<InitCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (var_to_add_ != the_rhs->variables_to_add())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+STC_Cmd_ptr InitCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_init_++;
+
+    { // update suite change numbers before job submission. submittable_ setup during authentication
+        SuiteChanged1 changed(submittable_->suite());
+        submittable_->init(process_or_remote_id()); // will set task->set_state(NState::ACTIVE);
+
+        for (const auto& var_to_add : var_to_add_) {
+            submittable_->addVariable(var_to_add); // will update or add variable
+        }
+    }
+
+    // Do job submission in case any triggers dependent on NState::ACTIVE
+    as->increment_job_generation_count();
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* InitCmd::arg() {
+    return TaskApi::initArg();
+}
+const char* InitCmd::desc() {
+    return "Mark task as started(active). For use in the '.ecf' script file *only*\n"
+           "Hence the context is supplied via environment variables.\n"
+           "  arg1(string)         = process_or_remote_id The process id of the job or remote_id\n"
+           "                         Using remote id allows the jobs to be killed\n"
+           "  arg2(--add)(optional)= add/update variables as name value pairs\n\n"
+           "If this child command is a zombie, then the default action will be to *block*.\n"
+           "The default can be overridden by using zombie attributes.\n"
+           "Otherwise the blocking period is defined by ECF_TIMEOUT.\n\n"
+           "Usage:\n"
+           "  ecflow_client --init=$$\n"
+           "  ecflow_client --init=$$ --add name=value name2=value2 # add/update variables to task";
+}
+
+void InitCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(InitCmd::arg(), po::value<string>(), InitCmd::desc())(
+        "add",
+        po::value<vector<string>>()->multitoken(),
+        "Add variables e.g. name1=value1 name2=value2. Can only be used in combination with --init command.");
+}
+
+void InitCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    std::string process_or_remote_id = vm[arg()].as<std::string>();
+
+    if (clientEnv->debug())
+        cout << "  InitCmd::create " << InitCmd::arg() << "  clientEnv->task_path(" << clientEnv->task_path()
+             << ") clientEnv->jobs_password(" << clientEnv->jobs_password() << ") clientEnv->process_or_remote_id("
+             << clientEnv->process_or_remote_id() << ") clientEnv->task_try_no(" << clientEnv->task_try_no()
+             << ") process_or_remote_id(" << process_or_remote_id << ") clientEnv->under_test("
+             << clientEnv->under_test() << ")\n";
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("InitCmd: " + errorMsg);
+    }
+
+    /// if ECF_RID is specified then it *MUST* be the same as input argument
+    /// On cca we ECF_RID can be specified under test, and therefore fail this check, hence we use
+    /// clientEnv->under_test()
+    if (!clientEnv->under_test() && !clientEnv->process_or_remote_id().empty() &&
+        clientEnv->process_or_remote_id() != process_or_remote_id) {
+        std::stringstream ss;
+        ss << "remote id(" << process_or_remote_id
+           << ") passed as an argument, not the same the client environment ECF_RID("
+           << clientEnv->process_or_remote_id() << ")";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::vector<Variable> variable_vec;
+    if (vm.count("add")) {
+        vector<string> var_args = vm["add"].as<vector<string>>();
+        if (!var_args.empty()) {
+            variable_vec.reserve(var_args.size());
+            for (const auto& v : var_args) {
+                std::vector<std::string> tokens;
+                Str::split(v, tokens, "=");
+                if (tokens.size() != 2) {
+                    throw std::runtime_error(
+                        "Could not parse variable provided to --add; Expected  var1=value1 var2=value2 but found " + v);
+                }
+                variable_vec.emplace_back(tokens[0], tokens[1]);
+            }
+        }
+    }
+
+    cmd = std::make_shared<InitCmd>(clientEnv->task_path(),
+                                    clientEnv->jobs_password(),
+                                    process_or_remote_id,
+                                    clientEnv->task_try_no(),
+                                    variable_vec);
+}
+
+std::ostream& operator<<(std::ostream& os, const InitCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(InitCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(InitCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/InitCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/InitCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/InitCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/InitCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,60 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_InitCmd_HPP
+#define ecflow_base_cts_task_InitCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+#include "ecflow/core/cereal_optional_nvp.hpp"
+
+class InitCmd final : public TaskCmd {
+public:
+    InitCmd(const std::string& pathToTask,
+            const std::string& jobsPassword,
+            const std::string& process_or_remote_id,
+            int try_no,
+            const std::vector<Variable>& vec = {})
+        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+          var_to_add_(vec) {}
+
+    InitCmd() : TaskCmd() {}
+
+    const std::vector<Variable>& variables_to_add() const { return var_to_add_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::INIT; }
+
+private:
+    std::vector<Variable> var_to_add_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this));
+        CEREAL_OPTIONAL_NVP(ar, var_to_add_, [this]() { return !var_to_add_.empty(); }); // conditionally save
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const InitCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(InitCmd)
+
+#endif /* ecflow_base_cts_task_InitCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/LabelCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/LabelCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/LabelCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/LabelCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,138 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/LabelCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool LabelCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<LabelCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (name_ != the_rhs->name())
+        return false;
+    if (label_ != the_rhs->label())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+void LabelCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += "label ";
+    os += name_;
+    os += " '";
+    os += label_;
+    os += "' ";
+    os += path_to_node();
+}
+
+STC_Cmd_ptr LabelCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_label_++;
+
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+
+    // submittable_ setup during authentication
+    if (submittable_->findLabel(name_)) {
+
+        SuiteChanged1 changed(submittable_->suite());
+        submittable_->changeLabel(name_, label_);
+    }
+    // else {
+    //   // ECFLOW-175, avoid filling up log file. Can get thousands of these messages, especially form MARS
+    //   std::string ss;
+    //   ss = "Label request failed as label '"; ss += name_; ss += "' does not exist on task "; ss += path_to_node();
+    //	  ecf::log(Log::ERR,ss);
+    //}
+
+    // Note: reclaiming memory for label_ earlier make *no* difference to performance of server
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* LabelCmd::arg() {
+    return TaskApi::labelArg();
+}
+const char* LabelCmd::desc() {
+    return "Change Label. For use in the '.ecf' script file *only*\n"
+           "Hence the context is supplied via environment variables\n"
+           "  arg1 = label-name\n"
+           "  arg2 = The new label value\n"
+           "         The labels values can be single or multi-line(space separated quoted strings)\n\n"
+           "If this child command is a zombie, then the default action will be to *fob*,\n"
+           "i.e allow the ecflow client command to complete without an error\n"
+           "The default can be overridden by using zombie attributes.\n\n"
+           "Usage:\n"
+           "  ecflow_client --label=progressed merlin";
+}
+
+void LabelCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(LabelCmd::arg(), po::value<vector<string>>()->multitoken(), LabelCmd::desc());
+}
+void LabelCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (clientEnv->debug()) {
+        dumpVecArgs(LabelCmd::arg(), args);
+        cout << "  LabelCmd::create " << LabelCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
+             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
+             << clientEnv->task_try_no() << ")\n";
+    }
+
+    if (args.size() < 2) {
+        std::stringstream ss;
+        ss << "LabelCmd: At least 2 arguments expected. Please specify: <label-name> <label-value>\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string labelName = args[0];
+    args.erase(args.begin()); // remove name from vector of strings
+    std::string labelValue;
+    for (size_t i = 0; i < args.size(); i++) {
+        if (i != 0)
+            labelValue += " ";
+        labelValue += args[i];
+    }
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("LabelCmd: " + errorMsg);
+    }
+
+    cmd = std::make_shared<LabelCmd>(clientEnv->task_path(),
+                                     clientEnv->jobs_password(),
+                                     clientEnv->process_or_remote_id(),
+                                     clientEnv->task_try_no(),
+                                     labelName,
+                                     labelValue);
+}
+
+std::ostream& operator<<(std::ostream& os, const LabelCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(LabelCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(LabelCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/LabelCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/LabelCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/LabelCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/LabelCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,61 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_LabelCmd_HPP
+#define ecflow_base_cts_task_LabelCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+
+class LabelCmd final : public TaskCmd {
+public:
+    LabelCmd(const std::string& pathToTask,
+             const std::string& jobsPassword,
+             const std::string& process_or_remote_id,
+             int try_no,
+             const std::string& name,
+             const std::string& label)
+        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+          name_(name),
+          label_(label) {}
+    LabelCmd() : TaskCmd() {}
+
+    const std::string& name() const { return name_; }
+    const std::string& label() const { return label_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::LABEL; }
+
+private:
+    std::string name_;  // the label name
+    std::string label_; // a single label, or multi-line label
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(name_), CEREAL_NVP(label_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const LabelCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(LabelCmd)
+
+#endif /* ecflow_base_cts_task_LabelCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/MeterCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/MeterCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/MeterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/MeterCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,159 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool MeterCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<MeterCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (name_ != the_rhs->name())
+        return false;
+    if (value_ != the_rhs->value())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+void MeterCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += "meter ";
+    os += name_;
+    os += " ";
+    os += ecf::convert_to<std::string>(value_);
+    os += " ";
+    os += path_to_node();
+}
+
+STC_Cmd_ptr MeterCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_meter_++;
+
+    { // Added scope for SuiteChanged1 changed: i.e update suite change numbers before job submission
+        // submittable_ setup during authentication
+        SuiteChanged1 changed(submittable_->suite());
+
+        /// Allow meter to set any valid value that is in range because:
+        ///   - When we have a network failure, and restoration. The meter tasks, will come in random, order.
+        ///   - When task is executed without a requee the meter value will less than maximum
+        ///
+        /// This has *IMPLICATION*, if the meter is used in a trigger, using a equality
+        /// operator, then the trigger will always hold.  hence suite designers need to
+        /// aware of this.
+        try {
+
+            Meter& the_meter = submittable_->find_meter(name_);
+            if (the_meter.empty()) {
+                LOG(Log::ERR,
+                    "MeterCmd::doHandleRequest: failed as meter '" << name_ << "' does not exist on task "
+                                                                   << path_to_node());
+                return PreAllocatedReply::ok_cmd();
+            }
+
+            /// Invalid meter values(out or range) will raise exceptions.
+            /// Just ignore the request rather than failing client cmd
+            the_meter.set_value(value_);
+        }
+        catch (std::exception& e) {
+            LOG(Log::ERR, "MeterCmd::doHandleRequest: failed for task " << path_to_node() << ". " << e.what());
+            return PreAllocatedReply::ok_cmd();
+        }
+    }
+
+    // Do job submission in case any triggers dependent on meters
+    as->increment_job_generation_count();
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* MeterCmd::arg() {
+    return TaskApi::meterArg();
+}
+const char* MeterCmd::desc() {
+    return "Change meter. For use in the '.ecf' script file *only*\n"
+           "Hence the context is supplied via environment variables\n"
+           "  arg1(string) = meter-name\n"
+           "  arg2(int)    = the new meter value\n\n"
+           "If this child command is a zombie, then the default action will be to *fob*,\n"
+           "i.e allow the ecflow client command to complete without an error\n"
+           "The default can be overridden by using zombie attributes.\n\n"
+           "Usage:\n"
+           "  ecflow_client --meter=my_meter 20";
+}
+
+void MeterCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(MeterCmd::arg(), po::value<vector<string>>()->multitoken(), MeterCmd::desc());
+}
+void MeterCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (clientEnv->debug()) {
+        dumpVecArgs(MeterCmd::arg(), args);
+        cout << "  MeterCmd::create " << MeterCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
+             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
+             << clientEnv->task_try_no() << ")\n";
+    }
+
+    if (args.size() != 2) {
+        std::stringstream ss;
+        ss << "MeterCmd: Two arguments expected, found " << args.size()
+           << " Please specify <meter-name> <meter-value>, ie --meter=name 100\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (args[0].empty()) {
+        throw std::runtime_error("MeterCmd: First argument must be a non-empty string, i.e. --meter=name 100\n");
+    }
+
+    int value = 0;
+    try {
+        std::string strVal = args[1];
+        value              = ecf::convert_to<int>(strVal);
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error("MeterCmd: Second argument must be a integer, i.e. --meter=name 100\n");
+    }
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("MeterCmd: " + errorMsg);
+    }
+
+    cmd = std::make_shared<MeterCmd>(clientEnv->task_path(),
+                                     clientEnv->jobs_password(),
+                                     clientEnv->process_or_remote_id(),
+                                     clientEnv->task_try_no(),
+                                     args[0],
+                                     value);
+}
+
+std::ostream& operator<<(std::ostream& os, const MeterCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(MeterCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(MeterCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/MeterCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/MeterCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/MeterCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/MeterCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,61 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_MeterCmd_HPP
+#define ecflow_base_cts_task_MeterCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+
+class MeterCmd final : public TaskCmd {
+public:
+    MeterCmd(const std::string& pathToTask,
+             const std::string& jobsPassword,
+             const std::string& process_or_remote_id,
+             int try_no,
+             const std::string& meterName,
+             int meterValue)
+        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+          name_(meterName),
+          value_(meterValue) {}
+    MeterCmd() : TaskCmd() {}
+
+    const std::string& name() const { return name_; }
+    int value() const { return value_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::METER; }
+
+private:
+    std::string name_; // the meters name
+    int value_{0};     // the meters value
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this), CEREAL_NVP(name_), CEREAL_NVP(value_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const MeterCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(MeterCmd)
+
+#endif /* ecflow_base_cts_task_MeterCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/QueueCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/QueueCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/QueueCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/QueueCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,292 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/QueueCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool QueueCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<QueueCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (name_ != the_rhs->name())
+        return false;
+    if (action_ != the_rhs->action())
+        return false;
+    if (step_ != the_rhs->step())
+        return false;
+    if (path_to_node_with_queue_ != the_rhs->path_to_node_with_queue())
+        return false;
+    return TaskCmd::equals(rhs);
+}
+
+void QueueCmd::print(std::string& os) const {
+    os += Str::CHILD_CMD();
+    os += TaskApi::queue_arg();
+    os += " ";
+    os += name_;
+    os += " ";
+    os += action_;
+    os += " ";
+    os += step_;
+    os += " ";
+    if (path_to_node_with_queue_.empty()) {
+        os += path_to_node();
+        return;
+    }
+
+    os += path_to_node_with_queue_;
+    os += " ";
+    os += path_to_node();
+}
+
+STC_Cmd_ptr QueueCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().task_queue_++;
+    std::string result;
+
+    //////////////////////////////////////////////////////////////////////////////
+    // Return the current string value, and then increment the index
+    //////////////////////////////////////////////////////////////////////////////
+    { // Added scope for SuiteChanged1 changed: i.e update suite change numbers before job submission
+        // submittable_ setup during authentication
+        SuiteChanged1 changed(submittable_->suite());
+
+        if (!path_to_node_with_queue_.empty()) {
+            Defs* defs = submittable_->defs();
+            if (defs) {
+                node_ptr node_with_queue = defs->findAbsNode(path_to_node_with_queue_);
+                if (node_with_queue) {
+
+                    QueueAttr& queue_attr = node_with_queue->findQueue(name_);
+                    if (queue_attr.empty()) {
+                        std::stringstream ss;
+                        ss << "QueueCmd:: Could not find queue of name " << name_ << ", on input node "
+                           << path_to_node_with_queue_;
+                        return PreAllocatedReply::error_cmd(ss.str());
+                    }
+
+                    result = handle_queue(queue_attr);
+                }
+                else {
+                    std::stringstream ss;
+                    ss << "QueueCmd:: Could not find node at path " << path_to_node_with_queue_;
+                    return PreAllocatedReply::error_cmd(ss.str());
+                }
+            }
+        }
+        else {
+            bool fnd_queue        = false;
+            QueueAttr& queue_attr = submittable_->findQueue(name_);
+            if (queue_attr.empty()) {
+                Node* parent = submittable_->parent();
+                while (parent) {
+                    QueueAttr& queue_attr1 = parent->findQueue(name_);
+                    if (!queue_attr1.empty()) {
+                        fnd_queue = true;
+                        result    = handle_queue(queue_attr1);
+                        break;
+                    }
+                    parent = parent->parent();
+                }
+            }
+            else {
+                fnd_queue = true;
+                result    = handle_queue(queue_attr);
+            }
+
+            if (!fnd_queue) {
+                std::stringstream ss;
+                ss << "QueueCmd:: Could not find queue " << name_ << " Up the node hierarchy";
+                return PreAllocatedReply::error_cmd(ss.str());
+            }
+        }
+    }
+
+    // Do job submission in case any triggers dependent on QueueAttr
+    as->increment_job_generation_count();
+
+    if (result.empty())
+        return PreAllocatedReply::ok_cmd();
+    return PreAllocatedReply::string_cmd(result);
+}
+
+std::string QueueCmd::handle_queue(QueueAttr& queue_attr) const {
+    if (queue_attr.empty()) {
+        std::stringstream ss;
+        ss << "QueueCmd:: Could not find queue of name " << name_ << " . Program error !";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (action_ == "active")
+        return queue_attr.active(); // return current index and value, make active, update index
+    if (action_ == "complete")
+        queue_attr.complete(step_);
+    if (action_ == "aborted")
+        queue_attr.aborted(step_);
+    if (action_ == "no_of_aborted")
+        return queue_attr.no_of_aborted();
+    if (action_ == "reset")
+        queue_attr.reset_index_to_first_queued_or_aborted();
+
+    return std::string();
+}
+
+const char* QueueCmd::arg() {
+    return TaskApi::queue_arg();
+}
+const char* QueueCmd::desc() {
+    return "QueueCmd. For use in the '.ecf' script file *only*\n"
+           "Hence the context is supplied via environment variables\n"
+           "  arg1(string) = queue-name:\n"
+           "  arg2(string) = action: [active | aborted | complete | no_of_aborted | reset ]\n"
+           "     active: returns the first queued/aborted step, the return string is the queue value from the "
+           "definition\n"
+           "     no_of_aborted: returns number of aborted steps as a string, i.e 10\n"
+           "     reset: sets the index to the first queued/aborted step. Allows steps to be reprocessed for errors\n"
+           "  arg3(string) = step: value returned from step=$(ecflow_client --queue=queue_name active)\n"
+           "                This is only valid for complete and aborted steps\n"
+           "  arg4(string) = path: (optional). The path where the queue is defined.\n"
+           "                 By default we search for the queue up the node tree.\n\n"
+           "If this child command is a zombie, then the default action will be to *block*,\n"
+           "The default can be overridden by using zombie attributes."
+           "If the path to the queue is not defined, then this command will\n"
+           "search for the queue up the node hierarchy. If no queue found, command fails\n\n"
+           "Usage:\n"
+           "step=\"\"\n"
+           "QNAME=\"my_queue_name\"\n"
+           "while [1 == 1 ] ; do\n"
+           "   # this return the first queued/aborted step, then increments to next step, return <NULL> when all steps "
+           "processed\n"
+           "   step=$(ecflow_client --queue=$QNAME active) # of the form string  i.e \"003\". this step is now active\n"
+           "   if [[ $step == \"<NULL>\" ]] ; then\n"
+           "        break;\n"
+           "   fi\n"
+           "   ...\n"
+           "   ecflow_client --queue=$QNAME complete $step   # tell ecflow this step completed\n"
+           "done\n"
+           "\n"
+           "trap() { ecflow_client --queue=$QNAME aborted $step # tell ecflow this step failed }\n";
+}
+
+void QueueCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(QueueCmd::arg(), po::value<vector<string>>()->multitoken(), QueueCmd::desc());
+}
+void QueueCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (clientEnv->debug()) {
+        dumpVecArgs(QueueCmd::arg(), args);
+        cout << "  QueueCmd::create " << QueueCmd::arg() << " task_path(" << clientEnv->task_path() << ") password("
+             << clientEnv->jobs_password() << ") remote_id(" << clientEnv->process_or_remote_id() << ") try_no("
+             << clientEnv->task_try_no() << ")\n";
+    }
+
+    // expect:
+    //   <queue-name> [active | aborted | complete | no_of_aborted | reset ] step <path to node with queue>
+    std::string queue_name, step;
+    std::string path_to_node_with_queue, action;
+    for (size_t i = 0; i < args.size(); i++) {
+        if (i == 0)
+            queue_name = args[i];
+        else {
+            if (args[i] == "active" || args[i] == "aborted" || args[i] == "complete" || args[i] == "no_of_aborted" ||
+                args[i] == "reset") {
+                action = args[i];
+            }
+            else if (args[i].find('/') != std::string::npos)
+                path_to_node_with_queue = args[i];
+            else
+                step = args[i];
+        }
+    }
+    if (clientEnv->debug()) {
+        cout << "  QueueCmd::create "
+             << "queue-name:(" << queue_name << ") action:(" << action << ") step:(" << step
+             << ") path_to_node_with_queue:(" << path_to_node_with_queue << ")\n";
+    }
+
+    if (args.size() == 4 && path_to_node_with_queue.empty()) {
+        std::stringstream ss;
+        ss << "QueueCmd: The fourth argument if specified must provide a path to a node where the queue resides.\n"
+           << "No path specified. " << args[3];
+        throw std::runtime_error(ss.str());
+    }
+
+    if (args.empty() || queue_name.empty() || action.empty()) {
+        std::stringstream ss;
+        ss << "QueueCmd: incorrect argument specified, expected at least two arguments but found " << args.size()
+           << " Please specify <queue-name> [active | aborted | complete | no_of_aborted | reset ] step <path to node "
+              "with queue>(optional) i.e\n"
+           << "--queue=name active  # active does not need a step\n"
+           << "--queue=name active /path/to/node/with/queue\n"
+           << "--queue=name aborted $step\n"
+           << "--queue=name complete $step\n"
+           << "--queue=name no_of_aborted\n"
+           << "--queue=name reset\n";
+        throw std::runtime_error(ss.str());
+    }
+    if ((action == "complete" || action == "aborted") && step.empty()) {
+        std::stringstream ss;
+        ss << "QueueCmd: when --queue=name complete || --queue=name aborted is used a step must be provided e.g.\n"
+           << "  ecflow_client --queue=name aborted $step\n"
+           << "  ecflow_client --queue=name complete $step\n"
+           << "where step is value returned from active, such as\n"
+           << "  step=$(ecflow_client --queue=name active)\n";
+        throw std::runtime_error(ss.str());
+    }
+    if ((action == "active" || action == "reset" || action == "no_of_aborted") && !step.empty()) {
+        throw std::runtime_error("QueueCmd: step should not be used with active, reset or no_of_aborted.");
+    }
+
+    string msg;
+    if (!Str::valid_name(queue_name, msg)) {
+        throw std::runtime_error("QueueCmd: Invalid queue name : " + msg);
+    }
+
+    std::string errorMsg;
+    if (!clientEnv->checkTaskPathAndPassword(errorMsg)) {
+        throw std::runtime_error("QueueCmd: " + errorMsg);
+    }
+
+    cmd = std::make_shared<QueueCmd>(clientEnv->task_path(),
+                                     clientEnv->jobs_password(),
+                                     clientEnv->process_or_remote_id(),
+                                     clientEnv->task_try_no(),
+                                     queue_name,
+                                     action,
+                                     step,
+                                     path_to_node_with_queue);
+}
+
+std::ostream& operator<<(std::ostream& os, const QueueCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(QueueCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(QueueCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/QueueCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/QueueCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/QueueCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/QueueCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,75 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_QueueCmd_HPP
+#define ecflow_base_cts_task_QueueCmd_HPP
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+
+class QueueAttr;
+
+class QueueCmd final : public TaskCmd {
+public:
+    QueueCmd(const std::string& pathToTask,
+             const std::string& jobsPassword,
+             const std::string& process_or_remote_id,
+             int try_no,
+             const std::string& queueName,
+             const std::string& action,
+             const std::string& step                    = "",
+             const std::string& path_to_node_with_queue = "") // if empty search for queue up node tree
+        : TaskCmd(pathToTask, jobsPassword, process_or_remote_id, try_no),
+          name_(queueName),
+          action_(action),
+          step_(step),
+          path_to_node_with_queue_(path_to_node_with_queue) {}
+    QueueCmd() : TaskCmd() {}
+
+    const std::string& name() const { return name_; }
+    const std::string& action() const { return action_; }
+    const std::string& step() const { return step_; }
+    const std::string& path_to_node_with_queue() const { return path_to_node_with_queue_; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    ecf::Child::CmdType child_type() const override { return ecf::Child::QUEUE; }
+
+    std::string handle_queue(QueueAttr& queue_attr) const;
+
+private:
+    std::string name_;   // the queue name
+    std::string action_; // [ active | aborted | complete | no_of_aborted ]
+    std::string step_;   // will be empty when action is [ active | no_of_aborted]
+    std::string path_to_node_with_queue_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<TaskCmd>(this),
+           CEREAL_NVP(name_),
+           CEREAL_NVP(action_),
+           CEREAL_NVP(step_),
+           CEREAL_NVP(path_to_node_with_queue_));
+    }
+};
+
+CEREAL_FORCE_DYNAMIC_INIT(QueueCmd)
+
+#endif /* ecflow_base_cts_task_QueueCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskApi.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskApi.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskApi.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskApi.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,108 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/TaskApi.hpp"
+
+std::string TaskApi::init(const std::string& process_id) {
+    std::string ret = "--init=";
+    ret += process_id;
+    return ret;
+}
+const char* TaskApi::initArg() {
+    return "init";
+}
+
+std::string TaskApi::abort(const std::string& reason) {
+    if (reason.empty())
+        return "--abort";
+    std::string ret = "--abort=";
+    ret += reason;
+    return ret;
+}
+const char* TaskApi::abortArg() {
+    return "abort";
+}
+
+std::vector<std::string> TaskApi::event(const std::string& eventName, const std::string& value) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+    std::string ret = "--event=";
+    ret += eventName;
+    retVec.push_back(ret);
+    retVec.push_back(value);
+    return retVec;
+}
+const char* TaskApi::eventArg() {
+    return "event";
+}
+
+std::vector<std::string> TaskApi::meter(const std::string& meterName, const std::string& new_meter_value) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+    std::string ret = "--meter=";
+    ret += meterName;
+    retVec.push_back(ret);
+    retVec.push_back(new_meter_value);
+    return retVec;
+}
+const char* TaskApi::meterArg() {
+    return "meter";
+}
+
+std::vector<std::string> TaskApi::queue(const std::string& queueName,
+                                        const std::string& action,
+                                        const std::string& step,
+                                        const std::string& path_to_node_with_queue) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+    std::string ret = "--queue=";
+    ret += queueName;
+    retVec.push_back(ret);
+    retVec.push_back(action);
+    if (!step.empty())
+        retVec.push_back(step);
+    if (!path_to_node_with_queue.empty())
+        retVec.push_back(path_to_node_with_queue);
+    return retVec;
+}
+const char* TaskApi::queue_arg() {
+    return "queue";
+}
+
+std::vector<std::string> TaskApi::label(const std::string& label_name, const std::vector<std::string>& labels) {
+    std::vector<std::string> retVec;
+    retVec.reserve(labels.size() + 1);
+    std::string ret = "--label=";
+    ret += label_name;
+    retVec.push_back(ret);
+    for (const auto& label : labels) {
+        retVec.push_back(label);
+    }
+    return retVec;
+}
+const char* TaskApi::labelArg() {
+    return "label";
+}
+
+std::string TaskApi::complete() {
+    return "--complete";
+}
+const char* TaskApi::completeArg() {
+    return "complete";
+}
+
+std::string TaskApi::wait(const std::string& expression) {
+    std::string ret = "--wait=";
+    ret += expression;
+    return ret;
+}
+const char* TaskApi::waitArg() {
+    return "wait";
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskApi.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskApi.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskApi.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskApi.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,51 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_TaskApi_HPP
+#define ecflow_base_cts_task_TaskApi_HPP
+
+#include <string>
+#include <vector>
+
+///
+/// \brief Task API, i.e the child commands, typically called from the jobs files
+/// The two variant api must correspond i.e '--get' and 'get' since this is used by boost program options
+///
+
+class TaskApi {
+public:
+    TaskApi(const TaskApi&)                  = delete;
+    const TaskApi& operator=(const TaskApi&) = delete;
+
+    /// Used to construct arguments, for argc,argv
+    static std::string init(const std::string& process_id);
+    static std::string abort(const std::string& reason = "");
+    static std::vector<std::string> event(const std::string& eventName, const std::string& value = "set");
+    static std::vector<std::string> meter(const std::string& meterName, const std::string& metervalue);
+    static std::vector<std::string> queue(const std::string& queueName,
+                                          const std::string& action,
+                                          const std::string& step,
+                                          const std::string& path_to_node_with_queue);
+    static std::vector<std::string> label(const std::string& label_name, const std::vector<std::string>& labels);
+    static std::string complete();
+    static std::string wait(const std::string& expression);
+
+    // Only to be used in Cmd
+    static const char* initArg();
+    static const char* abortArg();
+    static const char* eventArg();
+    static const char* meterArg();
+    static const char* queue_arg();
+    static const char* labelArg();
+    static const char* completeArg();
+    static const char* waitArg();
+};
+
+#endif /* ecflow_base_cts_task_TaskApi_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,330 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/task/TaskCmd.hpp"
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+// #define DEBUG_ZOMBIE 1
+
+////////////////////////////////////////////////////////////////////////////////////////////////
+bool TaskCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<TaskCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (path_to_submittable_ != the_rhs->path_to_node())
+        return false;
+    if (jobs_password_ != the_rhs->jobs_password())
+        return false;
+    if (process_or_remote_id_ != the_rhs->process_or_remote_id())
+        return false;
+    if (try_no_ != the_rhs->try_no())
+        return false;
+    return ClientToServerCmd::equals(rhs);
+}
+
+// **********************************************************************************
+// IMPORTANT: In the current SMS/ECF only the init child command, passes the
+// process_or_remote_id_, for *ALL* other child commands this is empty.
+// The Automated tests get round this via setting ECF_RID in the header/tail job includes
+// However since this may not be in .sms/.ecf files, we cannot rely on it
+// Hence we need to be able to handle *EMPTY* process_or_remote_id_ for child commands
+//
+//  Task State | Child                      | Log | Explanation
+//  -------------------------------------------------------------------------------------------------------------
+//  SUBMITTED  | child!=INIT                | ERR | Script has child command in back ground, Bug in script, out of order
+//  ACTIVE     | INIT & pid & passwd match  | WAR | two init commands, overloaded server, or 2*init in script, *FOB*.
+//  Forgive ACTIVE     | INIT & pid & passwd !match | ERR | two init commands, Task started again by user. COMPLETE   |
+//  COMPLETE                   | WAR | two complete, zombie, overloaded server. *FOB*, Allow job to complete. Forgive.
+//  COMPLETE   | child != COMPLETE          | ERR | zombie
+//  ABORTED    | ABORTED                    | WAR | two aborted, zombie, overloaded server. *FOB*, allow process to
+//  exit. Forgive ABORTED    | child != ABORTED           | WAR | zombie
+//  -------------------------------------------------------------------------------------------------------------------
+//
+//  zombie type    |   PID   | password | explanation
+//  ---------------------------------------------------------------------------------------------------------------
+//  ECF_PID        |    X    | matches  | PID miss-match, but password matches. Job scheduled twice. Check submitter
+//  ECF_PID_PASSWD |    X    |     X    | Both PID and password miss-match. Re-queue & submit of active job
+//  ECF_PASSWD     | matches |     X    | Password miss-match, PID matches, system has re-cycled PID or hacked job file?
+//  ECF            | matches | matches  | overloaded server,Two init commands or task complete or aborted but receives
+//  another child cmd USER           |    ?    |     ?    | User initiated zombie whilst task was active or submitted,
+//  command is recorded in zombie PATH           |   n/a   |    n/a   | Task not found. Nodes replaced whilst jobs were
+//  running
+//  ----------------------------------------------------------------------------------------------------------------
+bool TaskCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& theReply) const {
+#ifdef DEBUG_ZOMBIE
+    std::cout << "   TaskCmd::authenticate " << Child::to_string(child_type());
+    std::cout << " " << path_to_submittable_ << " " << process_or_remote_id_ << " " << jobs_password_ << " " << try_no_;
+    const Zombie& zombie = as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
+    if (!zombie.empty())
+        std::cout << "  " << zombie;
+    else {
+        const Zombie& zombiep = as->zombie_ctrl().find_by_path_only(path_to_submittable_);
+        if (!zombiep.empty())
+            std::cout << "  find_by_path_only: " << zombiep;
+    }
+#endif
+    /// ***************************************************************************
+    /// Task based cmd have their own authentication mechanism, hence we
+    /// Don't need to call the base class authenticate
+    /// **************************************************************************
+
+    if (!as->allowTaskCommunication()) {
+        // This is not an Error, hence we don't throw exception
+        theReply = PreAllocatedReply::block_client_server_halted_cmd();
+        return false;
+    }
+
+    submittable_ = get_submittable(as);
+    if (!submittable_) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << ": PATH Zombie\n";
+#endif
+        // Create path zombie, if not already created:
+        std::string action_taken;
+        static_cast<void>(as->zombie_ctrl().handle_path_zombie(as, this, action_taken, theReply));
+
+        // distinguish output by using *path*
+        std::stringstream ss;
+        ss << " zombie(*path*) : chd:" << ecf::Child::to_string(child_type()) << " : " << path_to_submittable_ << " : "
+           << process_or_remote_id_ << " : " << jobs_password_ << " : action(" << action_taken << ")";
+        log(Log::ERR, ss.str());
+        return false;
+    }
+
+    // If the CMD *WAS* created with Submittable::DUMMY_JOBS_PASSWORD then we were testing
+    // This will be copied from client to server, hence we want to avoid same check in the
+    // server. when handleRequest is called()
+    // DO NOT place #ifdef DEBUG otherwise test will start failing for the release build
+    if (jobs_password_ == Submittable::DUMMY_JOBS_PASSWORD()) {
+        return true;
+    }
+
+    SuiteChanged1 changed(submittable_->suite());
+
+    /// Check if User wants to explicitly bypass password checking
+    /// This can be done via AlterCmd by adding a variable on the task,  ECF_PASS with value
+    /// Submittable::FREE_JOBS_PASSWORD Note: this *does not* look for the variable up the node tree, only on the task.
+    std::string ecf_pass_value;
+    if (submittable_->findVariableValue(Str::ECF_PASS(), ecf_pass_value)) {
+
+        if (ecf_pass_value == Submittable::FREE_JOBS_PASSWORD()) {
+            submittable_->flag().clear(ecf::Flag::ZOMBIE);
+            return true;
+        }
+    }
+
+    /// Handle corner case ,where we have two jobs with different process id, but same password
+    /// Can happen if jobs is started externally,
+    /// or via test(i.e submit 1,submit 2(force)) before job1 active its password is overridden
+    bool submittable_allready_aborted  = false;
+    bool submittable_allready_active   = false;
+    bool submittable_allready_complete = false;
+    password_missmatch_                = false;
+    pid_missmatch_                     = false;
+
+    /// *** In complete state, the password is empty.
+    if (submittable_->jobsPassword() != jobs_password_) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << ": submittable pass(" << submittable_->jobsPassword() << ") != jobs_password_(" << jobs_password_
+                  << ")";
+#endif
+        password_missmatch_ = true;
+    }
+
+    /// When state is in SUBMITTED, its process/remote_id is EMPTY. It will be set by the INIT child command.
+    /// Hence we can *NOT* mark it as pid_missmatch.
+    ///
+    /// *** See Note above: Not all child commands pass a process_id. ***
+    /// *** Hence this test for zombies is ONLY valid if process sets the process_or_remote_id_ ****
+    /// *** User should really set ECF_RID in the scripts
+    /// *** In submitted state, the pid is empty. hence clear pid_missmatch_ below
+    /// *** In complete state, the pid is empty.  hence clear pid_missmatch_ below
+    if (!submittable_->process_or_remote_id().empty() && !process_or_remote_id_.empty() &&
+        submittable_->process_or_remote_id() != process_or_remote_id_) {
+#ifdef DEBUG_ZOMBIE
+        std::cout << ":task pid(" << submittable_->process_or_remote_id() << ") != process pid("
+                  << process_or_remote_id_ << ")";
+#endif
+        pid_missmatch_ = true;
+    }
+
+    switch (submittable_->state()) {
+        case NState::SUBMITTED: {
+            // The pid on the task will be empty
+            if (child_type() != Child::INIT) {
+                std::stringstream ss;
+                ss << path_to_submittable_
+                   << " When a node is submitted, expected next child command to be INIT but received "
+                   << Child::to_string(child_type());
+                log(Log::ERR, ss.str());
+            }
+            break;
+        }
+
+        case NState::ACTIVE: {
+            if (child_type() == Child::INIT) {
+#ifdef DEBUG_ZOMBIE
+                std::cout << ":(child_type() == Child::INIT) && submittable_->state() == NState::ACTIVE)";
+#endif
+                // *IF* password and pid matches be more forgiving. How can this case arise:
+                // i.e server is heavily overloaded, client calls init, which times out because server is busy
+                // Client then sends init again. In this case rather than treating it as a zombie, we will let it
+                // through providing the password and pid matches.
+                if (!password_missmatch_ && !pid_missmatch_) {
+                    string ret = " [ overloaded || --init*2 ](pid and passwd match) : chd:";
+                    ret += ecf::Child::to_string(child_type());
+                    ret += " : ";
+                    ret += path_to_submittable_;
+                    ret += " : already active : action(fob)";
+                    log(Log::WAR, ret);
+                    theReply = PreAllocatedReply::ok_cmd();
+                    return false;
+                }
+                submittable_allready_active = true;
+            }
+            break;
+        }
+
+        case NState::COMPLETE: {
+#ifdef DEBUG_ZOMBIE
+            std::cout << ": submittable_->state() == NState::COMPLETE)";
+#endif
+            if (child_type() == Child::COMPLETE) {
+                // Note: when a node completes, we clear tasks password and pid, to save memory on checkpt & network
+                // bandwidth (We could choose not to clear, This would allow us to disambiguate between 2/ and 3/
+                // below). HOWEVER:
+                //
+                // How can this situation arise:
+                //   1/ Two calls to --complete  (rare)
+                //   2/ Overloaded server. Client send --complete to server, but it is overload and does not respond,
+                //   the client then
+                //      times out. Server handles the request. When client tries again we get here. (possible)
+                //   3/ Zombie, two separate process. (possible, typically done by user action)
+                //
+                // For all three it should be safe to just fob:
+                //   1/ Two calls to --complete # Be forgiving
+                //   2/ Overloaded server       # The correct course of action
+                //   3/ zombie                  # The zombie has completed anyway, don't bother blocking it
+
+                submittable_->flag().clear(ecf::Flag::ZOMBIE);
+                as->zombie_ctrl().remove_by_path(path_to_submittable_);
+
+                string ret = " [ overloaded || zombie || --complete*2 ] : chd:";
+                ret += ecf::Child::to_string(child_type());
+                ret += " : ";
+                ret += path_to_submittable_;
+                ret += " : already complete : action(fob)";
+                log(Log::WAR, ret);
+                theReply = PreAllocatedReply::ok_cmd();
+                return false;
+            }
+
+            // If Task state is complete, and we receive **any** child command then it is a zombie
+            submittable_allready_complete = true;
+            password_missmatch_           = false;
+            pid_missmatch_                = false;
+            break;
+        }
+
+        case NState::ABORTED: {
+#ifdef DEBUG_ZOMBIE
+            std::cout << ": submittable_->state() == NState::ABORTED)";
+#endif
+
+            if (child_type() == Child::ABORT) {
+
+                if (!password_missmatch_ && !pid_missmatch_) {
+
+                    as->zombie_ctrl().remove(submittable_);
+
+                    string ret = " [ overloaded || --abort*2 ] (pid and passwd match) : chd:";
+                    ret += ecf::Child::to_string(child_type());
+                    ret += " : ";
+                    ret += path_to_submittable_;
+                    ret += " : already aborted : action(fob)";
+                    log(Log::WAR, ret);
+                    theReply = PreAllocatedReply::ok_cmd();
+                    return false;
+                }
+            }
+
+            // If Task state is aborted, and we receive **any** child command then it is a zombie
+            submittable_allready_aborted = true;
+            password_missmatch_          = false;
+            pid_missmatch_               = false;
+            break;
+        }
+        case NState::QUEUED:
+            break; // WTF
+        case NState::UNKNOWN:
+            break; // WTF
+    }
+
+#ifdef DEBUG_ZOMBIE
+    std::cout << "\n";
+#endif
+
+    if (password_missmatch_ || pid_missmatch_ || submittable_allready_active || submittable_allready_complete ||
+        submittable_allready_aborted) {
+        /// If the task has adopted we return true, and carry on as normal
+        std::string action_taken;
+        if (!as->zombie_ctrl().handle_zombie(submittable_, this, action_taken, theReply)) {
+
+            // LOG failure: Include type of zombie.
+            // ** NOTE **: the zombie may have been removed by user actions. i.e if fob and child cmd is abort |
+            // complete, etc
+            std::stringstream ss;
+            ss << " zombie";
+            const Zombie& theZombie =
+                as->zombie_ctrl().find(path_to_submittable_, process_or_remote_id_, jobs_password_);
+            if (!theZombie.empty())
+                ss << "(" << theZombie.type_str() << ")";
+
+            ss << " : chd:" << ecf::Child::to_string(child_type());
+            ss << " : " << path_to_submittable_ << "(" << NState::toString(submittable_->state()) << ")";
+            ss << " : " << process_or_remote_id_ << " : " << jobs_password_;
+            if (submittable_allready_active)
+                ss << " : already active";
+            if (submittable_allready_complete)
+                ss << " : already complete";
+            if (submittable_allready_aborted)
+                ss << " : already aborted";
+            if (password_missmatch_)
+                ss << " : passwd != [ task:" << submittable_->jobsPassword() << " child:" << jobs_password_ << " ]";
+            if (pid_missmatch_)
+                ss << " : pid != [ task:" << submittable_->process_or_remote_id() << " child:" << process_or_remote_id_
+                   << " ]";
+            ss << " : action(" << action_taken << ")";
+            log(Log::ERR, ss.str());
+            return false;
+        }
+    }
+    return true;
+}
+
+Submittable* TaskCmd::get_submittable(AbstractServer* as) const {
+    node_ptr node = as->defs()->findAbsNode(path_to_submittable_);
+    if (!node.get()) {
+        return nullptr;
+    }
+
+    return node->isSubmittable();
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/task/TaskCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/task/TaskCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,90 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_task_TaskCmd_HPP
+#define ecflow_base_cts_task_TaskCmd_HPP
+
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/Child.hpp"
+
+//=================================================================================
+// Task Command
+// ================================================================================
+class TaskCmd : public ClientToServerCmd {
+protected:
+    TaskCmd(const std::string& pathToSubmittable,
+            const std::string& jobsPassword,
+            const std::string& process_or_remote_id,
+            int try_no)
+        : submittable_(nullptr),
+          path_to_submittable_(pathToSubmittable),
+          jobs_password_(jobsPassword),
+          process_or_remote_id_(process_or_remote_id),
+          try_no_(try_no) {
+        assert(!hostname().empty());
+    }
+
+    TaskCmd() = default;
+
+public:
+    bool isWrite() const override { return true; }
+    int timeout() const override { return 190; } // ECFLOW-157 80 -> 190
+
+    const std::string& path_to_node() const { return path_to_submittable_; }
+    const std::string& jobs_password() const { return jobs_password_; }
+    const std::string& process_or_remote_id() const { return process_or_remote_id_; }
+    int try_no() const { return try_no_; }
+    virtual ecf::Child::CmdType child_type() const = 0;
+
+    bool equals(ClientToServerCmd*) const override;
+    bool task_cmd() const override { return true; }
+    bool connect_to_different_servers() const override { return true; }
+
+    bool password_missmatch() const { return password_missmatch_; }
+    bool pid_missmatch() const { return pid_missmatch_; }
+
+protected:
+    /// Overridden to do nothing since Task based commands don't need _user_ based authentication
+    void setup_user_authentification(const std::string& /*user*/, const std::string& /*passwd*/) override {}
+    bool setup_user_authentification(AbstractClientEnv&) override { return true; }
+    void setup_user_authentification() override {}
+
+    bool authenticate(AbstractServer*,
+                      STC_Cmd_ptr&) const override; /// Task have their own mechanism,can throw std::runtime_error
+    Submittable* get_submittable(AbstractServer* as) const; // can throw std::runtime_error
+
+protected:
+    mutable Submittable* submittable_{
+        nullptr}; // stored during authentication and re-used handle request, not persisted, server side only
+
+private:
+    std::string path_to_submittable_;
+    std::string jobs_password_;
+    std::string process_or_remote_id_;
+    int try_no_{0};
+
+private:
+    mutable bool password_missmatch_{
+        false}; // stored during authentication and re-used handle request, not persisted, server side only
+    mutable bool pid_missmatch_{
+        false}; // stored during authentication and re-used handle request, not persisted, server side only
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<ClientToServerCmd>(this),
+           CEREAL_NVP(path_to_submittable_),
+           CEREAL_NVP(jobs_password_),
+           CEREAL_NVP(process_or_remote_id_),
+           CEREAL_NVP(try_no_));
+    }
+};
+
+#endif /* ecflow_base_cts_task_TaskCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/AlterCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/AlterCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/AlterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/AlterCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1797 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Enumerate.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Message.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/exceptions/Exceptions.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/parser/AvisoParser.hpp"
+#include "ecflow/node/parser/MirrorParser.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+static std::string dump_args(const std::vector<std::string>& options, const std::vector<std::string>& paths) {
+    std::string the_args;
+    for (const auto& option : options) {
+        the_args += option;
+        the_args += " ";
+    }
+    for (const auto& path : paths) {
+        the_args += path;
+        the_args += " ";
+    }
+    return the_args;
+}
+
+namespace ecf::detail {
+
+template <>
+struct EnumTraits<AlterCmd::Delete_attr_type>
+{
+    using underlying_t = std::underlying_type_t<AlterCmd::Delete_attr_type>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(AlterCmd::DEL_VARIABLE, "variable"),
+        std::make_pair(AlterCmd::DEL_TIME, "time"),
+        std::make_pair(AlterCmd::DEL_TODAY, "today"),
+        std::make_pair(AlterCmd::DEL_DATE, "date"),
+        std::make_pair(AlterCmd::DEL_DAY, "day"),
+        std::make_pair(AlterCmd::DEL_CRON, "cron"),
+        std::make_pair(AlterCmd::DEL_EVENT, "event"),
+        std::make_pair(AlterCmd::DEL_METER, "meter"),
+        std::make_pair(AlterCmd::DEL_LABEL, "label"),
+        std::make_pair(AlterCmd::DEL_TRIGGER, "trigger"),
+        std::make_pair(AlterCmd::DEL_COMPLETE, "complete"),
+        std::make_pair(AlterCmd::DEL_REPEAT, "repeat"),
+        std::make_pair(AlterCmd::DEL_LIMIT, "limit"),
+        std::make_pair(AlterCmd::DEL_LIMIT_PATH, "limit_path"),
+        std::make_pair(AlterCmd::DEL_INLIMIT, "inlimit"),
+        std::make_pair(AlterCmd::DEL_ZOMBIE, "zombie"),
+        std::make_pair(AlterCmd::DEL_LATE, "late"),
+        std::make_pair(AlterCmd::DEL_QUEUE, "queue"),
+        std::make_pair(AlterCmd::DEL_GENERIC, "generic"),
+        std::make_pair(AlterCmd::DEL_AVISO, "aviso"),
+        std::make_pair(AlterCmd::DEL_MIRROR, "mirror")
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<AlterCmd::Delete_attr_type>::size == map.back().first);
+};
+
+template <>
+struct EnumTraits<AlterCmd::Add_attr_type>
+{
+    using underlying_t = std::underlying_type_t<AlterCmd::Add_attr_type>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(AlterCmd::ADD_TIME, "time"),
+        std::make_pair(AlterCmd::ADD_TODAY, "today"),
+        std::make_pair(AlterCmd::ADD_DATE, "date"),
+        std::make_pair(AlterCmd::ADD_DAY, "day"),
+        std::make_pair(AlterCmd::ADD_ZOMBIE, "zombie"),
+        std::make_pair(AlterCmd::ADD_VARIABLE, "variable"),
+        std::make_pair(AlterCmd::ADD_LATE, "late"),
+        std::make_pair(AlterCmd::ADD_LIMIT, "limit"),
+        std::make_pair(AlterCmd::ADD_INLIMIT, "inlimit"),
+        std::make_pair(AlterCmd::ADD_LABEL, "label"),
+        std::make_pair(AlterCmd::ADD_AVISO, "aviso"),
+        std::make_pair(AlterCmd::ADD_MIRROR, "mirror")
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<AlterCmd::Add_attr_type>::size == map.back().first);
+};
+
+template <>
+struct EnumTraits<AlterCmd::Change_attr_type>
+{
+    using underlying_t = std::underlying_type_t<AlterCmd::Change_attr_type>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(AlterCmd::VARIABLE, "variable"),
+        std::make_pair(AlterCmd::CLOCK_TYPE, "clock_type"),
+        std::make_pair(AlterCmd::CLOCK_DATE, "clock_date"),
+        std::make_pair(AlterCmd::CLOCK_GAIN, "clock_gain"),
+        std::make_pair(AlterCmd::CLOCK_SYNC, "clock_sync"),
+        std::make_pair(AlterCmd::EVENT, "event"),
+        std::make_pair(AlterCmd::METER, "meter"),
+        std::make_pair(AlterCmd::LABEL, "label"),
+        std::make_pair(AlterCmd::TRIGGER, "trigger"),
+        std::make_pair(AlterCmd::COMPLETE, "complete"),
+        std::make_pair(AlterCmd::REPEAT, "repeat"),
+        std::make_pair(AlterCmd::LIMIT_MAX, "limit_max"),
+        std::make_pair(AlterCmd::LIMIT_VAL, "limit_value"),
+        std::make_pair(AlterCmd::DEFSTATUS, "defstatus"),
+        std::make_pair(AlterCmd::LATE, "late"),
+        std::make_pair(AlterCmd::TIME, "time"),
+        std::make_pair(AlterCmd::TODAY, "today"),
+        std::make_pair(AlterCmd::AVISO, "aviso"),
+        std::make_pair(AlterCmd::MIRROR, "mirror")
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<AlterCmd::Change_attr_type>::size == map.back().first);
+};
+
+} // namespace ecf::detail
+
+static AlterCmd::Delete_attr_type deleteAttrType(const std::string& s) {
+    if (auto found = ecf::Enumerate<AlterCmd::Delete_attr_type>::to_enum(s); found) {
+        return found.value();
+    }
+    return AlterCmd::DELETE_ATTR_ND;
+}
+
+static std::string to_string(AlterCmd::Delete_attr_type d) {
+    if (auto found = ecf::Enumerate<AlterCmd::Delete_attr_type>::to_string(d); found) {
+        return std::string{found.value()};
+    }
+    return {};
+}
+
+static void validDeleteAttr(std::vector<std::string>& vec) {
+    vec = ecf::Enumerate<AlterCmd::Delete_attr_type>::designations();
+}
+
+static AlterCmd::Add_attr_type addAttrType(const std::string& s) {
+    if (auto found = ecf::Enumerate<AlterCmd::Add_attr_type>::to_enum(s); found) {
+        return found.value();
+    }
+    return AlterCmd::ADD_ATTR_ND;
+}
+
+static std::string to_string(AlterCmd::Add_attr_type a) {
+    if (auto found = ecf::Enumerate<AlterCmd::Add_attr_type>::to_string(a); found) {
+        return std::string{found.value()};
+    }
+    return {};
+}
+
+static void validAddAttr(std::vector<std::string>& vec) {
+    vec = Enumerate<AlterCmd::Add_attr_type>::designations();
+}
+
+static AlterCmd::Change_attr_type changeAttrType(const std::string& s) {
+    if (auto found = Enumerate<AlterCmd::Change_attr_type>::to_enum(s); found) {
+        return found.value();
+    }
+    return AlterCmd::CHANGE_ATTR_ND;
+}
+
+static std::string to_string(AlterCmd::Change_attr_type c) {
+    if (auto found = Enumerate<AlterCmd::Change_attr_type>::to_string(c); found) {
+        return std::string{found.value()};
+    }
+    return {};
+}
+
+static void validChangeAttr(std::vector<std::string>& vec) {
+    vec = ecf::Enumerate<AlterCmd::Change_attr_type>::designations();
+}
+
+//=======================================================================================
+
+bool AlterCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<AlterCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (paths_ != the_rhs->paths()) {
+        return false;
+    }
+    if (name_ != the_rhs->name()) {
+        return false;
+    }
+    if (value_ != the_rhs->value()) {
+        return false;
+    }
+    if (del_attr_type_ != the_rhs->delete_attr_type()) {
+        return false;
+    }
+    if (change_attr_type_ != the_rhs->change_attr_type()) {
+        return false;
+    }
+    if (add_attr_type_ != the_rhs->add_attr_type()) {
+        return false;
+    }
+    if (flag_type_ != the_rhs->flag_type()) {
+        return false;
+    }
+    if (flag_ != the_rhs->flag()) {
+        return false;
+    }
+    return UserCmd::equals(rhs);
+}
+
+void AlterCmd::alter_and_attr_type(std::string& alter_type, std::string& attr_type) const {
+    if (del_attr_type_ != AlterCmd::DELETE_ATTR_ND) {
+        alter_type = "delete";
+        attr_type  = to_string(del_attr_type_);
+    }
+    else if (change_attr_type_ != AlterCmd::CHANGE_ATTR_ND) {
+        alter_type = "change";
+        attr_type  = to_string(change_attr_type_);
+    }
+    else if (add_attr_type_ != AlterCmd::ADD_ATTR_ND) {
+        alter_type = "add";
+        attr_type  = to_string(add_attr_type_);
+    }
+    else if (flag_type_ != ecf::Flag::NOT_SET) {
+        if (flag_)
+            alter_type = "set_flag";
+        else
+            alter_type = "clear_flag";
+        attr_type = ecf::Flag::enum_to_string(flag_type_);
+    }
+    else {
+        alter_type = "sort";
+    }
+}
+
+void AlterCmd::print_only(std::string& os) const {
+    std::string alter_type, attr_type;
+    alter_and_attr_type(alter_type, attr_type);
+    if (paths_.empty())
+        os += CtsApi::to_string(CtsApi::alter(std::vector<std::string>(1, " "), alter_type, attr_type, name_, value_));
+    else
+        os += CtsApi::to_string(
+            CtsApi::alter(std::vector<std::string>(1, paths_[0]), alter_type, attr_type, name_, value_));
+}
+
+void AlterCmd::print(std::string& os) const {
+    std::string alter_type, attr_type;
+    alter_and_attr_type(alter_type, attr_type);
+    user_cmd(os, CtsApi::to_string(CtsApi::alter(paths_, alter_type, attr_type, name_, value_)));
+}
+
+void AlterCmd::print(std::string& os, const std::string& path) const {
+    std::string alter_type, attr_type;
+    alter_and_attr_type(alter_type, attr_type);
+    user_cmd(os,
+             CtsApi::to_string(CtsApi::alter(std::vector<std::string>(1, path), alter_type, attr_type, name_, value_)));
+}
+
+STC_Cmd_ptr AlterCmd::alter_server_state(AbstractServer* as) const {
+    Defs* defs = as->defs().get();
+
+    if (del_attr_type_ == AlterCmd::DEL_VARIABLE) {
+        defs->set_server().delete_user_variable(name_);
+    }
+    else if (change_attr_type_ == AlterCmd::VARIABLE || add_attr_type_ == AlterCmd::ADD_VARIABLE) {
+
+        // ECFLOW-380: Some variable should be read only
+        if (name_ == Str::ECF_HOST() || name_ == Str::ECF_PORT() || name_ == "ECF_PID" || name_ == "ECF_VERSION" ||
+            name_ == "ECF_LISTS") {
+            std::stringstream ss;
+            ss << "AlterCmd:: Cannot add or change read only server variable " << name_;
+            throw std::runtime_error(ss.str());
+        }
+        defs->set_server().add_or_update_user_variables(name_, value_);
+    }
+
+    // Update defs flag state
+    if (flag_type_ != Flag::NOT_SET) {
+        if (flag_)
+            defs->flag().set(flag_type_);
+        else {
+            defs->flag().clear(flag_type_);
+            if (flag_type_ == Flag::LOG_ERROR)
+                defs->set_server().delete_user_variable("ECF_LOG_ERROR");
+            if (flag_type_ == Flag::CHECKPT_ERROR)
+                defs->set_server().delete_user_variable("ECF_CHECKPT_ERROR");
+        }
+    }
+
+    // sort
+    ecf::Attr::Type attr = Attr::to_attr(name_);
+    if (attr != ecf::Attr::UNKNOWN) {
+        bool recursive = (value_ == "recursive") ? true : false;
+        defs->sort_attributes(attr, recursive);
+    }
+
+    return doJobSubmission(as);
+}
+
+STC_Cmd_ptr AlterCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().alter_cmd_++;
+    Defs* defs = as->defs().get();
+
+    std::stringstream ss;
+    size_t vec_size = paths_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+
+        /// For root node user means to change server state
+        if (paths_[i] == "/") {
+            return alter_server_state(as);
+        }
+
+        node_ptr node = find_node_for_edit_no_throw(defs, paths_[i]);
+        if (!node.get()) {
+            ss << "AlterCmd: Could not find node at path " << paths_[i] << "\n";
+            LOG(Log::ERR, "AlterCmd: Failed: Could not find node at path " << paths_[i]);
+            continue;
+        }
+
+        SuiteChangedPtr changed(node.get());
+        try {
+            switch (del_attr_type_) {
+                case AlterCmd::DEL_VARIABLE:
+                    node->deleteVariable(name_);
+                    break;
+                case AlterCmd::DEL_TIME:
+                    node->deleteTime(name_);
+                    break;
+                case AlterCmd::DEL_TODAY:
+                    node->deleteToday(name_);
+                    break;
+                case AlterCmd::DEL_DATE:
+                    node->deleteDate(name_);
+                    break;
+                case AlterCmd::DEL_DAY:
+                    node->deleteDay(name_);
+                    break;
+                case AlterCmd::DEL_CRON:
+                    node->deleteCron(name_);
+                    break;
+                case AlterCmd::DEL_EVENT:
+                    node->deleteEvent(name_);
+                    break;
+                case AlterCmd::DEL_METER:
+                    node->deleteMeter(name_);
+                    break;
+                case AlterCmd::DEL_LABEL:
+                    node->deleteLabel(name_);
+                    break;
+                case AlterCmd::DEL_TRIGGER:
+                    node->deleteTrigger();
+                    break;
+                case AlterCmd::DEL_COMPLETE:
+                    node->deleteComplete();
+                    break;
+                case AlterCmd::DEL_REPEAT:
+                    node->deleteRepeat();
+                    break;
+                case AlterCmd::DEL_LIMIT:
+                    node->deleteLimit(name_);
+                    break;
+                case AlterCmd::DEL_LIMIT_PATH:
+                    node->delete_limit_path(name_, value_);
+                    break;
+                case AlterCmd::DEL_INLIMIT:
+                    node->deleteInlimit(name_);
+                    break;
+                case AlterCmd::DEL_ZOMBIE:
+                    node->deleteZombie(name_);
+                    break;
+                case AlterCmd::DEL_LATE:
+                    node->deleteLate();
+                    break;
+                case AlterCmd::DEL_QUEUE:
+                    node->delete_queue(name_);
+                    break;
+                case AlterCmd::DEL_GENERIC:
+                    node->delete_generic(name_);
+                    break;
+                case AlterCmd::DELETE_ATTR_ND:
+                    break;
+                case AlterCmd::DEL_AVISO:
+                    node->deleteAviso(name_);
+                    break;
+                case AlterCmd::DEL_MIRROR:
+                    node->deleteMirror(name_);
+                    break;
+                default:
+                    break;
+            }
+        }
+        catch (std::exception& e) {
+            ss << "Alter (delete) failed for " << paths_[i] << " : " << e.what() << "\n";
+        }
+
+        try {
+            switch (change_attr_type_) {
+                case AlterCmd::VARIABLE:
+                    node->changeVariable(name_, value_);
+                    break;
+                case AlterCmd::CLOCK_TYPE:
+                    node->suite()->changeClockType(name_);
+                    break; // node must be a suite, value must [hybrid|real| virtual]
+                case AlterCmd::CLOCK_DATE:
+                    node->suite()->changeClockDate(name_);
+                    break; // Expecting day.month.year: node must be a suite, value must [hybrid|real| virtual]
+                case AlterCmd::CLOCK_GAIN:
+                    node->suite()->changeClockGain(name_);
+                    break; // node must be a suite, value must be int
+                case AlterCmd::CLOCK_SYNC:
+                    node->suite()->changeClockSync();
+                    break; // node must be a suite, sync clock with computer
+                case AlterCmd::EVENT:
+                    node->changeEvent(name_, value_);
+                    break; // if value is empty just set, [1|0] or name [set | clear]
+                case AlterCmd::METER:
+                    node->changeMeter(name_, value_);
+                    break;
+                case AlterCmd::LABEL:
+                    node->changeLabel(name_, value_);
+                    break;
+                case AlterCmd::AVISO:
+                    node->changeAviso(name_, value_);
+                    break;
+                case AlterCmd::TRIGGER:
+                    node->changeTrigger(name_);
+                    break; // expression must parse
+                case AlterCmd::COMPLETE:
+                    node->changeComplete(name_);
+                    break; // expression must parse
+                case AlterCmd::REPEAT:
+                    node->changeRepeat(name_);
+                    break; //
+                case AlterCmd::LIMIT_MAX:
+                    node->changeLimitMax(name_, value_);
+                    break; // value must be convertible to int
+                case AlterCmd::LIMIT_VAL:
+                    node->changeLimitValue(name_, value_);
+                    break; // value < limit max, & value must be convertible to an int
+                case AlterCmd::DEFSTATUS:
+                    node->changeDefstatus(name_);
+                    break; // must be a valid state
+                case AlterCmd::LATE:
+                    node->changeLate(LateAttr::create(name_));
+                    break; // must be a valid late
+                case AlterCmd::TIME:
+                    node->change_time(name_, value_);
+                    break;
+                case AlterCmd::TODAY:
+                    node->change_today(name_, value_);
+                    break;
+                case AlterCmd::CHANGE_ATTR_ND:
+                    break;
+                case AlterCmd::MIRROR:
+                    node->changeMirror(name_, value_);
+                    break;
+                default:
+                    break;
+            }
+        }
+        catch (std::exception& e) {
+            ss << "Alter (change) failed for " << paths_[i] << " : " << e.what() << "\n";
+        }
+
+        try {
+            switch (add_attr_type_) {
+                case AlterCmd::ADD_TIME:
+                    node->addTime(TimeAttr(TimeSeries::create(name_)));
+                    break;
+                case AlterCmd::ADD_TODAY:
+                    node->addToday(TodayAttr(TimeSeries::create(name_)));
+                    break;
+                case AlterCmd::ADD_DATE:
+                    node->addDate(DateAttr::create(name_));
+                    break;
+                case AlterCmd::ADD_DAY:
+                    node->addDay(DayAttr::create(name_));
+                    break;
+                case AlterCmd::ADD_AVISO: {
+                    auto aviso = AvisoParser::parse_aviso_line(value_, name_, node.get());
+                    node->addAviso(aviso);
+                    break;
+                }
+                case AlterCmd::ADD_MIRROR: {
+                    auto mirror = MirrorParser::parse_mirror_line(value_, name_, node.get());
+                    node->addMirror(mirror);
+                    break;
+                }
+                case AlterCmd::ADD_ZOMBIE:
+                    node->addZombie(ZombieAttr::create(name_));
+                    break;
+                case AlterCmd::ADD_VARIABLE:
+                    node->add_variable(name_, value_);
+                    break;
+                case AlterCmd::ADD_LATE:
+                    node->addLate(LateAttr::create(name_));
+                    break;
+                case AlterCmd::ADD_LABEL:
+                    node->addLabel(Label(name_, value_));
+                    break;
+                case AlterCmd::ADD_LIMIT: {
+                    int int_value = 0;
+                    try {
+                        int_value = ecf::convert_to<int>(value_);
+                    }
+                    catch (const ecf::bad_conversion&) {
+                        std::stringstream mss;
+                        mss << "AlterCmd: add_limit " << name_ << " " << value_ << " failed. Expected '" << value_
+                            << "' to be convertible to an integer";
+                        throw std::runtime_error(mss.str());
+                    }
+                    node->addLimit(Limit(name_, int_value));
+                    break;
+                }
+                case AlterCmd::ADD_INLIMIT: {
+                    string path_to_limit; // This can be empty
+                    string limitName;
+                    if (!Extract::pathAndName(name_, path_to_limit, limitName)) {
+                        throw std::runtime_error("AlterCmd::ADD_INLIMIT: Invalid inlimit : " + name_);
+                    }
+                    int token_value = 1;
+                    if (!value_.empty()) {
+                        try {
+                            token_value = ecf::convert_to<int>(value_);
+                        }
+                        catch (const ecf::bad_conversion&) {
+                            ss << "AlterCmd: add_inlimit expected '" << value_ << "' to be convertible to an integer";
+                            throw std::runtime_error(ss.str());
+                        }
+                    }
+                    node->addInLimit(InLimit(limitName, path_to_limit, token_value)); // will throw if not valid
+                    break;
+                }
+                case AlterCmd::ADD_ATTR_ND:
+                    break;
+            }
+        }
+        catch (std::exception& e) {
+            ss << "Alter (add) failed for " << paths_[i] << ": Could not parse " << name_ << " : " << e.what() << "\n";
+        }
+
+        // Change flags
+        if (flag_type_ != Flag::NOT_SET) {
+            if (flag_)
+                node->flag().set(flag_type_);
+            else
+                node->flag().clear(flag_type_);
+        }
+
+        // sort
+        ecf::Attr::Type attr = Attr::to_attr(name_);
+        if (attr != ecf::Attr::UNKNOWN) {
+            bool recursive = (value_ == "recursive") ? true : false;
+            node->sort_attributes(attr, recursive);
+        }
+    }
+
+    std::string error_msg = ss.str();
+    if (!error_msg.empty()) {
+        throw std::runtime_error(error_msg);
+    }
+
+    return doJobSubmission(as);
+}
+
+bool AlterCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, paths_);
+}
+
+const char* AlterCmd::arg() {
+    return CtsApi::alterArg();
+}
+const char* AlterCmd::desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Alter the node according to the options.\n"
+           "To add/delete/change server variables use '/' for the path.\n"
+           "arg1 =   [ delete | change | add | set_flag | clear_flag | sort ]\n"
+           "         one option must be specified\n"
+           "arg2 = For delete:\n"
+           "         [ variable | time | today | date  | day | cron | event | meter | late | generic | queue |\n"
+           "           label | trigger | complete | repeat | limit | inlimit | limit_path | zombie | aviso | mirror ]\n"
+           "       For change:\n"
+           "         [ variable | clock_type | clock_gain | clock_date | clock_sync  | event | meter | label |\n"
+           "           trigger  | complete   | repeat     | limit_max  | limit_value | defstatus | late | time |\n"
+           "           today, aviso, mirror ]\n"
+           "         *NOTE* If the clock is changed, then the suite will need to be re-queued in order for\n"
+           "         the change to take effect fully.\n"
+           "       For add:\n"
+           "         [ variable | time | today | date | day | zombie | late | limit | inlimit | label | aviso | mirror ]\n"
+           "       For set_flag and clear_flag:\n"
+           "         [ force_aborted | user_edit | task_aborted | edit_failed | ecfcmd_failed \n"
+           "           statuscmd_failed | killcmd_failed | no_script | killed | status | late | message | \n"
+           "           complete | queue_limit | task_waiting | locked | zombie | archived | restored |\n"
+           "           threshold | log_error | checkpt_error]\n"
+           "       For sort:\n"
+           "         [ event | meter | label | variable| limit | all ]\n"
+           "arg3 = name/value\n"
+           "arg4 = new_value\n"
+           "arg5 = paths : At least one node path required.The paths must start with a leading '/' character\n"
+           "\n"
+           "When adding or updating attributes, such as variable, meter, event, label, limits, or late,\n"
+           "  the name (arg3) and value (arg4) must be quoted.\n"
+           "\n"
+           "When sorting attributes, 'recursive' can be used as the value (arg3)\n"
+           "\n"
+           "When adding or updating aviso and mirror attributes, the value (arg4) is expected to be a quoted list of\n"
+           "  configuration options. For example:\n"
+           "   * for aviso, \"--remote_path /s1/f1/t2 --remote_host host --polling 20 --remote_port 3141 --ssl)\"\n"
+           "   * for mirror, \"--listener '{ \\\"event\\\": \\\"mars\\\", \\\"request\\\": { \\\"class\\\": \"od\" } }'\n"
+           "                  --url http://aviso/ --schema /path/to/schema --polling 60\"\n"
+           "\n"
+           "Usage:\n\n"
+           "   ecflow_client --alter=add variable GLOBAL \"value\" /           # add server variable\n"
+           "   ecflow_client --alter=add variable FRED \"value\" /path/to/node # add node variable\n"
+           "   ecflow_client --alter=add time \"+00:20\" /path/to/node\n"
+           "   ecflow_client --alter=add date \"01.*.*\" /path/to/node\n"
+           "   ecflow_client --alter=add day \"sunday\"  /path/to/node\n"
+           "   ecflow_client --alter=add label name \"label_value\" /path/to/node\n"
+           "   ecflow_client --alter=add late \"-s 00:01 -a 14:30 -c +00:01\" /path/to/node\n"
+           "   ecflow_client --alter=add limit mars \"100\" /path/to/node\n"
+           "   ecflow_client --alter=add inlimit /path/to/node/withlimit:limit_name \"10\" /path/to/node\n"
+           "   # zombie attributes have the following structure:\n"
+           "     `zombie_type`:(`client_side_action` | `server_side_action`):`child`:`zombie_life_time`\n"
+           "      zombie_type        = \"user\" | \"ecf\" | \"path\" | \"ecf_pid\" | \"ecf_passwd\" | "
+           "\"ecf_pid_passwd\"\n"
+           "      client_side_action = \"fob\" | \"fail\" | \"block\"\n"
+           "      server_side_action = \"adopt\" | \"delete\" | \"kill\"\n"
+           "      child              = \"init\" | \"event\" | \"meter\" | \"label\" | \"wait\" | \"abort\" | "
+           "\"complete\" | \"queue\"\n"
+           "      zombie_life_time   = unsigned integer default: user(300), ecf(3600), path(900)  minimum is 60\n"
+           "   ecflow_client --alter=add zombie \"ecf:fail::\" /path/to/node     # ask system zombies to fail\n"
+           "   ecflow_client --alter=add zombie \"user:fail::\" /path/to/node    # ask user generated zombies to fail\n"
+           "   ecflow_client --alter=add zombie \"path:fail::\" /path/to/node    # ask path zombies to fail\n\n"
+           "   ecflow_client --alter=delete variable FRED /path/to/node    # delete variable FRED\n"
+           "   ecflow_client --alter=delete variable      /path/to/node    # delete *ALL* variables on the specified "
+           "node\n";
+}
+
+void AlterCmd::addOption(boost::program_options::options_description& desc) const {
+    // Important: this option is, in practice, multi-token (and thus should use
+    // po::value<vector<string>>()->multitoken()). However, because of the special handling
+    // necessary to allow positional values, such as "--help", a custom `style_parser` is used
+    // instead when parsing the CLI options -- see ClientOptions for details.
+    desc.add_options()(AlterCmd::arg(), po::value<vector<string>>(), AlterCmd::desc());
+}
+void AlterCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(AlterCmd::arg(), args);
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
+    if (paths.empty()) {
+        std::stringstream ss;
+        ss << "AlterCmd: No paths specified. Paths must begin with a leading '/' character\n"
+           << dump_args(options, paths) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+    if (options.empty()) {
+        std::stringstream ss;
+        ss << "AlterCmd: Invalid argument list:\n" << dump_args(options, paths) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+    if (options.size() < 2) {
+        std::stringstream ss;
+        ss << "Alter: At least three arguments expected. Found " << args.size() << "\n"
+           << dump_args(options, paths) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // arg[0] should one of [ add | delete | change | set_flag | clear_flag | sort ]
+    std::string alterType = options[0];
+
+    if (alterType == "add") {
+
+        createAdd(cmd, options, paths);
+        return;
+    }
+    else if (alterType == "change") {
+
+        createChange(cmd, options, paths);
+        return;
+    }
+    else if (alterType == "delete") {
+
+        createDelete(cmd, options, paths);
+        return;
+    }
+    else if (alterType == "set_flag") {
+
+        create_flag(cmd, options, paths, true /*set */);
+        return;
+    }
+    else if (alterType == "clear_flag") {
+
+        create_flag(cmd, options, paths, false /*clear */);
+        return;
+    }
+    else if (alterType == "sort") {
+
+        create_sort_attributes(cmd, options, paths);
+        return;
+    }
+
+    std::stringstream ss;
+    ss << "Alter: The first argument must be one of [ change | delete | add | set_flag | clear_flag | sort ] but found "
+          "'"
+       << alterType << "'\n"
+       << dump_args(options, paths) << "\n";
+    throw std::runtime_error(ss.str());
+}
+
+AlterCmd::Add_attr_type AlterCmd::get_add_attr_type(const std::string& attr_type) const {
+    AlterCmd::Add_attr_type theAttrType = addAttrType(attr_type);
+    if (theAttrType == AlterCmd::ADD_ATTR_ND) {
+        std::stringstream ss;
+        ss << "AlterCmd: add: The second argument must be one of [ ";
+        std::vector<std::string> valid;
+        validAddAttr(valid);
+        for (size_t i = 0; i < valid.size(); ++i) {
+            if (i != 0)
+                ss << " | ";
+            ss << valid[i];
+        }
+        ss << "] but found " << attr_type << "\n" << AlterCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+    return theAttrType;
+}
+
+void AlterCmd::createAdd(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const {
+    // options[0] - add
+    // options[1] - [ time | today | date | day | zombie | variable | late | limit | inlimit | label ]
+    // options[2] - [ time_string | date_string | day_string | zombie_string | variable_name | limit_name |
+    //                path_to_limit ]
+    // options[3] - variable_value
+
+    AlterCmd::Add_attr_type theAttrType = get_add_attr_type(options[1]);
+
+    std::stringstream ss;
+    if (options.size() < 3) {
+        ss << "AlterCmd: add: At least four arguments expected. Found " << (options.size() + paths.size()) << "\n"
+           << dump_args(options, paths) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    string name, value;
+    try {
+        extract_name_and_value_for_add(theAttrType, name, value, options, paths);
+        check_for_add(theAttrType, name, value);
+    }
+    catch (std::exception& e) {
+        ss << "AlterCmd: add: Could not parse " << name << ". Error: " << e.what()
+           << "\n for time,today and date the new value should be a quoted string "
+           << "\n for add expected: --alter add variable <name> <value> <paths>\n"
+           << dump_args(options, paths) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    cmd = std::make_shared<AlterCmd>(paths, theAttrType, name, value);
+}
+
+void AlterCmd::extract_name_and_value_for_add(AlterCmd::Add_attr_type theAttrType,
+                                              std::string& name,
+                                              std::string& value,
+                                              std::vector<std::string>& options,
+                                              std::vector<std::string>& paths) const {
+    // **** parse and check format, expect this argument to be single or double tick quoted ****
+    // **** for time,date,day or zombie
+    std::stringstream ss;
+    name = options[2];
+    switch (theAttrType) {
+        case AlterCmd::ADD_TIME:
+            break;
+        case AlterCmd::ADD_TODAY:
+            break;
+        case AlterCmd::ADD_DATE:
+            break;
+        case AlterCmd::ADD_DAY:
+            break;
+        case AlterCmd::ADD_ZOMBIE:
+            break;
+        case AlterCmd::ADD_LATE:
+            break;
+        case AlterCmd::ADD_VARIABLE: {
+            if (options.size() == 3 && paths.size() > 1) {
+                // variable value may be a path, hence it will be in the paths parameter
+                options.push_back(paths[0]);
+                paths.erase(paths.begin());
+            }
+            if (options.size() < 4) {
+                ss << "AlterCmd: add: Expected 'add variable <name> <value> <paths>. Not enough arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            value = options[3];
+            break;
+        }
+        case AlterCmd::ADD_LABEL: {
+            if (options.size() == 3 && paths.size() > 1) {
+                // label value may be a path, hence it will be in the paths parameter
+                options.push_back(paths[0]);
+                paths.erase(paths.begin());
+            }
+            if (options.size() < 4) {
+                ss << "AlterCmd: add: Expected 'add label <name> <value> <paths>. Not enough arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            value = options[3];
+            break;
+        }
+        case AlterCmd::ADD_AVISO: {
+            if (options.size() != 4 || paths.size() < 1) {
+                ss << "AlterCmd: add: Expected 'add aviso <name> <cfg> <path> [<path> [...]]. Not enough arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            value = options[3];
+            break;
+        }
+        case AlterCmd::ADD_MIRROR: {
+            if (options.size() != 4 || paths.size() < 1) {
+                ss << "AlterCmd: add: Expected 'add mirror <name> <cfg> <path> [<path> [...]]. Not enough arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::ADD_LIMIT: {
+            if (options.size() < 4) {
+                ss << "AlterCmd: add: Expected 'add limit <name> int. Not enough arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            value = options[3];
+            break;
+        }
+        case AlterCmd::ADD_INLIMIT: { // inlimit /obs/limits:hpcd 2 name=hpcd, path=/obs/limits, tokens=2(optional)
+            // options[0]  - add
+            // options[1]  - [ inlimit ]
+            // options[2]  - [ path_to_limit:limit_name ]   --> name
+            // options[3]  - integer (optional)             --> value
+            if (options.size() < 3) {
+                ss << "AlterCmd: add: Expected 'add inlimit <path-to-limit:limit_name> <int>(optional) <paths>. Not "
+                      "enough arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            if (options.size() == 4) {
+                value = options[3];
+            }
+            break;
+        }
+        case AlterCmd::ADD_ATTR_ND:
+            break;
+    }
+}
+
+void AlterCmd::check_for_add(AlterCmd::Add_attr_type theAttrType,
+                             const std::string& name,
+                             const std::string& value) const {
+    // **** parse and check format, expect this argument to be single or double tick quoted ****
+    // **** for time,date,day or zombie
+    if (name.empty())
+        throw std::runtime_error("Alter: check_for_add : name is empty ?");
+
+    std::stringstream ss;
+    switch (theAttrType) {
+        case AlterCmd::ADD_TIME:
+            (void)TimeSeries::create(name);
+            break;
+        case AlterCmd::ADD_TODAY:
+            (void)TimeSeries::create(name);
+            break;
+        case AlterCmd::ADD_DATE:
+            (void)DateAttr::create(name);
+            break;
+        case AlterCmd::ADD_DAY:
+            (void)DayAttr::create(name);
+            break;
+        case AlterCmd::ADD_AVISO: {
+            AvisoParser::parse_aviso_line(value, name);
+            break;
+        }
+        case AlterCmd::ADD_MIRROR: {
+            MirrorParser::parse_mirror_line(value, name);
+            break;
+        }
+        case AlterCmd::ADD_ZOMBIE:
+            (void)ZombieAttr::create(name);
+            break;
+        case AlterCmd::ADD_LATE:
+            (void)LateAttr::create(name);
+            break;
+        case AlterCmd::ADD_VARIABLE: {
+            // Create a Variable to check valid names
+            Variable check(name, value);
+            break;
+        }
+        case AlterCmd::ADD_LABEL: {
+            // Create a Label to check valid names
+            Label check(name, value);
+            break;
+        }
+        case AlterCmd::ADD_LIMIT: {
+            int int_value = 0;
+            try {
+                int_value = ecf::convert_to<int>(value);
+            }
+            catch (const ecf::bad_conversion&) {
+                ss << "AlterCmd add_limit expected value(" << value << ") to be convertible to an integer\n";
+                throw std::runtime_error(ss.str());
+            }
+            Limit check(name, int_value); // will throw if not valid
+            break;
+        }
+        case AlterCmd::ADD_INLIMIT: { // inlimit /obs/limits:hpcd 2 name=hpcd, path=/obs/limits, tokens=2(optional)
+            // options[0]  - add
+            // options[1]  - [ inlimit ]
+            // options[2]  - [ path_to_limit:limit_name ]  ---> name
+            // options[3]  - integer (optional)            ---> value
+            string path_to_limit; // This can be empty
+            string limitName;
+            if (!Extract::pathAndName(name, path_to_limit, limitName)) {
+                throw std::runtime_error("AlterCmd add inlimit Invalid inlimit : " + name);
+            }
+            int token_value = 1;
+            if (!value.empty()) {
+                try {
+                    token_value = ecf::convert_to<int>(value);
+                }
+                catch (const ecf::bad_conversion&) {
+                    ss << "AlterCmd add inlimit expected optional limit token '" << value
+                       << "' to be convertible to an integer\n";
+                    throw std::runtime_error(ss.str());
+                }
+            }
+            InLimit inlimit(limitName, path_to_limit, token_value); // will throw if not valid
+            break;
+        }
+        case AlterCmd::ADD_ATTR_ND:
+            break;
+    }
+}
+
+AlterCmd::Delete_attr_type AlterCmd::get_delete_attr_type(const std::string& attr_type) const {
+    AlterCmd::Delete_attr_type theAttrType = deleteAttrType(attr_type);
+    if (theAttrType == AlterCmd::DELETE_ATTR_ND) {
+        std::stringstream ss;
+        ss << "Alter: delete: The second argument must be one of [ ";
+        std::vector<std::string> valid;
+        validDeleteAttr(valid);
+        for (size_t i = 0; i < valid.size(); ++i) {
+            if (i != 0)
+                ss << " | ";
+            ss << valid[i];
+        }
+        ss << "] but found " << attr_type << "\n" << AlterCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+    return theAttrType;
+}
+
+void AlterCmd::createDelete(Cmd_ptr& cmd,
+                            const std::vector<std::string>& options,
+                            const std::vector<std::string>& paths) const {
+    // options[0] = delete
+    // options[1] = [ variable | time | today | date | day | cron | event | meter | label | trigger | complete |
+    //                repeat | limit | limit_path | inlimit | zombie | late ]
+    // options[2] = name ( of object to be deleted ) optional
+    // options[3] = limit_path (optional *ONLY* applicable for limit_path), specifies the path to be deleted
+
+    AlterCmd::Delete_attr_type theAttrType = get_delete_attr_type(options[1]);
+
+    // Generally an empty third argument means delete all attributes, otherwise delete the specific one.
+    std::string name, value;
+    try {
+        extract_name_and_value_for_delete(theAttrType, name, value, options, paths);
+        check_for_delete(theAttrType, name, value);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "AlterCmd: delete: Could not parse " << name << ". Error: " << e.what()
+           << "\n for time,today and date the new value should be a quoted string\n"
+           << dump_args(options, paths) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+    cmd = std::make_shared<AlterCmd>(paths, theAttrType, name, value);
+}
+
+void AlterCmd::extract_name_and_value_for_delete(AlterCmd::Delete_attr_type theAttrType,
+                                                 std::string& name,
+                                                 std::string& value,
+                                                 const std::vector<std::string>& options,
+                                                 const std::vector<std::string>& paths) const {
+    // Generally an empty third argument means delete all attributes, otherwise delete the specific one.
+    if (options.size() >= 3)
+        name = options[2];
+
+    // Deleting the limit path requires an additional arg
+    std::string path_value;
+
+    // if specified make sure its parses
+    if (theAttrType == AlterCmd::DEL_LIMIT_PATH) {
+        if (name.empty()) {
+            std::stringstream ss;
+            ss << "Delete limit_path failed. No limit name provided. Expected 5 args: delete limit_path <limit_name> "
+                  "<path-to-limit> <path_to_node>\n";
+            ss << dump_args(options, paths) << "\n";
+            throw std::runtime_error(ss.str());
+        }
+
+        std::vector<std::string> altered_path = paths;
+        if (options.size() == 4) {
+            // User has provided a limit path which does not start with '/'. Go with flow
+            path_value = options[3];
+        }
+        else {
+            // Since we have a limit path(i.e begins with'/') it will appear in the paths, as the first path
+            if (paths.size() <= 1) {
+                std::stringstream ss;
+                ss << "Delete limit_path failed: No path to limit provided. Expected 5 args: delete limit_path "
+                      "<limit_name> <path-to-limit> <path_to_node>\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            path_value = paths[0];
+
+            // Change paths to remove the limit path.
+            altered_path.erase(altered_path.begin());
+        }
+        value = path_value;
+    }
+}
+
+void AlterCmd::check_for_delete(AlterCmd::Delete_attr_type theAttrType,
+                                const std::string& name,
+                                const std::string& value) const {
+    switch (theAttrType) {
+        case AlterCmd::DEL_VARIABLE: {
+            if (!name.empty())
+                Variable check(name, ""); // Create a Variable to check valid names
+            break;
+        }
+        case AlterCmd::DEL_TIME: {
+            if (!name.empty())
+                (void)TimeSeries::create(name); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_TODAY: {
+            if (!name.empty())
+                (void)TimeSeries::create(name); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_DATE: {
+            if (!name.empty())
+                (void)DateAttr::create(name); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_DAY: {
+            if (!name.empty())
+                (void)DayAttr::create(name); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_CRON: {
+            if (!name.empty()) {
+                CronAttr parsedCron = CronAttr::create(name); // will throw if not valid
+
+                // additional check since parsing is very forgiving. if parsed string is same as default
+                // then no cron was specified.
+                CronAttr emptyCron;
+                if (emptyCron.structureEquals(parsedCron)) {
+                    throw std::runtime_error("Delete cron Attribute failed. Check cron " + name);
+                }
+            }
+            break;
+        }
+        case AlterCmd::DEL_AVISO: {
+            if (!AvisoAttr::is_valid_name(name)) {
+                throw ecf::InvalidArgument(ecf::Message("Invalid AvisoAttr name :", name_));
+            }
+            break;
+        }
+        case AlterCmd::DEL_MIRROR: {
+            if (!MirrorAttr::is_valid_name(name)) {
+                throw ecf::InvalidArgument(ecf::Message("Invalid MirrorAttr name :", name_));
+            }
+            break;
+        }
+        case AlterCmd::DEL_EVENT: {
+            if (!name.empty()) {
+                Event check(name); // will throw if not valid
+            }
+            break;
+        }
+        case AlterCmd::DEL_METER: {
+            if (!name.empty())
+                Meter check(name, 0, 100); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_LABEL: {
+            if (!name.empty())
+                Label check(name, "value"); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_TRIGGER:
+            break; // there can only be one trigger per node, so we delete by path
+        case AlterCmd::DEL_COMPLETE:
+            break; // there can only be one complete per node, so we delete by path
+        case AlterCmd::DEL_REPEAT:
+            break; // there can only be one repeat per node, so we delete by path
+        case AlterCmd::DEL_LATE:
+            break; // there can only be one late per node, so we delete by path
+        case AlterCmd::DEL_QUEUE: {
+            if (!name.empty()) {
+                std::vector<std::string> vec;
+                vec.emplace_back("a");
+                QueueAttr check(name, vec); // will throw if not valid
+            }
+            break;
+        }
+        case AlterCmd::DEL_GENERIC: {
+            if (!name.empty())
+                GenericAttr check(name); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_LIMIT: {
+            if (!name.empty())
+                Limit check(name, 10); // will throw if not valid
+            break;
+        }
+        case AlterCmd::DEL_INLIMIT: {
+            if (!name.empty()) {
+                // name can be:
+                //    limit_name
+                //    /path/to/limit:limit_name
+                string path_to_limit; // This can be empty
+                string limitName;
+                if (!Extract::pathAndName(name, path_to_limit, limitName)) {
+                    throw std::runtime_error("AlterCmd::DEL_INLIMIT : Invalid inlimit : " + name);
+                }
+                InLimit check(limitName, path_to_limit); // will throw if not valid
+            }
+            break;
+        }
+        case AlterCmd::DEL_ZOMBIE: {
+            if (!Child::valid_zombie_type(name)) {
+                throw std::runtime_error(
+                    "Delete Zombie Attribute failed. Expected one of [ ecf | path | user ] but found " + name);
+            }
+            break;
+        }
+        case AlterCmd::DEL_LIMIT_PATH: {
+            if (name.empty()) {
+                throw std::runtime_error("Delete limit_path failed. No limit name provided");
+            }
+            return;
+        }
+        case AlterCmd::DELETE_ATTR_ND:
+            break;
+    }
+}
+
+// =====================================================================================
+
+AlterCmd::Change_attr_type AlterCmd::get_change_attr_type(const std::string& attr_type) const {
+    AlterCmd::Change_attr_type theAttrType = changeAttrType(attr_type);
+    if (theAttrType == AlterCmd::CHANGE_ATTR_ND) {
+        std::stringstream ss;
+        ss << "AlterCmd: change: The third argument(" << attr_type << ") must be one of [ ";
+        std::vector<std::string> valid;
+        validChangeAttr(valid);
+        for (size_t i = 0; i < valid.size(); ++i) {
+            if (i != 0)
+                ss << " | ";
+            ss << valid[i];
+        }
+        ss << "]\n" << AlterCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+    return theAttrType;
+}
+
+void AlterCmd::createChange(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const {
+    // options[0] = change
+    // options[1] = [ variable | clock_type | clock_gain | clock_date | clock_sync | event | meter | label | trigger |
+    //                complete | repeat | limit_max | limit_value | defstatus | late ]
+    // options[2] = name
+    // options[3] = value
+
+    AlterCmd::Change_attr_type theAttrType = get_change_attr_type(options[1]);
+
+    std::string name, value;
+    extract_name_and_value_for_change(theAttrType, name, value, options, paths);
+    cmd = std::make_shared<AlterCmd>(paths, theAttrType, name, value);
+}
+
+void AlterCmd::extract_name_and_value_for_change(AlterCmd::Change_attr_type theAttrType,
+                                                 std::string& name,
+                                                 std::string& value,
+                                                 std::vector<std::string>& options,
+                                                 std::vector<std::string>& paths) const {
+    std::stringstream ss;
+    switch (theAttrType) {
+        case AlterCmd::VARIABLE: {
+            if (options.size() == 3 && paths.size() > 1) {
+                // The variable value may be a path, and hence it will be paths and not options parameter
+                options.push_back(paths[0]);
+                paths.erase(paths.begin()); // remove first path, since it has been added to options
+            }
+            if (options.size() < 3 || options.size() > 4) {
+                ss << "AlterCmd: change: expected 5 args : change variable <variable_name> <new_value> <path_to_node>";
+                ss << " but found only " << (options.size() + paths.size())
+                   << " arguments.\nThe value should be quoted if there are spaces\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            if (options.size() == 4)
+                value = options[3];
+            break;
+        }
+
+        case AlterCmd::CLOCK_TYPE: {
+            if (options.size() != 3) {
+                ss << "AlterCmd: change: expected at least four args i.e. change clock_type [ hybrid | real ] "
+                      "<path_to_suite>";
+                ss << " but found only " << (options.size() + paths.size()) << " arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::CLOCK_DATE: {
+            if (options.size() != 3) {
+                ss << "AlterCmd: change clock_date : expected at least four args :  change clock_date day.month.year "
+                      "<path_to_suite>";
+                ss << " but found only " << (options.size() + paths.size()) << " arguments\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::CLOCK_GAIN: {
+            if (options.size() != 3) {
+                ss << "AlterCmd: change clock_gain : expected four args i.e. change clock_gain <int> <path_to_suite> ";
+                ss << " but found " << (options.size() + paths.size())
+                   << " arguments. The actual gain must be convertible to an integer\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::CLOCK_SYNC: {
+            if (options.size() != 2) {
+                ss << "AlterCmd: change clock_sync : expected three args i.e. change clock_sync  <path_to_suite> ";
+                ss << " but found " << (options.size() + paths.size()) << " arguments.\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+
+        case AlterCmd::EVENT: {
+            if (options.size() != 3 && options.size() != 4) {
+                ss << "AlterCmd: Change event : expected four/five args:  change event <name_or_number> <[set | clear "
+                      "| <nothing>]> <path_to_node>";
+                ss << " but found only " << (options.size() + paths.size()) << " arguments\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            if (options.size() == 4) {
+                value = options[3];
+            }
+            break;
+        }
+
+        case AlterCmd::METER: {
+            if (options.size() != 4) {
+                ss << "AlterCmd: change: expected five args: change meter meter_name meter_value  <path_to_node>";
+                ss << " but found only " << (options.size() + paths.size())
+                   << " arguments. The meter value must be convertible to an integer\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name  = options[2];
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::LABEL: {
+            if (options.size() == 3 && paths.size() == 1) {
+                // ECFLOW-648 allow label value to be empty
+                // HOWEVER , we cannot cope multiple paths, and setting value to empty.
+                // since empty quotes are removed by boost program options, hence if we have a label value which is
+                // path, and multiple paths
+                value.clear();
+            }
+            else {
+                // ECFLOW-480 take into account label values that is a path, adding quotes around the value does not
+                // help: Note boost program options will remove the quotes around the value
+                //      hence it's difficult to say what is an option and what is a path.
+                //      However since we expect 4(change,label,<label_name>,<label_value>) options, work around the
+                //      problem
+                if (options.size() == 3 && paths.size() > 1) {
+                    options.push_back(paths[0]);
+                    paths.erase(paths.begin()); // remove first path, since it has been added to options
+                }
+                if (options.size() != 4) {
+                    ss << "AlterCmd: change label expected at least five args : change label <label_name> "
+                          "<label_value> <path_to_node> ";
+                    ss << " but found  " << (options.size() + paths.size())
+                       << " arguments. the label value should be quoted\n";
+                    ss << dump_args(options, paths) << "\n";
+                    throw std::runtime_error(ss.str());
+                }
+                value = options[3];
+                if (value.find("\\n") != std::string::npos) {
+                    Str::replaceall(value, "\\n", "\n");
+                }
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::AVISO: {
+            if (options.size() != 4 || paths.size() < 1) {
+                ss << "AlterCmd: change: Expected 'change aviso <name> <cfg> <path> [<path>] [...]."
+                   << "Incorrect number of arguments.\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name  = options[2];
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::MIRROR: {
+            if (options.size() != 4 || paths.size() < 1) {
+                ss << "AlterCmd: change: Expected 'change mirror <name> <cfg> <path> [<path>] [...]."
+                   << "Incorrect number of arguments.\n"
+                   << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name  = options[2];
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::LATE: {
+            if (options.size() != 3) {
+                ss << "AlterCmd: change: expected three args: change late \"late -s +00:15  -a  20:00  -c +02:00\" "
+                      "<path_to_node>";
+                ss << " but found only " << (options.size() + paths.size()) << " arguments\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::TRIGGER: {
+            if (options.size() != 3) {
+                ss << "AlterCmd: change: expected four args : change trigger 'expression' <path_to_node>";
+                ss << " but found " << (options.size() + paths.size())
+                   << " arguments. The trigger expression must be quoted\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::COMPLETE: {
+            if (options.size() != 3) {
+                ss << "AlterCmd: change complete: expected four args: change complete 'expression'  <path_to_node> ";
+                ss << " but found " << (options.size() + paths.size()) << " arguments. The expression must be quoted\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::REPEAT: {
+            // *NOTE* a Node can only have *ONE* repeat, hence no need to provide name
+            if (options.size() != 3) {
+                ss << "AlterCmd: change repeat: expected four arg's : change repeat [ integer | string ] "
+                      "<path_to_node>";
+                ss << " but found only " << (options.size() + paths.size()) << " arguments.\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::LIMIT_MAX: {
+            if (options.size() != 4) {
+                ss << "AlterCmd: change: limit_max: : expected five arguments : change limit_max <limit_name> <int> "
+                      "<path_to_node>";
+                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name  = options[2];
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::LIMIT_VAL: {
+            if (options.size() != 4) {
+                ss << "AlterCmd: change: limit-value: expected five arguments : change limit_value <limit_name> <int> "
+                      "<path_to_node>";
+                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name  = options[2];
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::TIME: {
+            if (options.size() != 4) {
+                ss << "AlterCmd: change: time: expected five arguments : change time old_time new_time <path_to_node>";
+                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name  = options[2];
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::TODAY: {
+            if (options.size() != 4) {
+                ss << "AlterCmd: change: today: expected five arguments : change time old_today new_today "
+                      "<path_to_node>";
+                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name  = options[2];
+            value = options[3];
+            break;
+        }
+
+        case AlterCmd::DEFSTATUS: {
+            if (options.size() != 3) {
+                ss << "AlterCmd: change defstatus expected four args : change defstatus [ queued | complete | unknown "
+                      "| aborted | suspended ] <path_to_node>";
+                ss << " but found  " << (options.size() + paths.size()) << " arguments.\n";
+                ss << dump_args(options, paths) << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            name = options[2];
+            break;
+        }
+
+        case AlterCmd::CHANGE_ATTR_ND:
+            break;
+        default:
+            break;
+    }
+}
+
+void AlterCmd::check_for_change(AlterCmd::Change_attr_type theAttrType,
+                                const std::string& name,
+                                const std::string& value) const {
+    std::stringstream ss;
+    switch (theAttrType) {
+        case AlterCmd::VARIABLE:
+            break;
+        case AlterCmd::CLOCK_TYPE: {
+            if (name != "hybrid" && name != "real") {
+                ss << "AlterCmd: change clock_type: expected third argument to be one of [ hybrid | real ] but found "
+                   << name << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+        case AlterCmd::CLOCK_DATE: {
+            // Check date is in correct format:
+            try {
+                int day, month, year;
+                DateAttr::getDate(name, day, month, year);
+                DateAttr::checkDate(day, month, year, false /* for clocks, we don't allow wild carding */);
+            }
+            catch (std::exception& e) {
+                ss << "AlterCmd:change  clock_date " << name << " is not valid. " << e.what();
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+
+        case AlterCmd::CLOCK_GAIN: {
+            try {
+                ecf::convert_to<int>(name);
+            }
+            catch (const ecf::bad_conversion&) {
+                ss << "AlterCmd:change  clock_gain expected '" << name << "' to be convertible to an integer\n";
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+
+        case AlterCmd::CLOCK_SYNC:
+            break;
+
+        case AlterCmd::EVENT: {
+            if (!value.empty() && value != Event::SET() && value != Event::CLEAR()) {
+                ss << "AlterCmd: Change event : expected  <[set | clear | <nothing>]> for the value";
+                throw std::runtime_error(ss.str());
+            }
+            // The name could be an integer
+            try {
+                ecf::convert_to<int>(name);
+            }
+            catch (const ecf::bad_conversion&) {
+                // name is not an integer, check name is valid
+                Event check_name(name); // will throw if name is not valid
+            }
+            break;
+        }
+
+        case AlterCmd::METER: {
+            Meter check(name, 0, 100); // Check meter name , by creating a meter
+            try {
+                ecf::convert_to<int>(value);
+            }
+            catch (const ecf::bad_conversion&) {
+                ss << "AlterCmd change meter : " << value << " to be convertible to an integer\n";
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+
+        case AlterCmd::LABEL: {
+            Label check(name, value); // Check name , by creating
+            break;
+        }
+
+        case AlterCmd::LATE: {
+            (void)LateAttr::create(name); // Check we can create the late
+            break;
+        }
+
+        case AlterCmd::TIME: {
+            (void)TimeSeries::create(name);
+            (void)TimeSeries::create(value);
+            break;
+        }
+
+        case AlterCmd::TODAY: {
+            (void)TimeSeries::create(name);
+            (void)TimeSeries::create(value);
+            break;
+        }
+
+        case AlterCmd::TRIGGER: {
+            std::string error_msg       = "AlterCmd: change trigger:";
+            std::unique_ptr<AstTop> ast = Expression::parse_no_throw(name, error_msg);
+            if (!ast.get()) {
+                ss << error_msg << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+
+        case AlterCmd::COMPLETE: {
+            std::string error_msg       = "AlterCmd: change complete:";
+            std::unique_ptr<AstTop> ast = Expression::parse_no_throw(name, error_msg);
+            if (!ast.get()) {
+                ss << error_msg << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+
+        case AlterCmd::REPEAT: {
+            // *NOTE* a Node can only have *ONE* repeat, hence no need to provide name
+            break;
+        }
+
+        case AlterCmd::LIMIT_MAX: {
+            int limit = 0;
+            try {
+                limit = ecf::convert_to<int>(value);
+            }
+            catch (const ecf::bad_conversion&) {
+                ss << "AlterCmd: change: limit-max: expected " << value << " to be convertible to an integer\n";
+                throw std::runtime_error(ss.str());
+            }
+            Limit check(name, limit); // Check name , by creating
+            break;
+        }
+
+        case AlterCmd::LIMIT_VAL: {
+            try {
+                ecf::convert_to<int>(value);
+            }
+            catch (const ecf::bad_conversion&) {
+                ss << "AlterCmd: change: limit_value: expected " << value << " to be convertible to an integer\n";
+                throw std::runtime_error(ss.str());
+            }
+            Limit check(name, 10); // Check name, by creating
+            break;
+        }
+
+        case AlterCmd::DEFSTATUS: {
+            if (!DState::isValid(name)) {
+                ss << "AlterCmd change defstatus : expected " << name
+                   << " to be a valid state,  i.e one of [ queued | complete | unknown | aborted | suspended ]\n";
+                throw std::runtime_error(ss.str());
+            }
+            break;
+        }
+
+        case AlterCmd::CHANGE_ATTR_ND:
+            break;
+        default:
+            break;
+    }
+}
+
+ecf::Flag::Type AlterCmd::get_flag_type(const std::string& flag_type) const {
+    Flag::Type theFlagType = Flag::string_to_flag_type(flag_type);
+    if (theFlagType == Flag::NOT_SET) {
+        std::stringstream ss;
+        ss << "AlterCmd: set/clear_flag: The second argument(" << flag_type << ") must be one of [ ";
+        std::vector<std::string> valid;
+        Flag::valid_flag_type(valid);
+        for (size_t i = 0; i < valid.size(); ++i) {
+            if (i != 0)
+                ss << " | ";
+            ss << valid[i];
+        }
+        ss << "]\n" << AlterCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+    return theFlagType;
+}
+
+void AlterCmd::create_flag(Cmd_ptr& cmd,
+                           const std::vector<std::string>& options,
+                           const std::vector<std::string>& paths,
+                           bool flag) const {
+    // options[0] = set_flag | clear_flag
+    // options[1] = [ force_aborted | user_edit | task_aborted | edit_failed | ecfcmd_failed | no_script | killed |
+    //                late | message | complete | queue_limit | task_waiting | locked | zombie ]
+
+    Flag::Type theFlagType = get_flag_type(options[1]);
+    cmd                    = std::make_shared<AlterCmd>(paths, theFlagType, flag);
+}
+
+void AlterCmd::check_sort_attr_type(const std::string& attr_type) const {
+    ecf::Attr::Type theAttrType = Attr::to_attr(attr_type);
+    if (theAttrType == Attr::UNKNOWN) {
+        std::stringstream ss;
+        ss << "AlterCmd: sort: The second argument must be one of [ ";
+        std::vector<std::string> valid = Attr::all_attrs();
+        for (size_t i = 0; i < valid.size(); ++i) {
+            if (i != 0)
+                ss << " | ";
+            ss << valid[i];
+        }
+        ss << "] but found " << attr_type << "\n" << AlterCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+}
+
+void AlterCmd::create_sort_attributes(Cmd_ptr& cmd,
+                                      const std::vector<std::string>& options,
+                                      const std::vector<std::string>& paths) const {
+    // options[0] - sort
+    // options[1] - [ event | meter | label | limit | variable | all ]
+    // options[2] - recursive
+    std::stringstream ss;
+    if (options.size() < 2) {
+        ss << "AlterCmd: add: At least three arguments expected. Found " << (options.size() + paths.size()) << "\n"
+           << dump_args(options, paths) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    check_sort_attr_type(options[1]);
+    std::string name = options[1];
+
+    std::string value;
+    if (options.size() == 3) {
+        if (options[2] != "recursive") {
+            ss << "AlterCmd: sort: Expected third argument to be 'recursive' but found '" << options[2] << "\n"
+               << AlterCmd::desc();
+            throw std::runtime_error(ss.str());
+        }
+        value = "recursive";
+    }
+
+    cmd = std::make_shared<AlterCmd>(paths, name, value);
+}
+
+AlterCmd::AlterCmd(const std::vector<std::string>& paths,
+                   const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+                   const std::string& attrType,
+                   const std::string& name,
+                   const std::string& value)
+    : paths_(paths),
+      name_(name),
+      value_(value) {
+    if (alterType == "add") {
+
+        add_attr_type_ = get_add_attr_type(attrType);
+        check_for_add(add_attr_type_, name, value);
+        return;
+    }
+    else if (alterType == "change") {
+
+        change_attr_type_ = get_change_attr_type(attrType);
+        check_for_change(change_attr_type_, name, value);
+        return;
+    }
+    else if (alterType == "delete") {
+
+        del_attr_type_ = get_delete_attr_type(attrType);
+        check_for_delete(del_attr_type_, name, value);
+        return;
+    }
+    else if (alterType == "set_flag") {
+
+        flag_type_ = get_flag_type(attrType);
+        flag_      = true;
+        return;
+    }
+    else if (alterType == "clear_flag") {
+
+        flag_type_ = get_flag_type(attrType);
+        return;
+    }
+
+    std::stringstream ss;
+    ss << "AlterCmd constructor: The alterType argument must be one of [ change | delete | add | set_flag | clear_flag "
+          "| sort ] but found '"
+       << alterType << "'\n";
+    throw std::runtime_error(ss.str());
+}
+
+std::ostream& operator<<(std::ostream& os, const AlterCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(AlterCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(AlterCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/AlterCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/AlterCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/AlterCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/AlterCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,253 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_AlterCmd_HPP
+#define ecflow_base_cts_user_AlterCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+#include "ecflow/node/Flag.hpp"
+
+class AlterCmd final : public UserCmd {
+public:
+    enum Delete_attr_type {
+        DEL_VARIABLE,
+        DEL_TIME,
+        DEL_TODAY,
+        DEL_DATE,
+        DEL_DAY,
+        DEL_CRON,
+        DEL_EVENT,
+        DEL_METER,
+        DEL_LABEL,
+        DEL_TRIGGER,
+        DEL_COMPLETE,
+        DEL_REPEAT,
+        DEL_LIMIT,
+        DEL_LIMIT_PATH,
+        DEL_INLIMIT,
+        DEL_ZOMBIE,
+        DELETE_ATTR_ND,
+        DEL_LATE,
+        DEL_QUEUE,
+        DEL_GENERIC,
+        DEL_AVISO,
+        DEL_MIRROR,
+    };
+
+    enum Change_attr_type {
+        VARIABLE,
+        CLOCK_TYPE,
+        CLOCK_DATE,
+        CLOCK_GAIN,
+        EVENT,
+        METER,
+        LABEL,
+        TRIGGER,
+        COMPLETE,
+        REPEAT,
+        LIMIT_MAX,
+        LIMIT_VAL,
+        DEFSTATUS,
+        CHANGE_ATTR_ND,
+        CLOCK_SYNC,
+        LATE,
+        TIME,
+        TODAY,
+        AVISO,
+        MIRROR,
+    };
+
+    enum Add_attr_type {
+        ADD_TIME,
+        ADD_TODAY,
+        ADD_DATE,
+        ADD_DAY,
+        ADD_ZOMBIE,
+        ADD_VARIABLE,
+        ADD_ATTR_ND,
+        ADD_LATE,
+        ADD_LIMIT,
+        ADD_INLIMIT,
+        ADD_LABEL,
+        ADD_AVISO,
+        ADD_MIRROR,
+    };
+
+    // Python
+    AlterCmd(const std::vector<std::string>& paths,
+             const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+             const std::string& attrType,
+             const std::string& name,
+             const std::string& value);
+    // add
+    AlterCmd(const std::string& path, Add_attr_type attr, const std::string& name, const std::string& value = "")
+        : paths_(std::vector<std::string>(1, path)),
+          name_(name),
+          value_(value),
+          add_attr_type_(attr) {}
+    AlterCmd(const std::vector<std::string>& paths,
+             Add_attr_type attr,
+             const std::string& name,
+             const std::string& value = "")
+        : paths_(paths),
+          name_(name),
+          value_(value),
+          add_attr_type_(attr) {}
+    // delete
+    AlterCmd(const std::string& path, Delete_attr_type del, const std::string& name = "", const std::string& value = "")
+        : paths_(std::vector<std::string>(1, path)),
+          name_(name),
+          value_(value),
+          del_attr_type_(del) {}
+    AlterCmd(const std::vector<std::string>& paths,
+             Delete_attr_type del,
+             const std::string& name  = "",
+             const std::string& value = "")
+        : paths_(paths),
+          name_(name),
+          value_(value),
+          del_attr_type_(del) {}
+    // change
+    AlterCmd(const std::string& path, Change_attr_type attr, const std::string& name, const std::string& value = "")
+        : paths_(std::vector<std::string>(1, path)),
+          name_(name),
+          value_(value),
+          change_attr_type_(attr) {}
+    AlterCmd(const std::vector<std::string>& paths,
+             Change_attr_type attr,
+             const std::string& name,
+             const std::string& value = "")
+        : paths_(paths),
+          name_(name),
+          value_(value),
+          change_attr_type_(attr) {}
+    // flag
+    AlterCmd(const std::string& path, ecf::Flag::Type ft, bool flag)
+        : paths_(std::vector<std::string>(1, path)),
+          flag_type_(ft),
+          flag_(flag) {}
+    AlterCmd(const std::vector<std::string>& paths, ecf::Flag::Type ft, bool flag)
+        : paths_(paths),
+          flag_type_(ft),
+          flag_(flag) {}
+    // sort
+    AlterCmd(const std::string& path, const std::string& name, const std::string& value)
+        : paths_(std::vector<std::string>(1, path)),
+          name_(name),
+          value_(value) {}
+    AlterCmd(const std::vector<std::string>& paths, const std::string& name, const std::string& value)
+        : paths_(paths),
+          name_(name),
+          value_(value) {}
+
+    AlterCmd() = default;
+
+    // Uses by equals only
+    const std::vector<std::string>& paths() const { return paths_; }
+    const std::string& name() const { return name_; }
+    const std::string& value() const { return value_; }
+    Delete_attr_type delete_attr_type() const { return del_attr_type_; }
+    Change_attr_type change_attr_type() const { return change_attr_type_; }
+    Add_attr_type add_attr_type() const { return add_attr_type_; }
+    ecf::Flag::Type flag_type() const { return flag_type_; }
+    bool flag() const { return flag_; }
+
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    void print(std::string& os, const std::string& path) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    STC_Cmd_ptr alter_server_state(AbstractServer*) const;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
+
+    void my_print(std::string& os, const std::vector<std::string>& paths) const;
+
+    Add_attr_type get_add_attr_type(const std::string&) const;
+    void createAdd(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const;
+    void extract_name_and_value_for_add(Add_attr_type,
+                                        std::string& name,
+                                        std::string& value,
+                                        std::vector<std::string>& options,
+                                        std::vector<std::string>& paths) const;
+    void check_for_add(Add_attr_type, const std::string& name, const std::string& value) const;
+
+    Delete_attr_type get_delete_attr_type(const std::string&) const;
+    void
+    createDelete(Cmd_ptr& cmd, const std::vector<std::string>& options, const std::vector<std::string>& paths) const;
+    void extract_name_and_value_for_delete(Delete_attr_type,
+                                           std::string& name,
+                                           std::string& value,
+                                           const std::vector<std::string>& options,
+                                           const std::vector<std::string>& paths) const;
+    void check_for_delete(Delete_attr_type, const std::string& name, const std::string& value) const;
+
+    Change_attr_type get_change_attr_type(const std::string&) const;
+    void createChange(Cmd_ptr& cmd, std::vector<std::string>& options, std::vector<std::string>& paths) const;
+    void extract_name_and_value_for_change(Change_attr_type,
+                                           std::string& name,
+                                           std::string& value,
+                                           std::vector<std::string>& options,
+                                           std::vector<std::string>& paths) const;
+    void check_for_change(Change_attr_type, const std::string& name, const std::string& value) const;
+
+    ecf::Flag::Type get_flag_type(const std::string&) const;
+    void create_flag(Cmd_ptr& cmd,
+                     const std::vector<std::string>& options,
+                     const std::vector<std::string>& paths,
+                     bool flag) const;
+
+    void check_sort_attr_type(const std::string&) const;
+    void create_sort_attributes(Cmd_ptr& cmd,
+                                const std::vector<std::string>& options,
+                                const std::vector<std::string>& paths) const;
+
+    void alter_and_attr_type(std::string& alter_type, std::string& attr_type) const;
+
+private:
+    std::vector<std::string> paths_;
+    std::string name_;
+    std::string value_;
+    Add_attr_type add_attr_type_{ADD_ATTR_ND};
+    Delete_attr_type del_attr_type_{DELETE_ATTR_ND};
+    Change_attr_type change_attr_type_{CHANGE_ATTR_ND};
+    ecf::Flag::Type flag_type_{ecf::Flag::NOT_SET};
+    bool flag_{false}; // true means set false means clear
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(paths_),
+           CEREAL_NVP(name_),
+           CEREAL_NVP(value_),
+           CEREAL_NVP(add_attr_type_),
+           CEREAL_NVP(del_attr_type_),
+           CEREAL_NVP(change_attr_type_),
+           CEREAL_NVP(flag_type_),
+           CEREAL_NVP(flag_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const AlterCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(AlterCmd)
+
+#endif /* ecflow_base_cts_user_AlterCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/BeginCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/BeginCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/BeginCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/BeginCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,190 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+BeginCmd::BeginCmd(const std::string& suiteName, bool force) : suiteName_(suiteName), force_(force) {
+    // The begin command actually requires the suite name without the lead '/'
+    // i.e if we provide /suite --> change to suite
+    if (!suiteName_.empty() && suiteName_[0] == '/') {
+        suiteName_.erase(0, 1); // delete first character
+    }
+}
+
+void BeginCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::begin(suiteName_, force_));
+}
+
+void BeginCmd::print_only(std::string& os) const {
+    os += CtsApi::begin(suiteName_, force_);
+}
+
+bool BeginCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<BeginCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (suiteName_ != the_rhs->suiteName())
+        return false;
+    if (force_ != the_rhs->force())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+STC_Cmd_ptr BeginCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().begin_cmd_++;
+    defs_ptr defs = as->defs();
+
+    std::vector<Submittable*> tasks;
+
+    // If no suite name begin all suites, else begin the the specific suite
+    if (suiteName_.empty()) {
+
+        const std::vector<suite_ptr>& suiteVec = defs->suiteVec();
+        size_t theSuiteVecSize                 = suiteVec.size();
+        if (!force_) {
+            for (size_t s = 0; s < theSuiteVecSize; s++) {
+                /// check_suite_can_begin will throw if suite can't begin
+                defs->check_suite_can_begin(suiteVec[s]);
+            }
+        }
+        else {
+            defs->get_all_active_submittables(tasks);
+            as->zombie_ctrl().add_user_zombies(tasks, CtsApi::beginArg());
+
+            defs->reset_begin(); // Force should *only* be used for test
+        }
+
+        defs->beginAll();
+    }
+    else {
+
+        suite_ptr suite = defs->findSuite(suiteName_);
+        if (!suite.get()) {
+            std::stringstream ss;
+            ss << "BeginCmd::doHandleRequest:  Begin failed as suite '" << suiteName_ << "' is not loaded.\n";
+            throw std::runtime_error(ss.str());
+        }
+
+        /// check_suite_can_begin will throw if suite can't begin
+        if (!force_)
+            defs->check_suite_can_begin(suite);
+        else {
+
+            suite->get_all_active_submittables(tasks);
+            as->zombie_ctrl().add_user_zombies(tasks, CtsApi::beginArg());
+
+            suite->reset_begin(); // Force should *only* be used for test
+        }
+
+        defs->beginSuite(suite);
+    }
+
+    // The begin will clear the zombie flag: Hence reset it here.
+    for (auto task : tasks)
+        task->flag().set(ecf::Flag::ZOMBIE);
+
+    // After begin do the first Job submission. This will kick of those
+    // jobs that have no dependencies, or relative time of +00:00
+    return doJobSubmission(as);
+}
+
+const char* BeginCmd::arg() {
+    return CtsApi::beginArg();
+}
+const char* BeginCmd::desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Begin playing the definition in the server.\n"
+           "Expects zero or a single quoted string.\n"
+           "  arg1 = suite-name | Nothing | force\n"
+           "         play the chosen suite, if no arg specified, play all suites, in the definition\n"
+           "         force means reset the begin status on the suites and bypass checks.\n"
+           "         This is only required if suite-name is provide as the first argument\n"
+           "         Using force can cause the creation of zombies\n"
+           "Usage:\n"
+           "--begin                     # will begin all suites\n"
+           "--begin=\"--force\"         # reset and then begin all suites, bypassing any checks. Note: string must be "
+           "quoted\n"
+           "--begin=\"mySuite\"         # begin playing suite of name 'mySuite'\n"
+           "--begin=\"mySuite --force\" # reset and begin playing suite 'mySuite', bypass check";
+}
+
+void BeginCmd::addOption(boost::program_options::options_description& desc) const {
+    // allow options like
+    // client --begin=suitename       // begin <suitename>
+    // client --begin                 // means begin all suites
+    desc.add_options()(BeginCmd::arg(), po::value<string>()->implicit_value(string("")), BeginCmd::desc());
+}
+void BeginCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
+    std::string beginArg = vm[arg()].as<std::string>();
+    Str::removeQuotes(beginArg);
+
+    if (ace->debug()) {
+        cout << "  BeginCmd::create arg = " << beginArg << "\n";
+    }
+
+    std::string suiteName;
+    bool force = false;
+
+    if (!beginArg.empty()) {
+        std::vector<std::string> lineTokens;
+        Str::split(beginArg, lineTokens);
+        if (lineTokens.size() == 1) {
+            if (lineTokens[0] == "--force")
+                force = true;
+            else
+                suiteName = lineTokens[0];
+        }
+        else if (lineTokens.size() == 2) {
+            suiteName = lineTokens[0];
+            if (lineTokens[1] != "--force") {
+                std::stringstream ss;
+                ss << "BeginCmd: Expected second argument to be '--force' but found " << lineTokens[1] << "\n";
+                throw std::runtime_error(ss.str());
+            }
+            force = true;
+        }
+        else {
+            std::stringstream ss;
+            ss << "BeginCmd: Expect zero, one or 2 arguments, but found " << lineTokens.size() << " arguments\n"
+               << BeginCmd::desc() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    if (ace->debug()) {
+        std::cout << "  BeginCmd::create suiteName = " << suiteName << "\n";
+        std::cout << "  BeginCmd::create force = " << force << "\n";
+    }
+
+    cmd = std::make_shared<BeginCmd>(suiteName, force);
+}
+
+std::ostream& operator<<(std::ostream& os, const BeginCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(BeginCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(BeginCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/BeginCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/BeginCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/BeginCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/BeginCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,58 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_BeginCmd_HPP
+#define ecflow_base_cts_user_BeginCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+
+// class Begin:  if suiteName is empty we will begin all suites
+class BeginCmd final : public UserCmd {
+public:
+    explicit BeginCmd(const std::string& suiteName, bool force = false);
+    BeginCmd() = default;
+
+    const std::string& suiteName() const { return suiteName_; }
+    bool force() const { return force_; }
+
+    int timeout() const override { return 80; }
+
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+private:
+    std::string suiteName_;
+    bool force_{false}; // reset begin status on suites & bypass checks, can create zombies, used in test only
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(suiteName_), CEREAL_NVP(force_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const BeginCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(BeginCmd)
+
+#endif /* ecflow_base_cts_user_BeginCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CFileCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CFileCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CFileCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CFileCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,384 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/CFileCmd.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/EcfFile.hpp"
+#include "ecflow/node/Submittable.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+CFileCmd::CFileCmd(const std::string& pathToNode, const std::string& file_type, const std::string& input_max_lines)
+    : pathToNode_(pathToNode),
+      max_lines_(File::MAX_LINES()) {
+    // std::cout << "CFileCmd::CFileCmd the_max_lines " << the_max_lines << "\n";
+
+    if (file_type == "script")
+        file_ = CFileCmd::ECF;
+    else if (file_type == "job")
+        file_ = CFileCmd::JOB;
+    else if (file_type == "jobout")
+        file_ = CFileCmd::JOBOUT;
+    else if (file_type == "manual")
+        file_ = CFileCmd::MANUAL;
+    else if (file_type == "kill")
+        file_ = CFileCmd::KILL;
+    else if (file_type == "stat")
+        file_ = CFileCmd::STAT;
+    else {
+        std::stringstream ss;
+        ss << "CFileCmd::CFileCmd: Unrecognised file type " << file_type
+           << " expected one of [script | job | jobout | manual | kill | stat] \n";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (!input_max_lines.empty()) {
+        try {
+            // Note: max_lines_ if type size_t, hence we cast to int to check for negative numbers
+            auto the_max_lines = ecf::convert_to<int>(input_max_lines);
+            if (the_max_lines <= 0)
+                the_max_lines = File::MAX_LINES();
+            max_lines_ = the_max_lines;
+        }
+        catch (const ecf::bad_conversion&) {
+            std::stringstream ss;
+            ss << "CFileCmd::CFileCmd: The third argument(" << input_max_lines
+               << ") must be convertible to an integer\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+}
+
+std::vector<CFileCmd::File_t> CFileCmd::fileTypesVec() {
+    std::vector<CFileCmd::File_t> vec;
+    vec.reserve(5);
+    vec.push_back(CFileCmd::ECF);
+    vec.push_back(CFileCmd::JOB);
+    vec.push_back(CFileCmd::JOBOUT);
+    vec.push_back(CFileCmd::MANUAL);
+    vec.push_back(CFileCmd::KILL);
+    vec.push_back(CFileCmd::STAT);
+    return vec;
+}
+
+std::string CFileCmd::toString(CFileCmd::File_t ft) {
+    switch (ft) {
+        case CFileCmd::ECF:
+            return "script";
+            break;
+        case CFileCmd::MANUAL:
+            return "manual";
+            break;
+        case CFileCmd::JOB:
+            return "job";
+            break;
+        case CFileCmd::JOBOUT:
+            return "jobout";
+            break;
+        case CFileCmd::KILL:
+            return "kill";
+            break;
+        case CFileCmd::STAT:
+            return "stat";
+            break;
+        default:
+            break;
+    }
+    return "script";
+}
+
+bool CFileCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<CFileCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (file_ != the_rhs->fileType()) {
+        return false;
+    }
+    if (max_lines_ != the_rhs->max_lines()) {
+        return false;
+    }
+    if (pathToNode_ != the_rhs->pathToNode()) {
+        return false;
+    }
+    return UserCmd::equals(rhs);
+}
+
+void CFileCmd::print(std::string& os) const {
+    user_cmd(os,
+             CtsApi::to_string(CtsApi::file(pathToNode_, toString(file_), ecf::convert_to<std::string>(max_lines_))));
+}
+void CFileCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::file(pathToNode_, toString(file_), ecf::convert_to<std::string>(max_lines_)));
+}
+
+STC_Cmd_ptr CFileCmd::doHandleRequest(AbstractServer* as) const {
+    // cout << "CFileCmd::doHandleRequest " << toString(file_) << " =======================================\n";
+    switch (file_) {
+        case CFileCmd::ECF:
+            as->update_stats().file_ecf_++;
+            break;
+        case CFileCmd::MANUAL:
+            as->update_stats().file_manual_++;
+            break;
+        case CFileCmd::JOB:
+            as->update_stats().file_job_++;
+            break;
+        case CFileCmd::JOBOUT:
+            as->update_stats().file_jobout_++;
+            break;
+        case CFileCmd::KILL:
+            as->update_stats().file_cmdout_++;
+            break;
+        case CFileCmd::STAT:
+            as->update_stats().file_cmdout_++;
+            break;
+    }
+
+    node_ptr node = find_node(as->defs().get(), pathToNode_); // will throw if defs not defined, or node not found
+
+    std::string fileContents;
+    Submittable* submittable = node->isSubmittable();
+    if (submittable) {
+
+        switch (file_) {
+            case CFileCmd::ECF: {
+                EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
+                ecf_file.script(fileContents);                    // will throw std::runtime_error for errors
+                break;
+            }
+
+            case CFileCmd::MANUAL: {
+                EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
+                ecf_file.manual(fileContents);                    // will throw std::runtime_error for errors
+                break;
+            }
+
+            case CFileCmd::JOB: {
+                std::string ecf_job_file;
+                submittable->findParentVariableValue(Str::ECF_JOB(), ecf_job_file);
+                if (!File::open(ecf_job_file, fileContents)) {
+                    std::stringstream ss;
+                    ss << "CFileCmd::doHandleRequest: Failed to open the job file('" << ecf_job_file << "') for task "
+                       << pathToNode_ << " (" << strerror(errno) << ")";
+                    throw std::runtime_error(ss.str());
+                }
+                break;
+            }
+
+            case CFileCmd::JOBOUT: {
+
+                // ECF_JOBOUT is either constructed from:
+                // - (generated variable) ECF_HOME/ECF_NAME.ECF_TRYNO (common/default)
+                // - (generated variable) ECF_OUT/ECF_NAME.ECF_TRYNO  (common, user must create any directories)
+                // - (user variable)                                  (if defined try first,user must create any
+                // directories) See: Submittable.cpp: SubGenVariables::update_generated_variables()
+                //
+                // Typically if ECF_OUT is specified, we should only look at that location
+                // however SMS also looked at the alternate location (and RD relied on this ECFLOW-177 )
+
+                // First try user variable, if defined this has priority ECFLOW-999
+                std::stringstream ss;
+                std::string user_jobout;
+                if (submittable->findParentUserVariableValue(Str::ECF_JOBOUT(), user_jobout)) {
+                    if (File::open(user_jobout, fileContents))
+                        break;
+                    ss << "Failed to open user specified job-out(ECF_JOBOUT='" << user_jobout << "') ";
+                }
+
+                const Variable& ecf_jobout_gen_var = submittable->findGenVariable(Str::ECF_JOBOUT());
+                if (!File::open(ecf_jobout_gen_var.theValue(), fileContents)) {
+
+                    // If that fails as a backup, look under ECF_HOME/ECF_NAME.ECF_TRYNO,   ECFLOW-177 preserve old SMS
+                    // behaviour
+                    std::string ecfhome_jobout;
+                    submittable->findParentUserVariableValue(Str::ECF_HOME(), ecfhome_jobout);
+                    ecfhome_jobout += submittable->absNodePath();
+                    ecfhome_jobout += ".";
+                    ecfhome_jobout += submittable->tryNo();
+
+                    if (ecfhome_jobout != ecf_jobout_gen_var.theValue()) {
+                        // Implies ECF_OUT was specified, hence *ALSO* look in ECF_HOME/ECF_NAME.ECF_TRYNO
+                        if (!File::open(ecfhome_jobout, fileContents)) {
+                            ss << "Failed to open the job-out (ECF_JOBOUT=ECF_OUT/ECF_NAME.ECF_TRYNO='"
+                               << ecf_jobout_gen_var.theValue() << "') ";
+                            ss << "*AND* (ECF_JOBOUT=ECF_HOME/ECF_NAME.ECF_TRYNO='" << ecfhome_jobout << "')";
+                            ss << " for task " << pathToNode_ << " (" << strerror(errno) << ")";
+                            throw std::runtime_error(ss.str());
+                        }
+                    }
+                    else {
+                        // ECF_OUT *not* specified implies ECF_JOBOUT = ECF_HOME/ECF_NAME.ECF_TRYNO
+                        ss << "Failed to open the job-out(ECF_JOBOUT=ECF_HOME/ECF_NAME.ECF_TRYNO='"
+                           << ecf_jobout_gen_var.theValue() << "') ";
+                        ss << " for task " << pathToNode_ << " (" << strerror(errno) << ")";
+                        throw std::runtime_error(ss.str());
+                    }
+                }
+
+                break;
+            }
+
+            case CFileCmd::KILL: {
+                std::string ecf_job_file;
+                submittable->findParentVariableValue(Str::ECF_JOB(), ecf_job_file);
+                std::string file = ecf_job_file + ".kill";
+                if (!File::open(file, fileContents)) {
+                    std::stringstream ss;
+                    ss << "CFileCmd::doHandleRequest: Failed to open the kill output file('" << file << "') for task "
+                       << pathToNode_ << " (" << strerror(errno) << ")";
+                    throw std::runtime_error(ss.str());
+                }
+                break;
+            }
+
+            case CFileCmd::STAT: {
+                std::string ecf_job_file;
+                submittable->findParentVariableValue(Str::ECF_JOB(), ecf_job_file);
+                std::string file = ecf_job_file + ".stat";
+                if (!File::open(file, fileContents)) {
+                    std::stringstream ss;
+                    ss << "CFileCmd::doHandleRequest: Failed to open the status output file('" << file << "') for task "
+                       << pathToNode_ << " (" << strerror(errno) << ")";
+                    throw std::runtime_error(ss.str());
+                }
+                break;
+            }
+
+            default:
+                assert(false);
+                break;
+        }
+    }
+    else {
+
+        if (file_ == CFileCmd::MANUAL) {
+            // The only valid option for Suite or Family is Manual
+
+            // First look for .man files in ECF_FILES and then ECF_HOME
+            std::string ecf_files;
+            node->findParentUserVariableValue(Str::ECF_FILES(), ecf_files);
+            if (!ecf_files.empty() && fs::is_directory(ecf_files)) {
+
+                std::string manFile = File::backwardSearch(ecf_files, node->absNodePath(), File::MAN_EXTN());
+                if (!manFile.empty()) {
+                    EcfFile the_file(node.get(), manFile);
+                    the_file.manual(
+                        fileContents); // pre-process & extract manual: will throw std::runtime_error for errors
+                }
+            }
+
+            if (fileContents.empty()) {
+                // Try under ECF_HOME
+                std::string ecf_home;
+                node->findParentUserVariableValue(Str::ECF_HOME(), ecf_home);
+                if (!ecf_home.empty() && fs::is_directory(ecf_home)) {
+
+                    std::string manFile = File::backwardSearch(ecf_home, node->absNodePath(), File::MAN_EXTN());
+                    EcfFile the_file(node.get(), manFile);
+                    the_file.manual(
+                        fileContents); // pre-process & extract manual: will throw std::runtime_error for errors
+                }
+                else {
+                    std::string errorMsg = "Failed to find the manual for Suite/Family  ";
+                    errorMsg += pathToNode_;
+                    errorMsg +=
+                        " ECF_HOME directory does not exist and/or ECF_FILES not defined or directory does not exist.";
+                    throw std::runtime_error(errorMsg);
+                }
+            }
+        }
+        else {
+            std::stringstream ss;
+            ss << "Option " << CFileCmd::toString(file_) << " is only valid for tasks";
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    /// The file could get very large, hence truncate at the start
+    if (Str::truncate_at_start(fileContents, max_lines_)) {
+        std::stringstream ss;
+        ss << "\n# >>>>>>>> File truncated down to " << max_lines_
+           << ". Truncated from the end of the file <<<<<<<<<\n";
+        fileContents += ss.str();
+    }
+
+    return PreAllocatedReply::string_cmd(fileContents);
+}
+
+bool CFileCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, pathToNode_);
+}
+
+const char* CFileCmd::arg() {
+    return CtsApi::fileArg();
+}
+const char* CFileCmd::desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Return the chosen file. Select from [ script<default> | job | jobout | manual | kill | stat ]\n"
+           "By default will return the script.\n"
+           "  arg1 = path to node\n"
+           "  arg2 = (optional) [ script<default> | job | jobout | manual | kill | stat ]\n"
+           "         kill will attempt to return output of ECF_KILL_CMD, i.e the file %ECF_JOB%.kill\n"
+           "         stat will attempt to return output of ECF_STATUS_CMD, i.e the file %ECF_JOB%.stat\n"
+           "  arg3 = (optional) max_lines = 10000 <default>";
+}
+
+void CFileCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(CFileCmd::arg(), po::value<vector<string>>()->multitoken(), CFileCmd::desc());
+}
+void CFileCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(CFileCmd::arg(), args);
+
+    if (args.size() < 1) {
+        std::stringstream ss;
+        ss << "CFileCmd: At least one arguments expected for File. Found " << args.size() << "\n"
+           << CFileCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string pathToNode = args[0];
+
+    std::string file_type = "script";
+    if (args.size() >= 2) {
+        file_type = args[1];
+    }
+
+    std::string max_lines;
+    if (args.size() == 3) {
+        max_lines = args[2];
+    }
+
+    cmd = std::make_shared<CFileCmd>(pathToNode, file_type, max_lines);
+}
+
+std::ostream& operator<<(std::ostream& os, const CFileCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(CFileCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(CFileCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CFileCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CFileCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CFileCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CFileCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,69 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_CFileCmd_HPP
+#define ecflow_base_cts_user_CFileCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+//================================================================================
+// Paired with SStringCmd
+// Client---(CFileCmd)---->Server-----(SStringCmd)--->client:
+//================================================================================
+class CFileCmd final : public UserCmd {
+public:
+    enum File_t { ECF, JOB, JOBOUT, MANUAL, KILL, STAT };
+    CFileCmd(const std::string& pathToNode, File_t file, size_t max_lines)
+        : file_(file),
+          pathToNode_(pathToNode),
+          max_lines_(max_lines) {}
+    CFileCmd(const std::string& pathToNode, const std::string& file_type, const std::string& max_lines);
+    CFileCmd() = default;
+
+    // Uses by equals only
+    const std::string& pathToNode() const { return pathToNode_; }
+    File_t fileType() const { return file_; }
+    size_t max_lines() const { return max_lines_; }
+
+    static std::vector<CFileCmd::File_t> fileTypesVec();
+    static std::string toString(File_t);
+
+    bool handleRequestIsTestable() const override { return false; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+
+    File_t file_{ECF};
+    std::string pathToNode_;
+    size_t max_lines_{0};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(file_), CEREAL_NVP(pathToNode_), CEREAL_NVP(max_lines_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const CFileCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(CFileCmd)
+
+#endif /* ecflow_base_cts_user_CFileCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,234 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/CSyncCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+void CSyncCmd::print(std::string& os) const {
+    /// Note: Be careful how the *debug* output is interpreted, since the:
+    /// client_handle_  > 0  state/modify numbers will be for a set of registered suites,
+    /// client_handle_ == 0  state/modify numbers is global i.e. for all suites.
+    switch (api_) {
+        case CSyncCmd::NEWS:
+            user_cmd(
+                os, CtsApi::to_string(CtsApi::news(client_handle_, client_state_change_no_, client_modify_change_no_)));
+            break;
+        case CSyncCmd::SYNC:
+            user_cmd(
+                os, CtsApi::to_string(CtsApi::sync(client_handle_, client_state_change_no_, client_modify_change_no_)));
+            break;
+        case CSyncCmd::SYNC_FULL:
+            user_cmd(os, CtsApi::sync_full(client_handle_));
+            break;
+        case CSyncCmd::SYNC_CLOCK:
+            user_cmd(os,
+                     CtsApi::to_string(
+                         CtsApi::sync_clock(client_handle_, client_state_change_no_, client_modify_change_no_)));
+            break;
+    }
+}
+
+std::string CSyncCmd::print_short() const {
+    std::string os;
+    print_only(os);
+    return os;
+}
+
+void CSyncCmd::print_only(std::string& os) const {
+    switch (api_) {
+        case CSyncCmd::NEWS:
+            os += CtsApi::to_string(CtsApi::news(client_handle_, client_state_change_no_, client_modify_change_no_));
+            break;
+        case CSyncCmd::SYNC:
+            os += CtsApi::to_string(CtsApi::sync(client_handle_, client_state_change_no_, client_modify_change_no_));
+            break;
+        case CSyncCmd::SYNC_FULL:
+            os += CtsApi::sync_full(client_handle_);
+            break;
+        case CSyncCmd::SYNC_CLOCK:
+            os += CtsApi::to_string(
+                CtsApi::sync_clock(client_handle_, client_state_change_no_, client_modify_change_no_));
+            break;
+    }
+}
+
+bool CSyncCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<CSyncCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (api_ != the_rhs->api())
+        return false;
+    if (client_handle_ != the_rhs->client_handle())
+        return false;
+    if (client_state_change_no_ != the_rhs->client_state_change_no())
+        return false;
+    if (client_modify_change_no_ != the_rhs->client_modify_change_no())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+const char* CSyncCmd::theArg() const {
+    switch (api_) {
+        case CSyncCmd::NEWS:
+            return CtsApi::newsArg();
+        case CSyncCmd::SYNC:
+            return CtsApi::syncArg();
+        case CSyncCmd::SYNC_FULL:
+            return CtsApi::sync_full_arg();
+        case CSyncCmd::SYNC_CLOCK:
+            return CtsApi::sync_clock_arg();
+    }
+    // should never get here:
+    return CtsApi::syncArg();
+}
+
+int CSyncCmd::timeout() const {
+    if (api_ == CSyncCmd::SYNC || api_ == CSyncCmd::SYNC_FULL || api_ == CSyncCmd::SYNC_CLOCK) {
+        return time_out_for_load_sync_and_get();
+    }
+    return 20; // CSyncCmd::NEWS
+}
+
+void CSyncCmd::do_log(AbstractServer* as) const {
+    if (api_ == CSyncCmd::NEWS) {
+
+        /// Log without adding a new line, to the log file
+        /// The SNewsCmd will append additional debug and then add new line
+        std::string ss;
+        print(ss);                           // Populate the stream with command details:
+        if (!log_no_newline(Log::MSG, ss)) { // log command without adding newline
+            // problems with opening or writing to log file, warn users, ECFLOW-536
+            as->defs()->flag().set(ecf::Flag::LOG_ERROR);
+            as->defs()->set_server().add_or_update_user_variables("ECF_LOG_ERROR", Log::instance()->log_error());
+        }
+        return;
+    }
+
+    ClientToServerCmd::do_log(as);
+}
+
+STC_Cmd_ptr CSyncCmd::doHandleRequest(AbstractServer* as) const {
+    // LogTimer timer(" CSyncCmd::doHandleRequest");
+
+    // If no defs not loaded, SSyncCmd and SNewsCmd do nothing. This is a valid state, hence don't error for this
+    // request
+    switch (api_) {
+        case CSyncCmd::NEWS: {
+            as->update_stats().news_++;
+            return PreAllocatedReply::news_cmd(client_handle_, client_state_change_no_, client_modify_change_no_, as);
+        }
+        case CSyncCmd::SYNC: {
+            as->update_stats().sync_++;
+            return PreAllocatedReply::sync_cmd(client_handle_, client_state_change_no_, client_modify_change_no_, as);
+        }
+        case CSyncCmd::SYNC_FULL: {
+            as->update_stats().sync_full_++;
+            return PreAllocatedReply::sync_full_cmd(client_handle_, as);
+        }
+        case CSyncCmd::SYNC_CLOCK: {
+            as->update_stats().sync_clock_++;
+            return PreAllocatedReply::sync_clock_cmd(
+                client_handle_, client_state_change_no_, client_modify_change_no_, as);
+        }
+    }
+
+    // should never get here:
+    return PreAllocatedReply::sync_cmd(client_handle_, client_state_change_no_, client_modify_change_no_, as);
+}
+
+void CSyncCmd::addOption(boost::program_options::options_description& desc) const {
+    if (api_ == CSyncCmd::NEWS) {
+        desc.add_options()(
+            CtsApi::newsArg(),
+            po::value<vector<unsigned int>>()->multitoken(),
+            "Returns true if state of server definition changed.\n"
+            "*Important* for use with c++/python interface only.\n"
+            "Requires Given a client handle, change and modify number determine if server changed since last call\n"
+            "This relies on user calling sync after news to update the locally stored modify and change numbers.\n"
+            "These numbers are then used in the next call to news.");
+        return;
+    }
+
+    if (api_ == CSyncCmd::SYNC) {
+        desc.add_options()(
+            CtsApi::syncArg(),
+            po::value<vector<unsigned int>>()->multitoken(),
+            "Incrementally synchronise the local definition with the one in the server.\n"
+            "*Important* for use with c++/python interface only.\n"
+            "Preference should be given to this method as only the changes are returned.\n"
+            "This reduces the network bandwidth required to keep in sync with the server\n"
+            "Requires a client handle, change and modify number, to get the incremental changes from server.\n"
+            "The change in server state is then and merged with the client definition.");
+        return;
+    }
+
+    if (api_ == CSyncCmd::SYNC_CLOCK) {
+        desc.add_options()(
+            CtsApi::sync_clock_arg(),
+            po::value<vector<unsigned int>>()->multitoken(),
+            "Incrementally synchronise the local definition with the one in the server.\n"
+            "*Important* for use with c++/python interface only.\n"
+            "Same as sync, but will *always* sync with suite clock if it has changed.\n"
+            "Preference should be given to this method as only the changes are returned.\n"
+            "This reduces the network bandwidth required to keep in sync with the server\n"
+            "Requires a client handle, change and modify number, to get the incremental changes from server.\n"
+            "The change in server state is then and merged with the client definition.");
+        return;
+    }
+
+    desc.add_options()(CtsApi::sync_full_arg(),
+                       po::value<unsigned int>(),
+                       "Returns the full definition from the server.\n"
+                       "*Important* for use with c++/python interface only.\n"
+                       "Requires a client_handle. The returned definition is stored on the client.");
+}
+
+void CSyncCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    if (ac->debug())
+        cout << "  CSyncCmd::create api = '" << api_ << "'.\n";
+
+    if (api_ == CSyncCmd::NEWS || api_ == CSyncCmd::SYNC || api_ == CSyncCmd::SYNC_CLOCK) {
+        vector<unsigned int> args = vm[theArg()].as<vector<unsigned int>>();
+        if (args.size() != 3)
+            throw std::runtime_error("CSyncCmd::create(SYNC/SYN_CLOCK/NEWS) expects 3 integer arguments, Client "
+                                     "handle, state change number, and modify change number");
+        unsigned int client_handle    = args[0];
+        unsigned int state_change_no  = args[1];
+        unsigned int modify_change_no = args[2];
+        cmd = std::make_shared<CSyncCmd>(api_, client_handle, state_change_no, modify_change_no);
+        return;
+    }
+
+    unsigned int client_handle = vm[theArg()].as<unsigned int>();
+    cmd                        = std::make_shared<CSyncCmd>(client_handle); // FULL_SYNC
+}
+
+std::ostream& operator<<(std::ostream& os, const CSyncCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(CSyncCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(CSyncCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CSyncCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_CSyncCmd_HPP
+#define ecflow_base_cts_user_CSyncCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// Client---(CSyncCmd::SYNC_FULL)---->Server-----(SSyncCmd)--->client:
+// Client---(CSyncCmd::SYNC)--------->Server-----(SSyncCmd)--->client:
+// Client---(CSyncCmd::SYNC_CLOCK)--->Server-----(SSyncCmd)--->client:
+// Client---(CSyncCmd::NEWS)--------->Server-----(SNewsCmd)--->client:
+class CSyncCmd final : public UserCmd {
+public:
+    enum Api { NEWS, SYNC, SYNC_FULL, SYNC_CLOCK };
+
+    CSyncCmd(Api a,
+             unsigned int client_handle,
+             unsigned int client_state_change_no,
+             unsigned int client_modify_change_no)
+        : api_(a),
+          client_handle_(client_handle),
+          client_state_change_no_(client_state_change_no),
+          client_modify_change_no_(client_modify_change_no) {}
+    explicit CSyncCmd(unsigned int client_handle) : api_(SYNC_FULL), client_handle_(client_handle) {}
+    CSyncCmd() = default;
+
+    Api api() const { return api_; }
+    int client_state_change_no() const { return client_state_change_no_; }
+    int client_modify_change_no() const { return client_modify_change_no_; }
+    int client_handle() const { return client_handle_; }
+
+    void set_client_handle(int client_handle) override { client_handle_ = client_handle; } // used by group_cmd
+    void print(std::string&) const override;
+    std::string print_short() const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+    int timeout() const override;
+
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    /// Custom handling of command logging to add additional debug on same line
+    /// makes it easier to debug errors in syncing.
+    void do_log(AbstractServer*) const override;
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    Api api_{SYNC};
+    int client_handle_{0};
+    int client_state_change_no_{0};
+    int client_modify_change_no_{0};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(api_),
+           CEREAL_NVP(client_handle_),
+           CEREAL_NVP(client_state_change_no_),
+           CEREAL_NVP(client_modify_change_no_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const CSyncCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(CSyncCmd)
+
+#endif /* ecflow_base_cts_user_CSyncCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,235 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/CheckPtCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Converter.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+void CheckPtCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::checkPtDefs(mode_, check_pt_interval_, check_pt_save_time_alarm_));
+}
+void CheckPtCmd::print_only(std::string& os) const {
+    os += CtsApi::checkPtDefs(mode_, check_pt_interval_, check_pt_save_time_alarm_);
+}
+
+bool CheckPtCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<CheckPtCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (mode_ != the_rhs->mode())
+        return false;
+    if (check_pt_interval_ != the_rhs->check_pt_interval())
+        return false;
+    if (check_pt_save_time_alarm_ != the_rhs->check_pt_save_time_alarm())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+bool CheckPtCmd::isWrite() const {
+    if (mode_ != ecf::CheckPt::UNDEFINED)
+        return true;
+    if (check_pt_interval_ != 0)
+        return true;
+    if (check_pt_save_time_alarm_ != 0)
+        return true;
+    return false;
+}
+
+bool CheckPtCmd::is_mutable() const {
+    // if save to takes to long, the the late flag is set. Even when command is read only
+    // Also if writing to checkpoint fails we set: ecf::Flag::CHECKPT_ERROR
+    // Likewise writing to the log file can also fail, hence we set: ecf::Flag::LOG_ERROR, when manually check pointing
+    // Even when command is read only ?
+    // This an exceptional situation!!
+    return true;
+}
+
+const char* CheckPtCmd::theArg() const {
+    return CtsApi::checkPtDefsArg();
+}
+
+STC_Cmd_ptr CheckPtCmd::doHandleRequest(AbstractServer* as) const {
+    // Placed here rather than in server. Since we want to record explicit request to check pt
+    // The update_stats() is used to record the number of requests per second, hence we do not
+    // want to skew this, and hence we ignore implicit request's via signal handling,
+    // or when server terminates( does implicit check pt also)
+    as->update_stats().checkpt_++;
+    if (!as->checkPtDefs(mode_, check_pt_interval_, check_pt_save_time_alarm_)) {
+        throw std::runtime_error("Could not save check point file. file system full or permissions ?");
+    }
+    return PreAllocatedReply::ok_cmd();
+}
+
+static const char* arg_desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+    return "Forces the definition file in the server to be written to disk *or* allow mode,\n"
+           "interval and alarm to be changed.\n"
+           "Whenever the check pt file is written to disk, it is measured.\n"
+           "If the time to save to disk is greater than the default of 30 seconds,\n"
+           "then an alarm is raised. This can be seen in the GUI as a late flag on the server.\n"
+           "Once the late flag has been set it will need to manually cleared in the GUI\n"
+           "or by using --alter functionality\n"
+           "Note excessive save times can interfere with job scheduling.\n"
+           "The alarm threshold can be changed. See below.\n"
+           "   arg1 = (optional) mode [ never | on_time | on_time:<integer> | always | <integer>]\n"
+           "     never     : Never check point the definition in the server\n"
+           "     on_time   : Turn on automatic check pointing at interval stored on server\n"
+           "     on_time<integer> : Turn on automatic check point, with the specified interval in seconds\n"
+           "     alarm<integer>   : Modify the alarm notification time for check pt saving to disk\n"
+           "     always    : Check point at any change in node tree, *NOT* recommended for large definitions\n"
+           "     <integer> : This specifies the interval in seconds when server should automatically check pt.\n"
+           "                 This will only take effect of mode is on_time/CHECK_ON_TIME\n"
+           "                 Should ideally be a value greater than 60 seconds, default is 120 seconds\n"
+           "Usage:\n"
+           "  --check_pt\n"
+           "    Immediately check point the definition held in the server\n"
+           "  --check_pt=never\n"
+           "    Switch off check pointing\n"
+           "  --check_pt=on_time\n"
+           "    Start automatic check pointing at the interval stored in the server\n"
+           "  --check_pt=180\n"
+           "    Change the check pt interval to 180 seconds\n"
+           "  --check_pt=on_time:90\n"
+           "    Change mode and interval, to automatic check pointing every 90 seconds\n"
+           "  --check_pt=alarm:35\n"
+           "    Change the alarm time for check pt saves. i.e if saving the check pt takes longer than 35 seconds\n"
+           "    set the late flag on the server.";
+}
+
+void CheckPtCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(CtsApi::checkPtDefsArg(), po::value<string>()->implicit_value(string("")), arg_desc());
+}
+
+static int parse_check_pt_interval(const std::string& the_arg) {
+    int check_pt_interval = 0;
+    try {
+        check_pt_interval = ecf::convert_to<int>(the_arg);
+    }
+    catch (...) {
+        std::stringstream ss;
+        ss << "check_pt: Illegal argument(" << the_arg
+           << "), expected [ never | on_time | on_time:<integer> | always | <integer>]\n"
+           << arg_desc();
+        throw std::runtime_error(ss.str());
+    }
+    if (check_pt_interval <= 0) {
+        std::stringstream ss;
+        ss << "check_pt: interval(" << check_pt_interval << ") must be greater than zero :\n" << arg_desc();
+        throw std::runtime_error(ss.str());
+    }
+    return check_pt_interval;
+}
+
+static int parse_check_pt_alarm_time(const std::string& the_arg, int colon_pos) {
+    std::string alarm_time = the_arg.substr(colon_pos + 1);
+
+    int check_pt_alarm_time = 0;
+    try {
+        check_pt_alarm_time = ecf::convert_to<int>(alarm_time);
+    }
+    catch (...) {
+        std::stringstream ss;
+        ss << "check_pt: Illegal argument(" << the_arg
+           << "), expected [ never | on_time | on_time:<integer> | alarm::integer> | always | <integer>]\n"
+           << arg_desc();
+        throw std::runtime_error(ss.str());
+    }
+    if (check_pt_alarm_time <= 0) {
+        std::stringstream ss;
+        ss << "check_pt: alarm time(" << check_pt_alarm_time << ") must be greater than zero :\n" << arg_desc();
+        throw std::runtime_error(ss.str());
+    }
+    return check_pt_alarm_time;
+}
+
+void CheckPtCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
+    if (ace->debug())
+        cout << "CheckPtCmd::create\n";
+
+    std::string the_arg = vm[theArg()].as<std::string>();
+
+    if (ace->debug())
+        cout << "  CheckPtCmd::create arg = " << the_arg << "\n";
+
+    ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED;
+    int check_pt_interval        = 0;
+    int check_pt_save_time_alarm = 0;
+
+    if (!the_arg.empty()) {
+        size_t colon_pos = the_arg.find(":");
+        if (colon_pos != std::string::npos) {
+            // could be mode:interval or alarm:integer
+            if (the_arg.find("alarm") != std::string::npos) {
+                check_pt_save_time_alarm = parse_check_pt_alarm_time(the_arg, colon_pos);
+            }
+            else {
+                std::string mode     = the_arg.substr(0, colon_pos);
+                std::string interval = the_arg.substr(colon_pos + 1);
+
+                if (mode == "never")
+                    m = ecf::CheckPt::NEVER;
+                else if (mode == "on_time")
+                    m = ecf::CheckPt::ON_TIME;
+                else if (mode == "always")
+                    m = ecf::CheckPt::ALWAYS;
+                else {
+                    std::stringstream ss;
+                    ss << "check_pt: Illegal argument(" << the_arg
+                       << "), expected [ never | on_time | on_time:<integer> | alarm:<integer> | always | <integer>]\n"
+                       << arg_desc();
+                    throw std::runtime_error(ss.str());
+                }
+                check_pt_interval = parse_check_pt_interval(interval);
+            }
+        }
+        else {
+            if (the_arg == "never")
+                m = ecf::CheckPt::NEVER;
+            else if (the_arg == "on_time")
+                m = ecf::CheckPt::ON_TIME;
+            else if (the_arg == "always")
+                m = ecf::CheckPt::ALWAYS;
+            else {
+                check_pt_interval = parse_check_pt_interval(the_arg);
+            }
+        }
+    }
+
+    // testing client interface
+    if (ace->under_test())
+        return;
+
+    if (ace->debug())
+        cout << "  CheckPtCmd::create mode = " << m << " check_pt_interval = " << check_pt_interval << "\n";
+
+    cmd = std::make_shared<CheckPtCmd>(m, check_pt_interval, check_pt_save_time_alarm);
+}
+
+std::ostream& operator<<(std::ostream& os, const CheckPtCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(CheckPtCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(CheckPtCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CheckPtCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,60 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_CheckPtCmd_HPP
+#define ecflow_base_cts_user_CheckPtCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+#include "ecflow/core/CheckPt.hpp"
+
+class CheckPtCmd final : public UserCmd {
+public:
+    CheckPtCmd(ecf::CheckPt::Mode m, int interval, int checkpt_save_time_alarm)
+        : mode_(m),
+          check_pt_interval_(interval),
+          check_pt_save_time_alarm_(checkpt_save_time_alarm) {}
+    CheckPtCmd() = default;
+
+    ecf::CheckPt::Mode mode() const { return mode_; }
+    int check_pt_interval() const { return check_pt_interval_; }
+    int check_pt_save_time_alarm() const { return check_pt_save_time_alarm_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+    bool isWrite() const override;
+    bool is_mutable() const override;
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+private:
+    ecf::CheckPt::Mode mode_{ecf::CheckPt::UNDEFINED};
+    int check_pt_interval_{0};
+    int check_pt_save_time_alarm_{0};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(mode_),
+           CEREAL_NVP(check_pt_interval_),
+           CEREAL_NVP(check_pt_save_time_alarm_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const CheckPtCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(CheckPtCmd)
+
+#endif /* ecflow_base_cts_user_CheckPtCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,517 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+/// *****************************************************************************
+/// Note: The Client Handle commands, change the server,
+///       However the changes cant really be considered as incremental
+///       Hence for all handle command, we will do a FULL SYNC
+///       Relying on the modify_change_no is to CRUDE, as it affects all handles
+///       Instead we will use a simple flag to indicate that a FULL sync is required
+/// *****************************************************************************
+
+void ClientHandleCmd::print(std::string& os) const {
+    switch (api_) {
+        case ClientHandleCmd::REGISTER:
+            user_cmd(os, CtsApi::to_string(CtsApi::ch_register(client_handle_, auto_add_new_suites_, suites_)));
+            break;
+        case ClientHandleCmd::DROP:
+            user_cmd(os, CtsApi::ch_drop(client_handle_));
+            break;
+        case ClientHandleCmd::DROP_USER: {
+            if (drop_user_.empty())
+                user_cmd(os, CtsApi::ch_drop_user(user()));
+            else
+                user_cmd(os, CtsApi::ch_drop_user(drop_user_));
+            break;
+        }
+        case ClientHandleCmd::ADD:
+            user_cmd(os, CtsApi::to_string(CtsApi::ch_add(client_handle_, suites_)));
+            break;
+        case ClientHandleCmd::REMOVE:
+            user_cmd(os, CtsApi::to_string(CtsApi::ch_remove(client_handle_, suites_)));
+            break;
+        case ClientHandleCmd::AUTO_ADD:
+            user_cmd(os, CtsApi::to_string(CtsApi::ch_auto_add(client_handle_, auto_add_new_suites_)));
+            break;
+        case ClientHandleCmd::SUITES:
+            user_cmd(os, CtsApi::ch_suites());
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+
+void ClientHandleCmd::print_only(std::string& os) const {
+    switch (api_) {
+        case ClientHandleCmd::REGISTER:
+            os += CtsApi::to_string(CtsApi::ch_register(client_handle_, auto_add_new_suites_, suites_));
+            break;
+        case ClientHandleCmd::DROP:
+            os += CtsApi::ch_drop(client_handle_);
+            break;
+        case ClientHandleCmd::DROP_USER: {
+            if (drop_user_.empty())
+                os += CtsApi::ch_drop_user(user());
+            else
+                os += CtsApi::ch_drop_user(drop_user_);
+            break;
+        }
+        case ClientHandleCmd::ADD:
+            os += CtsApi::to_string(CtsApi::ch_add(client_handle_, suites_));
+            break;
+        case ClientHandleCmd::REMOVE:
+            os += CtsApi::to_string(CtsApi::ch_remove(client_handle_, suites_));
+            break;
+        case ClientHandleCmd::AUTO_ADD:
+            os += CtsApi::to_string(CtsApi::ch_auto_add(client_handle_, auto_add_new_suites_));
+            break;
+        case ClientHandleCmd::SUITES:
+            os += CtsApi::ch_suites();
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+
+bool ClientHandleCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<ClientHandleCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (api_ != the_rhs->api())
+        return false;
+    if (drop_user_ != the_rhs->drop_user())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+const char* ClientHandleCmd::theArg() const {
+    switch (api_) {
+        case ClientHandleCmd::REGISTER:
+            return CtsApi::ch_register_arg();
+            break;
+        case ClientHandleCmd::DROP:
+            return CtsApi::ch_drop_arg();
+            break;
+        case ClientHandleCmd::DROP_USER:
+            return CtsApi::ch_drop_user_arg();
+            break;
+        case ClientHandleCmd::ADD:
+            return CtsApi::ch_add_arg();
+            break;
+        case ClientHandleCmd::REMOVE:
+            return CtsApi::ch_remove_arg();
+            break;
+        case ClientHandleCmd::AUTO_ADD:
+            return CtsApi::ch_auto_add_arg();
+            break;
+        case ClientHandleCmd::SUITES:
+            return CtsApi::ch_suites_arg();
+            break;
+    }
+    assert(false);
+    return nullptr;
+}
+
+bool ClientHandleCmd::cmd_updates_defs() const {
+    switch (api_) {
+        case ClientHandleCmd::REGISTER:
+            return true;
+            break;
+        case ClientHandleCmd::DROP:
+            return true;
+            break; // can be expensive for large defs
+        case ClientHandleCmd::DROP_USER:
+            return true;
+            break; // can be expensive for large defs
+        case ClientHandleCmd::ADD:
+            return true;
+            break;
+        case ClientHandleCmd::REMOVE:
+            return true;
+            break;
+        case ClientHandleCmd::AUTO_ADD:
+            return false;
+            break;
+        case ClientHandleCmd::SUITES:
+            return false;
+            break;
+    }
+    assert(false);
+    return false;
+}
+
+STC_Cmd_ptr ClientHandleCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().ch_cmd_++;
+
+    switch (api_) {
+        case ClientHandleCmd::REGISTER: {
+
+            // If existing handle is non zero drop it first
+            if (client_handle_ != 0) {
+                as->defs()->client_suite_mgr().remove_client_suite(client_handle_); // will throw if handle not found
+            }
+
+            unsigned int client_handle =
+                as->defs()->client_suite_mgr().create_client_suite(auto_add_new_suites_, suites_, user());
+            // #ifdef DEBUG
+            //  	   LOG(Log::DBG,as->defs()->client_suite_mgr().dump_max_change_no());
+            // #endif
+
+            // If this command is part of a group command, let the following sync command, know about the new handle
+            // So it return the defs with the right set of suites.
+            if (group_cmd_)
+                group_cmd_->set_client_handle(client_handle);
+
+            // return the handle to the client
+            return PreAllocatedReply::client_handle_cmd(client_handle);
+        }
+
+        case ClientHandleCmd::DROP: {
+            as->defs()->client_suite_mgr().remove_client_suite(client_handle_); // will throw if handle not found
+
+            // If this command is part of a group command, let the following sync command, know about the new handle
+            // So it return the defs with the right set of suites.
+            // If used with following sync, will return *FULL* defs. Can be expensive
+            if (group_cmd_)
+                group_cmd_->set_client_handle(0);
+
+            // return the 0 handle to the client. The client stores the handle locally. Reset to zero.
+            return PreAllocatedReply::client_handle_cmd(0);
+        }
+
+        case ClientHandleCmd::DROP_USER: {
+            // will throw if no users handles dropped
+            if (drop_user_.empty())
+                as->defs()->client_suite_mgr().remove_client_suites(user());
+            else
+                as->defs()->client_suite_mgr().remove_client_suites(drop_user_);
+
+            if (drop_user_.empty() || drop_user_ == user()) {
+
+                // If this command is part of a group command, let the following sync command, know about the new handle
+                // So it return the defs with the right set of suites.
+                // If used with following sync, will return *FULL* defs.
+                if (group_cmd_)
+                    group_cmd_->set_client_handle(0);
+
+                // return the 0 handle to the client. The client stores the handle locally. Reset to zero.
+                return PreAllocatedReply::client_handle_cmd(0);
+            }
+            break;
+        }
+
+        case ClientHandleCmd::ADD: {
+            as->defs()->client_suite_mgr().add_suites(client_handle_, suites_); // will throw if handle not found
+            break;
+        }
+
+        case ClientHandleCmd::REMOVE: {
+            as->defs()->client_suite_mgr().remove_suites(client_handle_, suites_); // will throw if handle not found
+            break;
+        }
+
+        case ClientHandleCmd::AUTO_ADD: {
+            as->defs()->client_suite_mgr().auto_add_new_suites(client_handle_,
+                                                               auto_add_new_suites_); // will throw if handle not found
+            break;
+        }
+
+        case ClientHandleCmd::SUITES: {
+            return PreAllocatedReply::client_handle_suites_cmd(as);
+        }
+
+        default:
+            assert(false);
+            break;
+    }
+    return PreAllocatedReply::ok_cmd();
+}
+
+void ClientHandleCmd::addOption(boost::program_options::options_description& desc) const {
+    switch (api_) {
+        case ClientHandleCmd::REGISTER: {
+            desc.add_options()(
+                CtsApi::ch_register_arg(),
+                po::value<vector<string>>()->multitoken(),
+                "Register interest in a set of suites.\n"
+                "If a definition has lots of suites, but the client. is only interested in a small subset,\n"
+                "Then using this command can reduce network bandwidth and synchronisation will be quicker.\n"
+                "This command will create a client handle, which must be used for any other changes.\n"
+                "The newly created handle can be shown with the --ch_suites command\n"
+                "Deleted suites will stay registered, and must be explicitly removed/dropped.\n"
+                "Note: Suites can be registered before they are loaded into the server\n"
+                "This command affects news() and sync() commands\n"
+                "   arg1 = true | false           # true means add new suites to my list, when they are created\n"
+                "   arg2 = names                  # should be a list of suite names, names not in the definition are "
+                "ignored\n"
+                "Usage:\n"
+                "   --ch_register=true s1 s2 s3   # register interest in suites s1,s2,s3 and any new suites\n"
+                "   --ch_register=false s1 s2 s3  # register interest in suites s1,s2,s3 only\n"
+                "   --ch_register=false           # register handle, suites will be added later on\n"
+                "   --ch_register=1 true s1 s2 s3 # drop handle 1 then register interest in suites s1,s2,s3 and any "
+                "new suites\n"
+                "                                 # The client handle as the first argument is typically used by "
+                "GUI/python"
+                "                                 # When the client handle is no zero, then it is dropped first\n"
+                "To list all suites and handles use --ch_suites");
+            break;
+        }
+
+        case ClientHandleCmd::DROP: {
+            desc.add_options()(CtsApi::ch_drop_arg(),
+                               po::value<int>(),
+                               "Drop/de-register the client handle.\n"
+                               "Un-used handle should be dropped otherwise they will stay, in the server.\n"
+                               "   arg1 = handle(integer)  # The handle must be an integer that is > 0\n"
+                               "Usage:\n"
+                               "   --ch_drop=10            # drop the client handle 10\n"
+                               "An error is returned if the handle had not previously been registered\n"
+                               "The handle stored on the local client is set to zero\n"
+                               "To list all suites and handles use --ch_suites");
+            break;
+        }
+
+        case ClientHandleCmd::DROP_USER: {
+            desc.add_options()(
+                CtsApi::ch_drop_user_arg(),
+                po::value<std::string>()->implicit_value(string("")),
+                "Drop/de-register all handles associated with the given user.\n"
+                "If no user provided will drop for current user. Client must ensure un-used handle are dropped\n"
+                "otherwise they will stay, in the server.\n"
+                "   arg1 = user           # The user to be drooped, if left empty drop current user \n"
+                "Usage:\n"
+                "   --ch_drop_user=ma0    # drop all handles associated with user ma0\n"
+                "   --ch_drop_user        # drop all handles associated with current user\n"
+                "An error is returned if no registered handles\n"
+                "To list all suites and handles use --ch_suites");
+            break;
+        }
+
+        case ClientHandleCmd::ADD: {
+            desc.add_options()(CtsApi::ch_add_arg(),
+                               po::value<vector<string>>()->multitoken(),
+                               "Add a set of suites, to an existing handle.\n"
+                               "   arg1 = handle(integer)  # The handle must be an integer that is > 0\n"
+                               "   arg2 = names            # should be a list of suite names, names not in the "
+                               "definition are ignored\n"
+                               "Usage:\n"
+                               "   --ch_add=10 s2 s3 s4    # add suites s2 s3,s4 to  handle 10\n"
+                               "An error is returned if the handle had not previously been registered\n"
+                               "The handle is created with --ch_register command\n"
+                               "To list all suites and handles use --ch_suites");
+            break;
+        }
+
+        case ClientHandleCmd::REMOVE: {
+            desc.add_options()(CtsApi::ch_remove_arg(),
+                               po::value<vector<string>>()->multitoken(),
+                               "Remove a set of suites, from an existing handle.\n"
+                               "   arg1 = handle(integer)   # The handle must be an integer that is > 0\n"
+                               "   arg2 = names             # should be a list of suite names, names not in the "
+                               "definition are ignored\n"
+                               "Usage:\n"
+                               "   --ch_rem=10 s2 s3 s4     # remove suites s2 s3,s4 from handle 10\n"
+                               "The handle is created with --ch_register command\n"
+                               "To list all suites and handles use --ch_suites");
+            break;
+        }
+
+        case ClientHandleCmd::AUTO_ADD: {
+            desc.add_options()(
+                CtsApi::ch_auto_add_arg(),
+                po::value<vector<string>>()->multitoken(),
+                "Change an existing handle so that new suites can be added automatically.\n"
+                "   arg1 = handle(integer)  # The handle must be an integer that is > 0\n"
+                "   arg2 = true | false     # true means add new suites to my list, when they are created\n"
+                "Usage:\n"
+                " --ch_auto_add=10 true     # modify handle 10 so that new suites, get added automatically to it\n"
+                " --ch_auto_add=10 false    # modify handle 10 so that no new suites are added\n"
+                "The handle is created with --ch_register command\n"
+                "To list all suites and handles use --ch_suites");
+            break;
+        }
+
+        case ClientHandleCmd::SUITES: {
+            desc.add_options()(CtsApi::ch_suites_arg(), "Shows all the client handles, and the suites they reference");
+            break;
+        }
+        default:
+            assert(false);
+            break;
+    }
+}
+
+void ClientHandleCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    if (ac->debug())
+        cout << "  ClientHandleCmd::create api = '" << api_ << "'.\n";
+
+    switch (api_) {
+
+        case ClientHandleCmd::REGISTER: {
+            vector<string> args = vm[theArg()].as<vector<string>>();
+            // args can be empty, otherwise first arg must be integer or bool true or false, subsequent args represent
+            // suite names
+            int client_handle        = 0;
+            bool auto_add_new_suites = false;
+            std::vector<std::string> suite_names;
+            suite_names.reserve(args.size());
+            if (!args.empty()) {
+                int suite_names_index = 1;
+                try {
+                    client_handle = ecf::convert_to<int>(args[0]);
+                    if (args.size() > 1) {
+                        if (args[1] == "true")
+                            auto_add_new_suites = true;
+                        else if (args[1] == "false")
+                            auto_add_new_suites = false;
+                        suite_names_index = 2;
+                    }
+                }
+                catch (...) {
+                    if (args[0] == "true")
+                        auto_add_new_suites = true;
+                    else if (args[0] == "false")
+                        auto_add_new_suites = false;
+                    else
+                        throw std::runtime_error(
+                            "ClientHandleCmd::create: First argument should be integer | true | false. See help");
+                }
+                for (size_t i = suite_names_index; i < args.size(); i++) {
+                    suite_names.push_back(args[i]);
+                }
+            }
+            cmd = std::make_shared<ClientHandleCmd>(client_handle, suite_names, auto_add_new_suites);
+            break;
+        }
+
+        case ClientHandleCmd::DROP: {
+            int client_handle = vm[theArg()].as<int>();
+            if (0 == client_handle)
+                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
+            cmd = std::make_shared<ClientHandleCmd>(client_handle);
+            break;
+        }
+
+        case ClientHandleCmd::DROP_USER: {
+            std::string the_user_to_drop = vm[theArg()].as<std::string>();
+            cmd                          = std::make_shared<ClientHandleCmd>(the_user_to_drop);
+            break;
+        }
+
+        case ClientHandleCmd::ADD: {
+            vector<string> args = vm[theArg()].as<vector<string>>();
+            if (args.size() < 2)
+                throw std::runtime_error(
+                    "To few arguments. First arg should be a integer handle, then a list of suite names. See help");
+            int client_handle = 0;
+            try {
+                client_handle = ecf::convert_to<int>(args[0]);
+            }
+            catch (std::exception&) {
+                throw std::runtime_error("The first argument must be an integer. See help");
+            }
+            if (0 == client_handle)
+                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
+            std::vector<std::string> suite_names;
+            suite_names.reserve(args.size());
+            for (size_t i = 1; i < args.size(); i++) {
+                suite_names.push_back(args[i]);
+            }
+            cmd = std::make_shared<ClientHandleCmd>(client_handle, suite_names, ClientHandleCmd::ADD);
+            break;
+        }
+
+        case ClientHandleCmd::REMOVE: {
+            vector<string> args = vm[theArg()].as<vector<string>>();
+            if (args.size() < 2)
+                throw std::runtime_error(
+                    "To few arguments. First arg should be a integer handle, then a list of suite names. See help");
+            int client_handle = 0;
+            try {
+                client_handle = ecf::convert_to<int>(args[0]);
+            }
+            catch (std::exception&) {
+                throw std::runtime_error("ClientHandleCmd::create: The first argument must be an integer. See help");
+            }
+            if (0 == client_handle)
+                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
+            std::vector<std::string> suite_names;
+            suite_names.reserve(args.size());
+            for (size_t i = 1; i < args.size(); i++) {
+                suite_names.push_back(args[i]);
+            }
+            cmd = std::make_shared<ClientHandleCmd>(client_handle, suite_names, ClientHandleCmd::REMOVE);
+            break;
+        }
+
+        case ClientHandleCmd::AUTO_ADD: {
+            vector<string> args = vm[theArg()].as<vector<string>>();
+            if (args.size() != 2)
+                throw std::runtime_error("Two argument expected. First arg should be a integer handle, second should "
+                                         "be true or false. See help");
+            int client_handle = 0;
+            try {
+                client_handle = ecf::convert_to<int>(args[0]);
+            }
+            catch (std::exception&) {
+                throw std::runtime_error("ClientHandleCmd::create: The first argument must be an integer. See help");
+            }
+            if (0 == client_handle)
+                throw std::runtime_error("ClientHandleCmd::create: handles must have a value > 0");
+            bool auto_add_new_suites = false;
+            if (args[1] == "true")
+                auto_add_new_suites = true;
+            else if (args[1] == "false")
+                auto_add_new_suites = false;
+            else
+                throw std::runtime_error("ClientHandleCmd::create: First argument should be true | false. See help");
+            cmd = std::make_shared<ClientHandleCmd>(client_handle, auto_add_new_suites);
+            break;
+        }
+
+        case ClientHandleCmd::SUITES: {
+            cmd = std::make_shared<ClientHandleCmd>(ClientHandleCmd::SUITES);
+            break;
+        }
+
+        default:
+            assert(false);
+            break;
+    }
+}
+
+std::ostream& operator<<(std::ostream& os, const ClientHandleCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(ClientHandleCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(ClientHandleCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ClientHandleCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_ClientHandleCmd_HPP
+#define ecflow_base_cts_user_ClientHandleCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+class ClientHandleCmd final : public UserCmd {
+public:
+    enum Api { REGISTER, DROP, DROP_USER, ADD, REMOVE, AUTO_ADD, SUITES };
+
+    explicit ClientHandleCmd(Api api = AUTO_ADD) : api_(api) {}
+
+    ClientHandleCmd(int client_handle, const std::vector<std::string>& suites, bool add_add_new_suites)
+        : api_(REGISTER),
+          client_handle_(client_handle),
+          suites_(suites),
+          auto_add_new_suites_(add_add_new_suites) {}
+
+    explicit ClientHandleCmd(int client_handle) : api_(DROP), client_handle_(client_handle) {}
+
+    explicit ClientHandleCmd(const std::string& drop_user) : api_(DROP_USER), drop_user_(drop_user) {}
+
+    ClientHandleCmd(int client_handle, const std::vector<std::string>& suites, Api api)
+        : api_(api), // Must be ADD or REMOVE
+          client_handle_(client_handle),
+          suites_(suites) {}
+
+    ClientHandleCmd(int client_handle, bool add_add_new_suites)
+        : api_(AUTO_ADD),
+          client_handle_(client_handle),
+          auto_add_new_suites_(add_add_new_suites) {}
+
+    Api api() const { return api_; }
+    const std::string& drop_user() const { return drop_user_; }
+
+    bool cmd_updates_defs() const override;
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+    // called in the server
+    void set_group_cmd(const GroupCTSCmd* cmd) override { group_cmd_ = cmd; }
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    Api api_;
+    int client_handle_{0};
+    std::string drop_user_;
+    std::vector<std::string> suites_;
+    bool auto_add_new_suites_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(api_),
+           CEREAL_NVP(client_handle_),
+           CEREAL_NVP(drop_user_),
+           CEREAL_NVP(suites_),
+           CEREAL_NVP(auto_add_new_suites_));
+    }
+
+private:
+    const GroupCTSCmd* group_cmd_ = nullptr; // not persisted only used in server
+};
+
+std::ostream& operator<<(std::ostream& os, const ClientHandleCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(ClientHandleCmd)
+
+#endif /* ecflow_base_cts_user_ClientHandleCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsApi.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsApi.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsApi.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsApi.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1110 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/CtsApi.hpp"
+
+#include <cassert>
+#include <sstream>
+
+#include "ecflow/core/Converter.hpp"
+
+std::string CtsApi::to_string(const std::vector<std::string>& vec) {
+    std::string ret;
+    size_t vec_size = vec.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (vec[i].empty())
+            continue;
+        ret += vec[i];
+        if (i != vec_size - 1)
+            ret += " "; // don't add space at the end
+    }
+    return ret;
+}
+
+std::string CtsApi::server_version() {
+    return std::string("--server_version");
+}
+const char* CtsApi::server_version_arg() {
+    return "server_version";
+}
+
+std::string CtsApi::get(const std::string& absNodePath) {
+    std::string ret = "--get";
+    if (!absNodePath.empty()) {
+        ret += "=";
+        ret += absNodePath;
+    }
+    return ret;
+}
+const char* CtsApi::getArg() {
+    return "get";
+}
+
+std::string CtsApi::get_state(const std::string& absNodePath) {
+    std::string ret = "--get_state";
+    if (!absNodePath.empty()) {
+        ret += "=";
+        ret += absNodePath;
+    }
+    return ret;
+}
+const char* CtsApi::get_state_arg() {
+    return "get_state";
+}
+
+std::string CtsApi::migrate(const std::string& absNodePath) {
+    std::string ret = "--migrate";
+    if (!absNodePath.empty()) {
+        ret += "=";
+        ret += absNodePath;
+    }
+    return ret;
+}
+const char* CtsApi::migrate_arg() {
+    return "migrate";
+}
+
+std::string CtsApi::stats() {
+    return "--stats";
+}
+const char* CtsApi::statsArg() {
+    return "stats";
+}
+std::string CtsApi::stats_server() {
+    return "--stats_server";
+}
+const char* CtsApi::stats_server_arg() {
+    return "stats_server";
+}
+std::string CtsApi::stats_reset() {
+    return "--stats_reset";
+}
+const char* CtsApi::stats_reset_arg() {
+    return "stats_reset";
+}
+
+std::string CtsApi::suites() {
+    return "--suites";
+}
+const char* CtsApi::suitesArg() {
+    return "suites";
+}
+
+std::vector<std::string>
+CtsApi::ch_register(int client_handle, bool auto_add_new_suites, const std::vector<std::string>& suites) {
+    std::vector<std::string> retVec;
+    retVec.reserve(suites.size() + 1);
+    std::string ret = "--ch_register=";
+    if (client_handle != 0) {
+        ret += ecf::convert_to<std::string>(client_handle);
+        retVec.push_back(ret);
+        if (auto_add_new_suites)
+            retVec.emplace_back("true");
+        else
+            retVec.emplace_back("false");
+    }
+    else {
+        if (auto_add_new_suites)
+            ret += "true";
+        else
+            ret += "false";
+        retVec.push_back(ret);
+    }
+    for (const auto& suite : suites) {
+        retVec.push_back(suite);
+    }
+    return retVec;
+}
+const char* CtsApi::ch_register_arg() {
+    return "ch_register";
+}
+
+std::string CtsApi::ch_suites() {
+    return "--ch_suites";
+}
+const char* CtsApi::ch_suites_arg() {
+    return "ch_suites";
+}
+
+std::string CtsApi::ch_drop(int client_handle) {
+    std::string ret = "--ch_drop=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    return ret;
+}
+const char* CtsApi::ch_drop_arg() {
+    return "ch_drop";
+}
+
+std::string CtsApi::ch_drop_user(const std::string& user) {
+    std::string ret = "--ch_drop_user";
+    if (!user.empty()) {
+        ret += "=";
+        ret += user;
+    }
+    return ret;
+}
+const char* CtsApi::ch_drop_user_arg() {
+    return "ch_drop_user";
+}
+
+std::vector<std::string> CtsApi::ch_add(int client_handle, const std::vector<std::string>& suites) {
+    std::vector<std::string> retVec;
+    retVec.reserve(suites.size() + 1);
+    std::string ret = "--ch_add=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    retVec.push_back(ret);
+    for (const auto& suite : suites) {
+        retVec.push_back(suite);
+    }
+    return retVec;
+}
+const char* CtsApi::ch_add_arg() {
+    return "ch_add";
+}
+
+std::vector<std::string> CtsApi::ch_remove(int client_handle, const std::vector<std::string>& suites) {
+    std::vector<std::string> retVec;
+    retVec.reserve(suites.size() + 1);
+    std::string ret = "--ch_rem=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    retVec.push_back(ret);
+    for (const auto& suite : suites) {
+        retVec.push_back(suite);
+    }
+    return retVec;
+}
+const char* CtsApi::ch_remove_arg() {
+    return "ch_rem";
+}
+
+std::vector<std::string> CtsApi::ch_auto_add(int client_handle, bool auto_add_new_suites) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+    std::string ret = "--ch_auto_add=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    retVec.push_back(ret);
+    if (auto_add_new_suites)
+        retVec.emplace_back("true");
+    else
+        retVec.emplace_back("false");
+    return retVec;
+}
+const char* CtsApi::ch_auto_add_arg() {
+    return "ch_auto_add";
+}
+
+std::vector<std::string>
+CtsApi::sync(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no) {
+    std::vector<std::string> retVec;
+    retVec.reserve(3);
+    std::string ret = "--sync=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    retVec.push_back(ret);
+    retVec.push_back(ecf::convert_to<std::string>(state_change_no));
+    retVec.push_back(ecf::convert_to<std::string>(modify_change_no));
+    return retVec;
+}
+const char* CtsApi::syncArg() {
+    return "sync";
+}
+
+std::vector<std::string>
+CtsApi::sync_clock(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no) {
+    std::vector<std::string> retVec;
+    retVec.reserve(3);
+    std::string ret = "--sync_clock=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    retVec.push_back(ret);
+    retVec.push_back(ecf::convert_to<std::string>(state_change_no));
+    retVec.push_back(ecf::convert_to<std::string>(modify_change_no));
+    return retVec;
+}
+const char* CtsApi::sync_clock_arg() {
+    return "sync_clock";
+}
+
+std::string CtsApi::sync_full(unsigned int client_handle) {
+    std::string ret = "--sync_full=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    return ret;
+}
+const char* CtsApi::sync_full_arg() {
+    return "sync_full";
+}
+
+std::vector<std::string>
+CtsApi::news(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no) {
+    std::vector<std::string> retVec;
+    retVec.reserve(3);
+    std::string ret = "--news=";
+    ret += ecf::convert_to<std::string>(client_handle);
+    retVec.push_back(ret);
+    retVec.push_back(ecf::convert_to<std::string>(state_change_no));
+    retVec.push_back(ecf::convert_to<std::string>(modify_change_no));
+    return retVec;
+}
+const char* CtsApi::newsArg() {
+    return "news";
+}
+
+std::vector<std::string> CtsApi::loadDefs(const std::string& filePath, bool force, bool check_only, bool print) {
+
+    std::string ret = "--load=";
+    ret += filePath;
+
+    std::vector<std::string> retVec;
+    retVec.reserve(3);
+    retVec.push_back(ret);
+    if (force)
+        retVec.emplace_back("force");
+    if (check_only)
+        retVec.emplace_back("check_only");
+    if (print)
+        retVec.emplace_back("print");
+    return retVec;
+}
+const char* CtsApi::loadDefsArg() {
+    return "load";
+}
+
+std::string CtsApi::restartServer() {
+    return "--restart";
+}
+const char* CtsApi::restartServerArg() {
+    return "restart";
+}
+
+std::string CtsApi::haltServer(bool auto_confirm) {
+    return (auto_confirm) ? "--halt=yes" : "--halt";
+}
+const char* CtsApi::haltServerArg() {
+    return "halt";
+}
+
+std::string CtsApi::shutdownServer(bool auto_confirm) {
+    return (auto_confirm) ? "--shutdown=yes" : "--shutdown";
+}
+const char* CtsApi::shutdownServerArg() {
+    return "shutdown";
+}
+
+std::string CtsApi::terminateServer(bool auto_confirm) {
+    return (auto_confirm) ? "--terminate=yes" : "--terminate";
+}
+const char* CtsApi::terminateServerArg() {
+    return "terminate";
+}
+
+std::string CtsApi::pingServer() {
+    return "--ping";
+}
+const char* CtsApi::pingServerArg() {
+    return "ping";
+}
+
+std::string CtsApi::server_load(const std::string& path_to_log_file) {
+    std::string ret = "--server_load";
+    if (!path_to_log_file.empty()) {
+        ret += "=";
+        ret += path_to_log_file;
+    }
+    return ret;
+}
+const char* CtsApi::server_load_arg() {
+    return "server_load";
+}
+
+std::string CtsApi::debug_server_on() {
+    return "--debug_server_on";
+}
+const char* CtsApi::debug_server_on_arg() {
+    return "debug_server_on";
+}
+std::string CtsApi::debug_server_off() {
+    return "--debug_server_off";
+}
+const char* CtsApi::debug_server_off_arg() {
+    return "debug_server_off";
+}
+
+std::string CtsApi::begin(const std::string& suiteName, bool force) {
+
+    // *both* are optional
+    std::string ret = "--begin";
+    if (suiteName.empty() && !force) {
+        return ret;
+    }
+    if (!suiteName.empty()) {
+        ret += "=";
+        ret += suiteName;
+    }
+    if (force) {
+        if (suiteName.empty()) {
+            ret += "=--force";
+        }
+        else {
+            ret += " --force"; // note the space separator
+        }
+    }
+    return ret;
+}
+const char* CtsApi::beginArg() {
+    return "begin";
+}
+
+std::string CtsApi::checkJobGenOnly(const std::string& absNodePath) {
+    std::string ret = "--checkJobGenOnly";
+    if (!absNodePath.empty()) {
+        ret += "=";
+        ret += absNodePath;
+    }
+    return ret;
+}
+const char* CtsApi::checkJobGenOnlyArg() {
+    return "checkJobGenOnly";
+}
+
+std::string CtsApi::job_gen(const std::string& absNodePath) {
+    std::string ret = "--job_gen";
+    if (!absNodePath.empty()) {
+        ret += "=";
+        ret += absNodePath;
+    }
+    return ret;
+}
+const char* CtsApi::job_genArg() {
+    return "job_gen";
+}
+
+std::vector<std::string> CtsApi::check(const std::vector<std::string>& paths) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2 + paths.size());
+    retVec.emplace_back("--check");
+    if (paths.empty())
+        retVec.emplace_back("_all_");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::check(const std::string& path) {
+    if (path.empty()) {
+        return CtsApi::check(std::vector<std::string>());
+    }
+    return CtsApi::check(std::vector<std::string>(1, path));
+}
+const char* CtsApi::check_arg() {
+    return "check";
+}
+
+std::vector<std::string> CtsApi::delete_node(const std::vector<std::string>& paths, bool force, bool auto_confirm) {
+    std::vector<std::string> retVec;
+    retVec.reserve(4 + paths.size());
+    retVec.emplace_back("--delete");
+    if (paths.empty()) {
+        retVec.emplace_back("_all_");
+    }
+    if (force) {
+        retVec.emplace_back("force");
+    }
+    if (auto_confirm) {             // By default delete prompts
+        retVec.emplace_back("yes"); // yes means we don't prompt, and have automatically confirmed the delete
+    }
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::delete_node(const std::string& absNodePath, bool force, bool auto_confirm) {
+    if (absNodePath.empty())
+        return CtsApi::delete_node(std::vector<std::string>(), force, auto_confirm);
+    return CtsApi::delete_node(std::vector<std::string>(1, absNodePath), force, auto_confirm);
+}
+const char* CtsApi::delete_node_arg() {
+    return "delete";
+}
+
+std::vector<std::string> CtsApi::suspend(const std::vector<std::string>& paths) {
+    std::vector<std::string> retVec;
+    retVec.reserve(1 + paths.size());
+    retVec.emplace_back("--suspend");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::suspend(const std::string& path) {
+    return CtsApi::suspend(std::vector<std::string>(1, path));
+}
+const char* CtsApi::suspend_arg() {
+    return "suspend";
+}
+
+std::vector<std::string> CtsApi::resume(const std::vector<std::string>& paths) {
+    std::vector<std::string> retVec;
+    retVec.reserve(1 + paths.size());
+    retVec.emplace_back("--resume");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::resume(const std::string& path) {
+    return CtsApi::resume(std::vector<std::string>(1, path));
+}
+const char* CtsApi::resume_arg() {
+    return "resume";
+}
+
+std::vector<std::string> CtsApi::kill(const std::vector<std::string>& paths) {
+    std::vector<std::string> retVec;
+    retVec.reserve(1 + paths.size());
+    retVec.emplace_back("--kill");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::kill(const std::string& path) {
+    return CtsApi::kill(std::vector<std::string>(1, path));
+}
+const char* CtsApi::kill_arg() {
+    return "kill";
+}
+
+std::vector<std::string> CtsApi::status(const std::vector<std::string>& paths) {
+    std::vector<std::string> retVec;
+    retVec.reserve(1 + paths.size());
+    retVec.emplace_back("--status");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::status(const std::string& path) {
+    return CtsApi::status(std::vector<std::string>(1, path));
+}
+const char* CtsApi::statusArg() {
+    return "status";
+}
+
+std::vector<std::string> CtsApi::edit_history(const std::vector<std::string>& paths) {
+    std::vector<std::string> retVec;
+    retVec.reserve(1 + paths.size());
+    retVec.emplace_back("--edit_history");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::edit_history(const std::string& path) {
+    return CtsApi::edit_history(std::vector<std::string>(1, path));
+}
+const char* CtsApi::edit_history_arg() {
+    return "edit_history";
+}
+
+std::vector<std::string> CtsApi::archive(const std::vector<std::string>& paths, bool force) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2 + paths.size());
+    retVec.emplace_back("--archive");
+    if (force)
+        retVec.emplace_back("force");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::archive(const std::string& path, bool force) {
+    return CtsApi::archive(std::vector<std::string>(1, path), force);
+}
+const char* CtsApi::archive_arg() {
+    return "archive";
+}
+
+std::vector<std::string> CtsApi::restore(const std::vector<std::string>& paths) {
+    std::vector<std::string> retVec;
+    retVec.reserve(1 + paths.size());
+    retVec.emplace_back("--restore");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::restore(const std::string& path) {
+    return CtsApi::restore(std::vector<std::string>(1, path));
+}
+const char* CtsApi::restore_arg() {
+    return "restore";
+}
+
+std::string CtsApi::why(const std::string& absNodePath) {
+    if (absNodePath.empty())
+        return "--why";
+    std::string ret = "--why=";
+    ret += absNodePath;
+    return ret;
+}
+const char* CtsApi::whyArg() {
+    return "why";
+}
+
+std::string CtsApi::zombieGet() {
+    return "--zombie_get";
+}
+const char* CtsApi::zombieGetArg() {
+    return "zombie_get";
+}
+
+std::vector<std::string>
+CtsApi::zombieFob(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
+    std::string ret = "--zombie_fob=";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 3);
+    if (!paths.empty())
+        ret += paths[0];
+    retVec.push_back(ret);
+    for (size_t i = 1; i < paths.size(); i++)
+        retVec.push_back(paths[i]);
+    if (!process_id.empty())
+        retVec.push_back(process_id); // Note: order is important, even if empty
+    if (!password.empty())
+        retVec.push_back(password); // Note: order is important, even if empty
+    return retVec;
+}
+std::string CtsApi::zombieFobCli(const std::string& path) {
+    std::string ret = "--zombie_fob=";
+    ret += path;
+    return ret;
+}
+std::vector<std::string> CtsApi::zombieFobCli(const std::vector<std::string>& paths) {
+    std::string ret = "--zombie_fob";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 1);
+    retVec.push_back(ret);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+const char* CtsApi::zombieFobArg() {
+    return "zombie_fob";
+}
+
+std::vector<std::string>
+CtsApi::zombieFail(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
+    std::string ret = "--zombie_fail=";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 3);
+    if (!paths.empty())
+        ret += paths[0];
+    retVec.push_back(ret);
+    for (size_t i = 1; i < paths.size(); i++)
+        retVec.push_back(paths[i]);
+    if (!process_id.empty())
+        retVec.push_back(process_id); // Note: order is important, even if empty
+    return retVec;
+}
+std::string CtsApi::zombieFailCli(const std::string& path) {
+    std::string ret = "--zombie_fail=";
+    ret += path;
+    return ret;
+}
+std::vector<std::string> CtsApi::zombieFailCli(const std::vector<std::string>& paths) {
+    std::string ret = "--zombie_fail";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 1);
+    retVec.push_back(ret);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+const char* CtsApi::zombieFailArg() {
+    return "zombie_fail";
+}
+
+std::vector<std::string>
+CtsApi::zombieAdopt(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
+    std::string ret = "--zombie_adopt=";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 3);
+    if (!paths.empty())
+        ret += paths[0];
+    retVec.push_back(ret);
+    for (size_t i = 1; i < paths.size(); i++)
+        retVec.push_back(paths[i]);
+    if (!process_id.empty())
+        retVec.push_back(process_id); // Note: order is important, even if empty
+    if (!password.empty())
+        retVec.push_back(password); // Note: order is important, even if empty
+    return retVec;
+}
+std::string CtsApi::zombieAdoptCli(const std::string& path) {
+    std::string ret = "--zombie_adopt=";
+    ret += path;
+    return ret;
+}
+std::vector<std::string> CtsApi::zombieAdoptCli(const std::vector<std::string>& paths) {
+    std::string ret = "--zombie_adopt";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 1);
+    retVec.push_back(ret);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+const char* CtsApi::zombieAdoptArg() {
+    return "zombie_adopt";
+}
+
+std::vector<std::string> CtsApi::zombieRemove(const std::vector<std::string>& paths,
+                                              const std::string& process_id,
+                                              const std::string& password) {
+    std::string ret = "--zombie_remove=";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 3);
+    if (!paths.empty())
+        ret += paths[0];
+    retVec.push_back(ret);
+    for (size_t i = 1; i < paths.size(); i++)
+        retVec.push_back(paths[i]);
+    if (!process_id.empty())
+        retVec.push_back(process_id); // Note: order is important, even if empty
+    if (!password.empty())
+        retVec.push_back(password); // Note: order is important, even if empty
+    return retVec;
+}
+std::string CtsApi::zombieRemoveCli(const std::string& path) {
+    std::string ret = "--zombie_remove=";
+    ret += path;
+    return ret;
+}
+std::vector<std::string> CtsApi::zombieRemoveCli(const std::vector<std::string>& paths) {
+    std::string ret = "--zombie_remove";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 1);
+    retVec.push_back(ret);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+const char* CtsApi::zombieRemoveArg() {
+    return "zombie_remove";
+}
+
+std::vector<std::string>
+CtsApi::zombieBlock(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
+    std::string ret = "--zombie_block=";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 3);
+    if (!paths.empty())
+        ret += paths[0];
+    retVec.push_back(ret);
+    for (size_t i = 1; i < paths.size(); i++)
+        retVec.push_back(paths[i]);
+    if (!process_id.empty())
+        retVec.push_back(process_id); // Note: order is important, even if empty
+    if (!password.empty())
+        retVec.push_back(password); // Note: order is important, even if empty
+    return retVec;
+}
+std::string CtsApi::zombieBlockCli(const std::string& path) {
+    std::string ret = "--zombie_block=";
+    ret += path;
+    return ret;
+}
+std::vector<std::string> CtsApi::zombieBlockCli(const std::vector<std::string>& paths) {
+    std::string ret = "--zombie_block";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 1);
+    retVec.push_back(ret);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+const char* CtsApi::zombieBlockArg() {
+    return "zombie_block";
+}
+
+std::vector<std::string>
+CtsApi::zombieKill(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password) {
+    std::string ret = "--zombie_kill=";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 3);
+    if (!paths.empty())
+        ret += paths[0];
+    retVec.push_back(ret);
+    for (size_t i = 1; i < paths.size(); i++)
+        retVec.push_back(paths[i]);
+    if (!process_id.empty())
+        retVec.push_back(process_id); // Note: order is important, even if empty
+    if (!password.empty())
+        retVec.push_back(password); // Note: order is important, even if empty
+    return retVec;
+}
+std::string CtsApi::zombieKillCli(const std::string& path) {
+    std::string ret = "--zombie_kill=";
+    ret += path;
+    return ret;
+}
+std::vector<std::string> CtsApi::zombieKillCli(const std::vector<std::string>& paths) {
+    std::string ret = "--zombie_kill";
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 1);
+    retVec.push_back(ret);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+const char* CtsApi::zombieKillArg() {
+    return "zombie_kill";
+}
+
+std::vector<std::string> CtsApi::requeue(const std::vector<std::string>& paths, const std::string& option) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2 + paths.size());
+    retVec.emplace_back("--requeue");
+    if (!option.empty())
+        retVec.push_back(option);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::requeue(const std::string& absNodePath, const std::string& option) {
+    return CtsApi::requeue(std::vector<std::string>(1, absNodePath), option);
+}
+const char* CtsApi::requeueArg() {
+    return "requeue";
+}
+
+std::vector<std::string> CtsApi::run(const std::vector<std::string>& paths, bool force) {
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 2);
+    retVec.emplace_back("--run");
+    if (force)
+        retVec.emplace_back("force");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::run(const std::string& absNodePath, bool force) {
+    return CtsApi::run(std::vector<std::string>(1, absNodePath), force);
+}
+const char* CtsApi::runArg() {
+    return "run";
+}
+
+std::vector<std::string> CtsApi::order(const std::string& absNodePath, const std::string& orderType) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+    std::string ret = "--order=";
+    ret += absNodePath;
+    retVec.push_back(ret);
+    retVec.push_back(orderType);
+    return retVec;
+}
+const char* CtsApi::orderArg() {
+    return "order";
+}
+
+std::vector<std::string> CtsApi::replace(const std::string& absNodePath,
+                                         const std::string& path_to_client_defs,
+                                         bool create_parents_as_required,
+                                         bool force) {
+    std::vector<std::string> retVec;
+    retVec.reserve(3);
+
+    std::string ret = "--replace=";
+    ret += absNodePath;
+    retVec.push_back(ret);
+    retVec.push_back(path_to_client_defs);
+    if (create_parents_as_required)
+        retVec.emplace_back("parent");
+    if (force)
+        retVec.emplace_back("force");
+
+    return retVec;
+}
+const char* CtsApi::replace_arg() {
+    return "replace";
+}
+
+std::string CtsApi::checkPtDefs(ecf::CheckPt::Mode m, int check_pt_interval, int check_pt_save_time_alarm) {
+    std::string ret = "--check_pt";
+    if (m != ecf::CheckPt::UNDEFINED || check_pt_interval != 0 || check_pt_save_time_alarm != 0)
+        ret += "=";
+
+    switch (m) {
+        case ecf::CheckPt::NEVER:
+            ret += "never";
+            break;
+        case ecf::CheckPt::ON_TIME:
+            ret += "on_time";
+            break;
+        case ecf::CheckPt::ALWAYS:
+            ret += "always";
+            break;
+        case ecf::CheckPt::UNDEFINED:
+            break; // leave empty
+        default:
+            assert(false);
+            break;
+    }
+
+    if (check_pt_interval != 0) {
+        if (m != ecf::CheckPt::UNDEFINED)
+            ret += ":";
+        ret += ecf::convert_to<std::string>(check_pt_interval);
+    }
+    else {
+        if (m == ecf::CheckPt::UNDEFINED && check_pt_save_time_alarm != 0) {
+            ret += "alarm:";
+            ret += ecf::convert_to<std::string>(check_pt_save_time_alarm);
+        }
+    }
+    return ret;
+}
+const char* CtsApi::checkPtDefsArg() {
+    return "check_pt";
+}
+
+std::string CtsApi::restoreDefsFromCheckPt() {
+    return "--restore_from_checkpt";
+}
+const char* CtsApi::restoreDefsFromCheckPtArg() {
+    return "restore_from_checkpt";
+}
+
+std::string CtsApi::logMsg(const std::string& theMsgToLog) {
+    std::string ret = "--msg=";
+    ret += theMsgToLog;
+    return ret;
+}
+const char* CtsApi::logMsgArg() {
+    return "msg";
+}
+
+std::vector<std::string> CtsApi::force(const std::vector<std::string>& paths,
+                                       const std::string& state_or_event,
+                                       bool recursive,
+                                       bool set_repeats_to_last_value) {
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 3);
+
+    std::string ret = "--force=";
+    ret += state_or_event;
+    retVec.push_back(ret);
+    if (recursive)
+        retVec.emplace_back("recursive");
+    if (set_repeats_to_last_value)
+        retVec.emplace_back("full");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+
+std::vector<std::string> CtsApi::force(const std::string& path,
+                                       const std::string& state_or_event,
+                                       bool recursive,
+                                       bool set_repeats_to_last_value) {
+    return CtsApi::force(std::vector<std::string>(1, path), state_or_event, recursive, set_repeats_to_last_value);
+}
+const char* CtsApi::forceArg() {
+    return "force";
+}
+
+std::vector<std::string>
+CtsApi::freeDep(const std::vector<std::string>& paths, bool trigger, bool all, bool date, bool time) {
+
+    std::vector<std::string> retVec;
+    retVec.reserve(paths.size() + 4);
+
+    retVec.emplace_back("--free-dep");
+    if (all)
+        retVec.emplace_back("all");
+    else {
+        if (trigger)
+            retVec.emplace_back("trigger");
+        if (date)
+            retVec.emplace_back("date");
+        if (time)
+            retVec.emplace_back("time");
+    }
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::freeDep(const std::string& path, bool trigger, bool all, bool date, bool time) {
+
+    return CtsApi::freeDep(std::vector<std::string>(1, path), trigger, all, date, time);
+}
+const char* CtsApi::freeDepArg() {
+    return "free-dep";
+}
+
+std::vector<std::string>
+CtsApi::file(const std::string& absNodePath, const std::string& fileType, const std::string& max_lines) {
+    std::vector<std::string> retVec;
+    retVec.reserve(3);
+    std::string ret = "--file=";
+    ret += absNodePath;
+    retVec.push_back(ret);
+    retVec.push_back(fileType);
+    retVec.push_back(max_lines);
+    return retVec;
+}
+const char* CtsApi::fileArg() {
+    return "file";
+}
+
+std::vector<std::string> CtsApi::plug(const std::string& sourcePath, const std::string& destPath) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+
+    std::string ret = "--plug=";
+    ret += sourcePath;
+    retVec.push_back(ret);
+    retVec.push_back(destPath);
+
+    return retVec;
+}
+const char* CtsApi::plugArg() {
+    return "plug";
+}
+
+std::vector<std::string> CtsApi::alter(const std::vector<std::string>& paths,
+                                       const std::string& alterType,
+                                       const std::string& attrType,
+                                       const std::string& name,
+                                       const std::string& value) {
+    std::vector<std::string> retVec;
+    retVec.reserve(5 + paths.size());
+
+    retVec.emplace_back("--alter");
+    retVec.push_back(alterType);
+    retVec.push_back(attrType);
+    if (!name.empty())
+        retVec.push_back(name);
+    if (!value.empty())
+        retVec.push_back(value);
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+std::vector<std::string> CtsApi::alter(const std::string& path,
+                                       const std::string& alterType,
+                                       const std::string& attrType,
+                                       const std::string& name,
+                                       const std::string& value) {
+    return CtsApi::alter(std::vector<std::string>(1, path), alterType, attrType, name, value);
+}
+
+std::vector<std::string>
+CtsApi::alter_sort(const std::vector<std::string>& paths, const std::string& sortable_attribute_name, bool recursive) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2 + paths.size());
+
+    retVec.emplace_back("--alter");
+    retVec.emplace_back("sort");
+    retVec.push_back(sortable_attribute_name);
+    if (recursive)
+        retVec.emplace_back("recursive");
+    std::copy(paths.begin(), paths.end(), std::back_inserter(retVec));
+    return retVec;
+}
+const char* CtsApi::alterArg() {
+    return "alter";
+}
+
+std::string CtsApi::reloadwsfile() {
+    return "--reloadwsfile";
+}
+const char* CtsApi::reloadwsfileArg() {
+    return "reloadwsfile";
+}
+
+std::string CtsApi::reloadpasswdfile() {
+    return "--reloadpasswdfile";
+}
+const char* CtsApi::reloadpasswdfile_arg() {
+    return "reloadpasswdfile";
+}
+
+std::string CtsApi::reloadcustompasswdfile() {
+    return "--reloadcustompasswdfile";
+}
+const char* CtsApi::reloadcustompasswdfile_arg() {
+    return "reloadcustompasswdfile";
+}
+
+std::string CtsApi::group(const std::string& cmds) {
+    std::string ret = "--group=";
+    ret += cmds;
+    return ret;
+}
+const char* CtsApi::groupArg() {
+    return "group";
+}
+
+std::vector<std::string> CtsApi::getLog(int lastLine) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+    retVec.emplace_back("--log=get");
+    if (lastLine != 0) {
+        std::stringstream ss;
+        ss << lastLine;
+        retVec.push_back(ss.str());
+    }
+    return retVec;
+}
+std::vector<std::string> CtsApi::new_log(const std::string& new_path) {
+    std::vector<std::string> retVec;
+    retVec.reserve(2);
+    retVec.emplace_back("--log=new");
+    if (!new_path.empty())
+        retVec.push_back(new_path);
+    return retVec;
+}
+std::string CtsApi::clearLog() {
+    return "--log=clear";
+}
+std::string CtsApi::flushLog() {
+    return "--log=flush";
+}
+std::string CtsApi::get_log_path() {
+    return "--log=path";
+}
+
+std::string CtsApi::forceDependencyEval() {
+    return "--force-dep-eval";
+}
+const char* CtsApi::forceDependencyEvalArg() {
+    return "force-dep-eval";
+}
+
+std::vector<std::string> CtsApi::edit_script(const std::string& path_to_task,
+                                             const std::string& edit_type,
+                                             const std::string& path_to_script,
+                                             bool create_alias,
+                                             bool run) {
+    std::vector<std::string> retVec;
+    std::string ret = "--edit_script=";
+    ret += path_to_task;
+    retVec.push_back(ret);
+    retVec.push_back(edit_type);
+    if (!path_to_script.empty())
+        retVec.push_back(path_to_script);
+    if (create_alias)
+        retVec.emplace_back("create_alias");
+    if (!run)
+        retVec.emplace_back("no_run");
+    return retVec;
+}
+const char* CtsApi::edit_script_arg() {
+    return "edit_script";
+}
+
+std::vector<std::string>
+CtsApi::query(const std::string& query_type, const std::string& path_to_attribute, const std::string& attribute) {
+    std::vector<std::string> retVec;
+    retVec.reserve(3);
+    std::string ret = "--query=";
+    ret += query_type;
+    retVec.push_back(ret);
+    if (query_type == "event" || query_type == "meter" || query_type == "variable") {
+        retVec.push_back(path_to_attribute + ":" + attribute);
+    }
+    else if (query_type == "trigger") {
+        retVec.push_back(path_to_attribute);
+        retVec.push_back(attribute);
+    }
+    else if (query_type == "repeat") {
+        retVec.push_back(path_to_attribute);
+        if (!attribute.empty())
+            retVec.push_back(attribute);
+    }
+    else if (query_type == "state" || query_type == "dstate") {
+        retVec.push_back(path_to_attribute);
+    }
+    return retVec;
+}
+const char* CtsApi::queryArg() {
+    return "query";
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsApi.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsApi.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsApi.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsApi.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,286 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_CtsApi_HPP
+#define ecflow_base_cts_user_CtsApi_HPP
+
+///
+/// \brief (C)lient (t)o (s)erver API
+///
+
+#include <string>
+#include <vector>
+
+#include "ecflow/core/CheckPt.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+// The two variant api must correspond i.e '--get' and 'get' since this is used by boost program options
+// *************************************************************************************
+// Note:: if the api requires multiple parameters it must return a std::vector<std::string>
+// ***************************************************************************************
+class CtsApi {
+public:
+    CtsApi(const CtsApi&)                  = delete;
+    const CtsApi& operator=(const CtsApi&) = delete;
+
+    static std::string to_string(const std::vector<std::string>&);
+
+    static std::string server_version();
+
+    // For python
+    static defs_ptr load(defs_ptr defs) { return defs; }
+    static std::vector<std::string> loadDefs(const std::string& filePath,
+                                             bool force,
+                                             bool check_only,
+                                             bool print); // check_only & print are client side only
+    static std::string get(const std::string& absNodePath = "");
+    static std::string get_state(const std::string& absNodePath = "");
+    static std::string migrate(const std::string& absNodePath = "");
+    static std::vector<std::string>
+    sync(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no);
+    static std::vector<std::string>
+    sync_clock(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no);
+    static std::string sync_full(unsigned int client_handle);
+    static std::vector<std::string>
+    news(unsigned int client_handle, unsigned int state_change_no, unsigned int modify_change_no);
+
+    static std::vector<std::string>
+    ch_register(int client_handle, bool auto_add_new_suites, const std::vector<std::string>& suites);
+    static std::string ch_suites();
+    static std::string ch_drop(int client_handle);
+    static std::string ch_drop_user(const std::string& user);
+    static std::vector<std::string> ch_add(int client_handle, const std::vector<std::string>& suites);
+    static std::vector<std::string> ch_remove(int client_handle, const std::vector<std::string>& suites);
+    static std::vector<std::string> ch_auto_add(int client_handle, bool auto_add_new_suites);
+    static std::string suites(); // returns list if all suites, and client handles.
+
+    static std::string restartServer();
+    static std::string haltServer(bool auto_confirm = true);
+    static std::string shutdownServer(bool auto_confirm = true);
+    static std::string terminateServer(bool auto_confirm = true);
+    static std::string pingServer();
+    static std::string server_load(const std::string& path_to_log_file);
+    static std::string debug_server_on();
+    static std::string debug_server_off();
+
+    // odd one out, take multi-args but expects string
+    static std::string begin(const std::string& suiteName = "", bool force = false); // no suite begins all suites
+
+    static std::string job_gen(const std::string& absNodePath = "");
+    static std::string checkJobGenOnly(const std::string& absNodePath = "");
+
+    static std::vector<std::string> check(const std::string& absNodePath = "");
+    static std::vector<std::string> check(const std::vector<std::string>& paths);
+    static std::vector<std::string>
+    delete_node(const std::vector<std::string>& paths,
+                bool force        = false,
+                bool auto_confirm = true); // no paths specified ,delete all suites, for test
+    static std::vector<std::string>
+    delete_node(const std::string& absNodePath = "",
+                bool force                     = false,
+                bool auto_confirm              = true); // no node specified ,delete all suites, for test
+    static std::vector<std::string> suspend(const std::string& absNodePath);
+    static std::vector<std::string> suspend(const std::vector<std::string>& paths);
+    static std::vector<std::string> resume(const std::string& absNodePath);
+    static std::vector<std::string> resume(const std::vector<std::string>& paths);
+    static std::vector<std::string> kill(const std::string& absNodePath);
+    static std::vector<std::string> kill(const std::vector<std::string>& paths);
+    static std::vector<std::string> status(const std::string& absNodePath);
+    static std::vector<std::string> status(const std::vector<std::string>& paths);
+    static std::vector<std::string> edit_history(const std::vector<std::string>& paths);
+    static std::vector<std::string> edit_history(const std::string& absNodePath);
+    static std::vector<std::string> archive(const std::vector<std::string>& paths, bool force = false);
+    static std::vector<std::string> archive(const std::string& absNodePath, bool force = false);
+    static std::vector<std::string> restore(const std::vector<std::string>& paths);
+    static std::vector<std::string> restore(const std::string& absNodePath);
+
+    static std::string why(const std::string& absNodePath);
+    static std::string zombieGet();
+    static std::vector<std::string>
+    zombieFob(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
+    static std::vector<std::string>
+    zombieFail(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
+    static std::vector<std::string>
+    zombieAdopt(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
+    static std::vector<std::string>
+    zombieRemove(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
+    static std::vector<std::string>
+    zombieBlock(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
+    static std::vector<std::string>
+    zombieKill(const std::vector<std::string>& paths, const std::string& process_id, const std::string& password);
+    static std::string zombieFobCli(const std::string& task_path);
+    static std::string zombieFailCli(const std::string& task_path);
+    static std::string zombieAdoptCli(const std::string& task_path);
+    static std::string zombieRemoveCli(const std::string& task_path);
+    static std::string zombieBlockCli(const std::string& task_path);
+    static std::string zombieKillCli(const std::string& task_path);
+    static std::vector<std::string> zombieFobCli(const std::vector<std::string>& paths);
+    static std::vector<std::string> zombieFailCli(const std::vector<std::string>& paths);
+    static std::vector<std::string> zombieAdoptCli(const std::vector<std::string>& paths);
+    static std::vector<std::string> zombieRemoveCli(const std::vector<std::string>& paths);
+    static std::vector<std::string> zombieBlockCli(const std::vector<std::string>& paths);
+    static std::vector<std::string> zombieKillCli(const std::vector<std::string>& paths);
+
+    static std::vector<std::string> replace(const std::string& absNodePath,
+                                            const std::string& path_to_client_defs,
+                                            bool create_parents_as_required = true,
+                                            bool force                      = false);
+    static std::vector<std::string> requeue(const std::vector<std::string>& paths,
+                                            const std::string& option /* [ "" | "force" | "abort" ] */);
+    static std::vector<std::string> requeue(const std::string& absNodePath,
+                                            const std::string& option /* [ "" | "force" | "abort" ] */);
+    static std::vector<std::string> run(const std::vector<std::string>& paths, bool force = false);
+    static std::vector<std::string> run(const std::string& absNodePath, bool force = false);
+    static std::vector<std::string> order(const std::string& absNodePath, const std::string& orderType);
+
+    static std::string checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
+                                   int check_pt_interval        = 0,
+                                   int check_pt_save_time_alarm = 0);
+    static std::string restoreDefsFromCheckPt();
+
+    static std::vector<std::string> force(const std::vector<std::string>& paths,
+                                          const std::string& state_or_event,
+                                          bool recursive                 = false,
+                                          bool set_repeats_to_last_value = false);
+    static std::vector<std::string> force(const std::string& path,
+                                          const std::string& state_or_event,
+                                          bool recursive                 = false,
+                                          bool set_repeats_to_last_value = false);
+
+    static std::vector<std::string> freeDep(const std::vector<std::string>& paths,
+                                            bool trigger = true,
+                                            bool all     = false,
+                                            bool date    = false,
+                                            bool time    = false);
+    static std::vector<std::string> freeDep(const std::string& absNodePath,
+                                            bool trigger = true,
+                                            bool all     = false,
+                                            bool date    = false,
+                                            bool time    = false);
+
+    static std::vector<std::string>
+    file(const std::string& absNodePath, const std::string& fileType, const std::string& max_lines);
+    static std::vector<std::string> plug(const std::string& sourcePath, const std::string& destPath);
+
+    static std::vector<std::string>
+    alter(const std::string& path,
+          const std::string& alterType, /* one of [ 'add' | 'change' | 'delete' | 'set_flag' | 'clear_flag' ] */
+          const std::string& attrType,
+          const std::string& name  = "",
+          const std::string& value = "");
+    static std::vector<std::string>
+    alter(const std::vector<std::string>& paths,
+          const std::string& alterType, /* one of [ 'add' | 'change' | 'delete' | 'set_flag' | 'clear_flag' ] */
+          const std::string& attrType,
+          const std::string& name  = "",
+          const std::string& value = "");
+    static std::vector<std::string>
+    alter_sort(const std::vector<std::string>& paths, const std::string& sortable_attribute_name, bool recursive);
+
+    static std::string reloadwsfile();
+    static std::string reloadpasswdfile();
+    static std::string reloadcustompasswdfile();
+
+    // "expect string of the form "shutdown; get" must be ';' separated
+    static std::string group(const std::string& cmds);
+
+    static std::string logMsg(const std::string& theMsgToLog);
+    static std::vector<std::string> getLog(int lastLines = 0);
+    static std::vector<std::string> new_log(const std::string& new_path);
+    static std::string get_log_path();
+    static std::string clearLog();
+    static std::string flushLog();
+    static std::string forceDependencyEval();
+
+    static std::string stats();
+    static std::string stats_server(); // used in test, as serialisation subject to change
+    static std::string stats_reset();
+
+    static std::vector<std::string> edit_script(const std::string& path_to_task,
+                                                const std::string& edit_type,
+                                                const std::string& path_to_script = "",
+                                                bool create_alias                 = false,
+                                                bool run                          = true);
+    static std::vector<std::string>
+    query(const std::string& query_type, const std::string& path_to_attribute, const std::string& attribute);
+
+    // Only to be used in Cmd
+    static const char* server_version_arg();
+    static const char* statsArg();
+    static const char* stats_server_arg();
+    static const char* stats_reset_arg();
+    static const char* suitesArg();
+    static const char* ch_register_arg();
+    static const char* ch_drop_arg();
+    static const char* ch_suites_arg();
+    static const char* ch_drop_user_arg();
+    static const char* ch_add_arg();
+    static const char* ch_remove_arg();
+    static const char* ch_auto_add_arg();
+
+    static const char* terminateServerArg();
+    static const char* restartServerArg();
+    static const char* haltServerArg();
+    static const char* shutdownServerArg();
+    static const char* pingServerArg();
+    static const char* server_load_arg();
+    static const char* debug_server_on_arg();
+    static const char* debug_server_off_arg();
+
+    static const char* getArg();
+    static const char* get_state_arg();
+    static const char* migrate_arg();
+    static const char* syncArg();
+    static const char* sync_clock_arg();
+    static const char* sync_full_arg();
+    static const char* newsArg();
+    static const char* loadDefsArg();
+    static const char* beginArg();
+    static const char* job_genArg();
+    static const char* check_arg();
+    static const char* checkJobGenOnlyArg();
+    static const char* delete_node_arg();
+    static const char* suspend_arg();
+    static const char* resume_arg();
+    static const char* kill_arg();
+    static const char* statusArg();
+    static const char* edit_history_arg();
+    static const char* archive_arg();
+    static const char* restore_arg();
+    static const char* whyArg();
+    static const char* zombieGetArg();
+    static const char* zombieFobArg();
+    static const char* zombieFailArg();
+    static const char* zombieAdoptArg();
+    static const char* zombieRemoveArg();
+    static const char* zombieBlockArg();
+    static const char* zombieKillArg();
+    static const char* replace_arg();
+    static const char* requeueArg();
+    static const char* runArg();
+    static const char* orderArg();
+    static const char* checkPtDefsArg();
+    static const char* restoreDefsFromCheckPtArg();
+    static const char* logMsgArg();
+    static const char* forceArg();
+    static const char* freeDepArg();
+    static const char* fileArg();
+    static const char* plugArg();
+    static const char* reloadwsfileArg();
+    static const char* reloadpasswdfile_arg();
+    static const char* reloadcustompasswdfile_arg();
+    static const char* groupArg();
+    static const char* forceDependencyEvalArg();
+    static const char* alterArg();
+    static const char* edit_script_arg();
+    static const char* queryArg();
+};
+
+#endif /* ecflow_base_cts_user_CtsApi_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,790 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/Gnuplot.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+// *IMPORTANT*: STATS_RESET was introduced in release 4.0.5
+
+void CtsCmd::print(std::string& os) const {
+    switch (api_) {
+        case CtsCmd::GET_ZOMBIES:
+            user_cmd(os, CtsApi::zombieGet());
+            break;
+        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
+            user_cmd(os, CtsApi::restoreDefsFromCheckPt());
+            break;
+        case CtsCmd::RESTART_SERVER:
+            user_cmd(os, CtsApi::restartServer());
+            break;
+        case CtsCmd::SHUTDOWN_SERVER:
+            user_cmd(os, CtsApi::shutdownServer());
+            break;
+        case CtsCmd::HALT_SERVER:
+            user_cmd(os, CtsApi::haltServer());
+            break;
+        case CtsCmd::TERMINATE_SERVER:
+            user_cmd(os, CtsApi::terminateServer());
+            break;
+        case CtsCmd::RELOAD_WHITE_LIST_FILE:
+            user_cmd(os, CtsApi::reloadwsfile());
+            break;
+        case CtsCmd::RELOAD_PASSWD_FILE:
+            user_cmd(os, CtsApi::reloadpasswdfile());
+            break;
+        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
+            user_cmd(os, CtsApi::reloadcustompasswdfile());
+            break;
+        case CtsCmd::FORCE_DEP_EVAL:
+            user_cmd(os, CtsApi::forceDependencyEval());
+            break;
+        case CtsCmd::PING:
+            user_cmd(os, CtsApi::pingServer());
+            break;
+        case CtsCmd::STATS:
+            user_cmd(os, CtsApi::stats());
+            break;
+        case CtsCmd::STATS_SERVER:
+            user_cmd(os, CtsApi::stats_server());
+            break;
+        case CtsCmd::STATS_RESET:
+            user_cmd(os, CtsApi::stats_reset());
+            break;
+        case CtsCmd::SUITES:
+            user_cmd(os, CtsApi::suites());
+            break;
+        case CtsCmd::DEBUG_SERVER_ON:
+            user_cmd(os, CtsApi::debug_server_on());
+            break;
+        case CtsCmd::DEBUG_SERVER_OFF:
+            user_cmd(os, CtsApi::debug_server_off());
+            break;
+        case CtsCmd::SERVER_LOAD:
+            user_cmd(os, CtsApi::server_load(""));
+            break;
+        case CtsCmd::NO_CMD:
+            assert(false);
+            os += "CtsCmdCtsCmd::NO_CMD  !!!!";
+            break;
+        default:
+            assert(false);
+            os += "CtsCmd did not match api_ !!!!";
+            break;
+    }
+}
+
+void CtsCmd::print_only(std::string& os) const {
+    switch (api_) {
+        case CtsCmd::GET_ZOMBIES:
+            os += CtsApi::zombieGet();
+            break;
+        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
+            os += CtsApi::restoreDefsFromCheckPt();
+            break;
+        case CtsCmd::RESTART_SERVER:
+            os += CtsApi::restartServer();
+            break;
+        case CtsCmd::SHUTDOWN_SERVER:
+            os += CtsApi::shutdownServer();
+            break;
+        case CtsCmd::HALT_SERVER:
+            os += CtsApi::haltServer();
+            break;
+        case CtsCmd::TERMINATE_SERVER:
+            os += CtsApi::terminateServer();
+            break;
+        case CtsCmd::RELOAD_WHITE_LIST_FILE:
+            os += CtsApi::reloadwsfile();
+            break;
+        case CtsCmd::RELOAD_PASSWD_FILE:
+            os += CtsApi::reloadpasswdfile();
+            break;
+        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
+            os += CtsApi::reloadcustompasswdfile();
+            break;
+        case CtsCmd::FORCE_DEP_EVAL:
+            os += CtsApi::forceDependencyEval();
+            break;
+        case CtsCmd::PING:
+            os += CtsApi::pingServer();
+            break;
+        case CtsCmd::STATS:
+            os += CtsApi::stats();
+            break;
+        case CtsCmd::STATS_SERVER:
+            os += CtsApi::stats_server();
+            break;
+        case CtsCmd::STATS_RESET:
+            os += CtsApi::stats_reset();
+            break;
+        case CtsCmd::SUITES:
+            os += CtsApi::suites();
+            break;
+        case CtsCmd::DEBUG_SERVER_ON:
+            os += CtsApi::debug_server_on();
+            break;
+        case CtsCmd::DEBUG_SERVER_OFF:
+            os += CtsApi::debug_server_off();
+            break;
+        case CtsCmd::SERVER_LOAD:
+            os += CtsApi::server_load("");
+            break;
+        case CtsCmd::NO_CMD:
+            assert(false);
+            os += "CtsCmdCtsCmd::NO_CMD  !!!!";
+            break;
+        default:
+            assert(false);
+            os += "CtsCmd did not match api_ !!!!";
+            break;
+    }
+}
+
+bool CtsCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<CtsCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (api_ != the_rhs->api())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+bool CtsCmd::isWrite() const {
+    switch (api_) {
+        case CtsCmd::GET_ZOMBIES:
+            return false;
+            break; // read only
+        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::RESTART_SERVER:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::SHUTDOWN_SERVER:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::HALT_SERVER:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::TERMINATE_SERVER:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::RELOAD_WHITE_LIST_FILE:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::RELOAD_PASSWD_FILE:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::FORCE_DEP_EVAL:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::PING:
+            return false;
+            break; // read only
+        case CtsCmd::STATS:
+            return false;
+            break; // read only
+        case CtsCmd::STATS_SERVER:
+            return false;
+            break; // read only
+        case CtsCmd::STATS_RESET:
+            return true;
+            break; // requires write privilege
+        case CtsCmd::SUITES:
+            return false;
+            break; // read only
+        case CtsCmd::DEBUG_SERVER_ON:
+            return false;
+            break; // read only
+        case CtsCmd::DEBUG_SERVER_OFF:
+            return false;
+            break; // read only
+        case CtsCmd::SERVER_LOAD:
+            return false;
+            break; // read only
+        case CtsCmd::NO_CMD:
+            assert(false);
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    assert(false);
+    return false;
+}
+
+bool CtsCmd::cmd_updates_defs() const {
+    switch (api_) {
+        case CtsCmd::GET_ZOMBIES:
+            return false;
+            break;
+        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
+            return true;
+            break;
+        case CtsCmd::RESTART_SERVER:
+            return true;
+            break;
+        case CtsCmd::SHUTDOWN_SERVER:
+            return true;
+            break;
+        case CtsCmd::HALT_SERVER:
+            return true;
+            break;
+        case CtsCmd::TERMINATE_SERVER:
+            return true;
+            break;
+        case CtsCmd::RELOAD_WHITE_LIST_FILE:
+            return false;
+            break;
+        case CtsCmd::RELOAD_PASSWD_FILE:
+            return false;
+            break;
+        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
+            return false;
+            break;
+        case CtsCmd::FORCE_DEP_EVAL:
+            return true;
+            break;
+        case CtsCmd::PING:
+            return false;
+            break;
+        case CtsCmd::STATS:
+            return false;
+            break;
+        case CtsCmd::STATS_SERVER:
+            return false;
+            break;
+        case CtsCmd::STATS_RESET:
+            return false;
+            break;
+        case CtsCmd::SUITES:
+            return false;
+            break;
+        case CtsCmd::DEBUG_SERVER_ON:
+            return false;
+            break;
+        case CtsCmd::DEBUG_SERVER_OFF:
+            return false;
+            break;
+        case CtsCmd::SERVER_LOAD:
+            return false;
+            break;
+        case CtsCmd::NO_CMD:
+            assert(false);
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    assert(false);
+    return false;
+}
+
+int CtsCmd::timeout() const {
+    if (api_ == CtsCmd::PING)
+        return 10;
+    return ClientToServerCmd::timeout();
+}
+
+const char* CtsCmd::theArg() const {
+    switch (api_) {
+        case CtsCmd::GET_ZOMBIES:
+            return CtsApi::zombieGetArg();
+            break;
+        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT:
+            return CtsApi::restoreDefsFromCheckPtArg();
+            break;
+        case CtsCmd::RESTART_SERVER:
+            return CtsApi::restartServerArg();
+            break;
+        case CtsCmd::SHUTDOWN_SERVER:
+            return CtsApi::shutdownServerArg();
+            break;
+        case CtsCmd::HALT_SERVER:
+            return CtsApi::haltServerArg();
+            break;
+        case CtsCmd::TERMINATE_SERVER:
+            return CtsApi::terminateServerArg();
+            break;
+        case CtsCmd::RELOAD_WHITE_LIST_FILE:
+            return CtsApi::reloadwsfileArg();
+            break;
+        case CtsCmd::RELOAD_PASSWD_FILE:
+            return CtsApi::reloadpasswdfile_arg();
+            break;
+        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE:
+            return CtsApi::reloadcustompasswdfile_arg();
+            break;
+        case CtsCmd::FORCE_DEP_EVAL:
+            return CtsApi::forceDependencyEvalArg();
+            break;
+        case CtsCmd::PING:
+            return CtsApi::pingServerArg();
+            break;
+        case CtsCmd::STATS:
+            return CtsApi::statsArg();
+            break;
+        case CtsCmd::STATS_SERVER:
+            return CtsApi::stats_server_arg();
+            break;
+        case CtsCmd::STATS_RESET:
+            return CtsApi::stats_reset_arg();
+            break;
+        case CtsCmd::SUITES:
+            return CtsApi::suitesArg();
+            break;
+        case CtsCmd::DEBUG_SERVER_ON:
+            return CtsApi::debug_server_on_arg();
+            break;
+        case CtsCmd::DEBUG_SERVER_OFF:
+            return CtsApi::debug_server_off_arg();
+            break;
+        case CtsCmd::SERVER_LOAD:
+            return CtsApi::server_load_arg();
+            break;
+        case CtsCmd::NO_CMD:
+            assert(false);
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    assert(false);
+    return nullptr;
+}
+
+STC_Cmd_ptr CtsCmd::doHandleRequest(AbstractServer* as) const {
+    switch (api_) {
+        case CtsCmd::GET_ZOMBIES: {
+            as->update_stats().zombie_get_++;
+            return PreAllocatedReply::zombie_get_cmd(as);
+        }
+
+        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT: {
+            as->update_stats().restore_defs_from_checkpt_++;
+            as->restore_defs_from_checkpt(); // this can throw, i.e. if server not halted, or defs has suites, etc
+            break;
+        }
+
+        case CtsCmd::RESTART_SERVER: {
+            as->update_stats().restart_server_++;
+            as->restart();
+            return doJobSubmission(as);
+        }
+        case CtsCmd::SHUTDOWN_SERVER:
+            as->update_stats().shutdown_server_++;
+            as->shutdown();
+            break;
+        case CtsCmd::HALT_SERVER:
+            as->update_stats().halt_server_++;
+            as->halted();
+            break;
+        case CtsCmd::TERMINATE_SERVER:
+            as->checkPtDefs();
+            break;
+        case CtsCmd::RELOAD_WHITE_LIST_FILE: {
+            as->update_stats().reload_white_list_file_++;
+            std::string errorMsg;
+            if (!as->reloadWhiteListFile(errorMsg)) {
+                throw std::runtime_error(errorMsg);
+            }
+            break;
+        }
+        case CtsCmd::RELOAD_PASSWD_FILE: {
+            as->update_stats().reload_passwd_file_++;
+            std::string errorMsg;
+            if (!as->reloadPasswdFile(errorMsg)) {
+                throw std::runtime_error(errorMsg);
+            }
+            break;
+        }
+        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE: {
+            as->update_stats().reload_passwd_file_++;
+            std::string errorMsg;
+            if (!as->reloadCustomPasswdFile(errorMsg)) {
+                throw std::runtime_error(errorMsg);
+            }
+            break;
+        }
+        case CtsCmd::FORCE_DEP_EVAL: {
+            // The Default JobsParam does *not* allow Job creation, & hence => does not submit jobs
+            // The default does *not* allow job spawning
+            Jobs jobs(as->defs());
+            JobsParam jobsParam; // create jobs =  false, spawn_jobs = false
+            if (!jobs.generate(jobsParam))
+                throw std::runtime_error(jobsParam.getErrorMsg());
+            break;
+        }
+        case CtsCmd::PING:
+            as->update_stats().ping_++;
+            break;
+        case CtsCmd::STATS: {
+            as->update_stats().stats_++;
+            std::stringstream ss;
+            as->stats().update_for_serialisation();
+            as->stats().no_of_suites_ = as->defs()->suiteVec().size();
+            as->stats().show(ss); // ECFLOW-880, allow stats to be changed in server, by only returning string
+            return PreAllocatedReply::string_cmd(ss.str());
+            break;
+        }
+        case CtsCmd::STATS_SERVER: {
+            as->update_stats().stats_++;
+            return PreAllocatedReply::stats_cmd(as);
+            break; // Only to be used in test, as subject to change, returns Stats struct
+        }
+        case CtsCmd::STATS_RESET:
+            as->update_stats().reset();
+            break; // we could have done as->update_stats().stats_++, to honor reset, we dont
+        case CtsCmd::SUITES:
+            as->update_stats().suites_++;
+            return PreAllocatedReply::suites_cmd(as);
+            break;
+        case CtsCmd::DEBUG_SERVER_ON:
+            as->update_stats().debug_server_on_++;
+            as->debug_server_on();
+            break;
+        case CtsCmd::DEBUG_SERVER_OFF:
+            as->update_stats().debug_server_off_++;
+            as->debug_server_off();
+            break;
+        case CtsCmd::SERVER_LOAD: {
+            as->update_stats().server_load_cmd_++;
+            return PreAllocatedReply::server_load_cmd(Log::instance()->path());
+        }
+        case CtsCmd::NO_CMD:
+            assert(false);
+            break;
+        default:
+            assert(false);
+            break;
+    }
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+static const char* server_load_desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Generates gnuplot files that show the server load graphically.\n"
+           "This is done by parsing the log file. If no log file is provided,\n"
+           "then the log file path is obtained from the server. If the returned\n"
+           "log file path is not accessible an error is returned\n"
+           "This command produces a three files in the CWD.\n"
+           "    o <host>.<port>.gnuplot.dat\n"
+           "    o <host>.<port>.gnuplot.script\n"
+           "    o <host>.<port>.png\n\n"
+           "The generated script can be manually changed, to see different rendering\n"
+           "effects. i.e. just run 'gnuplot <host>.<port>.gnuplot.script'\n\n"
+           "  arg1 = <optional> path to log file\n\n"
+           "If the path to log file is known, it is *preferable* to use this,\n"
+           "rather than requesting the log path from the server.\n\n"
+           "Usage:\n"
+           "   --server_load=/path/to_log_file  # Parses log and generate gnuplot files\n"
+           "   --server_load                    # Log file path is requested from server\n"
+           "                                    # which is then used to generate gnuplot files\n"
+           "                                    # *AVOID* if log file path is accessible\n\n"
+           "Now use any png viewer to see the output i.e\n\n"
+           "> display   <host>.<port>.png\n"
+           "> feh       <host>.<port>.png\n"
+           "> eog       <host>.<port>.png\n"
+           "> xdg-open  <host>.<port>.png\n"
+           "> w3m       <host>.<port>.png\n";
+}
+
+void CtsCmd::addOption(boost::program_options::options_description& desc) const {
+    switch (api_) {
+        case CtsCmd::GET_ZOMBIES: {
+            desc.add_options()(CtsApi::zombieGetArg(),
+                               "Returns the list of zombies from the server.\n"
+                               "Results reported to standard output.");
+            break;
+        }
+        case CtsCmd::RESTORE_DEFS_FROM_CHECKPT: {
+            desc.add_options()(CtsApi::restoreDefsFromCheckPtArg(),
+                               "Ask the server to load the definition from an check pt file.\n"
+                               "The server must be halted and the definition in the server must be deleted\n"
+                               "first, otherwise an error is returned");
+            break;
+        }
+        case CtsCmd::RESTART_SERVER: {
+            desc.add_options()(CtsApi::restartServerArg(),
+                               "Start job scheduling, communication with jobs, and respond to all requests.\n"
+                               "The following table shows server behaviour in the different states.\n"
+                               "|----------------------------------------------------------------------------------|\n"
+                               "| Server State | User Request | Task Request |Job Scheduling | Auto-Check-pointing |\n"
+                               "|--------------|--------------|--------------|---------------|---------------------|\n"
+                               "|     RUNNING  |    yes       |      yes     |      yes      |      yes            |\n"
+                               "|    SHUTDOWN  |    yes       |      yes     |      no       |      yes            |\n"
+                               "|      HALTED  |    yes       |      no      |      no       |      no             |\n"
+                               "|--------------|--------------|--------------|---------------|---------------------|");
+            break;
+        }
+        case CtsCmd::SHUTDOWN_SERVER: {
+            desc.add_options()(CtsApi::shutdownServerArg(),
+                               po::value<string>()->implicit_value(string("")),
+                               "Stop server from scheduling new jobs.\n"
+                               "  arg1 = yes(optional) # use to bypass confirmation prompt,i.e\n"
+                               "  --shutdown=yes\n"
+                               "The following table shows server behaviour in the different states.\n"
+                               "|----------------------------------------------------------------------------------|\n"
+                               "| Server State | User Request | Task Request |Job Scheduling | Auto-Check-pointing |\n"
+                               "|--------------|--------------|--------------|---------------|---------------------|\n"
+                               "|     RUNNING  |    yes       |      yes     |      yes      |      yes            |\n"
+                               "|    SHUTDOWN  |    yes       |      yes     |      no       |      yes            |\n"
+                               "|      HALTED  |    yes       |      no      |      no       |      no             |\n"
+                               "|--------------|--------------|--------------|---------------|---------------------|");
+            break;
+        }
+        case CtsCmd::HALT_SERVER: {
+            desc.add_options()(CtsApi::haltServerArg(),
+                               po::value<string>()->implicit_value(string("")),
+                               "Stop server communication with jobs, and new job scheduling.\n"
+                               "Also stops automatic check pointing\n"
+                               "  arg1 = yes(optional) # use to bypass confirmation prompt,i.e.\n"
+                               "  --halt=yes\n"
+                               "The following table shows server behaviour in the different states.\n"
+                               "|----------------------------------------------------------------------------------|\n"
+                               "| Server State | User Request | Task Request |Job Scheduling | Auto-Check-pointing |\n"
+                               "|--------------|--------------|--------------|---------------|---------------------|\n"
+                               "|     RUNNING  |    yes       |      yes     |      yes      |      yes            |\n"
+                               "|    SHUTDOWN  |    yes       |      yes     |      no       |      yes            |\n"
+                               "|      HALTED  |    yes       |      no      |      no       |      no             |\n"
+                               "|--------------|--------------|--------------|---------------|---------------------|");
+            break;
+        }
+        case CtsCmd::TERMINATE_SERVER: {
+            desc.add_options()(CtsApi::terminateServerArg(),
+                               po::value<string>()->implicit_value(string("")),
+                               "Terminate the server.\n"
+                               "  arg1 = yes(optional) # use to bypass confirmation prompt.i.e\n"
+                               "  --terminate=yes");
+            break;
+        }
+        case CtsCmd::RELOAD_WHITE_LIST_FILE: {
+            desc.add_options()(CtsApi::reloadwsfileArg(),
+                               "Reload the white list file.\n"
+                               "The white list file is used to authenticate 'user' commands.\n"
+                               "File path is specified by ECF_LISTS environment, read by the server on *startup*.\n"
+                               "Hence the contents of the file can be changed but not the location\n"
+                               "If ECF_LISTS is not specified, or is specified and is 'ecf.lists' then by default\n"
+                               "it will open <host>.<port>.ecf.lists.If a path like /var/tmp/ecf.lists was specified\n"
+                               "for ECF_LISTS, then this is the path used for reloading the white list file\n"
+                               "On startup, if the file is not present or is present but is empty (i.e just contains "
+                               "the version number)\n"
+                               "then all users have read/write access\n"
+                               "However on reload it will raises an error if file does not exist, or fails to parse\n"
+                               "Expected format for this file is:\n\n"
+                               "# comment\n"
+                               "4.4.14  # version number, this must be present, even if no users specified\n\n"
+                               "# Users with read/write access\n"
+                               "user1   # comment\n"
+                               "user2   # comment\n\n"
+                               "*       # use this form if you want all users to have read/write access\n\n"
+                               "# Users with read  access, must have - before user name\n"
+                               "-user3  # comment\n"
+                               "-user4\n\n"
+                               "-*      # use this form if you want all users to have read access");
+            break;
+        }
+        case CtsCmd::RELOAD_PASSWD_FILE: {
+            desc.add_options()(
+                CtsApi::reloadpasswdfile_arg(),
+                "Reload the server password file. To be used when ALL users have a password\n"
+                "Although the password file can be reloaded(i.e to add/remove users), its location can't be changed\n"
+                "The password file is located by the ECF_PASSWD environment variable, both for the client and server\n"
+                "On the server the default file name is <host>.<port>.ecf.passwd\n"
+                "On the client the default file name is ecf.passwd\n"
+                "The format of the file is same for client and server:\n\n"
+                "4.5.0\n"
+                "# comment\n"
+                "<user> <host> <port> <passwd> # comment\n\n"
+                "i.e\n"
+                "4.5.0 # the version\n"
+                "fred machine1 3142 xxyyyd\n"
+                "fred machine2 3133 xxyyyd # comment\n"
+                "bill machine2 3133 xxyggyyd\n\n"
+                "The same user may appear multiple times. i.e with different host/port. This allows the password file\n"
+                "to be used for multiple servers\n"
+                "For the password authentication to work. It must be:\n"
+                "  - Defined for the client and server\n"
+                "  - Creating an empty password file,(i.e with just the version) will mean, no client can reload it.\n"
+                "    Hence at least the server administrator needs to be added to the file\n"
+                "  - The password file permission's must be set for reading by the user only\n"
+                "Usage:\n"
+                " --reloadpasswdfile");
+            break;
+        }
+        case CtsCmd::RELOAD_CUSTOM_PASSWD_FILE: {
+            desc.add_options()(
+                CtsApi::reloadcustompasswdfile_arg(),
+                "Reload the server custom password file. For those user's who don't use login name\n"
+                "This should be used when most users use the machine login name, but a few users specify their own "
+                "user name,\n"
+                "in this case these user must provide a password.\n"
+                "Although the password file can be reloaded(i.e to add/remove users), its location can't be changed\n"
+                "The password file is located by the ECF_CUSTOM_PASSWD environment variable, both for the client and "
+                "server\n"
+                "On the server the default file name is <host>.<port>.ecf.custom_passwd\n"
+                "On the client the default file name is ecf.custom_passwd\n"
+                "The format of the file is same for client and server:\n\n"
+                "4.5.0\n"
+                "# comment\n"
+                "<user> <host> <port> <passwd> # comment\n\n"
+                "i.e\n"
+                "4.5.0 # the version\n"
+                "fred machine1 3142 xxyyyd\n"
+                "fred machine2 3133 xxyyyd # comment\n"
+                "bill machine2 3133 xxyggyyd\n\n"
+                "The same user may appear multiple times. i.e with different host/port. This allows the password file\n"
+                "to be used for multiple servers\n"
+                "For the password authentication to work. It must be:\n"
+                "  - Defined for the client and server\n"
+                "  - Creating an empty password file,(i.e with just the version) will mean, no client can reload it.\n"
+                "    Hence at least the server administrator needs to be added to the file\n"
+                "  - The password file permission's must be set for reading by the user only\n"
+                "Usage:\n"
+                " --reloadcustompasswdfile");
+            break;
+        }
+
+        case CtsCmd::FORCE_DEP_EVAL: {
+            desc.add_options()(CtsApi::forceDependencyEvalArg(), "Force dependency evaluation. Used for DEBUG only.");
+            break;
+        }
+        case CtsCmd::PING: {
+            desc.add_options()(
+                CtsApi::pingServerArg(),
+                "Check if server is running on given host/port. Result reported to standard output.\n"
+                "Usage:\n"
+                "  --ping --host=mach --port=3144  # Check if server alive on host mach & port 3144\n"
+                "  --ping --host=fred              # Check if server alive on host fred and port ECF_PORT,\n"
+                "                                  # otherwise default port of 3141\n"
+                "  --ping                          # Check if server alive by using environment variables\n"
+                "                                  # ECF_HOST and ECF_PORT\n"
+                "If ECF_HOST not defined uses 'localhost', if ECF_PORT not defined assumes 3141");
+            break;
+        }
+        case CtsCmd::STATS: {
+            desc.add_options()(CtsApi::statsArg(), "Returns the server statistics as a string.");
+            break;
+        }
+        case CtsCmd::STATS_SERVER: {
+            desc.add_options()(CtsApi::stats_server_arg(),
+                               "Returns the server statistics as a struct and string. For test use only.");
+            break;
+        }
+        case CtsCmd::STATS_RESET: {
+            desc.add_options()(CtsApi::stats_reset_arg(), "Resets the server statistics.");
+            break;
+        }
+        case CtsCmd::SUITES: {
+            desc.add_options()(CtsApi::suitesArg(), "Returns the list of suites, in the order defined in the server.");
+            break;
+        }
+        case CtsCmd::DEBUG_SERVER_ON: {
+            desc.add_options()(CtsApi::debug_server_on_arg(), "Enables debug output from the server");
+            break;
+        }
+        case CtsCmd::DEBUG_SERVER_OFF: {
+            desc.add_options()(CtsApi::debug_server_off_arg(), "Disables debug output from the server");
+            break;
+        }
+        case CtsCmd::SERVER_LOAD: {
+            desc.add_options()(
+                CtsApi::server_load_arg(), po::value<std::string>()->implicit_value(string("")), server_load_desc());
+            break;
+        }
+        case CtsCmd::NO_CMD:
+            assert(false);
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+
+bool CtsCmd::handleRequestIsTestable() const {
+    if (api_ == CtsCmd::TERMINATE_SERVER)
+        return false;
+    if (api_ == CtsCmd::RESTORE_DEFS_FROM_CHECKPT)
+        return false;
+    return true;
+}
+
+void CtsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    if (ac->debug())
+        cout << "  CtsCmd::create api = '" << api_ << "'.\n";
+
+    assert(api_ != CtsCmd::NO_CMD);
+
+    if (api_ == CtsCmd::HALT_SERVER || api_ == CtsCmd::SHUTDOWN_SERVER || api_ == CtsCmd::TERMINATE_SERVER) {
+
+        std::string do_prompt = vm[theArg()].as<std::string>();
+        if (do_prompt.empty()) {
+            if (api_ == CtsCmd::HALT_SERVER)
+                prompt_for_confirmation("Are you sure you want to halt the server ? ");
+            else if (api_ == CtsCmd::SHUTDOWN_SERVER)
+                prompt_for_confirmation("Are you sure you want to shut down the server ? ");
+            else
+                prompt_for_confirmation("Are you sure you want to terminate the server ? ");
+        }
+        else if (do_prompt != "yes")
+            throw std::runtime_error(
+                "Halt, shutdown and terminate expected 'yes' as the only argument to bypass the confirmation prompt");
+    }
+    else if (api_ == CtsCmd::SERVER_LOAD) {
+
+        std::string log_file = vm[theArg()].as<std::string>();
+        if (ac->debug())
+            std::cout << "  CtsCmd::create CtsCmd::SERVER_LOAD " << log_file << "\n";
+
+        if (!log_file.empty()) {
+
+            // testing client interface
+            if (ac->under_test())
+                return;
+
+            // No need to call server. Parse the log file to create gnu_plot file.
+            Gnuplot gnuplot(log_file, ac->host(), ac->port());
+            gnuplot.show_server_load();
+
+            return; // Don't create command, since with log file, it is client specific only
+        }
+    }
+    cmd = std::make_shared<CtsCmd>(api_);
+}
+
+std::ostream& operator<<(std::ostream& os, const CtsCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(CtsCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(CtsCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,88 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_CtsCmd_HPP
+#define ecflow_base_cts_user_CtsCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// This command is used to encapsulate all commands that are
+// simple signals to the server. This helps to cut down on the
+// number of global symbols used by boost serialisation.
+// =========================================================================
+// *** IMPORTANT ***: If any of these commands in the future need arguments,
+// *** then ensure to place a DUMMY enum in its place.
+// *** This will allow a *newer* development client to still send message to a older server.
+// *** i.e like terminating the server
+// *** IMPORTANT: For any new commands, must be added to the end, for each major release
+// *** - STATS_RESET was introduced in release 4.0.5
+// =========================================================================
+class CtsCmd final : public UserCmd {
+public:
+    enum Api {
+        NO_CMD,
+        RESTORE_DEFS_FROM_CHECKPT,
+        RESTART_SERVER,
+        SHUTDOWN_SERVER,
+        HALT_SERVER,
+        TERMINATE_SERVER,
+        RELOAD_WHITE_LIST_FILE,
+        FORCE_DEP_EVAL,
+        PING,
+        GET_ZOMBIES,
+        STATS,
+        SUITES,
+        DEBUG_SERVER_ON,
+        DEBUG_SERVER_OFF,
+        SERVER_LOAD,
+        STATS_RESET,
+        RELOAD_PASSWD_FILE,
+        STATS_SERVER,
+        RELOAD_CUSTOM_PASSWD_FILE
+    };
+
+    explicit CtsCmd(Api a) : api_(a) {}
+    CtsCmd() = default;
+
+    Api api() const { return api_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    bool isWrite() const override;
+    bool cmd_updates_defs() const override;
+    bool terminate_cmd() const override { return api_ == TERMINATE_SERVER; }
+    bool ping_cmd() const override { return api_ == PING; }
+    int timeout() const override;
+
+    bool handleRequestIsTestable() const override;
+
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    Api api_{NO_CMD};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const CtsCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(CtsCmd)
+
+#endif /* ecflow_base_cts_user_CtsCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,387 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/JobCreationCtrl.hpp"
+#include "ecflow/node/Jobs.hpp"
+#ifdef DEBUG
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool CtsNodeCmd::why_cmd(std::string& nodePath) const {
+    if (api_ == CtsNodeCmd::WHY) {
+        nodePath = absNodePath_;
+        return true;
+    }
+    return false;
+}
+
+void CtsNodeCmd::print(std::string& os) const {
+    switch (api_) {
+        case CtsNodeCmd::GET: {
+            user_cmd(os, CtsApi::get(absNodePath_));
+#ifdef DEBUG
+            std::stringstream ss;
+            if (Ecf::server())
+                ss << " [server(" << Ecf::state_change_no() << " " << Ecf::modify_change_no() << ")]";
+            os += ss.str();
+#endif
+            break;
+        }
+        case CtsNodeCmd::GET_STATE:
+            user_cmd(os, CtsApi::get_state(absNodePath_));
+            break;
+        case CtsNodeCmd::MIGRATE:
+            user_cmd(os, CtsApi::migrate(absNodePath_));
+            break;
+        case CtsNodeCmd::JOB_GEN:
+            user_cmd(os, CtsApi::job_gen(absNodePath_));
+            break;
+        case CtsNodeCmd::WHY:
+            user_cmd(os, CtsApi::why(absNodePath_));
+            break;
+        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
+            user_cmd(os, CtsApi::checkJobGenOnly(absNodePath_));
+            break;
+        case CtsNodeCmd::NO_CMD:
+            break;
+        default:
+            throw std::runtime_error("CtsNodeCmd::print: Unrecognised command");
+            break;
+    }
+}
+void CtsNodeCmd::print_only(std::string& os) const {
+    switch (api_) {
+        case CtsNodeCmd::GET:
+            os += CtsApi::get(absNodePath_);
+            break;
+        case CtsNodeCmd::GET_STATE:
+            os += CtsApi::get_state(absNodePath_);
+            break;
+        case CtsNodeCmd::MIGRATE:
+            os += CtsApi::migrate(absNodePath_);
+            break;
+        case CtsNodeCmd::JOB_GEN:
+            os += CtsApi::job_gen(absNodePath_);
+            break;
+        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
+            os += CtsApi::checkJobGenOnly(absNodePath_);
+            break;
+        case CtsNodeCmd::WHY:
+            os += CtsApi::why(absNodePath_);
+            break;
+        case CtsNodeCmd::NO_CMD:
+            break;
+        default:
+            throw std::runtime_error("CtsNodeCmd::print_only : Unrecognised command");
+            break;
+    }
+}
+
+bool CtsNodeCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<CtsNodeCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (api_ != the_rhs->api())
+        return false;
+    if (absNodePath_ != the_rhs->absNodePath())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+bool CtsNodeCmd::isWrite() const {
+    switch (api_) {
+        case CtsNodeCmd::GET:
+            return false;
+            break; // read only
+        case CtsNodeCmd::GET_STATE:
+            return false;
+            break; // read only
+        case CtsNodeCmd::MIGRATE:
+            return false;
+            break; // read only
+        case CtsNodeCmd::JOB_GEN:
+            return true;
+            break; // requires write privilege
+        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
+            return false;
+            break; // read only
+        case CtsNodeCmd::WHY:
+            return false;
+            break; // read only
+        case CtsNodeCmd::NO_CMD:
+            break;
+        default:
+            throw std::runtime_error("CtsNodeCmd::isWrite: Unrecognised command");
+            break;
+    }
+    assert(false);
+    return false;
+}
+
+const char* CtsNodeCmd::theArg() const {
+    switch (api_) {
+        case CtsNodeCmd::GET:
+            return CtsApi::getArg();
+            break;
+        case CtsNodeCmd::GET_STATE:
+            return CtsApi::get_state_arg();
+            break;
+        case CtsNodeCmd::MIGRATE:
+            return CtsApi::migrate_arg();
+            break;
+        case CtsNodeCmd::JOB_GEN:
+            return CtsApi::job_genArg();
+            break;
+        case CtsNodeCmd::CHECK_JOB_GEN_ONLY:
+            return CtsApi::checkJobGenOnlyArg();
+            break;
+        case CtsNodeCmd::WHY:
+            return CtsApi::whyArg();
+            break;
+        case CtsNodeCmd::NO_CMD:
+            break;
+        default:
+            throw std::runtime_error("CtsNodeCmd::theArg: Unrecognised command");
+            break;
+    }
+    assert(false);
+    return nullptr;
+}
+
+PrintStyle::Type_t CtsNodeCmd::show_style() const {
+    if (api_ == CtsNodeCmd::GET)
+        return PrintStyle::DEFS;
+    else if (api_ == CtsNodeCmd::GET_STATE)
+        return PrintStyle::STATE;
+    else if (api_ == CtsNodeCmd::MIGRATE)
+        return PrintStyle::MIGRATE;
+    return ClientToServerCmd::show_style();
+}
+
+int CtsNodeCmd::timeout() const {
+    if (api_ == CtsNodeCmd::GET) {
+        return time_out_for_load_sync_and_get();
+    }
+    if (api_ == CtsNodeCmd::MIGRATE) {
+        return 120;
+    }
+    return ClientToServerCmd::timeout();
+}
+
+STC_Cmd_ptr CtsNodeCmd::doHandleRequest(AbstractServer* as) const {
+    Defs* defs = as->defs().get();
+
+    switch (api_) {
+
+        case CtsNodeCmd::GET:
+        case CtsNodeCmd::MIGRATE:
+        case CtsNodeCmd::GET_STATE: {
+            // The client will configure the output display
+            as->update_stats().get_defs_++;
+            if (absNodePath_.empty()) {
+                // with migrate we need to get edit history.
+                return PreAllocatedReply::defs_cmd(as, (api_ == MIGRATE)); // if true, save edit history
+            }
+            // however request for a particular node, thats not there, treated as an error
+            node_ptr theNodeToReturn = find_node(defs, absNodePath_);
+            return PreAllocatedReply::node_cmd(as, theNodeToReturn);
+        }
+
+        case CtsNodeCmd::CHECK_JOB_GEN_ONLY: {
+            as->update_stats().node_check_job_gen_only_++;
+            job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
+            jobCtrl->set_node_path(absNodePath_);
+            defs->check_job_creation(jobCtrl);
+            if (!jobCtrl->get_error_msg().empty()) {
+                throw std::runtime_error(jobCtrl->get_error_msg());
+            }
+            break;
+        }
+
+        case CtsNodeCmd::JOB_GEN: {
+            as->update_stats().node_job_gen_++;
+
+            if (as->state() == SState::RUNNING) {
+
+                if (absNodePath_.empty()) {
+                    // If no path specified do a full job generation over all suites
+                    return doJobSubmission(as);
+                }
+
+                // Generate jobs for the given node, downwards
+                node_ptr theNode = find_node_for_edit(defs, absNodePath_);
+                Jobs jobs(theNode.get());
+                jobs.generate();
+            }
+            break;
+        }
+
+        case CtsNodeCmd::WHY: {
+            /// Why is actually invoked on client side.
+            /// Added as a command because:
+            ///    o documentation
+            ///    o allows use with group command, without any other changes
+            break;
+        }
+
+        case CtsNodeCmd::NO_CMD:
+        default:
+            throw std::runtime_error("CtsNodeCmd::doHandleRequest: Unrecognised command");
+            break;
+    }
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+bool CtsNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, absNodePath_);
+}
+
+static const char* job_gen_only_desc() {
+    return "Test hierarchical Job generation only, for chosen Node.\n"
+           "The jobs are generated independent of the dependencies\n"
+           "This will generate the jobs *only*, i.e. no job submission. Used for checking job generation only\n"
+           "  arg = node path | arg = NULL\n"
+           "     If no node path specified generates for all Tasks in the definition. For Test only";
+}
+
+static const char* job_gen_desc() { // dependency_dependent_job_submission
+    return "Job submission for chosen Node *based* on dependencies.\n"
+           "The server traverses the node tree every 60 seconds, and if the dependencies are free\n"
+           "does job generation and submission. Sometimes the user may free time/date dependencies\n"
+           "to avoid waiting for the server poll, this commands allows early job generation\n"
+           "  arg = node path | arg = NULL\n"
+           "     If no node path specified generates for full definition.";
+}
+
+static const char* why_desc() {
+    return "Show the reason why a node is not running.\n"
+           "Can only be used with the group command. The group command must include a \n"
+           "'get' command(i.e returns the server defs)\n"
+           "The why command take a optional string argument representing a node path\n"
+           "Will return reason why the node is holding and for all its children.\n"
+           "If no arguments supplied will report on all nodes\n"
+           "  arg = node path | arg = NULL\n"
+           "Usage:\n"
+           "  --group=\"get; why\"               # returns why for all holding nodes\n"
+           "  --group=\"get; why=/suite/family\" # returns why for a specific node";
+}
+
+static const char* get_desc() {
+    return "Get the suite definition or node tree in form that is re-parse able\n"
+           "Get all suite node tree's from the server and write to standard out.\n"
+           "The output is parse-able, and can be used to re-load the definition\n"
+           "  arg = NULL | arg = node path\n"
+           "Usage:\n"
+           "  --get     # gets the definition from the server,and writes to standard out\n"
+           "  --get=/s1 # gets the suite from the server,and writes to standard out";
+}
+
+static const char* get_state_desc() {
+    return "Get state data. For the whole suite definition or individual nodes.\n"
+           "This will include event, meter, node state, trigger and time state.\n"
+           "The output is written to standard out.\n"
+           "  arg = NULL | arg = node path\n"
+           "Usage:\n"
+           "  --get_state     # gets the definition from the server,and writes to standard out\n"
+           "  --get_state=/s1 # gets the suite from the server,and writes to standard out";
+}
+
+const char* migrate_desc() {
+    return "Used to print state of the definition returned from the server to standard output.\n"
+           "The node state is shown in the comments.\n"
+           "This is the format used in the check point file, but with indentation.\n"
+           "Since this is essentially the defs format with state in the comments,"
+           "it allows the definition to be migrated to future version of ecflow.\n"
+           "The output includes edit history but excludes externs.\n"
+           "When the definition is reloaded *NO* checking is done.\n"
+           "\n"
+           "The following shows a summary of the features associated with each choice:\n"
+           "                       --get  --get_state  --migrate\n"
+           "Auto generate externs    Yes    Yes          No\n"
+           "Checking on reload       Yes    Yes          No\n"
+           "Edit History             No     No           Yes\n"
+           "Show trigger AST         No     Yes          No\n\n"
+           "Usage:\n"
+           "    --migrate         # show all suites\n"
+           "    --migrate=/s1     # show state for suite s1\n";
+}
+
+void CtsNodeCmd::addOption(boost::program_options::options_description& desc) const {
+    switch (api_) {
+        case CtsNodeCmd::GET: {
+            desc.add_options()(CtsApi::getArg(), po::value<string>()->implicit_value(string()), get_desc());
+            break;
+        }
+        case CtsNodeCmd::GET_STATE: {
+            desc.add_options()(
+                CtsApi::get_state_arg(), po::value<string>()->implicit_value(string()), get_state_desc());
+            break;
+        }
+        case CtsNodeCmd::MIGRATE: {
+            desc.add_options()(CtsApi::migrate_arg(), po::value<string>()->implicit_value(string()), migrate_desc());
+            break;
+        }
+        case CtsNodeCmd::JOB_GEN: {
+            desc.add_options()(CtsApi::job_genArg(), po::value<string>()->implicit_value(string()), job_gen_desc());
+            break;
+        }
+        case CtsNodeCmd::CHECK_JOB_GEN_ONLY: {
+            desc.add_options()(
+                CtsApi::checkJobGenOnlyArg(), po::value<string>()->implicit_value(string()), job_gen_only_desc());
+            break;
+        }
+        case CtsNodeCmd::WHY: {
+            desc.add_options()(CtsApi::whyArg(), po::value<string>()->implicit_value(string()), why_desc());
+            break;
+        }
+        case CtsNodeCmd::NO_CMD:
+            assert(false);
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+
+void CtsNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    assert(api_ != CtsNodeCmd::NO_CMD);
+
+    if (ac->debug())
+        cout << "  CtsNodeCmd::create = '" << theArg() << "'.\n";
+
+    std::string absNodePath = vm[theArg()].as<std::string>();
+
+    cmd = std::make_shared<CtsNodeCmd>(api_, absNodePath);
+}
+
+std::ostream& operator<<(std::ostream& os, const CtsNodeCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(CtsNodeCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(CtsNodeCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/CtsNodeCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,74 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_CtsNodeCmd_HPP
+#define ecflow_base_cts_user_CtsNodeCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// Collection of commands, that all take a abs node path as their only arg
+// Reduce number of global symbols caused by boost serialisation
+// Previously they were all separate commands
+//
+// Client---(CtsNodeCmd(GET))---->Server-----(DefsCmd | SNodeCmd )--->client:
+// When doHandleRequest is called in the server it will return DefsCmd
+// The DefsCmd is used to transport the node tree hierarchy to/from the server
+//
+// CHECK_JOB_GEN_ONLY command will traverse hierarchically from the given node path
+// and force generation of jobs. (i.e independently of dependencies).
+// This is used in *testing* only, so that we can compare/test/verify
+// job generation with the old version.
+// if absNodepath is empty we will generate jobs for all tasks
+class CtsNodeCmd final : public UserCmd {
+public:
+    enum Api { NO_CMD, JOB_GEN, CHECK_JOB_GEN_ONLY, GET, WHY, GET_STATE, MIGRATE };
+    CtsNodeCmd(Api a, const std::string& absNodePath) : api_(a), absNodePath_(absNodePath) {}
+    explicit CtsNodeCmd(Api a) : api_(a) { assert(a != NO_CMD); }
+    CtsNodeCmd() = default;
+
+    Api api() const { return api_; }
+    const std::string& absNodePath() const { return absNodePath_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    PrintStyle::Type_t show_style() const override;
+
+    int timeout() const override;
+    bool isWrite() const override;
+    bool handleRequestIsTestable() const override { return !terminate_cmd(); }
+    bool why_cmd(std::string& nodePath) const override;
+    bool get_cmd() const override { return api_ == GET; }
+
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+
+private:
+    Api api_{NO_CMD};
+    std::string absNodePath_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_), CEREAL_NVP(absNodePath_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const CtsNodeCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(CtsNodeCmd)
+
+#endif /* ecflow_base_cts_user_UserCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,226 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/DeleteCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+DeleteCmd::DeleteCmd(const std::string& absNodePath, bool force) : group_cmd_(nullptr), force_(force) {
+    if (!absNodePath.empty())
+        paths_.push_back(absNodePath);
+}
+
+void DeleteCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::delete_node(paths_, force_)));
+}
+
+void DeleteCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::delete_node(paths_, force_));
+}
+
+void DeleteCmd::print(std::string& os, const std::string& path) const {
+    std::vector<std::string> paths(1, path);
+    user_cmd(os, CtsApi::to_string(CtsApi::delete_node(paths, force_)));
+}
+
+bool DeleteCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<DeleteCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (paths_ != the_rhs->paths())
+        return false;
+    if (force_ != the_rhs->force())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+const char* DeleteCmd::theArg() const {
+    return CtsApi::delete_node_arg();
+}
+
+STC_Cmd_ptr DeleteCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().node_delete_++;
+
+    if (paths_.empty()) {
+        if (!force_)
+            check_for_active_or_submitted_tasks(as, nullptr);
+        else
+            as->zombie_ctrl().add_user_zombies(as->defs(), CtsApi::delete_node_arg());
+        as->clear_defs();
+
+        // If this command is part of a group command, let the following sync command, know about the new handle
+        if (group_cmd_)
+            group_cmd_->set_client_handle(0);
+
+        // This will reset client defs and set client handle to zero on the client side.
+        return PreAllocatedReply::delete_all_cmd();
+    }
+    else {
+        std::stringstream ss;
+        Defs* defs = as->defs().get();
+
+        for (const auto& path : paths_) {
+
+            node_ptr theNodeToDelete = defs->findAbsNode(path);
+            if (!theNodeToDelete.get()) {
+                ss << "DeleteCmd:Delete: Could not find node at path '" << path << "'\n";
+                continue;
+            }
+            // since node is to be deleted, we need to record the paths.
+            add_node_path_for_edit_history(path);
+
+            if (!force_)
+                check_for_active_or_submitted_tasks(as, theNodeToDelete.get());
+            else
+                as->zombie_ctrl().add_user_zombies(theNodeToDelete.get(), CtsApi::delete_node_arg());
+
+            if (!defs->deleteChild(theNodeToDelete.get())) {
+                std::string errorMsg = "Delete: Cannot delete node " + theNodeToDelete->debugNodePath();
+                throw std::runtime_error(errorMsg);
+            }
+        }
+
+        std::string error_msg = ss.str();
+        if (!error_msg.empty()) {
+            throw std::runtime_error(error_msg);
+        }
+    }
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+bool DeleteCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, paths_);
+}
+
+void DeleteCmd::check_for_active_or_submitted_tasks(AbstractServer* as, Node* theNodeToDelete) {
+    vector<Task*> taskVec;
+    if (theNodeToDelete) {
+        theNodeToDelete->getAllTasks(taskVec);
+    }
+    else {
+        as->defs()->getAllTasks(taskVec);
+    }
+
+    vector<Task*> activeVec, submittedVec;
+    for (Task* t : taskVec) {
+        if (t->state() == NState::ACTIVE)
+            activeVec.push_back(t);
+        if (t->state() == NState::SUBMITTED)
+            submittedVec.push_back(t);
+    }
+    if (!activeVec.empty() || !submittedVec.empty()) {
+        std::stringstream ss;
+        if (theNodeToDelete)
+            ss << "Cannot delete node " << theNodeToDelete->debugNodePath() << "\n";
+        else
+            ss << "Cannot delete all nodes.\n";
+        if (!activeVec.empty()) {
+            ss << " There are " << activeVec.size() << " active tasks. First : " << activeVec.front()->absNodePath()
+               << "\n";
+        }
+        if (!submittedVec.empty()) {
+            ss << " There are " << submittedVec.size()
+               << " submitted tasks. First : " << submittedVec.front()->absNodePath() << "\n";
+        }
+        ss << "Please use the 'force' option to bypass this check, at the expense of creating zombies\n";
+        throw std::runtime_error(ss.str());
+    }
+}
+
+static const char* delete_node_desc() {
+    return "Deletes the specified node(s) or _ALL_ existing definitions( i.e delete all suites) in the server.\n"
+           "  arg1 = [ force | yes ](optional)  # Use this parameter to bypass checks, i.e. for active or submitted "
+           "tasks\n"
+           "  arg2 = yes(optional)              # Use 'yes' to bypass the confirmation prompt\n"
+           "  arg3 = node paths | _all_         # _all_ means delete all suites\n"
+           "                                    # node paths must start with a leading '/'\n"
+           "Usage:\n"
+           "  --delete=_all_                    # Delete all suites in server. Use with care.\n"
+           "  --delete=/suite/f1/t1             # Delete node at /suite/f1/t1. This will prompt\n"
+           "  --delete=force /suite/f1/t1       # Delete node at /suite/f1/t1 even if active or submitted\n"
+           "  --delete=force yes /s1 /s2        # Delete suites s1,s2 even if active or submitted, bypassing prompt";
+}
+
+void DeleteCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(CtsApi::delete_node_arg(), po::value<vector<string>>()->multitoken(), delete_node_desc());
+}
+
+void DeleteCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[theArg()].as<vector<string>>();
+    if (ac->debug())
+        dumpVecArgs(theArg(), args);
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
+
+    bool force      = false;
+    bool all        = false;
+    bool do_prompt  = true;
+    size_t vec_size = options.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (args[i] == "_all_")
+            all = true;
+        if (args[i] == "force")
+            force = true;
+        if (args[i] == "yes")
+            do_prompt = false;
+    }
+
+    if (!all && paths.empty()) {
+        std::stringstream ss;
+        ss << "Delete: No paths specified. Paths must begin with a leading '/' character\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (do_prompt) {
+        std::string confirm;
+        if (paths.empty())
+            confirm = "Are you sure you want to delete all the suites ? ";
+        else {
+            confirm          = "Are you sure want to delete nodes at paths:\n";
+            size_t path_size = paths.size();
+            for (size_t i = 0; i < path_size; i++) {
+                confirm += "  " + paths[i];
+                if (i == path_size - 1)
+                    confirm += " ? ";
+                else
+                    confirm += "\n";
+            }
+        }
+        prompt_for_confirmation(confirm);
+    }
+
+    cmd = std::make_shared<DeleteCmd>(paths, force);
+}
+
+std::ostream& operator<<(std::ostream& os, const DeleteCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(DeleteCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(DeleteCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/DeleteCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,66 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_DeleteCmd_HPP
+#define ecflow_base_cts_user_DeleteCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// DELETE If paths_ empty will delete all suites (beware) else will delete the chosen nodes.
+class DeleteCmd final : public UserCmd {
+public:
+    explicit DeleteCmd(const std::vector<std::string>& paths, bool force = false)
+        : group_cmd_(nullptr),
+          paths_(paths),
+          force_(force) {}
+    explicit DeleteCmd(const std::string& absNodePath, bool force = false);
+    DeleteCmd() = default;
+
+    const std::vector<std::string>& paths() const { return paths_; }
+    bool force() const { return force_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    void print(std::string& os, const std::string& path) const override;
+
+    bool equals(ClientToServerCmd*) const override;
+    bool isWrite() const override { return true; }
+
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+    // called in the server
+    void set_group_cmd(const GroupCTSCmd* cmd) override { group_cmd_ = cmd; }
+
+    static void check_for_active_or_submitted_tasks(AbstractServer* as, Node* theNodeToDelete);
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after handlerequest
+
+private:
+    const GroupCTSCmd* group_cmd_{nullptr}; // not persisted only used in server
+    std::vector<std::string> paths_;
+    bool force_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(paths_), CEREAL_NVP(force_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const DeleteCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(DeleteCmd)
+
+#endif /* ecflow_base_cts_user_DeleteCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,472 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/EditScriptCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/EcfFile.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool EditScriptCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<EditScriptCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (path_to_node_ != the_rhs->path_to_node()) {
+        return false;
+    }
+    if (edit_type_ != the_rhs->edit_type()) {
+        return false;
+    }
+    if (alias_ != the_rhs->alias()) {
+        return false;
+    }
+    if (run_ != the_rhs->run()) {
+        return false;
+    }
+    return UserCmd::equals(rhs);
+}
+
+static std::string to_string(EditScriptCmd::EditType et) {
+    switch (et) {
+        case EditScriptCmd::EDIT:
+            return "edit";
+            break;
+        case EditScriptCmd::PREPROCESS:
+            return "pre_process";
+            break;
+        case EditScriptCmd::SUBMIT:
+            return "submit";
+            break;
+        case EditScriptCmd::PREPROCESS_USER_FILE:
+            return "pre_process_file";
+            break;
+        case EditScriptCmd::SUBMIT_USER_FILE:
+            return "submit_file";
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    return "edit";
+}
+static std::vector<std::string> valid_edit_types() {
+    std::vector<std::string> edit_types;
+    edit_types.reserve(5);
+    edit_types.emplace_back("edit");
+    edit_types.emplace_back("pre_process");
+    edit_types.emplace_back("submit");
+    edit_types.emplace_back("pre_process_file");
+    edit_types.emplace_back("submit_file");
+    return edit_types;
+}
+
+void EditScriptCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::edit_script(path_to_node_, to_string(edit_type()), "", alias_, run_)));
+}
+
+void EditScriptCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::edit_script(path_to_node_, to_string(edit_type()), "", alias_, run_));
+}
+
+bool EditScriptCmd::isWrite() const {
+    switch (edit_type_) {
+        case EditScriptCmd::EDIT:
+            return false;
+            break;
+        case EditScriptCmd::PREPROCESS:
+            return false;
+            break;
+        case EditScriptCmd::PREPROCESS_USER_FILE:
+            return false;
+            break;
+        case EditScriptCmd::SUBMIT:
+            return true;
+            break;
+        case EditScriptCmd::SUBMIT_USER_FILE:
+            return true;
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    return false;
+}
+
+STC_Cmd_ptr EditScriptCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().edit_script_++;
+
+    node_ptr node =
+        find_node_for_edit(as->defs().get(), path_to_node_); // will throw if defs not defined, or node not found
+    Submittable* submittable = node->isSubmittable();
+    if (!submittable)
+        throw std::runtime_error("EditScriptCmd failed. Cannot locate task or alias at path " + path_to_node_);
+
+    /// record any changes made to suite. Needed for incremental updates
+    SuiteChangedPtr changed(node.get());
+
+    switch (edit_type_) {
+        case EditScriptCmd::EDIT: {
+
+            /// Find all the used variable in the script, i.e 'ecf file'
+            EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
+
+            /// This will throw std::runtime_error  for parse errors
+            /// Returns the script with the used variables added at the front of the file
+            // **********************************************************************
+            // Custom handling of dynamic variables, i.e ECF_TRYNO, ECF_PASS and
+            // any variable that embeds a try number, i.e. ECF_JOB, ECF_JOBOUT
+            // This is required since the try number is *always* incremented *before* job submission,
+            // hence the value extracted from the job file will not be accurate, hence we exclude it.
+            // This way at job submission we use the latest/correct value, which is in-sync with JOB OUTPUT
+            // Note: Otherwise the job output will not be in sync
+            //
+            // Custom handling of ECF_PORT,ECF_HOST,ECF_NAME do not show these variables, these veriables
+            // including ECF_PASS appear in the script. If the user accidentally edits them,
+            // Child communication with the server will be broken. Hence not shown
+            //
+            // This special handling is done in: EcfFile::get_used_variables
+            // **********************************************************************
+            std::string ret_file_contents;
+            ecf_file.edit_used_variables(ret_file_contents);
+            return PreAllocatedReply::string_cmd(ret_file_contents);
+        }
+
+        case EditScriptCmd::PREPROCESS: {
+
+            /// PRE_PROCESS the ecf file accessible by the server
+            /// We only *ONLY* want %include pre-processed and *NOT* variable substitution
+            /// The used variable will be listed at the top, the user can then edit these.
+            /// Hence it is NOT until -> EditScriptCmd::SUBMIT_USER_FILE do we need to variable substitute
+            EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
+
+            /// This function can throw std::runtime error if pre_processing fails
+            /// This *WILL* also include the used variables
+            std::string ret_file_contents;
+            ecf_file.pre_process(ret_file_contents);
+            return PreAllocatedReply::string_cmd(ret_file_contents);
+        }
+
+        case EditScriptCmd::PREPROCESS_USER_FILE: {
+
+            /// The file contents('user_file_contents_') here could have been edited by the user on the client side.
+            EcfFile ecf_file = submittable->locatedEcfFile(); // will throw std::runtime_error for errors
+
+            /// This function can throw std::runtime error if pre_processing fails
+            /// Does full pre-processing:
+            ///   - include pre-processing
+            ///   - variable substitution
+            ///   - remove comment and manual sections
+            ///   - ignore %noop
+            std::string ret_file_contents;
+            ecf_file.pre_process_user_file(user_file_contents_, ret_file_contents);
+            vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
+            return PreAllocatedReply::string_cmd(ret_file_contents);
+        }
+
+        case EditScriptCmd::SUBMIT: {
+
+            if (submittable->state() == NState::ACTIVE || submittable->state() == NState::SUBMITTED) {
+                std::stringstream ss;
+                ss << "Node " << path_to_node_ << " is already " << NState::toString(submittable->state()) << " : ";
+                throw std::runtime_error("EditScriptCmd:: failed for submit: " + ss.str());
+            }
+
+            /// Using the User edited variables, generate the job using the ECF/USR file accessible from the server
+            /// Convert from vector to map
+            NameValueMap user_variables_map;
+            for (const auto& user_variable : user_variables_) {
+                user_variables_map.insert(std::make_pair(user_variable.first, user_variable.second));
+            }
+
+            /// Do job submission, but creating .usr file first
+            /// This will *NOT* timeout, unlike server Job generation
+            JobsParam jobsParam(as->poll_interval(), true /* create jobs */); // spawn_jobs = true
+            jobsParam.set_user_edit_variables(user_variables_map);
+
+            // Custom handling of dynamic variables, i.e ECF_TRYNO, ECF_PASS and
+            // any variable that embeds a try number, i.e. ECF_JOB, ECF_JOBOUT
+            // This is required since the try number is *always* incremented *before* job submission,
+            // hence the value extracted from the job file will *not* be accurate, hence we exclude it form user
+            // variables
+            if (!submittable->submitJob(jobsParam)) {
+                throw std::runtime_error("EditScriptCmd:: failed for submit: " + jobsParam.getErrorMsg());
+            }
+            submittable->flag().set(ecf::Flag::USER_EDIT);
+            break;
+        }
+
+        case EditScriptCmd::SUBMIT_USER_FILE: {
+            /// The file contents('user_file_contents_') here could have been edited by the user on the client side.
+            /// ECF_HOME
+            /// If the selected node is an Alias, Just submit it. Since aliases can *NOT* have other aliases as children
+            if (!alias_ || submittable->isAlias()) {
+                if (submittable->state() == NState::ACTIVE || submittable->state() == NState::SUBMITTED) {
+                    std::stringstream ss;
+                    ss << "Node " << path_to_node_ << " is already " << NState::toString(submittable->state()) << " : ";
+                    throw std::runtime_error("EditScriptCmd:: failed for submit: " + ss.str());
+                }
+
+                /// Convert from vector to map
+                NameValueMap user_variables_map;
+                for (const auto& user_variable : user_variables_) {
+                    user_variables_map.insert(std::make_pair(user_variable.first, user_variable.second));
+                }
+
+                /// Do job submission, *USING* the user supplied file , will create .usr file
+                /// This will *NOT* timeout, unlike server Job generation
+                JobsParam jobsParam(as->poll_interval(), true /* create jobs */); //  spawn_jobs = true
+                jobsParam.set_user_edit_variables(user_variables_map);
+                jobsParam.set_user_edit_file(user_file_contents_);
+
+                if (!submittable->submitJob(jobsParam)) {
+                    vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
+                    throw std::runtime_error("EditScriptCmd::SUBMIT_USER_FILE: failed : " + jobsParam.getErrorMsg());
+                }
+                submittable->flag().set(ecf::Flag::USER_EDIT);
+            }
+            else {
+                // CREATE a Child Alias. The create alias and parent it to the Task., and choose to run or not.
+                Task* task = submittable->isTask();
+                if (!task) {
+                    vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
+                    throw std::runtime_error("EditScriptCmd::SUBMIT_USER_FILE: Aliases can only be created for a task. "
+                                             "Selected path is a Alias. Please select a Task path");
+                }
+                alias_ptr alias = task->add_alias(user_file_contents_, user_variables_);
+
+                if (run_) {
+                    /// This will *NOT* timeout, unlike server Job generation
+                    JobsParam jobsParam(as->poll_interval(), true /* create jobs */); // spawn jobs = true
+                    if (!alias->submitJob(jobsParam)) {
+                        vector<string>().swap(
+                            user_file_contents_); // clear user_file_contents_ and minimise its capacity
+                        throw std::runtime_error("EditScriptCmd::SUBMIT_USER_FILE: failed for Alias : " +
+                                                 jobsParam.getErrorMsg());
+                    }
+                    alias->flag().set(ecf::Flag::USER_EDIT);
+                }
+            }
+            break;
+        }
+
+        default:
+            assert(false);
+            break;
+    }
+
+    // Clear up memory allocated *ASAP*
+    // When dealing with several thousands strings, this makes a *HUGE* difference
+    vector<string>().swap(user_file_contents_); // clear user_file_contents_ and minimise its capacity
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+bool EditScriptCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, path_to_node_);
+}
+
+const char* EditScriptCmd::arg() {
+    return CtsApi::edit_script_arg();
+}
+const char* EditScriptCmd::desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Allows user to edit, pre-process and submit the script.\n"
+           "Will allow pre-processing of arbitrary file with 'pre_process_file' option\n"
+           " arg1 = path to task  # The path to the task/alias\n"
+           " arg2 = [ edit | pre_process | submit | pre_process_file | submit_file ]\n"
+           "    edit : will return the script file to standard out. The script will\n"
+           "           include used variables enclosed between %comment/%end at the\n"
+           "           start of the file\n"
+           "    pre_process: Will return the script file to standard out.The script will\n"
+           "                 include used variables enclosed between %comment/%end at the\n"
+           "                 start of the file and with all %include expanded\n"
+           "    submit: Will extract the used variables from the supplied file, i.e\n"
+           "            between the %comment/%end and use these them to generate the\n"
+           "            job using the ecf file accessible from the server\n"
+           "    pre_process_file: Will pre process the user supplied file.\n"
+           "                      Will expand includes,variable substitution,\n"
+           "                      remove manual & comment sections.\n"
+           "    submit_file: Like submit, but the supplied file, is submitted by the server\n"
+           "                 The last 2 options allow complete freedom to debug the script file\n"
+           " arg3 = [ path_to_script_file ]\n"
+           "          needed for option [  pre_process_file | submit_file ]\n"
+           " arg4 = create_alias (optional) default value is false, for use with 'submit_file' option\n"
+           " arg5 = no_run (optional) default value is false, i.e immediately run the alias\n"
+           "        is no_run is specified the alias in only created\n"
+           "Usage:\n"
+           "--edit_script=/path/to/task edit > script_file\n"
+           "   server returns script with the used variables to standard out\n"
+           "   The user can choose to edit this file\n\n"
+           "--edit_script=/path/to/task pre_process > pre_processed_script_file\n"
+           "  server will pre process the ecf file accessible from the server\n"
+           "  (i.e expand all %includes) and return the file to standard out\n\n"
+           "--edit_script=/path/to/task submit script_file\n"
+           "  Will extract the used variables in the 'script_file' and will uses these\n"
+           "  variables during variable substitution of the ecf file accessible by the\n"
+           "  server. This is then submitted as a job\n\n"
+           "--edit_script=/path/to/task pre_process_file file_to_pre_process\n"
+           "  The server will pre-process the user supplied file and return the contents\n"
+           "  to standard out. This pre-processing is the same as job file processing,\n"
+           "  but on a arbitrary file\n\n"
+           "--edit_script=/path/to/task submit_file file_to_submit\n"
+           "  Will extract the used variables in the 'file_to_submit' and will uses these\n"
+           "  variables during variable substitution, the file is then submitted for job\n"
+           "  generation by the server\n\n"
+           "--edit_script=/path/to/task submit_file file_to_submit create_alias\n"
+           "  Like the the previous example but will create and run as an alias";
+}
+
+void EditScriptCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(EditScriptCmd::arg(), po::value<vector<string>>()->multitoken(), EditScriptCmd::desc());
+}
+
+void EditScriptCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(EditScriptCmd::arg(), args);
+
+    std::stringstream ss;
+    if (args.size() < 2) {
+        ss << "EditScriptCmd:At least 2 arguments required:\n" << EditScriptCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+
+    string path_to_task               = args[0];
+    string edit_type_str              = args[1];
+    EditScriptCmd::EditType edit_type = EditScriptCmd::EDIT;
+
+    /// Check edit_type is valid
+    bool ok                             = false;
+    std::vector<std::string> edit_types = valid_edit_types();
+    for (const auto& i : edit_types) {
+        if (edit_type_str == i) {
+            if (edit_type_str == "edit")
+                edit_type = EditScriptCmd::EDIT;
+            else if (edit_type_str == "pre_process")
+                edit_type = EditScriptCmd::PREPROCESS;
+            else if (edit_type_str == "submit")
+                edit_type = EditScriptCmd::SUBMIT;
+            else if (edit_type_str == "pre_process_file")
+                edit_type = EditScriptCmd::PREPROCESS_USER_FILE;
+            else if (edit_type_str == "submit_file")
+                edit_type = EditScriptCmd::SUBMIT_USER_FILE;
+            else {
+                assert(false);
+            }
+            ok = true;
+            break;
+        }
+    }
+
+    if (!ok) {
+        ss << "The second argument(" << args[1] << ") to edit_script must be one of [ ";
+        for (size_t i = 0; i < edit_types.size(); ++i) {
+            if (i != 0)
+                ss << " | ";
+            ss << edit_types[i];
+        }
+        ss << "]\n" << EditScriptCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+
+    if (args.size() == 2) {
+        if (edit_type == EditScriptCmd::EDIT || edit_type == EditScriptCmd::PREPROCESS) {
+            cmd = std::make_shared<EditScriptCmd>(path_to_task, edit_type);
+            return;
+        }
+        else {
+            ss << "When two arguments specified, the second argument must be one of [ edit | pre_process ]\n"
+               << EditScriptCmd::desc();
+            throw ss.str();
+        }
+    }
+
+    bool create_alias = false; // for use with "submit_file" option only
+    bool run_alias    = true;  // for use with "submit_file" option only
+    for (size_t i = 0; i < args.size(); i++) {
+        if (i > 2 && args[i] == "create_alias")
+            create_alias = true;
+        if (i > 2 && args[i] == "no_run")
+            run_alias = false;
+    }
+    if ((create_alias || !run_alias) && edit_type != EditScriptCmd::SUBMIT_USER_FILE) {
+        ss << "The create_alias option is only valid when the second argument is 'submit_file' \n"
+           << EditScriptCmd::desc();
+        throw ss.str();
+    }
+
+    if (args.size() >= 3 && args.size() <= 5) {
+        string path_to_script = args[2];
+        std::vector<std::string> script_lines;
+
+        if (!fs::exists(path_to_script)) {
+            ss << "The script file specified '" << path_to_script << "' does not exist\n";
+            throw std::runtime_error(ss.str());
+        }
+        if (!File::splitFileIntoLines(path_to_script, script_lines)) {
+            ss << "Could not open script file " << path_to_script << " (" << strerror(errno) << ")";
+            throw std::runtime_error(ss.str());
+        }
+
+        if (edit_type == EditScriptCmd::SUBMIT || edit_type == EditScriptCmd::SUBMIT_USER_FILE) {
+            // extract the Used variables from the script file
+            NameValueMap used_variables_as_map;
+            EcfFile::extract_used_variables(used_variables_as_map, script_lines);
+
+            // Convert MAP to Vec
+            NameValueVec used_variables_as_vec;
+            for (const NameValueMap::value_type& pair : used_variables_as_map) {
+                used_variables_as_vec.push_back(std::make_pair(pair.first, pair.second));
+            }
+
+            if (edit_type == EditScriptCmd::SUBMIT) {
+                cmd = std::make_shared<EditScriptCmd>(path_to_task, used_variables_as_vec); // SUMBIT
+                return;
+            }
+
+            cmd = std::make_shared<EditScriptCmd>(
+                path_to_task, used_variables_as_vec, script_lines, create_alias, run_alias); // SUBMIT_USER_FILE
+            return;
+        }
+        else if (edit_type == EditScriptCmd::PREPROCESS_USER_FILE) {
+
+            cmd = std::make_shared<EditScriptCmd>(path_to_task, script_lines);
+            return;
+        }
+    }
+
+    ss << "Wrong number of arguments specified\n" << EditScriptCmd::desc();
+    throw std::runtime_error(ss.str());
+}
+
+std::ostream& operator<<(std::ostream& os, const EditScriptCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(EditScriptCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(EditScriptCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/EditScriptCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,102 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_EditScriptCmd_HPP
+#define ecflow_base_cts_user_EditScriptCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+//================================================================================
+// Paired with SStringCmd
+// Client---(EditScriptCmd)---->Server-----(SStringCmd)--->client:
+//================================================================================
+class EditScriptCmd final : public UserCmd {
+public:
+    enum EditType { EDIT, PREPROCESS, SUBMIT, PREPROCESS_USER_FILE, SUBMIT_USER_FILE };
+    EditScriptCmd(const std::string& path_to_node, EditType et) // EDIT or PREPROCESS
+        : edit_type_(et),
+          path_to_node_(path_to_node) {}
+
+    EditScriptCmd(const std::string& path_to_node, const NameValueVec& user_variables)
+        : edit_type_(SUBMIT),
+          path_to_node_(path_to_node),
+          user_variables_(user_variables) {}
+
+    EditScriptCmd(const std::string& path_to_node, const std::vector<std::string>& user_file_contents)
+        : edit_type_(PREPROCESS_USER_FILE),
+          path_to_node_(path_to_node),
+          user_file_contents_(user_file_contents) {}
+
+    EditScriptCmd(const std::string& path_to_node,
+                  const NameValueVec& user_variables,
+                  const std::vector<std::string>& user_file_contents,
+                  bool create_alias,
+                  bool run_alias)
+        : edit_type_(SUBMIT_USER_FILE),
+          path_to_node_(path_to_node),
+          user_file_contents_(user_file_contents),
+          user_variables_(user_variables),
+          alias_(create_alias),
+          run_(run_alias) {}
+
+    EditScriptCmd() = default;
+
+    // Uses by equals only
+    const std::string& path_to_node() const { return path_to_node_; }
+    EditType edit_type() const { return edit_type_; }
+    bool alias() const { return alias_; }
+    bool run() const { return run_; }
+
+    bool handleRequestIsTestable() const override { return false; }
+    bool isWrite() const override;
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override {
+        std::vector<std::string>().swap(user_file_contents_);
+    } /// run in the server, after doHandleRequest
+
+private:
+    EditType edit_type_{EDIT};
+    std::string path_to_node_;
+    mutable std::vector<std::string> user_file_contents_;
+    NameValueVec user_variables_;
+    bool alias_{false};
+    bool run_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(edit_type_),
+           CEREAL_NVP(path_to_node_),
+           CEREAL_NVP(user_file_contents_),
+           CEREAL_NVP(user_variables_),
+           CEREAL_NVP(alias_),
+           CEREAL_NVP(run_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const EditScriptCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(EditScriptCmd)
+
+#endif /* ecflow_base_cts_user_EditScriptCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ForceCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ForceCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ForceCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ForceCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,321 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/ForceCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+// ===================================================================================
+
+bool ForceCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<ForceCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (paths_ != the_rhs->paths()) {
+        return false;
+    }
+    if (stateOrEvent_ != the_rhs->stateOrEvent()) {
+        return false;
+    }
+    if (recursive_ != the_rhs->recursive()) {
+        return false;
+    }
+    if (setRepeatToLastValue_ != the_rhs->setRepeatToLastValue()) {
+        return false;
+    }
+    return UserCmd::equals(rhs);
+}
+
+void ForceCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::force(paths_, stateOrEvent_, recursive_, setRepeatToLastValue_)));
+}
+
+std::string ForceCmd::print_short() const {
+    std::vector<std::string> paths;
+    if (!paths_.empty())
+        paths.emplace_back(paths_[0]);
+
+    std::string os;
+    my_print_only(os, paths);
+
+    if (paths_.size() > 1) {
+        os += " : truncated : ";
+        os += ecf::convert_to<std::string>(paths_.size() - 1);
+        os += " paths *not* shown";
+    }
+    return os;
+}
+
+void ForceCmd::print_only(std::string& os) const {
+    my_print_only(os, paths_);
+}
+
+void ForceCmd::print(std::string& os, const std::string& path) const {
+    std::vector<std::string> paths(1, path);
+    my_print(os, paths);
+}
+
+void ForceCmd::my_print(std::string& os, const std::vector<std::string>& paths) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::force(paths, stateOrEvent_, recursive_, setRepeatToLastValue_)));
+}
+
+void ForceCmd::my_print_only(std::string& os, const std::vector<std::string>& paths) const {
+    os += CtsApi::to_string(CtsApi::force(paths, stateOrEvent_, recursive_, setRepeatToLastValue_));
+}
+
+STC_Cmd_ptr ForceCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().force_++;
+
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+
+    bool is_event_state = Event::isValidState(stateOrEvent_);
+    bool is_node_state  = NState::isValid(stateOrEvent_);
+    if (!is_node_state && !is_event_state) {
+        std::stringstream ss;
+        ss << "ForceCmd: failed. Invalid node state or event " << stateOrEvent_ << " expected one of "
+           << "[ unknown | complete | queued | submitted | active | aborted | clear | set ]";
+        throw std::runtime_error(ss.str());
+    }
+
+    use_EditHistoryMgr_ =
+        false; // will add edit history ourselves. Quicker than EditHistoryMgr when we have > 200000 paths
+
+    Defs* defs = as->defs().get();
+    string the_path;
+    string the_event;
+    std::stringstream error_ss;
+    for (const auto& path : paths_) {
+
+        the_path = path;
+        the_event.clear();
+        if (is_event_state) {
+            Extract::pathAndName(path, the_path, the_event);
+            if (the_path.empty() || the_event.empty()) {
+                error_ss << "ForceCmd: When 'set' or 'clear' is specified the path needs to include name of the event "
+                            "i.e --force=/path/to_task:event_name set\n";
+                continue;
+            }
+        }
+
+        node_ptr node = defs->findAbsNode(the_path);
+        if (!node.get()) {
+            error_ss << "ForceCmd: Could not find node at path " << the_path << "\n";
+            continue;
+        }
+
+        SuiteChangedPtr changed(node.get()); // Cater for suites in handles
+        node->flag().set(ecf::Flag::MESSAGE);
+        add_edit_history(defs, the_path);
+
+        if (is_node_state) {
+            /// We want this to have side effects. i.e bubble up state and re-queue if complete and has repeat's
+            /// **** However if state is SET to complete, we want to MISS the next time slot.
+            /// **** we need to mark the time dependency as *expired*, otherwise, it will be automatically reset to
+            /// QUEUED state
+            NState::State new_state = NState::toState(stateOrEvent_);
+            if (new_state == NState::COMPLETE) {
+                node->miss_next_time_slot();
+            }
+
+            if (new_state != NState::ACTIVE && new_state != NState::SUBMITTED) {
+                as->zombie_ctrl().add_user_zombies(node.get(), CtsApi::forceArg());
+            }
+
+            if (recursive_)
+                node->set_state_hierarchically(new_state, true /* force */);
+            else
+                node->set_state(new_state, true /* force */);
+
+            // force queued allows a job to re-run preserving job output.
+            // However other nodes may reference this nodes events/meters/late in trigger expression, hence
+            // reset events,meters and late flag ECFLOW-1617
+            if (new_state == NState::QUEUED)
+                node->reset_late_event_meters();
+        }
+        else {
+            // The recursive option is *NOT* applicable to events, hence ignore. According to Axel !!!!
+            if (stateOrEvent_ == Event::SET()) {
+                if (!node->set_event(the_event)) {
+                    error_ss << "ForceCmd: force set: failed for node(" << node->absNodePath() << ") cannot find event("
+                             << the_event << ")\n";
+                    continue;
+                }
+            }
+            else if (stateOrEvent_ == Event::CLEAR()) {
+                if (!node->clear_event(the_event)) {
+                    error_ss << "ForceCmd: force clear: failed for node(" << node->absNodePath()
+                             << ") cannot find event(" << the_event << ")\n";
+                    continue;
+                }
+            }
+            else
+                throw std::runtime_error("ForceCmd: Invalid parameter");
+        }
+
+        if (recursive_ && setRepeatToLastValue_) {
+            node->setRepeatToLastValueHierarchically();
+        }
+    }
+
+    std::string error_msg = error_ss.str();
+    if (!error_msg.empty()) {
+        throw std::runtime_error(error_msg);
+    }
+
+    /// Change of state, do immediate job generation
+    return doJobSubmission(as);
+}
+
+bool ForceCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, paths_);
+}
+
+const char* ForceCmd::arg() {
+    return CtsApi::forceArg();
+}
+const char* ForceCmd::desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Force a node to a given state, or set its event.\n"
+           "When a task is set to complete, it may be automatically re-queued if it has\n"
+           "multiple future time dependencies. However each time we force a complete it will\n"
+           "expire any time based attribute on that node. When the last time based attribute\n"
+           "expires, the node will stay in a complete state.\n"
+           "This behaviour allow Repeat values to be incremented interactively.\n"
+           "A repeat attribute is incremented when all the child nodes are complete\n"
+           "in this case the child nodes are automatically re-queued.\n"
+           "  arg1 = [ unknown | complete | queued | submitted | active | aborted | clear | set ]\n"
+           "  arg2 = (optional) recursive\n"
+           "         Applies state to node and recursively to all its children\n"
+           "  arg3 = (optional) full\n"
+           "         Set repeat variables to last value, only works in conjunction\n"
+           "         with recursive option\n"
+           "  arg4 = path_to_node or path_to_node:<event>: paths must begin with '/'\n"
+           "Usage:\n"
+           "  --force=complete /suite/t1 /suite/t2   # Set task t1 & t2 to complete\n"
+           "  --force=clear /suite/task:ev           # Clear the event 'ev' on task /suite/task\n"
+           "  --force=complete recursive /suite/f1   # Recursively set complete all children of /suite/f1\n"
+           "Effect:\n"
+           "  Consider the effect of forcing complete when the current time is at 09:00\n"
+           "  suite s1\n"
+           "     task t1; time 12:00             # will complete straight away\n"
+           "     task t2; time 10:00 13:00 01:00 # will complete on fourth attempt\n\n"
+           "  --force=complete /s1/t1 /s1/t2\n"
+           "  When we have a time range(i.e as shown with task t2), it is re-queued and the\n"
+           "  next time slot is incremented for each complete, until it expires, and the task completes.\n"
+           "  Use the Why command, to show next run time (i.e. next time slot)";
+}
+
+void ForceCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(ForceCmd::arg(), po::value<vector<string>>()->multitoken(), ForceCmd::desc());
+}
+void ForceCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(ForceCmd::arg(), args);
+
+    if (args.size() < 2) {
+        std::stringstream ss;
+        ss << "ForceCmd: At least two arguments expected for Force. Found " << args.size() << "\n"
+           << ForceCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(
+        args, options, paths, true /*treat_colon_in_path_as_path*/); // relative order is still preserved
+    if (paths.empty()) {
+        std::stringstream ss;
+        ss << "ForceCmd: No paths specified. Paths must begin with a leading '/' character\n"
+           << ForceCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+    if (options.empty()) {
+        std::stringstream ss;
+        ss << "ForceCmd: Invalid argument list. Expected of:\n"
+           << "[ unknown | complete | queued | submitted | active | aborted | clear | set]\n"
+           << ForceCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    bool is_valid_state       = false;
+    bool is_valid_event_state = false;
+    bool setRepeatToLastValue = false;
+    bool recursive            = false;
+    std::string stateOrEvent;
+    size_t options_size = options.size();
+    for (size_t i = 0; i < options_size; i++) {
+        if (Str::caseInsCompare(options[i], "recursive"))
+            recursive = true;
+        else if (Str::caseInsCompare(options[i], "full"))
+            setRepeatToLastValue = true;
+        else if (NState::isValid(options[i])) {
+            is_valid_state = true;
+            stateOrEvent   = options[i];
+        }
+        else if (Event::isValidState(options[i])) {
+            is_valid_event_state = true;
+            stateOrEvent         = options[i];
+        }
+        else {
+            std::stringstream ss;
+            ss << "ForceCmd: Invalid argument \n" << ForceCmd::desc() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    if (!is_valid_state && !is_valid_event_state) {
+        std::stringstream ss;
+        ss << "ForceCmd: Invalid node state or event expected one of:\n"
+           << "[ unknown | complete | queued | submitted | active | aborted | clear | set]\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (is_valid_event_state) {
+        // When set or clear used the path needs to include the name of the event:
+        size_t path_size = paths.size();
+        for (size_t i = 0; i < path_size; i++) {
+            string the_event, the_path;
+            Extract::pathAndName(paths[i], the_path, the_event);
+            if (the_path.empty() || the_event.empty()) {
+                std::stringstream ss;
+                ss << "ForceCmd: When 'set' or 'clear' is specified the path needs to include name of the event i.e\n";
+                ss << " --force=/path/to_task:event_name set\n";
+                throw std::runtime_error(ss.str());
+            }
+        }
+    }
+    cmd = std::make_shared<ForceCmd>(paths, stateOrEvent, recursive, setRepeatToLastValue);
+}
+
+std::ostream& operator<<(std::ostream& os, const ForceCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(ForceCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(ForceCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ForceCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ForceCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ForceCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ForceCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_ForceCmd_HPP
+#define ecflow_base_cts_user_ForceCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// Set the state on the affected node ONLY.
+// If recursive is used set the state, on node and  _ALL_ nodes _beneath
+// setRepeatToLastValue set, only make sense when used with recursive.
+// stateOrEvent, string is one of:
+// < unknown | suspended | complete | queued | submitted | active | aborted | clear | set >
+class ForceCmd final : public UserCmd {
+public:
+    ForceCmd(const std::vector<std::string>& paths,
+             const std::string& stateOrEvent,
+             bool recursive,
+             bool setRepeatToLastValue)
+        : paths_(paths),
+          stateOrEvent_(stateOrEvent),
+          recursive_(recursive),
+          setRepeatToLastValue_(setRepeatToLastValue) {}
+    ForceCmd(const std::string& path, const std::string& stateOrEvent, bool recursive, bool setRepeatToLastValue)
+        : paths_(std::vector<std::string>(1, path)),
+          stateOrEvent_(stateOrEvent),
+          recursive_(recursive),
+          setRepeatToLastValue_(setRepeatToLastValue) {}
+    ForceCmd() = default;
+
+    // Uses by equals only
+    const std::vector<std::string> paths() const { return paths_; }
+    const std::string& stateOrEvent() const { return stateOrEvent_; }
+    bool recursive() const { return recursive_; }
+    bool setRepeatToLastValue() const { return setRepeatToLastValue_; }
+
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    std::string print_short() const override;
+    void print_only(std::string&) const override;
+    void print(std::string& os, const std::string& path) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
+
+    void my_print(std::string& os, const std::vector<std::string>& paths) const;
+    void my_print_only(std::string& os, const std::vector<std::string>& paths) const;
+
+private:
+    std::vector<std::string> paths_;
+    std::string stateOrEvent_;
+    bool recursive_{false};
+    bool setRepeatToLastValue_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(paths_),
+           CEREAL_NVP(stateOrEvent_),
+           CEREAL_NVP(recursive_),
+           CEREAL_NVP(setRepeatToLastValue_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ForceCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(ForceCmd)
+
+#endif /* ecflow_base_cts_user_ForceCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,183 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/FreeDepCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+//=======================================================================================
+
+bool FreeDepCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<FreeDepCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (paths_ != the_rhs->paths()) {
+        return false;
+    }
+    if (all_ != the_rhs->all()) {
+        return false;
+    }
+    if (trigger_ != the_rhs->trigger()) {
+        return false;
+    }
+    if (date_ != the_rhs->date()) {
+        return false;
+    }
+    if (time_ != the_rhs->time()) {
+        return false;
+    }
+    return UserCmd::equals(rhs);
+}
+
+void FreeDepCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::freeDep(paths_, trigger_, all_, date_, time_)));
+}
+void FreeDepCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::freeDep(paths_, trigger_, all_, date_, time_));
+}
+void FreeDepCmd::print(std::string& os, const std::string& path) const {
+    std::vector<std::string> paths(1, path);
+    user_cmd(os, CtsApi::to_string(CtsApi::freeDep(paths, trigger_, all_, date_, time_)));
+}
+
+STC_Cmd_ptr FreeDepCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().free_dep_++;
+
+    Defs* defs = as->defs().get();
+    std::stringstream ss;
+    size_t vec_size = paths_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+
+        node_ptr node = find_node_for_edit_no_throw(defs, paths_[i]);
+        if (!node.get()) {
+            ss << "FreeDepCmd: Could not find node at path " << paths_[i] << "\n";
+            LOG(Log::ERR, "FreeDepCmd: Could not find node at path " << paths_[i]);
+            continue;
+        }
+
+        SuiteChangedPtr changed(node.get());
+        if (all_) {
+            node->freeTrigger();
+            node->freeHoldingDateDependencies();
+            node->freeHoldingTimeDependencies();
+        }
+        else {
+            if (trigger_)
+                node->freeTrigger();
+            if (date_)
+                node->freeHoldingDateDependencies();
+            if (time_)
+                node->freeHoldingTimeDependencies();
+        }
+    }
+
+    std::string error_msg = ss.str();
+    if (!error_msg.empty()) {
+        throw std::runtime_error(error_msg);
+    }
+
+    return doJobSubmission(as);
+}
+
+bool FreeDepCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, paths_);
+}
+
+const char* FreeDepCmd::arg() {
+    return CtsApi::freeDepArg();
+}
+const char* FreeDepCmd::desc() {
+    return "Free dependencies for a node. Defaults to triggers\n"
+           "After freeing the time related dependencies (i.e time,today,cron)\n"
+           "the next time slot will be missed.\n"
+           "  arg1 = (optional) trigger\n"
+           "  arg2 = (optional) all\n"
+           "         Free trigger, date and all time dependencies\n"
+           "  arg3 = (optional) date\n"
+           "         Free date dependencies\n"
+           "  arg4 = (optional) time\n"
+           "         Free all time dependencies i.e time, day, today, cron\n"
+           "  arg5 = List of paths. At least one required. Must start with a leading '/'\n"
+           "Usage:\n"
+           "  --free-dep=/s1/t1 /s2/t2   # free trigger dependencies for task's t1,t2\n"
+           "  --free-dep=all /s1/f1/t1   # free all dependencies of /s1/f1/t1\n"
+           "  --free-dep=date /s1/f1     # free holding date dependencies of /s1/f1";
+}
+
+void FreeDepCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(FreeDepCmd::arg(), po::value<vector<string>>()->multitoken(), FreeDepCmd::desc());
+}
+void FreeDepCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(FreeDepCmd::arg(), args);
+
+    if (args.size() < 1) {
+        std::stringstream ss;
+        ss << "FreeDepCmd: At least one arguments expected for Free dependencies. Found " << args.size() << "\n"
+           << FreeDepCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
+    if (paths.empty()) {
+        std::stringstream ss;
+        ss << "FreeDepCmd: No paths specified. Paths must begin with a leading '/' character\n"
+           << FreeDepCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    bool trigger    = options.empty(); // If no options default to freeing trigger dependencies
+    bool all        = false;
+    bool date       = false;
+    bool time       = false;
+    size_t vec_size = options.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (options[i] == "trigger")
+            trigger = true;
+        else if (options[i] == "all")
+            all = true;
+        else if (options[i] == "date")
+            date = true;
+        else if (options[i] == "time")
+            time = true;
+        else {
+            std::stringstream ss;
+            ss << "FreeDepCmd: Invalid argument(" << options[i] << ")\n" << FreeDepCmd::desc() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    assert(trigger || all || date || time); // at least one must be true
+    cmd = std::make_shared<FreeDepCmd>(paths, trigger, all, date, time);
+}
+
+std::ostream& operator<<(std::ostream& os, const FreeDepCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(FreeDepCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(FreeDepCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/FreeDepCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,93 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_FreeDepCmd_HPP
+#define ecflow_base_cts_user_FreeDepCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// Free Dependencies
+class FreeDepCmd final : public UserCmd {
+public:
+    explicit FreeDepCmd(const std::vector<std::string>& paths,
+                        bool trigger = true,
+                        bool all     = false, // day, date, time, today, trigger, cron
+                        bool date    = false,
+                        bool time    = false // includes time, day, date, today, cron
+                        )
+        : paths_(paths),
+          trigger_(trigger),
+          all_(all),
+          date_(date),
+          time_(time) {}
+
+    explicit FreeDepCmd(const std::string& path,
+                        bool trigger = true,
+                        bool all     = false, // day, date, time, today, trigger, cron
+                        bool date    = false,
+                        bool time    = false // includes time, day, date, today, cron
+                        )
+        : paths_(std::vector<std::string>(1, path)),
+          trigger_(trigger),
+          all_(all),
+          date_(date),
+          time_(time) {}
+
+    FreeDepCmd() = default;
+
+    // Uses by equals only
+    const std::vector<std::string>& paths() const { return paths_; }
+    bool trigger() const { return trigger_; }
+    bool all() const { return all_; }
+    bool date() const { return date_; }
+    bool time() const { return time_; }
+
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    void print(std::string& os, const std::string& path) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
+
+private:
+    std::vector<std::string> paths_;
+    bool trigger_{true};
+    bool all_{false};
+    bool date_{false};
+    bool time_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(paths_),
+           CEREAL_NVP(trigger_),
+           CEREAL_NVP(all_),
+           CEREAL_NVP(date_),
+           CEREAL_NVP(time_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const FreeDepCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(FreeDepCmd)
+
+#endif /* ecflow_base_cts_user_FreeDepCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,408 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
+
+#include <iostream>
+#include <memory>
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/ClientOptionsParser.hpp"
+#include "ecflow/base/cts/CtsCmdRegistry.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/ErrorCmd.hpp"
+#include "ecflow/base/stc/GroupSTCCmd.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/CommandLine.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+// #define DEBUG_GROUP_CMD 1
+
+//======================================================================================
+
+GroupCTSCmd::GroupCTSCmd(const std::string& cmdSeries, AbstractClientEnv* clientEnv) {
+    std::vector<std::string> individualCmdVec;
+    Str::split(cmdSeries, individualCmdVec, ";");
+    if (individualCmdVec.empty())
+        throw std::runtime_error("GroupCTSCmd::GroupCTSCmd: Please provide a list of ';' separated commands\n");
+    if (clientEnv->debug()) {
+        for (const auto& i : individualCmdVec) {
+            cout << "  CHILD COMMAND = " << i << "\n";
+        }
+    }
+
+    // Create a list of allowable commands for a group. i.e excludes help, group
+    po::options_description desc("Allowed group options");
+    CtsCmdRegistry cmdRegistry(false /* don't add group option */);
+    cmdRegistry.addCmdOptions(desc);
+
+    std::string subCmd;
+    for (auto aCmd : individualCmdVec) {
+        // massage the commands so that, we add -- at the start of each command.
+        // This is required by the boost program options.
+        ecf::algorithm::trim(aCmd);
+
+        subCmd.clear();
+        if (aCmd.find("--") == std::string::npos)
+            subCmd = "--";
+        subCmd += aCmd;
+
+        // handle case like: alter add variable FRED "fre d ddy" /suite
+        // If we have quote marks, then treat as one string,
+        // by replacing spaces with /b, then replacing back after the split
+        // This can only handle one level of quotes  hence can't cope with "fred \"joe fred\"
+        bool start_quote     = false;
+        bool replaced_spaces = false;
+        for (char& i : subCmd) {
+            if (start_quote) {
+                if (i == '"' || i == '\'')
+                    start_quote = false;
+                else if (i == ' ') {
+                    i               = '\b'; // "fre d ddy"  => "fre\bd\bddy"
+                    replaced_spaces = true;
+                }
+            }
+            else {
+                if (i == '"' || i == '\'')
+                    start_quote = true;
+            }
+        }
+
+        // Each sub command can have, many args
+        std::vector<std::string> subCmdArgs;
+        Str::split(subCmd, subCmdArgs);
+
+        if (replaced_spaces) {
+            for (auto& str : subCmdArgs) {
+                for (char& j : str) {
+                    if (j == '\b')
+                        j = ' '; // "fre\bd\bddy"  => "fre d ddy"
+                }
+            }
+        }
+
+        // The first will be the command, then the args. However from boost 1.59
+        // we must use --cmd=value, instead of --cmd value
+        if (!subCmdArgs.empty() && subCmdArgs.size() > 1 && subCmdArgs[0].find("=") == std::string::npos) {
+            subCmdArgs[0] += "=";
+            subCmdArgs[0] += subCmdArgs[1];
+            subCmdArgs.erase(subCmdArgs.begin() + 1); // remove, since we have added to first
+        }
+
+        /// Hack because we *can't* create program option with vector of strings, which can be empty
+        /// Hence if command is just show, add a dummy arg.
+        // if (aCmd == "show")  subCmdArgs.push_back("<dummy_arg>");
+
+        std::vector<std::string> theArgs;
+        theArgs.emplace_back("ClientInvoker");
+        std::copy(subCmdArgs.begin(), subCmdArgs.end(), std::back_inserter(theArgs));
+
+        // Create a Argv array from a vector of strings
+        CommandLine cl(theArgs);
+
+        if (clientEnv->debug()) {
+            cout << "  PROCESSING COMMAND = '" << subCmd << "' " << cl << "\n";
+        }
+
+        // Treat each sub command  separately
+        boost::program_options::variables_map group_vm;
+
+        // 1) Parse the CLI options
+        po::parsed_options parsed_options =
+            po::command_line_parser(cl.tokens())
+                .options(desc)
+                .style(po::command_line_style::unix_style ^ po::command_line_style::allow_short)
+                .extra_style_parser(ClientOptionsParser{})
+                .run();
+
+        // 2) Store the CLI options into the variable map
+        po::store(parsed_options, group_vm);
+        po::notify(group_vm);
+
+        Cmd_ptr childCmd;
+        cmdRegistry.parse(childCmd, group_vm, clientEnv);
+        addChild(childCmd);
+    }
+}
+
+bool GroupCTSCmd::isWrite() const {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        if (subCmd->isWrite())
+            return true;
+    }
+    return false;
+}
+
+bool GroupCTSCmd::cmd_updates_defs() const {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        if (subCmd->cmd_updates_defs())
+            return true;
+    }
+    return false;
+}
+
+bool GroupCTSCmd::get_cmd() const {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        if (subCmd->get_cmd())
+            return true;
+    }
+    return false;
+}
+
+PrintStyle::Type_t GroupCTSCmd::show_style() const {
+    // Only return non default style( PrintStyle::NOTHING ) if sub command
+    // contains a show cmd
+    for (Cmd_ptr subCmd : cmdVec_) {
+        if (subCmd->show_cmd())
+            return subCmd->show_style();
+    }
+    return PrintStyle::NOTHING;
+}
+
+bool GroupCTSCmd::task_cmd() const {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        if (subCmd->task_cmd())
+            return true;
+    }
+    return false;
+}
+
+bool GroupCTSCmd::terminate_cmd() const {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        if (subCmd->terminate_cmd())
+            return true;
+    }
+    return false;
+}
+
+bool GroupCTSCmd::why_cmd(std::string& nodePath) const {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        if (subCmd->why_cmd(nodePath))
+            return true;
+    }
+    return false;
+}
+
+void GroupCTSCmd::print(std::string& os) const {
+    std::string ret;
+    size_t the_size = cmdVec_.size();
+    for (size_t i = 0; i < the_size; i++) {
+        if (i != 0)
+            ret += "; ";
+        cmdVec_[i]->print_only(ret); //  avoid overhead of user@host for each child command
+    }
+    user_cmd(os, CtsApi::group(ret));
+}
+
+std::string GroupCTSCmd::print_short() const {
+    std::string ret;
+    size_t the_size = cmdVec_.size();
+    for (size_t i = 0; i < the_size; i++) {
+        if (i != 0)
+            ret += "; ";
+        ret +=
+            cmdVec_[i]
+                ->print_short(); // limit number of paths shown and avoid overhead of user@host for each child command
+    }
+    return CtsApi::group(ret);
+}
+
+bool GroupCTSCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<GroupCTSCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+
+    const std::vector<Cmd_ptr>& rhsCmdVec = the_rhs->cmdVec();
+    if (cmdVec_.size() != rhsCmdVec.size())
+        return false;
+
+    for (size_t i = 0; i < cmdVec_.size(); i++) {
+        if (!cmdVec_[i]->equals(rhsCmdVec[i].get())) {
+            return false;
+        }
+    }
+
+    return UserCmd::equals(rhs);
+}
+
+void GroupCTSCmd::addChild(Cmd_ptr childCmd) {
+    assert(childCmd.get()); // Dont add NULL children
+    cmdVec_.push_back(childCmd);
+}
+
+void GroupCTSCmd::setup_user_authentification(const std::string& user, const std::string& passwd) {
+    UserCmd::setup_user_authentification(user, passwd);
+    for (auto& i : cmdVec_) {
+        i->setup_user_authentification(user, passwd);
+    }
+}
+
+bool GroupCTSCmd::setup_user_authentification(AbstractClientEnv& env) {
+    if (!UserCmd::setup_user_authentification(env))
+        return false;
+    for (auto& i : cmdVec_) {
+        if (!i->setup_user_authentification(env))
+            return false;
+    }
+    return true;
+}
+
+void GroupCTSCmd::setup_user_authentification() {
+    UserCmd::setup_user_authentification();
+    for (auto& i : cmdVec_) {
+        i->setup_user_authentification();
+    }
+}
+
+void GroupCTSCmd::add_edit_history(Defs* defs) const {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        subCmd->add_edit_history(defs);
+    }
+}
+
+void GroupCTSCmd::cleanup() {
+    for (Cmd_ptr subCmd : cmdVec_) {
+        subCmd->cleanup();
+    }
+}
+
+bool GroupCTSCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& errorMsg) const {
+    // Can only run Group cmd if all child commands authenticate
+    size_t cmd_vec_size = cmdVec_.size();
+    for (size_t i = 0; i < cmd_vec_size; i++) {
+        if (!cmdVec_[i]->authenticate(as, errorMsg)) {
+
+            // Log authentication failure:
+            std::string ss;
+            ss += "GroupCTSCmd::authenticate failed: for ";
+            cmdVec_[i]->print(ss);
+            std::stringstream stream;
+            stream << errorMsg;
+            ss += stream.str();
+            log(Log::ERR, ss); // will automatically add end of line
+
+#ifdef DEBUG_GROUP_CMD
+            std::cout << "GroupCTSCmd::authenticate failed for " << ss << "\n";
+#endif
+            return false;
+        }
+    }
+    return true;
+}
+
+// in the server
+void GroupCTSCmd::set_client_handle(int client_handle) const {
+    size_t cmd_vec_size = cmdVec_.size();
+    if (cmd_vec_size >= 2) {
+        cmdVec_[1]->set_client_handle(client_handle);
+    }
+}
+
+STC_Cmd_ptr GroupCTSCmd::doHandleRequest(AbstractServer* as) const {
+#ifdef DEBUG_GROUP_CMD
+    std::cout << "GroupCTSCmd::doHandleRequest cmdVec_.size() = " << cmdVec_.size() << "\n";
+#endif
+    // ecf::LogTimer timer(" GroupCTSCmd::doHandleRequest");
+
+    as->update_stats().group_cmd_++;
+
+    std::shared_ptr<GroupSTCCmd> theReturnedGroupCmd = std::make_shared<GroupSTCCmd>();
+
+    // For the command to succeed all children MUST succeed
+    size_t cmd_vec_size = cmdVec_.size();
+    for (size_t i = 0; i < cmd_vec_size; i++) {
+#ifdef DEBUG_GROUP_CMD
+        std::cout << "  GroupCTSCmd::doHandleRequest calling ";
+        string ret;
+        cmdVec_[i]->print(ret);
+        cout << ret << "\n"; // std::cout << "\n";
+#endif
+        // Let child know about Group command.
+        // Only used by ClientHandleCmd and DeleteCmd to transfer client_handle to the sync cmd, in *this* group
+        cmdVec_[i]->set_group_cmd(this);
+
+        STC_Cmd_ptr theReturnCmd;
+        try {
+            theReturnCmd = cmdVec_[i]->doHandleRequest(as);
+        }
+        catch (std::exception& e) {
+            cmdVec_[i]->cleanup(); // recover memory asap, important when cmd has a large number of paths.
+            theReturnedGroupCmd->addChild(std::make_shared<ErrorCmd>(e.what()));
+            continue;
+        }
+        cmdVec_[i]->cleanup(); // recover memory asap, important when cmd has a large number of paths.
+
+#ifdef DEBUG_GROUP_CMD
+        std::cout << " return Cmd = ";
+        theReturnCmd->print(std::cout);
+        std::cout << " to client\n";
+#endif
+
+        if (theReturnCmd->is_returnable_in_group_cmd()) {
+            theReturnedGroupCmd->addChild(theReturnCmd);
+            continue;
+        }
+    }
+
+    if (theReturnedGroupCmd->cmdVec().empty()) {
+        // Nothing to return, i.e. no Defs, Node or Log file
+        return PreAllocatedReply::ok_cmd();
+    }
+
+    return theReturnedGroupCmd;
+}
+
+const char* GroupCTSCmd::arg() {
+    return CtsApi::groupArg();
+}
+const char* GroupCTSCmd::desc() {
+    return "Allows a series of ';' separated commands to be grouped and executed as one.\n"
+           "Some commands like halt, shutdown and terminate will prompt the user. To bypass the prompt\n"
+           "provide 'yes' as an additional parameter. See example below.\n"
+           "  arg = string\n"
+           "Usage:\n"
+           "   --group=\"halt=yes; reloadwsfile; restart;\"\n"
+           "                                 # halt server,bypass the confirmation prompt,\n"
+           "                                 # reload white list file, restart server\n"
+           "   --group=\"get; show\"           # get server defs, and write to standard output\n"
+           "   --group=\"get=/s1; show state\" # get suite 's1', and write state to standard output";
+}
+
+void GroupCTSCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(GroupCTSCmd::arg(), po::value<string>(), GroupCTSCmd::desc());
+}
+
+void GroupCTSCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    if (clientEnv->debug())
+        cout << "  " << arg() << ": Group Cmd '" << vm[arg()].as<std::string>() << "'\n";
+
+    // Parse and split commands and then parse individually. Assumes commands are separated by ';'
+    std::string cmdSeries = vm[GroupCTSCmd::arg()].as<std::string>();
+
+    cmd = std::make_shared<GroupCTSCmd>(cmdSeries, clientEnv);
+}
+
+std::ostream& operator<<(std::ostream& os, const GroupCTSCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(GroupCTSCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(GroupCTSCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/GroupCTSCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_GroupCTSCmd_HPP
+#define ecflow_base_cts_user_GroupCTSCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// The group command allows a series of commands to be be executed:
+//
+// Client---(GroupCTSCmd)---->Server-----(GroupSTCCmd | StcCmd(OK) | Error )--->client:
+//
+// If client->server contains GetDefs cmd and log file commands, then a group
+// command will be created for returning to the client
+//
+// If group command contains multiple [ CtsNodeCmd(GET) | LogCmd --get ] commands then
+// all the results are returned back to the client, HOWEVER when client calls
+// Cmd::defs() | Cmd::get_string() only the first data is returned.
+//
+class GroupCTSCmd final : public UserCmd {
+public:
+    GroupCTSCmd(const std::string& list_of_commands, AbstractClientEnv* clientEnv);
+    explicit GroupCTSCmd(Cmd_ptr cmd) : cli_(false) { addChild(cmd); }
+    GroupCTSCmd() = default;
+
+    bool isWrite() const override;
+    bool cmd_updates_defs() const override;
+
+    PrintStyle::Type_t show_style() const override;
+    bool get_cmd() const override;
+    bool task_cmd() const override;
+    bool terminate_cmd() const override;
+    bool why_cmd(std::string&) const override;
+    bool group_cmd() const override { return true; }
+
+    void set_client_handle(int client_handle) const; // used in group sync with client register
+
+    void print(std::string&) const override;
+    std::string print_short() const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    void addChild(Cmd_ptr childCmd);
+    const std::vector<Cmd_ptr>& cmdVec() const { return cmdVec_; }
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+    void add_edit_history(Defs*) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    void setup_user_authentification(const std::string& user, const std::string& passwd) override;
+    bool setup_user_authentification(AbstractClientEnv&) override;
+    void setup_user_authentification() override;
+
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    void cleanup() override; // cleanup all children
+
+private:
+    std::vector<Cmd_ptr> cmdVec_;
+    bool cli_{true};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(cmdVec_), CEREAL_NVP(cli_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const GroupCTSCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(GroupCTSCmd)
+
+#endif /* ecflow_base_cts_user_GroupCTSCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,231 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+LoadDefsCmd::LoadDefsCmd(const defs_ptr& defs, bool force) : force_(force) {
+    if (defs) {
+        defs->handle_migration();
+        defs->save_as_string(defs_, PrintStyle::NET);
+    }
+}
+
+LoadDefsCmd::LoadDefsCmd(const std::string& defs_filename,
+                         bool force,
+                         bool check_only,
+                         bool print,
+                         bool stats,
+                         const std::vector<std::pair<std::string, std::string>>& client_env)
+    : force_(force),
+      defs_filename_(defs_filename) {
+    if (defs_filename_.empty()) {
+        std::stringstream ss;
+        ss << "LoadDefsCmd::LoadDefsCmd: The pathname to the definition file must be provided\n" << LoadDefsCmd::desc();
+        throw std::runtime_error(ss.str());
+    }
+
+    defs_ptr defs = Defs::create();
+    std::string errMsg, warningMsg;
+
+    bool load_ok = false;
+
+    if (defs_filename.find("suite") != std::string::npos && defs_filename.find("endsuite") != std::string::npos) {
+        load_ok        = defs->restore_from_string(defs_filename, errMsg, warningMsg);
+        defs_filename_ = "";
+    }
+    else if (fs::exists(defs_filename)) {
+        // defs_filename is actually a file, open the file and read it. This is the method
+        // when loading definitions with ecflow_client
+
+        // At the end of the parse check the trigger/complete expressions and resolve in-limits
+
+        load_ok = defs->restore(defs_filename_, errMsg, warningMsg);
+    }
+
+    if (load_ok) {
+        defs->handle_migration();
+        defs->set_server().add_or_update_user_variables(client_env); // use in test environment
+
+        if (print) {
+            PrintStyle print_style(PrintStyle::NET); // should be same as MIGRATE, only differ on reload
+            cout << defs;
+        }
+        if (stats) {
+            cout << defs->stats();
+        }
+
+        if (!check_only && !stats && !print)
+            defs->save_as_string(defs_, PrintStyle::NET); // NET only takes affect on restore
+
+        // Output any warning to standard output
+        cout << warningMsg;
+    }
+    else {
+        std::stringstream ss;
+        ss << "\nLoadDefsCmd::LoadDefsCmd. Failed to parse file/definition " << defs_filename_ << "\n";
+        ss << errMsg;
+        throw std::runtime_error(ss.str());
+    }
+}
+
+bool LoadDefsCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<LoadDefsCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (!UserCmd::equals(rhs))
+        return false;
+    if (defs_ != the_rhs->defs_as_string())
+        return false;
+    return true;
+}
+
+STC_Cmd_ptr LoadDefsCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().load_defs_++;
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+
+    if (!defs_.empty()) {
+
+        // Parse the string and load the defs file into memory.
+        std::string errMsg, warningMsg;
+        defs_ptr defs = Defs::create();
+        if (!defs->restore_from_string(defs_, errMsg, warningMsg)) {
+            std::stringstream ss;
+            ss << "LoadDefsCmd::doHandleRequest : Could not parse file " << defs_filename_ << " : " << errMsg;
+            throw std::runtime_error(ss.str());
+        }
+
+        // After the updateDefs, defs will be left with NO suites.
+        // Can't really used defs after this point
+        // *NOTE* Externs are not persisted. Hence calling check() will report
+        // all errors, references are not resolved.
+        as->updateDefs(defs, force_);
+
+        LOG_ASSERT(defs->suiteVec().size() == 0, "Expected suites to be transferred to server defs");
+    }
+    LOG_ASSERT(as->defs()->externs().size() == 0, "Expected server to have no externs");
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+void LoadDefsCmd::print(std::string& os) const {
+    /// If defs_filename_ is empty, the Defs was a in memory defs.
+    if (defs_filename_.empty()) {
+        user_cmd(
+            os, CtsApi::to_string(CtsApi::loadDefs("<in-memory-defs>", force_, false /*check_only*/, false /*print*/)));
+        return;
+    }
+    user_cmd(os, CtsApi::to_string(CtsApi::loadDefs(defs_filename_, force_, false /*check_only*/, false /*print*/)));
+}
+void LoadDefsCmd::print_only(std::string& os) const {
+    if (defs_filename_.empty()) {
+        os += CtsApi::to_string(CtsApi::loadDefs("<in-memory-defs>", force_, false /*check_only*/, false /*print*/));
+        return;
+    }
+    os += CtsApi::to_string(CtsApi::loadDefs(defs_filename_, force_, false /*check_only*/, false /*print*/));
+}
+
+const char* LoadDefsCmd::arg() {
+    return CtsApi::loadDefsArg();
+}
+const char* LoadDefsCmd::desc() {
+    return "Check and load definition or checkpoint file into server.\n"
+           "The loaded definition will be checked for valid trigger and complete expressions,\n"
+           "additionally in-limit references to limits will be validated.\n"
+           "If the server already has the 'suites' of the same name, then a error message is issued.\n"
+           "The suite's can be overwritten if the force option is used.\n"
+           "To just check the definition and not send to server, use 'check_only'\n"
+           "This command can also be used to load a checkpoint file into the server\n"
+           "  arg1 = path to the definition file or checkpoint file\n"
+           "  arg2 = (optional) [ force | check_only | print | stats ]  # default = false for all\n"
+           "Usage:\n"
+           "--load=/my/home/exotic.def               # will error if suites of same name exists\n"
+           "--load=/my/home/exotic.def force         # overwrite suite's of same name in the server\n"
+           "--load=/my/home/exotic.def check_only    # Just check, don't send to server\n"
+           "--load=/my/home/exotic.def stats         # Show defs statistics, don't send to server\n"
+           "--load=host1.3141.check                  # Load checkpoint file to the server\n"
+           "--load=host1.3141.check print            # print definition to standard out in defs format\n";
+}
+
+void LoadDefsCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(LoadDefsCmd::arg(), po::value<vector<string>>()->multitoken(), LoadDefsCmd::desc());
+}
+
+void LoadDefsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+    if (clientEnv->debug())
+        dumpVecArgs(LoadDefsCmd::arg(), args);
+
+    bool check_only = false;
+    bool force      = false;
+    bool print      = false;
+    bool stats      = false;
+    std::string defs_filename;
+    for (const auto& arg : args) {
+        if (arg == "force")
+            force = true;
+        else if (arg == "check_only")
+            check_only = true;
+        else if (arg == "print")
+            print = true;
+        else if (arg == "stats")
+            stats = true;
+        else
+            defs_filename = arg;
+    }
+    if (clientEnv->debug())
+        cout << "  LoadDefsCmd::create: Defs file '" << defs_filename << "'.\n";
+
+    cmd = LoadDefsCmd::create(defs_filename, force, check_only, print, stats, clientEnv);
+}
+
+Cmd_ptr LoadDefsCmd::create(const std::string& defs_filename,
+                            bool force,
+                            bool check_only,
+                            bool print,
+                            bool stats,
+                            AbstractClientEnv* clientEnv) {
+    // For test allow the server environment to be changed, i.e. allow us to inject ECF_CLIENT
+    // The server will also update the env on the defs, server will override client env, where they clash
+
+    // The constructor can throw if parsing of defs_filename fail's
+    std::shared_ptr<LoadDefsCmd> load_cmd =
+        std::make_shared<LoadDefsCmd>(defs_filename, force, check_only, print, stats, clientEnv->env());
+
+    // Don't send to server if checking, i.e cmd not set
+    if (check_only || stats || print)
+        return Cmd_ptr();
+
+    return load_cmd;
+}
+
+std::ostream& operator<<(std::ostream& os, const LoadDefsCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(LoadDefsCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(LoadDefsCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/LoadDefsCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_LoadDefsCmd_HPP
+#define ecflow_base_cts_user_LoadDefsCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// Will *load* the suites, into the server.
+// Additionally the server will try to resolve extern's. The extern are references
+// to Node, events, meters, limits, variables defined on another suite.
+class LoadDefsCmd final : public UserCmd {
+public:
+    explicit LoadDefsCmd(const defs_ptr& defs, bool force = false);
+    explicit LoadDefsCmd(const std::string& defs_filename,
+                         bool force      = false,
+                         bool check_only = false /* not persisted */,
+                         bool print      = false /* not persisted */,
+                         bool stats      = false /* not persisted */,
+                         const std::vector<std::pair<std::string, std::string>>& client_env =
+                             std::vector<std::pair<std::string, std::string>>());
+    LoadDefsCmd() = default;
+
+    // Uses by equals only
+    const std::string& defs_as_string() const { return defs_; }
+
+    bool isWrite() const override { return true; }
+    int timeout() const override { return time_out_for_load_sync_and_get(); }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+    static Cmd_ptr create(const std::string& defs_filename,
+                          bool force,
+                          bool check_only,
+                          bool print,
+                          bool stats,
+                          AbstractClientEnv* clientEnv);
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the command as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    bool force_{false};
+    std::string defs_;
+    std::string defs_filename_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(force_), CEREAL_NVP(defs_), CEREAL_NVP(defs_filename_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const LoadDefsCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(LoadDefsCmd)
+
+#endif /* ecflow_base_cts_user_LoadDefsCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,305 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/LogCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace ecf;
+using namespace std;
+namespace po = boost::program_options;
+
+LogCmd::LogCmd(LogApi a, int get_last_n_lines) : api_(a), get_last_n_lines_(get_last_n_lines) {
+    if (get_last_n_lines_ == 0)
+        get_last_n_lines_ = Log::get_last_n_lines_default();
+}
+
+LogCmd::LogCmd() : get_last_n_lines_(Log::get_last_n_lines_default()) {
+}
+
+LogCmd::LogCmd(const std::string& path)
+    : api_(NEW),
+      get_last_n_lines_(Log::get_last_n_lines_default()),
+      new_path_(path) {
+    // ECFLOW-154, If path to new log file is specified, it should only be checked by the server,
+    //             as that could be on a different machine.
+    // ECFLOW-174, Never get the full log, as this can make server consume to much memory
+    //             default taken from get_last_n_lines_default
+    // ECFLOW-377, should remove leading/trailing spaces from path
+    ecf::algorithm::trim(new_path_);
+}
+
+void LogCmd::print(std::string& os) const {
+    switch (api_) {
+        case LogCmd::GET:
+            user_cmd(os, CtsApi::to_string(CtsApi::getLog(get_last_n_lines_)));
+            break;
+        case LogCmd::CLEAR:
+            user_cmd(os, CtsApi::clearLog());
+            break;
+        case LogCmd::FLUSH:
+            user_cmd(os, CtsApi::flushLog());
+            break;
+        case LogCmd::NEW:
+            user_cmd(os, CtsApi::to_string(CtsApi::new_log(new_path_)));
+            break;
+        case LogCmd::PATH:
+            user_cmd(os, CtsApi::get_log_path());
+            break;
+        default:
+            throw std::runtime_error("LogCmd::print: Unrecognised log api command,");
+    }
+}
+void LogCmd::print_only(std::string& os) const {
+    switch (api_) {
+        case LogCmd::GET:
+            os += CtsApi::to_string(CtsApi::getLog(get_last_n_lines_));
+            break;
+        case LogCmd::CLEAR:
+            os += CtsApi::clearLog();
+            break;
+        case LogCmd::FLUSH:
+            os += CtsApi::flushLog();
+            break;
+        case LogCmd::NEW:
+            os += CtsApi::to_string(CtsApi::new_log(new_path_));
+            break;
+        case LogCmd::PATH:
+            os += CtsApi::get_log_path();
+            break;
+        default:
+            throw std::runtime_error("LogCmd::print: Unrecognised log api command,");
+    }
+}
+
+bool LogCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<LogCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (api_ != the_rhs->api())
+        return false;
+    if (get_last_n_lines_ != the_rhs->get_last_n_lines())
+        return false;
+    if (new_path_ != the_rhs->new_path())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+// changed for release 4.1.0
+bool LogCmd::isWrite() const {
+    switch (api_) {
+        case LogCmd::GET:
+            return false;
+            break;
+        case LogCmd::CLEAR:
+            return false;
+            break;
+        case LogCmd::FLUSH:
+            return false;
+            break;
+        case LogCmd::NEW:
+            return true;
+            break;
+        case LogCmd::PATH:
+            return false;
+            break;
+        default:
+            throw std::runtime_error("LogCmd::isWrite: Unrecognised log api command,");
+    }
+    return false;
+}
+
+STC_Cmd_ptr LogCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().log_cmd_++;
+
+    switch (api_) {
+        case LogCmd::GET:
+            return PreAllocatedReply::string_cmd(Log::instance()->contents(get_last_n_lines_));
+        case LogCmd::CLEAR:
+            Log::instance()->clear();
+            break;
+        case LogCmd::FLUSH:
+            Log::instance()->flush();
+            break;
+        case LogCmd::NEW: {
+            if (!new_path_.empty()) {
+                Log::instance()->new_path(new_path_); // will throw for errors
+
+                // *NOTE* calling --log=new <path> should be treated the *SAME* as editing ECF_LOG in the GUI
+                //        This is done adding it as a *USER* variable. This overloads the server variables
+                //        It also allows us to see the change in GUI. Note: Defs/server_variables are not synced
+                // ECFLOW-376
+                as->defs()->set_server().add_or_update_user_variables(Str::ECF_LOG(), Log::instance()->path());
+            }
+            else {
+                // User could have overridden ECF_LOG variable
+                // *FIRST* look at user variables, then look at *server* variables.
+                std::string log_file_name = as->defs()->server().find_variable(Str::ECF_LOG());
+
+                // ECFLOW-377 should remove leading/trailing spaces from path
+                ecf::algorithm::trim(log_file_name);
+
+                Log::instance()->new_path(log_file_name); // will throw for errors
+            }
+
+            as->stats().ECF_LOG_ = Log::instance()->path(); // do NOT update number of requests
+            break;
+        }
+        case LogCmd::PATH:
+            return PreAllocatedReply::string_cmd(Log::instance()->path());
+        default:
+            throw std::runtime_error("Unrecognised log api command,");
+    }
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* LogCmd::arg() {
+    return "log";
+}
+const char* LogCmd::desc() {
+    return "Get,clear,flush or create a new log file.\n"
+           "The user must ensure that a valid path is specified.\n"
+           "Specifying '--log=get' with a large number of lines from the server,\n"
+           "can consume a lot of **memory**. The log file can be a very large file,\n"
+           "hence we use a default of 100 lines, optionally the number of lines can be specified.\n"
+           " arg1 = [ get | clear | flush | new | path ]\n"
+           "  get -   Outputs the log file to standard out.\n"
+           "          defaults to return the last 100 lines\n"
+           "          The second argument can specify how many lines to return\n"
+           "  clear - Clear the log file of its contents.\n"
+           "  flush - Flush and close the log file. (only temporary) next time\n"
+           "          server writes to log, it will be opened again. Hence it best\n"
+           "          to halt the server first\n"
+           "  new -   Flush and close the existing log file, and start using the\n"
+           "          the path defined for ECF_LOG. By changing this variable\n"
+           "          a new log file path can be used\n"
+           "          Alternatively an explicit path can also be provided\n"
+           "          in which case ECF_LOG is also updated\n"
+           "  path -  Returns the path name to the existing log file\n"
+           " arg2 = [ new_path | optional last n lines ]\n"
+           "         if get specified can specify lines to get. Value must be convertible to an integer\n"
+           "         Otherwise if arg1 is 'new' then the second argument must be a path\n"
+           "Usage:\n"
+           "  --log=get                        # Write the last 100 lines of the log file to standard out\n"
+           "  --log=get 200                    # Write the last 200 lines of the log file to standard out\n"
+           "  --log=clear                      # Clear the log file. The log is now empty\n"
+           "  --log=flush                      # Flush and close log file, next request will re-open log file\n"
+           "  --log=new /path/to/new/log/file  # Close and flush log file, and create a new log file, updates ECF_LOG\n"
+           "  --log=new                        # Close and flush log file, and create a new log file using ECF_LOG "
+           "variable\n";
+}
+
+void LogCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(LogCmd::arg(), po::value<vector<string>>()->multitoken(), LogCmd::desc());
+}
+
+void LogCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(LogCmd::arg(), args);
+
+    if (!args.empty() && args[0] == "get") {
+
+        if (args.size() != 1 && args.size() != 2) {
+            std::stringstream ss;
+            ss << "LogCmd: Please use '--log==get 100' to get the log file contents from the server\n";
+            ss << "optionally an integer can be provide to specify the last number of lines\n";
+            throw std::runtime_error(ss.str());
+        }
+
+        if (args.size() == 1) {
+            // This will retrieve Log::get_last_n_lines_default() lines from the log file.
+            cmd = Cmd_ptr(new LogCmd(LogCmd::GET, Log::get_last_n_lines_default()));
+            return;
+        }
+
+        int value = Log::get_last_n_lines_default();
+        if (args.size() == 2) {
+            try {
+                value = ecf::convert_to<int>(args[1]);
+            }
+            catch (const ecf::bad_conversion&) {
+                throw std::runtime_error("LogCmd: Second argument must be a integer, i.e. --log get 100\n");
+            }
+        }
+
+        cmd = std::make_shared<LogCmd>(LogCmd::GET, value);
+        return;
+    }
+
+    if (!args.empty() && args[0] == "clear") {
+
+        if (args.size() != 1) {
+            std::stringstream ss;
+            ss << "LogCmd: Too many arguments. Please use " << CtsApi::clearLog() << " to clear the log file\n";
+            throw std::runtime_error(ss.str());
+        }
+        cmd = std::make_shared<LogCmd>(LogCmd::CLEAR);
+        return;
+    }
+    if (!args.empty() && args[0] == "flush") {
+
+        if (args.size() != 1) {
+            std::stringstream ss;
+            ss << "LogCmd: Too many arguments. Please use " << CtsApi::flushLog() << " to flush the log file\n";
+            throw std::runtime_error(ss.str());
+        }
+        cmd = std::make_shared<LogCmd>(LogCmd::FLUSH);
+        return;
+    }
+    if (!args.empty() && args[0] == "path") {
+
+        if (args.size() != 1) {
+            std::stringstream ss;
+            ss << "LogCmd: Too many arguments. Please use " << CtsApi::get_log_path() << " to get the log file path\n";
+            throw std::runtime_error(ss.str());
+        }
+        cmd = std::make_shared<LogCmd>(LogCmd::PATH);
+        return;
+    }
+    if (!args.empty() && args[0] == "new") {
+
+        if (args.size() > 2) {
+            std::stringstream ss;
+            ss << "LogCmd: Too many arguments.  Expected --log=new   OR   --log=new /path/to/newlog/file\n";
+            throw std::runtime_error(ss.str());
+        }
+        std::string path;
+        if (args.size() == 2) {
+            path = args[1];
+        }
+        cmd = std::make_shared<LogCmd>(path);
+        return;
+    }
+
+    std::stringstream ss;
+    ss << "LogCmd: The arguments have not been specified correctly\n" << LogCmd::desc();
+    throw std::runtime_error(ss.str());
+}
+
+std::ostream& operator<<(std::ostream& os, const LogCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(LogCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(LogCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,62 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_LogCmd_HPP
+#define ecflow_base_cts_user_LogCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+/// The LogCmd is paired with SStringCmd
+/// Client---(LogCmd)---->Server-----(SStringCmd)--->client:
+/// When doHandleRequest is called in the server it will return SStringCmd
+/// The SStringCmd is used to transport the log file contents to the client
+class LogCmd final : public UserCmd {
+public:
+    enum LogApi { GET, CLEAR, FLUSH, NEW, PATH };
+    explicit LogCmd(LogApi a,
+                    int get_last_n_lines = 0); // for zero we take default from log. Avoid adding dependency on log.hpp
+    explicit LogCmd(const std::string& path);  // NEW
+    LogCmd();
+
+    LogApi api() const { return api_; }
+    int get_last_n_lines() const { return get_last_n_lines_; }
+    const std::string& new_path() const { return new_path_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    bool isWrite() const override;
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    LogApi api_{LogCmd::GET};
+    int get_last_n_lines_; // default to 100 -> ECFLOW-174
+    std::string new_path_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_), CEREAL_NVP(get_last_n_lines_), CEREAL_NVP(new_path_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const LogCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(LogCmd)
+
+#endif /* ecflow_base_cts_user_LogCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,77 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/LogMessageCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+void LogMessageCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::logMsg(msg_));
+}
+void LogMessageCmd::print_only(std::string& os) const {
+    os += CtsApi::logMsg(msg_);
+}
+
+bool LogMessageCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<LogMessageCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (msg_ != the_rhs->msg())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+STC_Cmd_ptr LogMessageCmd::doHandleRequest(AbstractServer* as) const {
+    // ***** No need to log message here, already done via print, in base ****
+    as->update_stats().log_msg_cmd_++;
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* LogMessageCmd::arg() {
+    return CtsApi::logMsgArg();
+}
+const char* LogMessageCmd::desc() {
+    return "Writes the input string to the log file.\n"
+           "  arg1 = string\n"
+           "Usage:\n"
+           "  --msg=\"place me in the log file\"";
+}
+
+void LogMessageCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(LogMessageCmd::arg(), po::value<string>(), LogMessageCmd::desc());
+}
+
+void LogMessageCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
+    string msg = vm[arg()].as<string>();
+    if (ace->debug()) {
+        cout << "  LogMessageCmd::create arg = " << msg << "\n";
+    }
+    cmd = std::make_shared<LogMessageCmd>(msg);
+}
+
+std::ostream& operator<<(std::ostream& os, const LogMessageCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(LogMessageCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(LogMessageCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/LogMessageCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,50 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_LogMessageCmd_HPP
+#define ecflow_base_cts_user_LogMessageCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+/// Simply writes the message to the log file
+class LogMessageCmd final : public UserCmd {
+public:
+    explicit LogMessageCmd(const std::string& msg) : msg_(msg) {}
+    LogMessageCmd() = default;
+
+    const std::string& msg() const { return msg_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    std::string msg_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(msg_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const LogMessageCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(LogMessageCmd)
+
+#endif /* ecflow_base_cts_user_LogMessageCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/MoveCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/MoveCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/MoveCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/MoveCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,203 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/MoveCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/Openssl.hpp"
+    #include "ecflow/base/SslClient.hpp"
+#endif
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+namespace {
+
+/// Class to manage locking: Only unlock if acquired the lock,
+class Lock {
+public:
+    Lock(const std::string& user, AbstractServer* as) : as_(as) { ok_ = as->lock(user); }
+    ~Lock() {
+        if (ok_)
+            as_->unlock();
+    }
+    bool ok() const { return ok_; }
+
+private:
+    bool ok_;
+    AbstractServer* as_;
+};
+
+} // namespace
+
+//=======================================================================================
+
+MoveCmd::MoveCmd(const std::pair<std::string, std::string>& host_port, Node* src, const std::string& dest)
+    : src_node_(src->print(PrintStyle::NET)),
+      src_host_(host_port.first),
+      src_port_(host_port.second),
+      src_path_(src->absNodePath()),
+      dest_(dest) {
+}
+
+MoveCmd::MoveCmd()  = default;
+MoveCmd::~MoveCmd() = default;
+
+bool MoveCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<MoveCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (dest_ != the_rhs->dest()) {
+        return false;
+    }
+    if (src_node_ != the_rhs->src_node()) {
+        return false;
+    }
+    return UserCmd::equals(rhs);
+}
+
+void MoveCmd::print(std::string& os) const {
+    std::string ss;
+    ss += "Plug(Move) source(";
+    ss += src_host_;
+    ss += ":";
+    ss += src_port_;
+    ss += ":";
+    ss += src_path_;
+    ss += ") destination(";
+    ss += dest_;
+    ss += ")";
+    user_cmd(os, ss);
+}
+
+bool MoveCmd::check_source() const {
+    return !src_node_.empty();
+}
+
+STC_Cmd_ptr MoveCmd::doHandleRequest(AbstractServer* as) const {
+    Defs* defs = as->defs().get();
+
+    Lock lock(user(), as);
+    if (!lock.ok()) {
+        std::string errorMsg = "Plug(Move) command failed. User ";
+        errorMsg += as->lockedUser();
+        errorMsg += " already has an exclusive lock";
+        throw std::runtime_error(errorMsg);
+    }
+
+    if (!check_source()) {
+        throw std::runtime_error("Plug(Move) command failed. No source specified");
+    }
+
+    std::string error_msg;
+    node_ptr src_node = Node::create(src_node_, error_msg);
+    if (!error_msg.empty() || !src_node) {
+        throw std::runtime_error("Plug(Move) command failed. Error in source:\n" + error_msg);
+    }
+
+    // destNode can be NULL when we are moving a suite
+    node_ptr destNode;
+    if (!dest_.empty()) {
+
+        destNode = defs->findAbsNode(dest_);
+        if (!destNode.get()) {
+            std::string errorMsg = "Plug(Move) command failed. The destination path ";
+            errorMsg += dest_;
+            errorMsg += " does not exist on server";
+            throw std::runtime_error(errorMsg);
+        }
+    }
+    else {
+        if (!src_node->isSuite()) {
+            throw std::runtime_error("::Destination path can only be empty when moving a whole suite to a new server");
+        }
+    }
+
+    if (destNode.get()) {
+
+        // The destNode containing suite may be in a handle
+        SuiteChanged0 suiteChanged(destNode);
+
+        // If the destination is task, replace with its parent
+        Node* thedestNode = destNode.get();
+        if (thedestNode->isTask())
+            thedestNode = thedestNode->parent();
+
+        // check its ok to add
+        std::string errorMsg;
+        if (!thedestNode->isAddChildOk(src_node.get(), errorMsg)) {
+            std::string msg = "Plug(Move) command failed. ";
+            msg += errorMsg;
+            throw std::runtime_error(msg);
+        }
+
+        // pass ownership
+        if (!thedestNode->addChild(src_node)) {
+            // This should never fail !!!! else we have lost/ and leaked source node !!!!
+            throw std::runtime_error("Fatal error plug(move) command failed. cannot addChild");
+        }
+
+        add_node_for_edit_history(destNode);
+    }
+    else {
+
+        if (!src_node->isSuite())
+            throw std::runtime_error("plug(move): Source node was expected to be a suite");
+
+        // convert node_ptr to suite_ptr
+        suite_ptr the_source_suite = std::dynamic_pointer_cast<Suite>(src_node);
+
+        // The sourceSuite may be in a handle or pre-registered suite
+        SuiteChanged suiteChanged(the_source_suite);
+
+        defs->addSuite(the_source_suite);
+
+        add_node_for_edit_history(the_source_suite);
+    }
+
+    defs->set_most_significant_state();
+
+    // Ownership for src_node has been passed on.
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* MoveCmd::arg() {
+    return "move";
+}
+const char* MoveCmd::desc() {
+    return "The move command is an internal cmd, Called by the plug cmd. Does not appear on public api.";
+}
+
+void MoveCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(MoveCmd::arg(), po::value<vector<string>>()->multitoken(), MoveCmd::desc());
+}
+
+void MoveCmd::create(Cmd_ptr&, boost::program_options::variables_map&, AbstractClientEnv*) const {
+    assert(false);
+}
+
+std::ostream& operator<<(std::ostream& os, const MoveCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(MoveCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(MoveCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/MoveCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/MoveCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/MoveCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/MoveCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,67 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_MoveCmd_HPP
+#define ecflow_base_cts_user_MoveCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+class MoveCmd final : public UserCmd {
+public:
+    MoveCmd(const std::pair<std::string, std::string>& host_port, Node* src, const std::string& dest);
+    MoveCmd();
+    ~MoveCmd() override;
+
+    Node* source() const;
+    const std::string& src_node() const { return src_node_; }
+    const std::string& dest() const { return dest_; }
+
+    bool handleRequestIsTestable() const override { return false; }
+    bool isWrite() const override { return true; }
+
+    void print(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    bool check_source() const;
+
+private:
+    std::string src_node_;
+    std::string src_host_;
+    std::string src_port_;
+    std::string src_path_;
+    std::string dest_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(src_node_),
+           CEREAL_NVP(src_host_),
+           CEREAL_NVP(src_port_),
+           CEREAL_NVP(src_path_),
+           CEREAL_NVP(dest_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const MoveCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(MoveCmd)
+
+#endif /* ecflow_base_cts_user_MoveCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,130 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool OrderNodeCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<OrderNodeCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (absNodepath_ != the_rhs->absNodepath())
+        return false;
+    if (option_ != the_rhs->option())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+void OrderNodeCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::order(absNodepath_, NOrder::toString(option_))));
+}
+void OrderNodeCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::order(absNodepath_, NOrder::toString(option_)));
+}
+
+STC_Cmd_ptr OrderNodeCmd::doHandleRequest(AbstractServer* as) const {
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+
+    as->update_stats().order_node_++;
+
+    Defs* defs       = as->defs().get();
+    node_ptr theNode = find_node_for_edit(defs, absNodepath_);
+
+    Node* theParent = theNode->parent();
+    if (theParent)
+        theParent->order(theNode.get(), option_);
+    else
+        defs->order(theNode.get(), option_);
+
+    return doJobSubmission(as);
+}
+
+bool OrderNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, absNodepath_);
+}
+
+const char* OrderNodeCmd::arg() {
+    return CtsApi::orderArg();
+}
+const char* OrderNodeCmd::desc() {
+    return "Re-orders the nodes held by the server\n"
+           "  arg1 = node path\n"
+           "  arg2 = [ top | bottom | alpha | order | up | down | runtime]\n"
+           "It should be noted that in the absence of triggers and time/date dependencies,\n"
+           "the tasks are submitted in order.\n"
+           "This changes the order and hence affects the submission order::\n\n"
+           "   o top     raises the node within its parent, so that it is first\n"
+           "   o bottom  lowers the node within its parent, so that it is last\n"
+           "   o alpha   Arranges for all the peers of selected note to be sorted alphabetically (case-insensitive)\n"
+           "   o order   Arranges for all the peers of selected note to be sorted in reverse "
+           "alphabet(case-insensitive)\n"
+           "   o up      Moves the selected node up one place amongst its peers\n"
+           "   o down    Moves the selected node down one place amongst its peers\n\n"
+           "   o runtime Orders the nodes according to state change runtime\n"
+           "             for families by accumulated runtime of its children\n"
+           "             useful to submit the task that take longer earlier\n\n"
+           "This command can fail because:\n"
+           "- The node path does not exist in the server\n"
+           "- The order_type is not does not match one of arg2\n"
+           "Usage:\n"
+           "  --order=/suite/f1 top  # move node f1 to the top";
+}
+
+void OrderNodeCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(OrderNodeCmd::arg(), po::value<vector<string>>()->multitoken(), OrderNodeCmd::desc());
+}
+void OrderNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[OrderNodeCmd::arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(OrderNodeCmd::arg(), args);
+
+    if (args.size() != 2) {
+        std::stringstream ss;
+        ss << "OrderNodeCmd: Two arguments expected. Please specify one of:\n";
+        ss << OrderNodeCmd::arg() << " pathToNode top\n";
+        ss << OrderNodeCmd::arg() << " pathToNode bottom\n";
+        ss << OrderNodeCmd::arg() << " pathToNode alpha\n";
+        ss << OrderNodeCmd::arg() << " pathToNode order\n";
+        ss << OrderNodeCmd::arg() << " pathToNode up\n";
+        ss << OrderNodeCmd::arg() << " pathToNode down\n";
+        ss << OrderNodeCmd::arg() << " pathToNode runtime\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (!NOrder::isValid(args[1])) {
+        throw std::runtime_error("OrderNodeCmd: Invalid second option: please specify one of [ top, bottom, alpha, "
+                                 "order, up, down, runtime]\n");
+    }
+
+    cmd = std::make_shared<OrderNodeCmd>(args[0], NOrder::toOrder(args[1]));
+}
+
+std::ostream& operator<<(std::ostream& os, const OrderNodeCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(OrderNodeCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(OrderNodeCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/OrderNodeCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_OrderNodeCmd_HPP
+#define ecflow_base_cts_user_OrderNodeCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+#include "ecflow/core/NOrder.hpp"
+
+class OrderNodeCmd final : public UserCmd {
+public:
+    OrderNodeCmd(const std::string& absNodepath, NOrder::Order op) : absNodepath_(absNodepath), option_(op) {}
+    OrderNodeCmd() = default;
+
+    const std::string& absNodepath() const { return absNodepath_; }
+    NOrder::Order option() const { return option_; }
+
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+
+private:
+    std::string absNodepath_;
+    NOrder::Order option_{NOrder::TOP};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(absNodepath_), CEREAL_NVP(option_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const OrderNodeCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(OrderNodeCmd)
+
+#endif /* ecflow_base_cts_user_OrderNodeCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/PathsCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/PathsCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/PathsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/PathsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,689 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+
+#include <algorithm>
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/cts/user/DeleteCmd.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+PathsCmd::PathsCmd(Api api, const std::string& absNodePath, bool force) : api_(api), force_(force) {
+    if (!absNodePath.empty())
+        paths_.push_back(absNodePath);
+}
+
+void PathsCmd::print(std::string& os) const {
+    my_print(os, paths_);
+}
+
+std::string PathsCmd::print_short() const {
+    std::vector<std::string> paths;
+    if (!paths_.empty())
+        paths.emplace_back(paths_[0]);
+
+    std::string os;
+    my_print_only(os, paths);
+    if (paths_.size() > 1) {
+        os += " : truncated : ";
+        os += ecf::convert_to<std::string>(paths_.size() - 1);
+        os += " paths *not* shown";
+    }
+    return os;
+}
+
+void PathsCmd::print_only(std::string& os) const {
+    my_print_only(os, paths_);
+}
+
+void PathsCmd::print(std::string& os, const std::string& path) const {
+    std::vector<std::string> paths(1, path);
+    my_print(os, paths);
+}
+
+void PathsCmd::my_print(std::string& os, const std::vector<std::string>& paths) const {
+    switch (api_) {
+        case PathsCmd::SUSPEND:
+            user_cmd(os, CtsApi::to_string(CtsApi::suspend(paths)));
+            break;
+        case PathsCmd::RESUME:
+            user_cmd(os, CtsApi::to_string(CtsApi::resume(paths)));
+            break;
+        case PathsCmd::KILL:
+            user_cmd(os, CtsApi::to_string(CtsApi::kill(paths)));
+            break;
+        case PathsCmd::STATUS:
+            user_cmd(os, CtsApi::to_string(CtsApi::status(paths)));
+            break;
+        case PathsCmd::CHECK:
+            user_cmd(os, CtsApi::to_string(CtsApi::check(paths)));
+            break;
+        case PathsCmd::EDIT_HISTORY:
+            user_cmd(os, CtsApi::to_string(CtsApi::edit_history(paths)));
+            break;
+        case PathsCmd::ARCHIVE:
+            user_cmd(os, CtsApi::to_string(CtsApi::archive(paths, force_)));
+            break;
+        case PathsCmd::RESTORE:
+            user_cmd(os, CtsApi::to_string(CtsApi::restore(paths)));
+            break;
+        case PathsCmd::NO_CMD:
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+void PathsCmd::my_print_only(std::string& os, const std::vector<std::string>& paths) const {
+    switch (api_) {
+        case PathsCmd::SUSPEND:
+            os += CtsApi::to_string(CtsApi::suspend(paths));
+            break;
+        case PathsCmd::RESUME:
+            os += CtsApi::to_string(CtsApi::resume(paths));
+            break;
+        case PathsCmd::KILL:
+            os += CtsApi::to_string(CtsApi::kill(paths));
+            break;
+        case PathsCmd::STATUS:
+            os += CtsApi::to_string(CtsApi::status(paths));
+            break;
+        case PathsCmd::CHECK:
+            os += CtsApi::to_string(CtsApi::check(paths));
+            break;
+        case PathsCmd::EDIT_HISTORY:
+            os += CtsApi::to_string(CtsApi::edit_history(paths));
+            break;
+        case PathsCmd::ARCHIVE:
+            os += CtsApi::to_string(CtsApi::archive(paths, force_));
+            break;
+        case PathsCmd::RESTORE:
+            os += CtsApi::to_string(CtsApi::restore(paths));
+            break;
+        case PathsCmd::NO_CMD:
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+
+bool PathsCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<PathsCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (api_ != the_rhs->api())
+        return false;
+    if (paths_ != the_rhs->paths())
+        return false;
+    if (force_ != the_rhs->force())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+bool PathsCmd::isWrite() const {
+    switch (api_) {
+        case PathsCmd::SUSPEND:
+            return true;
+            break; // requires write privilege
+        case PathsCmd::RESUME:
+            return true;
+            break; // requires write privilege
+        case PathsCmd::KILL:
+            return true;
+            break; // requires write privilege, modifies Flag::KILLCMD_FAILED
+        case PathsCmd::STATUS:
+            return true;
+            break; // requires write privilege, modifies Flag::STATUSCMD_FAILED
+        case PathsCmd::CHECK:
+            return false;
+            break; // read only
+        case PathsCmd::EDIT_HISTORY: {
+            if (paths_.size() == 1 && paths_[0] == "clear")
+                return true; // requires write privilege
+            return false;
+            break; // read only
+        }
+        case PathsCmd::ARCHIVE:
+            return true;
+            break; // requires write privilege
+        case PathsCmd::RESTORE:
+            return true;
+            break; // requires write privilege
+        case PathsCmd::NO_CMD:
+            break;
+        default:
+            break;
+    }
+    assert(false);
+    return false;
+}
+
+const char* PathsCmd::theArg() const {
+    switch (api_) {
+        case PathsCmd::SUSPEND:
+            return CtsApi::suspend_arg();
+            break;
+        case PathsCmd::RESUME:
+            return CtsApi::resume_arg();
+            break;
+        case PathsCmd::KILL:
+            return CtsApi::kill_arg();
+            break;
+        case PathsCmd::STATUS:
+            return CtsApi::statusArg();
+            break;
+        case PathsCmd::CHECK:
+            return CtsApi::check_arg();
+            break;
+        case PathsCmd::EDIT_HISTORY:
+            return CtsApi::edit_history_arg();
+            break;
+        case PathsCmd::ARCHIVE:
+            return CtsApi::archive_arg();
+            break;
+        case PathsCmd::RESTORE:
+            return CtsApi::restore_arg();
+            break;
+        case PathsCmd::NO_CMD:
+            break;
+        default:
+            break;
+    }
+    assert(false);
+    return nullptr;
+}
+
+STC_Cmd_ptr PathsCmd::doHandleRequest(AbstractServer* as) const {
+    // LogTimer timer(" PathsCmd::doHandleRequest");
+
+    Defs* defs = as->defs().get();
+    std::stringstream ss;
+    switch (api_) {
+
+        case PathsCmd::SUSPEND: {
+            use_EditHistoryMgr_ =
+                false; // will add edit history ourselves. Quicker than EditHistoryMgr when we have > 200000 paths
+
+            as->update_stats().node_suspend_++;
+            for (const auto& path : paths_) {
+                node_ptr theNode = defs->findAbsNode(path);
+                if (!theNode.get()) {
+                    ss << "PathsCmd:Suspend: Could not find node at path '" << path << "'\n";
+                    LOG(Log::ERR, "Suspend: Could not find node at path " << path);
+                    continue;
+                }
+                SuiteChangedPtr changed(theNode.get());
+                theNode->suspend();
+                theNode->flag().set(ecf::Flag::MESSAGE);
+                add_edit_history(defs, path);
+                assert(isWrite()); // should only add edit history for write-able commands
+            }
+            break;
+        }
+
+        case PathsCmd::RESUME: {
+            use_EditHistoryMgr_ =
+                false; // will add edit history ourselves. Quicker than EditHistoryMgr when we have > 200000 paths
+
+            // At the end of resume, we need to traverse node tree, and do job submission
+            as->update_stats().node_resume_++;
+            for (const auto& path : paths_) {
+                node_ptr theNode = defs->findAbsNode(path);
+                if (!theNode.get()) {
+                    ss << "PathsCmd:Resume: Could not find node at path '" << path << "'\n";
+                    LOG(Log::ERR, "Resume: Could not find path " << path);
+                    continue;
+                }
+                SuiteChangedPtr changed(theNode.get());
+                theNode->resume();
+                theNode->flag().set(ecf::Flag::MESSAGE);
+                add_edit_history(defs, path);
+                assert(isWrite()); // should only add edit history for write-able commands
+
+                as->increment_job_generation_count(); // in case we throw below
+            }
+            break;
+        }
+
+        case PathsCmd::KILL: {
+            as->update_stats().node_kill_++;
+            for (const auto& path : paths_) {
+                node_ptr theNode = find_node_for_edit_no_throw(defs, path);
+                if (!theNode.get()) {
+                    ss << "PathsCmd:Kill: Could not find node at path '" << path << "'\n";
+                    LOG(Log::ERR, "Kill: Could not find node at path " << path);
+                    continue;
+                }
+                SuiteChanged0 changed(theNode);
+                theNode->kill(); // this can throw std::runtime_error
+            }
+            break;
+        }
+
+        case PathsCmd::EDIT_HISTORY: {
+            as->update_stats().node_edit_history_++;
+            if (paths_.empty())
+                throw std::runtime_error("No paths/options specified for edit history");
+            if (paths_.size() == 1 && paths_[0] == "clear") {
+                defs->clear_edit_history();
+                break;
+            }
+            // Only first path used
+            return PreAllocatedReply::string_vec_cmd(as->defs()->get_edit_history(paths_[0]));
+        }
+
+        case PathsCmd::ARCHIVE: {
+            use_EditHistoryMgr_ = false; // will add edit history ourselves
+
+            as->update_stats().node_archive_++;
+            if (paths_.empty())
+                throw std::runtime_error("No paths specified for archive");
+
+            // make sure paths don't overlap, Should not find same path up the hierarchy, which is also in paths_
+            std::vector<NodeContainer*> containers_to_archive;
+            containers_to_archive.reserve(paths_.size());
+            for (const auto& path : paths_) {
+                node_ptr theNode = defs->findAbsNode(path);
+                if (!theNode.get()) {
+                    ss << "PathsCmd:ARCHIVE: Could not find node at path '" << path << "'\n";
+                    LOG(Log::ERR, "ARCHIVE: Could not find node at path " << path);
+                    continue;
+                }
+                NodeContainer* container = theNode->isNodeContainer();
+                if (!container)
+                    continue;
+
+                bool unique  = true;
+                Node* parent = theNode->parent();
+                while (parent) {
+                    std::string abs_node_path = parent->absNodePath();
+                    if (find(paths_.begin(), paths_.end(), abs_node_path) != paths_.end()) {
+                        unique = false;
+                        break; // parent also in paths, so don't archive child
+                    }
+                    parent = parent->parent();
+                }
+                if (unique)
+                    containers_to_archive.push_back(container);
+            }
+
+            size_t vec_size = containers_to_archive.size();
+            for (size_t i = 0; i < vec_size; i++) {
+                NodeContainer* the_container = containers_to_archive[i];
+
+                if (!force_)
+                    DeleteCmd::check_for_active_or_submitted_tasks(as, the_container);
+                else
+                    as->zombie_ctrl().add_user_zombies(the_container, CtsApi::archive_arg());
+
+                SuiteChanged1 changed(the_container->suite());
+
+                the_container->flag().set(ecf::Flag::MESSAGE);
+                add_edit_history(defs, the_container->absNodePath());
+                assert(isWrite()); // should only add edit history for write-able commands
+
+                the_container->archive(); // this can throw std::runtime_error
+            }
+            break;
+        }
+
+        case PathsCmd::RESTORE: {
+            as->update_stats().node_restore_++;
+            if (paths_.empty())
+                throw std::runtime_error("No paths specified for restore");
+            for (const auto& path : paths_) {
+                node_ptr theNode = find_node_for_edit_no_throw(defs, path);
+                if (!theNode.get()) {
+                    ss << "PathsCmd:RESTORE: Could not find node at path '" << path << "'\n";
+                    LOG(Log::ERR, "RESTORE: Could not find node at path " << path);
+                    continue;
+                }
+                NodeContainer* container = theNode->isNodeContainer();
+                if (!container)
+                    continue;
+
+                SuiteChanged1 changed(container->suite());
+                container->restore(); // this can throw std::runtime_error
+            }
+            break;
+        }
+
+        case PathsCmd::STATUS: {
+            as->update_stats().node_status_++;
+            for (const auto& path : paths_) {
+                node_ptr theNode = find_node_for_edit_no_throw(defs, path);
+                if (!theNode.get()) {
+                    ss << "PathsCmd:Status: Could not find node at path '" << path << "'\n";
+                    LOG(Log::ERR, "Status: Could not find node at path " << path);
+                    continue;
+                }
+                if (!theNode->suite()->begun()) {
+                    std::stringstream mss;
+                    mss << "Status failed. For " << path << " The suite " << theNode->suite()->name()
+                        << " must be 'begun' first\n";
+                    throw std::runtime_error(mss.str());
+                }
+                SuiteChangedPtr changed(theNode.get());
+                theNode->status(); // this can throw std::runtime_error
+            }
+            break;
+        }
+
+        case PathsCmd::CHECK: {
+            as->update_stats().check_++;
+
+            if (paths_.empty()) {
+                // check all the defs,
+                std::string error_msg, warning_msg;
+                if (!defs->check(error_msg, warning_msg)) {
+                    error_msg += "\n";
+                    error_msg += warning_msg;
+                    return PreAllocatedReply::string_cmd(error_msg);
+                }
+                return PreAllocatedReply::string_cmd(warning_msg); // can be empty
+            }
+            else {
+                std::string acc_warning_msg;
+                for (const auto& path : paths_) {
+
+                    node_ptr theNodeToCheck = defs->findAbsNode(path);
+                    if (!theNodeToCheck.get()) {
+                        ss << "PathsCmd:Check: Could not find node at path '" << path << "'\n";
+                        LOG(Log::ERR, "Check: Could not find node at path " << path);
+                        continue;
+                    }
+
+                    std::string error_msg, warning_msg;
+                    if (!theNodeToCheck->check(error_msg, warning_msg)) {
+                        error_msg += "\n";
+                        error_msg += warning_msg;
+                        return PreAllocatedReply::string_cmd(error_msg);
+                    }
+                    acc_warning_msg += warning_msg;
+                }
+                std::string paths_not_fnd_error_msg = ss.str();
+                if (!paths_not_fnd_error_msg.empty())
+                    throw std::runtime_error(paths_not_fnd_error_msg);
+                return PreAllocatedReply::string_cmd(acc_warning_msg);
+            }
+            break;
+        }
+
+        case PathsCmd::NO_CMD:
+            assert(false);
+            break;
+
+        default:
+            assert(false);
+            break;
+    }
+
+    std::string error_msg = ss.str();
+    if (!error_msg.empty()) {
+        throw std::runtime_error(error_msg);
+    }
+
+    if (PathsCmd::RESUME == api_) {
+        // After resume we need to do job submission.
+        return doJobSubmission(as);
+    }
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+bool PathsCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, paths_);
+}
+
+static const char* get_check_desc() {
+    return "Checks the expression and limits in the server. Will also check trigger references.\n"
+           "Trigger expressions that reference paths that don't exist, will be reported as errors.\n"
+           "(Note: On the client side unresolved paths in trigger expressions must\n"
+           "have an associated 'extern' specified)\n"
+           "  arg = [ _all_ | / | list of node paths ]\n"
+           "Usage:\n"
+           "  --check=_all_           # Checks all the suites\n"
+           "  --check=/               # Checks all the suites\n"
+           "  --check=/s1 /s2/f1/t1   # Check suite /s1 and task t1";
+}
+
+static const char* get_kill_desc() {
+    return "Kills the job associated with the node.\n"
+           "If a family or suite is selected, will kill hierarchically.\n"
+           "Kill uses the ECF_KILL_CMD variable. After variable substitution it is invoked as a command.\n"
+           "The command should be written in such a way that the output is written to %ECF_JOB%.kill\n"
+           "as this allow the --file command to report the output: .e.e.\n"
+           " /home/ma/emos/bin/ecfkill %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1::\n"
+           "Usage::\n"
+           "   --kill=/s1/f1/t1 /s1/f2/t2 # kill the jobs for tasks t1 and t2\n"
+           "   --file=/s1/f1/t1 kill      # write to standard out the '.kill' file for task /s1/f1/t1";
+}
+const char* get_status_desc() {
+    return "Shows the status of a job associated with a task, in %ECF_JOB%.stat file\n"
+           "If a family or suite is selected, will invoke status command hierarchically.\n"
+           "Status uses the ECF_STATUS_CMD variable. After variable substitution it is invoked as a command.\n"
+           "The command should be written in such a way that the output is written to %ECF_JOB%.stat\n"
+           "This will allow the output of status command to be shown by the --file command\n"
+           "i.e /home/ma/emos/bin/ecfstatus  %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.stat 2>&1::\n"
+           "If the process id cannot be found on the remote system, then the status command can also\n"
+           "arrange for the task to be aborted\n"
+           "The status command can fail for the following reasons:\n"
+           " - ECF_STATUS_CMD not found\n"
+           " - variable substitution fails\n"
+           " - state is active but it can't find process id, i.e. ECF_RID\n"
+           " - the status command does not exit cleanly\n"
+           "When this happens a flag is set, STATUSCMD_FAILED, which is visible in the GUI\n"
+           "Usage::\n"
+           "   --status=/s1/f1/t1     # ECF_STATUS_CMD should output to %ECF_JOB%.stat\n"
+           "   --file=/s1/f1/t1 stat  # Return contents of %ECF_JOB%.stat file";
+}
+const char* get_edit_history_desc() {
+    return "Returns the edit history associated with a Node.\n"
+           "Can also be used to clear the edit history.\n"
+           "Usage::\n"
+           "   --edit_history=/s1/f1/t1  # return history of changes for the given node\n"
+           "   --edit_history=clear      # clear/purge *ALL* edit history from all nodes.\n";
+}
+const char* suspend_desc() {
+    return "Suspend the given node. This prevents job generation for the given node, or any child node.\n"
+           "Usage::\n"
+           "   --suspend=/s1/f1/t1   # suspend task s1/f1/t1\n"
+           "   --suspend=/s1 /s2     # suspend suites /s1 and /s2\n";
+}
+const char* resume_desc() {
+    return "Resume the given node. This allows job generation for the given node, or any child node.\n"
+           "Usage::\n"
+           "   --resume=/s1/f1/t1   # resume task s1/f1/t1\n"
+           "   --resume=/s1 /s2     # resume suites /s1 and /s2\n";
+}
+const char* archive_desc() {
+    return "Archives suite or family nodes *IF* they have child nodes(otherwise does nothing).\n"
+           "Saves the suite/family nodes to disk, and then removes the child nodes from the definition.\n"
+           "This saves memory in the server, when dealing with huge definitions that are not needed.\n"
+           "It improves time taken to checkpoint and reduces network bandwidth.\n"
+           "If the node is re-queued or begun, the child nodes are automatically restored.\n"
+           "Use --restore to reload the archived nodes manually\n"
+           "Care must be taken if you have trigger reference to the archived nodes\n"
+           "The nodes are saved to the file ECF_HOME/<hostname>.<port>.<ECF_NAME>.check,\n"
+           "where '/' has been replaced with ':' in ECF_NAME\n\n"
+           "Nodes like (family and suites) can also to automatically archived by using,\n"
+           "the 'autoarchive' attribute. The attribute is only applied once the node is complete\n\n"
+           "suite autoarchive\n"
+           " family f1\n"
+           "    autoarchive +01:00 # archive one hour after complete\n"
+           "    task t1\n"
+           " endfamily\n"
+           " family f2\n"
+           "     autoarchive 01:00 # archive at 1 am in morning after complete\n"
+           "    task t1\n"
+           " endfamily\n"
+           " family f3\n"
+           "    autoarchive 10     # archive 10 days after complete\n"
+           "    task t1\n"
+           " endfamily\n"
+           " family f4\n"
+           "    autoarchive 0      # archive immediately (upto 60s) after complete\n"
+           "    task t1\n"
+           "  endfamily\n"
+           "endsuite\n"
+           "\n"
+           "Usage::\n"
+           "   --archive=/s1           # archive suite s1\n"
+           "   --archive=/s1/f1 /s2    # archive family /s1/f1 and suite /s2\n"
+           "   --archive=force /s1 /s2 # archive suites /s1,/s2 even if they have active tasks";
+}
+const char* restore_desc() {
+    return "Manually restore archived nodes.\n"
+           "Restore will fail if:\n"
+           "  - Node has not been archived\n"
+           "  - Node has children, (since archived nodes have no children)\n"
+           "  - If the file ECF_HOME/<host>.<port>.<ECF_NAME>.check does not exist\n"
+           "Nodes can be restored manually(as in this command) but also automatically\n\n"
+           "Automatic restore is done using the 'autorestore' attribute.\n"
+           "Once the node containing the 'autorestore' completes, the attribute is applied\n\n"
+           " suite s\n"
+           "   family farchive_now\n"
+           "     autoarchive 0      # archive immediately after complete\n"
+           "     task tx\n"
+           "   endfamily\n"
+           "   family frestore_from_task\n"
+           "     task t1\n"
+           "        trigger ../farchive_now<flag>archived\n"
+           "        autorestore ../farchive_now  # call autorestore when t1 completes\n"
+           "   endfamily\n"
+           " endsuite\n\n"
+           "In this example task '/s/frestore_from_task/t1' is only triggered if 'farchive_now'\n"
+           "is archived, then when t1 completes it will restore family 'farchive_now'\n"
+           "Usage::\n"
+           "   --restore=/s1/f1   # restore family /s1/f1\n"
+           "   --restore=/s1 /s2  # restore suites /s1 and /s2";
+}
+
+void PathsCmd::addOption(boost::program_options::options_description& desc) const {
+    switch (api_) {
+        case PathsCmd::CHECK: {
+            desc.add_options()(CtsApi::check_arg(), po::value<vector<string>>()->multitoken(), get_check_desc());
+            break;
+        }
+        case PathsCmd::SUSPEND: {
+            desc.add_options()(CtsApi::suspend_arg(), po::value<vector<string>>()->multitoken(), suspend_desc());
+            break;
+        }
+        case PathsCmd::RESUME: {
+            desc.add_options()(CtsApi::resume_arg(), po::value<vector<string>>()->multitoken(), resume_desc());
+            break;
+        }
+        case PathsCmd::KILL: {
+            desc.add_options()(CtsApi::kill_arg(), po::value<vector<string>>()->multitoken(), get_kill_desc());
+            break;
+        }
+        case PathsCmd::STATUS: {
+            desc.add_options()(CtsApi::statusArg(), po::value<vector<string>>()->multitoken(), get_status_desc());
+            break;
+        }
+        case PathsCmd::EDIT_HISTORY: {
+            desc.add_options()(
+                CtsApi::edit_history_arg(), po::value<vector<string>>()->multitoken(), get_edit_history_desc());
+            break;
+        }
+        case PathsCmd::ARCHIVE: {
+            desc.add_options()(CtsApi::archive_arg(), po::value<vector<string>>()->multitoken(), archive_desc());
+            break;
+        }
+        case PathsCmd::RESTORE: {
+            desc.add_options()(CtsApi::restore_arg(), po::value<vector<string>>()->multitoken(), restore_desc());
+            break;
+        }
+        case PathsCmd::NO_CMD:
+            assert(false);
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+
+void PathsCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    assert(api_ != PathsCmd::NO_CMD);
+
+    vector<string> args = vm[theArg()].as<vector<string>>();
+    if (ac->debug())
+        dumpVecArgs(theArg(), args);
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
+
+    bool force = false;
+    if (api_ == PathsCmd::CHECK) {
+
+        bool all        = false;
+        size_t vec_size = options.size();
+        for (size_t i = 0; i < vec_size; i++) {
+            if (args[i] == "_all_")
+                all = true;
+        }
+        if (!all && paths.empty()) {
+            std::stringstream ss;
+            ss << "Check: Please specify one of [ _all_ | / | /<path/to/anode> ]. Paths must begin with a leading '/' "
+                  "character\n";
+            throw std::runtime_error(ss.str());
+        }
+        if (paths.size() == 1 && paths[0] == "/") {
+            // treat as _all_
+            paths.clear();
+        }
+    }
+    else if (api_ == PathsCmd::EDIT_HISTORY) {
+
+        if (paths.empty()) {
+            if (options.size() == 1 && options[0] == "clear")
+                paths.emplace_back("clear");
+            else {
+                std::stringstream ss;
+                ss << theArg() << ":  No paths or option specified. Paths must begin with a leading '/' character\n";
+                throw std::runtime_error(ss.str());
+            }
+        }
+    }
+    else {
+        if (paths.empty()) {
+            std::stringstream ss;
+            ss << theArg() << ":  No paths specified. Paths must begin with a leading '/' character\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    cmd = std::make_shared<PathsCmd>(api_, paths, force);
+}
+
+std::ostream& operator<<(std::ostream& os, const PathsCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(PathsCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(PathsCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/PathsCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/PathsCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/PathsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/PathsCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,69 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_PathsCmd_HPP
+#define ecflow_base_cts_user_PathsCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// DELETE If paths_ empty will delete all suites (beware) else will delete the chosen nodes.
+class PathsCmd final : public UserCmd {
+public:
+    enum Api { NO_CMD, SUSPEND, RESUME, KILL, STATUS, CHECK, EDIT_HISTORY, ARCHIVE, RESTORE };
+
+    PathsCmd(Api api, const std::vector<std::string>& paths, bool force = false)
+        : api_(api),
+          paths_(paths),
+          force_(force) {}
+    PathsCmd(Api api, const std::string& absNodePath, bool force = false);
+    explicit PathsCmd(Api api) : api_(api) { assert(api != NO_CMD); }
+    PathsCmd() = default;
+
+    Api api() const { return api_; }
+    const std::vector<std::string>& paths() const { return paths_; }
+    bool force() const { return force_; }
+
+    void print(std::string&) const override;
+    std::string print_short() const override;
+    void print_only(std::string&) const override;
+    void print(std::string& os, const std::string& path) const override;
+
+    bool equals(ClientToServerCmd*) const override;
+    bool isWrite() const override;
+
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after handlerequest
+
+    void my_print(std::string& os, const std::vector<std::string>& paths) const;
+    void my_print_only(std::string& os, const std::vector<std::string>& paths) const;
+
+private:
+    Api api_{NO_CMD};
+    std::vector<std::string> paths_;
+    bool force_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(api_), CEREAL_NVP(paths_), CEREAL_NVP(force_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const PathsCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(PathsCmd)
+
+#endif /* ecflow_base_cts_user_PathsCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/PlugCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/PlugCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/PlugCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/PlugCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,302 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/PlugCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/Client.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/cts/user/MoveCmd.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/NodePath.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/Openssl.hpp"
+    #include "ecflow/base/SslClient.hpp"
+#endif
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+namespace {
+
+/// Class to manage locking: Only unlock if acquired the lock,
+class Lock {
+public:
+    Lock(const std::string& user, AbstractServer* as) : as_(as) { ok_ = as->lock(user); }
+    ~Lock() {
+        if (ok_)
+            as_->unlock();
+    }
+    bool ok() const { return ok_; }
+
+private:
+    bool ok_;
+    AbstractServer* as_;
+};
+
+static void restore(NodeContainer* container) {
+    if (container && container->get_flag().is_set(ecf::Flag::ARCHIVED)) {
+        container->restore();
+        std::vector<family_ptr> family_vec = container->familyVec();
+        for (family_ptr node : family_vec) {
+            restore(node->isNodeContainer());
+        }
+    }
+}
+
+} // namespace
+
+//=======================================================================================
+
+bool PlugCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<PlugCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (source_ != the_rhs->source()) {
+        return false;
+    }
+    if (dest_ != the_rhs->dest()) {
+        return false;
+    }
+    return UserCmd::equals(rhs);
+}
+
+void PlugCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::plug(source_, dest_)));
+}
+
+void PlugCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::plug(source_, dest_));
+}
+
+STC_Cmd_ptr PlugCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().plug_++;
+    Defs* defs = as->defs().get();
+
+    Lock lock(user(), as);
+    if (!lock.ok()) {
+        std::string errorMsg = "Plug command failed. User ";
+        errorMsg += as->lockedUser();
+        errorMsg += " already has an exclusive lock";
+        throw std::runtime_error(errorMsg);
+    }
+
+    node_ptr sourceNode = defs->findAbsNode(source_);
+    if (!sourceNode.get())
+        throw std::runtime_error("Plug command failed. Could not find source path " + source_);
+
+    // Moving a node which is active, or submitted, will lead to zombie's. hence prevent
+    if (sourceNode->state() == NState::ACTIVE || sourceNode->state() == NState::SUBMITTED) {
+        std::string errorMsg = "Plug command failed. The source node ";
+        errorMsg += source_;
+        errorMsg += " is ";
+        errorMsg += NState::toString(sourceNode->state());
+        throw std::runtime_error(errorMsg);
+    }
+
+    if (sourceNode->isAlias()) {
+        std::string errorMsg = "Plug command failed. The source node ";
+        errorMsg += source_;
+        errorMsg += " is a Alias. Alias cannot be moved";
+        throw std::runtime_error(errorMsg);
+    }
+
+    // If the source node or *any* of its children are archived restore them first.
+    // Must be done in a top down manner.
+    restore(sourceNode->isNodeContainer());
+
+    // Check to see if dest node is on the same server
+    std::string host, port, destPath;
+    node_ptr destNode = defs->findAbsNode(dest_);
+    if (!destNode.get()) {
+
+        // Dest could still be on the same server. Extract host and port
+        // expect: host:port/suite/family/node
+        if (!NodePath::extractHostPort(dest_, host, port)) {
+            std::string errorMsg = "Plug command failed. The destination path ";
+            errorMsg += dest_;
+            errorMsg += " does not exist on server, and could not extract host/port from the destination path";
+            throw std::runtime_error(errorMsg);
+        }
+
+        // Remove the host:port from the path
+        destPath = NodePath::removeHostPortFromPath(dest_);
+
+        std::pair<std::string, std::string> hostPortPair = as->hostPort();
+        if ((hostPortPair.first == host || host == "localhost") && hostPortPair.second == port) {
+
+            // Matches local server, try to find dest node again.
+            destNode = defs->findAbsNode(destPath);
+            if (!destNode) {
+                std::string errorMsg = "Plug command failed. The destination path ";
+                errorMsg += dest_;
+                errorMsg += " does not exist on server ";
+                errorMsg += hostPortPair.first;
+                throw std::runtime_error(errorMsg);
+            }
+        }
+        // dest_ is on another server.
+    }
+
+    if (!destNode.get()) {
+
+        // Since host/port does not match local server, move source node to remote server
+        try {
+            if (destPath.empty()) {
+                // Note destPath can be empty, when moving a suite
+                if (!sourceNode->isSuite()) {
+                    throw std::runtime_error(
+                        "Destination path can only be empty when moving a whole suite to a new server");
+                }
+            }
+
+            {
+                // MoveCmd should inherit user and passwd, from PlugCmd
+                Cmd_ptr cts_cmd = Cmd_ptr(new MoveCmd(as->hostPort(), sourceNode.get(), destPath));
+                cts_cmd->setup_user_authentification(user(), passwd());
+
+                // Server is acting like a client, Send MoveCmd to another server
+                // The source should end up being copied, when sent to remote server
+                ServerReply server_reply;
+                boost::asio::io_service io_service;
+#ifdef ECF_OPENSSL
+                if (!as->ssl().empty()) {
+                    ecf::Openssl openssl;
+                    if (!openssl.enable_no_throw(host, port, as->ssl()))
+                        throw std::runtime_error("PlugCmd::doHandleRequest Could not enable ssl for " + as->ssl());
+                    openssl.init_for_client();
+
+                    SslClient theClient(io_service, openssl.context(), cts_cmd, host, port);
+                    io_service.run();
+                    theClient.handle_server_response(server_reply, false /* debug */);
+                    if (server_reply.client_request_failed()) {
+                        throw std::runtime_error(server_reply.error_msg());
+                    }
+                }
+                else {
+#endif
+                    Client theClient(io_service, cts_cmd, host, port);
+                    io_service.run();
+                    theClient.handle_server_response(server_reply, false /* debug */);
+                    if (server_reply.client_request_failed()) {
+                        throw std::runtime_error(server_reply.error_msg());
+                    }
+                }
+#ifdef ECF_OPENSSL
+            }
+#endif
+
+            // The move command was ok, remove the source node, and delete its memory
+            sourceNode->remove();
+
+            // Updated defs state
+            defs->set_most_significant_state();
+
+            return PreAllocatedReply::ok_cmd();
+        }
+        catch (std::exception& e) {
+            std::stringstream ss;
+            ss << "MoveCmd Failed for " << host << ":" << port << "  " << e.what() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    // source and destination on same defs file
+    // See if its a sibling move:
+    SuiteChanged1 suiteChanged(destNode->suite());
+    SuiteChanged1 suiteChanged1(sourceNode->suite());
+
+    if (sourceNode->parent() == destNode->parent()) {
+        Node* parent = sourceNode->parent();
+        if (parent)
+            parent->move_peer(sourceNode.get(), destNode.get());
+        else
+            defs->move_peer(sourceNode.get(), destNode.get());
+    }
+    else {
+
+        // If the destination is task, replace with its parent
+        Node* theDestNode = destNode.get();
+        if (theDestNode->isTask())
+            theDestNode = theDestNode->parent();
+
+        // Before we do remove the source node, check its ok to add it as a child
+        std::string errorMsg;
+        if (!theDestNode->isAddChildOk(sourceNode.get(), errorMsg)) {
+            throw std::runtime_error("Plug command failed. " + errorMsg);
+        }
+
+        if (!theDestNode->addChild(sourceNode->remove())) {
+            // This should never fail !!!! else we have lost/ and leaked source node !!!!
+            throw std::runtime_error("Fatal error plug command failed.");
+        }
+    }
+
+    add_node_for_edit_history(destNode);
+
+    // Updated defs state
+    defs->set_most_significant_state();
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* PlugCmd::arg() {
+    return CtsApi::plugArg();
+}
+const char* PlugCmd::desc() {
+    return "Plug command is used to move nodes.\n"
+           "The destination node can be on another server In which case the destination\n"
+           "path should be of the form '<host>:<port>/suite/family/task\n"
+           "  arg1 = path to source node\n"
+           "  arg2 = path to the destination node\n"
+           "This command can fail because:\n"
+           "- Source node is in a 'active' or 'submitted' state\n"
+           "- Another user already has an lock\n"
+           "- source/destination paths do not exist on the corresponding servers\n"
+           "- If the destination node path is empty, i.e. only host:port is specified,\n"
+           "  then the source node must correspond to a suite.\n"
+           "- If the source node is added as a child, then its name must be unique\n"
+           "  amongst its peers\n"
+           "Usage:\n"
+           "  --plug=/suite macX:3141  # move the suite to ecFlow server on host(macX) and port(3141)";
+}
+
+void PlugCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(PlugCmd::arg(), po::value<vector<string>>()->multitoken(), PlugCmd::desc());
+}
+
+void PlugCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (ace->debug())
+        dumpVecArgs(PlugCmd::arg(), args);
+
+    if (args.size() != 2) {
+        std::stringstream ss;
+        ss << "PlugCmd: Two arguments are expected, found " << args.size() << "\n" << PlugCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string sourceNode = args[0];
+    std::string destNode   = args[1];
+
+    cmd = std::make_shared<PlugCmd>(sourceNode, destNode);
+}
+
+CEREAL_REGISTER_TYPE(PlugCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(PlugCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/PlugCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/PlugCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/PlugCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/PlugCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_PlugCmd_HPP
+#define ecflow_base_cts_user_PlugCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+class PlugCmd final : public UserCmd {
+public:
+    PlugCmd(const std::string& source, const std::string& dest) : source_(source), dest_(dest) {}
+    PlugCmd() = default;
+
+    // Uses by equals only
+    const std::string& source() const { return source_; }
+    const std::string& dest() const { return dest_; }
+
+    int timeout() const override { return 120; }
+    bool handleRequestIsTestable() const override { return false; }
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+private:
+    std::string source_;
+    std::string dest_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(source_), CEREAL_NVP(dest_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const PlugCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(PlugCmd)
+
+#endif /* ecflow_base_cts_user_PlugCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/QueryCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/QueryCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/QueryCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/QueryCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,338 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/QueryCmd.hpp"
+
+#include <iostream>
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+QueryCmd::~QueryCmd() = default;
+
+void QueryCmd::print(std::string& os) const {
+    // path_to_task_ is only used in logging, so we know which task initiated the query, can be empty when invoked via
+    // cmd line
+    user_cmd(os, CtsApi::to_string(CtsApi::query(query_type_, path_to_attribute_, attribute_)) + path_to_task_);
+}
+void QueryCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::query(query_type_, path_to_attribute_, attribute_));
+    os += path_to_task_;
+}
+
+bool QueryCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<QueryCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (query_type_ != the_rhs->query_type())
+        return false;
+    if (path_to_attribute_ != the_rhs->path_to_attribute())
+        return false;
+    if (attribute_ != the_rhs->attribute())
+        return false;
+    if (path_to_task_ != the_rhs->path_to_task())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+void QueryCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(QueryCmd::arg(), po::value<vector<string>>()->multitoken(), QueryCmd::desc());
+}
+
+void QueryCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (clientEnv->debug()) {
+        dumpVecArgs(QueryCmd::arg(), args);
+        cout << "  QueryCmd::create " << QueryCmd::arg() << " task_path(" << clientEnv->task_path() << ")\n";
+    }
+
+    std::string query_type;
+    std::string path_to_attribute;
+    std::string attribute;
+
+    if (args.size())
+        query_type = args[0];
+    if (query_type == "event" || query_type == "meter" || query_type == "label" || query_type == "variable" ||
+        query_type == "limit" || query_type == "limit_max") {
+        // second argument must be <path>:event_or_meter_or_label_or_variable_or_limit
+        std::string path_and_name;
+        if (args.size() == 2) {
+            path_and_name = args[1];
+            if (!Extract::pathAndName(path_and_name, path_to_attribute, attribute)) {
+                throw std::runtime_error("QueryCmd: second argument must be of the form <path>:name for query\n, where "
+                                         "name is [event | meter | label | variable | limit | limit_max ] name " +
+                                         query_type + " : could not extract from:" + path_and_name);
+            }
+        }
+        else {
+            std::stringstream ss;
+            ss << "QueryCmd: second argument must be of the form <path>:name for query\n where name is [event | meter "
+                  "| label | variable | limit | limit_max] name "
+               << query_type;
+            ss << " args size = " << args.size() << " expected 2 arguments";
+            throw std::runtime_error(ss.str());
+        }
+        if (attribute.empty())
+            throw std::runtime_error("QueryCmd: no attribute specified: query type: " + query_type +
+                                     " path+attribute: " + path_and_name + "\n" + string(QueryCmd::desc()));
+    }
+    else if (query_type == "trigger") {
+        for (size_t i = 1; i < args.size(); i++) {
+            if (i == 1)
+                path_to_attribute = args[i];
+            if (i == 2) {
+                attribute = args[i];
+                (void)Expression::parse(attribute, "QueryCmd:"); // will throw if expression does not parse
+            }
+        }
+        if (attribute.empty())
+            throw std::runtime_error("QueryCmd: no attribute specified: query type: trigger\n" +
+                                     string(QueryCmd::desc()));
+    }
+    else if (query_type == "state" || query_type == "dstate") {
+        // for state and dstate attribute is empty
+        if (args.size() > 1)
+            path_to_attribute = args[1];
+        if (args.size() > 2)
+            throw std::runtime_error("QueryCmd: invalid (state | dstate) query : " + args[2]);
+    }
+    else if (query_type == "repeat") {
+        // for repeat attribute can only be next or prev
+        if (args.size() > 1)
+            path_to_attribute = args[1];
+        if (args.size() == 3) {
+            attribute = args[2];
+            if (attribute != "next" && attribute != "prev") {
+                throw std::runtime_error("QueryCmd: invalid (repeat) query expected 'next' or 'prev' but found " +
+                                         attribute);
+            }
+        }
+        if (args.size() > 3)
+            throw std::runtime_error("QueryCmd: invalid (repeat) query : " + args[3]);
+    }
+    else
+        throw std::runtime_error("QueryCmd: first argument must be one of [ state | dstate | repeat | event | meter | "
+                                 "variable | trigger ] but found:" +
+                                 query_type);
+
+    if (path_to_attribute.empty() || (!path_to_attribute.empty() && path_to_attribute[0] != '/')) {
+        throw std::runtime_error("QueryCmd: invalid path to attribute: " + path_to_attribute);
+    }
+
+    // path_to_task can be empty if invoked via the command line. ( used for logging, i.e identifying which task invoked
+    // this command) However if invoked from the shell/python we expect the path_to_task(ECF_NAME) to have been set
+    std::string path_to_task = clientEnv->task_path(); // can be empty, when cmd called from command line
+    if (!path_to_task.empty() && path_to_task[0] != '/') {
+        throw std::runtime_error("QueryCmd: invalid path to task: " + path_to_task);
+    }
+
+    cmd = std::make_shared<QueryCmd>(query_type, path_to_attribute, attribute, path_to_task);
+}
+
+const char* QueryCmd::arg() {
+    return CtsApi::queryArg();
+}
+
+const char* QueryCmd::desc() {
+    return "Query the status of attributes\n"
+           " i.e state,dstate,repeat,event,meter,label,variable or trigger expression without blocking\n"
+           " - state     return [unknown | complete | queued |             aborted | submitted | active] to standard "
+           "out\n"
+           " - dstate    return [unknown | complete | queued | suspended | aborted | submitted | active] to standard "
+           "out\n"
+           " - repeat    returns current value as a string to standard out\n"
+           " - event     return 'set' | 'clear' to standard out\n"
+           " - meter     return value of the meter to standard out\n"
+           " - limit     return current value of limit to standard out\n"
+           " - limit_max return limit max value to standard out\n"
+           " - label     return new value otherwise the old value\n"
+           " - variable  return value of the variable, repeat or generated variable to standard out,\n"
+           "             will search up the node tree\n"
+           " - trigger   returns 'true' if the expression is true, otherwise 'false'\n\n"
+           "If this command is called within a '.ecf' script we will additionally log the task calling this command\n"
+           "This is required to aid debugging for excessive use of this command\n"
+           "The command will fail if the node path to the attribute does not exist in the definition and if:\n"
+           " - repeat   The repeat is not found\n"
+           " - event    The event is not found\n"
+           " - meter    The meter is not found\n"
+           " - limit/limit_max The limit is not found\n"
+           " - label    The label is not found\n"
+           " - variable No user or generated variable or repeat of that name found on node, or any of its parents\n"
+           " - trigger  Trigger does not parse, or reference to nodes/attributes in the expression are not valid\n"
+           "Arguments:\n"
+           "  arg1 = [ state | dstate | repeat | event | meter | label | variable | trigger | limit | limit_max ]\n"
+           "  arg2 = <path> | <path>:name where name is name of a event, meter, label, limit or variable\n"
+           "  arg3 = trigger expression | prev | next # prev,next only used when arg1 is repeat\n\n"
+           "Usage:\n"
+           " ecflow_client --query state /                                     # return top level state to standard "
+           "out\n"
+           " ecflow_client --query state /path/to/node                         # return node state to standard out\n"
+           " ecflow_client --query dstate /path/to/node                        # state that can included suspended\n"
+           " ecflow_client --query repeat /path/to/node                        # return the current value as a string\n"
+           " ecflow_client --query repeat /path/to/node prev                   # return the previous value as a "
+           "string\n"
+           " ecflow_client --query repeat /path/to/node next                   # return the next value as a string\n"
+           " ecflow_client --query event /path/to/task/with/event:event_name   # return set | clear to standard out\n"
+           " ecflow_client --query meter /path/to/task/with/meter:meter_name   # returns the current value of the "
+           "meter to standard out\n"
+           " ecflow_client --query limit /path/to/task/with/limit:limit_name   # returns the current value of the "
+           "limit to standard out\n"
+           " ecflow_client --query limit_max /path/to/task/with/limit:limit_name # returns the max value of the limit "
+           "to standard out\n"
+           " ecflow_client --query label /path/to/task/with/label:label_name   # returns the current value of the "
+           "label to standard out\n"
+           " ecflow_client --query variable /path/to/task/with/var:var_name    # returns the variable value to "
+           "standard out\n"
+           " ecflow_client --query trigger /path/to/node/with/trigger \"/suite/task == complete\" # return true if "
+           "expression evaluates false otherwise\n";
+}
+
+STC_Cmd_ptr QueryCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().query_++;
+
+    Defs* defs = as->defs().get();
+
+    if (path_to_attribute_ == "/") {
+        if (query_type_ == "state") {
+            return PreAllocatedReply::string_cmd(NState::toString(defs->state()));
+        }
+        std::stringstream ss;
+        ss << "QueryCmd: The only valid query for the server is 'state', i.e. ecflow_client --query state /";
+        throw std::runtime_error(ss.str());
+    }
+
+    node_ptr node = find_node(defs, path_to_attribute_);
+
+    if (query_type_ == "event") {
+        const Event& event = node->findEventByNameOrNumber(attribute_);
+        if (event.empty()) {
+            std::stringstream ss;
+            ss << "QueryCmd: Cannot find event " << attribute_ << " on node " << path_to_attribute_;
+            throw std::runtime_error(ss.str());
+        }
+        if (event.value())
+            return PreAllocatedReply::string_cmd(Event::SET());
+        return PreAllocatedReply::string_cmd(Event::CLEAR());
+    }
+
+    if (query_type_ == "meter") {
+        const Meter& meter = node->findMeter(attribute_);
+        if (meter.empty()) {
+            std::stringstream ss;
+            ss << "QueryCmd: Cannot find meter " << attribute_ << " on node " << path_to_attribute_;
+            throw std::runtime_error(ss.str());
+        }
+        return PreAllocatedReply::string_cmd(ecf::convert_to<std::string>(meter.value()));
+    }
+
+    if (query_type_ == "limit") {
+        limit_ptr limit = node->find_limit(attribute_);
+        if (!limit.get())
+            throw std::runtime_error("QueryCmd: Could not find limit " + attribute_);
+        return PreAllocatedReply::string_cmd(ecf::convert_to<std::string>(limit->value()));
+    }
+    if (query_type_ == "limit_max") {
+        limit_ptr limit = node->find_limit(attribute_);
+        if (!limit.get())
+            throw std::runtime_error("QueryCmd: Could not find limit " + attribute_);
+        return PreAllocatedReply::string_cmd(ecf::convert_to<std::string>(limit->theLimit()));
+    }
+
+    if (query_type_ == "label") {
+        const Label& label = node->find_label(attribute_);
+        if (label.empty()) {
+            std::stringstream ss;
+            ss << "QueryCmd: Cannot find label " << attribute_ << " on node " << path_to_attribute_;
+            throw std::runtime_error(ss.str());
+        }
+        if (label.new_value().empty())
+            return PreAllocatedReply::string_cmd(label.value());
+        return PreAllocatedReply::string_cmd(label.new_value());
+    }
+
+    if (query_type_ == "variable") {
+        std::string the_value;
+        if (node->findParentVariableValue(attribute_, the_value)) {
+            return PreAllocatedReply::string_cmd(the_value);
+        }
+        std::stringstream ss;
+        ss << "QueryCmd: Cannot find variable, repeat or generated var' of name " << attribute_ << " on node "
+           << path_to_attribute_ << " or its parents";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (query_type_ == "trigger") {
+        std::unique_ptr<AstTop> ast =
+            node->parse_and_check_expressions(attribute_, true, "QueryCmd:"); // will throw for errors
+        if (ast->evaluate())
+            return PreAllocatedReply::string_cmd("true");
+        return PreAllocatedReply::string_cmd("false");
+    }
+
+    if (query_type_ == "state") {
+        return PreAllocatedReply::string_cmd(NState::toString(node->state()));
+    }
+
+    if (query_type_ == "dstate") {
+        return PreAllocatedReply::string_cmd(DState::to_string(node->dstate()));
+    }
+
+    if (query_type_ == "repeat") {
+        const Repeat& repeat = node->repeat();
+        if (repeat.empty()) {
+            std::stringstream ss;
+            ss << "QueryCmd: Cannot find repeat on node " << path_to_attribute_;
+            throw std::runtime_error(ss.str());
+        }
+        if (attribute_.empty())
+            return PreAllocatedReply::string_cmd(repeat.valueAsString());
+        if (attribute_ == "next")
+            return PreAllocatedReply::string_cmd(repeat.next_value_as_string());
+        if (attribute_ == "prev")
+            return PreAllocatedReply::string_cmd(repeat.prev_value_as_string());
+        std::stringstream ss;
+        ss << "QueryCmd: invalid repeat attribute expected next | prev but found " << attribute_;
+        throw std::runtime_error(ss.str());
+    }
+    else {
+        std::stringstream ss;
+        ss << "QueryCmd: unrecognised query_type " << query_type_;
+        throw std::runtime_error(ss.str());
+    }
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+std::ostream& operator<<(std::ostream& os, const QueryCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(QueryCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(QueryCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/QueryCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/QueryCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/QueryCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/QueryCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_QueryCmd_HPP
+#define ecflow_base_cts_user_QueryCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+class QueryCmd final : public UserCmd {
+public:
+    QueryCmd(const std::string& query_type,
+             const std::string& path_to_attribute,
+             const std::string& attribute,
+             const std::string& path_to_task)
+        : query_type_(query_type),
+          path_to_attribute_(path_to_attribute),
+          attribute_(attribute),
+          path_to_task_(path_to_task) {}
+    QueryCmd() : UserCmd() {}
+    ~QueryCmd() override;
+
+    const std::string& query_type() const { return query_type_; }
+    const std::string& path_to_attribute() const { return path_to_attribute_; }
+    const std::string& attribute() const { return attribute_; }
+    const std::string& path_to_task() const { return path_to_task_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    bool handleRequestIsTestable() const override { return false; }
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+private:
+    std::string query_type_; // [ state | dstate | event | meter | label | trigger ]
+    std::string path_to_attribute_;
+    std::string attribute_;    // [ event_name | meter_name | label_name | variable_name | trigger expression] empty for
+                               // state and dstate
+    std::string path_to_task_; // The task the invoked this command, needed for logging
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(query_type_),
+           CEREAL_NVP(path_to_attribute_),
+           CEREAL_NVP(attribute_),
+           CEREAL_NVP(path_to_task_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const QueryCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(QueryCmd)
+
+#endif /* ecflow_base_cts_user_QueryCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,242 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+ReplaceNodeCmd::ReplaceNodeCmd(const std::string& node_path, bool createNodesAsNeeded, defs_ptr client_defs, bool force)
+    : createNodesAsNeeded_(createNodesAsNeeded),
+      force_(force),
+      pathToNode_(node_path) {
+    if (!client_defs.get()) {
+        throw std::runtime_error("ReplaceNodeCmd::ReplaceNodeCmd: client definition is empty");
+    }
+
+    // Client defs has been created in memory.
+    // warn about naff expression and unresolved in-limit references to Limit's
+    std::string errMsg, warningMsg;
+    if (!client_defs->check(errMsg, warningMsg)) {
+        throw std::runtime_error(errMsg);
+    }
+
+    // Make sure pathToNode exists in the client defs
+    node_ptr nodeToReplace = client_defs->findAbsNode(node_path);
+    if (!nodeToReplace.get()) {
+        std::stringstream ss;
+        ss << "ReplaceNodeCmd::ReplaceNodeCmd: Cannot replace child since path " << node_path;
+        ss << ", does not exist in the client definition ";
+        throw std::runtime_error(ss.str());
+    }
+
+    client_defs->save_as_string(clientDefs_, PrintStyle::NET);
+
+    // Out put any warning's to standard output
+    cout << warningMsg;
+}
+
+ReplaceNodeCmd::ReplaceNodeCmd(const std::string& node_path,
+                               bool createNodesAsNeeded,
+                               const std::string& path_to_defs,
+                               bool force)
+    : createNodesAsNeeded_(createNodesAsNeeded),
+      force_(force),
+      pathToNode_(node_path),
+      path_to_defs_(path_to_defs) {
+    // Parse the file and load the defs file into memory.
+    std::string errMsg, warningMsg;
+    defs_ptr client_defs = Defs::create();
+    bool ok              = false;
+    if (path_to_defs.find("suite") != std::string::npos && path_to_defs.find("endsuite") != std::string::npos) {
+        ok = client_defs->restore_from_string(path_to_defs, errMsg, warningMsg);
+    }
+    else {
+        ok = client_defs->restore(path_to_defs, errMsg, warningMsg);
+    }
+    if (!ok) {
+        std::stringstream ss;
+        ss << "ReplaceNodeCmd::ReplaceNodeCmd: Could not parse file " << path_to_defs << " : " << errMsg;
+        throw std::runtime_error(ss.str());
+    }
+
+    // Make sure pathToNode exists in the client defs
+    node_ptr nodeToReplace = client_defs->findAbsNode(node_path);
+    if (!nodeToReplace.get()) {
+        std::stringstream ss;
+        ss << "ReplaceNodeCmd::ReplaceNodeCmd: Cannot replace child since path " << node_path;
+        ss << ", does not exist in the client definition " << path_to_defs;
+        throw std::runtime_error(ss.str());
+    }
+
+    client_defs->save_as_string(clientDefs_, PrintStyle::NET);
+
+    // Out put any warning's to standard output
+    cout << warningMsg;
+}
+
+bool ReplaceNodeCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<ReplaceNodeCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (!UserCmd::equals(rhs))
+        return false;
+    if (createNodesAsNeeded_ != the_rhs->createNodesAsNeeded()) {
+        return false;
+    }
+    if (force_ != the_rhs->force())
+        return false;
+    if (pathToNode_ != the_rhs->pathToNode())
+        return false;
+    if (path_to_defs_ != the_rhs->path_to_defs())
+        return false;
+    if (clientDefs_ != the_rhs->the_client_defs())
+        return false;
+    return true;
+}
+
+STC_Cmd_ptr ReplaceNodeCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().replace_++;
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+    Defs* defs = as->defs().get();
+
+    std::string errMsg, warningMsg;
+    defs_ptr client_defs = Defs::create();
+    if (!client_defs->restore_from_string(clientDefs_, errMsg, warningMsg)) {
+        std::stringstream ss;
+        ss << "ReplaceNodeCmd::doHandleRequest : Could not create client defs : " << errMsg;
+        throw std::runtime_error(ss.str());
+    }
+
+    if (force_) {
+        node_ptr node = defs->findAbsNode(pathToNode_);
+        as->zombie_ctrl().add_user_zombies(node.get(), CtsApi::replace_arg());
+    }
+
+    // If we return a node_ptr then we have changed the data model, and therefore must flag node as changed.
+    std::string errorMsg;
+    node_ptr client_node_to_add = defs->replaceChild(pathToNode_, client_defs, createNodesAsNeeded_, force_, errorMsg);
+    if (!client_node_to_add) {
+        throw std::runtime_error(errorMsg);
+    }
+
+    // ECFLOW-835, flag node as changed, before check for trigger expressions.
+    add_node_for_edit_history(defs, pathToNode_);
+
+    // Although we have change the data model, Check if the trigger expressions are still valid.
+    // Note:: trigger AST are not copied. If you use trigger in the test environment
+    //        then copying the nodes will copy the trigger reference, which will be out of sync
+    std::string warning_msg;
+    if (!client_node_to_add->suite()->check(errorMsg, warning_msg)) {
+        throw std::runtime_error(errorMsg);
+    }
+
+    return doJobSubmission(as);
+}
+
+bool ReplaceNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, pathToNode_);
+}
+
+void ReplaceNodeCmd::print(std::string& os) const {
+    std::string path_to_client_defs = path_to_defs_;
+    if (path_to_client_defs.empty())
+        path_to_client_defs = "<empty>"; // defs must have been loaded in memory via python api
+    user_cmd(os, CtsApi::to_string(CtsApi::replace(pathToNode_, path_to_client_defs, createNodesAsNeeded_, force_)));
+}
+void ReplaceNodeCmd::print_only(std::string& os) const {
+    std::string path_to_client_defs = path_to_defs_;
+    if (path_to_client_defs.empty())
+        path_to_client_defs = "<empty>"; // defs must have been loaded in memory via python api
+    os += CtsApi::to_string(CtsApi::replace(pathToNode_, path_to_client_defs, createNodesAsNeeded_, force_));
+}
+
+const char* ReplaceNodeCmd::arg() {
+    return CtsApi::replace_arg();
+}
+const char* ReplaceNodeCmd::desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Replaces a node in the server, with the given path\n"
+           "Can also be used to add nodes in the server\n"
+           "  arg1 = path to node\n"
+           "         must exist in the client defs(arg2). This is also the node we want to\n"
+           "         replace in the server\n"
+           "  arg2 = path to client definition file\n"
+           "         provides the definition of the new node\n"
+           "  arg3 = (optional) [ parent | false ] (default = parent)\n"
+           "         create parent families or suite as needed, when arg1 does not\n"
+           "         exist in the server\n"
+           "  arg4 = (optional) force (default = false) \n"
+           "         Force the replacement even if it causes zombies to be created\n"
+           "Replace can fail if:\n"
+           "- The node path(arg1) does not exist in the provided client definition(arg2)\n"
+           "- The client definition(arg2) must be free of errors\n"
+           "- If the third argument is not provided, then node path(arg1) must exist in the server\n"
+           "- Nodes to be replaced are in active/submitted state, in which case arg4(force) can be used\n\n"
+           "Replace will preserve the suspended status, if this is not required please re-queue first\n"
+           "After replace is done, we check trigger expressions. These are reported to standard output.\n"
+           "It is up to the user to correct invalid trigger expressions, otherwise the tasks will *not* run.\n"
+           "Please note, you can use --check to check trigger expression and limits in the server.\n"
+           "For more information use --help check.\n\n"
+           "Usage:\n"
+           "  --replace=/suite/f1/t1 /tmp/client.def  parent      # Add/replace node tree /suite/f1/t1\n"
+           "  --replace=/suite/f1/t1 /tmp/client.def  false force # replace t1 even if its active or submitted";
+}
+
+void ReplaceNodeCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(ReplaceNodeCmd::arg(), po::value<vector<string>>()->multitoken(), ReplaceNodeCmd::desc());
+}
+void ReplaceNodeCmd::create(Cmd_ptr& cmd,
+                            boost::program_options::variables_map& vm,
+                            AbstractClientEnv* clientEnv) const {
+    vector<string> args = vm[arg()].as<vector<string>>();
+
+    if (clientEnv->debug())
+        dumpVecArgs(ReplaceNodeCmd::arg(), args);
+
+    if (args.size() < 2) {
+        std::stringstream ss;
+        ss << "ReplaceNodeCmd: At least two arguments expected, found " << args.size()
+           << " Please specify <path-to-Node>  <defs files> parent(optional) force(optional), i.e\n"
+           << "--" << arg() << "=/suite/fa/t AdefsFile.def  parent force\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string pathToNode     = args[0];
+    std::string pathToDefsFile = args[1];
+    bool createNodesAsNeeded   = true; // parent arg
+    bool force                 = false;
+    if (args.size() == 3 && args[2] == "false")
+        createNodesAsNeeded = false;
+    if (args.size() == 4 && args[3] == "force")
+        force = true;
+
+    cmd = std::make_shared<ReplaceNodeCmd>(pathToNode, createNodesAsNeeded, pathToDefsFile, force);
+}
+
+std::ostream& operator<<(std::ostream& os, const ReplaceNodeCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(ReplaceNodeCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(ReplaceNodeCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ReplaceNodeCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_ReplaceNodeCmd_HPP
+#define ecflow_base_cts_user_ReplaceNodeCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+class ReplaceNodeCmd final : public UserCmd {
+public:
+    ReplaceNodeCmd(const std::string& node_path, bool createNodesAsNeeded, defs_ptr client_defs, bool force);
+    ReplaceNodeCmd(const std::string& node_path, bool createNodesAsNeeded, const std::string& path_to_defs, bool force);
+    ReplaceNodeCmd() = default;
+
+    const std::string& the_client_defs() const { return clientDefs_; }
+    const std::string& pathToNode() const { return pathToNode_; }
+    const std::string& path_to_defs() const { return path_to_defs_; }
+    bool createNodesAsNeeded() const { return createNodesAsNeeded_; }
+    bool force() const { return force_; }
+
+    bool isWrite() const override { return true; }
+    int timeout() const override { return 300; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+    // void set_client_env(const std::vector<std::pair<std::string,std::string> >& env ) { client_env_ = env;} // only
+    // used in test
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::string().swap(clientDefs_); } /// run in the server, after command send to client
+
+    bool createNodesAsNeeded_{false};
+    bool force_{false};
+    std::string pathToNode_;
+    std::string path_to_defs_; // Can be empty if defs loaded in memory via python api
+    std::string clientDefs_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(createNodesAsNeeded_),
+           CEREAL_NVP(force_),
+           CEREAL_NVP(pathToNode_),
+           CEREAL_NVP(path_to_defs_),
+           CEREAL_NVP(clientDefs_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ReplaceNodeCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(ReplaceNodeCmd)
+
+#endif /* ecflow_base_cts_user_ReplaceNodeCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,259 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool RequeueNodeCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<RequeueNodeCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (paths_ != the_rhs->paths())
+        return false;
+    if (option_ != the_rhs->option())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+static std::string to_string(RequeueNodeCmd::Option option) {
+    switch (option) {
+        case RequeueNodeCmd::NO_OPTION:
+            return string();
+        case RequeueNodeCmd::FORCE:
+            return "force";
+        case RequeueNodeCmd::ABORT:
+            return "abort";
+        default:
+            assert(false);
+            break;
+    }
+    return string();
+}
+
+void RequeueNodeCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::requeue(paths_, to_string(option_))));
+}
+void RequeueNodeCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::requeue(paths_, to_string(option_)));
+}
+
+void RequeueNodeCmd::print(std::string& os, const std::string& path) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::requeue(std::vector<std::string>(1, path), to_string(option_))));
+}
+
+STC_Cmd_ptr RequeueNodeCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().requeue_node_++;
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+
+    // The clear_suspended_in_child_nodes *only* incremented for child nodes.
+    // Hence we only clear suspended for child nodes.
+    Node::Requeue_args args(Node::Requeue_args::FULL,
+                            true /* reset repeats */,
+                            0 /* clear_suspended_in_child_nodes */,
+                            true /* reset_next_time_slot */,
+                            true /* reset relative duration */);
+
+    Defs* defs = as->defs().get();
+    std::stringstream ss;
+    size_t vec_size = paths_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+
+        node_ptr theNodeToRequeue = find_node_for_edit_no_throw(defs, paths_[i]);
+        if (!theNodeToRequeue.get()) {
+            ss << "RequeueNodeCmd: Could not find node at path " << paths_[i] << "\n";
+            LOG(Log::ERR, "RequeueNodeCmd: Could not find node at path " << paths_[i]);
+            continue;
+        }
+
+        if (!theNodeToRequeue->suite()->begun()) {
+            std::stringstream mss;
+            mss << "RequeueNodeCmd::doHandleRequest: For node " << paths_[i] << ". The suite "
+                << theNodeToRequeue->suite()->name() << " must be 'begun' first\n";
+            throw std::runtime_error(mss.str());
+        }
+
+        SuiteChangedPtr changed(theNodeToRequeue.get());
+
+        if (option_ == RequeueNodeCmd::ABORT) {
+            // ONLY Re-queue the aborted tasks
+            std::vector<Task*> taskVec;
+            theNodeToRequeue->getAllTasks(taskVec);
+            for (auto& task : taskVec) {
+                if (task->state() == NState::ABORTED) {
+                    task->requeue(args);
+                    task->set_most_significant_state_up_node_tree(); // Must in loop and not outside ECFLOW-428
+                }
+            }
+
+            // Call handleStateChange on parent, to avoid requeue same node again.
+            Node* parent = theNodeToRequeue->parent();
+            if (parent)
+                parent->handleStateChange(); // ECFLOW-359
+        }
+        else if (option_ == RequeueNodeCmd::NO_OPTION) {
+            // ONLY Re-queue if there no tasks in submitted or active states
+            std::vector<Task*> taskVec;
+            theNodeToRequeue->getAllTasks(taskVec);
+            for (auto& task : taskVec) {
+                if (task->state() == NState::SUBMITTED || task->state() == NState::ACTIVE) {
+                    return PreAllocatedReply::ok_cmd();
+                }
+            }
+
+            // The NO_REQUE_IF_SINGLE_TIME_DEP is typically cleared at the *end* requeue, however there are cases
+            // where we need to reset it *BEFORE* re-queue. Since it is tied to missing the next time slot
+            // i.e take this case:
+            //     time 10:00  15:00 00:30
+            // If we force complete, we set NO_REQUE_IF_SINGLE_TIME_DEP, which is used to advance next valid time slot
+            // (i.e no reset), however when we reach the *end* time i.e 15:00
+            // calling force complete now leaves node in a complete state and with NO_REQUE_IF_SINGLE_TIME_DEP set.
+            // Therefore *any* *MANUAL* re-queue afterward will NOT reset the next valid time slot.
+            // To overcome this manual re-queue will always clear NO_REQUE_IF_SINGLE_TIME_DEP and hence reset next valid
+            // time slot
+            theNodeToRequeue->requeue(args);
+            theNodeToRequeue->set_most_significant_state_up_node_tree();
+
+            // Call handleStateChange on parent, to avoid requeue same node again.
+            Node* parent = theNodeToRequeue->parent();
+            if (parent)
+                parent->handleStateChange(); // ECFLOW-359
+        }
+        else if (option_ == RequeueNodeCmd::FORCE) {
+
+            as->zombie_ctrl().add_user_zombies(theNodeToRequeue.get(), CtsApi::requeueArg());
+
+            // Please note: that if any tasks under theNodeToRequeue are in
+            // active or submitted states, then we will have created zombie jobs
+            // The GUI: that calls this command should call a separate request
+            // the returns the active/submitted tasks first. This can then be
+            // presented to the user, who can elect to kill them if required.
+            theNodeToRequeue->requeue(args);
+            theNodeToRequeue->set_most_significant_state_up_node_tree();
+
+            // Call handleStateChange on parent, to avoid requeue same node again.
+            Node* parent = theNodeToRequeue->parent();
+            if (parent)
+                parent->handleStateChange(); // ECFLOW-359
+        }
+    }
+
+    std::string error_msg = ss.str();
+    if (!error_msg.empty()) {
+        throw std::runtime_error(error_msg);
+    }
+
+    // Do an immediate job submission, so that any re-queued tasks are submitted
+    return doJobSubmission(as);
+}
+
+bool RequeueNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, paths_);
+}
+
+const char* RequeueNodeCmd::arg() {
+    return CtsApi::requeueArg();
+}
+const char* RequeueNodeCmd::desc() {
+    return "Re queues the specified node(s)\n"
+           "  If any child of the specified node(s) is in a suspended state, this state is cleared\n"
+           "Repeats are reset to their starting values, relative time attributes are reset.\n"
+           "  arg1 = (optional) [ abort | force ]\n"
+           "         abort  = re-queue only aborted tasks below node\n"
+           "         force  = Force the re-queueing even if there are nodes that are active or submitted\n"
+           "         <null> = Checks if any tasks are in submitted or active states below the node\n"
+           "                  if so does nothing. Otherwise re-queues the node.\n"
+           "  arg2 = list of node paths. The node paths must begin with a leading '/' character\n\n"
+           "Usage:\n"
+           "  --requeue=abort /suite/f1  # re-queue all aborted tasks of /suite/f1\n"
+           "  --requeue=force /suite/f1  # forcibly re-queue /suite/f1 and all its children.May cause zombies.\n"
+           "  --requeue=/s1/f1/t1 /s1/t2 # Re-queue node '/suite/f1/t1' and '/s1/t2'";
+}
+
+void RequeueNodeCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(RequeueNodeCmd::arg(), po::value<vector<string>>()->multitoken(), RequeueNodeCmd::desc());
+}
+void RequeueNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    vector<string> args = vm[RequeueNodeCmd::arg()].as<vector<string>>();
+
+    if (ac->debug())
+        dumpVecArgs(RequeueNodeCmd::arg(), args);
+
+    if (args.size() < 1) {
+        std::stringstream ss;
+        ss << "RequeueNodeCmd: At least 1 argument(path to node) expected. Please specify one of:\n";
+        ss << RequeueNodeCmd::arg() << " pathToNode\n";
+        ss << RequeueNodeCmd::arg() << " abort pathToNode\n";
+        ss << RequeueNodeCmd::arg() << " force pathToNode\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
+    if (paths.empty()) {
+        std::stringstream ss;
+        ss << "RequeueNodeCmd: No paths specified. At least one path expected. Paths must begin with a leading '/' "
+              "character\n"
+           << RequeueNodeCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    RequeueNodeCmd::Option option = RequeueNodeCmd::NO_OPTION;
+    size_t vec_size               = options.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (options[i] == "abort") {
+            option = RequeueNodeCmd::ABORT;
+            if (ac->debug())
+                cout << "  ABORT selected\n";
+        }
+        else if (options[i] == "force") {
+            option = RequeueNodeCmd::FORCE;
+            if (ac->debug())
+                cout << "  FORCE selected\n";
+        }
+        else {
+            std::stringstream ss;
+            ss << "RequeueNodeCmd: RequeueNodeCmd: Expected : [force | abort ] paths.\n"
+               << RequeueNodeCmd::desc() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    if (options.size() > 1) {
+        std::stringstream ss;
+        ss << "RequeueNodeCmd: Expected only a single option i.e [ force | abort ]\n" << RequeueNodeCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    cmd = std::make_shared<RequeueNodeCmd>(paths, option);
+}
+
+std::ostream& operator<<(std::ostream& os, const RequeueNodeCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(RequeueNodeCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(RequeueNodeCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/RequeueNodeCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,66 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_RequeueNodeCmd_HPP
+#define ecflow_base_cts_user_RequeueNodeCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+class RequeueNodeCmd final : public UserCmd {
+public:
+    enum Option { NO_OPTION, ABORT, FORCE };
+
+    explicit RequeueNodeCmd(const std::vector<std::string>& paths, Option op = NO_OPTION)
+        : paths_(paths),
+          option_(op) {}
+
+    explicit RequeueNodeCmd(const std::string& absNodepath, Option op = NO_OPTION)
+        : paths_(std::vector<std::string>(1, absNodepath)),
+          option_(op) {}
+
+    RequeueNodeCmd() = default;
+
+    const std::vector<std::string>& paths() const { return paths_; }
+    Option option() const { return option_; }
+
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    void print(std::string& os, const std::string& path) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
+
+private:
+    mutable std::vector<std::string> paths_; // mutable to allow swap to clear & reclaim memory, as soon as possible
+    Option option_{NO_OPTION};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(paths_), CEREAL_NVP(option_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const RequeueNodeCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(RequeueNodeCmd)
+
+#endif /* ecflow_base_cts_user_RequeueNodeCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,187 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/RunNodeCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+bool RunNodeCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<RunNodeCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (paths_ != the_rhs->paths())
+        return false;
+    if (force_ != the_rhs->force())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+void RunNodeCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::run(paths_, force_)));
+}
+void RunNodeCmd::print_only(std::string& os) const {
+    os += CtsApi::to_string(CtsApi::run(paths_, force_));
+}
+void RunNodeCmd::print(std::string& os, const std::string& path) const {
+    user_cmd(os, CtsApi::to_string(CtsApi::run(std::vector<std::string>(1, path), force_)));
+}
+
+STC_Cmd_ptr RunNodeCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().run_node_++;
+    assert(isWrite()); // isWrite used in handleRequest() to control check pointing
+
+    Defs* defs = as->defs().get();
+    std::stringstream ss;
+    size_t vec_size = paths_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        node_ptr node = find_node_for_edit_no_throw(defs, paths_[i]);
+        if (!node.get()) {
+            ss << "RunNodeCmd: Could not find node at path " << paths_[i] << "\n";
+            LOG(Log::ERR, "RunNodeCmd: Could not find node at path " << paths_[i]);
+            continue;
+        }
+
+        if (!node->suite()->begun()) {
+            std::stringstream mss;
+            mss << "RunNodeCmd failed: For " << paths_[i] << ". The suite " << node->suite()->name()
+                << " must be 'begun' first\n";
+            throw std::runtime_error(mss.str());
+        }
+
+        SuiteChangedPtr changed(node.get());
+
+        // Please note: that if any tasks under theNode are in
+        // active or submitted states, then we will have created zombies jobs
+        // The GUI: that calls this command should call a separate request
+        // the returns the active/submitted tasks first. This can then be
+        // presented to the user, who can elect to kill them if required.
+        bool createJobs = true;
+        if (test_)
+            createJobs = false;
+
+        /// This will *NOT* timeout, unlike server Job generation
+        JobsParam jobsParam(as->poll_interval(),
+                            createJobs); // default here is to spawn jobs , spawn jobs = true
+                                         // At the task level, if create jobs is false, we will not spawn jobs
+#ifdef DEBUG_JOB_SUBMISSION
+        jobsParam.logDebugMessage(" from RunNodeCmd::doHandleRequest");
+#endif
+
+        if (force_)
+            as->zombie_ctrl().add_user_zombies(node.get(), CtsApi::runArg());
+
+        // Avoid re-running the task again on the same time slot
+        node->miss_next_time_slot();
+
+        if (!node->run(jobsParam, force_)) {
+            LOG(Log::ERR, "RunNodeCmd: Failed for " << paths_[i] << " : " << jobsParam.getErrorMsg());
+        }
+    }
+
+    std::string error_msg = ss.str();
+    if (!error_msg.empty()) {
+        throw std::runtime_error(error_msg);
+    }
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+bool RunNodeCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    return do_authenticate(as, cmd, paths_);
+}
+
+const char* RunNodeCmd::arg() {
+    return CtsApi::runArg();
+}
+const char* RunNodeCmd::desc() {
+    return "Ignore triggers, limits, time or date dependencies, just run the Task.\n"
+           "When a job completes, it may be automatically re-queued if it has a cron\n"
+           "or multiple time dependencies. If we have multiple time based attributes,\n"
+           "then each run, will expire the time.\n"
+           "When we run before the time, we want to avoid re-running the task then\n"
+           "a flag is set, so that it is not automatically re-queued.\n"
+           "A repeat attribute is incremented when all the child nodes are complete\n"
+           "in this case the child nodes are automatically re-queued.\n"
+           "Hence this command can be aid, in allowing a Repeat attribute to be incremented\n"
+           "  arg1 = (optional)force\n"
+           "         Forcibly run, even if there are nodes that are active or submitted\n"
+           "         This can result in zombie creation\n"
+           "  arg2 = node path(s). The paths must begin with a leading '/' character.\n"
+           "         If the path is /suite/family will recursively run all tasks\n"
+           "         When providing multiple paths avoid running the same task twice\n"
+           "Example:\n"
+           "  --run=/suite/t1                    # run task t1\n"
+           "Effect:\n"
+           "     task t1; time 12:00             # will complete if run manually\n"
+           "     task t2; time 10:00 13:00 01:00 # will run 4 times before completing\n"
+           " When we have a time range(i.e as shown with task t2), then next time slot\n"
+           " is incremented for each run, until it expires, and the task completes.\n"
+           " Use the Why command, to show next run time (i.e. next time slot)";
+}
+
+void RunNodeCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(RunNodeCmd::arg(), po::value<vector<string>>()->multitoken(), RunNodeCmd::desc());
+}
+void RunNodeCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
+    vector<string> args = vm[RunNodeCmd::arg()].as<vector<string>>();
+
+    if (ace->debug())
+        dumpVecArgs(RunNodeCmd::arg(), args);
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
+    if (paths.empty()) {
+        std::stringstream ss;
+        ss << "RunNodeCmd: No paths specified. Paths must begin with a leading '/' character\n"
+           << RunNodeCmd::desc() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    bool force = false;
+    if (!options.empty()) {
+        if (options.size() != 1) {
+            std::stringstream ss;
+            ss << "RunNodeCmd: Invalid arguments. Expected a single optional 'force'\n" << RunNodeCmd::desc() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+        if (options[0].find("force") != std::string::npos)
+            force = true;
+        else {
+            std::stringstream ss;
+            ss << "RunNodeCmd: Expected force <path(s)>\n" << RunNodeCmd::desc() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    cmd = std::make_shared<RunNodeCmd>(paths, force);
+}
+
+std::ostream& operator<<(std::ostream& os, const RunNodeCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(RunNodeCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(RunNodeCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/RunNodeCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_RunNodeCmd_HPP
+#define ecflow_base_cts_user_RunNodeCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// The absNodepath must be provided
+class RunNodeCmd final : public UserCmd {
+public:
+    RunNodeCmd(const std::string& absNodepath, bool force, bool test = false)
+        : paths_(std::vector<std::string>(1, absNodepath)),
+          force_(force),
+          test_(test) {}
+
+    RunNodeCmd(const std::vector<std::string>& paths, bool force, bool test = false)
+        : paths_(paths),
+          force_(force),
+          test_(test) {}
+
+    RunNodeCmd() = default;
+
+    const std::vector<std::string>& paths() const { return paths_; }
+    bool force() const { return force_; }
+
+    bool isWrite() const override { return true; }
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    void print(std::string& os, const std::string& path) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after doHandleRequest
+
+private:
+    std::vector<std::string> paths_;
+    bool force_{false};
+    bool test_{false}; // only for test, hence we don't serialise this
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this), CEREAL_NVP(paths_), CEREAL_NVP(force_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const RunNodeCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(RunNodeCmd)
+
+#endif /* ecflow_base_cts_user_RunNodeCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Version.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+void ServerVersionCmd::print(std::string& os) const {
+    user_cmd(os, CtsApi::server_version());
+}
+void ServerVersionCmd::print_only(std::string& os) const {
+    os += CtsApi::server_version();
+}
+
+bool ServerVersionCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<ServerVersionCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+const char* ServerVersionCmd::theArg() const {
+    return CtsApi::server_version_arg();
+}
+
+STC_Cmd_ptr ServerVersionCmd::doHandleRequest(AbstractServer* as) const {
+    as->update_stats().server_version_++;
+    return PreAllocatedReply::string_cmd(Version::raw());
+}
+
+static const char* arg_desc() {
+    /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+    return "Returns the version number of the server\n"
+           "Usage:\n"
+           "  --server_version\n"
+           "    Writes the version to standard output\n";
+}
+
+void ServerVersionCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(CtsApi::server_version_arg(), arg_desc());
+}
+
+void ServerVersionCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
+    if (ace->debug())
+        cout << "  ServerVersionCmd::create\n";
+
+    // testing client interface
+    if (ace->under_test())
+        return;
+
+    cmd = std::make_shared<ServerVersionCmd>();
+}
+
+std::ostream& operator<<(std::ostream& os, const ServerVersionCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(ServerVersionCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(ServerVersionCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ServerVersionCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_ServerVersionCmd_HPP
+#define ecflow_base_cts_user_ServerVersionCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// ========================================================================
+// This Command should NEVER be changed
+// This will allow new client to ask OLD server about its version
+// ========================================================================
+class ServerVersionCmd final : public UserCmd {
+public:
+    ServerVersionCmd() = default;
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ServerVersionCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(ServerVersionCmd)
+
+#endif /* ecflow_base_cts_user_ServerVersionCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ShowCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ShowCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ShowCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ShowCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,114 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/ShowCmd.hpp"
+
+#include <iostream>
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+bool ShowCmd::equals(ClientToServerCmd* rhs) const {
+    return (dynamic_cast<ShowCmd*>(rhs)) ? UserCmd::equals(rhs) : false;
+}
+
+void ShowCmd::print(std::string& os) const {
+    user_cmd(os, "show");
+}
+void ShowCmd::print_only(std::string& os) const {
+    os += "show";
+}
+
+STC_Cmd_ptr ShowCmd::doHandleRequest(AbstractServer* as) const {
+    /// Should never get called since, show command is only called on client side.
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* ShowCmd::arg() {
+    return "show";
+}
+const char* ShowCmd::desc() {
+    return "Used to print state of the definition returned from the server to standard output.\n"
+           "This command can *only* be used in a group command, and will only work if it is\n"
+           "preceded with a get command. See examples below.\n"
+           "   arg1 = [ defs | state | migrate ] \n"
+           "The output of show has several options: i.e\n"
+           "  o no arguments: With no arguments, print the definition structure to standard output\n"
+           "    Extern's are automatically added, allowing the output to be reloaded into the server\n"
+           "    i.e --group=\"get ; show\"\n"
+           "  o state:\n"
+           "    This will output definition structure along with all the state information.\n"
+           "    This will include the trigger expressions, abstract syntax tree as comments.\n"
+           "    Excludes the edit history\n"
+           "  o migrate:\n"
+           "    This will output definition structure along with all the state information.\n"
+           "    The node state is shown in the comments.\n"
+           "    This format allows the definition to be migrated to future version of ecflow.\n"
+           "    The output includes edit history but excludes externs.\n"
+           "    When the definition is reloaded *NO* checking is done.\n"
+           "\n"
+           "The following shows a summary of the features associated with each choice\n"
+           "                        DEFS          STATE      MIGRATE\n"
+           "Auto generate externs   Yes           Yes        No\n"
+           "Checking on reload      Yes           Yes        No\n"
+           "Edit History            No            No         Yes\n"
+           "trigger AST             No            Yes        No\n"
+           "\n"
+           "Usage:\n"
+           "    --group=\"get ; show\"\n"
+           "    --group=\"get ; show defs\"    # same as the previous example\n"
+           "    --group=\"get ; show state\"   # Show all state for the node tree\n"
+           "    --group=\"get ; show migrate\" # Shows state and allows migration\n"
+           "    --group=\"get=/s1; show\"      # show state for the node only\n"
+           "    --group=\"get=/s1; show state\"";
+}
+
+void ShowCmd::addOption(boost::program_options::options_description& desc) const {
+    desc.add_options()(ShowCmd::arg(), po::value<string>()->implicit_value(string()), ShowCmd::desc());
+}
+void ShowCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ac) const {
+    std::string show_state = vm[ShowCmd::arg()].as<std::string>();
+
+    if (ac->debug())
+        cout << "  ShowCmd::create api = '" << show_state << "'.\n";
+
+    PrintStyle::Type_t style = PrintStyle::DEFS;
+    if (!show_state.empty()) {
+        if (show_state == "state")
+            style = PrintStyle::STATE;
+        else if (show_state == "migrate")
+            style = PrintStyle::MIGRATE;
+        else if (show_state == "defs")
+            style = PrintStyle::DEFS;
+        else
+            throw std::runtime_error(
+                "ShowCmd::create invalid show option expected one of [ defs | state | migrate ] but found " +
+                show_state);
+    }
+    cmd = std::make_shared<ShowCmd>(style);
+}
+
+std::ostream& operator<<(std::ostream& os, const ShowCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(ShowCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(ShowCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ShowCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ShowCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ShowCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ShowCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,58 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_ShowCmd_HPP
+#define ecflow_base_cts_user_ShowCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+// Does Nothing in the server, however allows client code to display the
+// returned Defs in different showStyles
+// This class has no need for persistence, i.e client side only
+class ShowCmd final : public UserCmd {
+public:
+    explicit ShowCmd(PrintStyle::Type_t s = PrintStyle::DEFS) : style_(s) {}
+
+    // returns the showStyle
+    bool show_cmd() const override { return true; }
+    PrintStyle::Type_t show_style() const override { return style_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override { return arg(); }
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    static const char* arg();  // used for argument parsing
+    static const char* desc(); // The description of the argument as provided to user
+
+    // The Show Cmd is processed on the client side,
+    // Likewise the doHandleRequest does nothing,
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+
+    PrintStyle::Type_t style_;
+
+    // Persistence is still required since show command can be *USED* in a *GROUP* command
+    // However its ONLY used on the client side, hence no need to serialise data members
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ShowCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(ShowCmd)
+
+#endif /* ecflow_base_cts_user_ShowCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/UserCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/UserCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/UserCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/UserCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,250 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+
+#include <iostream>
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/User.hpp"
+
+using namespace std;
+using namespace boost;
+using namespace ecf;
+
+bool UserCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<UserCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (user_ != the_rhs->user())
+        return false;
+    return ClientToServerCmd::equals(rhs);
+}
+
+bool UserCmd::authenticate(AbstractServer* as, STC_Cmd_ptr& cmd) const {
+    // The user should NOT be empty. Rather than asserting and killing the server, fail authentication
+    // ECFLOW-577 and ECFLOW-512. When user_ empty ??
+    if (!user_.empty() && as->authenticateReadAccess(user_, cu_, pswd_)) {
+
+        // Does this user command require write access
+        if (isWrite()) {
+            // command requires write access. Check user has write access
+            if (as->authenticateWriteAccess(user_)) {
+                return true;
+            }
+            std::string msg = "[ authentication failed ] User ";
+            msg += user_;
+            msg += " has no *write* access. Please see your administrator.";
+            throw std::runtime_error(msg);
+        }
+        else {
+            // read request, and we have read access
+            return true;
+        }
+    }
+
+    std::string msg = "[ authentication failed ] User '";
+    msg += user_;
+    msg += "' is not allowed any access.";
+    throw std::runtime_error(msg);
+
+    return false;
+}
+
+bool UserCmd::do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::string& path) const {
+    if (!user_.empty() && as->authenticateReadAccess(user_, cu_, pswd_, path)) {
+
+        // Does this user command require write access
+        if (isWrite()) {
+            // command requires write access. Check user has write access, add access to suite/node/path
+            if (as->authenticateWriteAccess(user_, path)) {
+                return true;
+            }
+            std::string msg = "[ authentication failed ] User ";
+            msg += user_;
+            msg += " has no *write* access. path(";
+            msg += path;
+            msg += ")Please see your administrator.";
+            throw std::runtime_error(msg);
+        }
+        else {
+            // read request, and we have read access
+            return true;
+        }
+    }
+
+    std::string msg = "[ authentication failed ] User '";
+    msg += user_;
+    msg += "' is not allowed any access. path(";
+    msg += path;
+    msg += ")";
+    throw std::runtime_error(msg);
+
+    return false;
+}
+
+bool UserCmd::do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::vector<std::string>& paths) const {
+    if (!user_.empty() && as->authenticateReadAccess(user_, cu_, pswd_, paths)) {
+
+        // Does this user command require write access
+        if (isWrite()) {
+            // command requires write access. Check user has write access
+            if (as->authenticateWriteAccess(user_, paths)) {
+                return true;
+            }
+            std::string msg = "[ authentication failed ] User ";
+            msg += user_;
+            msg += " has no *write* access to paths(";
+            for (const auto& path : paths) {
+                msg += path;
+                msg += ",";
+            }
+            msg += ") Please see your administrator.";
+            throw std::runtime_error(msg);
+        }
+        else {
+            // read request, and we have read access
+            return true;
+        }
+    }
+
+    std::string msg = "[ authentication failed ] User '";
+    msg += user_;
+    msg += "' is not allowed any access. paths(";
+    for (const auto& path : paths) {
+        msg += path;
+        msg += ",";
+    }
+    msg += ")";
+    throw std::runtime_error(msg);
+
+    return false;
+}
+
+void UserCmd::setup_user_authentification(const std::string& user, const std::string& passwd) {
+    user_ = user;
+    pswd_ = passwd; // assumes this has been crypted()
+    assert(!hostname().empty());
+    assert(!user_.empty());
+}
+
+bool UserCmd::setup_user_authentification(AbstractClientEnv& clientEnv) {
+    // A Custom user is one where:
+    //   o/ ECF_USER environment used
+    //   o/ --user on the command line
+    //   o/ ClientInvoker::set_user_name()
+    // Having a custom user name is an exception, to avoid having ALL user to provide a password
+    // we have a CUSTOM password file ECF_CUSTOM_PASSWD,   <host>.<port>.ecf.custom_passwd
+    const std::string& user_name = clientEnv.get_user_name(); // Using ECF_USER || --user <user> || set_user_name()/GUI
+    if (!user_name.empty()) {
+        cu_ = true; // inform server side custom USER used, server will expect password in ECF_CUSTOM_PASSWD files
+        const std::string& passwd = clientEnv.get_custom_user_password(user_name);
+        if (passwd.empty()) {
+            // cout << "invalid user as password is empty, must have a password when user specified \n";
+            return false; // invalid user as password is empty, must have a password when user specified
+        }
+
+        setup_user_authentification(user_name, passwd);
+        return true;
+    }
+
+    // User name is same as login name, if ECF_PASSWD is defined on server side *ALL* user must provide a password.
+    std::string the_user      = User::login_name();
+    const std::string& passwd = clientEnv.get_user_password(the_user);
+    setup_user_authentification(the_user, passwd);
+    return true;
+}
+
+void UserCmd::setup_user_authentification() {
+    if (user_.empty()) {
+        setup_user_authentification(User::login_name(), Str::EMPTY());
+    }
+}
+
+void UserCmd::prompt_for_confirmation(const std::string& prompt) {
+    cout << prompt;
+    char reply[256];
+    cin.getline(reply, 256);
+    if (reply[0] != 'y' && reply[0] != 'Y') {
+        exit(1);
+    }
+}
+
+void UserCmd::user_cmd(std::string& os, const std::string& the_cmd) const {
+    os += the_cmd;
+    os += " :";
+    os += user_;
+    os += '@';
+    os += hostname();
+}
+
+// #define DEBUG_ME 1
+
+void UserCmd::split_args_to_options_and_paths(const std::vector<std::string>& args,
+                                              std::vector<std::string>& options,
+                                              std::vector<std::string>& paths,
+                                              bool treat_colon_in_path_as_path) {
+    // ** ECFLOW-137 **, if the trigger expression have a leading '/' then it gets parsed into the paths
+    //                   vector and not options
+    // This is because boost program options does *NOT* seem to preserve the leading quotes around the
+    // trigger/complete expression,  i.e "/suite/t2 == complete"   is read as /suite/t2 == complete
+    // However in paths we do not expect to see any spaces
+
+    // Note: Node names are not allowed ':', hence ':' in a node path is always to reference a node attribute,
+    // event,limit in this case However we need to deal with special situations:
+    //   o --alter add inlimit /path/to/node/withlimit:limit_name 10  /s1  # TREAT /path/to/node/withlimit:limit_name as
+    //   a OPTION o --change trigger "/suite/task:a" /path/to/a/node                # TREAT "/suite/task:a" as a OPTION
+    //   o --force=clear /suite/task:ev                                    # TREAT /suite/task:ev as a PATH
+    // We need to distinguish between the two, hence use treat_colon_in_path_as_path
+    size_t vec_size = args.size();
+    if (treat_colon_in_path_as_path) {
+        for (size_t i = 0; i < vec_size; i++) {
+            if (args[i].empty())
+                continue;
+            if (args[i][0] == '/' && args[i].find(" ") == std::string::npos) {
+                // --force=clear /suite/task:ev  -> treat '/suite/task:ev' as a path
+                paths.push_back(args[i]);
+            }
+            else {
+                options.push_back(args[i]);
+            }
+        }
+    }
+    else {
+        // Treat ':' is path as a option, TREAT '/path/to/node/withlimit:limit_name' as a option
+        for (size_t i = 0; i < vec_size; i++) {
+            if (args[i][0] == '/' && args[i].find(" ") == std::string::npos && args[i].find(":") == std::string::npos) {
+                paths.push_back(args[i]);
+            }
+            else {
+                options.push_back(args[i]);
+            }
+        }
+    }
+#ifdef DEBUG_ME
+    std::cout << "split_args_to_options_and_paths\n";
+    for (size_t i = 0; i < args.size(); ++i) {
+        std::cout << "args[" << i << "]=" << args[i] << "\n";
+    }
+    for (size_t i = 0; i < options.size(); ++i) {
+        std::cout << "options[" << i << "]=" << options[i] << "\n";
+    }
+    for (size_t i = 0; i < paths.size(); ++i) {
+        std::cout << "paths[" << i << "]=" << paths[i] << "\n";
+    }
+#endif
+}
+
+int UserCmd::time_out_for_load_sync_and_get() {
+    return 600;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/UserCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/UserCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/UserCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/UserCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,65 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_UserCmd_HPP
+#define ecflow_base_cts_user_UserCmd_HPP
+
+#include "ecflow/base/Cmd.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+
+//=================================================================================
+// User Command
+// ================================================================================
+class UserCmd : public ClientToServerCmd {
+public:
+    UserCmd() = default;
+
+    const std::string& user() const { return user_; }
+    const std::string& passwd() const { return pswd_; }
+
+    void setup_user_authentification(const std::string& user, const std::string& passwd) override;
+    bool setup_user_authentification(AbstractClientEnv&) override;
+    void setup_user_authentification() override;
+
+protected:
+    bool equals(ClientToServerCmd*) const override;
+    bool authenticate(AbstractServer*, STC_Cmd_ptr&) const override;
+    bool do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::string& path) const;
+    bool do_authenticate(AbstractServer* as, STC_Cmd_ptr&, const std::vector<std::string>& paths) const;
+
+    /// Prompt the user for confirmation: If user responds with no, will exit client
+    static void prompt_for_confirmation(const std::string& prompt);
+
+    /// All user commands will be pre_fixed with "--" and post_fixed with :user@host
+    void user_cmd(std::string& os, const std::string& the_cmd) const;
+
+    static int time_out_for_load_sync_and_get();
+
+    // The order is preserved during the split. Paths assumed to start with '/' char
+    static void split_args_to_options_and_paths(const std::vector<std::string>& args,
+                                                std::vector<std::string>& options,
+                                                std::vector<std::string>& paths,
+                                                bool treat_colon_in_path_as_path = false);
+
+private:
+    std::string user_;
+    std::string pswd_;
+    bool cu_ = false; // custom user, i.e used set_user_name() || ECF_USER || --user -> only check this password
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<ClientToServerCmd>(this), CEREAL_NVP(user_));
+        CEREAL_OPTIONAL_NVP(ar, pswd_, [this]() { return !pswd_.empty(); }); // conditionally save
+        CEREAL_OPTIONAL_NVP(ar, cu_, [this]() { return cu_; });              // conditionally save
+    }
+};
+
+#endif /* ecflow_base_cts_user_UserCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,348 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/cts/user/ZombieCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/base/AbstractClientEnv.hpp"
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+void ZombieCmd::print(std::string& os) const {
+    switch (user_action_) {
+        case User::FOB:
+            user_cmd(os, CtsApi::to_string(CtsApi::zombieFob(paths_, process_id_, password_)));
+            break;
+        case User::FAIL:
+            user_cmd(os, CtsApi::to_string(CtsApi::zombieFail(paths_, process_id_, password_)));
+            break;
+        case User::ADOPT:
+            user_cmd(os, CtsApi::to_string(CtsApi::zombieAdopt(paths_, process_id_, password_)));
+            break;
+        case User::REMOVE:
+            user_cmd(os, CtsApi::to_string(CtsApi::zombieRemove(paths_, process_id_, password_)));
+            break;
+        case User::BLOCK:
+            user_cmd(os, CtsApi::to_string(CtsApi::zombieBlock(paths_, process_id_, password_)));
+            break;
+        case User::KILL:
+            user_cmd(os, CtsApi::to_string(CtsApi::zombieKill(paths_, process_id_, password_)));
+            break;
+        default:
+            break;
+    }
+}
+
+void ZombieCmd::print_only(std::string& os) const {
+    switch (user_action_) {
+        case User::FOB:
+            os += CtsApi::to_string(CtsApi::zombieFob(paths_, process_id_, password_));
+            break;
+        case User::FAIL:
+            os += CtsApi::to_string(CtsApi::zombieFail(paths_, process_id_, password_));
+            break;
+        case User::ADOPT:
+            os += CtsApi::to_string(CtsApi::zombieAdopt(paths_, process_id_, password_));
+            break;
+        case User::REMOVE:
+            os += CtsApi::to_string(CtsApi::zombieRemove(paths_, process_id_, password_));
+            break;
+        case User::BLOCK:
+            os += CtsApi::to_string(CtsApi::zombieBlock(paths_, process_id_, password_));
+            break;
+        case User::KILL:
+            os += CtsApi::to_string(CtsApi::zombieKill(paths_, process_id_, password_));
+            break;
+        default:
+            break;
+    }
+}
+
+bool ZombieCmd::equals(ClientToServerCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<ZombieCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (paths_ != the_rhs->paths())
+        return false;
+    if (process_id_ != the_rhs->process_or_remote_id())
+        return false;
+    if (password_ != the_rhs->password())
+        return false;
+    return UserCmd::equals(rhs);
+}
+
+STC_Cmd_ptr ZombieCmd::doHandleRequest(AbstractServer* as) const {
+    switch (user_action_) {
+        case User::FOB:
+            as->update_stats().zombie_fob_++;
+            break;
+        case User::FAIL:
+            as->update_stats().zombie_fail_++;
+            break;
+        case User::ADOPT:
+            as->update_stats().zombie_adopt_++;
+            break;
+        case User::REMOVE:
+            as->update_stats().zombie_remove_++;
+            break;
+        case User::BLOCK:
+            as->update_stats().zombie_block_++;
+            break;
+        case User::KILL:
+            as->update_stats().zombie_kill_++;
+            break;
+    }
+
+    // To uniquely identify a zombie we need path to task and remote_id, This information
+    // is available from the zombie class via get command. However we do not want to expose the password.
+    // Hence the Command level interface  will make do with just the path to the task.
+    // The first zombie whose corresponding task where password does *NOT* match is acted upon
+    if (process_id_.empty() && password_.empty()) {
+        for (const auto& path : paths_) {
+            node_ptr node = as->defs()->findAbsNode(path);
+            Task* task    = nullptr;
+            if (node.get())
+                task = node->isTask();
+            switch (user_action_) {
+                case User::FOB:
+                    as->zombie_ctrl().fobCli(path, task);
+                    break;
+                case User::FAIL:
+                    as->zombie_ctrl().failCli(path, task);
+                    break;
+                case User::ADOPT:
+                    as->zombie_ctrl().adoptCli(path, task);
+                    break;
+                case User::REMOVE:
+                    as->zombie_ctrl().removeCli(path, task);
+                    break;
+                case User::BLOCK:
+                    as->zombie_ctrl().blockCli(path, task);
+                    break;
+                case User::KILL:
+                    as->zombie_ctrl().killCli(path, task);
+                    break;
+            }
+        }
+    }
+    else {
+        // expect a single path, process_id and password only apply for a single task
+        if (paths_.size() == 1) {
+            switch (user_action_) {
+                case User::FOB:
+                    as->zombie_ctrl().fob(paths_[0], process_id_, password_);
+                    break;
+                case User::FAIL:
+                    as->zombie_ctrl().fail(paths_[0], process_id_, password_);
+                    break;
+                case User::ADOPT:
+                    as->zombie_ctrl().adopt(paths_[0], process_id_, password_);
+                    break;
+                case User::REMOVE:
+                    as->zombie_ctrl().remove(paths_[0], process_id_, password_);
+                    break;
+                case User::BLOCK:
+                    as->zombie_ctrl().block(paths_[0], process_id_, password_);
+                    break;
+                case User::KILL:
+                    as->zombie_ctrl().kill(paths_[0], process_id_, password_);
+                    break;
+            }
+        }
+        else {
+            return PreAllocatedReply::error_cmd("ZombieCmd: process_or_remote_id and password cannot be used when "
+                                                "multiple paths are specified. Please specify a single path");
+        }
+    }
+
+    return PreAllocatedReply::ok_cmd();
+}
+
+const char* ZombieCmd::theArg() const {
+
+    switch (user_action_) {
+        case User::FOB:
+            return CtsApi::zombieFobArg();
+            break;
+        case User::FAIL:
+            return CtsApi::zombieFailArg();
+            break;
+        case User::ADOPT:
+            return CtsApi::zombieAdoptArg();
+            break;
+        case User::REMOVE:
+            return CtsApi::zombieRemoveArg();
+            break;
+        case User::BLOCK:
+            return CtsApi::zombieBlockArg();
+            break;
+        case User::KILL:
+            return CtsApi::zombieKillArg();
+            break;
+        default:
+            break;
+    }
+    assert(false);
+    return nullptr;
+}
+
+void ZombieCmd::addOption(boost::program_options::options_description& desc) const {
+    switch (user_action_) {
+
+        case User::FOB: {
+            desc.add_options()(
+                CtsApi::zombieFobArg(),
+                po::value<vector<string>>()->multitoken(),
+                "Locates the task in the servers list of zombies, and sets to fob.\n"
+                "This default behaviour of the child commands(label,event,meter) is to fob\n"
+                "Next time the child commands (init,event,meter,label,abort,complete,wait,queue) communicate\n"
+                "with the server, they will complete successfully (but without updating the node tree)\n"
+                "allowing the job to finish.\n"
+                "The references to the zombie in the server is automatically deleted after 1 hour\n"
+                "  args = list of task paths, at least one expected\n"
+                "  --zombie_fob=/path/to/task1 /path/to/task2");
+            break;
+        }
+        case User::FAIL: {
+            desc.add_options()(CtsApi::zombieFailArg(),
+                               po::value<vector<string>>()->multitoken(),
+                               "Locates the task in the servers list of zombies, and sets to fail.\n"
+                               "Next time a child command (init,event,meter,label,abort,complete) which "
+                               "matches zombie, communicates with the server, will be set to fail.\n"
+                               "Depending on the job setup this may force a abort, the abort will also fail.\n"
+                               "Hence job structure should use 'set -e' in the error trapping functions to prevent\n"
+                               "infinite recursion.\n"
+                               "The references to the zombie in the server is automatically deleted after 1 hour\n"
+                               "  args = list of task paths, at least one expected\n"
+                               "  --zombie_fail=/path/to/task  /path/to/task2");
+            break;
+        }
+        case User::ADOPT: {
+            desc.add_options()(CtsApi::zombieAdoptArg(),
+                               po::value<vector<string>>()->multitoken(),
+                               "Locates the task in the servers list of zombies, and sets to adopt.\n"
+                               "Next time a child command (init,event,meter,label,abort,complete,wait queue) "
+                               "communicates with the server, the password on the zombie is adopted by the task.\n"
+                               "This is only allowed if the process id matches, otherwise an error is issued.\n"
+                               "The zombie reference stored in the server is then deleted.\n"
+                               "  args = list of task paths, at least one expected\n"
+                               "  --zombie_adopt=/path/to/task  /path/to/task2");
+            break;
+        }
+        case User::REMOVE: {
+            desc.add_options()(
+                CtsApi::zombieRemoveArg(),
+                po::value<vector<string>>()->multitoken(),
+                "Locates the task in the servers list of zombies, and removes it.\n"
+                "Since a job typically has many child commands (i.e init, complete, event, meter, label, wait, queue)\n"
+                "the zombie may reappear\n"
+                "  args = list of task paths, at least one expected\n"
+                "  --zombie_remove=/path/to/task  /path/to/task2");
+            break;
+        }
+        case User::BLOCK: {
+            desc.add_options()(CtsApi::zombieBlockArg(),
+                               po::value<vector<string>>()->multitoken(),
+                               "Locates the task in the servers list of zombies, and sets flags to block it.\n"
+                               "This is default behaviour of the child commands(init,abort,complete,wait,queue)\n"
+                               "when the server cannot match the passwords. Each child commands will continue\n"
+                               "attempting to connect to the server for 24 hours, and will then return an error.\n"
+                               "The connection timeout can be configured with environment ECF_TIMEOUT\n"
+                               "  args = list of task paths, at least one expected\n"
+                               "  --zombie_block=/path/to/task  /path/to/task2");
+            break;
+        }
+        case User::KILL: {
+            desc.add_options()(CtsApi::zombieKillArg(),
+                               po::value<vector<string>>()->multitoken(),
+                               "Locates the task in the servers list of zombies, and sets flags to kill\n"
+                               "The kill is done using ECF_KILL_CMD, but using the process_id from the zombie\n"
+                               "The job is allowed to continue until the kill is received\n"
+                               "Can only kill zombies that have an associated Task, hence path zombies\n"
+                               "must be killed manually.\n"
+                               "  arg = list of task paths, at least one expected\n"
+                               "  --zombie_kill=/path/to/task  /path/to/task2");
+            break;
+        }
+        default:
+            assert(false);
+            break;
+    }
+}
+
+void ZombieCmd::create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* ace) const {
+    vector<string> args = vm[theArg()].as<vector<string>>();
+    if (ace->debug())
+        dumpVecArgs(theArg(), args);
+
+    // For Command Line Interface only the task_path is provided. Just have to make do.
+    // arg = process_or_remote_id   ( empty for CLI and when multiple paths specified)
+    // arg = password               ( empty for CLI and when multiple paths specified)
+    // arg = paths
+    std::string process_or_remote_id;
+    std::string password;
+
+    std::vector<std::string> options, paths;
+    split_args_to_options_and_paths(args, options, paths); // relative order is still preserved
+    if (paths.empty()) {
+        std::stringstream ss;
+        ss << "ZombieCmd: No paths specified. At least one path expected. Paths must begin with a leading '/' "
+              "character\n";
+        throw std::runtime_error(ss.str());
+    }
+    if (paths.size() > 1 && !options.empty()) {
+        std::stringstream ss;
+        ss << "ZombieCmd: process_or_remote_id and password cannot be used when multiple paths are specified. Please "
+              "specify a single path\n";
+        throw std::runtime_error(ss.str());
+    }
+    if (options.size() >= 3) {
+        std::stringstream ss;
+        ss << "ZombieCmd: to many options expected only process_or_remote_id and password and a list of paths.\n";
+        throw std::runtime_error(ss.str());
+    }
+    if (options.size() == 1)
+        process_or_remote_id = options[0];
+    if (options.size() == 2)
+        password = options[1];
+
+    if (ace->get_cli()) {
+        // We are using command line, expect only paths
+        if (!process_or_remote_id.empty()) {
+            throw std::runtime_error(
+                "ZombieCmd:: With the command line interface, we expected only paths i.e /path/to/task");
+        }
+        if (!password.empty()) {
+            throw std::runtime_error(
+                "ZombieCmd:: With the command line interface, we expected only paths i.e /path/to/task");
+        }
+    }
+
+    cmd = std::make_shared<ZombieCmd>(user_action_, paths, process_or_remote_id, password);
+}
+
+std::ostream& operator<<(std::ostream& os, const ZombieCmd& c) {
+    std::string ret;
+    c.print(ret);
+    os << ret;
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(ZombieCmd)
+CEREAL_REGISTER_DYNAMIC_INIT(ZombieCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/cts/user/ZombieCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,65 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_user_ZombieCmd_HPP
+#define ecflow_base_cts_user_ZombieCmd_HPP
+
+#include "ecflow/base/cts/user/UserCmd.hpp"
+#include "ecflow/core/User.hpp"
+
+class ZombieCmd final : public UserCmd {
+public:
+    ZombieCmd(ecf::User::Action uc,
+              const std::vector<std::string>& paths,
+              const std::string& process_id,
+              const std::string& password)
+        : user_action_(uc),
+          process_id_(process_id),
+          password_(password),
+          paths_(paths) {}
+    explicit ZombieCmd(ecf::User::Action uc = ecf::User::BLOCK) : user_action_(uc) {}
+
+    const std::vector<std::string>& paths() const { return paths_; }
+    const std::string& process_or_remote_id() const { return process_id_; }
+    const std::string& password() const { return password_; }
+
+    void print(std::string&) const override;
+    void print_only(std::string&) const override;
+    bool equals(ClientToServerCmd*) const override;
+
+    const char* theArg() const override;
+    void addOption(boost::program_options::options_description& desc) const override;
+    void create(Cmd_ptr& cmd, boost::program_options::variables_map& vm, AbstractClientEnv* clientEnv) const override;
+
+private:
+    STC_Cmd_ptr doHandleRequest(AbstractServer*) const override;
+    void cleanup() override { std::vector<std::string>().swap(paths_); } /// run in the server, after handlerequest
+
+    ecf::User::Action user_action_;
+    std::string process_id_; // should be empty for multiple paths and when using CLI
+    std::string password_;   // should be empty for multiple paths and when using CLI
+    std::vector<std::string> paths_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/) {
+        ar(cereal::base_class<UserCmd>(this),
+           CEREAL_NVP(user_action_),
+           CEREAL_NVP(process_id_),
+           CEREAL_NVP(password_),
+           CEREAL_NVP(paths_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ZombieCmd&);
+
+CEREAL_FORCE_DYNAMIC_INIT(ZombieCmd)
+
+#endif /* ecflow_base_cts_user_ZombieCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ssl_connection.cpp 5.13.0-1/libs/base/src/ecflow/base/ssl_connection.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/ssl_connection.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ssl_connection.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,76 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/ssl_connection.hpp"
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Log.hpp"
+
+ssl_connection::~ssl_connection() {
+#ifdef DEBUG_CONNECTION
+    if (Ecf::server())
+        std::cout << "SERVER: ssl_connection::~ssl_connection socket_.is_open() = " << socket_.is_open() << "\n\n";
+    else
+        std::cout << "CLIENT: ssl_connection::~ssl_connection socket_.is_open() = " << socket_.is_open() << "\n\n";
+#endif
+}
+
+ssl_connection::ssl_connection(boost::asio::io_service& io_service, boost::asio::ssl::context& context)
+    : socket_(io_service, context) {
+#ifdef DEBUG_CONNECTION
+    if (Ecf::server())
+        std::cout << "SERVER: ssl_connection::ssl_connection\n";
+    else
+        std::cout << "CLIENT: ssl_connection::ssl_connection\n";
+#endif
+    socket_.set_verify_mode(boost::asio::ssl::verify_peer);
+
+    // If we want server to verify client certificate, the use as below:
+    // However this requires that certificate is installed.
+    // if (Ecf::server())
+    // socket_.set_verify_mode(boost::asio::ssl::verify_peer|boost::asio::ssl::verify_fail_if_no_peer_cert); else
+    // socket_.set_verify_mode(boost::asio::ssl::verify_peer);
+    socket_.set_verify_callback([this](bool preverified, boost::asio::ssl::verify_context& ctx) {
+        return this->verify_certificate(preverified, ctx);
+    });
+}
+
+bool ssl_connection::verify_certificate(bool preverified, boost::asio::ssl::verify_context& ctx) {
+    // The verify callback can be used to check whether the certificate that is
+    // being presented is valid for the peer. For example, RFC 2818 describes
+    // the steps involved in doing this for HTTPS. Consult the OpenSSL
+    // documentation for more details. Note that the callback is called once
+    // for each certificate in the certificate chain, starting from the root
+    // certificate authority.
+
+    // In this example we will simply print the certificate's subject name.
+    char subject_name[256];
+    X509* cert = X509_STORE_CTX_get_current_cert(ctx.native_handle());
+    X509_NAME_oneline(X509_get_subject_name(cert), subject_name, 256);
+    // std::cout << "Verifying " << subject_name << "\n";
+
+    return preverified;
+}
+
+void ssl_connection::log_error(const char* msg) {
+    const char* in_context = ", in client";
+    if (Ecf::server())
+        in_context = ", in server";
+    ecf::LogToCout logToCout;
+    LOG(ecf::Log::ERR, msg << in_context);
+}
+
+void ssl_connection::log_archive_error(const char* msg, const std::exception& ae, const std::string& data) {
+    const char* in_context = ", in client";
+    if (Ecf::server())
+        in_context = ", in server";
+    ecf::LogToCout logToCout;
+    LOG(ecf::Log::ERR, msg << ae.what() << in_context << " data:\n" << data);
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/ssl_connection.hpp 5.13.0-1/libs/base/src/ecflow/base/ssl_connection.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/ssl_connection.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/ssl_connection.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,232 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_ssl_connection_HPP
+#define ecflow_base_ssl_connection_HPP
+
+#if defined(HPUX)
+    #include <sys/select.h> // hp-ux uses pselect
+#endif
+
+#include <iomanip>
+#include <memory>
+#include <sstream>
+
+#include <boost/asio.hpp>
+#include <boost/asio/ssl.hpp>
+
+#include "ecflow/core/Serialization.hpp"
+
+// #define DEBUG_CONNECTION 1
+#ifdef DEBUG_CONNECTION
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+///
+/// \brief Serves as the connection between client server
+///
+/// \note If you change this file then Connection.hpp may also need changing
+///
+
+typedef boost::asio::ssl::stream<boost::asio::ip::tcp::socket> ssl_socket;
+
+/// The connection class provides serialisation primitives on top of a socket.
+/**
+ * Each message sent using this class consists of:
+ * @li An 8-byte header containing the length of the serialized data in
+ * hexadecimal.
+ * @li The serialized data.
+ */
+
+class ssl_connection {
+public:
+    ~ssl_connection();
+
+    ssl_connection(boost::asio::io_service& io_service, boost::asio::ssl::context& context);
+    bool verify_certificate(bool preverified, boost::asio::ssl::verify_context& ctx);
+
+    /// Get the underlying socket. Used for making a connection or for accepting
+    /// an incoming connection.
+    ssl_socket::lowest_layer_type& socket_ll() { return socket_.lowest_layer(); }
+    ssl_socket& socket() { return socket_; }
+
+    /// Asynchronously write a data structure to the socket.
+    template <typename T, typename Handler>
+    void async_write(const T& t, Handler handler) {
+
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: ssl_connection::async_write\n";
+        else
+            std::cout << "CLIENT: ssl_connection::async_write\n";
+        std::cout << "   Serialise the data first so we know how large it is\n";
+#endif
+        // Serialise the data first so we know how large it is.
+        try {
+            ecf::save_as_string(outbound_data_, t);
+        }
+        catch (const std::exception& ae) {
+            // Unable to decode data. Something went wrong, inform the caller.
+            log_archive_error("ssl_connection::async_write, exception ", ae, outbound_data_);
+            boost::system::error_code error(boost::asio::error::invalid_argument);
+            boost::asio::post(socket_.get_executor(), [handler, error]() { handler(error); });
+            return;
+        }
+
+#ifdef DEBUG_CONNECTION
+        std::cout << "   Format the header:\n";
+#endif
+        // Format the header.
+        std::ostringstream header_stream;
+        header_stream << std::setw(header_length) << std::hex << outbound_data_.size();
+        if (!header_stream || header_stream.str().size() != header_length) {
+            // Something went wrong, inform the caller.
+            log_error("ssl_connection::async_write, could not format header");
+            boost::system::error_code error(boost::asio::error::invalid_argument);
+            boost::asio::post(socket_.get_executor(), [handler, error]() { handler(error); });
+            return;
+        }
+        outbound_header_ = header_stream.str();
+
+#ifdef DEBUG_CONNECTION
+        std::cout << "   Write the HEADER and serialised DATA to the socket\n";
+        std::cout << "   outbound_header_.size(" << outbound_header_.size() << ")\n";
+        std::cout << "   outbound_header_:'" << outbound_header_ << "' # this is the size in hex\n";
+        std::cout << "   outbound_data_.size(" << outbound_data_.size() << ")\n";
+        std::cout << "   hdr+data:'" << outbound_header_ << outbound_data_ << "'\n";
+#endif
+
+        // Write the serialized data to the socket. We use "gather-write" to send
+        // both the header and the data in a single write operation.
+        std::vector<boost::asio::const_buffer> buffers;
+        buffers.reserve(2);
+        buffers.emplace_back(boost::asio::buffer(outbound_header_));
+        buffers.emplace_back(boost::asio::buffer(outbound_data_));
+        boost::asio::async_write(
+            socket_, buffers, [handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
+                handler(error);
+            });
+
+#ifdef DEBUG_CONNECTION
+        std::cout << "   END\n";
+#endif
+    }
+
+    /// Asynchronously read a data structure from the socket.
+    template <typename T, typename Handler>
+    void async_read(T& t, Handler handler) {
+
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: ssl_connection::async_read\n";
+        else
+            std::cout << "CLIENT: ssl_connection::async_read\n";
+#endif
+
+        // Issue a read operation to read exactly the number of bytes in a header.
+        boost::asio::async_read(
+            socket_,
+            boost::asio::buffer(inbound_header_),
+            [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
+                this->handle_read_header(error, t, handler);
+            });
+    }
+
+private:
+    /// Handle a completed read of a message header.
+    template <typename T, typename Handler>
+    void handle_read_header(const boost::system::error_code& e, T& t, Handler handler) {
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: ssl_onnection::handle_read_header\n";
+        else
+            std::cout << "CLIENT: ssl_connection::handle_read_header\n";
+        std::cout << "   header:'" << std::string(inbound_header_, header_length)
+                  << "'  # this size of payload in hex\n";
+#endif
+        if (e) {
+            handler(e);
+        }
+        else {
+            // Determine the length of the serialized data.
+            std::istringstream is(std::string(inbound_header_, header_length));
+            std::size_t inbound_data_size = 0;
+            if (!(is >> std::hex >> inbound_data_size)) {
+
+                // Header doesn't seem to be valid. Inform the caller.
+                std::string err = "ssl_connection::handle_read_header: invalid header : " +
+                                  std::string(inbound_header_, header_length);
+                log_error(err.c_str());
+                handler(boost::asio::error::invalid_argument);
+                return;
+            }
+
+            // Start an asynchronous call to receive the data.
+            inbound_data_.resize(inbound_data_size);
+            boost::asio::async_read(
+                socket_,
+                boost::asio::buffer(inbound_data_),
+                [this, &t, handler](const boost::system::error_code& error, std::size_t bytes_transferred) {
+                    this->handle_read_data(error, t, handler);
+                });
+        }
+    }
+
+    /// Handle a completed read of message data.
+    template <typename T, typename Handler>
+    void handle_read_data(const boost::system::error_code& e, T& t, Handler handler) {
+#ifdef DEBUG_CONNECTION
+        if (Ecf::server())
+            std::cout << "SERVER: ssl_connection::handle_read_data\n";
+        else
+            std::cout << "CLIENT: ssl_connection::handle_read_data\n";
+#endif
+
+        if (e) {
+            handler(e);
+        }
+        else {
+            // Extract the data structure from the data just received.
+            std::string archive_data(&inbound_data_[0], inbound_data_.size());
+            try {
+#ifdef DEBUG_CONNECTION
+                std::cout << "   inbound_data_.size(" << inbound_data_.size() << ") typeid(" << typeid(t).name()
+                          << ")\n";
+                std::cout << "   '" << archive_data << "'\n";
+#endif
+                ecf::restore_from_string(archive_data, t);
+            }
+            catch (std::exception& e) {
+                log_archive_error("ssl_connection::handle_read_data, Unable to decode data :", e, archive_data);
+                handler(boost::asio::error::invalid_argument);
+                return;
+            }
+
+            // Inform caller that data has been received ok.
+            handler(e);
+        }
+    }
+
+private:
+    static void log_error(const char* msg);
+    static void log_archive_error(const char* msg, const std::exception& ae, const std::string& data);
+
+private:
+    ssl_socket socket_;                  /// The underlying socket.
+    std::string outbound_header_;        /// Holds an out-bound header.
+    std::string outbound_data_;          /// Holds the out-bound data.
+    enum { header_length = 8 };          /// The size of a fixed length header.
+    char inbound_header_[header_length]; /// Holds an in-bound header.
+    std::vector<char> inbound_data_;     /// Holds the in-bound data.
+};
+
+typedef std::shared_ptr<ssl_connection> ssl_connection_ptr;
+
+#endif /* ecflow_base_ssl_connection_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/BlockClientZombieCmd.hpp"
+
+#include <iostream>
+
+std::string BlockClientZombieCmd::print() const {
+    switch (zombie_type_) {
+        case ecf::Child::USER:
+            return "cmd:BlockClientZombieCmd: user";
+        case ecf::Child::PATH:
+            return "cmd:BlockClientZombieCmd: path";
+        case ecf::Child::ECF:
+            return "cmd:BlockClientZombieCmd: ecf";
+        case ecf::Child::ECF_PID:
+            return "cmd:BlockClientZombieCmd: ecf_pid";
+        case ecf::Child::ECF_PID_PASSWD:
+            return "cmd:BlockClientZombieCmd: ecf_pid_passwd";
+        case ecf::Child::ECF_PASSWD:
+            return "cmd:BlockClientZombieCmd: ecf_passwd";
+        case ecf::Child::NOT_SET:
+            return "cmd:BlockClientZombieCmd: not_set";
+    }
+    assert(false); // unknown command
+    return "cmd:Unknown??";
+}
+
+// Client context
+bool BlockClientZombieCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        std::cout << "  BlockClientZombieCmd::handle_server_response BLOCK_CLIENT_ZOMBIE "
+                  << ecf::Child::to_string(zombie_type_) << "\n";
+    server_reply.set_block_client_zombie_detected(); // requires further work, by ClientInvoker
+    return false;                                    // false means fall through and try again, i.e BLOCK client
+}
+
+bool BlockClientZombieCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<BlockClientZombieCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (zombie_type_ != the_rhs->zombie_type())
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::ostream& operator<<(std::ostream& os, const BlockClientZombieCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/BlockClientZombieCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_BlockClientZombieCmd_HPP
+#define ecflow_base_stc_BlockClientZombieCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/core/Child.hpp"
+
+//
+// This command send the zombie type to the client
+// For the moment we simply block for zombie, but the client
+// in the future could do different things depending on the zombie type
+//
+class BlockClientZombieCmd final : public ServerToClientCmd {
+public:
+    explicit BlockClientZombieCmd(ecf::Child::ZombieType zt) : zombie_type_(zt) {}
+    BlockClientZombieCmd() = default;
+
+    void init(ecf::Child::ZombieType zt) { zombie_type_ = zt; } // server context
+    ecf::Child::ZombieType zombie_type() const { return zombie_type_; }
+
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool
+    handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override; // client context
+
+    bool is_returnable_in_group_cmd() const override { return false; } /// used by group command
+
+private:
+    ecf::Child::ZombieType zombie_type_{ecf::Child::NOT_SET};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(zombie_type_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const BlockClientZombieCmd&);
+
+#endif /* ecflow_base_stc_BlockClientZombieCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCache.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCache.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCache.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCache.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/DefsCache.hpp"
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+
+// =====================================================================================================
+// #define DEBUG_SERVER_SYNC 1
+// #define DEBUG_CLIENT_SYNC 1
+#ifdef DEBUG_SERVER_SYNC
+    #include <iostream>
+#endif
+
+using namespace std;
+using namespace boost;
+
+// ===========================================================================================
+// CACHE: the deserialization costs, so that if multiple clients request the full defs
+//        we can improve the performance, by only performing that once for each state change.
+std::string DefsCache::full_server_defs_as_string_ = "";
+unsigned int DefsCache::state_change_no_           = 0;
+unsigned int DefsCache::modify_change_no_          = 0;
+
+void DefsCache::update_cache_if_state_changed(Defs* defs) {
+    // See if there was a state change *OR* if cache is empty
+    if (state_change_no_ != Ecf::state_change_no() || modify_change_no_ != Ecf::modify_change_no() ||
+        full_server_defs_as_string_.empty()) {
+        update_cache(defs);
+    }
+#ifdef DEBUG_SERVER_SYNC
+    else {
+        cout << ": *cache* up to date";
+    }
+#endif
+}
+
+void DefsCache::update_cache(Defs* defs) {
+#ifdef DEBUG_SERVER_SYNC
+    cout << ": *updating* cache";
+#endif
+    defs->save_as_string(full_server_defs_as_string_, PrintStyle::NET); // update cache
+    state_change_no_  = Ecf::state_change_no();
+    modify_change_no_ = Ecf::modify_change_no();
+}
+
+defs_ptr DefsCache::restore_defs_from_string(const std::string& archive_data) {
+#ifdef DEBUG_CLIENT_SYNC
+    cout << ": DefsCache::restore_defs_from_string: archive_data.size(" << archive_data.size() << ")";
+#endif
+
+    defs_ptr defs = Defs::create();
+    try {
+        // cout << "archive_data:\n" << archive_data << "\n";
+        defs->restore_from_string(archive_data);
+    }
+    catch (std::exception& e) {
+        ecf::LogToCout logToCout;
+        LOG(ecf::Log::ERR, "DefsCache::restore_defs_from_string " << e.what());
+        throw;
+    }
+
+#ifdef DEBUG_CLIENT_SYNC
+    if (defs.get())
+        cout << ": valid defs";
+    else
+        cout << ": *empty* defs?";
+#endif
+    return defs;
+}
+
+defs_ptr DefsCache::restore_defs_from_string() {
+    // Used in Test when no client/server
+    return restore_defs_from_string(full_server_defs_as_string_);
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCache.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCache.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCache.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCache.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,67 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_DefsCache_HPP
+#define ecflow_base_cts_DefsCache_HPP
+
+#include "ecflow/node/NodeFwd.hpp"
+
+//================================================================================
+// Cache the de-serialisation cost, in the *SERVER* when returning the FULL definition
+// When there are no state changes, we can just return the cache string for other clients
+// Thereby saving time in the server and client for de-serialisation.
+// Here we are trading memory for speed:
+//
+//  Current for each client request we have:
+//      client1:  --------------> get---------------> Server
+//                serialise---------<----de-serialize
+//
+//      client2:  --------------> get---------------> Server
+//                serialise---------<----de-serialize
+//
+//      client3:  --------------> get---------------> Server
+//                serialise---------<----de-serialize
+//
+// By caching the de-serialisation process, we can speed up the downloads.
+// However whenever there is a state change we need to update the cache
+//
+//      client1:  --------------> get---------------> Server
+//                serialise------<----de-serialisation
+//
+//      client2:  --------------> get---------------> Server
+//                serialise---------<----return cache
+//
+//      client3:  --------------> get---------------> Server
+//                serialise---------<----return cache
+//================================================================================
+class DefsCache {
+public:
+    DefsCache()                            = delete;
+    DefsCache(const DefsCache&)            = delete;
+    DefsCache& operator=(const DefsCache&) = delete;
+
+    // Server side
+    static void update_cache_if_state_changed(Defs* defs);
+    static void update_cache(Defs* defs);
+
+    // Client side
+    static defs_ptr restore_defs_from_string(const std::string&);
+    static defs_ptr restore_defs_from_string(); // used in test
+
+private:
+    friend class SSyncCmd;
+    friend class DefsCmd;
+
+    static std::string full_server_defs_as_string_;
+    static unsigned int state_change_no_;  // detect state change in defs across clients
+    static unsigned int modify_change_no_; // detect state change in defs across clients
+};
+
+#endif /* ecflow_base_cts_DefsCache_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,92 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/DefsCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace boost;
+
+//=====================================================================================
+// The defs command returns the full definition back to the client
+
+DefsCmd::DefsCmd(AbstractServer* as, bool save_edit_history) {
+    init(as, save_edit_history); // save edit history
+}
+
+void DefsCmd::init(AbstractServer* as, bool save_edit_history) {
+    /// Return the current value of the state change no. So the that
+    /// the next call to get the SSYncCmd , we need only return what's changed
+    Defs* server_defs = as->defs().get();
+    server_defs->set_state_change_no(Ecf::state_change_no());
+    server_defs->set_modify_change_no(Ecf::modify_change_no());
+    server_defs->save_edit_history(save_edit_history);
+
+    // The CACHE is only updated if state/modify numbers change, hence does not take into account suite CLOCK
+    // However DefsCmd should always return the most up to date server contents.
+    DefsCache::update_cache(server_defs);
+}
+
+bool DefsCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<DefsCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (!ServerToClientCmd::equals(rhs))
+        return false;
+    return true;
+}
+
+std::string DefsCmd::print() const {
+    return "cmd:DefsCmd [ defs ]";
+}
+
+// Called in client
+bool DefsCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        std::cout << "  DefsCmd::handle_server_response show_state = " << PrintStyle::to_string(cts_cmd->show_style())
+                  << "\n";
+
+    // If we asked for the defs node tree from the server, then this is what we should have got back.
+    // ** Keep existing defs in memory, until a new one is requested. This allows clients
+    // ** to continue using this defs, in between other api calls, until a new defs is requested.
+
+    defs_ptr defs = DefsCache::restore_defs_from_string(full_server_defs_as_string_);
+
+    if (server_reply.cli() && !cts_cmd->group_cmd()) {
+        /// This Could be part of a group command, hence ONLY show defs if NOT group command
+        PrintStyle style(cts_cmd->show_style());
+
+        if (!PrintStyle::is_persist_style(cts_cmd->show_style())) {
+            /// Auto generate externs, before writing to standard out. This can be expensive since
+            /// All the trigger references need to to be resolved. & AST need to be created first
+            /// The old spirit based parsing, horrendously, slow. Can't use Spirit QI, till IBM pull support it
+            defs->auto_add_externs();
+        }
+        std::cout << *defs;
+    }
+    else {
+        server_reply.set_sync(true);      // always in sync when getting the full defs
+        server_reply.set_full_sync(true); // Done a full sync, as opposed to incremental
+        server_reply.set_client_defs(defs);
+    }
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const DefsCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/DefsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/DefsCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_cts_DefsCmd_HPP
+#define ecflow_base_cts_DefsCmd_HPP
+
+#include "ecflow/base/stc/DefsCache.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+class AbstractServer;
+
+//================================================================================
+// Paired with CtsNodeCmd(GET)
+// Client---CtsNodeCmd(GET)---->Server-----(DefsCmd | SNodeCmd)--->client:
+//================================================================================
+class DefsCmd final : public ServerToClientCmd {
+public:
+    explicit DefsCmd(AbstractServer* as, bool save_edit_history = false);
+    DefsCmd() = default;
+
+    void init(AbstractServer* as, bool save_edit_history);
+
+    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    void cleanup() override {
+        std::string().swap(full_server_defs_as_string_);
+    } /// run in the server, after command send to client
+
+private:
+    std::string full_server_defs_as_string_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this));
+
+        if (Archive::is_saving::value) {
+            // Avoid copying the string. As this could be very large
+            ar& DefsCache::full_server_defs_as_string_;
+        }
+        else {
+            ar & full_server_defs_as_string_;
+        }
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const DefsCmd&);
+
+#endif /* ecflow_base_cts_DefsCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/ErrorCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/ErrorCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/ErrorCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/ErrorCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/ErrorCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/Log.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+ErrorCmd::ErrorCmd(const std::string& errorMsg) {
+    init(errorMsg);
+}
+
+void ErrorCmd::init(const std::string& errorMsg) {
+    // #ifdef DEBUG
+    // std::cout << ErrorCmd::init " << errorMsg << "\n";
+    // LogToCout toCoutAsWell;
+    // #endif
+
+    LOG_ASSERT(!errorMsg.empty(), "");
+    error_msg_ = errorMsg;
+
+    // Log the error, Remove any "/n" as the log file will add this automatically
+    size_t pos = error_msg_.rfind("\n");
+    if (pos != string::npos)
+        error_msg_.erase(error_msg_.begin() + pos);
+    ecf::log(Log::ERR, error_msg_); // will automatically add end of line
+}
+
+std::string ErrorCmd::print() const {
+    std::string os;
+    os += "cmd:Error [ ";
+    os += error_msg_;
+    os += " ]";
+    return os;
+}
+
+bool ErrorCmd::equals(ServerToClientCmd* rhs) const {
+    return (dynamic_cast<ErrorCmd*>(rhs)) ? ServerToClientCmd::equals(rhs) : false;
+}
+
+bool ErrorCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        std::cout << "  ErrorCmd::handle_server_response " << error_msg_ << "\n";
+
+    std::string ss;
+    ss += "Error: request( ";
+    ss += cts_cmd->print_short();
+    ss += " ) failed!  Server reply: ";
+    ss += error_msg_;
+    ss += "\n";
+    server_reply.set_error_msg(server_reply.get_error_msg() + ss); // append in-case multiple errors from group cmd
+    return false;
+}
+
+std::ostream& operator<<(std::ostream& os, const ErrorCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/ErrorCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/ErrorCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/ErrorCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/ErrorCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_ErrorCmd_HPP
+#define ecflow_base_stc_ErrorCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+class ErrorCmd final : public ServerToClientCmd {
+public:
+    explicit ErrorCmd(const std::string& errorMsg);
+    ErrorCmd() : ServerToClientCmd() {}
+
+    void init(const std::string& errorMsg);
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
+
+    std::string error() const override { return error_msg_; }   /// Used by test
+    bool ok() const override { return false; }                  /// Used by group command
+    void cleanup() override { std::string().swap(error_msg_); } /// run in the server, after command send to client
+
+private:
+    std::string error_msg_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(error_msg_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ErrorCmd&);
+
+#endif /* ecflow_base_stc_ErrorCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,163 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/GroupSTCCmd.hpp"
+
+#include "ecflow/base/WhyCmd.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+std::string GroupSTCCmd::print() const {
+    return "cmd:GroupSTCCmd";
+}
+
+bool GroupSTCCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<GroupSTCCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+
+    const std::vector<STC_Cmd_ptr>& rhsCmdVec = the_rhs->cmdVec();
+    if (cmdVec_.size() != rhsCmdVec.size())
+        return false;
+
+    for (size_t i = 0; i < cmdVec_.size(); i++) {
+        if (!cmdVec_[i]->equals(rhsCmdVec[i].get())) {
+            return false;
+        }
+    }
+
+    return ServerToClientCmd::equals(rhs);
+}
+
+bool GroupSTCCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        std::cout << "  GroupSTCCmd::handle_server_response\n";
+
+    bool ret_flag = true;
+    for (STC_Cmd_ptr subCmd : cmdVec_) {
+        if (!subCmd->handle_server_response(server_reply, cts_cmd, debug))
+            ret_flag = false; // one of the commands failed
+    }
+    if (!server_reply.cli())
+        return ret_flag;
+
+    /// CLI called from the command line.
+    /// This assumes the DefsCmd::handle_server_response() | SNodeCmd::handle_server_response has been called
+    /// this will populate ServerReply with the defs/node returned from the server
+    defs_ptr defs = server_reply.client_defs();
+    node_ptr node = server_reply.client_node();
+
+    if (defs.get() || node.get()) {
+        if (debug)
+            std::cout << "   GroupSTCCmd::handle_server_response *get* | *sync* | *sync_full* called\n";
+
+        /// client --group="get; show"         # where get will call DefsCmd will return defs, from the server
+        /// client --group="get; show state"   # where get will call DefsCmd will return defs, from the server
+        /// client --group="get /s1; show state"   # where get will call DefsCmd will return defs, from the server
+        /// client --group="sync_full; show"       # similar to get return defs, from the server
+        /// client --group="sync 1 0 0; show"      # where sync will call SyncCmd will return defs, from the server
+        ///                                        # will return those suites with handle 1
+
+        // Print out the data that was received from server. as a part of get request.
+        // The server cannot do a show, it MUST be done at the Client side
+        // The show request is only valid if the out bound request to the server
+        PrintStyle::Type_t style = cts_cmd->show_style();
+        if (style != PrintStyle::NOTHING) {
+            if (debug)
+                std::cout << "   GroupSTCCmd::handle_server_response *show* was called " << PrintStyle::to_string(style)
+                          << "\n";
+            PrintStyle print_style(style);
+            if (defs.get()) {
+
+                /// Auto generate externs, before writing to standard out. This can be expensive since
+                /// All the trigger references need to to be resolved. & AST need to be created first
+                /// The old spirit based parsing is horrendously, slow. Can't use Spirit QI, till IBM support it
+                if (!PrintStyle::is_persist_style(cts_cmd->show_style())) {
+                    defs->auto_add_externs();
+                }
+
+                std::cout << *defs.get();
+            }
+            else {
+                if (node.get()) {
+                    Suite* suite = node->isSuite();
+                    if (suite)
+                        std::cout << *suite << "\n";
+                    Family* fam = node->isFamily();
+                    if (fam)
+                        std::cout << *fam << "\n";
+                    Task* task = node->isTask();
+                    if (task)
+                        std::cout << *task << "\n";
+                }
+            }
+        }
+    }
+
+    std::string nodePath;
+    if (cts_cmd->why_cmd(nodePath) && defs.get()) {
+        if (debug)
+            std::cout << "  GroupSTCCmd::handle_server_response *why* was called\n";
+
+        /// client --group="get; why"          # where get will call DefsCmd will return defs, from the server
+        /// client --group="get; why <path>"   # where get will call DefsCmd will return defs, from the server
+        WhyCmd cmd(defs, nodePath);
+        std::cout << cmd.why() << "\n";
+    }
+
+    return ret_flag;
+}
+
+void GroupSTCCmd::addChild(STC_Cmd_ptr childCmd) {
+    LOG_ASSERT(childCmd.get(), ""); // Dont add NULL children
+    cmdVec_.push_back(childCmd);
+}
+
+// these two must be opposite of each other
+bool GroupSTCCmd::ok() const {
+    for (const auto& i : cmdVec_) {
+        if (!i->ok())
+            return false; // if child is ErrorCmd will return false
+    }
+    return true;
+}
+
+void GroupSTCCmd::cleanup() {
+    /// After the command has run this function can be used to reclaim memory
+    for (auto& cmd : cmdVec_) {
+        cmd->cleanup();
+    }
+}
+
+std::string GroupSTCCmd::error() const {
+    std::string ret;
+    for (const auto& i : cmdVec_) {
+        std::string error_str = i->error();
+        if (!error_str.empty()) {
+            ret += error_str;
+            ret += "\n";
+        }
+    }
+    return ret;
+}
+
+std::ostream& operator<<(std::ostream& os, const GroupSTCCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/GroupSTCCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_GroupSTCCmd_HPP
+#define ecflow_base_stc_GroupSTCCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+class GroupSTCCmd final : public ServerToClientCmd {
+public:
+    GroupSTCCmd() : ServerToClientCmd() {}
+
+    void cleanup() override; /// After the command has run this function can be used to reclaim memory
+
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+
+    void addChild(STC_Cmd_ptr childCmd);
+    const std::vector<STC_Cmd_ptr>& cmdVec() const { return cmdVec_; }
+
+    // these two must be opposite of each other
+    bool ok() const override;
+    std::string error() const override;
+
+private:
+    std::vector<STC_Cmd_ptr> cmdVec_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(cmdVec_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const GroupSTCCmd&);
+
+#endif /* ecflow_base_stc_GroupSTCCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,200 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+
+#include "ecflow/base/stc/BlockClientZombieCmd.hpp"
+#include "ecflow/base/stc/DefsCmd.hpp"
+#include "ecflow/base/stc/ErrorCmd.hpp"
+#include "ecflow/base/stc/GroupSTCCmd.hpp"
+#include "ecflow/base/stc/SClientHandleCmd.hpp"
+#include "ecflow/base/stc/SClientHandleSuitesCmd.hpp"
+#include "ecflow/base/stc/SNewsCmd.hpp"
+#include "ecflow/base/stc/SNodeCmd.hpp"
+#include "ecflow/base/stc/SServerLoadCmd.hpp"
+#include "ecflow/base/stc/SStatsCmd.hpp"
+#include "ecflow/base/stc/SStringCmd.hpp"
+#include "ecflow/base/stc/SStringVecCmd.hpp"
+#include "ecflow/base/stc/SSuitesCmd.hpp"
+#include "ecflow/base/stc/SSyncCmd.hpp"
+#include "ecflow/base/stc/StcCmd.hpp"
+#include "ecflow/base/stc/ZombieGetCmd.hpp"
+
+STC_Cmd_ptr PreAllocatedReply::stc_cmd_                  = std::make_shared<StcCmd>();
+STC_Cmd_ptr PreAllocatedReply::defs_cmd_                 = std::make_shared<DefsCmd>();
+STC_Cmd_ptr PreAllocatedReply::node_cmd_                 = std::make_shared<SNodeCmd>();
+STC_Cmd_ptr PreAllocatedReply::stats_cmd_                = std::make_shared<SStatsCmd>();
+STC_Cmd_ptr PreAllocatedReply::suites_cmd_               = std::make_shared<SSuitesCmd>();
+STC_Cmd_ptr PreAllocatedReply::zombie_get_cmd_           = std::make_shared<ZombieGetCmd>();
+STC_Cmd_ptr PreAllocatedReply::error_cmd_                = std::make_shared<ErrorCmd>();
+STC_Cmd_ptr PreAllocatedReply::client_handle_cmd_        = std::make_shared<SClientHandleCmd>();
+STC_Cmd_ptr PreAllocatedReply::client_handle_suites_cmd_ = std::make_shared<SClientHandleSuitesCmd>();
+STC_Cmd_ptr PreAllocatedReply::string_cmd_               = std::make_shared<SStringCmd>();
+STC_Cmd_ptr PreAllocatedReply::string_vec_cmd_           = std::make_shared<SStringVecCmd>();
+STC_Cmd_ptr PreAllocatedReply::server_load_cmd_          = std::make_shared<SServerLoadCmd>();
+STC_Cmd_ptr PreAllocatedReply::news_cmd_                 = std::make_shared<SNewsCmd>();
+STC_Cmd_ptr PreAllocatedReply::sync_cmd_                 = std::make_shared<SSyncCmd>();
+STC_Cmd_ptr PreAllocatedReply::block_client_zombie_cmd_  = std::make_shared<BlockClientZombieCmd>();
+
+STC_Cmd_ptr PreAllocatedReply::ok_cmd() {
+    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
+    cmd->init(StcCmd::OK);
+    return stc_cmd_;
+}
+STC_Cmd_ptr PreAllocatedReply::block_client_server_halted_cmd() {
+    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
+    cmd->init(StcCmd::BLOCK_CLIENT_SERVER_HALTED);
+    return stc_cmd_;
+}
+STC_Cmd_ptr PreAllocatedReply::block_client_on_home_server_cmd() {
+    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
+    cmd->init(StcCmd::BLOCK_CLIENT_ON_HOME_SERVER);
+    return stc_cmd_;
+}
+STC_Cmd_ptr PreAllocatedReply::delete_all_cmd() {
+    auto* cmd = dynamic_cast<StcCmd*>(stc_cmd_.get());
+    cmd->init(StcCmd::DELETE_ALL);
+    return stc_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::block_client_zombie_cmd(ecf::Child::ZombieType zt) {
+    auto* cmd = dynamic_cast<BlockClientZombieCmd*>(block_client_zombie_cmd_.get());
+    cmd->init(zt);
+    return block_client_zombie_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::defs_cmd(AbstractServer* as, bool save_edit_history) {
+    auto* cmd = dynamic_cast<DefsCmd*>(defs_cmd_.get());
+    cmd->init(as, save_edit_history);
+    return defs_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::node_cmd(AbstractServer* as, node_ptr node) {
+    auto* cmd = dynamic_cast<SNodeCmd*>(node_cmd_.get());
+    cmd->init(as, node);
+    return node_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::stats_cmd(AbstractServer* as) {
+    auto* cmd = dynamic_cast<SStatsCmd*>(stats_cmd_.get());
+    cmd->init(as);
+    return stats_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::suites_cmd(AbstractServer* as) {
+    auto* cmd = dynamic_cast<SSuitesCmd*>(suites_cmd_.get());
+    cmd->init(as);
+    return suites_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::zombie_get_cmd(AbstractServer* as) {
+    auto* cmd = dynamic_cast<ZombieGetCmd*>(zombie_get_cmd_.get());
+    cmd->init(as);
+    return zombie_get_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::error_cmd(const std::string& error_msg) {
+    auto* cmd = dynamic_cast<ErrorCmd*>(error_cmd_.get());
+    cmd->init(error_msg);
+    return error_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::client_handle_cmd(int handle) {
+    auto* cmd = dynamic_cast<SClientHandleCmd*>(client_handle_cmd_.get());
+    cmd->init(handle);
+    return client_handle_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::client_handle_suites_cmd(AbstractServer* as) {
+    auto* cmd = dynamic_cast<SClientHandleSuitesCmd*>(client_handle_suites_cmd_.get());
+    cmd->init(as);
+    return client_handle_suites_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::string_cmd(const std::string& any_string) {
+    auto* cmd = dynamic_cast<SStringCmd*>(string_cmd_.get());
+    cmd->init(any_string);
+    return string_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::string_vec_cmd(const std::vector<std::string>& vec) {
+    auto* cmd = dynamic_cast<SStringVecCmd*>(string_vec_cmd_.get());
+    cmd->init(vec);
+    return string_vec_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::server_load_cmd(const std::string& log_file_path) {
+    auto* cmd = dynamic_cast<SServerLoadCmd*>(server_load_cmd_.get());
+    cmd->init(log_file_path);
+    return server_load_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::news_cmd(unsigned int client_handle,
+                                        unsigned int client_state_change_no,
+                                        unsigned int client_modify_change_no,
+                                        AbstractServer* as) {
+    auto* cmd = dynamic_cast<SNewsCmd*>(news_cmd_.get());
+    cmd->init(client_handle, client_state_change_no, client_modify_change_no, as);
+    return news_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::sync_cmd(unsigned int client_handle,
+                                        unsigned int client_state_change_no,
+                                        unsigned int client_modify_change_no,
+                                        AbstractServer* as) {
+    auto* cmd = dynamic_cast<SSyncCmd*>(sync_cmd_.get());
+    cmd->init(client_handle,
+              client_state_change_no,
+              client_modify_change_no,
+              false /*full sync*/,
+              false /*sync suite clock*/,
+              as);
+    return sync_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::sync_clock_cmd(unsigned int client_handle,
+                                              unsigned int client_state_change_no,
+                                              unsigned int client_modify_change_no,
+                                              AbstractServer* as) {
+    auto* cmd = dynamic_cast<SSyncCmd*>(sync_cmd_.get());
+    cmd->init(client_handle,
+              client_state_change_no,
+              client_modify_change_no,
+              false /*full sync*/,
+              true /*sync suite clock*/,
+              as);
+    return sync_cmd_;
+}
+
+STC_Cmd_ptr PreAllocatedReply::sync_full_cmd(unsigned int client_handle, AbstractServer* as) {
+    auto* cmd = dynamic_cast<SSyncCmd*>(sync_cmd_.get()); // can reuse the same command
+    cmd->init(client_handle, 0, 0, true /*full sync*/, false /*sync suite clock*/, as);
+    return sync_cmd_;
+}
+
+// ==============================================================================
+// Serialisation export
+
+CEREAL_REGISTER_TYPE(DefsCmd)
+CEREAL_REGISTER_TYPE(SNodeCmd)
+CEREAL_REGISTER_TYPE(SStringCmd)
+CEREAL_REGISTER_TYPE(SStringVecCmd)
+CEREAL_REGISTER_TYPE(SServerLoadCmd)
+CEREAL_REGISTER_TYPE(GroupSTCCmd)
+CEREAL_REGISTER_TYPE(ErrorCmd)
+CEREAL_REGISTER_TYPE(StcCmd)
+CEREAL_REGISTER_TYPE(SSyncCmd)
+CEREAL_REGISTER_TYPE(SNewsCmd)
+CEREAL_REGISTER_TYPE(SStatsCmd)
+CEREAL_REGISTER_TYPE(SSuitesCmd)
+CEREAL_REGISTER_TYPE(SClientHandleCmd)
+CEREAL_REGISTER_TYPE(SClientHandleSuitesCmd)
+CEREAL_REGISTER_TYPE(ZombieGetCmd)
+CEREAL_REGISTER_TYPE(BlockClientZombieCmd)
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/PreAllocatedReply.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,82 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_PreAllocatedReply_HPP
+#define ecflow_base_stc_PreAllocatedReply_HPP
+
+#include <string>
+
+#include "ecflow/base/Cmd.hpp"
+#include "ecflow/core/Child.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+class AbstractServer;
+
+// class PreAllocatedReply:
+// This class pre allocates the replies back to the client
+// This will help to reduce memory fragmentation.
+// Since the commands are re-used those commands with state,
+// should be cleared first
+class PreAllocatedReply {
+public:
+    PreAllocatedReply()                                    = delete;
+    PreAllocatedReply(const PreAllocatedReply&)            = delete;
+    PreAllocatedReply& operator=(const PreAllocatedReply&) = delete;
+
+    static STC_Cmd_ptr ok_cmd();
+    static STC_Cmd_ptr block_client_server_halted_cmd();
+    static STC_Cmd_ptr block_client_on_home_server_cmd();
+    static STC_Cmd_ptr block_client_zombie_cmd(ecf::Child::ZombieType zt);
+    static STC_Cmd_ptr delete_all_cmd();
+
+    static STC_Cmd_ptr defs_cmd(AbstractServer*, bool save_edit_history);
+    static STC_Cmd_ptr node_cmd(AbstractServer*, node_ptr);
+    static STC_Cmd_ptr stats_cmd(AbstractServer*);
+    static STC_Cmd_ptr suites_cmd(AbstractServer*);
+    static STC_Cmd_ptr zombie_get_cmd(AbstractServer*);
+    static STC_Cmd_ptr error_cmd(const std::string& error_msg);
+    static STC_Cmd_ptr client_handle_cmd(int handle);
+    static STC_Cmd_ptr client_handle_suites_cmd(AbstractServer*);
+    static STC_Cmd_ptr string_cmd(const std::string& any_string);
+    static STC_Cmd_ptr string_vec_cmd(const std::vector<std::string>&);
+    static STC_Cmd_ptr server_load_cmd(const std::string& any_string);
+    static STC_Cmd_ptr news_cmd(unsigned int client_handle,
+                                unsigned int client_state_change_no,
+                                unsigned int client_modify_change_no,
+                                AbstractServer* as);
+    static STC_Cmd_ptr sync_cmd(unsigned int client_handle,
+                                unsigned int client_state_change_no,
+                                unsigned int client_modify_change_no,
+                                AbstractServer* as);
+    static STC_Cmd_ptr sync_clock_cmd(unsigned int client_handle,
+                                      unsigned int client_state_change_no,
+                                      unsigned int client_modify_change_no,
+                                      AbstractServer* as);
+    static STC_Cmd_ptr sync_full_cmd(unsigned int client_handle, AbstractServer* as);
+
+private:
+    static STC_Cmd_ptr stc_cmd_;
+    static STC_Cmd_ptr defs_cmd_;
+    static STC_Cmd_ptr node_cmd_;
+    static STC_Cmd_ptr stats_cmd_;
+    static STC_Cmd_ptr suites_cmd_;
+    static STC_Cmd_ptr zombie_get_cmd_;
+    static STC_Cmd_ptr error_cmd_;
+    static STC_Cmd_ptr client_handle_cmd_;
+    static STC_Cmd_ptr client_handle_suites_cmd_;
+    static STC_Cmd_ptr string_cmd_;
+    static STC_Cmd_ptr string_vec_cmd_;
+    static STC_Cmd_ptr server_load_cmd_;
+    static STC_Cmd_ptr news_cmd_;
+    static STC_Cmd_ptr sync_cmd_;
+    static STC_Cmd_ptr block_client_zombie_cmd_;
+};
+
+#endif /* ecflow_base_stc_PreAllocatedReply_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SClientHandleCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/core/Converter.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool SClientHandleCmd::equals(ServerToClientCmd* rhs) const {
+    return (dynamic_cast<SClientHandleCmd*>(rhs)) ? ServerToClientCmd::equals(rhs) : false;
+}
+
+std::string SClientHandleCmd::print() const {
+    string os;
+    os += "cmd:SClientHandleCmd [ ";
+    os += ecf::convert_to<std::string>(handle_);
+    os += " ]";
+    return os;
+}
+
+bool SClientHandleCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        cout << "  SClientHandleCmd::handle_server_response handle_ = " << handle_ << "\n";
+    server_reply.set_client_handle(handle_);
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SClientHandleCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SClientHandleCmd_HPP
+#define ecflow_base_stc_SClientHandleCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+class SClientHandleCmd final : public ServerToClientCmd {
+public:
+    explicit SClientHandleCmd(int handle) : handle_(handle) {}
+    SClientHandleCmd() : ServerToClientCmd() {}
+
+    void init(int handle) { handle_ = handle; }
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
+
+private:
+    int handle_{0};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(handle_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SClientHandleCmd&);
+
+#endif /* ecflow_base_stc_SClientHandleCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,120 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SClientHandleSuitesCmd.hpp"
+
+#include <iomanip> // for setw
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/node/ClientSuiteMgr.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+SClientHandleSuitesCmd::SClientHandleSuitesCmd(AbstractServer* as) {
+    init(as);
+}
+
+void SClientHandleSuitesCmd::init(AbstractServer* as) {
+    // This command can be re-used hence clear existing data members
+    users_.clear();
+    client_handles_.clear();
+
+    ClientSuiteMgr& client_suite_mgr                   = as->defs()->client_suite_mgr();
+    const std::vector<ecf::ClientSuites>& clientSuites = client_suite_mgr.clientSuites();
+
+    size_t client_suites_size = clientSuites.size();
+    client_handles_.reserve(client_suites_size);
+    for (size_t c = 0; c < client_suites_size; c++) {
+
+        // The handle suites are already ordered same as Defs suites
+        std::vector<std::string> suite_names;
+        clientSuites[c].suites(suite_names);
+
+        client_handles_.emplace_back(clientSuites[c].handle(), suite_names);
+
+        // Create user, and his list of handles
+        bool fnd_user = false;
+        for (auto& user : users_) {
+            if (user.first == clientSuites[c].user()) {
+                user.second.push_back(clientSuites[c].handle());
+                fnd_user = true;
+                break;
+            }
+        }
+        if (!fnd_user) {
+            std::vector<unsigned int> handles;
+            handles.push_back(clientSuites[c].handle());
+            users_.emplace_back(clientSuites[c].user(), handles);
+        }
+    }
+}
+
+bool SClientHandleSuitesCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SClientHandleSuitesCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SClientHandleSuitesCmd::print() const {
+    return "cmd:SClientHandleSuitesCmd ";
+}
+
+bool SClientHandleSuitesCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        std::cout << "  SClientHandleSuitesCmd::handle_server_response\n";
+
+    if (server_reply.cli() && !cts_cmd->group_cmd()) {
+        /// This Could be part of a group command, hence ONLY if NOT group command
+
+        // print out:
+        // user  handle suites
+        // user1 1 s1 s2 s3
+        //       2 s1 s2
+        // user2 1 s1 s2 s3
+        //       2 s1 s2
+        for (size_t u = 0; u < users_.size(); u++) {
+            if (u == 0) {
+                cout << "\n";
+                cout << left << setw(10) << "User" << setw(6) << "handle"
+                     << "  suites\n";
+            }
+            cout << left << setw(10) << users_[u].first;
+            for (size_t h = 0; h < users_[u].second.size(); h++) {
+                unsigned int handle = users_[u].second[h];
+                for (const auto& client_handle : client_handles_) {
+                    if (handle == client_handle.first) {
+                        if (h != 0)
+                            cout << "          "; // 10 spaces to align handles
+                        cout << right << setw(6) << handle << "  ";
+                        const std::vector<std::string>& suites = client_handle.second;
+                        for (const auto& suite : suites) {
+                            cout << suite << "  ";
+                        }
+                        cout << "\n";
+                    }
+                }
+            }
+        }
+    }
+    else {
+        server_reply.set_client_handle_suites(client_handles_);
+    }
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SClientHandleSuitesCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SClientHandleSuitesCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SClientHandleSuitesCmd_HPP
+#define ecflow_base_stc_SClientHandleSuitesCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+class AbstractServer;
+
+//================================================================================
+class SClientHandleSuitesCmd final : public ServerToClientCmd {
+public:
+    explicit SClientHandleSuitesCmd(AbstractServer* as);
+    SClientHandleSuitesCmd() : ServerToClientCmd() {}
+
+    void init(AbstractServer* as);
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+
+private:
+    std::vector<std::pair<std::string, std::vector<unsigned int>>> users_;          // users , list of handles
+    std::vector<std::pair<unsigned int, std::vector<std::string>>> client_handles_; // handle, list of suites
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(users_), CEREAL_NVP(client_handles_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SClientHandleSuitesCmd&);
+
+#endif /* ecflow_base_stc_SClientHandleSuitesCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SNewsCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SNewsCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SNewsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SNewsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,250 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SNewsCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+
+/// Custom handling of command logging so that we can add additional debug.
+/// Rely's on CSyncCmd not adding newline when logging the command
+#define DEBUG_NEWS 1
+
+SNewsCmd::SNewsCmd(unsigned int client_handle,
+                   unsigned int client_state_change_no,
+                   unsigned int client_modify_change_no,
+                   AbstractServer* as) {
+    init(client_handle, client_state_change_no, client_modify_change_no, as);
+}
+
+/// Called in the server
+void SNewsCmd::init(unsigned int client_handle, // a reference to a set of suites used by client
+                    unsigned int client_state_change_no,
+                    unsigned int client_modify_change_no,
+                    AbstractServer* as) {
+    news_ = ServerReply::NO_NEWS;
+
+    // =====================================================================================
+    // The code to determine changes here must also relate to SSyncCmd
+    // ======================================================================================
+
+    if (client_handle == 0) {
+
+        // Here Ecf::modify_change_no() and  Ecf::state_change_no() represent the max change numbers over *all* the
+        // suites
+
+        /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
+        /// *** i.e the value should be less or equal to server. However if::
+        /// ***   o/ Server **dies** we can get the case, where client numbers are greater than server numbers.
+        /// ***   o/ Server changes number overflows, since it unsigned, and re-start's with 0
+        /// *** When no handle are involved, we can get by with a full sync
+        /// *** Note: whenever the server starts, the state and modify numbers start from zero
+        if ((client_modify_change_no > Ecf::modify_change_no()) || (client_state_change_no > Ecf::state_change_no())) {
+
+            news_ = ServerReply::DO_FULL_SYNC;
+
+#if DEBUG_NEWS
+            std::stringstream ss;
+            ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+               << ") : client no > server no ! :DO_FULL_SYNC]";
+            log_append(ss.str());
+#else
+            log_append("");
+#endif
+            return;
+        }
+
+        if (client_modify_change_no < Ecf::modify_change_no()) {
+
+            news_ = ServerReply::NEWS;
+
+#if DEBUG_NEWS
+            std::stringstream ss;
+            ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+               << ") : *Large* scale changes(" << (Ecf::modify_change_no() - client_modify_change_no) << ") :NEWS]";
+            log_append(ss.str());
+#else
+            log_append("");
+#endif
+            return;
+        }
+
+        if (client_state_change_no < Ecf::state_change_no()) {
+
+            news_ = ServerReply::NEWS;
+
+#if DEBUG_NEWS
+            std::stringstream ss;
+            ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+               << ") : *Small* scale changes(" << (Ecf::state_change_no() - client_state_change_no) << ") :NEWS]";
+            log_append(ss.str());
+#else
+            log_append("");
+#endif
+            return;
+        }
+
+#if DEBUG_NEWS
+        log_append(" [:NO_NEWS]");
+#else
+        log_append("");
+#endif
+        return;
+    }
+
+    // =============================================================================================
+    // Handle used: Determine the max modify and state change no, for suites in our handle
+    // =============================================================================================
+
+    /// *** If we can't find the handle, then it may be that the server died ?
+    /// *** It is up to the client to do a full sync *including* re-registering suites
+    ClientSuiteMgr& client_suite_mgr = as->defs()->client_suite_mgr();
+    if (!client_suite_mgr.valid_handle(client_handle)) {
+
+        news_ = ServerReply::DO_FULL_SYNC;
+
+#if DEBUG_NEWS
+        std::stringstream ss;
+        ss << " [server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no() << ") : Cannot find handle("
+           << client_handle << ") :DO_FULL_SYNC]";
+        log_append(ss.str());
+#else
+        log_append("");
+#endif
+
+        return;
+    }
+
+    /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
+    /// *** i.e the value should be less or equal to server. However if
+    /// ***   o/ Server **dies** we can get the case, where client numbers are greater than server numbers.
+    /// ***   o/ Server changes number overflows, since it unsigned, and re-start's with 0
+    /// *** we can get the case, where client numbers are greater than server numbers and also the
+    /// *** handle will not exist in the server,
+    /// *** It is up to the client to do a full sync *including* re-registering suites
+    /// *** Note: whenever the server starts, the state and modify numbers start from zero
+    unsigned int max_client_handle_modify_change_no = 0;
+    unsigned int max_client_handle_state_change_no  = 0;
+    client_suite_mgr.max_change_no(
+        client_handle, max_client_handle_state_change_no, max_client_handle_modify_change_no);
+
+    if ((client_modify_change_no > max_client_handle_modify_change_no) ||
+        (client_state_change_no > max_client_handle_state_change_no)) {
+
+        news_ = ServerReply::DO_FULL_SYNC;
+
+#if DEBUG_NEWS
+        std::stringstream ss;
+        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
+           << ")  server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+           << ") : client no > server no ! :DO_FULL_SYNC]";
+        log_append(ss.str());
+#else
+        log_append("");
+#endif
+
+        return;
+    }
+
+    /// Changes where user adds a new handle/auto adds/removes require a full update, but only for changed handle
+    if (client_suite_mgr.handle_changed(client_handle)) {
+
+        news_ = ServerReply::NEWS;
+
+#if DEBUG_NEWS
+        std::stringstream ss;
+        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
+           << ") server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+           << ") : *Large* scale changes (new handle or suites added or removed) :NEWS]";
+        log_append(ss.str());
+#else
+        log_append("");
+#endif
+
+        return;
+    }
+
+    // The client handle represents a subset of the suites.
+    if (client_modify_change_no < max_client_handle_modify_change_no) {
+
+        news_ = ServerReply::NEWS;
+
+#if DEBUG_NEWS
+        std::stringstream ss;
+        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
+           << ") server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+           << ") : *Large* scale changes :NEWS]";
+        log_append(ss.str());
+#else
+        log_append("");
+#endif
+
+        return;
+    }
+
+    // This should also reflect changes made just to the defs(state/suspended) and also the server state
+    if (client_state_change_no < max_client_handle_state_change_no) {
+
+        news_ = ServerReply::NEWS;
+
+#if DEBUG_NEWS
+        std::stringstream ss;
+        ss << " [server handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no
+           << ") server(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+           << ") : *Small* scale changes :NEWS]";
+        log_append(ss.str());
+#else
+        log_append("");
+#endif
+
+        return;
+    }
+
+#if DEBUG_NEWS
+    log_append(" [:NO_NEWS]");
+#else
+    log_append("");
+#endif
+}
+
+/// Called in the client
+bool SNewsCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr /*cts_cmd*/, bool debug) const {
+    if (debug)
+        std::cout << "  SNewsCmd::handle_server_response news_ = " << news_ << "\n";
+    server_reply.set_news(news_);
+    return true;
+}
+
+bool SNewsCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SNewsCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (news_ != the_rhs->news())
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SNewsCmd::print() const {
+    std::stringstream ss;
+    ss << "cmd:SNewsCmd [ " << news_ << " ] ";
+    return ss.str();
+}
+
+std::ostream& operator<<(std::ostream& os, const SNewsCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SNewsCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SNewsCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SNewsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SNewsCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,62 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SNewsCmd_HPP
+#define ecflow_base_stc_SNewsCmd_HPP
+
+///
+/// \brief class SNewsCmd is used to determine any change in the server
+///
+/// The *client_state_change_no* was passed from the client to the server
+/// The *client_modify_change_no* was passed from the client to the server
+///
+/// The code here needs to coordinate with SSyncCmd
+///
+/// Paired with CtsCmd(NEWS)
+/// Client---CtsCmd(NEWS)---->Server-----(SNewsCmd)--->client:
+///
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+class AbstractServer;
+
+class SNewsCmd final : public ServerToClientCmd {
+public:
+    // The constructor is *called* in the server.
+    SNewsCmd(unsigned int client_handle, // a reference to a set of suites used by client
+             unsigned int client_state_change_no,
+             unsigned int client_modify_change_no,
+             AbstractServer* as);
+    SNewsCmd() : ServerToClientCmd() {}
+
+    void init(unsigned int client_handle, // a reference to a set of suites used by client
+              unsigned int client_state_change_no,
+              unsigned int client_modify_change_no,
+              AbstractServer* as);
+
+    ServerReply::News_t news() const { return news_; } // used by equals only
+    bool get_news() const { return (news_ != ServerReply::NO_NEWS); }
+
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+
+private:
+    ServerReply::News_t news_{ServerReply::NO_NEWS};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(news_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SNewsCmd&);
+
+#endif /* ecflow_base_stc_SNewsCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SNodeCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SNodeCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,117 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SNodeCmd.hpp"
+
+#include <iostream>
+#include <stdexcept>
+
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace boost;
+
+//=====================================================================================
+// This command returns the requested node back to the client
+// Note: In the case where defs has not been loaded, it can be NULL
+
+SNodeCmd::SNodeCmd(AbstractServer* as, node_ptr node) {
+    init(as, node);
+}
+
+void SNodeCmd::init(AbstractServer* as, node_ptr node) {
+    the_node_str_.clear();
+    if (node.get()) {
+        the_node_str_ = node->print(PrintStyle::NET);
+    }
+}
+
+node_ptr SNodeCmd::get_node_ptr(std::string& error_msg) const {
+    return Node::create(the_node_str_, error_msg);
+}
+
+bool SNodeCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SNodeCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (!ServerToClientCmd::equals(rhs))
+        return false;
+    return true;
+}
+
+std::string SNodeCmd::print() const {
+    std::string os;
+    os += "cmd:SNodeCmd [ ";
+    std::string error_msg;
+    node_ptr node = get_node_ptr(error_msg);
+    if (node.get())
+        os += node->absNodePath();
+    else
+        os += "node == NULL";
+    os += " ]";
+    return os;
+}
+
+// Called in client
+bool SNodeCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        std::cout << "  SNodeCmd::handle_server_response\n";
+
+    std::string error_msg;
+    node_ptr node = get_node_ptr(error_msg);
+    if (!node.get()) {
+        std::string ss;
+        ss += "SNodeCmd::handle_server_response: Error Node could not be retrieved from server. Request ";
+        ss += cts_cmd->print_short();
+        ss += " failed.\n";
+        ss += error_msg;
+        throw std::runtime_error(ss);
+    }
+
+    if (server_reply.cli() && !cts_cmd->group_cmd()) {
+        /// This Could be part of a group command, hence ONLY show Node if NOT group command
+        PrintStyle style(cts_cmd->show_style());
+
+        Suite* suite = node->isSuite();
+        if (suite) {
+            if (!PrintStyle::is_persist_style(cts_cmd->show_style())) {
+                /// Auto generate externs, before writing to standard out. This can be expensive since
+                /// All the trigger references need to to be resolved. & AST need to be created first
+                /// The old spirit based parsing, horrendously, slow. Can't use Spirit QI, till IBM pull support it
+                ///
+                /// We need a fabricate a defs to show the externs, used by the suite
+                Defs defs;
+                defs.addSuite(std::dynamic_pointer_cast<Suite>(node));
+                defs.auto_add_externs();
+                std::cout << defs.print(cts_cmd->show_style());
+                return true;
+            }
+
+            // with defs_state MIGRATE on --load we will recover the state.
+            if (PrintStyle::is_persist_style(cts_cmd->show_style()))
+                std::cout << "defs_state " << PrintStyle::to_string(cts_cmd->show_style()) << "\n"; // see ECFLOW-1233
+            std::cout << *suite << "\n";
+            return true;
+        }
+        cout << node->print() << "\n";
+    }
+    else {
+        server_reply.set_client_node(node);
+    }
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SNodeCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SNodeCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SNodeCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SNodeCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SNodeCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SNodeCmd_HPP
+#define ecflow_base_stc_SNodeCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+class AbstractServer;
+
+//================================================================================
+// Paired with CtsNodeCmd(Get)
+// Client---CtsNodeCmd(GET)---->Server-----(SNodeCmd | SNodeCmd)--->client:
+//================================================================================
+class SNodeCmd final : public ServerToClientCmd {
+public:
+    SNodeCmd(AbstractServer* as, node_ptr node);
+    SNodeCmd() = default;
+
+    void init(AbstractServer* as, node_ptr node);
+
+    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    void cleanup() override { std::string().swap(the_node_str_); } /// run in the server, after command send to client
+
+private:
+    node_ptr get_node_ptr(std::string& error_msg) const;
+    std::string the_node_str_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(the_node_str_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SNodeCmd&);
+
+#endif /* ecflow_base_stc_SNodeCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SServerLoadCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/Gnuplot.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+bool SServerLoadCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SServerLoadCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (log_file_path_ != the_rhs->log_file_path())
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SServerLoadCmd::print() const {
+    std::string os;
+    os += "cmd:SServerLoadCmd [ ";
+    os += log_file_path_;
+    os += " ]";
+    return os;
+}
+
+bool SServerLoadCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        cout << "  SServerLoadCmd::handle_server_response log_file_path = " << log_file_path() << "\n";
+    Gnuplot gnuplot(log_file_path(), server_reply.host(), server_reply.port());
+    gnuplot.show_server_load();
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SServerLoadCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SServerLoadCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,44 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SServerLoadCmd_HPP
+#define ecflow_base_stc_SServerLoadCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+///================================================================================
+/// Paired with CtsCmd::SERVER_LOAD
+/// Client---(CtsCmd::SERVER_LOAD)---->Server-----(SServerLoadCmd)--->client:
+///================================================================================
+class SServerLoadCmd final : public ServerToClientCmd {
+public:
+    explicit SServerLoadCmd(const std::string& log_file_path) : log_file_path_(log_file_path) {}
+    SServerLoadCmd() : ServerToClientCmd() {}
+
+    void init(const std::string& s) { log_file_path_ = s; }
+    const std::string& log_file_path() const { return log_file_path_; }
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+    void cleanup() override { std::string().swap(log_file_path_); } /// run in the server, after command send to client
+
+private:
+    std::string log_file_path_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(log_file_path_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SServerLoadCmd&);
+
+#endif /* ecflow_base_stc_SServerLoadCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SStatsCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SStatsCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SStatsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SStatsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SStatsCmd.hpp"
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+SStatsCmd::SStatsCmd(AbstractServer* as) {
+    init(as);
+}
+
+void SStatsCmd::init(AbstractServer* as) {
+    as->stats().update_for_serialisation();
+    stats_               = as->stats();
+    stats_.no_of_suites_ = as->defs()->suiteVec().size();
+}
+
+bool SStatsCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SStatsCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SStatsCmd::print() const {
+    return "cmd:SStatsCmd ";
+}
+
+bool SStatsCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr /*cts_cmd*/, bool debug) const {
+    if (debug)
+        std::cout << "  SStatsCmd::handle_server_response\n";
+    if (server_reply.cli())
+        stats_.show();
+    else {
+        server_reply.set_stats(stats_);
+    }
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SStatsCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SStatsCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SStatsCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SStatsCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SStatsCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SStatsCmd_HPP
+#define ecflow_base_stc_SStatsCmd_HPP
+
+#include "ecflow/base/Stats.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+class AbstractServer;
+
+//================================================================================
+// Paired with CtsCmd(SERVER_STATS)
+// Client---(CtsCmd(SERVER_STATS))---->Server-----(SStatsCmd)--->client:
+// ****** Used in Test ONLY, since Stats is subject to change for each release
+// ****** see ECFLOW-880, we use CtsCmd(STATS) to return server stats as a string
+// ****** this allows the format to change in the server(with out affecting protocol)
+//================================================================================
+class SStatsCmd final : public ServerToClientCmd {
+public:
+    explicit SStatsCmd(AbstractServer* as);
+    SStatsCmd() : ServerToClientCmd() {}
+
+    void init(AbstractServer* as);
+
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+
+private:
+    Stats stats_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(stats_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SStatsCmd&);
+
+#endif /* ecflow_base_stc_SStatsCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SStringCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SStringCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SStringCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SStringCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SStringCmd.hpp"
+
+#include <iostream>
+
+using namespace std;
+using namespace boost;
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+bool SStringCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SStringCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (str_ != the_rhs->get_string())
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SStringCmd::print() const {
+    return "cmd:SStringCmd ";
+}
+
+bool SStringCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        cout << "  SStringCmd::handle_server_response str.size()= " << str_.size() << "\n";
+    if (server_reply.cli())
+        // The following uses std::endl to ensure the output is flushed.
+        // This is necessary when called from the Python API, otherwise the output cannot be captured systematically.
+        std::cout << str_ << std::endl;
+    else
+        server_reply.set_string(str_);
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SStringCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SStringCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SStringCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SStringCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SStringCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,50 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SStringCmd_HPP
+#define ecflow_base_stc_SStringCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+///================================================================================
+/// Paired with CFileCmd
+/// Client---(CFileCmd)---->Server-----(SStringCmd)--->client:
+/// Only valid when the clients request a CFileCmd *OR* Log file
+/// Other times this will be empty.
+/// CFileCmd:: The file Contents(script,job,jobout,manual)
+///     Can be potentially very large
+/// LogCmd: The log file Can be potentially very large
+///     Only really valid if the out bound request was a LogCmd(LogCmd::GET)
+///================================================================================
+class SStringCmd final : public ServerToClientCmd {
+public:
+    explicit SStringCmd(const std::string& s) : str_(s) {}
+    SStringCmd() : ServerToClientCmd() {}
+
+    void init(const std::string& s) { str_ = s; }
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    const std::string& get_string() const override { return str_; }
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+    void cleanup() override { std::string().swap(str_); } /// run in the server, after command send to client
+
+private:
+    std::string str_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(str_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SStringCmd&);
+
+#endif /* ecflow_base_stc_SStringCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SStringVecCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SStringVecCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SStringVecCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SStringVecCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SStringVecCmd.hpp"
+
+#include <iostream>
+
+using namespace std;
+using namespace boost;
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+bool SStringVecCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SStringVecCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (vec_ != the_rhs->get_string_vec())
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SStringVecCmd::print() const {
+    return "cmd:SStringVecCmd ";
+}
+
+bool SStringVecCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        cout << "  SStringVecCmd::handle_server_response str.size()= " << vec_.size() << "\n";
+    if (server_reply.cli()) {
+        for (const auto& i : vec_) {
+            std::cout << i << "\n";
+        }
+    }
+    else
+        server_reply.set_string_vec(vec_);
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SStringVecCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SStringVecCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SStringVecCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SStringVecCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SStringVecCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,44 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SStringVecCmd_HPP
+#define ecflow_base_stc_SStringVecCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+///================================================================================
+class SStringVecCmd final : public ServerToClientCmd {
+public:
+    explicit SStringVecCmd(const std::vector<std::string>& s) : vec_(s) {}
+    SStringVecCmd() : ServerToClientCmd() {}
+
+    void init(const std::vector<std::string>& s) { vec_ = s; }
+    const std::vector<std::string>& get_string_vec() const { return vec_; }
+
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+    void cleanup() override {
+        std::vector<std::string>().swap(vec_);
+    } /// run in the server, after command send to client
+
+private:
+    std::vector<std::string> vec_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(vec_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SStringVecCmd&);
+
+#endif /* ecflow_base_stc_SStringVecCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SSuitesCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SSuitesCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SSuitesCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SSuitesCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SSuitesCmd.hpp"
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+
+//////////////////////////////////////////////////////////////////////////////////////////////////
+
+SSuitesCmd::SSuitesCmd(AbstractServer* as) {
+    init(as);
+}
+
+void SSuitesCmd::init(AbstractServer* as) {
+    // This command can be re-used hence clear existing data members
+    suites_.clear();
+
+    const std::vector<suite_ptr>& suiteVec = as->defs()->suiteVec();
+    size_t suite_vec_size                  = suiteVec.size();
+    suites_.reserve(suite_vec_size);
+    for (size_t i = 0; i < suite_vec_size; i++) {
+        suites_.push_back(suiteVec[i]->name());
+    }
+}
+
+bool SSuitesCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SSuitesCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SSuitesCmd::print() const {
+    return "cmd:SSuitesCmd ";
+}
+
+bool SSuitesCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug)
+        std::cout << "  SSuitesCmd::handle_server_response\n";
+
+    if (server_reply.cli() && !cts_cmd->group_cmd()) {
+        /// This Could be part of a group command, hence ONLY if NOT group command
+        if (suites_.empty()) {
+            cout << "No suites\n";
+        }
+
+        size_t max_suite_name_size = 0;
+        size_t the_size            = suites_.size();
+        for (size_t i = 0; i < the_size; i++) {
+            max_suite_name_size = std::max(max_suite_name_size, suites_[i].size());
+        }
+        max_suite_name_size += 1;
+
+        int newline_at = 4;
+        for (size_t i = 0; i < the_size; i++) {
+            cout << left << setw(max_suite_name_size) << suites_[i];
+            if (i != 0 && (i % newline_at) == 0) {
+                cout << "\n";
+                newline_at += 5;
+            }
+        }
+        cout << "\n";
+    }
+    else {
+        server_reply.set_string_vec(suites_);
+    }
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const SSuitesCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SSuitesCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SSuitesCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SSuitesCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SSuitesCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SSuitesCmd_HPP
+#define ecflow_base_stc_SSuitesCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+class AbstractServer;
+
+//================================================================================
+// Paired with CtsCmd(SUITES)
+// Client---(CtsCmd(SUITES))---->Server-----(SSuitesCmd)--->client:
+//================================================================================
+class SSuitesCmd final : public ServerToClientCmd {
+public:
+    explicit SSuitesCmd(AbstractServer* as);
+    SSuitesCmd() : ServerToClientCmd() {}
+
+    void init(AbstractServer* as);
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+    void cleanup() override {
+        std::vector<std::string>().swap(suites_);
+    } /// run in the server, after command send to client
+
+private:
+    std::vector<std::string> suites_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(suites_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SSuitesCmd&);
+
+#endif /* ecflow_base_stc_SSuitesCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SSyncCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/SSyncCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SSyncCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SSyncCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,363 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/SSyncCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+// =====================================================================================================
+// #define DEBUG_SERVER_SYNC 1  # Also update DefsCache::DEBUG_SERVER_SYNC
+// #define DEBUG_CLIENT_SYNC 1  # Also update DefsCache::DEBUG_CLIENT_SYNC
+
+SSyncCmd::SSyncCmd(unsigned int client_handle,
+                   unsigned int client_state_change_no,
+                   unsigned int client_modify_change_no,
+                   AbstractServer* as)
+    : incremental_changes_(client_state_change_no) {
+    init(client_handle, client_state_change_no, client_modify_change_no, false, false, as);
+}
+
+void SSyncCmd::reset_data_members(unsigned int client_state_change_no, bool sync_suite_clock) {
+    full_defs_ = false;
+    incremental_changes_.init(client_state_change_no,
+                              sync_suite_clock); // persisted, used for returning INCREMENTAL changes
+    server_defs_.clear();                        // persisted, used for returning FULL definition
+    full_server_defs_as_string_.clear(); // semi-persisted, i.e on load & not on saving used to return cached defs
+}
+
+void SSyncCmd::init(unsigned int client_handle, // a reference to a set of suites used by client
+                    unsigned int client_state_change_no,
+                    unsigned int client_modify_change_no,
+                    bool do_full_sync,
+                    bool sync_suite_clock,
+                    AbstractServer* as) {
+    // ********************************************************
+    // This is called in the server
+    // ********************************************************
+#ifdef DEBUG_SERVER_SYNC
+    cout << "SSyncCmd::init: client(" << client_state_change_no << "," << client_modify_change_no << ") server("
+         << Ecf::state_change_no() << "," << Ecf::modify_change_no() << ") sync_suite_clock(" << sync_suite_clock
+         << ")";
+#endif
+
+    // Reset all data members since this command can be re-used
+    reset_data_members(client_state_change_no, sync_suite_clock);
+
+    // explicit request
+    if (do_full_sync) {
+#ifdef DEBUG_SERVER_SYNC
+        cout << ": *Flag do_full_sync set* ";
+#endif
+        full_sync(client_handle, as);
+        return;
+    }
+
+    if (client_handle == 0) {
+#ifdef DEBUG_SERVER_SYNC
+        cout << ": No *handle* ";
+#endif
+
+        /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
+        /// *** i.e the value should be less or equal to server. However if the server **dies** we can
+        /// *** get the case, where client numbers are greater than server numbers.
+        /// *** When no handle are involved, we get by with a full sync
+        /// *** Note: whenever the server starts, the state and modify numbers start from zero
+        if (client_modify_change_no > Ecf::modify_change_no() || client_state_change_no > Ecf::state_change_no()) {
+#ifdef DEBUG_SERVER_SYNC
+            cout << ": client modify no > server modify no: Server died/restored? ";
+#endif
+            full_sync(client_handle, as);
+            return;
+        }
+
+        if (client_modify_change_no < Ecf::modify_change_no()) {
+#ifdef DEBUG_SERVER_SYNC
+            cout << ": *Large* scale changes: modify numbers not in sync ";
+#endif
+            full_sync(client_handle, as);
+            return;
+        }
+
+        //      // small scale changes.
+        //      // When we going to get thousand of memento, quicker to do a full sync
+        //      if (Ecf::state_change_no()-client_state_change_no > 200000) {
+        //         full_sync(client_handle,as);
+        //         return;
+        //      }
+
+        // small scale changes. Collate changes over *defs* and all suites.
+        // Suite stores the maximum state change, over *all* its children, this is used by client handle mechanism
+        // and here to avoid traversing down the hierarchy.
+        // ******** We must trap all child changes under the suite. See class SuiteChanged
+        // ******** otherwise some attribute sync's will be missed
+        as->defs()->collateChanges(client_handle, incremental_changes_);
+        incremental_changes_.set_server_state_change_no(Ecf::state_change_no());
+        incremental_changes_.set_server_modify_change_no(Ecf::modify_change_no());
+#ifdef DEBUG_SERVER_SYNC
+        if (incremental_changes_.size())
+            cout << ":*small* scale changes: no of changes(" << incremental_changes_.size() << ")\n";
+        else
+            cout << ": *No changes*\n";
+#endif
+        //      LOG(Log::DBG,"SSyncCmd::init incremental_changes_.size() " << incremental_changes_.size() << "
+        //      Ecf::state_change_no()-client_state_change_no " << Ecf::state_change_no()-client_state_change_no );
+        return;
+    }
+
+    //==========================================================================================
+    // Handle used
+    //==========================================================================================
+    ClientSuiteMgr& client_suite_mgr = as->defs()->client_suite_mgr();
+#ifdef DEBUG_SERVER_SYNC
+    cout << ": *handle* used " << client_handle << " : ";
+    std::vector<string> suites;
+    client_suite_mgr.suites(client_handle, suites);
+    for (const std::string& name : suites) {
+        std::cout << name << " ";
+    }
+#endif
+
+    /// *** The client_modify_change_no and client_state_change_no should always be trailing the server
+    /// *** i.e the value should be less or equal to server. However if the server **dies** we can
+    /// *** get the case, where client numbers are greater than server numbers. In this case we do a full sync
+    /// *** It is up to the client to catch the exception. and do a full sync *including* re-registering suites
+    /// *** Note: whenever the server starts, the state and modify numbers start from zero
+    unsigned int max_client_handle_modify_change_no = 0;
+    unsigned int max_client_handle_state_change_no  = 0;
+    client_suite_mgr.max_change_no(
+        client_handle, max_client_handle_state_change_no, max_client_handle_modify_change_no);
+#ifdef DEBUG_SERVER_SYNC
+    cout << ": server_handle(" << max_client_handle_state_change_no << "," << max_client_handle_modify_change_no << ")";
+#endif
+
+    if (client_modify_change_no > max_client_handle_modify_change_no ||
+        client_state_change_no > max_client_handle_state_change_no) {
+#ifdef DEBUG_SERVER_SYNC
+        cout << ": client no > server no: Server died/restored?";
+#endif
+        full_sync(client_handle, as);
+        return;
+    }
+
+    if (client_modify_change_no < max_client_handle_modify_change_no) {
+#ifdef DEBUG_SERVER_SYNC
+        cout << ": *Large* scale changes : modify numbers not in sync";
+#endif
+        full_sync(client_handle, as);
+        return;
+    }
+
+    if (client_suite_mgr.handle_changed(client_handle)) {
+        // *Large* scale handle changes, i.e. created handle/ added or removed suites
+#ifdef DEBUG_SERVER_SYNC
+        cout << ": *Large* scale changes: added/removed suites to handle";
+#endif
+        full_sync(client_handle, as);
+        return;
+    }
+
+    // small scale changes
+    as->defs()->collateChanges(client_handle, incremental_changes_);
+    incremental_changes_.set_server_state_change_no(max_client_handle_state_change_no);
+    incremental_changes_.set_server_modify_change_no(max_client_handle_modify_change_no);
+#ifdef DEBUG_SERVER_SYNC
+    if (incremental_changes_.size())
+        cout << ": *small* scale changes: no of changes(" << incremental_changes_.size() << ")\n";
+    else
+        cout << ": *No changes*\n";
+#endif
+}
+
+void SSyncCmd::full_sync(unsigned int client_handle, AbstractServer* as) {
+    Defs* server_defs = as->defs().get();
+
+    if (0 == client_handle) {
+        // Have already checked for no defs.
+        server_defs->set_state_change_no(Ecf::state_change_no());
+        server_defs->set_modify_change_no(Ecf::modify_change_no());
+
+        DefsCache::update_cache_if_state_changed(server_defs);
+        full_defs_ = true;
+#ifdef DEBUG_SERVER_SYNC
+        cout << ": *no handle* returning FULL defs(*cached* string, size("
+             << DefsCache::full_server_defs_as_string_.size() << "))" << endl;
+#endif
+        return;
+    }
+
+#ifdef DEBUG_SERVER_SYNC
+    cout << ": returning handle based FULL defs";
+#endif
+    // Only return the defs state and suites that the client has registered in the client handle
+    // *HOWEVER* if the client has registered *ALL* the suites, just return the server defs
+    //           *with* the updated change numbers
+    //
+    // *OTHERWISE* this compute the **maximum** state and modify change numbers over
+    // the suites managed by the client handle and then set it on the newly created defs file.
+    // **** It also takes special precaution *NOT* to change Ecf::state_change_no() and Ecf::modify_change_no()
+    // **** so that we avoid changing max modify no for suites not in our handle
+    // **** Will clear the handle_changed flag
+    //
+    // **** Although we create a new defs, we use the same suites. This presents
+    // **** a problem with the suites defs() pointer. To avoid corrupting the server defs
+    // **** we set the suite defs ptr to the the real server defs.
+    // **** --> The defs serialisation will setup the suite defs pointers. <---
+    // **** An alternative would be to clone the entire suites, since this can have
+    // **** hundreds of tasks. It would be very expensive.
+    // **** This means that server_defs_ will fail invarint_checking before serialisation
+    defs_ptr the_server_defs = server_defs->client_suite_mgr().create_defs(client_handle, as->defs());
+    if (the_server_defs.get() == server_defs) {
+        DefsCache::update_cache_if_state_changed(server_defs);
+        full_defs_ = true;
+#ifdef DEBUG_SERVER_SYNC
+        cout << ": The handle has *ALL* the suites: return the FULL defs(*cached* string, size("
+             << DefsCache::full_server_defs_as_string_.size() << "))";
+#endif
+    }
+    else {
+        the_server_defs->save_as_string(server_defs_, PrintStyle::NET);
+    }
+
+#ifdef DEBUG_SERVER_SYNC
+    if (the_server_defs)
+        cout << ": no of suites(" << the_server_defs->suiteVec().size() << ")" << endl;
+    else
+        cout << ": NULL defs!" << endl;
+#endif
+}
+
+void SSyncCmd::cleanup() {
+    /// run in the server, after command sent to client
+    incremental_changes_.cleanup();
+    std::string().swap(server_defs_);
+    std::string().swap(full_server_defs_as_string_); // will typically be empty in server
+}
+
+bool SSyncCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<SSyncCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string SSyncCmd::print() const {
+    return "cmd:SSyncCmd";
+}
+
+bool SSyncCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr /*cts_cmd*/, bool debug) const {
+    // Update server_reply.client_defs_, with the changes returned from the server
+    do_sync(server_reply, debug);
+
+    return true;
+}
+
+bool SSyncCmd::do_sync(ServerReply& server_reply, bool debug) const {
+    // ****************************************************
+    // On the client side
+    // ****************************************************
+    if (!server_defs_.empty()) {
+        // *FULL* sync
+        // to keep pace with the state changes. Passed back later on, get further changes
+        // If non zero handle will contain suites specified in the client handle, including their max change numbers
+        defs_ptr server_defs = Defs::create();
+        server_defs->restore_from_string(server_defs_); // this can throw
+
+        server_reply.client_defs_ = server_defs;
+        server_reply.set_sync(true);
+        server_reply.set_full_sync(true);
+        if (debug)
+            cout << "  SSyncCmd::do_sync::*FULL sync*, client side state/modify numbers("
+                 << server_defs->state_change_no() << "," << server_defs->modify_change_no() << ")\n";
+#ifdef DEBUG_CLIENT_SYNC
+        cout << "SSyncCmd::do_sync: defs *FULL sync*, client side state/modify numbers("
+             << server_defs->state_change_no() << "," << server_defs->modify_change_no() << ")\n";
+#endif
+        return true;
+    }
+
+    if (full_defs_) {
+        if (full_server_defs_as_string_.empty()) {
+            // TEST path.(i.e no client server): re-use static string
+#ifdef DEBUG_CLIENT_SYNC
+            cout << "SSyncCmd::do_sync: TEST PATH: *FULL CACHE sync* : using static cache";
+#endif
+            server_reply.client_defs_ = DefsCache::restore_defs_from_string();
+        }
+        else {
+#ifdef DEBUG_CLIENT_SYNC
+            cout << "SSyncCmd::do_sync: *FULL CACHE sync* : using cache returned from server: cache_size("
+                 << full_server_defs_as_string_.size() << ")";
+#endif
+            server_reply.client_defs_ = DefsCache::restore_defs_from_string(full_server_defs_as_string_);
+        }
+        server_reply.set_sync(true);
+        server_reply.set_full_sync(true);
+        if (debug)
+            cout << "  SSyncCmd::do_sync::*FULL CACHE sync*, client side state/modify numbers("
+                 << server_reply.client_defs_->state_change_no() << "," << server_reply.client_defs_->modify_change_no()
+                 << ")\n";
+#ifdef DEBUG_CLIENT_SYNC
+        cout << ": client side state/modify numbers(" << server_reply.client_defs_->state_change_no() << ","
+             << server_reply.client_defs_->modify_change_no() << ")\n";
+#endif
+        return true;
+    }
+
+    // Can only sync, *if* we have definition on the client side
+    if (server_reply.client_defs_.get()) {
+        // *INCREMENTAL* sync
+
+        if (server_reply.client_defs_->in_notification()) {
+            // For debug: place a break point here: It appear as Change manager observers, has called another client to
+            // server command
+            std::cout << "SSyncCmd::do_sync ERROR!!!!! called in the middle of notification(server->client sync)\n";
+            std::cout << "It appears that change observer have called *ANOTHER* client->server command in the middle "
+                         "synchronising client definition\n";
+        }
+        /// - Sets notification flag, so that observers can also query if they are in the middle of notification.
+        ChangeStartNotification start_notification(server_reply.client_defs_);
+
+        // Apply mementos to the client side defs, to bring in sync with server defs
+        // If *no* server loaded, then no changes applied
+        // Returns true if are any memento's, i.e. server changed.
+        server_reply.set_full_sync(false);
+        bool changes_made_to_client = incremental_changes_.incremental_sync(
+            server_reply.client_defs_, server_reply.changed_nodes(), server_reply.client_handle());
+        server_reply.set_sync(changes_made_to_client);
+
+        if (debug)
+            cout << "  SSyncCmd::do_sync::*INCREMENTAL sync*, client side state/modify numbers("
+                 << incremental_changes_.get_server_state_change_no() << ","
+                 << incremental_changes_.get_server_modify_change_no() << ") changes_made_to_client("
+                 << changes_made_to_client << ")\n";
+
+#ifdef DEBUG_CLIENT_SYNC
+        cout << "SSyncCmd::do_sync::*INCREMENTAL sync*, client side state/modify numbers("
+             << incremental_changes_.get_server_state_change_no() << ","
+             << incremental_changes_.get_server_modify_change_no() << ") changes_made_to_client("
+             << changes_made_to_client << "), changed_node_paths(" << server_reply.changed_nodes().size() << ")\n";
+#endif
+        return changes_made_to_client;
+    }
+    return false;
+}
+
+std::ostream& operator<<(std::ostream& os, const SSyncCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/SSyncCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/SSyncCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/SSyncCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/SSyncCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,110 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_SSyncCmd_HPP
+#define ecflow_base_stc_SSyncCmd_HPP
+
+#include "ecflow/base/stc/DefsCache.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/node/DefsDelta.hpp"
+
+class AbstractServer;
+
+///
+/// \brief the class SSyncCmd is used to transfer changes made in the server to the client.
+///  The client can then apply the changes to the client side defs.
+///
+/// *** This class should be used in conjunction with the news command.
+/// *** i.e The news command is used to test for server changes. This command
+/// *** will then get those changes and merge them with client side defs, bringing
+/// *** client and server defs in sync.
+///
+/// The *client_state_change_no* was passed from the client to the server
+/// The *client_modify_change_no* was passed from the client to the server
+///
+/// This class make use of DefsCache as a performance optimisation.
+///
+
+class SSyncCmd final : public ServerToClientCmd {
+public:
+    // The constructor is *called* in the server.
+    // This will collate the incremental changes made so far relative to the client_state_change_no.
+    // For large scale change we use client_modify_change_no this will require a full update
+    SSyncCmd(unsigned int client_handle, // a reference to a set of suites used by client
+             unsigned int client_state_change_no,
+             unsigned int client_modify_change_no,
+             AbstractServer* as);
+
+    SSyncCmd() : ServerToClientCmd(), incremental_changes_(0) {}
+
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+
+    // Client side functions:
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+
+    /// do_sync() is invoked on the *client side*, Can throw std::runtime_error
+    /// Either does a *FULL* or *INCREMENTAL sync depending on the
+    /// changes in the server. Returns true if client defs changed.
+    bool do_sync(ServerReply& server_reply, bool debug = false) const;
+
+private:
+    friend class PreAllocatedReply;
+    void init(unsigned int client_handle, // a reference to a set of suites used by client
+              unsigned int client_state_change_no,
+              unsigned int client_modify_change_no,
+              bool full_sync,
+              bool sync_suite_clock,
+              AbstractServer* as);
+
+    /// For use when doing a full sync
+    void init(unsigned int client_handle, AbstractServer* as);
+
+    void reset_data_members(unsigned int client_state_change_no, bool sync_suite_clock);
+    void full_sync(unsigned int client_handle, AbstractServer* as);
+    void cleanup() override; /// run in the server, after command sent to client
+
+private:
+    bool full_defs_{false};
+    DefsDelta incremental_changes_;
+    std::string server_defs_;                // for returning a subset of the suites
+    std::string full_server_defs_as_string_; // semi-persisted, i.e on load & not on saving, used to return cached defs
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this),
+           CEREAL_NVP(full_defs_),           // returning full defs as a string
+           CEREAL_NVP(incremental_changes_), // state changes, small scale changes
+
+           /// When the server_defs_ was created the def's pointer on the suites was reset back to real server defs
+           /// This is not correct for server_defs_, since we use the *same* suites
+           /// **** This is OK since by default the Defs serialisation will fix up the suite's def's pointers ***
+           /// The alternative is to clone all the suites, which is very expensive
+           CEREAL_NVP(server_defs_)); // large scale changes, if non zero handle, a small subset of the suites
+
+        // when full_defs_ is set 'server_defs_' will be empty.
+        if (Archive::is_saving::value) {
+            // Avoid copying the string. As this could be very large
+            if (full_defs_) {
+                ar& DefsCache::full_server_defs_as_string_;
+            }
+            else
+                ar & full_server_defs_as_string_;
+        }
+        else {
+            ar & full_server_defs_as_string_;
+        }
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const SSyncCmd&);
+
+#endif /* ecflow_base_stc_SSyncCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,21 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+#include "ecflow/core/Str.hpp"
+
+using namespace ecf;
+
+ServerToClientCmd::~ServerToClientCmd() = default;
+
+const std::string& ServerToClientCmd::get_string() const {
+    return Str::EMPTY();
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/ServerToClientCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,52 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_ServerToClientCmd_HPP
+#define ecflow_base_stc_ServerToClientCmd_HPP
+
+#include "ecflow/base/Cmd.hpp"
+#include "ecflow/base/ServerReply.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+//================================================================================
+// Start of Server->client
+//================================================================================
+class ServerToClientCmd {
+public:
+    virtual ~ServerToClientCmd();
+
+    virtual void cleanup() {} /// After the command has run this function can be used to reclaim memory
+
+    virtual std::string print() const = 0;
+    virtual bool equals(ServerToClientCmd*) const { return true; }
+
+    virtual const std::string&
+    get_string() const;                      /// Used by group command, can return any string, including file contents
+    virtual bool ok() const { return true; } /// Used by group command
+    virtual bool is_returnable_in_group_cmd() const { return true; } /// used by group command
+
+    virtual std::string error() const { return std::string(); } /// Used by test
+
+    // Called in client, if any data to be returned , the set on class ServerReply
+    // Cmd_ptr cts_cmd  can used for additional context.
+    // return true, if client should exit, returns false, if further work required, ie blocking, errors, etc
+    virtual bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const = 0;
+
+protected:
+    ServerToClientCmd() = default;
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {}
+};
+
+#endif /* ecflow_base_stc_ServerToClientCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/StcCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/StcCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/StcCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/StcCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,113 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/StcCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+
+std::string StcCmd::print() const {
+    switch (api_) {
+        case StcCmd::OK:
+            return "cmd:Ok";
+        case StcCmd::BLOCK_CLIENT_SERVER_HALTED:
+            return "cmd:Server_halted";
+        case StcCmd::BLOCK_CLIENT_ON_HOME_SERVER:
+            return "cmd:Wait";
+        case StcCmd::DELETE_ALL:
+            return "cmd:delete_all";
+        case StcCmd::END_OF_FILE:
+            return "cmd:end_of_file";
+        case StcCmd::INVALID_ARGUMENT:
+            return "cmd:Invalid_argument";
+        default:
+            assert(false);
+            break;
+    }
+    assert(false); // unknown command
+    return "cmd:Unknown??";
+}
+
+// Client context
+bool StcCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    bool ret = false;
+    switch (api_) {
+        case StcCmd::OK: {
+            if (debug)
+                std::cout << "  StcCmd::handle_server_response OK\n";
+            ret = true;
+            break;
+        }
+        case StcCmd::BLOCK_CLIENT_SERVER_HALTED: {
+            if (debug)
+                std::cout << "  StcCmd::handle_server_response BLOCK_CLIENT_SERVER_HALTED\n";
+            server_reply.set_block_client_server_halted(); // requires further work, by ClientInvoker
+            break;
+        }
+        case StcCmd::BLOCK_CLIENT_ON_HOME_SERVER: {
+            if (debug)
+                std::cout << "  StcCmd::handle_server_response BLOCK_CLIENT_ON_HOME_SERVER\n";
+            server_reply.set_block_client_on_home_server(); // requires further work, by ClientInvoker
+            break;
+        }
+        case StcCmd::DELETE_ALL: {
+            if (debug)
+                std::cout << "  StcCmd::handle_server_response DELETE_ALL\n";
+            server_reply.set_client_defs(defs_ptr());
+            server_reply.set_client_node(node_ptr());
+            server_reply.set_client_handle(0);
+            ret = true;
+            break;
+        }
+        case StcCmd::END_OF_FILE: {
+            if (debug)
+                std::cout << "  StcCmd::handle_server_response END_OF_FILE\n";
+            server_reply.set_eof(); // requires further work, by ClientInvoker
+            std::string ss;
+            ss += "Error: request( ";
+            ss += cts_cmd->print_short();
+            ss += " ) failed! Server replied with: EOF(Server did not reply or mixing ssl and non-ssl)\n";
+            server_reply.set_error_msg(ss);
+            break;
+        }
+        case StcCmd::INVALID_ARGUMENT: {
+            // This is created on the client side, after detecting a INVALID_ARGUMENT reply from the server
+            // This keeps compatibility with 4 servers
+            if (debug)
+                std::cout << "  StcCmd::handle_server_response INVALID_ARGUMENT\n";
+            server_reply.set_invalid_argument(); // requires further work, by ClientInvoker
+            std::string ss;
+            ss += "Error: request( ";
+            ss += cts_cmd->print_short();
+            ss += " ) failed! Server replied with: invalid_argument(Could not decode client protocol)\n";
+            server_reply.set_error_msg(ss);
+            break;
+        }
+        default:
+            assert(false);
+            break;
+    }
+    return ret;
+}
+
+bool StcCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<StcCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    if (api_ != the_rhs->api())
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::ostream& operator<<(std::ostream& os, const StcCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/StcCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/StcCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/StcCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/StcCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,58 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_StcCmd_HPP
+#define ecflow_base_stc_StcCmd_HPP
+
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+
+// Command that are simple replies to the client.
+// Originally we had separate commands. However this lead
+// TOC overflow on the AIX. Hence in order to minimise global
+// symbols due to use of boost serialisation, will use a single command
+class StcCmd final : public ServerToClientCmd {
+public:
+    enum Api {
+        OK,
+        BLOCK_CLIENT_SERVER_HALTED,
+        BLOCK_CLIENT_ON_HOME_SERVER,
+        DELETE_ALL,
+        INVALID_ARGUMENT, // Created on the Client side
+        END_OF_FILE
+    };
+    explicit StcCmd(Api a) : api_(a) {}
+    StcCmd() = default;
+
+    void init(Api a) { api_ = a; }
+    Api api() const { return api_; }
+
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
+
+    /// Other legitimate ServerToClientCmd commands also return ok() as true
+    bool ok() const override { return api_ == OK; } // used by group command
+
+    // avoid adding OK to group command. Since groupCmd will return true from GroupSTCCmd::ok() *IF* there are no errors
+    bool is_returnable_in_group_cmd() const override { return api_ == DELETE_ALL; }
+
+private:
+    Api api_{OK};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(api_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const StcCmd&);
+
+#endif /* ecflow_base_stc_StcCmd_HPP */
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.cpp 5.13.0-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.cpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,67 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/base/stc/ZombieGetCmd.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/core/Converter.hpp"
+
+using namespace std;
+using namespace boost;
+
+ZombieGetCmd::ZombieGetCmd(AbstractServer* as) {
+    init(as);
+}
+
+// called in the server
+void ZombieGetCmd::init(AbstractServer* as) {
+    zombies_.clear();
+    as->zombie_ctrl().get(zombies_);
+}
+
+bool ZombieGetCmd::equals(ServerToClientCmd* rhs) const {
+    auto* the_rhs = dynamic_cast<ZombieGetCmd*>(rhs);
+    if (!the_rhs)
+        return false;
+    return ServerToClientCmd::equals(rhs);
+}
+
+std::string ZombieGetCmd::print() const {
+    string os;
+    os += "cmd:ZombieGetCmd [ ";
+    os += ecf::convert_to<std::string>(zombies_.size());
+    os += " ]";
+    return os;
+}
+
+// Called in client
+bool ZombieGetCmd::handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const {
+    if (debug) {
+        std::cout << "  ZombieGetCmd::handle_server_response zombies.size() = " << zombies_.size() << "\n";
+    }
+
+    if (server_reply.cli()) {
+        std::cout << Zombie::pretty_print(zombies_);
+    }
+    else {
+        if (debug) {
+            std::cout << Zombie::pretty_print(zombies_);
+        }
+        server_reply.set_zombies(zombies_);
+    }
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const ZombieGetCmd& c) {
+    os << c.print();
+    return os;
+}
diff -pruN 5.12.4-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.hpp 5.13.0-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.hpp
--- 5.12.4-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/src/ecflow/base/stc/ZombieGetCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,47 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_stc_ZombieGetCmd_HPP
+#define ecflow_base_stc_ZombieGetCmd_HPP
+
+#include "ecflow/attribute/Zombie.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+class AbstractServer;
+
+//================================================================================
+// Paired with CtsCmd(GET_ZOMBIES)
+// Client---CtsCmd(GET_ZOMBIES)---->Server-----(ZombieGetCmd)--->client:
+//================================================================================
+class ZombieGetCmd final : public ServerToClientCmd {
+public:
+    explicit ZombieGetCmd(AbstractServer*);
+    ZombieGetCmd() : ServerToClientCmd() {}
+
+    void init(AbstractServer*);
+    bool handle_server_response(ServerReply&, Cmd_ptr cts_cmd, bool debug) const override;
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    void cleanup() override {
+        std::vector<Zombie>().swap(zombies_);
+    } /// run in the server, after command send to client
+
+private:
+    std::vector<Zombie> zombies_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(zombies_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, const ZombieGetCmd&);
+
+#endif /* ecflow_base_stc_ZombieGetCmd_HPP */
diff -pruN 5.12.4-1/libs/base/test/MockServer.hpp 5.13.0-1/libs/base/test/MockServer.hpp
--- 5.12.4-1/libs/base/test/MockServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/MockServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,163 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_test_MockServer_HPP
+#define ecflow_base_test_MockServer_HPP
+
+#include <cassert>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/core/Ecf.hpp" // In server we increment modify and state change numbers,
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+/// Act as stand in for a server since Request require at least a AbstractServer
+class MockServer : public AbstractServer {
+public:
+    // For the MockServer don't delete the Defs. since we past in a fixture defs
+    struct null_deleter
+    {
+        void operator()(void const*) const {}
+    };
+
+    // Only in server side do we increment state/modify numbers, controlled by: Ecf::set_server(true)
+    explicit MockServer(Defs* defs) : defs_(defs_ptr(defs, MockServer::null_deleter())) { Ecf::set_server(true); }
+    explicit MockServer(defs_ptr defs) : defs_(defs) { Ecf::set_server(true); }
+    ~MockServer() override { Ecf::set_server(false); }
+
+    void set_server_state(SState::State ss) {
+        serverState_    = ss;
+        stats().status_ = static_cast<int>(serverState_);
+        defs_->set_server().set_state(serverState_);
+    }
+
+    // AbstractServer functions
+    SState::State state() const override { return serverState_; }
+    std::pair<std::string, std::string> hostPort() const override {
+        assert(defs_.get());
+        return defs_->server().hostPort();
+    }
+    defs_ptr defs() const override { return defs_; }
+    void updateDefs(defs_ptr d, bool force) override {
+        assert(defs_.get());
+        defs_->absorb(d.get(), force);
+    }
+    void clear_defs() override {
+        if (defs_.get())
+            defs_->clear();
+    } // dont delete since we pass in Fixture defs. Otherwise it will crash
+    bool checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
+                     int check_pt_interval        = 0,
+                     int check_pt_save_time_alarm = 0) override {
+        return true;
+    }
+    void restore_defs_from_checkpt() override {}
+    void nodeTreeStateChanged() override {}
+    bool allowTaskCommunication() const override { return (serverState_ != SState::HALTED) ? true : false; }
+    void shutdown() override { set_server_state(SState::SHUTDOWN); }
+    void halted() override { set_server_state(SState::HALTED); }
+    void restart() override { set_server_state(SState::RUNNING); }
+    bool reloadWhiteListFile(std::string&) override { return true; }
+    bool reloadPasswdFile(std::string& errorMsg) override { return true; }
+    bool reloadCustomPasswdFile(std::string& errorMsg) override { return true; }
+    bool authenticateReadAccess(const std::string&, bool custom_user, const std::string& passwd) override {
+        return true;
+    }
+    bool authenticateReadAccess(const std::string&,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::string&) override {
+        return true;
+    }
+    bool authenticateReadAccess(const std::string&,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::vector<std::string>&) override {
+        return true;
+    }
+    bool authenticateWriteAccess(const std::string&) override { return true; }
+    bool authenticateWriteAccess(const std::string&, const std::string&) override { return true; }
+    bool authenticateWriteAccess(const std::string&, const std::vector<std::string>&) override { return true; }
+
+    bool lock(const std::string& user) override {
+        if (userWhoHasLock_.empty()) {
+            userWhoHasLock_           = user;
+            stats().locked_by_user_   = user;
+            server_state_to_preserve_ = state();
+            shutdown();
+            return true;
+        }
+        else if (userWhoHasLock_ == user && serverState_ == SState::SHUTDOWN) {
+            // Same user attempting multiple locks
+            return true;
+        }
+        return false;
+    }
+    void unlock() override {
+        userWhoHasLock_.clear();
+        stats().locked_by_user_.clear();
+        switch (server_state_to_preserve_) {
+            case SState::RUNNING:
+                restart();
+                break;
+            case SState::SHUTDOWN:
+                shutdown();
+                break;
+            case SState::HALTED:
+                halted();
+                break;
+        }
+    }
+    const std::string& lockedUser() const override { return userWhoHasLock_; }
+
+    void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
+                                             bool user_cmd_context) const override {
+        if (state() == SState::RUNNING && defs_.get()) {
+            JobsParam jobsParam(poll_interval(), false /* as->allow_job_creation_during_tree_walk() */);
+            Jobs jobs(defs_);
+            if (!jobs.generate(jobsParam))
+                ecf::log(ecf::Log::ERR, jobsParam.getErrorMsg()); // will automatically add end of line
+        }
+    }
+    int poll_interval() const override { return 60; }
+    void debug_server_on() override {}
+    void debug_server_off() override {}
+    bool debug() const override { return true; }
+
+private:
+    defs_ptr defs_;
+    std::string userWhoHasLock_;
+    SState::State serverState_{SState::RUNNING};
+    SState::State server_state_to_preserve_{SState::RUNNING};
+};
+
+/// This class is used to create a Mock Server, so that we can make direct
+/// data model changes without using commands.
+/// In particular it will:
+///   o Ecf::set_server(true): This controls incrementing of state/modify change numbers
+///                            which should *only* be done on the server side
+///   o Update Suite state/modify change number
+class MockSuiteChangedServer {
+public:
+    MockSuiteChangedServer()                              = delete;
+    MockSuiteChangedServer(const MockSuiteChangedServer&) = delete;
+    explicit MockSuiteChangedServer(suite_ptr suite) : suiteChanged_(suite) { Ecf::set_server(true); }
+    ~MockSuiteChangedServer() { Ecf::set_server(false); }
+
+    MockSuiteChangedServer& operator=(const MockSuiteChangedServer&) = delete;
+
+private:
+    ecf::SuiteChanged suiteChanged_;
+};
+
+#endif /* ecflow_base_test_MockServer_HPP */
diff -pruN 5.12.4-1/libs/base/test/TestAlterCmd.cpp 5.13.0-1/libs/base/test/TestAlterCmd.cpp
--- 5.12.4-1/libs/base/test/TestAlterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestAlterCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1275 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_AlterCmd)
+
+class TestStateChanged {
+public:
+    explicit TestStateChanged(suite_ptr s)
+        : suite_(s),
+          initial_suite_state_change_no_(s->state_change_no()),
+          initial_suite_modify_change_no_(s->modify_change_no()) {
+        Ecf::set_server(true);
+    }
+
+    ~TestStateChanged() {
+        Ecf::set_server(false);
+        BOOST_CHECK_MESSAGE(suite_->state_change_no() != initial_suite_state_change_no_ ||
+                                suite_->modify_change_no() != initial_suite_modify_change_no_,
+                            "Suite " << suite_->name() << " has no change in attributes. Forget to increment change no?"
+                                     << " suite_->state_change_no(" << suite_->state_change_no() << ")-"
+                                     << "-initial_suite_state_change_no_(" << initial_suite_state_change_no_ << ") "
+                                     << " suite_->modify_change_no(" << suite_->modify_change_no() << ")-"
+                                     << "-initial_suite_modify_change_no_(" << initial_suite_modify_change_no_ << ")");
+    }
+
+private:
+    suite_ptr suite_;
+    unsigned int initial_suite_state_change_no_;
+    unsigned int initial_suite_modify_change_no_;
+};
+
+class TestDefsStateChanged {
+public:
+    explicit TestDefsStateChanged(Defs* s) : defs_(s), initial_state_change_no_(s->defs_only_max_state_change_no()) {}
+
+    ~TestDefsStateChanged() {
+        Ecf::set_server(false);
+        BOOST_CHECK_MESSAGE(defs_->defs_only_max_state_change_no() != initial_state_change_no_,
+                            "Defs has no change in attributes. Forget to increment change no?");
+    }
+
+private:
+    Defs* defs_;
+    unsigned int initial_state_change_no_;
+};
+
+BOOST_AUTO_TEST_CASE(test_add_log5) {
+    // create once for all test below, then remove at the end
+    Log::create("test_add_log5.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_type_hybrid) {
+    cout << "Base:: ...test_alter_cmd_for_clock_type_hybrid\n";
+
+    // In this test the suite has NO Clock attribute. It should get added automatically
+    // when a new clock is added, we should sync with the computer clock
+    Defs defs;
+    suite_ptr s = Suite::create("suite");
+    defs.addSuite(s);
+
+    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
+    std::string error_msg;
+    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+
+    { // Change clock type
+      // =====================================================================================================
+        defs.beginAll();
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "hybrid", "")));
+        clock_ptr v = s->clockAttr();
+        BOOST_CHECK_MESSAGE(v && v->hybrid(), "expected clock to be added and be hybrid");
+
+        // Altering the suite clock attributes, should force suite calendar to  align to todays date and time
+        boost::posix_time::ptime date_now = Calendar::second_clock_time();
+        int day_of_month                  = date_now.date().day();
+        int month                         = date_now.date().month();
+        int year                          = date_now.date().year();
+        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
+                            "Calendar should be updated after re-queue/begin. Expected "
+                                << day_of_month << " but found " << s->calendar().day_of_month());
+        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
+                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
+                                                                                         << s->calendar().month());
+        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_type_real) {
+    cout << "Base:: ...test_alter_cmd_for_clock_type_real\n";
+
+    // In this test the suite has NO Clock attribute. It should get added automatically
+    // when a new clock is added, we should sync with the computer clock
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+
+    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
+    std::string error_msg;
+    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+
+    { // Change clock type
+      // =====================================================================================================
+        defs.beginAll();
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "real", "")));
+        clock_ptr v = s->clockAttr();
+        BOOST_CHECK_MESSAGE(v && !v->hybrid(), "expected clock to be added and be real");
+
+        // Altering the suite clock attributes, should force suite calendar to  align to todays date and time
+        boost::posix_time::ptime date_now = Calendar::second_clock_time();
+        int day_of_month                  = date_now.date().day();
+        int month                         = date_now.date().month();
+        int year                          = date_now.date().year();
+        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
+                            "Calendar should be updated after re-queue/begin. Expected "
+                                << day_of_month << " but found " << s->calendar().day_of_month());
+        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
+                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
+                                                                                         << s->calendar().month());
+        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_sync) {
+    cout << "Base:: ...test_alter_cmd_for_clock_sync\n";
+
+    // Add a suite with a hybrid clock set to the past, on switch to real time, should have todays date
+    // Since the clock exists on the suite, with another date, we must explicitly sync with computer
+    // alternatively user can change clock date and clock gain to align with computer
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    ClockAttr clockAttr(true); // add hybrid clock
+    clockAttr.date(1, 1, 2009);
+    s->addClock(clockAttr);
+
+    BOOST_REQUIRE_MESSAGE(s->clockAttr(), "Expected clock");
+    BOOST_REQUIRE_MESSAGE(s->clockAttr()->hybrid(), "Expected hybrid clock");
+    std::string error_msg;
+    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+
+    { // Change clock type
+      // =====================================================================================================
+        defs.beginAll();
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "real", "")));
+        clock_ptr v = s->clockAttr();
+        BOOST_CHECK_MESSAGE(v && !v->hybrid(), "expected clock to be added and be real");
+
+        // When we reque, the date should be unchanged
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd("/" + s->name())));
+        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 1,
+                            "Calendar should be updated after re-queue/begin. Expected day of month "
+                                << 1 << " but found " << s->calendar().day_of_month());
+        BOOST_CHECK_MESSAGE(s->calendar().month() == 1,
+                            "Calendar should be updated after re-queue/begin. Expected month "
+                                << 1 << " but found " << s->calendar().month());
+        BOOST_CHECK_MESSAGE(s->calendar().year() == 2009,
+                            "Calendar should be updated after re-queued/begin, Expected year " << 2009 << " but found "
+                                                                                               << s->calendar().year());
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+
+        // After a clk sync, data should match computer
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_SYNC, "", "")));
+
+        boost::posix_time::ptime date_now = Calendar::second_clock_time();
+        int day_of_month                  = date_now.date().day();
+        int month                         = date_now.date().month();
+        int year                          = date_now.date().year();
+        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
+                            "Calendar should be updated after re-queue/begin. Expected "
+                                << day_of_month << " but found " << s->calendar().day_of_month());
+        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
+                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
+                                                                                         << s->calendar().month());
+        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_date) {
+    cout << "Base:: ...test_alter_cmd_for_clock_date\n";
+
+    // In this test the suite has NO Clock attribute. It should get added automatically
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
+    std::string error_msg;
+    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+
+    // Change clock date
+    // =====================================================================================================
+    TestStateChanged changed(s);
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_DATE, "12.12.2012", "")));
+    clock_ptr v = s->clockAttr();
+    BOOST_CHECK_MESSAGE(v.get(), "expected clock to be added");
+
+    // Check that calendar is updated  by the Alter
+    {
+        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 12, "Calendar should be updated");
+        BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated");
+        BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated");
+
+        defs.beginAll();
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(s->absNodePath())));
+        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 12, "Calendar should be updated after re-queued");
+        BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated after re-queued");
+        BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated after re-queued");
+
+        // Now re sync with the computers clock, the suite calendar should align to todays date and time
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_SYNC, "", "")));
+
+        boost::posix_time::ptime date_now = Calendar::second_clock_time();
+        int day_of_month                  = date_now.date().day();
+        int month                         = date_now.date().month();
+        int year                          = date_now.date().year();
+        BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
+                            "Calendar should be updated after re-queue/begin. Expected "
+                                << day_of_month << " but found " << s->calendar().day_of_month());
+        BOOST_CHECK_MESSAGE(s->calendar().month() == month,
+                            "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
+                                                                                         << s->calendar().month());
+        BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_cmd_for_clock_gain) {
+    cout << "Base:: ...test_alter_cmd_for_clock_gain\n";
+
+    // In this test the suite has NO Clock attribute. It should get added automatically
+    Defs defs;
+    std::string suitename = "suite";
+    suite_ptr s           = defs.add_suite(suitename);
+    BOOST_CHECK_MESSAGE(!s->clockAttr(), "Expected no clock");
+    std::string error_msg;
+    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+
+    { // Change clock gain
+      // =====================================================================================================
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(suitename, AlterCmd::CLOCK_GAIN, "86400", ""))); // add 24 hours in seconds
+        clock_ptr v = s->clockAttr();
+        BOOST_CHECK_MESSAGE(v.get(), "expected clock to be added");
+        BOOST_CHECK_MESSAGE(v && v->gain() == 86400, "expected clock gain to be 86400 but found " << v->gain());
+
+        // Check that calendar is updated by the alter
+        {
+            // add one day, to current date, to simulate a gain of 24 hours
+            boost::posix_time::ptime date_now = Calendar::second_clock_time();
+            boost::gregorian::date newDate    = date_now.date();
+            boost::gregorian::date_duration one_day(1);
+            newDate += one_day;
+            int day_of_month = newDate.day();
+            int month        = newDate.month();
+            int year         = newDate.year();
+            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
+                                "Calendar should be updated after alter. Expected " << day_of_month << " but found "
+                                                                                    << s->calendar().day_of_month());
+            BOOST_CHECK_MESSAGE(s->calendar().month() == month,
+                                "Calendar should be updated after alter. Expected " << month << " but found "
+                                                                                    << s->calendar().month());
+            BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after alter");
+
+            // This should init calendar with todays date + 86400 seconds. i.e +1 day.
+            defs.beginAll();
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd("/" + suitename)));
+            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
+                                "Calendar should be updated after re-queue/begin. Expected "
+                                    << day_of_month << " but found " << s->calendar().day_of_month());
+            BOOST_CHECK_MESSAGE(s->calendar().month() == month,
+                                "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
+                                                                                             << s->calendar().month());
+            BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
+
+            // Now re sync with the computers clock,When we reque, the suite calendar should align to todays date and
+            // time
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_SYNC, "", "")));
+            day_of_month = date_now.date().day();
+            month        = date_now.date().month();
+            year         = date_now.date().year();
+            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == day_of_month,
+                                "Calendar should be updated after re-queue/begin. Expected "
+                                    << day_of_month << " but found " << s->calendar().day_of_month());
+            BOOST_CHECK_MESSAGE(s->calendar().month() == month,
+                                "Calendar should be updated after re-queue/begin. Expected " << month << " but found "
+                                                                                             << s->calendar().month());
+            BOOST_CHECK_MESSAGE(s->calendar().year() == year, "Calendar should be updated after re-queued/begin");
+            BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_cmd) {
+    cout << "Base:: ...test_alter_cmd\n";
+
+    Defs defs;
+    suite_ptr s   = defs.add_suite("suite");
+    task_ptr task = s->add_task("t1");
+    task_ptr t2   = s->add_task("t2");
+    {
+        ClockAttr clockAttr(false); // real clock
+        clockAttr.date(1, 1, 2009);
+        clockAttr.set_gain_in_seconds(3600);
+        s->addClock(clockAttr);
+        s->addDefStatus(DState::SUSPENDED); // avoid AlterCmd from job submission
+    }
+
+    std::string error_msg;
+    BOOST_CHECK_MESSAGE(defs.checkInvariants(error_msg), "checkInvariants failed " << error_msg);
+
+    { // Change server state. This will cause Flag::MESSAGE to be set on the defs
+        TestDefsStateChanged chenged(&defs);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "_fred_", "value")));
+        BOOST_CHECK_MESSAGE(defs.server().find_variable("_fred_") == "value", "expected to find value");
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::VARIABLE, "_fred_", "_value_")));
+        BOOST_CHECK_MESSAGE(defs.server().find_variable("_fred_") == "_value_", "expected to find _value_");
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::DEL_VARIABLE, "_fred_")));
+        BOOST_CHECK_MESSAGE(defs.server().find_variable("_fred_") == "", "expected to find empty string");
+
+        BOOST_CHECK_MESSAGE(defs.get_edit_history("/").size() == 3,
+                            "expected edit_history of 3 to be added but found " << defs.get_edit_history("/").size());
+
+        {
+            // test set and clear flags of the definition
+            // Note: we cannot really test Flag::Message clear, since that act of clearing, sets the message
+            std::vector<Flag::Type> flag_list = Flag::list();
+            for (auto& i : flag_list) {
+                // When any user command(including setting flags) invoked, we set Flag::MESSAGE on the defs.
+                // Hence setting flag Flag::MESSAGE has no effect. Likewise clearing has no affect since it get set
+                if (i == Flag::MESSAGE)
+                    continue;
+
+                TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", i, true)));
+                BOOST_CHECK_MESSAGE(defs.flag().is_set(i), "Expected flag " << i << " to be set ");
+
+                TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", i, false)));
+                BOOST_CHECK_MESSAGE(!defs.flag().is_set(i), "Expected flag " << i << " to be clear ");
+            }
+        }
+    }
+
+    { // Change clock type
+      // =====================================================================================================
+        defs.beginAll();
+        BOOST_CHECK_MESSAGE(s->calendar().hybrid() == false, "expected calendar to be real after begin");
+        BOOST_CHECK_MESSAGE(s->calendar().hybrid() == s->clockAttr()->hybrid(),
+                            "Calendar and Clock attribute must be in sync after begin");
+
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "hybrid", "")));
+        clock_ptr v = s->clockAttr();
+        BOOST_CHECK_MESSAGE(v && v->hybrid(), "expected clock to be hybrid");
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 1,
+                            "expected edit_history of 1 to be added but found "
+                                << defs.get_edit_history(s->absNodePath()).size());
+
+        // Check that calendar is in sync with clock attribute after the alter
+        {
+            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == s->clockAttr()->hybrid(),
+                                "Calendar and Clock attribute must be in sync after alter");
+            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == true,
+                                "expected calendar to be re-initialised to be hybrid after alter");
+        }
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_TYPE, "real", "")));
+        BOOST_CHECK_MESSAGE(v && !v->hybrid(), "expected clock to be real");
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 2,
+                            "expected edit_history of 2 to be added but found "
+                                << defs.get_edit_history(s->absNodePath()).size());
+
+        // Check that calendar is in sync with clock attribute after the alter
+        {
+            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == s->clockAttr()->hybrid(),
+                                "Calendar and Clock attribute must be in sync after alter");
+            BOOST_CHECK_MESSAGE(s->calendar().hybrid() == false,
+                                "expected calendar to be re-initialised to be real after alter");
+        }
+    }
+
+    { // Change clock date
+      // =====================================================================================================
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_DATE, "12.12.2012", "")));
+        clock_ptr v = s->clockAttr();
+        BOOST_CHECK_MESSAGE((v->day() == 12 && v->month() == 12 && v->year() == 2012),
+                            "expected clock date to be 12.12.2012 but found " << v->toString());
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 3,
+                            "expected edit_history of 3 to be added but found "
+                                << defs.get_edit_history(s->absNodePath()).size());
+
+        // Check that calendar is updated after alter
+        {
+            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 12, "Calendar should be updated after re-queued");
+            BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated after re-queued");
+            BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated after re-queued");
+        }
+    }
+
+    { // Change clock gain
+      // =====================================================================================================
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::CLOCK_GAIN, "86400", ""))); // add 24 hours in seconds
+        clock_ptr v = s->clockAttr();
+        BOOST_CHECK_MESSAGE(v && v->gain() == 86400, "expected clock gain to be 3333 but found " << v->gain());
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 4,
+                            "expected edit_history of 4 to be added but found "
+                                << defs.get_edit_history(s->absNodePath()).size());
+
+        // Check that calendar is updated after the alter
+        {
+            BOOST_CHECK_MESSAGE(s->calendar().day_of_month() == 13, "Calendar should be updated after re-queued");
+            BOOST_CHECK_MESSAGE(s->calendar().month() == 12, "Calendar should be updated after re-queued");
+            BOOST_CHECK_MESSAGE(s->calendar().year() == 2012, "Calendar should be updated after re-queued");
+        }
+    }
+
+    // test add, the deleting of a specific attribute
+    {
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "12.12.2010")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "sunday")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "23:00")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "23:00")));
+        BOOST_CHECK_MESSAGE(task->dates().size() == 1, "expected 1 date to be added but found " << s->dates().size());
+        BOOST_CHECK_MESSAGE(task->days().size() == 1, "expected 1 day to be added but found " << s->days().size());
+        BOOST_CHECK_MESSAGE(task->timeVec().size() == 1,
+                            "expected 1 time to be added but found " << s->timeVec().size());
+        BOOST_CHECK_MESSAGE(task->todayVec().size() == 1,
+                            "expected 1 today attr, to be added but found " << s->todayVec().size());
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 4,
+                            "expected edit_history of 4 to be added but found "
+                                << defs.get_edit_history(task->absNodePath()).size());
+    }
+    {
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DATE, "12.12.2010")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DAY, "sunday")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TIME, "23:00")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TODAY, "23:00")));
+        BOOST_CHECK_MESSAGE(task->dates().size() == 0, "expected 0 dates,   but found " << s->dates().size());
+        BOOST_CHECK_MESSAGE(task->days().size() == 0, "expected 0 day       but found " << s->days().size());
+        BOOST_CHECK_MESSAGE(task->timeVec().size() == 0, "expected 0 time   but found " << s->timeVec().size());
+        BOOST_CHECK_MESSAGE(task->todayVec().size() == 0, "expected 0 today but found " << s->todayVec().size());
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 8,
+                            "expected edit_history of 8 to be added but found "
+                                << defs.get_edit_history(task->absNodePath()).size());
+    }
+
+    { // test delete all
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "12.12.2010")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "12.*.2010")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DATE, "8.*.2010")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "sunday")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "monday")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_DAY, "tuesday")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "09:00")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "22:00")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "23:00")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "02:00")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "03:00")));
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 10,
+                            "expected edit_history of 10 to be added but found "
+                                << defs.get_edit_history(task->absNodePath()).size());
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DATE)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_DAY)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TIME)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TODAY)));
+        BOOST_CHECK_MESSAGE(task->dates().size() == 0, "expected 0 dates,   but found " << s->dates().size());
+        BOOST_CHECK_MESSAGE(task->days().size() == 0, "expected 0 day       but found " << s->days().size());
+        BOOST_CHECK_MESSAGE(task->timeVec().size() == 0, "expected 0 time   but found " << s->timeVec().size());
+        BOOST_CHECK_MESSAGE(task->todayVec().size() == 0, "expected 0 today but found " << s->todayVec().size());
+
+        /// Edit history should be truncated to max of 20
+        BOOST_CHECK_MESSAGE(defs.get_edit_history(task->absNodePath()).size() == 10,
+                            "expected edit_history to be truncated to 10, but found "
+                                << defs.get_edit_history(task->absNodePath()).size());
+    }
+
+    { // test add variables
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED1", "_val_")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED2", "_val_")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED3", "_val_")));
+        BOOST_CHECK_MESSAGE(s->variables().size() == 3, "expected 3 variable but found " << s->variables().size());
+
+        // test delete variables
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_VARIABLE, "FRED1")));
+        BOOST_CHECK_MESSAGE(s->variables().size() == 2, "expected 2 variable but found " << s->variables().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_VARIABLE)));
+        BOOST_CHECK_MESSAGE(s->variables().size() == 0, "expected 0 variable but found " << s->variables().size());
+
+        // test change variable
+        s->add_variable("FRED1", "BILL");
+        {
+            TestHelper::invokeRequest(&defs,
+                                      Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::VARIABLE, "FRED1", "BILL1")));
+            const Variable& v = s->findVariable("FRED1");
+            BOOST_CHECK_MESSAGE(!v.empty() && v.theValue() == "BILL1",
+                                "expected to find variable FRED1, with value BILL1");
+        }
+        {
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::VARIABLE, "FRED1")));
+            const Variable& v = s->findVariable("FRED1");
+            BOOST_CHECK_MESSAGE(!v.empty() && v.theValue() == "", "expected to find variable FRED1, with empty value");
+        }
+    }
+
+    { // test add variable to multiple nodes
+        std::vector<node_ptr> all_nodes;
+        defs.get_all_nodes(all_nodes);
+        std::vector<std::string> paths;
+        for (auto& all_node : all_nodes)
+            paths.push_back(all_node->absNodePath());
+        BOOST_CHECK_MESSAGE(paths.size() >= 2, "expected at least 2 nodes");
+
+        for (auto& all_node : all_nodes) {
+            if (all_node->variables().size() > 0) {
+                TestHelper::invokeRequest(&defs,
+                                          Cmd_ptr(new AlterCmd(all_node->absNodePath(), AlterCmd::DEL_VARIABLE)));
+            }
+        }
+
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::ADD_VARIABLE, "FRED1", "_val_")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::ADD_VARIABLE, "FRED2", "_val_")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::ADD_VARIABLE, "FRED3", "_val_")));
+        for (auto& all_node : all_nodes) {
+            BOOST_CHECK_MESSAGE(all_node->variables().size() == 3,
+                                "expected 3 variable but found " << all_node->variables().size());
+        }
+
+        // test change variable
+        {
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::VARIABLE, "FRED1", "BILL1")));
+            for (size_t i = 0; i < all_nodes.size(); i++) {
+                const Variable& v = s->findVariable("FRED1");
+                BOOST_CHECK_MESSAGE(!v.empty() && v.theValue() == "BILL1",
+                                    "expected to find variable FRED1, with value BILL1");
+            }
+        }
+
+        // test delete variables
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::DEL_VARIABLE, "FRED1")));
+        for (auto& all_node : all_nodes) {
+            BOOST_CHECK_MESSAGE(all_node->variables().size() == 2,
+                                "expected 2 variable but found " << all_node->variables().size());
+        }
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(paths, AlterCmd::DEL_VARIABLE)));
+        for (auto& all_node : all_nodes) {
+            BOOST_CHECK_MESSAGE(all_node->variables().size() == 0,
+                                "expected 0 variable but found " << all_node->variables().size());
+        }
+    }
+
+    { // test add event
+        TestStateChanged changed(s);
+        s->addEvent(Event(1, "event1"));
+        s->addEvent(Event(2, "event2"));
+        s->addEvent(Event(3, "event3"));
+        BOOST_CHECK_MESSAGE(s->events().size() == 3, "expected 3  but found " << s->events().size());
+
+        // test delete event
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_EVENT, "event1")));
+        BOOST_CHECK_MESSAGE(s->events().size() == 2, "expected 2  but found " << s->events().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_EVENT)));
+        BOOST_CHECK_MESSAGE(s->events().size() == 0, "expected 0  but found " << s->events().size());
+
+        // test change event
+        s->addEvent(Event(1, "event1"));
+        s->addEvent(Event(2, "event2"));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::EVENT, "event1", Event::SET())));
+        {
+            const Event& v = s->findEventByNameOrNumber("event1");
+            BOOST_CHECK_MESSAGE(v.value() == 1, "expected to find  event with value set");
+        }
+
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::EVENT, "event1", Event::CLEAR())));
+        {
+            const Event& v = s->findEventByNameOrNumber("event1");
+            BOOST_CHECK_MESSAGE(!v.empty() && v.value() == 0, "expected to find  event with value cleared");
+        }
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::EVENT, "event1", "")));
+        {
+            const Event& v = s->findEventByNameOrNumber("event1");
+            BOOST_CHECK_MESSAGE(v.value() == 1, "expected to find  event with value set");
+        }
+    }
+
+    { // test add meter
+        // TestStateChanged changed(s);
+        s->addMeter(Meter("meter", 0, 100, 100));
+        s->addMeter(Meter("meter1", 0, 100, 100));
+        s->addMeter(Meter("meter2", 0, 100, 100));
+        BOOST_CHECK_MESSAGE(s->meters().size() == 3, "expected 3  but found " << s->meters().size());
+
+        // test delete meter
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_METER, "meter")));
+        BOOST_CHECK_MESSAGE(s->meters().size() == 2, "expected 2  but found " << s->meters().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_METER)));
+        BOOST_CHECK_MESSAGE(s->meters().size() == 0, "expected 0 meters but found " << s->meters().size());
+
+        // test change meter value
+        s->addMeter(Meter("meter", 0, 100, 100));
+        BOOST_CHECK_MESSAGE(s->meters().size() == 1, "expected 1 meter but found " << s->meters().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::METER, "meter", "10")));
+        const Meter& v = s->findMeter("meter");
+        BOOST_CHECK_MESSAGE(v.value() == 10, "expected to find meter with value 10");
+    }
+
+    { // test add label
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "labelValue")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label1", "labelValue")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label2", "labelValue")));
+        BOOST_CHECK_MESSAGE(s->labels().size() == 3, "expected 3  but found " << s->labels().size());
+
+        // test delete label
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LABEL, "label")));
+        BOOST_CHECK_MESSAGE(s->labels().size() == 2, "expected 2  but found " << s->labels().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LABEL)));
+        BOOST_CHECK_MESSAGE(s->labels().size() == 0, "expected 0  but found " << s->labels().size());
+
+        // test change label value
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "labelValue")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LABEL, "label", "--fred--")));
+        std::string label_value;
+        BOOST_CHECK_MESSAGE(s->getLabelNewValue("label", label_value), "Expected to find label");
+        BOOST_CHECK_MESSAGE(label_value == "--fred--", "expected to find label with value --fred--");
+
+        // change label to be empty, ECFLOW-648
+        label_value.clear();
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LABEL, "label", "")));
+        BOOST_CHECK_MESSAGE(s->getLabelNewValue("label", label_value), "Expected to find label");
+        BOOST_CHECK_MESSAGE(label_value.empty(), "expected to find label with empty value");
+    }
+
+    { // test add Trigger
+        TestStateChanged changed(s);
+        task->add_trigger("t1 == complete");
+        BOOST_CHECK_MESSAGE(task->get_trigger(), "expected  trigger to be added");
+
+        // test delete trigger
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TRIGGER)));
+        BOOST_CHECK_MESSAGE(!task->get_trigger(), "expected  trigger to be deleted");
+
+        // test change trigger expression
+        task->add_trigger("t1 == complete");
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TRIGGER, "x == complete", "")));
+
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TRIGGER, "t2 == complete", "")));
+        BOOST_CHECK_MESSAGE(task->triggerExpression() == "trigger t2 == complete",
+                            "expected trigger to be changed found " << task->triggerExpression());
+    }
+
+    { // test add complete expression
+        TestStateChanged changed(s);
+        task->add_complete("t1 == complete");
+        BOOST_CHECK_MESSAGE(task->get_complete(), "expected complete to be added");
+
+        // test delete complete
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_COMPLETE)));
+        BOOST_CHECK_MESSAGE(!task->get_complete(), "expected complete to be deleted");
+
+        // test change complete expression
+        task->add_complete("t1 == complete");
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::COMPLETE, "x == complete", "")));
+
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::COMPLETE, "t2 == complete", "")));
+        BOOST_CHECK_MESSAGE(task->completeExpression() == "complete t2 == complete",
+                            "expected complete expression to be changed found " << task->completeExpression());
+    }
+
+    { // test add limit
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit", "10")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit1", "10")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit2", "10")));
+        BOOST_CHECK_MESSAGE(s->limits().size() == 3, "expected 3  but found " << s->limits().size());
+
+        // test delete limit
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LIMIT, "limit2")));
+        BOOST_CHECK_MESSAGE(s->limits().size() == 2, "expected 2  but found " << s->limits().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LIMIT)));
+        BOOST_CHECK_MESSAGE(s->limits().size() == 0, "expected 0  but found " << s->limits().size());
+
+        // test change limit max value
+        s->addLimit(Limit("limit", 10));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_MAX, "limit", "90")));
+        limit_ptr v = s->find_limit("limit");
+        BOOST_CHECK_MESSAGE(v.get() && v->theLimit() == 90, "expected to find limit with max value of 90");
+
+        // test change limit value
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_VAL, "limit", "33")));
+        BOOST_CHECK_MESSAGE(v.get() && v->value() == 33, "expected to find limit with value of 33");
+
+        // Test delete limit path
+        std::set<std::string> paths;
+        paths.insert("made_up_path");
+        Limit limit_path("limit_name", 10);
+        limit_path.set_paths(paths);
+
+        s->addLimit(limit_path);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LIMIT_PATH, "limit_name", "made_up_path")));
+        limit_ptr lm = s->find_limit("limit_name");
+        BOOST_CHECK_MESSAGE(lm.get() && lm->paths().empty(), "Expected no paths but found " << lm->paths().size());
+    }
+
+    { // test add in-limit
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "limit_name")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "limit_name1", "11")));
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit:limit_name2")));
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit:limit_name3", "10")));
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit:limitA", "10")));
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit/a:limitA", "10")));
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/to/limit/aa:limitA", "10")));
+        BOOST_CHECK_MESSAGE(s->inlimits().size() == 7, "expected 7  but found " << s->inlimits().size());
+
+        // test delete in-limit
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "limit_name")));
+        BOOST_CHECK_MESSAGE(s->inlimits().size() == 6, "expected 6 but found " << s->inlimits().size());
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/to/limit:limitA")));
+        BOOST_CHECK_MESSAGE(s->inlimits().size() == 5, "expected 5 but found " << s->inlimits().size());
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/to/limit/a:limitA")));
+        BOOST_CHECK_MESSAGE(s->inlimits().size() == 4, "expected 4 but found " << s->inlimits().size());
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/to/limit/aa:limitA")));
+        BOOST_CHECK_MESSAGE(s->inlimits().size() == 3, "expected 3 but found " << s->inlimits().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT)));
+        BOOST_CHECK_MESSAGE(s->inlimits().size() == 0, "expected 0  but found " << s->inlimits().size());
+    }
+
+    { // test add repeat
+        TestStateChanged changed(s);
+        s->addRepeat(RepeatDate("YMD", 20090916, 20090930, 1));
+        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
+
+        // test delete repeat
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
+        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
+
+        // test change repeat value
+        s->addRepeat(RepeatDate("YMD", 20090916, 20090930, 1));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "20090917", "")));
+        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "20090917",
+                            "expected 20090917 but found " << s->repeat().valueAsString());
+    }
+    {
+        s->deleteRepeat();
+        TestStateChanged changed(s);
+        s->addRepeat(RepeatDateList("YMD", {20090916, 20090930}));
+        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
+
+        // test delete repeat
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
+        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
+
+        // test change repeat value, the changed value *MUST* correspond to one of the existing values
+        s->addRepeat(RepeatDateList("YMD", {20090916, 20090930, 20190930}));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "20090930", "")));
+        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "20090930",
+                            "expected 20090930 but found " << s->repeat().valueAsString());
+    }
+    {
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT))); // delete previous repeat
+
+        std::vector<std::string> stringList;
+        stringList.reserve(3);
+        stringList.emplace_back("a");
+        stringList.emplace_back("b");
+        stringList.emplace_back("c");
+
+        s->addRepeat(RepeatEnumerated("AEnum", stringList));
+        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
+
+        // test delete repeat
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
+        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
+
+        // test change repeat value
+        s->addRepeat(RepeatEnumerated("AEnum", stringList));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "1", "")));
+        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "b",
+                            "expected 'b' but found " << s->repeat().valueAsString());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "c", "")));
+        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "c",
+                            "expected 'c' but found " << s->repeat().valueAsString());
+    }
+    {
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT))); // delete previous repeat
+
+        std::vector<std::string> stringList;
+        stringList.reserve(3);
+        stringList.emplace_back("a");
+        stringList.emplace_back("b");
+        stringList.emplace_back("c");
+
+        s->addRepeat(RepeatString("RepeatString", stringList));
+        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
+
+        // test delete repeat
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
+        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
+
+        // test change repeat value
+        s->addRepeat(RepeatString("RepeatString", stringList));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "1", "")));
+        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "b",
+                            "expected 'b' but found " << s->repeat().valueAsString());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "c", "")));
+        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "c",
+                            "expected 'c' but found " << s->repeat().valueAsString());
+    }
+
+    {
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT))); // delete previous repeat
+
+        std::vector<std::string> stringList;
+        stringList.reserve(3);
+        stringList.emplace_back("a");
+        stringList.emplace_back("b");
+        stringList.emplace_back("c");
+
+        s->addRepeat(RepeatInteger("rep", 0, 100, 1));
+        BOOST_CHECK_MESSAGE(!s->repeat().empty(), "expected repeat to be added");
+
+        // test delete repeat
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_REPEAT)));
+        BOOST_CHECK_MESSAGE(s->repeat().empty(), "expected repeat to be deleted");
+
+        // test change repeat value
+        s->addRepeat(RepeatInteger("rep", 0, 100, 1));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::REPEAT, "22", "")));
+        BOOST_CHECK_MESSAGE(s->repeat().valueAsString() == "22",
+                            "expected '22' but found " << s->repeat().valueAsString());
+    }
+
+    { // add cron
+        TestStateChanged changed(s);
+        ecf::CronAttr cronAttr;
+        ecf::TimeSlot start(0, 0);
+        ecf::TimeSlot finish(10, 0);
+        ecf::TimeSlot incr(0, 5);
+        std::vector<int> weekdays;
+        for (int i = 0; i < 7; ++i)
+            weekdays.push_back(i);
+        std::vector<int> daysOfMonth;
+        for (int i = 1; i < 32; ++i)
+            daysOfMonth.push_back(i);
+        std::vector<int> months;
+        for (int i = 1; i < 13; ++i)
+            months.push_back(i);
+        cronAttr.addTimeSeries(start, finish, incr);
+        cronAttr.addWeekDays(weekdays);
+        cronAttr.addDaysOfMonth(daysOfMonth);
+        cronAttr.addMonths(months);
+        task->addCron(cronAttr);
+
+        BOOST_CHECK_MESSAGE(task->crons().size() == 1, "expected cron to be added");
+
+        // test delete cron
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_CRON)));
+        BOOST_CHECK_MESSAGE(task->crons().size() == 0, "expected cron to be delete");
+    }
+
+    { // test suite changed
+        TestStateChanged changed(s);
+
+        // test add zombie
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_ZOMBIE, "user:fob:init:300")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_ZOMBIE, "path:fob:init:300")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_ZOMBIE, "ecf:fob:init:300")));
+        BOOST_CHECK_MESSAGE(s->zombies().size() == 3, "expected 3  but found " << s->zombies().size());
+
+        // test delete zombie
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_ZOMBIE, "ecf")));
+        BOOST_CHECK_MESSAGE(s->zombies().size() == 2, "expected 2  but found " << s->zombies().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_ZOMBIE, "path")));
+        BOOST_CHECK_MESSAGE(s->zombies().size() == 1, "expected 1  but found " << s->zombies().size());
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_ZOMBIE, "user")));
+        BOOST_CHECK_MESSAGE(s->zombies().size() == 0, "expected 0  but found " << s->zombies().size());
+    }
+
+    { // free password
+        TestStateChanged changed(s);
+        std::string returnedValue;
+        BOOST_CHECK_MESSAGE(!task->findVariableValue(Str::ECF_PASS(), returnedValue),
+                            "Expected no variable of name ECF_PASS");
+
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new AlterCmd(
+                task->absNodePath(), AlterCmd::ADD_VARIABLE, Str::ECF_PASS(), Submittable::FREE_JOBS_PASSWORD())));
+
+        BOOST_CHECK_MESSAGE(task->findVariableValue(Str::ECF_PASS(), returnedValue),
+                            "Expected to find variable ECF_PASS on the task");
+        BOOST_CHECK_MESSAGE(returnedValue == Submittable::FREE_JOBS_PASSWORD(),
+                            "Expected variable value of name " << Submittable::FREE_JOBS_PASSWORD() << " but found "
+                                                               << returnedValue);
+    }
+
+    {
+        // test set and clear flags
+        // Note: we cannot really test Flag::Message clear, since that act of clearing, sets the message
+        std::vector<Flag::Type> flag_list = Flag::list();
+        for (auto& i : flag_list) {
+            // When any user command(including setting flags) invoked, we set Flag::MESSAGE on the defs.
+            // Hence setting flag Flag::MESSAGE has no effect. Likewise clearing has no affect since it get set
+            if (i == Flag::MESSAGE)
+                continue;
+
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), i, true)));
+            BOOST_CHECK_MESSAGE(s->flag().is_set(i), "Expected flag " << i << " to be set ");
+
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), i, false)));
+            BOOST_CHECK_MESSAGE(!s->flag().is_set(i), "Expected flag " << i << " to be clear ");
+        }
+    }
+
+    BOOST_CHECK_MESSAGE(defs.get_edit_history(s->absNodePath()).size() == 10,
+                        "expected edit_history to be truncated to 10, but found "
+                            << defs.get_edit_history(s->absNodePath()).size());
+
+    {
+        // clear edit history
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new PathsCmd(PathsCmd::EDIT_HISTORY, "clear")), false);
+        BOOST_CHECK_MESSAGE(defs.get_edit_history().size() == 0,
+                            "expected edit_history to be cleared but found" << defs.get_edit_history().size());
+    }
+
+    { // Change suite def status
+      // =====================================================================================================
+        TestStateChanged changed(s);
+        std::vector<std::string> dstates = DState::allStates();
+        for (const auto& dstate : dstates) {
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEFSTATUS, dstate)));
+        }
+        // reset back to suspended
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEFSTATUS, "suspended")));
+    }
+
+    // ================================ LATE ==================================================================
+    { // test add late
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LATE, "late -s 10:10 -a 23:10 -c +23:10")));
+        BOOST_CHECK_MESSAGE(s->get_late(), "expected late to be added");
+
+        // test change late
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LATE, "late -s 10:10")));
+        BOOST_CHECK_MESSAGE(s->get_late() && s->get_late()->toString() == "late -s +10:10",
+                            "expected 'late -s 10:10' but found " << s->get_late()->toString());
+
+        // test delete variable
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LATE)));
+        BOOST_CHECK_MESSAGE(!s->get_late(), "expected late to be deleted");
+    }
+    {
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LATE, "-s 10:10 -a 23:10 -c +23:10")));
+        BOOST_CHECK_MESSAGE(s->get_late(), "expected late to be added");
+
+        // test change late
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LATE, "-s 10:10 -a 12:00")));
+        BOOST_CHECK_MESSAGE(s->get_late() && s->get_late()->toString() == "late -s +10:10 -a 12:00",
+                            "expected 'late -s +10:10 -a 12:00' but found " << s->get_late()->toString());
+
+        // test delete variable
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_LATE)));
+        BOOST_CHECK_MESSAGE(!s->get_late(), "expected late to be deleted");
+    }
+
+    // ================================ TIME ==================================================================
+    {
+        // test add time
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TIME, "+23:10")));
+        BOOST_CHECK_MESSAGE(task->timeVec().size() == 1, "expected 1 time   but found " << task->timeVec().size());
+
+        // test change time
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TIME, "+23:10", "10:10")));
+        BOOST_CHECK_MESSAGE(task->timeVec()[0].toString() == "time 10:10",
+                            "expected 'time 10:10' but found " << task->timeVec()[0].toString());
+
+        // test delete time
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TIME)));
+        BOOST_CHECK_MESSAGE(task->timeVec().size() == 0, "expected 0 time but found " << task->timeVec().size());
+    }
+
+    // ================================ TODAY ==================================================================
+    {
+        // test add today
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::ADD_TODAY, "+10:10 23:00 00:01")));
+        BOOST_CHECK_MESSAGE(task->todayVec().size() == 1, "expected 1 today but found " << task->todayVec().size());
+
+        // test change today
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::TODAY, "+10:10 23:00 00:01", "+10:10")));
+        BOOST_CHECK_MESSAGE(task->todayVec()[0].toString() == "today +10:10",
+                            "expected 'today +10:10' but found " << task->todayVec()[0].toString());
+
+        // test delete today
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(task->absNodePath(), AlterCmd::DEL_TODAY)));
+        BOOST_CHECK_MESSAGE(task->todayVec().size() == 0, "expected 0 time but found " << task->todayVec().size());
+    }
+
+    // ================================ Generic ==================================================================
+    // Cannot add generic via Alter
+    {
+        s->add_generic(GenericAttr("a"));
+        s->add_generic(GenericAttr("b"));
+        s->add_generic(GenericAttr("3"));
+        BOOST_CHECK_MESSAGE(s->generics().size() == 3, "Expected 3 generics but found " << s->generics().size());
+
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_GENERIC, "a")));
+        BOOST_CHECK_MESSAGE(s->generics().size() == 2, "Expected 2 generics but found " << s->generics().size());
+
+        // test delete variable
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_GENERIC)));
+        BOOST_CHECK_MESSAGE(s->generics().size() == 0, "Expected no generics but found " << s->generics().size());
+    }
+}
+
+void add_sortable_attributes(Node* node) {
+    node->add_variable("varz", "-");
+    node->add_variable("vary", "-");
+    node->add_variable("vara", "-");
+    node->addEvent(Event("zevent"));
+    node->addEvent(Event("aevent"));
+    node->addEvent(Event(1));
+    node->addEvent(Event(2));
+    node->addMeter(Meter("zmeter", 1, 100));
+    node->addMeter(Meter("ameter", 1, 100));
+    node->addLabel(Label("zlabel", "-"));
+    node->addLabel(Label("alabel", "-"));
+    node->addLimit(Limit("zlimit", 10));
+    node->addLimit(Limit("ylimit", 10));
+    node->addLimit(Limit("xlimit", 10));
+}
+void add_sorted_attributes(Node* node) {
+    node->add_variable("vara", "-");
+    node->add_variable("vary", "-");
+    node->add_variable("varz", "-");
+    node->addEvent(Event(1));
+    node->addEvent(Event(2));
+    node->addEvent(Event("aevent"));
+    node->addEvent(Event("zevent"));
+    node->addMeter(Meter("ameter", 1, 100));
+    node->addMeter(Meter("zmeter", 1, 100));
+    node->addLabel(Label("alabel", "-"));
+    node->addLabel(Label("zlabel", "-"));
+    node->addLimit(Limit("xlimit", 10));
+    node->addLimit(Limit("ylimit", 10));
+    node->addLimit(Limit("zlimit", 10));
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_sort_attributes) {
+    cout << "Base:: ...test_alter_sort_attributes\n";
+
+    Defs defs;
+    defs.set_server().add_or_update_user_variables("z", "z");
+    defs.set_server().add_or_update_user_variables("y", "y");
+    defs.set_server().add_or_update_user_variables("x", "x");
+    suite_ptr s = defs.add_suite("suite");
+    add_sortable_attributes(s.get());
+    family_ptr f1 = s->add_family("f1");
+    add_sortable_attributes(f1.get());
+    task_ptr t1 = f1->add_task("t1");
+    add_sortable_attributes(t1.get());
+
+    Defs sorted_defs;
+    sorted_defs.flag().set(ecf::Flag::MESSAGE); // take into account alter
+    sorted_defs.set_server().add_or_update_user_variables("x", "x");
+    sorted_defs.set_server().add_or_update_user_variables("y", "y");
+    sorted_defs.set_server().add_or_update_user_variables("z", "z");
+    suite_ptr ss = sorted_defs.add_suite("suite");
+    add_sorted_attributes(ss.get());
+    family_ptr sf1 = ss->add_family("f1");
+    add_sorted_attributes(sf1.get());
+    task_ptr st1 = sf1->add_task("t1");
+    add_sorted_attributes(st1.get());
+    sorted_defs.sort_attributes(ecf::Attr::VARIABLE, false /*recursive*/); // just sort the server variables
+
+    {
+        TestDefsStateChanged chenged(&defs);
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "event", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "meter", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "label", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "limit", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd("/", "variable", "recursive")));
+        DebugEquality debug_equality; // only as affect in DEBUG build
+        BOOST_CHECK_MESSAGE(defs == sorted_defs, "Sort failed expected\n" << sorted_defs << "\nbut found\n" << defs);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_sort_attributes_for_task) {
+    cout << "Base:: ...test_alter_sort_attributes_for_task\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    add_sortable_attributes(s.get());
+    family_ptr f1 = s->add_family("f1");
+    add_sortable_attributes(f1.get());
+    task_ptr t1 = f1->add_task("t1");
+    add_sortable_attributes(t1.get());
+
+    Defs sorted_defs; // sorted_defs.flag().set(ecf::Flag::MESSAGE); // take into account alter
+    suite_ptr ss = sorted_defs.add_suite("suite");
+    add_sortable_attributes(ss.get());
+    family_ptr sf1 = ss->add_family("f1");
+    add_sortable_attributes(sf1.get());
+    task_ptr st1 = sf1->add_task("t1");
+    add_sorted_attributes(st1.get());
+    st1->flag().set(ecf::Flag::MESSAGE);
+    {
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "event", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "meter", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "label", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "limit", "recursive")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(t1->absNodePath(), "variable", "recursive")));
+        DebugEquality debug_equality; // only as affect in DEBUG build
+        BOOST_CHECK_MESSAGE(defs == sorted_defs, "Sort failed expected\n" << sorted_defs << "\nbut found\n" << defs);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alter_cmd_errors) {
+    cout << "Base:: ...test_alter_cmd_errors\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    s->add_task("t1");
+
+    { // test add variables
+        TestStateChanged changed(s);
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_VARIABLE, "FRED1", "_val_")));
+        BOOST_CHECK_MESSAGE(s->variables().size() == 1, "expected 1 variable but found " << s->variables().size());
+
+        // test delete variables, with a non existent path
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/idont/exist", AlterCmd::DEL_VARIABLE, "FRED1")));
+
+        // ECFLOW-380 test change read only server variables
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_HOST", "a")));
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_PORT", "a")));
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_PID", "a")));
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_VERSION", "a")));
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "ECF_LISTS", "a")));
+
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, "limit"))); // no limit value
+        TestHelper::invokeFailureRequest(
+            &defs,
+            Cmd_ptr(new AlterCmd(
+                s->absNodePath(), AlterCmd::ADD_LIMIT, "limit", "xx"))); // value not convertible to integer
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LIMIT, ".1", "10"))); // not a valid name
+
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, ""))); // no inlimit value
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/limit"))); // limit path, but no name
+        TestHelper::invokeFailureRequest(&defs,
+                                         Cmd_ptr(new AlterCmd(s->absNodePath(),
+                                                              AlterCmd::ADD_INLIMIT,
+                                                              "/path/tolimit:limit",
+                                                              "xx"))); // tokens must be convertible to an integer
+
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_INLIMIT, "/path/tolimit:limit", "1")));
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/tolimit"))); // no limit name
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/tolimit:"))); // no limit name
+        TestHelper::invokeFailureRequest(
+            &defs,
+            Cmd_ptr(
+                new AlterCmd(s->absNodePath(), AlterCmd::DEL_INLIMIT, "/path/tolimit:12 34"))); // invalid limit name
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "1")));
+        TestHelper::invokeFailureRequest(
+            &defs,
+            Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::ADD_LABEL, "label", "value"))); // duplicate label name
+    }
+
+    /// Destroy singleton's to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_destroy_log5) {
+    Log::destroy();
+    fs::remove("test_add_log5.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestArchiveAndRestoreCmd.cpp 5.13.0-1/libs/base/test/TestArchiveAndRestoreCmd.cpp
--- 5.12.4-1/libs/base/test/TestArchiveAndRestoreCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestArchiveAndRestoreCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,357 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/DeleteCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Pid.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_ArchiveAndRestoreCmd)
+
+BOOST_AUTO_TEST_CASE(test_add_log4) {
+    // create once for all test below, then remove at the end
+    Log::create("test_add_log4.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_CASE(test_archive_and_restore_suite) {
+    cout << "Base:: ...test_archive_and_restore_suite\n";
+
+    // Please note: after archive we delete the children, hence any references to child refer to a different object
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_HOME ....
+    //  family f1
+    //     task t1
+
+    // We use Pid::unique_name, to allow multiple invocation of this test
+    Defs theDefs;
+    std::string ecf_home = File::test_data("libs/base/test", "libs/base");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_suite"));
+    suite->add_family("f1")->add_task("t1");
+    // cout << theDefs << "\n";
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, suite->absNodePath())));
+    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
+    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()), "Archive path" << suite->archive_path() << " not created");
+    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children not removed");
+    // cout << theDefs << "\n";
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
+    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::RESTORED), "Restored flag not set");
+    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
+    BOOST_CHECK_MESSAGE(!fs::exists(suite->archive_path()), "Archived file has not been deleted after restore");
+    BOOST_CHECK_MESSAGE(!suite->nodeVec().empty(), "Children are not restored");
+
+    // Archive again but restore via begin
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, suite->absNodePath())));
+    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
+    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()), "Archive path" << suite->archive_path() << " not created");
+    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children not removed");
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new BeginCmd(suite->absNodePath(), true))); // nodes will be active
+    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
+    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::RESTORED), "restored flag not *cleared");
+    BOOST_CHECK_MESSAGE(!fs::exists(suite->archive_path()), "Archived file has not been deleted after restore");
+    BOOST_CHECK_MESSAGE(!suite->nodeVec().empty(), "Children are not restored");
+
+    // PrintStyle::setStyle(PrintStyle::MIGRATE);
+    // cout << theDefs << "\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_archive_and_restore_family) {
+    cout << "Base:: ...test_archive_and_restore_family\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_HOME ....
+    //  family f1
+    //     family f2
+    //       family f3
+    //          task t1
+
+    Defs theDefs;
+    std::string ecf_home = File::test_data("libs/base/test", "libs/base");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_family"));
+    family_ptr f3   = suite->add_family("f1")->add_family("f2")->add_family("f3");
+    f3->add_task("t1");
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, f3->absNodePath())));
+    BOOST_CHECK_MESSAGE(f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
+    BOOST_CHECK_MESSAGE(fs::exists(f3->archive_path()), "Archive path" << f3->archive_path() << " not created");
+    BOOST_CHECK_MESSAGE(f3->nodeVec().empty(), "Children not removed");
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, f3->absNodePath())));
+    BOOST_CHECK_MESSAGE(f3->flag().is_set(ecf::Flag::RESTORED), "restored flag not set");
+    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
+    BOOST_CHECK_MESSAGE(!fs::exists(f3->archive_path()), "Archived file has not been deleted after restore");
+    BOOST_CHECK_MESSAGE(!f3->nodeVec().empty(), "Children are not restored");
+
+    // Archive again but restore via begin
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, f3->absNodePath())));
+    BOOST_CHECK_MESSAGE(f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
+    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::RESTORED), "Restored flag not cleared");
+    BOOST_CHECK_MESSAGE(fs::exists(f3->archive_path()), "Archive path" << suite->archive_path() << " not created");
+    BOOST_CHECK_MESSAGE(f3->nodeVec().empty(), "Children not removed");
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new BeginCmd(suite->absNodePath(), true))); // nodes will be active
+    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
+    BOOST_CHECK_MESSAGE(!f3->flag().is_set(ecf::Flag::RESTORED), "Restored flag not *cleared");
+    BOOST_CHECK_MESSAGE(!fs::exists(f3->archive_path()), "Archived file has not been deleted after restore");
+    BOOST_CHECK_MESSAGE(!f3->nodeVec().empty(), "Children are not restored");
+
+    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
+    //   cout << theDefs << "\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_archive_and_restore_all) {
+    cout << "Base:: ...test_archive_and_restore_all\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_HOME ....
+    //  family f1
+    //     task t1; task t2
+    //     family f2
+    //       task t1; task t2
+    //       family f3
+    //         task t1; task t2
+    //         family f4
+    //           task t1; task t2
+
+    Defs theDefs;
+    {
+        std::string ecf_home = File::test_data("libs/base/test", "libs/base");
+        theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+        suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_all"));
+        family_ptr f1   = suite->add_family("f1");
+        f1->add_task("t1");
+        f1->add_task("t2");
+        family_ptr f2 = f1->add_family("f2");
+        f2->add_task("t1");
+        f2->add_task("t2");
+        family_ptr f3 = f2->add_family("f3");
+        f3->add_task("t1");
+        f3->add_task("t2");
+        family_ptr f4 = f3->add_family("f4");
+        f4->add_task("t1");
+        f4->add_task("t2");
+        TestHelper::invokeRequest(&theDefs,
+                                  Cmd_ptr(new BeginCmd(suite->absNodePath(), false))); // al nodes wil be active
+    }
+    // cout << theDefs << "\n";
+
+    // ****************************************************************************************
+    // *** Each time we restore, we have a new set of pointers *FOR* the children of archived/restored NODE
+    // *** Hence use paths
+    // ****************************************************************************************
+    std::vector<node_ptr> nodes;
+    theDefs.get_all_nodes(nodes);
+    std::vector<std::string> nc_vec;
+    for (auto& node : nodes) {
+        NodeContainer* nc = node->isNodeContainer();
+        if (!nc)
+            continue;
+        nc_vec.push_back(nc->absNodePath());
+    }
+
+    for (const auto& i : nc_vec) {
+        // cout << "archive and restore " << nc_vec[i]  << "\n";
+        {
+            TestHelper::invokeRequest(
+                &theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, i, true))); // use force since jobs are active
+            node_ptr node = theDefs.findAbsNode(i);
+            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
+            NodeContainer* nc = node->isNodeContainer();
+            BOOST_CHECK_MESSAGE(nc->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(fs::exists(nc->archive_path()), "Archive path" << nc->archive_path() << " not created");
+            BOOST_CHECK_MESSAGE(nc->nodeVec().empty(), "Children not removed " << nc->absNodePath());
+
+            TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, i)));
+            node = theDefs.findAbsNode(i);
+            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
+            nc = node->isNodeContainer();
+            BOOST_CHECK_MESSAGE(nc->flag().is_set(ecf::Flag::RESTORED),
+                                "restored flag should be set " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::ARCHIVED),
+                                "Archived flag not *cleared " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(!fs::exists(nc->archive_path()),
+                                "Archived file has not been deleted after restore " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(!nc->nodeVec().empty(), "Children are not restored " << nc->absNodePath());
+        }
+        {
+            // Archive again but restore via re-queue
+            TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, i, true)));
+            node_ptr node = theDefs.findAbsNode(i);
+            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
+            NodeContainer* nc = node->isNodeContainer();
+            BOOST_CHECK_MESSAGE(nc->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::RESTORED),
+                                "Restored flag should be clear " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(fs::exists(nc->archive_path()), "Archive path" << nc->archive_path() << " not created");
+            BOOST_CHECK_MESSAGE(nc->nodeVec().empty(), "Children not removed " << nc->absNodePath());
+
+            TestHelper::invokeRequest(&theDefs, Cmd_ptr(new RequeueNodeCmd(i, RequeueNodeCmd::FORCE)));
+            node = theDefs.findAbsNode(i);
+            BOOST_REQUIRE_MESSAGE(node, "Could not find node " << i);
+            nc = node->isNodeContainer();
+            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::RESTORED),
+                                "Restored flag not *cleared " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(!nc->flag().is_set(ecf::Flag::ARCHIVED),
+                                "Archived flag not *cleared " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(!fs::exists(nc->archive_path()),
+                                "Archived file has not been deleted after restore " << nc->absNodePath());
+            BOOST_CHECK_MESSAGE(!nc->nodeVec().empty(), "Children are not restored " << nc->absNodePath());
+        }
+    }
+    // cout << theDefs << "\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_archive_and_restore_overlap) {
+    cout << "Base:: ...test_archive_and_restore_overlap\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_HOME ....
+    //  family f1
+    //     task t1
+
+    Defs theDefs;
+    std::string ecf_home = File::test_data("libs/base/test", "libs/base");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_overlap"));
+    std::string f1_abs_node_path;
+    {
+        family_ptr f1 = suite->add_family("f1");
+        f1->add_task("t1");
+        f1_abs_node_path = f1->absNodePath();
+    }
+
+    // Archive suite and its immediate child. This should be detected and we should only archive the suite and not the
+    // family
+    std::vector<std::string> paths;
+    paths.push_back(suite->absNodePath()); // archive suite
+    paths.push_back(f1_abs_node_path);     // archive family its child at the same time, should be ignored
+
+    TestHelper::invokeRequest(&theDefs,
+                              Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, paths))); // family_ptr f1 removed from the suite
+    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set");
+    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()), "Archive path " << suite->archive_path() << " not created");
+    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children not removed");
+    BOOST_CHECK_MESSAGE(!theDefs.findAbsNode(f1_abs_node_path), "f1 should have been removed");
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
+    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::RESTORED), "Restored flag not set");
+    BOOST_CHECK_MESSAGE(!suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not *cleared");
+    BOOST_CHECK_MESSAGE(!fs::exists(suite->archive_path()), "Archived file has not been deleted after restore");
+    BOOST_CHECK_MESSAGE(!suite->nodeVec().empty(), "Children are not restored");
+    node_ptr f1 = theDefs.findAbsNode(f1_abs_node_path);
+    BOOST_CHECK_MESSAGE(f1, "f1 should have been restored");
+    BOOST_CHECK_MESSAGE(!f1->flag().is_set(ecf::Flag::RESTORED), "Family f1 should not have restored flag set");
+}
+
+BOOST_AUTO_TEST_CASE(test_archive_and_delete_suite) {
+    cout << "Base:: ...test_archive_and_delete_suite\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_HOME ....
+    //  family f1
+    //     task t1
+    // Here we are archiving the family and then the suite
+    // We then delete the suite and check that both archived files are removed.
+
+    // We use Pid::unique_name, to allow multiple invocation of this test
+    Defs theDefs;
+    std::string ecf_home = File::test_data("libs/base/test", "libs/base");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+    suite_ptr suite   = theDefs.add_suite(Pid::unique_name("test_archive_and_delete_suite"));
+    family_ptr family = suite->add_family("f1");
+    family->add_task("t1");
+    // cout << theDefs << "\n";
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, family->absNodePath())));
+    BOOST_CHECK_MESSAGE(family->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set on family");
+    BOOST_CHECK_MESSAGE(family->has_archive(), "Archived flag not set on family");
+    std::string family_archive_path = family->archive_path();
+    BOOST_CHECK_MESSAGE(fs::exists(family_archive_path), "Archive path" << family->archive_path() << " not created");
+    BOOST_CHECK_MESSAGE(family->nodeVec().empty(), "Children of family not removed after archive");
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::ARCHIVE, suite->absNodePath())));
+    BOOST_CHECK_MESSAGE(suite->flag().is_set(ecf::Flag::ARCHIVED), "Archived flag not set on suite");
+    BOOST_CHECK_MESSAGE(suite->has_archive(), "Archived flag not set on family");
+    std::string suite_archive_path = suite->archive_path();
+    BOOST_CHECK_MESSAGE(fs::exists(suite_archive_path), "Archive path" << suite->archive_path() << " not created");
+    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Children of suite not removed after archive");
+
+    TestHelper::invokeRequest(&theDefs, Cmd_ptr(new DeleteCmd(suite->absNodePath())));
+    BOOST_CHECK_MESSAGE(!fs::exists(suite_archive_path), "Suite Archived file not removed after DeleteCmd");
+    BOOST_CHECK_MESSAGE(!fs::exists(family_archive_path), "Family Archived file not removed after DeleteCmd");
+}
+
+BOOST_AUTO_TEST_CASE(test_archive_and_restore_errors) {
+    cout << "Base:: ...test_archive_and_restore_errors\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_HOME ....
+    //  family f1
+    //     task t1
+
+    // We use Pid::unique_name, to allow multiple invocation of this test
+    Defs theDefs;
+    std::string ecf_home = File::test_data("libs/base/test", "libs/base");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_archive_and_restore_errors"));
+    family_ptr f1   = suite->add_family("f1");
+    f1->add_task("t1");
+
+    // FLAG ecf::Flag::ARCHIVED should be set, for restore to work
+    TestHelper::invokeFailureRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
+
+    // set  ecf::Flag::ARCHIVED, but now suite has children, the suite should have no children for restore
+    suite->flag().set(ecf::Flag::ARCHIVED);
+    TestHelper::invokeFailureRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
+
+    // remove the suite children, should no fail since the restore file is missing
+    f1->remove();
+    TestHelper::invokeFailureRequest(&theDefs, Cmd_ptr(new PathsCmd(PathsCmd::RESTORE, suite->absNodePath())));
+
+    /// Destroy singleton's to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_destroy_log4) {
+    Log::destroy();
+    fs::remove("test_add_log4.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestBase_main.cpp 5.13.0-1/libs/base/test/TestBase_main.cpp
--- 5.12.4-1/libs/base/test/TestBase_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestBase_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Base
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/base/test/TestClientHandleCmd.cpp 5.13.0-1/libs/base/test/TestClientHandleCmd.cpp
--- 5.12.4-1/libs/base/test/TestClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestClientHandleCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,369 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// The client handle commands do not change state & modify change number, hence need to bypass these checks
+static bool bypass_state_modify_change_check = false;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_ClientHandleCmd)
+
+BOOST_AUTO_TEST_CASE(test_add_log3) {
+    // create once for all test below, then remove at the end
+    Log::create("test_add_log3.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_CASE(test_client_handle_cmd_empty_server) {
+    cout << "Base:: ...test_client_handle_cmd_empty_server\n";
+
+    std::vector<std::string> suite_names;
+    suite_names.reserve(5);
+    for (int i = 0; i < 5; i++)
+        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
+
+    defs_ptr new_defs = Defs::create();
+
+    // Register new handle on an EMPTY server. register the suite
+    for (const auto& suite_name : suite_names) {
+        std::vector<std::string> names;
+        names.push_back(suite_name);
+        TestHelper::invokeRequest(
+            new_defs.get(), Cmd_ptr(new ClientHandleCmd(0, names, false)), bypass_state_modify_change_check);
+    }
+
+    // We should have 5 handle, 1,2,3,4,5
+
+    // std::cout << "   expect failure when dropping(DROP_USER) on handle that does not exist, handle 6" << endl;
+    TestHelper::invokeFailureRequest(new_defs.get(), Cmd_ptr(new ClientHandleCmd(6)));
+
+    // std::cout << "   expect failure for auto add,on handle that does not exist, handle 6" << endl;
+    TestHelper::invokeFailureRequest(new_defs.get(), Cmd_ptr(new ClientHandleCmd(6, true /* auto add */)));
+
+    // std::cout << "   expect failure for ADD,on handle that does not exist, handle 6" << endl;
+    TestHelper::invokeFailureRequest(new_defs.get(),
+                                     Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::ADD)));
+
+    // std::cout << "   expect failure for REMOVE, on handle that does not exist, handle 6" << endl;
+    TestHelper::invokeFailureRequest(new_defs.get(),
+                                     Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::REMOVE)));
+
+    for (int handle = 1; handle < 6; handle++) {
+
+        // std::cout << "   expect success for dropping handle " << handle << endl;
+        TestHelper::invokeRequest(
+            new_defs.get(), Cmd_ptr(new ClientHandleCmd(handle)), bypass_state_modify_change_check);
+
+        // std::cout << "   expect failure for auto add,on handle that does not exist, handle " << handle << endl;
+        TestHelper::invokeFailureRequest(new_defs.get(), Cmd_ptr(new ClientHandleCmd(6, true /* auto add */)));
+
+        // std::cout << "   expect failure for ADD,on handle that does not exist, handle " << handle <<endl;
+        TestHelper::invokeFailureRequest(new_defs.get(),
+                                         Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::ADD)));
+
+        // std::cout << "   expect failure for REMOVE, on handle that does not exist, handle " << handle << "\n" <<
+        // endl;
+        TestHelper::invokeFailureRequest(new_defs.get(),
+                                         Cmd_ptr(new ClientHandleCmd(6, suite_names, ClientHandleCmd::REMOVE)));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_client_handle_cmd_register_and_drop) {
+    cout << "Base:: ...test_client_handle_cmd_register_and_drop\n";
+
+    std::vector<std::string> suite_names;
+    suite_names.reserve(6);
+    for (int i = 0; i < 5; i++)
+        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
+
+    Defs defs;
+    for (const auto& suite_name : suite_names)
+        defs.addSuite(Suite::create(suite_name));
+
+    // Register new handle
+    for (size_t j = 0; j < suite_names.size(); j++) {
+        std::vector<std::string> names;
+        names.push_back(suite_names[j]);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new ClientHandleCmd(0, names, false)), bypass_state_modify_change_check);
+        BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == j + 1,
+                            "Expected " << j + 1 << " Client suites but found "
+                                        << defs.client_suite_mgr().clientSuites().size());
+    }
+
+    // Drop the handles. take a copy, since we about to delete clientSuites
+    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
+    for (auto& clientSuite : clientSuites) {
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new ClientHandleCmd(clientSuite.handle())), bypass_state_modify_change_check);
+    }
+    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().empty(),
+                        "Expected  no client handles, but found " << defs.client_suite_mgr().clientSuites().size());
+}
+
+BOOST_AUTO_TEST_CASE(test_client_handle_cmd_register__with_drop) {
+    cout << "Base:: ...test_client_handle_cmd_register_with_drop\n";
+
+    std::vector<std::string> suite_names;
+    suite_names.reserve(6);
+    for (int i = 0; i < 5; i++)
+        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
+
+    Defs defs;
+    for (const auto& suite_name : suite_names)
+        defs.addSuite(Suite::create(suite_name));
+
+    // Register new handle
+    for (size_t j = 0; j < suite_names.size(); j++) {
+        std::vector<std::string> names;
+        names.push_back(suite_names[j]);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new ClientHandleCmd(0, names, false)), bypass_state_modify_change_check);
+        BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == j + 1,
+                            "Expected " << j + 1 << " Client suites but found "
+                                        << defs.client_suite_mgr().clientSuites().size());
+    }
+
+    // Register new handle and drop existing handle at the same time. The number of registered should stay the same
+    for (size_t j = 0; j < suite_names.size(); j++) {
+        std::vector<std::string> names;
+        names.push_back(suite_names[j]);
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new ClientHandleCmd(j + 1, names, false)), bypass_state_modify_change_check);
+        BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == suite_names.size(),
+                            "Expected " << suite_names.size() << " Client suites but found "
+                                        << defs.client_suite_mgr().clientSuites().size());
+    }
+
+    // Drop the handles. take a copy, since we about to delete clientSuites
+    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
+    for (auto& clientSuite : clientSuites) {
+        TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new ClientHandleCmd(clientSuite.handle())), bypass_state_modify_change_check);
+    }
+    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().empty(),
+                        "Expected  no client handles, but found " << defs.client_suite_mgr().clientSuites().size());
+}
+
+BOOST_AUTO_TEST_CASE(test_client_handle_cmd_auto_add) {
+    cout << "Base:: ...test_client_handle_cmd_auto_add\n";
+
+    std::vector<std::string> suite_names;
+    suite_names.reserve(6);
+    for (int i = 0; i < 5; i++)
+        suite_names.push_back("s" + std::to_string(i));
+
+    Defs defs;
+    for (const auto& suite_name : suite_names)
+        defs.addSuite(Suite::create(suite_name));
+
+    // Register new handle, with no suites, but with auto add new suites
+    std::vector<std::string> names;
+    TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new ClientHandleCmd(0, names, false /* auto_add */)), bypass_state_modify_change_check);
+    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == 1,
+                        "Expected 1 Client suites but found " << defs.client_suite_mgr().clientSuites().size());
+    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().front().auto_add_new_suites() == false,
+                        "Expected auto add to be disabled");
+
+    // Now enable auto add
+    TestHelper::invokeRequest(
+        &defs,
+        Cmd_ptr(new ClientHandleCmd(defs.client_suite_mgr().clientSuites().front().handle(), true /* auto add */)),
+        bypass_state_modify_change_check);
+    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().front().auto_add_new_suites(),
+                        "Expected auto add to be enabled");
+
+    // now add new suite, they should get added to the new client handles
+    names.clear();
+    for (int i = 5; i < 10; i++)
+        names.push_back("s" + std::to_string(i));
+    for (const auto& name : names)
+        defs.addSuite(Suite::create(name));
+
+    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
+    std::vector<std::string> handle_suites;
+    clientSuites[0].suites(handle_suites);
+    BOOST_CHECK_MESSAGE(handle_suites == names, "Expected suites to be automatically added to our handle");
+
+    // Delete the suite s5,s6,s7,s8,s9
+    for (int i = 5; i < 10; i++) {
+        suite_ptr suite = defs.findSuite("s" + std::to_string(i));
+        BOOST_CHECK_MESSAGE(suite.get(), "Failed to find suite s" << i);
+        suite->remove();
+    }
+
+    { // Even when suites have been removed, we still keep registered suite
+      // These have to be explicitly deleted by the user
+        std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
+        std::vector<std::string> handle_suites;
+        clientSuites[0].suites(handle_suites);
+        BOOST_CHECK_MESSAGE(handle_suites.size() == 5,
+                            "Expected handle to have 5 suites but found" << handle_suites.size());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_client_handle_cmd_add_remove) {
+    cout << "Base:: ...test_client_handle_cmd_add_remove\n";
+
+    std::vector<std::string> suite_names;
+    suite_names.reserve(6);
+    for (int i = 0; i < 5; i++)
+        suite_names.push_back("s" + std::to_string(i));
+
+    defs_ptr defs = Defs::create();
+    for (const auto& suite_name : suite_names)
+        defs->addSuite(Suite::create(suite_name));
+    std::vector<std::string> empty_vec;
+
+    // Register new handle, with no suites,
+    {
+        TestHelper::invokeRequest(
+            defs.get(), Cmd_ptr(new ClientHandleCmd(0, empty_vec, false)), bypass_state_modify_change_check);
+        BOOST_CHECK_MESSAGE(defs->client_suite_mgr().clientSuites().size() == 1,
+                            "Expected 1 Client suites but found " << defs->client_suite_mgr().clientSuites().size());
+        BOOST_CHECK_MESSAGE(!defs->client_suite_mgr().handle_changed(1),
+                            "Expected No handle change, when no real suites added");
+
+        defs_ptr created_defs = defs->client_suite_mgr().create_defs(1, defs); // clear the handle change
+        BOOST_CHECK_MESSAGE(created_defs, "Expected defs to be created");
+        BOOST_CHECK_MESSAGE(created_defs->suiteVec().empty(), "Expected no suites");
+        BOOST_CHECK_MESSAGE(!defs->client_suite_mgr().handle_changed(1),
+                            "Expected handle changed to be cleared after create_defs()");
+    }
+
+    // Now add suites to the existing handle, then check they match.
+    std::vector<std::string> handle_suites;
+    {
+        TestHelper::invokeRequest(defs.get(),
+                                  Cmd_ptr(new ClientHandleCmd(defs->client_suite_mgr().clientSuites().front().handle(),
+                                                              suite_names,
+                                                              ClientHandleCmd::ADD)),
+                                  bypass_state_modify_change_check);
+        defs->client_suite_mgr().clientSuites().front().suites(handle_suites);
+        BOOST_CHECK_MESSAGE(handle_suites == suite_names, "Expected suites to be added to our handle");
+        BOOST_CHECK_MESSAGE(defs->client_suite_mgr().handle_changed(1),
+                            "Expected handle changed when adding new suites to our handle");
+
+        defs_ptr created_defs = defs->client_suite_mgr().create_defs(1, defs); // clear the handle change
+        BOOST_CHECK_MESSAGE(created_defs, "Expected defs to be created");
+        BOOST_CHECK_MESSAGE(created_defs.get() == defs.get(),
+                            "When *ALL* suites registered, the returned defs should be the same");
+        BOOST_CHECK_MESSAGE(created_defs->suiteVec().size() == suite_names.size(), "Not all suites created");
+    }
+
+    // Now remove the suites from the handle
+    {
+        TestHelper::invokeRequest(defs.get(),
+                                  Cmd_ptr(new ClientHandleCmd(defs->client_suite_mgr().clientSuites().front().handle(),
+                                                              suite_names,
+                                                              ClientHandleCmd::REMOVE)),
+                                  bypass_state_modify_change_check);
+        handle_suites.clear();
+        defs->client_suite_mgr().clientSuites().front().suites(handle_suites);
+        BOOST_CHECK_MESSAGE(handle_suites == empty_vec,
+                            "Expected no suites in our handle but found " << handle_suites.size());
+        BOOST_CHECK_MESSAGE(defs->client_suite_mgr().handle_changed(1),
+                            "Expected handle changed when adding new removing suites");
+
+        defs_ptr created_defs = defs->client_suite_mgr().create_defs(1, defs); // clear the handle change
+        BOOST_CHECK_MESSAGE(created_defs, "Expected defs to be created");
+        BOOST_CHECK_MESSAGE(created_defs->suiteVec().empty(), "Expected no suites");
+        BOOST_CHECK_MESSAGE(!defs->client_suite_mgr().handle_changed(1),
+                            "Expected handle changed to be cleared after create_defs()");
+    }
+}
+
+static bool check_ordering(Defs& defs) {
+    // make sure order of suites in handles is the same as server order
+    const std::vector<suite_ptr>& suite_vec = defs.suiteVec();
+    std::vector<std::string> suite_names;
+    for (const auto& i : suite_vec)
+        suite_names.push_back(i->name());
+
+    // Drop the handles. take a copy, since we about to delete clientSuites
+    std::vector<ecf::ClientSuites> clientSuites = defs.client_suite_mgr().clientSuites();
+    for (auto& clientSuite : clientSuites) {
+        std::vector<std::string> names;
+        names.reserve(6);
+        clientSuite.suites(names);
+        if (names != suite_names)
+            return false;
+    }
+    return true;
+}
+
+BOOST_AUTO_TEST_CASE(test_client_handle_suite_ordering) {
+    cout << "Base:: ...test_client_handle_suite_ordering\n";
+    // ensure order of suites in a handle is the same as server suites
+
+    std::vector<std::string> suite_names;
+    suite_names.reserve(6);
+    for (int i = 0; i < 5; i++)
+        suite_names.push_back("s" + ecf::convert_to<std::string>(i));
+
+    Defs defs;
+    for (const auto& suite_name : suite_names)
+        defs.addSuite(Suite::create(suite_name));
+
+    // Register 3 new handle
+    TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, true)), bypass_state_modify_change_check);
+    TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, true)), bypass_state_modify_change_check);
+    TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, true)), bypass_state_modify_change_check);
+    BOOST_CHECK_MESSAGE(defs.client_suite_mgr().clientSuites().size() == 3,
+                        "Expected 3 Client suites but found " << defs.client_suite_mgr().clientSuites().size());
+
+    // After registration make sure ordering is the same
+    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after registration of handles");
+
+    // Check ordering after OrderNodeCmd
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::DOWN)));
+    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::DOWN");
+
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::UP)));
+    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::UP");
+
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::BOTTOM)));
+    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::BOTTOM");
+
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::TOP)));
+    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::TOP");
+
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new OrderNodeCmd("/s0", NOrder::ALPHA)));
+    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after NOrder::ALPHA");
+
+    // check ordering after adding new suites, notice we auto add new suites to all our handles
+    defs.add_suite("sxx");
+    BOOST_CHECK_MESSAGE(check_ordering(defs), "Ordering not preserved after adding a new suite");
+}
+
+BOOST_AUTO_TEST_CASE(test_destroy_log3) {
+    Log::destroy();
+    fs::remove("test_add_log3.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestCmd.cpp 5.13.0-1/libs/base/test/TestCmd.cpp
--- 5.12.4-1/libs/base/test/TestCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,128 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/task/AbortCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_Cmd)
+
+BOOST_AUTO_TEST_CASE(test_simple_cmd) {
+    cout << "Base:: ...test_simple_cmd\n";
+    TestLog test_log("test_simple_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    // Create the defs file. Note that the default ECF_TRIES = 3
+    //   suite suite
+    //     family f
+    //       task t1
+    //       task t2
+    //     endfamily
+    //   endsuite
+    Defs defs;
+    string suite_f_t1     = "suite/f/t1";
+    std::string suitename = "suite";
+    family_ptr f          = Family::create("f");
+    task_ptr t1           = Task::create("t1");
+    task_ptr t2           = Task::create("t2");
+    suite_ptr s           = Suite::create(suitename);
+    {
+        f->addTask(t1);
+        f->addTask(t2);
+        s->addFamily(f);
+        defs.addSuite(s);
+    }
+
+    // ***********************************************************************
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename, false)));
+        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
+        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
+        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
+        BOOST_CHECK_MESSAGE(t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(t2->state()));
+    }
+
+    // ***********************************************************************
+    // Create a request to abort  Node: suite1/f/t1, Since the default ECF_TRIES is > 0, the aborted tasks
+    // should be re-submitted, until the task try number > ECF_TRIES
+    {
+        std::string varValue;
+        if (t1->findParentUserVariableValue(Str::ECF_TRIES(), varValue)) {
+            auto ecf_tries = ecf::convert_to<int>(varValue);
+            while (true) {
+                TestHelper::invokeRequest(
+                    &defs,
+                    Cmd_ptr(new AbortCmd(
+                        suite_f_t1, Submittable::DUMMY_JOBS_PASSWORD(), Submittable::DUMMY_PROCESS_OR_REMOTE_ID(), 1)));
+                TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
+                BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
+                                    "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
+                BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
+                                    "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
+                BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
+                                    "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
+                // std::cout << "tryNo = " << t1->try_no() << " ECF_TRIES = " <<  ecf_tries << "\n";
+                if (t1->try_no() == ecf_tries)
+                    break;
+            }
+
+            /// Since we have exceeded the try number, abort should mean abort
+            TestHelper::invokeRequest(
+                &defs,
+                Cmd_ptr(new AbortCmd(
+                    suite_f_t1, Submittable::DUMMY_JOBS_PASSWORD(), Submittable::DUMMY_PROCESS_OR_REMOTE_ID(), 1)));
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)), false);
+            BOOST_CHECK_MESSAGE(t1->state() == NState::ABORTED,
+                                "expected state NState::ABORTED, but found to be " << NState::toString(t1->state()));
+            BOOST_CHECK_MESSAGE(f->state() == NState::ABORTED,
+                                "expected state NState::ABORTED, but found to be " << NState::toString(f->state()));
+            BOOST_CHECK_MESSAGE(s->state() == NState::ABORTED,
+                                "expected state NState::ABORTED, but found to be " << NState::toString(s->state()));
+        }
+    }
+
+    {
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestDeleteNodeCmd.cpp 5.13.0-1/libs/base/test/TestDeleteNodeCmd.cpp
--- 5.12.4-1/libs/base/test/TestDeleteNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestDeleteNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,269 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MockServer.hpp"
+#include "MyDefsFixture.hpp"
+#include "ecflow/base/cts/user/DeleteCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_DeleteNodeCmd)
+
+BOOST_AUTO_TEST_CASE(test_delete_node_cmd) {
+    cout << "Base:: ...test_delete_node_cmd\n";
+    TestLog test_log(
+        "test_delete_node_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    MyDefsFixture fixtureDef;
+    MockServer mockServer(&fixtureDef.defsfile_);
+
+    // IMPORTANT: ******************************************************************************
+    // If the DeleteCmd is given a EMPTY list of paths, it will delete *EVERYTHING*
+    // *****************************************************************************************
+
+    // Delete all Aliases
+    {
+        std::vector<alias_ptr> vec;
+        fixtureDef.defsfile_.get_all_aliases(vec);
+        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 aliases but found " << vec.size());
+
+        std::vector<std::string> paths;
+        paths.reserve(vec.size());
+        for (alias_ptr t : vec) {
+            paths.push_back(t->absNodePath());
+        }
+
+        size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
+        BOOST_CHECK_MESSAGE(!paths.empty(), "Expected paths to be specified, *OTHERWISE* we delete all nodes");
+        DeleteCmd cmd(paths);
+        cmd.setup_user_authentification();
+        STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+        BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete aliases");
+        {
+            // ECFLOW-434
+            const std::vector<std::string>& edit_history = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
+            size_t edit_history_size_after               = edit_history_size_before + paths.size();
+            if (edit_history_size_after > Defs::max_edit_history_size_per_node())
+                edit_history_size_after = Defs::max_edit_history_size_per_node();
+            BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
+                                "Expected   " << edit_history_size_after << " edit history but found "
+                                              << edit_history.size());
+        }
+
+        std::vector<alias_ptr> afterDeleteVec;
+        fixtureDef.defsfile_.get_all_aliases(afterDeleteVec);
+        BOOST_REQUIRE_MESSAGE(afterDeleteVec.empty(),
+                              "Expected all aliases to be deleted but found " << afterDeleteVec.size());
+    }
+
+    // Delete all tasks
+    {
+        std::vector<Task*> vec;
+        fixtureDef.defsfile_.getAllTasks(vec);
+        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 tasks but found " << vec.size());
+
+        std::vector<std::string> paths;
+        paths.reserve(vec.size());
+        for (Task* t : vec) {
+            paths.push_back(t->absNodePath());
+        }
+
+        BOOST_CHECK_MESSAGE(!paths.empty(), "Expected paths to be specified, *OTHERWISE* we delete all nodes");
+        size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
+        DeleteCmd cmd(paths);
+        cmd.setup_user_authentification();
+        STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+        BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete tasks");
+        {
+            const std::vector<std::string>& edit_history = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
+            size_t edit_history_size_after               = edit_history_size_before + paths.size();
+            if (edit_history_size_after > Defs::max_edit_history_size_per_node())
+                edit_history_size_after = Defs::max_edit_history_size_per_node();
+            BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
+                                "Expected   " << edit_history_size_after << " edit history but found "
+                                              << edit_history.size());
+        }
+
+        std::vector<Task*> afterDeleteVec;
+        fixtureDef.defsfile_.getAllTasks(afterDeleteVec);
+        BOOST_REQUIRE_MESSAGE(afterDeleteVec.empty(),
+                              "Expected all tasks to be deleted but found " << afterDeleteVec.size());
+    }
+
+    // Delete all Families
+    {
+        // DONT use getAllFamilies as this will return hierarchical families
+        // we don't want to delete families twice
+        //		std::vector<Family*> vec;
+        //		fixtureDef.defsfile_.getAllFamilies(vec);
+    }
+
+    // Delete all Suites
+    {
+        std::vector<suite_ptr> vec = fixtureDef.defsfile_.suiteVec();
+        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 Suites but found " << vec.size());
+        for (suite_ptr s : vec) {
+            {
+                // Delete all Families
+                // *********************************************************************************************
+                // **EXPLICITLY** check for empty paths otherwise we can end up deleting ALL suites accidentally
+                // if DeleteCmd is given an empty list, we will delete all nodes including the suites
+                // *********************************************************************************************
+                std::vector<family_ptr> familyVec = s->familyVec();
+                // 	DONT USE:
+                //        for(family_ptr f: s->familyVec()) {
+                //  As with this will invalidate the iterators.
+                std::vector<std::string> paths;
+                paths.reserve(vec.size());
+                for (family_ptr f : familyVec) {
+                    paths.push_back(f->absNodePath());
+                }
+
+                if (!paths.empty()) {
+                    size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
+                    DeleteCmd cmd(paths);
+                    cmd.setup_user_authentification();
+                    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+                    BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete families");
+                    BOOST_REQUIRE_MESSAGE(s->familyVec().empty(),
+                                          "Expected all Families to be deleted but found " << s->familyVec().size());
+                    {
+                        const std::vector<std::string>& edit_history =
+                            fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
+                        size_t edit_history_size_after = edit_history_size_before + paths.size();
+                        if (edit_history_size_after > Defs::max_edit_history_size_per_node())
+                            edit_history_size_after = Defs::max_edit_history_size_per_node();
+                        BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
+                                            "Expected   " << edit_history_size_after << " edit history but found "
+                                                          << edit_history.size());
+                    }
+                }
+            }
+
+            // delete the suite
+            size_t edit_history_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
+            std::string absNodePath         = s->absNodePath();
+            DeleteCmd cmd(absNodePath);
+            cmd.setup_user_authentification();
+            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+            BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete suite at path " << absNodePath);
+            {
+                const std::vector<std::string>& edit_history = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH());
+                size_t edit_history_size_after               = edit_history_size_before + 1;
+                if (edit_history_size_after > Defs::max_edit_history_size_per_node())
+                    edit_history_size_after = Defs::max_edit_history_size_per_node();
+                BOOST_CHECK_MESSAGE(edit_history.size() == edit_history_size_after,
+                                    "Expected   " << edit_history_size_after << " edit history but found "
+                                                  << edit_history.size());
+            }
+        }
+
+        BOOST_REQUIRE_MESSAGE(fixtureDef.defsfile_.suiteVec().empty(),
+                              "Expected all Suites to be deleted but found " << fixtureDef.defsfile_.suiteVec().size());
+    }
+
+    {
+        // Clear edit history
+        fixtureDef.defsfile_.clear_edit_history();
+        BOOST_CHECK_MESSAGE(fixtureDef.defsfile_.get_edit_history().size() == 0, "Expected edit history to be empty");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_delete_node_edit_history_ECFLOW_1684) {
+    cout << "Base:: ...test_delete_node_edit_history_ECFLOW_1684\n";
+
+    // This test will ensure that if a suite/family node is deleted, we *remove* any *OLD* edit history associated
+    // with the node, AND and of its children
+
+    // Create log file for the commands to work. auto destroy at end of scope
+    TestLog test_log("test_delete_node_edit_history.log");
+
+    MyDefsFixture fixtureDef;
+    MockServer mockServer(&fixtureDef.defsfile_);
+
+    // suspend all suites and tasks, then check we have some edit history
+    {
+        size_t edit_history_root_size_before = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
+        size_t edit_history_before           = fixtureDef.defsfile_.get_edit_history().size();
+        BOOST_CHECK_MESSAGE(edit_history_root_size_before == 0,
+                            "Expected edit_history_root_size_before == 0 but found " << edit_history_root_size_before);
+        BOOST_CHECK_MESSAGE(edit_history_before == 0,
+                            "Expected edit_history_before == 0 but found " << edit_history_before);
+
+        std::vector<Task*> task_vec;
+        fixtureDef.defsfile_.getAllTasks(task_vec);
+        BOOST_CHECK_MESSAGE(task_vec.size() > 0, "Expected > 0 tasks but found " << task_vec.size());
+        std::vector<std::string> paths;
+        paths.reserve(task_vec.size());
+        for (Task* t : task_vec) {
+            paths.push_back(t->absNodePath());
+        }
+        BOOST_CHECK_MESSAGE(!paths.empty(), "Expected paths to be specified, *OTHERWISE* we delete all nodes");
+
+        std::vector<suite_ptr> suite_vec = fixtureDef.defsfile_.suiteVec();
+        for (suite_ptr s : suite_vec) {
+            paths.push_back(s->absNodePath());
+        }
+
+        PathsCmd cmd(PathsCmd::SUSPEND, paths);
+        cmd.setup_user_authentification();
+        STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+        BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to suspend tasks");
+        {
+            size_t edit_history_root_size_after = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
+            size_t edit_history_after           = fixtureDef.defsfile_.get_edit_history().size();
+
+            BOOST_CHECK_MESSAGE(edit_history_root_size_after == 0,
+                                "Expected edit_history_root_size_after == 0 but found "
+                                    << edit_history_root_size_after);
+            BOOST_CHECK_MESSAGE(edit_history_after == paths.size(),
+                                "Expected edit_history_after to be same number of suspended tasks and suites("
+                                    << paths.size() << ") but found " << edit_history_after);
+        }
+    }
+
+    // Delete all Suites, this should delete edit history associated with suites and child tasks
+    {
+        std::vector<suite_ptr> vec = fixtureDef.defsfile_.suiteVec();
+        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 Suites but found " << vec.size());
+        for (suite_ptr s : vec) {
+            std::string absNodePath = s->absNodePath();
+            DeleteCmd cmd(absNodePath);
+            cmd.setup_user_authentification();
+            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+            BOOST_CHECK_MESSAGE(returnCmd->ok(), "Failed to delete suite at path " << absNodePath);
+        }
+        BOOST_REQUIRE_MESSAGE(fixtureDef.defsfile_.suiteVec().empty(),
+                              "Expected all Suites to be deleted but found " << fixtureDef.defsfile_.suiteVec().size());
+
+        size_t edit_history_root_size_after = fixtureDef.defsfile_.get_edit_history(Str::ROOT_PATH()).size();
+        size_t edit_history_after           = fixtureDef.defsfile_.get_edit_history().size();
+
+        BOOST_CHECK_MESSAGE(edit_history_root_size_after == vec.size(),
+                            "Expected edit_history size of root node to be same as number of deleted suites("
+                                << vec.size() << ") but found " << edit_history_root_size_after);
+        BOOST_CHECK_MESSAGE(edit_history_after == 1,
+                            "Expected edit_history_after == 1 to *ONLY* have root node, but found "
+                                << edit_history_after << "\n"
+                                << fixtureDef.defsfile_.dump_edit_history());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestForceCmd.cpp 5.13.0-1/libs/base/test/TestForceCmd.cpp
--- 5.12.4-1/libs/base/test/TestForceCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestForceCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1104 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp> // IWYU pragma: keep
+
+#include "MockServer.hpp"
+#include "MyDefsFixture.hpp"
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/ForceCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/core/PrintStyle.hpp" // IWYU pragma: keep
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_ForceCmd)
+
+static defs_ptr create_defs() {
+    defs_ptr theDefs = Defs::create();
+    suite_ptr suite  = theDefs->add_suite("s1");
+    family_ptr f1    = suite->add_family("f1");
+    task_ptr t1      = f1->add_task("t1");
+    t1->addTime(TimeAttr(10, 30));
+    t1->add_alias_only();
+    task_ptr t2 = f1->add_task("t2");
+    t2->add_alias_only();
+    return theDefs;
+}
+
+BOOST_AUTO_TEST_CASE(test_add_log2) {
+    // create once for all test below, then remove at the end
+    Log::create("test_add_log2.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_CASE(test_force_cmd) {
+    cout << "Base:: ...test_force_cmd\n";
+
+    defs_ptr the_defs = create_defs();
+    the_defs->beginAll();
+    node_ptr s1 = the_defs->findAbsNode("/s1");
+    node_ptr f1 = the_defs->findAbsNode("/s1/f1");
+    node_ptr t1 = the_defs->findAbsNode("/s1/f1/t1");
+    node_ptr t2 = the_defs->findAbsNode("/s1/f1/t2");
+
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
+    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
+
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t2->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t2, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(
+        !t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set since there are NO time depedencies");
+    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
+    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be NOT set");
+
+    the_defs->requeue();
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(s1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(s1, NState::COMPLETE);
+    TestHelper::test_state(f1, NState::COMPLETE);
+    TestHelper::test_state(t1, NState::COMPLETE);
+
+    Node::Requeue_args args(Node::Requeue_args::FULL,
+                            true /* reset repeats*/,
+                            0 /* clear_suspended_in_child_nodes */,
+                            false /* reset_next_time_slot_ */,
+                            true /* reset relative duration */);
+    s1->requeue(args);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
+    BOOST_CHECK_MESSAGE(!t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
+    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
+    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear after requeue");
+
+    node_ptr alias = the_defs->findAbsNode("/s1/f1/t1/alias0");
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(alias->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(alias, NState::COMPLETE);
+}
+
+static void
+doForce(MockServer& mockServer, Node* fnode, const std::string& stateOrEvent, const std::vector<Node*>& nodes) {
+    ForceCmd cmd(fnode->absNodePath(), stateOrEvent, true /*recursive */, true /* set Repeat to last value */);
+    cmd.setup_user_authentification();
+    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force for node " << fnode->debugNodePath());
+
+    for (auto node : nodes) {
+        if (NState::isValid(stateOrEvent)) {
+            NState::State state = NState::toState(stateOrEvent);
+
+            // Force Cmd recursive does **NOT** apply to aliases.
+            if (node->isAlias()) {
+                // The alias should still be in default QUEUED state
+                BOOST_CHECK_MESSAGE(node->state() == NState::QUEUED,
+                                    "Expected state NState::QUEUED for alias but found "
+                                        << NState::toString(node->state()) << " for alias " << node->debugNodePath());
+            }
+            else {
+                BOOST_CHECK_MESSAGE(node->state() == state,
+                                    "Expected state " << NState::toString(state) << " but found "
+                                                      << NState::toString(node->state()) << " for node "
+                                                      << node->debugNodePath());
+            }
+        }
+        else
+            BOOST_CHECK_MESSAGE(false, "oops");
+
+        if (!(node->repeat().empty())) {
+            BOOST_CHECK_MESSAGE(!node->repeat().valid(), "Expected repeat to be set to last value. ie in valid");
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_force_cmd_recursive) {
+    cout << "Base:: ...test_force_cmd_recursive\n";
+
+    defs_ptr the_defs = create_defs();
+    node_ptr suite    = the_defs->findAbsNode("/s1");
+    std::vector<Node*> nodes;
+    suite->getAllNodes(nodes);
+
+    MockServer mockServer(the_defs);
+    std::vector<std::string> all_states = NState::allStates();
+    for (const std::string& state : all_states) {
+        doForce(mockServer, suite.get(), state, nodes);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_force_cmd_bubbles_up_state_changes) {
+    cout << "Base:: ...test_force_cmd_bubbles_up_state_changes\n";
+
+    defs_ptr the_defs = create_defs();
+    std::vector<Node*> nodes;
+    std::vector<Task*> tasks;
+    the_defs->getAllNodes(nodes);
+    the_defs->getAllTasks(tasks);
+    node_ptr suite = the_defs->findAbsNode("/s1");
+
+    MockServer mockServer(the_defs);
+
+    std::vector<std::string> all_states = NState::allStates();
+    for (const std::string& state : all_states) {
+
+        // 		cout << "Setting all tasks to state " << state << "\n";
+        for (Task* task : tasks) {
+            ForceCmd cmd(task->absNodePath(), state, false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force for node " << task->debugNodePath());
+        }
+
+        // Check that state change set on task has bubbled up to the suite.
+        // Since the state has been set on *all* tasks
+        // 		cout << "Suite state = " << NState::toString(suite->state()) << "\n";
+        NState::State expected_state = NState::toState(state);
+        BOOST_CHECK_MESSAGE(suite->state() == expected_state,
+                            "Expected state " << NState::toString(expected_state) << " but found "
+                                              << NState::toString(suite->state()) << " for suite "
+                                              << suite->debugNodePath());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_force_cmd_alias_does_not_bubble_up_state_changes) {
+    cout << "Base:: ...test_force_cmd_alias_does_not_bubble_up_state_changes\n";
+
+    defs_ptr the_defs = create_defs();
+    std::vector<Node*> nodes;
+    std::vector<alias_ptr> aliases;
+    the_defs->getAllNodes(nodes);
+    the_defs->get_all_aliases(aliases);
+    node_ptr suite = the_defs->findAbsNode("/s1");
+
+    // initialize by setting all nodes to state QUEUED
+    for (Node* n : nodes) {
+        n->set_state(NState::QUEUED);
+    }
+
+    MockServer mockServer(the_defs);
+    std::vector<std::string> all_states = NState::allStates();
+    for (const std::string& state : all_states) {
+
+        for (alias_ptr alias : aliases) {
+            ForceCmd cmd(alias->absNodePath(), state, false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force for alias " << alias->debugNodePath());
+        }
+
+        // Check that state change set on alias has *NOT* bubbled up to the suite.
+        BOOST_CHECK_MESSAGE(suite->state() == NState::QUEUED,
+                            "Expected suite to have state QUEUED but found " << NState::toString(suite->state()));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_force_events) {
+    cout << "Base:: ...test_force_events\n";
+
+    MyDefsFixture fixtureDef;
+    MockServer mockServer(&fixtureDef.defsfile_);
+
+    node_ptr suite = fixtureDef.fixtureDefsFile().findAbsNode("/suiteName");
+    BOOST_REQUIRE_MESSAGE(suite.get(), "Could not find suite");
+    std::vector<Node*> nodes;
+    suite->getAllNodes(nodes);
+
+    /// Set and clear events
+    for (Node* node : nodes) {
+        for (const Event& e : node->events()) {
+            std::string path = node->absNodePath() + ":" + e.name_or_number();
+            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force event for node " << node->debugNodePath());
+        }
+        for (const Event& e : node->events()) {
+            BOOST_CHECK_MESSAGE(e.value(), "Event not set as expected for node " << node->debugNodePath());
+        }
+    }
+    for (Node* node : nodes) {
+        for (const Event& e : node->events()) {
+            std::string path = node->absNodePath() + ":" + e.name_or_number();
+            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+            BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to force event for node " << node->debugNodePath());
+        }
+        for (const Event& e : node->events()) {
+            BOOST_CHECK_MESSAGE(!e.value(), "Event not cleared as expected for node " << node->debugNodePath());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_force_events_errors) {
+    cout << "Base:: ...test_force_events_errors\n";
+
+    MyDefsFixture fixtureDef;
+    MockServer mockServer(&fixtureDef.defsfile_);
+
+    node_ptr suite = fixtureDef.fixtureDefsFile().findAbsNode("/suiteName");
+    BOOST_REQUIRE_MESSAGE(suite.get(), "Could not find suite");
+    std::vector<Node*> nodes;
+    suite->getAllNodes(nodes);
+
+    /// Make a path that does not exist
+    for (Node* node : nodes) {
+        for (const Event& e : node->events()) {
+            std::string path = node->absNodePath() + "/path/doesnot/exist" + ":" + e.name_or_number();
+            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
+        }
+    }
+    for (Node* node : nodes) {
+        for (const Event& e : node->events()) {
+            std::string path = node->absNodePath() + "/path/doesnot/exist" + ":" + e.name_or_number();
+            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
+        }
+    }
+
+    /// Make path that does not contain a event
+    for (Node* node : nodes) {
+        if (node->events().empty()) {
+            std::string path = node->absNodePath();
+            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
+        }
+    }
+    for (Node* node : nodes) {
+        if (node->events().empty()) {
+            std::string path = node->absNodePath();
+            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
+        }
+    }
+
+    /// Make a event that does not exist
+    for (Node* node : nodes) {
+        for (const Event& e : node->events()) {
+            std::string path = node->absNodePath() + ":" + e.name_or_number() + "made_up";
+            ForceCmd cmd(path, Event::SET(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
+        }
+    }
+    for (Node* node : nodes) {
+        for (const Event& e : node->events()) {
+            std::string path = node->absNodePath() + ":" + e.name_or_number() + "made_up";
+            ForceCmd cmd(path, Event::CLEAR(), false /*recursive */, false /* set Repeat to last value */);
+            cmd.setup_user_authentification();
+            BOOST_REQUIRE_THROW(cmd.handleRequest(&mockServer), std::runtime_error);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive) {
+    // This test is custom. When the user interactively forces a node to the
+    // complete state, and that node has pending time activities. The default
+    // behaviour, is the node is re-queued again, and hence the propagation up the
+    // node tree does not happen. This is test checks that the node does *not* exhibit
+    // this functionality. What we want is that task is set to complete, without
+    // forcing a re-queue, this is then propagated up the node tree. Which forces the
+    // family to complete, and hence update the repeat variable.
+    cout << "Base:: ...test_force_interactive\n";
+
+    //   suite s1
+    //     family daily
+    //       repeat date YMD 20101215 20101217 1
+    //       task t1
+    //         time 11:30
+    //     endfamily
+    //   endsuite
+    // make sure time is set *before* 11:30, so that time dependency holds the task
+    defs_ptr the_defs = Defs::create();
+    suite_ptr suite   = Suite::create("s1");
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(1 /*hour*/, 0 /*minutes*/);
+    suite->addClock(clockAttr);
+    family_ptr f1 = Family::create("daily");
+    f1->addRepeat(RepeatDate("date", 20101215, 20101217));
+    task_ptr t1 = Task::create("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(11, 30)));
+    f1->addTask(t1);
+    suite->addFamily(f1);
+    the_defs->addSuite(suite);
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, before test");
+    BOOST_CHECK_MESSAGE(!suite->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_REQUIRE_MESSAGE(f1->repeat().value() == 20101215,
+                          "Repeat value expected is 20101215 but found " << f1->repeat().value());
+
+    // Force the task t1 to complete state.
+    // Since task t1 is complete, the family 'daily' should complete.
+    // This will cause the repeat to take the next value anf forcing a requeue
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_REQUIRE_MESSAGE(f1->repeat().value() == 20101216,
+                          "Repeat value expected is 20101216 but found " << f1->repeat().value());
+
+    // Reque should mean flag was cleared + on suite should never get set, since flag is stopped at repeat
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, since task was REQUED");
+    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, since family was REQUED");
+    BOOST_CHECK_MESSAGE(!suite->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, since repeat should stop flag "
+                        "propagation up node tree");
+
+    // Force the task t1 to complete again
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_REQUIRE_MESSAGE(f1->repeat().value() == 20101217,
+                          "Repeat value expected is 20101217 but found " << f1->repeat().value());
+
+    // Do for the last time,
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    TestHelper::test_state(f1, NState::COMPLETE);
+    TestHelper::test_state(suite, NState::COMPLETE);
+
+    // Since we completed, without a requeue, we should expect flag to stay set.
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set, since there was no reque");
+
+    // Flag propagation should stop at the repeat
+    BOOST_CHECK_MESSAGE(!suite->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP *NOT* to be set");
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot) {
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user has a single time slot. We should stay complete and NOT requee
+    //
+    cout << "Base:: ...test_force_interactive_next_time_slot\n";
+
+    //   suite s1
+    //       task t1
+    //          time 10:00
+    //   endsuite
+    // make sure time is set *before* 10:00, so that time dependency holds the task
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    task_ptr t1     = suite->add_task("t1");
+    t1->addTime(TimeAttr(10, 0));
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
+    suite->addClock(clockAttr);
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
+
+    // since we started at 09:30 the next time slot should be 10:00
+    const TimeSlot& next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
+                        "Expected next time slot of 10:00 but found " << next_time_slot.toString());
+
+    // Force the task t1 to complete state. Since we had ONLY a SINGLE time dependency we should stay complete
+    // It should also advance the next time slot
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(!t1->timeVec().back().time_series().is_valid(), "Expected 10:00 time slot to have expired");
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+
+    // call again should, should be do difference, EXPECT no change, if its complete, seting complete, avoids another
+    // state change
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)),
+        false /*dont Check change numbers*/);
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(!t1->timeVec().back().time_series().is_valid(), "Expected 10:00 time slot to have expired");
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+
+    /// we will now Re-queue, Since the time is still 09:30, we expect next_time slot to be 10:00
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
+                        "After Re-queue, Expected next time slot of 10:00 but found " << next_time_slot.toString());
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_1) {
+    // Start TIME at 9:30
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user set of time slots. In this case the node should complete and then
+    // requee and miss the next time. If this is repeated, eventually we should reach the
+    // end of the time slot. In which case the node should *not* re-queue and stay complete
+    //
+    // When the node is then re-queued check that the time has been correctly reset.
+    cout << "Base:: ...test_force_interactive_next_time_slot_1\n";
+
+    //   suite s1
+    //       task t1
+    //          time 10:00
+    //          time 11:00
+    //          time 12:00
+    //          time 13:00
+    //   endsuite
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    task_ptr t1     = suite->add_task("t1");
+    t1->addTime(TimeAttr(10, 0));
+    t1->addTime(TimeAttr(11, 0));
+    t1->addTime(TimeAttr(12, 0));
+    t1->addTime(TimeAttr(13, 0));
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // *start* at 9:30
+    suite->addClock(clockAttr);
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
+
+    // get all the time attributes
+    const TimeSeries& ts_10 = t1->timeVec()[0].time_series();
+    const TimeSeries& ts_11 = t1->timeVec()[1].time_series();
+    const TimeSeries& ts_12 = t1->timeVec()[2].time_series();
+    const TimeSeries& ts_13 = t1->timeVec()[3].time_series();
+    BOOST_CHECK_MESSAGE(ts_10.is_valid(), "Expected time 10 to be valid since we started at 9:30 ");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
+
+    const TimeSlot& time_10 = t1->timeVec()[0].time_series().get_next_time_slot();
+    const TimeSlot& time_11 = t1->timeVec()[1].time_series().get_next_time_slot();
+    const TimeSlot& time_12 = t1->timeVec()[2].time_series().get_next_time_slot();
+    const TimeSlot& time_13 = t1->timeVec()[3].time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(time_10 == TimeSlot(10, 0),
+                        "Expected next time slot of 10:00 but found " << time_10.toString());
+    BOOST_CHECK_MESSAGE(time_11 == TimeSlot(11, 0),
+                        "Expected next time slot of 11:00 but found " << time_11.toString());
+    BOOST_CHECK_MESSAGE(time_12 == TimeSlot(12, 0),
+                        "Expected next time slot of 12:00 but found " << time_12.toString());
+    BOOST_CHECK_MESSAGE(time_13 == TimeSlot(13, 0),
+                        "Expected next time slot of 13:00 but found " << time_13.toString());
+
+    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired  ");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid.");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
+
+    // Repeat
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
+
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
+
+    // Repeat *last* time, since all times have expired, we expect task to stay complete.
+    // Addtionally since we have *not* re-queued the flag NO_REQUE_IF_SINGLE_TIME_DEP should have remained set
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_13.is_valid(), "Expected time 13 to be expired due to force cmd");
+
+    /// we will now Re-queue, Since the time is still 10:30, we expect valid from 11:00 and not 10:00
+    /// We should also have cleared NO_REQUE_IF_SINGLE_TIME_DEP
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(ts_10.is_valid(), "Expected time 10 to be in valid since we started clock at 9:30 ");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_2) {
+    // Start TIME at 9:30
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user has a time range. In this case the node should complete and then
+    // requee and miss the next time slot. If this is repeated, eventually we should reach the
+    // end of the time slot. In which case the node should *not* reque and stay complete
+    //
+    // When the node is then requeed check that the next time slot has been correctly reset.
+    cout << "Base:: ...test_force_interactive_next_time_slot_2\n";
+
+    //   suite s1
+    //       task t1
+    //          time 10:00 14:00 01:00
+    //   endsuite
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    task_ptr t1     = suite->add_task("t1");
+    t1->addTime(TimeAttr(TimeSlot(10, 0), TimeSlot(14, 0), TimeSlot(1, 0)));
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 99:30
+    suite->addClock(clockAttr);
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+
+    // since we started at 09:30 the next time slot should be 10:00
+    const TimeSlot& next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
+                        "Expected next time slot of 10:00 but found " << next_time_slot.toString());
+
+    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
+    // It should also advance the next time slot
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
+                        "Expected next time slot of 11:00 but found " << next_time_slot.toString());
+
+    // Repeat, to make sure next_time_slot is advanced
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(12, 0),
+                        "Expected next time slot of 12:00 but found " << next_time_slot.toString());
+
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(13, 0),
+                        "Expected next time slot of 13:00 but found " << next_time_slot.toString());
+
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(14, 0),
+                        "Expected next time slot of 14:00 but found " << next_time_slot.toString());
+
+    // Repeat, ** THIS time we have *exceeded* the time range, it should no longer requeue, and should stay complete
+    //         Additionally since there is no reque we expect NO_REQUE_IF_SINGLE_TIME_DEP to remain set
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(15, 0),
+                        "Expected next time slot of 15:00 but found " << next_time_slot.toString());
+
+    /// we will now Re-queue, Since the time is still 10:30, we expect next_time slot to be 11:00 and not 10:00
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
+                        "After Re-queue, Expected next time slot of 10:00 but found " << next_time_slot.toString());
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_3) {
+    // Start TIME at 10:30
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user set of time slots. In this case the node should complete and then
+    // requee and miss the next time. If this is repeated, eventually we should reach the
+    // end of the time slot. In which case the node should *not* re-queue and stay complete
+    //
+    // When the node is then re-queued check that the time has been correctly reset.
+    cout << "Base:: ...test_force_interactive_next_time_slot_3\n";
+
+    //   suite s1
+    //       task t1
+    //          time 10:00
+    //          time 11:00
+    //          time 12:00
+    //          time 13:00
+    //   endsuite
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    task_ptr t1     = suite->add_task("t1");
+    t1->addTime(TimeAttr(10, 0));
+    t1->addTime(TimeAttr(11, 0));
+    t1->addTime(TimeAttr(12, 0));
+    t1->addTime(TimeAttr(13, 0));
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(10 /*hour*/, 30 /*minutes*/); // *start* at 10:30
+    suite->addClock(clockAttr);
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
+
+    // get all the time attributes
+    const TimeSeries& ts_10 = t1->timeVec()[0].time_series();
+    const TimeSeries& ts_11 = t1->timeVec()[1].time_series();
+    const TimeSeries& ts_12 = t1->timeVec()[2].time_series();
+    const TimeSeries& ts_13 = t1->timeVec()[3].time_series();
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be in-valid since we started clock at 10:30 ");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 10:30");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 10:30");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 10:30");
+
+    const TimeSlot& time_10 = t1->timeVec()[0].time_series().get_next_time_slot();
+    const TimeSlot& time_11 = t1->timeVec()[1].time_series().get_next_time_slot();
+    const TimeSlot& time_12 = t1->timeVec()[2].time_series().get_next_time_slot();
+    const TimeSlot& time_13 = t1->timeVec()[3].time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(time_10 == TimeSlot(10, 0),
+                        "Expected next time slot of 10:00 but found " << time_10.toString());
+    BOOST_CHECK_MESSAGE(time_11 == TimeSlot(11, 0),
+                        "Expected next time slot of 11:00 but found " << time_11.toString());
+    BOOST_CHECK_MESSAGE(time_12 == TimeSlot(12, 0),
+                        "Expected next time slot of 12:00 but found " << time_12.toString());
+    BOOST_CHECK_MESSAGE(time_13 == TimeSlot(13, 0),
+                        "Expected next time slot of 13:00 but found " << time_13.toString());
+
+    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired, since we just completed.");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
+
+    // Repeat
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
+
+    // Repeat *last* time, since all times have expired, we expect task to complete.
+    // Addtionally since we have *not* re-queued the flag NO_REQUE_IF_SINGLE_TIME_DEP should have remained set
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired since we started clock at 10:30 ");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired due to force cmd");
+    BOOST_CHECK_MESSAGE(!ts_13.is_valid(), "Expected time 13 to be expired due to force cmd");
+
+    /// we will now Re-queue, Since the time is still 10:30, we expect valid from 11:00 and not 10:00
+    /// We should also have cleared NO_REQUE_IF_SINGLE_TIME_DEP
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be in valid since we started clock at 10:30 ");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid");
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_4) {
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user has a time range. In this case the node should complete and then
+    // requee and miss the next time slot. If this is repeated, eventually we should reach the
+    // end of the time slot. In which case the node should *not* reque and stay complete
+    //
+    // When the node is then requeed check that the next time slot has been correctly reset.
+    cout << "Base:: ...test_force_interactive_next_time_slot_4\n";
+
+    //   suite s1
+    //       task t1
+    //          time 10:00 14:00 01:00
+    //   endsuite
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    task_ptr t1     = suite->add_task("t1");
+    t1->addTime(TimeAttr(TimeSlot(10, 0), TimeSlot(14, 0), TimeSlot(1, 0)));
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(10 /*hour*/, 30 /*minutes*/); // start at 10:30
+    suite->addClock(clockAttr);
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
+
+    // since we started at 10:30 the next time slot should be 11:00
+    const TimeSlot& next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
+                        "Expected next time slot of 11:00 but found " << next_time_slot.toString());
+
+    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
+    // It should also advance the next time slot
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(12, 0),
+                        "Expected next time slot of 12:00 but found " << next_time_slot.toString());
+
+    // Repeat, to make sure next_time_slot is advanced
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(13, 0),
+                        "Expected next time slot of 13:00 but found " << next_time_slot.toString());
+
+    // Repeat, to make sure next_time_slot is advanced
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(14, 0),
+                        "Expected next time slot of 14:00 but found " << next_time_slot.toString());
+
+    // Repeat, ** THIS time we have *exceeded* the time range, it should no longer requeue, and should stay complete
+    //         Additionally since there is no reque we expect NO_REQUE_IF_SINGLE_TIME_DEP to remain set
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(15, 0),
+                        "Expected next time slot of 15:00 but found " << next_time_slot.toString());
+
+    /// we will now Re-queue, Since the time is still 10:30, we expect next_time slot to be 11:00 and not 10:00
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
+                        "After Re-queue, Expected next time slot of 11:00 but found " << next_time_slot.toString());
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_for_cron) {
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user has a time range. In this case the node should complete and then
+    // requee and miss the next time slot. If this is repeated, eventually we should reach the
+    // end of the time slot.
+    //
+    // When the node is then requeed check that the next time slot has been correctly reset.
+    cout << "Base:: ...test_force_interactive_next_time_slot_for_cron\n";
+
+    //   suite s1
+    //       task t1
+    //          cron 10:00 13:00 01:00
+    //   endsuite
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
+    suite->addClock(clockAttr);
+
+    task_ptr t1 = suite->add_task("t1");
+    ecf::CronAttr cronAttr;
+    cronAttr.addTimeSeries(TimeSlot(10, 0), TimeSlot(13, 0), TimeSlot(1, 0));
+    t1->addCron(cronAttr);
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
+
+    // since we started at 09:30 the next time slot should be 10:00
+    const TimeSlot& next_time_slot = t1->crons().back().time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
+                        "Expected next time slot of 10:00 but found " << next_time_slot.toString());
+
+    // Force the task t1 to complete state. Since we have a future time dependency, we should get re-queued again
+    // It should also advance the next time slot
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(11, 0),
+                        "Expected next time slot of 11:00 but found " << next_time_slot.toString());
+
+    // Repeat, to make sure next_time_slot is advanced
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(12, 0),
+                        "Expected next time slot of 12:00 but found " << next_time_slot.toString());
+
+    // Repeat, to make sure next_time_slot is advanced
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(13, 0),
+                        "Expected next time slot of 13:00 but found " << next_time_slot.toString());
+
+    // Repeat, ** THIS time we have *exceeded* the time range, However the cron *ALWAYS* re-queues
+    //         Additionally since there is no reque we expect NO_REQUE_IF_SINGLE_TIME_DEP to remain set
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear, after a requeue");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(14, 0),
+                        "Expected next time slot of 14:00 but found " << next_time_slot.toString());
+
+    /// we will now Re-queue, Since the time is still 09:30, we expect next_time slot to be 10:00 and not 14:00
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(next_time_slot == TimeSlot(10, 0),
+                        "After Re-queue, Expected next time slot of 10:00 but found " << next_time_slot.toString());
+}
+
+BOOST_AUTO_TEST_CASE(test_force_interactive_next_time_slot_for_cron_on_family) {
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user has a time range. In this case the node should complete and then
+    // requee and miss the next time slot. If this is repeated, eventually we should reach the
+    // end of the time slot.
+    //
+    // When the node is then requeed check that the next time slot has been correctly reset.
+    cout << "Base:: ...test_force_interactive_next_time_slot_for_cron_on_family\n";
+
+    //   suite s1
+    //     family
+    //       cron 10:00 13:00 01:00
+    //       task t1
+    //          time 11:00
+    //       task t2
+    //          time 12:00
+    //   endsuite
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
+    suite->addClock(clockAttr);
+
+    family_ptr f1 = suite->add_family("f1");
+    ecf::CronAttr cronAttr;
+    cronAttr.addTimeSeries(TimeSlot(10, 0), TimeSlot(13, 0), TimeSlot(1, 0));
+    f1->addCron(cronAttr);
+
+    task_ptr t1 = f1->add_task("t1");
+    t1->addTime(TimeAttr(11, 0));
+
+    task_ptr t2 = f1->add_task("t2");
+    t2->addTime(TimeAttr(12, 0));
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!f1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+    BOOST_CHECK_MESSAGE(!t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    /// begin the suite
+    TestHelper::invokeRequest(&the_defs, Cmd_ptr(new BeginCmd("s1", false)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    TestHelper::test_state(t2, NState::QUEUED);
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs << "\n";
+
+    // since we started at 09:30 the next time slot should be 11:00
+    const TimeSlot& t1_next_time_slot = t1->timeVec().back().time_series().get_next_time_slot();
+    const TimeSlot& t2_next_time_slot = t2->timeVec().back().time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(t1_next_time_slot == TimeSlot(11, 0),
+                        "Expected next time slot of 11:00 but found " << t1_next_time_slot.toString());
+    BOOST_CHECK_MESSAGE(t2_next_time_slot == TimeSlot(12, 0),
+                        "Expected next time slot of 12:00 but found " << t2_next_time_slot.toString());
+
+    // Force the task t1 & t2 to complete state. Since we only have a single time dependency it should expire
+    // It should also advance the next time slot
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    TestHelper::test_state(t2, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(!t1->timeVec().back().time_series().is_valid(), "Expected 11:00 time slot to be expired ");
+
+    // Forcing t2 to complete as well should, end up requeueing t1,t2 due to parent cron
+    TestHelper::invokeRequest(
+        &the_defs,
+        Cmd_ptr(
+            new ForceCmd(t2->absNodePath(), "complete", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::QUEUED);
+    TestHelper::test_state(t2, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(t1->timeVec().back().time_series().is_valid(), "Expected 11:00 time slot to be valid ");
+    BOOST_CHECK_MESSAGE(t2->timeVec().back().time_series().is_valid(), "Expected 12:00 time slot to be valid ");
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+    BOOST_CHECK_MESSAGE(!t2->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_destroy_log2) {
+    Log::destroy();
+    fs::remove("test_add_log2.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestFreeDepCmd.cpp 5.13.0-1/libs/base/test/TestFreeDepCmd.cpp
--- 5.12.4-1/libs/base/test/TestFreeDepCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestFreeDepCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,342 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "MockServer.hpp"
+#include "ecflow/base/cts/user/FreeDepCmd.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_FreeDepCmd)
+
+BOOST_AUTO_TEST_CASE(test_free_dep_cmd) {
+    cout << "Base:: ...test_free_dep_cmd\n";
+    TestLog test_log("test_free_dep_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    // Create a test and add the date and time dependencies
+    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 30, 0));
+    ptime time_plus_hour   = theLocalTime + hours(1);
+    ptime time_plus_2_hour = theLocalTime + hours(2);
+    date todaysDate        = theLocalTime.date();
+    date tomorrows_date    = todaysDate + date_duration(1);
+    date tomorrows_date_1  = todaysDate + date_duration(2);
+
+    // Get tomorrow as a day so that isFree fails.
+    tm day_1 = to_tm(tomorrows_date);
+    tm day_2 = to_tm(tomorrows_date_1);
+
+    suite_ptr suite;
+    task_ptr task;
+    Defs theDefs;
+    {
+        suite = theDefs.add_suite("test_time");
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task           = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_hour.time_of_day())));
+        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_2_hour.time_of_day())));
+        task->addTime(ecf::TimeAttr(
+            ecf::TimeSlot(1, 1), ecf::TimeSlot(1, 3), ecf::TimeSlot(0, 1), true /*relative to suite start*/
+            ));
+        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_hour.time_of_day())));
+        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_2_hour.time_of_day())));
+        task->addDate(DateAttr(tomorrows_date));
+        task->addDate(DateAttr(tomorrows_date_1));
+        task->addDay(DayAttr(static_cast<DayAttr::Day_t>(day_1.tm_wday)));
+        task->addDay(DayAttr(static_cast<DayAttr::Day_t>(day_2.tm_wday)));
+        task->add_trigger("t2 == complete");
+
+        CronAttr cronAttr;
+        cronAttr.addTimeSeries(ecf::TimeSlot(time_plus_hour.time_of_day()),
+                               ecf::TimeSlot(time_plus_2_hour.time_of_day()),
+                               ecf::TimeSlot(0, 1));
+        task->addCron(cronAttr);
+
+        fam->add_task("t2");
+        //  	cout << theDefs << "\n";
+    }
+    std::vector<task_ptr> vec;
+    theDefs.get_all_tasks(vec);
+    BOOST_REQUIRE_MESSAGE(vec.size() == 2, "Error in number of tasks");
+
+    // This will initialise the calendar from the Clock attribute
+    theDefs.beginAll();
+
+    // First all trigger should fail to evaluate AND all dependencies should NOT be free
+    BOOST_REQUIRE_MESSAGE(task->triggerAst(), "Expected trigger abstract syntax tree for task " << task->absNodePath());
+    BOOST_REQUIRE_MESSAGE(!task->triggerAst()->evaluate(), "Trigger should not evaluate");
+
+    const Calendar& cal = suite->calendar();
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
+    }
+    for (const ecf::TodayAttr& attr : task->todayVec()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Today should not be free");
+    }
+    for (const ecf::CronAttr& attr : task->crons()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Cron should not be free");
+    }
+    for (const DateAttr& attr : task->dates()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Date should not be free");
+    }
+    for (const DayAttr& attr : task->days()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), "Day should not be free");
+    }
+
+    // Invoke the FreeDepCmd
+    MockServer mockServer(&theDefs);
+
+    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
+    cmd.setup_user_authentification();
+    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
+
+    // Dependencies should now all be free now.
+    BOOST_REQUIRE_MESSAGE(task->get_trigger()->isFree(), "Trigger should evaluate");
+    bool at_least_one_free = false;
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
+
+    at_least_one_free = false;
+    for (const ecf::TodayAttr& attr : task->todayVec()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Today should be free");
+
+    at_least_one_free = false;
+    for (const ecf::CronAttr& attr : task->crons()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Cron should be free");
+
+    at_least_one_free = false;
+    for (const DateAttr& attr : task->dates()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Date should be free");
+
+    at_least_one_free = false;
+    for (const DayAttr& attr : task->days()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Day should be free");
+}
+
+BOOST_AUTO_TEST_CASE(test_free_dep_cmd_single_time_slot) {
+    cout << "Base:: ...test_free_dep_cmd_single_time_slot\n";
+    TestLog test_log("test_free_dep_cmd_single_time_slot.log"); // will create log file, and destroy log and remove file
+                                                                // at end of scope
+
+    // We add a time dependency *AFTER* the suite/calendar time
+    // This checks that we DO NOT re-queue a task with a future time dependency
+    // when a time dependency has been freed
+    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 30, 0));
+    ptime time_plus_2minute = theLocalTime + minutes(2);
+
+    suite_ptr suite;
+    task_ptr task;
+    Defs theDefs;
+    {
+        suite = theDefs.add_suite("test_time");
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite->addClock(clockAttr);
+        task = suite->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_2minute.time_of_day())));
+    }
+
+    // This will initialise the calendar from the Clock attribute
+    theDefs.beginAll();
+
+    // expect task to be holding at 9:30
+    const Calendar& cal = suite->calendar();
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
+    }
+
+    // Invoke the FreeDepCmd
+    MockServer mockServer(&theDefs);
+    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
+    cmd.setup_user_authentification();
+    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
+
+    // expect task to be free
+    bool at_least_one_free = false;
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
+
+    // The crux of the test. Should not requeue.
+    BOOST_CHECK_MESSAGE(task->state() == NState::ACTIVE,
+                        "Free dependency should have done an immediate job submission. Expected active state");
+    task->complete();
+    BOOST_CHECK_MESSAGE(task->state() == NState::COMPLETE,
+                        "Expected Complete but found "
+                            << NState::toString(task->state())
+                            << ", free dependency should avoid re-queue for a future single time dependency.");
+}
+
+BOOST_AUTO_TEST_CASE(test_free_dep_cmd_with_time_series) {
+    cout << "Base:: ...test_free_dep_cmd_with_time_series\n";
+    TestLog test_log("test_free_dep_cmd_with_time_series.log"); // will create log file, and destroy log and remove file
+                                                                // at end of scope
+
+    // We start the suite *IN BETWEEN* a time series, and the force free dependency
+    // This checks that we DO NOT re-queue a task with a future time dependency
+    // when a time dependency has been freed
+    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 29, 0));
+    suite_ptr suite;
+    task_ptr task;
+    Defs theDefs;
+    {
+        suite = theDefs.add_suite("test_time");
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite->addClock(clockAttr);
+        task = suite->add_task("t");
+        task->addTime(ecf::TimeAttr(
+            ecf::TimeSlot(9, 28), ecf::TimeSlot(9, 30), ecf::TimeSlot(0, 2), false /*relative to suite start*/
+            ));
+    }
+
+    // This will initialise the calendar from the Clock attribute
+    theDefs.beginAll();
+
+    // expect task to be holding, at 9:29
+    const Calendar& cal = suite->calendar();
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
+    }
+
+    // Invoke the FreeDepCmd
+    MockServer mockServer(&theDefs);
+    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
+    cmd.setup_user_authentification();
+    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
+
+    // expect task to be free
+    bool at_least_one_free = false;
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
+
+    // The crux of the test. Should not requeue, as we should have advanced the time slot beyond the END point
+    // i.e FreeDepCmd will advance the time slot, beyond end time
+    BOOST_CHECK_MESSAGE(task->state() == NState::ACTIVE,
+                        "Free dependency should have done an immediate job submission. Expected active state");
+    task->complete();
+    BOOST_CHECK_MESSAGE(task->state() == NState::COMPLETE,
+                        "Expected Complete but found "
+                            << NState::toString(task->state())
+                            << ", free dependency should avoid re-queue for a future single time dependency.");
+}
+
+BOOST_AUTO_TEST_CASE(test_free_dep_cmd_with_time_series_2) {
+    cout << "Base:: ...test_free_dep_cmd_with_time_series_2\n";
+    TestLog test_log("test_free_dep_cmd_with_time_series_2.log"); // will create log file, and destroy log and remove
+                                                                  // file at end of scope
+
+    // We start the suite *IN BETWEEN* a time series, and the force free dependency
+    // This time we have a larger range, and *SHOULD* re-queue, even if we miss a time slot
+    ptime theLocalTime(date(2011, Nov, 4), time_duration(9, 29, 0));
+    suite_ptr suite;
+    task_ptr task;
+    Defs theDefs;
+    {
+        suite = theDefs.add_suite("test_time");
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite->addClock(clockAttr);
+        task = suite->add_task("t");
+        task->addTime(ecf::TimeAttr(
+            ecf::TimeSlot(9, 28), ecf::TimeSlot(9, 34), ecf::TimeSlot(0, 2), false /*relative to suite start*/
+            ));
+    }
+
+    // This will initialise the calendar from the Clock attribute
+    // Will initialise  nextTimeSlot=09:30
+    theDefs.beginAll();
+
+    // expect task to be holding, at 9:29
+    const Calendar& cal = suite->calendar();
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        BOOST_CHECK_MESSAGE(!attr.isFree(cal), " Time should not be free");
+    }
+
+    // Invoke the FreeDepCmd. This will update next nextTimeSlot to 09:32
+    MockServer mockServer(&theDefs);
+    FreeDepCmd cmd(task->absNodePath(), true /*trigger*/, true /* all */);
+    cmd.setup_user_authentification();
+    STC_Cmd_ptr returnCmd = cmd.handleRequest(&mockServer);
+    BOOST_REQUIRE_MESSAGE(returnCmd->ok(), "Failed to for FreeDepCmd");
+
+    // expect task to be free
+    bool at_least_one_free = false;
+    for (const ecf::TimeAttr& attr : task->timeVec()) {
+        if (attr.isFree(cal)) {
+            at_least_one_free = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(at_least_one_free, "At least one Time should be free");
+
+    // The crux of the test. Even if we advance the time slot we should *STILL* be in range
+    BOOST_CHECK_MESSAGE(task->state() == NState::ACTIVE,
+                        "Free dependency should have done an immediate job submission. Expected active state");
+    task->complete();
+    BOOST_CHECK_MESSAGE(task->state() == NState::QUEUED,
+                        "Expected QUEUED but found "
+                            << NState::toString(task->state())
+                            << ", free dependency should avoid re-queue for a future single time dependency.");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestHelper.hpp 5.13.0-1/libs/base/test/TestHelper.hpp
--- 5.12.4-1/libs/base/test/TestHelper.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestHelper.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,125 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_base_test_TestHelper_HPP
+#define ecflow_base_test_TestHelper_HPP
+
+#include <boost/test/test_tools.hpp>
+
+#include "MockServer.hpp"
+#include "ecflow/base/ClientToServerRequest.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/node/Node.hpp"
+
+// defines statics utility functions used by more than one test
+class TestHelper {
+public:
+    static std::string invokeRequest(Defs* defs, Cmd_ptr theCmd, bool check_change_numbers = true) {
+
+        // Check that state change happens
+        unsigned int state_change_no  = Ecf::state_change_no();
+        unsigned int modify_change_no = Ecf::modify_change_no();
+
+        // Setup command for invocation
+        ClientToServerRequest cmd_request;
+        cmd_request.set_cmd(theCmd);
+        // std::cout << cmd_request << "\n";
+
+        MockServer server(defs);
+        STC_Cmd_ptr result = cmd_request.handleRequest(&server);
+        BOOST_CHECK_MESSAGE(result, "ClientToServerRequest " << cmd_request << " returned NULL\n");
+        BOOST_CHECK_MESSAGE(result->error().empty(), cmd_request << " " << result->error());
+        if (check_change_numbers) {
+            BOOST_CHECK_MESSAGE(state_change_no != Ecf::state_change_no() ||
+                                    modify_change_no != Ecf::modify_change_no(),
+                                "State & modify change numbers unaltered by command " << cmd_request);
+
+            // Some tests(TestSSyncCmd_CH1.cpp), create defs where invariants like change numbers are deliberately
+            // different
+            std::string error_msg;
+            BOOST_CHECK_MESSAGE(defs->checkInvariants(error_msg),
+                                "invokeRequest checkInvariants failed " << error_msg << " for cmd " << cmd_request);
+        }
+        if (result)
+            return result->get_string();
+        return std::string();
+    }
+
+    static std::string invokeRequest(AbstractServer* server, Cmd_ptr theCmd, bool check_change_numbers = true) {
+
+        // Check that state change happens
+        unsigned int state_change_no  = Ecf::state_change_no();
+        unsigned int modify_change_no = Ecf::modify_change_no();
+
+        // Setup command for invocation
+        ClientToServerRequest cmd_request;
+        cmd_request.set_cmd(theCmd);
+        // std::cout << cmd_request << "\n";
+
+        STC_Cmd_ptr result = cmd_request.handleRequest(server);
+        BOOST_CHECK_MESSAGE(result, "ClientToServerRequest " << cmd_request << " returned NULL\n");
+        BOOST_CHECK_MESSAGE(result->error().empty(), cmd_request << " " << result->error());
+        if (check_change_numbers) {
+            BOOST_CHECK_MESSAGE(state_change_no != Ecf::state_change_no() ||
+                                    modify_change_no != Ecf::modify_change_no(),
+                                "State & modify change numbers unaltered by command " << cmd_request);
+
+            // Some tests(TestSSyncCmd_CH1.cpp), create defs where invariants like change numbers are deliberately
+            // different
+            std::string error_msg;
+            BOOST_CHECK_MESSAGE(server->defs()->checkInvariants(error_msg),
+                                "invokeRequest checkInvariants failed " << error_msg << " for cmd " << cmd_request);
+        }
+        if (result)
+            return result->get_string();
+        return std::string();
+    }
+
+    static void invokeFailureRequest(Defs* defs, Cmd_ptr theCmd) {
+
+        ClientToServerRequest cmd_request;
+        cmd_request.set_cmd(theCmd);
+
+        MockServer server(defs);
+
+        // We expect this to fail
+        BOOST_CHECK_THROW(cmd_request.handleRequest(&server), std::runtime_error);
+    }
+
+    static void invokeFailureRequest(MockServer& server, Cmd_ptr theCmd) {
+
+        ClientToServerRequest cmd_request;
+        cmd_request.set_cmd(theCmd);
+
+        BOOST_CHECK_THROW(cmd_request.handleRequest(&server), std::runtime_error);
+
+        //		STC_Cmd_ptr result = cmd_request.handleRequest(&server);
+        //		BOOST_CHECK_MESSAGE( !result->ok(), "ClientToServerRequest " << cmd_request << " was expected to
+        // fail \n");
+    }
+
+    static void test_state(node_ptr n, NState::State expected) {
+        BOOST_REQUIRE_MESSAGE(n->state() == expected,
+                              "Expected state " << NState::toString(expected) << " but found "
+                                                << NState::toString(n->state()) << " for " << n->debugNodePath());
+    }
+
+    static void test_state(node_ptr n, DState::State expected) {
+        BOOST_REQUIRE_MESSAGE(n->dstate() == expected,
+                              "Expected state " << DState::toString(expected) << " but found "
+                                                << DState::toString(n->dstate()) << " for " << n->debugNodePath());
+    }
+
+private:
+    TestHelper() = default;
+};
+
+#endif /* ecflow_base_test_TestHelper_HPP */
diff -pruN 5.12.4-1/libs/base/test/TestInLimitAndLimit.cpp 5.13.0-1/libs/base/test/TestInLimitAndLimit.cpp
--- 5.12.4-1/libs/base/test/TestInLimitAndLimit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestInLimitAndLimit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1296 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/ForceCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/core/PrintStyle.hpp" // IWYU pragma: keep
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_InLimitAndLimit)
+
+BOOST_AUTO_TEST_CASE(test_add_log) {
+    // create once for all test below, then remove at the end
+    Log::create("test_add_log.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_CASE(test_add_limit) {
+    cout << "Base:: ...test_add_limit\n";
+    suite_ptr suite = Suite::create("suite");
+    suite->addLimit(Limit("fast", 1)); // " Adding limit first time should be ok");
+    BOOST_REQUIRE_THROW(suite->addLimit(Limit("fast", 1)),
+                        std::runtime_error); //" Adding same limit second time should fail");
+
+    suite->addInLimit(InLimit("fast", "/suite")); //" Adding in-limit first time should be ok");
+    BOOST_REQUIRE_THROW(suite->addInLimit(InLimit("fast", "/suite")),
+                        std::runtime_error); // " Adding in-limit second time should fail");
+
+    // adding inlimit with limit node only and submission should fail
+    BOOST_REQUIRE_THROW(
+        suite->addInLimit(InLimit("limit", "/suite", 1, true, /*limit_this_node_only*/ true /*limit submission*/)),
+        std::runtime_error); // " Adding in-limit second time should fail");
+}
+
+BOOST_AUTO_TEST_CASE(test_limit_increment) {
+    cout << "Base:: ...test_limit_increment\n";
+
+    // Test than when a job is submitted multiple times, it should only consume 1 token
+    //
+    // Create the defs file
+    // suite suite
+    //     limit fast 10
+    //    family f
+    //          inlimit /suite:fast
+    //          task t1
+    //    endfamily
+    // endsuite
+    Defs defs;
+    std::string limitName   = "fast";
+    std::string pathToLimit = "/suite";
+    std::string suitename   = "suite";
+    suite_ptr s             = defs.add_suite(suitename);
+    family_ptr f            = s->add_family("f");
+    task_ptr t1             = f->add_task("t1");
+    {
+        f->addInLimit(InLimit(limitName, pathToLimit));
+        s->addLimit(Limit(limitName, 10));
+    }
+    // cerr << defs << "\n";
+
+    {
+        // Resolve dependencies:: BEFORE calling beginCmd, should be a NO OP
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 tasks to submit but found " << jobsParam.submitted().size());
+    }
+
+    {
+        // Create a request to begin suite
+        // make sure chosen suite can begin to resolve dependencies.
+        // beginning the suite will:
+        //     1/ set all children to the QUEUED state
+        //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+        //
+        //  Resolve dependencies. Only one task should be submitted due to Limit
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
+        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
+        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
+        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
+    }
+
+    {
+        // Resolve dependencies. No task should submit since we have reached the limit
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
+    }
+
+    {
+        // Try resubmitting the an active task, it should still only consume 1 token in the limit
+        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
+
+        // Hack the state, to allow job to re- resubmitted
+        t1->setStateOnly(NState::QUEUED);
+
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 1,
+                            "Expected 1 task to submit but found " << jobsParam.submitted().size());
+
+        // Limit should still have only consumed one token
+        limit_ptr limit = s->find_limit(limitName);
+        BOOST_CHECK_MESSAGE(limit.get(), "Limit not found");
+        BOOST_CHECK_MESSAGE(limit->value() == 1, "Expected limit of value 1, but found " << limit->value());
+        BOOST_CHECK_MESSAGE(limit->paths().size() == 1,
+                            "Expected Only 1 task path in limit but found " << limit->paths().size());
+    }
+}
+
+//===============================================================================
+// This TEST is used to test limit and inLimit.
+// Both examples taken from the documentation
+BOOST_AUTO_TEST_CASE(test_limit) {
+    cout << "Base:: ...test_limit\n";
+
+    ///////////////////////////////////////////////////////////////////////////
+    // Create the defs file
+    //	suite suite
+    //     limit fast 1
+    //	   family f
+    //          inlimit /suite:fast
+    //	   		task t1
+    //	   		task t2
+    //	   endfamily
+    //	endsuite
+    Defs defs;
+    std::string limitName   = "fast";
+    std::string pathToLimit = "/suite";
+    std::string suitename   = "suite";
+    family_ptr f            = Family::create("f");
+    task_ptr t1             = Task::create("t1");
+    task_ptr t2             = Task::create("t2");
+    suite_ptr s             = Suite::create(suitename);
+    {
+        f->addTask(t1);
+        f->addTask(t2);
+        f->addInLimit(InLimit(limitName, pathToLimit));
+
+        s->addFamily(f);
+        s->addLimit(Limit(limitName, 1));
+
+        defs.addSuite(s);
+    }
+    // cerr << defs << "\n";
+
+    //*******************************************************************************
+    // Resolve dependencies:: BEFORE calling beginCmd, should be a NO OP
+    {
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 tasks to submit but found " << jobsParam.submitted().size());
+    }
+
+    // ***********************************************************************
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    //
+    //  Resolve dependencies. Only one task should be submitted due to Limit
+    //
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
+        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
+        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
+        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
+        BOOST_CHECK_MESSAGE(t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(t2->state()));
+    }
+
+    //*******************************************************************************
+    // Resolve dependencies. No task should submit since we have reached the limit
+    {
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
+    }
+
+    {
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_limit1) {
+    cout << "Base:: ...test_limit1\n";
+    ////////////////////////////////////////////////////////////////////////////////////////////////////
+    // Create the defs file
+    //	suite suite
+    //     limit disk 50
+    //	   family f
+    //          inlimit /suite:disk 20
+    //	   		task t1
+    //	   		task t2
+    //	   		task t3
+    //	   endfamily
+    //	endsuite
+    //
+    //  Test that only 2 Tasks can run
+    Defs defs;
+    std::string limitName   = "disk";
+    std::string pathToLimit = "/suite";
+    std::string suitename   = "suite";
+    family_ptr f            = Family::create("f");
+    task_ptr t1             = Task::create("t1");
+    task_ptr t2             = Task::create("t2");
+    task_ptr t3             = Task::create("t3");
+    suite_ptr s             = Suite::create(suitename);
+    {
+        f->addTask(t1);
+        f->addTask(t2);
+        f->addTask(t3);
+        f->addInLimit(InLimit(limitName, pathToLimit, 20));
+
+        s->addFamily(f);
+        s->addLimit(Limit(limitName, 50));
+
+        defs.addSuite(s);
+    }
+    // cerr << defs << "\n";
+
+    //*******************************************************************************
+    // Resolve dependencies:: BEFORE calling beginCmd, should be a NO OP
+    {
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 tasks to submit but found " << jobsParam.submitted().size());
+    }
+
+    // ***********************************************************************
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    //
+    //  Resolve dependencies. Only TWO task should be active due to Limit
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
+        BOOST_CHECK_MESSAGE(s->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s->state()));
+        BOOST_CHECK_MESSAGE(f->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f->state()));
+        BOOST_CHECK_MESSAGE(t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(t1->state()));
+        BOOST_CHECK_MESSAGE(t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(t2->state()));
+        BOOST_CHECK_MESSAGE(t3->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(t3->state()));
+    }
+
+    //*******************************************************************************
+    // Resolve dependencies. No task should submit since we have reached the limit
+    {
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
+        if (jobsParam.submitted().size() != 0) {
+            for (Submittable* t : jobsParam.submitted()) {
+                cerr << "Submittable " << t->absNodePath() << "\n";
+            }
+        }
+    }
+
+    {
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_limit_references_after_delete) {
+    /// In-limit have a reference to a limit. This limit can be on another node. If that node is deleted
+    /// The limits are also deleted, hence we need to ensure in-limit reference to limits that are being
+    /// deleted are cleared. Currently we use shared_ptr to achieve this
+    cout << "Base:: ...test_limit_references_after_delete\n";
+
+    ////////////////////////////////////////////////////////////////////////////////////////////////////
+    //  Create the defs file
+    //	suite suiteLimits    # the limit we want delete
+    //     limit limit1  1
+    //     limit limit2  1
+    //     limit limit3  1
+    //	endsuite
+    //
+    //	suite suite
+    //	   family f
+    //          inlimit /suiteLimits:limit1    # check limits references cleared after suiteLimits is deleted
+    //	   		task t1
+    //	   endfamily
+    //	   family f1
+    //          inlimit /suiteLimits:limit2
+    //	   		task t1
+    //	   endfamily
+    //	   family f2
+    //          inlimit /suiteLimits:limit3
+    //	   		task t1
+    //	   endfamily
+    //	endsuite
+    //
+    // In this test case we will delete the suiteLimits, and then test to ensure the the in-limits
+    // in suite have been reset.
+    Defs defs;
+    {
+        suite_ptr suite = Suite::create("suiteLimits");
+        suite->addLimit(Limit("limit1", 1));
+        suite->addLimit(Limit("limit2", 1));
+        suite->addLimit(Limit("limit3", 1));
+        defs.addSuite(suite);
+    }
+
+    InLimit in_limit1("limit1", "/suiteLimits");
+    InLimit in_limit2("limit2", "/suiteLimits");
+    InLimit in_limit3("limit3", "/suiteLimits");
+    {
+        suite_ptr suite = Suite::create("suite");
+
+        family_ptr fam = Family::create("f");
+        fam->addTask(Task::create("t1"));
+        fam->addInLimit(in_limit1);
+        suite->addFamily(fam);
+
+        family_ptr fam2 = Family::create("f1");
+        fam2->addTask(Task::create("t1"));
+        fam2->addInLimit(in_limit2);
+        suite->addFamily(fam2);
+
+        family_ptr fam3 = Family::create("f2");
+        fam3->addTask(Task::create("t1"));
+        fam3->addInLimit(in_limit3);
+        suite->addFamily(fam3);
+
+        defs.addSuite(suite);
+    }
+
+    // First check that in-limit reference have been setup
+    node_ptr f  = defs.findAbsNode("/suite/f");
+    node_ptr f1 = defs.findAbsNode("/suite/f1");
+    node_ptr f2 = defs.findAbsNode("/suite/f2");
+    BOOST_REQUIRE_MESSAGE(f.get() && f1.get() && f2.get(), "Failed to find family than contain the inlimits");
+
+    BOOST_REQUIRE_MESSAGE(f->findInLimitByNameAndPath(in_limit1) && f1->findInLimitByNameAndPath(in_limit2) &&
+                              f2->findInLimitByNameAndPath(in_limit3),
+                          "Failed to find in-limits on the families" << defs);
+
+    // Now check they all reference the limits
+    BOOST_REQUIRE_MESSAGE(f->findLimitViaInLimit(in_limit1),
+                          "Inlimit does not reference its limit. Post process failed ?");
+    BOOST_REQUIRE_MESSAGE(f1->findLimitViaInLimit(in_limit2),
+                          "Inlimit does not reference its limit. Post process failed ?");
+    BOOST_REQUIRE_MESSAGE(f2->findLimitViaInLimit(in_limit3),
+                          "Inlimit does not reference its limit. Post process failed ?");
+
+    // Ok Now delete suiteLimits, as this is where the limits reside
+    // *** It is extremely important that shared_ptr for '/suiteLimit' is in its own
+    // *** scope, otherwise it will keep the 'suite' live, and NOT delete the limits
+    {
+        node_ptr suiteLimits = defs.findAbsNode("/suiteLimits");
+        BOOST_REQUIRE_MESSAGE(suiteLimits.get(), "Could not find the suite we want to delete?");
+        BOOST_REQUIRE_MESSAGE(defs.deleteChild(suiteLimits.get()), "Deletion failed?");
+        BOOST_REQUIRE_MESSAGE(!defs.findAbsNode("/suiteLimits").get(), "Deletion failed?");
+    }
+
+    BOOST_REQUIRE_MESSAGE(!f->findLimitViaInLimit(in_limit1), "In-limit still references limit that has been deleted?");
+    BOOST_REQUIRE_MESSAGE(!f1->findLimitViaInLimit(in_limit2),
+                          "In-limit still references limit that has been deleted?");
+    BOOST_REQUIRE_MESSAGE(!f2->findLimitViaInLimit(in_limit3),
+                          "In-limit still references limit that has been deleted?");
+}
+
+BOOST_AUTO_TEST_CASE(test_limits_after_force_cmd) {
+    cout << "Base:: ...test_limits_after_force_cmd\n";
+
+    // Create the following defs
+    // suite s1
+    //   limit A 10
+    //   family f1
+    //     inlimit A
+    //     task t1
+    //     task t2
+    //   family f2
+    //     inlimit A
+    //     task t1
+    //     task t2
+
+    // When all the tasks are running/submitted state, limit A should have consumed 4 tokens
+    // However if we how force family f2 to be complete, then the limit should be reset back to 2 tokens.
+    // Repeating for family f1, should result with a Limit with no tokens
+    Defs defs;
+    suite_ptr s1 = defs.add_suite("s1");
+    s1->addLimit(Limit("A", 10));
+    family_ptr f1 = s1->add_family("f1");
+    f1->addInLimit(InLimit("A", "/s1"));
+    task_ptr f1_t1 = f1->add_task("t1");
+    task_ptr f1_t2 = f1->add_task("t2");
+    family_ptr f2  = s1->add_family("f2");
+    f2->addInLimit(InLimit("A", "/s1"));
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+    // cout << defs;
+
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    //
+    //  Resolve dependencies. All tasks are within the limit and hence should start
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
+
+        limit_ptr the_limit = s1->find_limit("A");
+        BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
+        BOOST_CHECK_MESSAGE(the_limit->value() == 4, "Expected limit value to be 4 but found " << the_limit->value());
+    }
+
+    {
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new ForceCmd(
+                f2->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
+
+        limit_ptr the_limit = s1->find_limit("A");
+        BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
+        BOOST_CHECK_MESSAGE(the_limit->value() == 2, "Expected limit value to be 2 but found " << the_limit->value());
+    }
+
+    {
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new ForceCmd(
+                f1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+        BOOST_CHECK_MESSAGE(s1->state() == NState::COMPLETE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
+
+        limit_ptr the_limit = s1->find_limit("A");
+        BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
+        BOOST_CHECK_MESSAGE(the_limit->value() == 0, "Expected limit value to be 0 but found " << the_limit->value());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_limits_after_requeue_family_ECFLOW_196) {
+    cout << "Base:: ...test_limits_after_requeue_family_ECFLOW_196\n";
+
+    // This test is used to ensure that, requeue causes node to release tokens held by the Limits
+
+    // Create the following defs
+    // suite s1
+    //   limit A 10
+    //   family f1
+    //     inlimit A
+    //     task t1
+    //     task t2
+    //   family f2
+    //     inlimit A
+    //     task t1
+    //     task t2
+
+    // When all the tasks are running/submitted state, limit A should have consumed 4 tokens
+    // However if we how force family f2 to be requeud, then the limit should be reset back to 2 tokens.
+    Defs defs;
+    suite_ptr s1 = defs.add_suite("s1");
+    s1->addLimit(Limit("A", 10));
+    family_ptr f1 = s1->add_family("f1");
+    f1->addInLimit(InLimit("A", "/s1"));
+    task_ptr f1_t1 = f1->add_task("t1");
+    task_ptr f1_t2 = f1->add_task("t2");
+    family_ptr f2  = s1->add_family("f2");
+    f2->addInLimit(InLimit("A", "/s1"));
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+    // cout << defs;
+
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    //
+    //  Resolve dependencies. All tasks are within the limit and hence should start
+    int expected_limit_value = 4;
+    limit_ptr the_limit      = s1->find_limit("A");
+    BOOST_CHECK_MESSAGE(the_limit, "Could not find limit");
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
+
+        BOOST_CHECK_MESSAGE(the_limit->value() == expected_limit_value,
+                            "Expected limit value to be 4 but found " << the_limit->value());
+    }
+
+    {
+        expected_limit_value = 2;
+        // We now want to re-queue node f2, and check to see that limit tokens are released after the re-queue
+        // However, the Mock server, will call resolve dependencies after re-queue command , and place nodes *back* into
+        // active state, to *STOP* this, we will add a trigger, so that the dependencies will not resolve, and hence
+        // nodes stay queued
+        f2->add_trigger("1 == 0");
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(f2->absNodePath(), RequeueNodeCmd::FORCE)));
+
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
+
+        BOOST_CHECK_MESSAGE(the_limit->value() == expected_limit_value,
+                            "Expected limit value to be 2 but found " << the_limit->value());
+    }
+
+    {
+        expected_limit_value = 0;
+        // We now want to re-queue node f1, and check to see that limit tokens are released after the re-queue
+        // However, the Mock server, will call resolve dependencies after re-queue command , and place nodes *back* into
+        // active state, to *STOP* this, we will add a trigger, so that the dependencies will not resolve, and hence
+        // nodes stay queued
+        f1->add_trigger("1 == 0");
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(f1->absNodePath(), RequeueNodeCmd::FORCE)));
+
+        BOOST_CHECK_MESSAGE(s1->state() == NState::QUEUED,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::QUEUED,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::QUEUED,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::QUEUED,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
+
+        BOOST_CHECK_MESSAGE(the_limit->value() == expected_limit_value,
+                            "Expected limit value to be 0 but found " << the_limit->value());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_limits_after_requeue_task_ECFLOW_196) {
+    cout << "Base:: ...test_limits_after_requeue_task_ECFLOW_196\n";
+
+    // This test is used to ensure that, requeue causes node to release tokens held by the Limits
+
+    // Create the following def, i.e using internal and external limits
+    // suite s0
+    //   limit X 5
+    // suite s1
+    //   limit A 10
+    //   limit B 5
+    //   family f1
+    //     inlimit A
+    //     inlimit B
+    //     inlimit X /s0/
+    //     task t1
+    //     task t2
+    //   family f2
+    //     inlimit A
+    //     inlimit B
+    //     inlimit X /s0/
+    //     task t1
+    //     task t2
+
+    // When all the tasks are running/submitted state, limit A should have consumed 4 tokens
+    // However if we how force task to reque, then the token should be released
+    Defs defs;
+    suite_ptr s0 = defs.add_suite("s0");
+    s0->addLimit(Limit("X", 10));
+
+    suite_ptr s1 = defs.add_suite("s1");
+    s1->addLimit(Limit("A", 10));
+    s1->addLimit(Limit("B", 5));
+    family_ptr f1 = s1->add_family("f1");
+    f1->addInLimit(InLimit("A", "/s1"));
+    f1->addInLimit(InLimit("B", "/s1"));
+    f1->addInLimit(InLimit("X", "/s0"));
+    task_ptr f1_t1 = f1->add_task("t1");
+    task_ptr f1_t2 = f1->add_task("t2");
+    family_ptr f2  = s1->add_family("f2");
+    f2->addInLimit(InLimit("A", "/s1"));
+    f2->addInLimit(InLimit("B", "/s1"));
+    f2->addInLimit(InLimit("X", "/s0"));
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+
+    std::vector<task_ptr> tasks;
+    tasks.push_back(f1_t1);
+    tasks.push_back(f1_t2);
+    tasks.push_back(f2_t1);
+    tasks.push_back(f2_t2);
+    // cout << defs;
+
+    limit_ptr the_A_limit = s1->find_limit("A");
+    limit_ptr the_B_limit = s1->find_limit("B");
+    limit_ptr the_X_limit = s0->find_limit("X");
+    BOOST_CHECK_MESSAGE(the_A_limit && the_B_limit && the_X_limit, "Could not find limits");
+
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    //
+    //  Resolve dependencies. All tasks are within the limit and hence should start
+    int expected_limit_value = 4;
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
+
+        BOOST_CHECK_MESSAGE(the_A_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_A_limit->value());
+        BOOST_CHECK_MESSAGE(the_B_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_B_limit->value());
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+    }
+
+    {
+        // We now want to re-queue node tasks, and check to see that limit tokens are released after the re-queue
+        // However, the Mock server, will call resolve dependencies after re-queue command , and place nodes *back* into
+        // active state, to *STOP* this, we will add a trigger, so that the dependencies will not resolve, and hence
+        // nodes stay queued
+        f1->add_trigger("1 == 0");
+        f2->add_trigger("1 == 0");
+
+        for (auto& task : tasks) {
+            TestHelper::invokeRequest(&defs, Cmd_ptr(new RequeueNodeCmd(task->absNodePath(), RequeueNodeCmd::FORCE)));
+            expected_limit_value--;
+            BOOST_CHECK_MESSAGE(the_A_limit->value() == expected_limit_value,
+                                "Expected limit value " << expected_limit_value << " but found "
+                                                        << the_A_limit->value());
+            BOOST_CHECK_MESSAGE(the_B_limit->value() == expected_limit_value,
+                                "Expected limit value " << expected_limit_value << " but found "
+                                                        << the_B_limit->value());
+            BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                                "Expected limit value " << expected_limit_value << " but found "
+                                                        << the_X_limit->value());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_inlimit_with_family_ECFLOW_878) {
+    cout << "Base:: ...test_inlimit_with_family_ECFLOW_878\n";
+
+    // This test places a limit on the families. Should ignore the tasks
+    // With this test only 1 family can start at a time
+    //
+    // Create the following def. with inlimit -n, we limit node only
+    // suite s0
+    //   limit X 1   # Only allow one family at a time to start
+    // suite s1
+    //   family f1
+    //     inlimit -n X
+    //     task t1
+    //     task t2
+    //   family f2
+    //     inlimit -n X
+    //     task t1
+    //     task t2
+    //   family f3
+    //     inlimit -n X
+    //     task t1
+    //     task t2
+
+    Defs defs;
+    suite_ptr s0 = defs.add_suite("s0");
+    s0->addLimit(Limit("X", 1));
+
+    suite_ptr s1  = defs.add_suite("s1");
+    family_ptr f1 = s1->add_family("f1");
+    f1->addInLimit(InLimit("X", "/s0", 1, true));
+    task_ptr f1_t1 = f1->add_task("t1");
+    task_ptr f1_t2 = f1->add_task("t2");
+    family_ptr f2  = s1->add_family("f2");
+    f2->addInLimit(InLimit("X", "/s0", 1, true));
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+    family_ptr f3  = s1->add_family("f3");
+    f3->addInLimit(InLimit("X", "/s0", 1, true));
+    task_ptr f3_t1 = f3->add_task("t1");
+    task_ptr f3_t2 = f3->add_task("t2");
+
+    // cout << defs;
+    limit_ptr the_X_limit = s0->find_limit("X");
+    BOOST_CHECK_MESSAGE(the_X_limit, "Could not find limits");
+
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    //
+    //  Resolve dependencies. Only 2 task should start
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
+
+        //      PrintStyle::setStyle(PrintStyle::MIGRATE);
+        //      cout << defs;
+
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
+
+        int expected_limit_value = 1;
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+
+        // should only have 1 path, and it should be path to family f1
+        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
+        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
+        BOOST_CHECK_MESSAGE(x_limit_paths.find(f1->absNodePath()) != x_limit_paths.end(),
+                            "Expected to find path " << f1->absNodePath());
+
+        //      // why f2_t1 is queued
+        //      cout << "why ============================================";
+        //      std::vector<std::string> vec;
+        //      f2_t1->bottom_up_why(vec);
+        //      for(size_t i =0; i < vec.size(); i++) {
+        //         cout << "why:" << i << " " << vec[i] << "\n";
+        //      }
+    }
+
+    // Now set tasks f1_t1, f1_t2 to complete, this should release the limit, so that next family can run
+    {
+        std::vector<std::string> task_paths;
+        task_paths.push_back(f1_t1->absNodePath());
+        task_paths.push_back(f1_t2->absNodePath());
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
+
+        int expected_limit_value = 1;
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+
+        // Paths should be empty
+        // should only have 1 path, and it should be path to family f1
+        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
+        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
+        BOOST_CHECK_MESSAGE(x_limit_paths.find(f2->absNodePath()) != x_limit_paths.end(),
+                            "Expected to find path " << f2->absNodePath());
+    }
+
+    // Now set tasks f2_t1, f2_t2 to complete, this should release the limit, so that next family can run
+    {
+        std::vector<std::string> task_paths;
+        task_paths.push_back(f2_t1->absNodePath());
+        task_paths.push_back(f2_t2->absNodePath());
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f3_t2->state()));
+
+        int expected_limit_value = 1;
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+
+        // should only have 1 path, and it should be path to family f3
+        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
+        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
+        BOOST_CHECK_MESSAGE(x_limit_paths.find(f3->absNodePath()) != x_limit_paths.end(),
+                            "Expected to find path " << f3->absNodePath());
+    }
+
+    // Now set tasks f3_t1, f3_t2 to complete, this should release the limit
+    {
+        std::vector<std::string> task_paths;
+        task_paths.push_back(f3_t1->absNodePath());
+        task_paths.push_back(f3_t2->absNodePath());
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f3_t2->state()));
+
+        int expected_limit_value = 0;
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+
+        // Paths should be empty
+        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
+        BOOST_CHECK_MESSAGE(the_X_limit->paths().empty(), "Expected no paths, but found" << x_limit_paths.size());
+    }
+
+    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
+    //   cout << defs;
+}
+
+BOOST_AUTO_TEST_CASE(test_inlimit_ECFLOW_878) {
+    cout << "Base:: ...test_inlimit_ECFLOW_878\n";
+
+    // This test places a limit on the families. Should ignore the tasks
+    // With this test only 1 family can start at a time.
+    // However we *ALSO* want to constrain the tasks, to only 1 task at a time
+    //
+    // Create the following def. with inlimit -n, we limit node only
+    // suite s0
+    //   limit X 1   # Only allow one family at a time to start
+    //   limit T 1   # Only allow one task at a time to start
+    // suite s1
+    //   family f1
+    //     inlimit -n X
+    //     inlimit T
+    //     task t1
+    //     task t2
+    //   family f2
+    //     inlimit -n X
+    //     inlimit T
+    //     task t1
+    //     task t2
+    //   family f3
+    //     inlimit -n X
+    //     inlimit T
+    //     task t1
+    //     task t2
+
+    Defs defs;
+    suite_ptr s0 = defs.add_suite("s0");
+    s0->addLimit(Limit("X", 1));
+    s0->addLimit(Limit("T", 1));
+
+    suite_ptr s1  = defs.add_suite("s1");
+    family_ptr f1 = s1->add_family("f1");
+    f1->addInLimit(InLimit("X", "/s0", 1, true));
+    f1->addInLimit(InLimit("T", "/s0", 1));
+    task_ptr f1_t1 = f1->add_task("t1");
+    task_ptr f1_t2 = f1->add_task("t2");
+    family_ptr f2  = s1->add_family("f2");
+    f2->addInLimit(InLimit("X", "/s0", 1, true));
+    f2->addInLimit(InLimit("T", "/s0", 1));
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+    family_ptr f3  = s1->add_family("f3");
+    f3->addInLimit(InLimit("X", "/s0", 1, true));
+    f3->addInLimit(InLimit("T", "/s0", 1));
+    task_ptr f3_t1 = f3->add_task("t1");
+    task_ptr f3_t2 = f3->add_task("t2");
+
+    // cout << defs;
+    limit_ptr the_X_limit = s0->find_limit("X");
+    limit_ptr the_T_limit = s0->find_limit("T");
+    BOOST_CHECK_MESSAGE(the_X_limit && the_T_limit, "Could not find limits");
+
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    //
+    //  Resolve dependencies. Only 1 task should start
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
+
+        // PrintStyle::setStyle(PrintStyle::MIGRATE);
+        // cout << defs;
+
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
+
+        int expected_limit_value = 1;
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+
+        // should only have 1 path, and it should be path to family f1
+        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
+        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
+        BOOST_CHECK_MESSAGE(x_limit_paths.find(f1->absNodePath()) != x_limit_paths.end(),
+                            "Expected to find path " << f1->absNodePath());
+
+        const std::set<std::string>& t_limit_paths = the_T_limit->paths();
+        BOOST_CHECK_MESSAGE(t_limit_paths.size() == 1, "Expected one path in limit but found " << t_limit_paths.size());
+
+        //      // why f2_t1 is queued
+        //      cout << "why ============================================";
+        //      std::vector<std::string> vec;
+        //      f2_t1->bottom_up_why(vec);
+        //      for(size_t i =0; i < vec.size(); i++) {
+        //         cout << "why:" << i << " " << vec[i] << "\n";
+        //      }
+    }
+
+    // Now set tasks f1_t1 complete, this should release  t1_t2
+    {
+        std::vector<std::string> task_paths;
+        task_paths.push_back(f1_t1->absNodePath());
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
+
+        int expected_limit_value = 1;
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+
+        // should only have 1 path, and it should be path to family f1
+        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
+        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
+        BOOST_CHECK_MESSAGE(x_limit_paths.find(f1->absNodePath()) != x_limit_paths.end(),
+                            "Expected to find path " << f1->absNodePath());
+
+        const std::set<std::string>& t_limit_paths = the_T_limit->paths();
+        BOOST_CHECK_MESSAGE(t_limit_paths.size() == 1, "Expected one path in limit but found " << t_limit_paths.size());
+    }
+
+    // Now set tasks f1_t2 complete, this should release  f2_1
+    {
+        std::vector<std::string> task_paths;
+        task_paths.push_back(f1_t2->absNodePath());
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new ForceCmd(task_paths, "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(f3_t2->state()));
+
+        int expected_limit_value = 1;
+        BOOST_CHECK_MESSAGE(the_X_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_X_limit->value());
+
+        // should only have 1 path, and it should be path to family f2
+        const std::set<std::string>& x_limit_paths = the_X_limit->paths();
+        BOOST_CHECK_MESSAGE(x_limit_paths.size() == 1, "Expected one path in limit but found " << x_limit_paths.size());
+        BOOST_CHECK_MESSAGE(x_limit_paths.find(f2->absNodePath()) != x_limit_paths.end(),
+                            "Expected to find path " << f2->absNodePath());
+
+        const std::set<std::string>& t_limit_paths = the_T_limit->paths();
+        BOOST_CHECK_MESSAGE(t_limit_paths.size() == 1, "Expected one path in limit but found " << t_limit_paths.size());
+    }
+
+    // PrintStyle::setStyle(PrintStyle::MIGRATE);
+    // cout << defs;
+}
+
+BOOST_AUTO_TEST_CASE(test_inlimit_submission_only) {
+    cout << "Base:: ...test_inlimit_submission_only \n";
+
+    // Create the following def. with inlimit -s, we limit submission
+    // suite s0
+    //   limit T 1   # Only allow one task at a time to start
+    // suite s1
+    //   family f1
+    //     inlimit -s T
+    //     task t1
+    //     task t2
+    //   family f2
+    //     inlimit -s T
+    //     task t1
+    //     task t2
+    //   family f3
+    //     inlimit -s T
+    //     task t1
+    //     task t2
+
+    Defs defs;
+    suite_ptr s0 = defs.add_suite("s0");
+    s0->addLimit(Limit("T", 1));
+
+    suite_ptr s1  = defs.add_suite("s1");
+    family_ptr f1 = s1->add_family("f1");
+    f1->addInLimit(InLimit("T", "/s0", 1, false, true));
+    task_ptr f1_t1 = f1->add_task("t1");
+    task_ptr f1_t2 = f1->add_task("t2");
+    family_ptr f2  = s1->add_family("f2");
+    f2->addInLimit(InLimit("T", "/s0", 1, false, true));
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+    family_ptr f3  = s1->add_family("f3");
+    f3->addInLimit(InLimit("T", "/s0", 1, false, true));
+    task_ptr f3_t1 = f3->add_task("t1");
+    task_ptr f3_t2 = f3->add_task("t2");
+
+    // cout << defs;
+    limit_ptr the_T_limit = s0->find_limit("T");
+    BOOST_CHECK_MESSAGE(the_T_limit, "Could not find limits");
+
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will:
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state  queued->submitted->active
+    //        Hence under test scenario there is no delay between submitted->active , hence limit is incremented and
+    //        decrement
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("/s1")));
+
+        // PrintStyle::setStyle(PrintStyle::MIGRATE);
+        // cout << defs;
+
+        BOOST_CHECK_MESSAGE(s1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(s1->state()));
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1->state()));
+        BOOST_CHECK_MESSAGE(f1_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(f1_t1->state()));
+        BOOST_CHECK_MESSAGE(f1_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE , but found to be " << NState::toString(f1_t2->state()));
+        BOOST_CHECK_MESSAGE(f2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE , but found to be " << NState::toString(f2->state()));
+        BOOST_CHECK_MESSAGE(f2_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE , but found to be " << NState::toString(f2_t1->state()));
+        BOOST_CHECK_MESSAGE(f2_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE , but found to be " << NState::toString(f2_t2->state()));
+        BOOST_CHECK_MESSAGE(f3->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE , but found to be " << NState::toString(f3->state()));
+        BOOST_CHECK_MESSAGE(f3_t1->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE , but found to be " << NState::toString(f3_t1->state()));
+        BOOST_CHECK_MESSAGE(f3_t2->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE , but found to be " << NState::toString(f3_t2->state()));
+
+        // The active state *decrements* the inlimit/limit value
+        int expected_limit_value = 0;
+        BOOST_CHECK_MESSAGE(the_T_limit->value() == expected_limit_value,
+                            "Expected limit value to be " << expected_limit_value << " but found "
+                                                          << the_T_limit->value());
+
+        //      // why f2_t1 is queued
+        //      cout << "why ============================================";
+        //      std::vector<std::string> vec;
+        //      f2_t1->bottom_up_why(vec);
+        //      for(size_t i =0; i < vec.size(); i++) {
+        //         cout << "why:" << i << " " << vec[i] << "\n";
+        //      }
+    }
+
+    // PrintStyle::setStyle(PrintStyle::MIGRATE);
+    // cout << defs;
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_destroy_log) {
+    Log::destroy();
+    fs::remove("test_add_log.log");
+    BOOST_CHECK_MESSAGE(true, "stop boost test form complaining");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestJobGenPerf.cpp 5.13.0-1/libs/base/test/TestJobGenPerf.cpp
--- 5.12.4-1/libs/base/test/TestJobGenPerf.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestJobGenPerf.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,186 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+#include <vector>
+
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/JobProfiler.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// #define DEBUG 1
+
+// This relies on Pyext/samples/TestJobGenPerf.py to make any defs amenable
+// for this test program.
+//
+// The defs is in /var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf
+//
+// Timing for /var/tmp/ma0/DEFS/metabuilder.def
+// First/base point: real:10.15  user: 5.58  sys: 1.62
+// After ECFLOW-846: real: 4.46  user: 3.72  sys: 0.74  # Only open/close include file once
+// After ECFLOW-864: real: 4.36  user: 3.68  sys: 0.68  # minimise stat calls
+//
+//     strace -c ./Base/bin/gcc-4.8/release/perf_job_gen ./metabuilder.def
+//
+//                            % time     seconds  usecs/call     calls    errors syscall
+//                            ------ ----------- ----------- --------- --------- ----------------
+//   Before ECFLOW-864:        22.77    0.001159           0    132329     50737 stat
+//   After  ECFLOW-864:        21.35    0.001097           0    125644     50737 stat
+//
+//
+// After ECFLOW-1244:
+//  - cacheing of stat of include files
+//  - re-arranging EcfFile data member for hotness
+//  - re-arrange search for generation variables, most common first
+//  - replace ecffile_->countEcfMicro _. EcfFile::countEcfMicro(..) remove reference since function is static
+//
+// time Base/bin/gcc-5.3.0/release/perf_job_gen ./metabuilder.def : submitted 5808 out of 7941( fastest of 10 attempts)
+// - ECFLOW-1244: real: 2.84s user: 2.41s sys: 0.40s
+//
+// perf stat -r 10 -d Base/bin/gcc-5.3.0/release/perf_job_gen ./metabuilder.def
+// Performance counter stats for 'Base/bin/gcc-5.3.0/release/perf_job_gen ./metabuilder.def' (10 runs):
+//
+//       2908.895909      task-clock (msec)         #    0.933 CPUs utilized            ( +-  1.02% )
+//                89      context-switches          #    0.031 K/sec                    ( +-  7.13% )
+//                 2      cpu-migrations            #    0.001 K/sec                    ( +- 25.00% )
+//            11,500      page-faults               #    0.004 M/sec                    ( +-  0.03% )
+//    10,900,694,824      cycles                    #    3.747 GHz                      ( +-  0.93% )  (37.44%)
+//     4,810,738,973      stalled-cycles-frontend   #   44.13% frontend cycles idle     ( +-  2.34% )  (49.98%)
+//   <not supported>      stalled-cycles-backend
+//    13,845,775,843      instructions              #    1.27  insns per cycle
+//                                                  #    0.35  stalled cycles per insn  ( +-  0.03% )  (62.51%)
+//     3,777,695,721      branches                  # 1298.670 M/sec                    ( +-  0.05% )  (62.56%)
+//       107,367,375      branch-misses             #    2.84% of all branches          ( +-  0.15% )  (62.70%)
+//     3,410,593,440      L1-dcache-loads           # 1172.470 M/sec                    ( +-  0.09% )  (49.60%)
+//       260,536,494      L1-dcache-load-misses     #    7.64% of all L1-dcache hits    ( +-  0.13% )  (24.94%)
+//       101,191,979      LLC-loads                 #   34.787 M/sec                    ( +-  0.20% )  (24.90%)
+//   <not supported>      LLC-load-misses
+//
+//       3.118979324 seconds time elapsed                                          ( +-  2.80% )
+
+int main(int argc, char* argv[]) {
+    if (argc != 2) {
+        cout << "TestJobGenPerf.cpp --> " << argv[0] << "\n";
+        cout << "Expect single argument which is path to a defs file\n";
+        return 1;
+    }
+
+    // delete the log file if it exists.
+    std::string log_path = File::test_data("Base/test/TestJobGenPerf.log", "Base");
+    fs::remove(log_path);
+    std::string path = argv[1];
+
+#ifdef DEBUG
+    cout << "Loading file " << path << " log file " << log_path << "\n";
+#endif
+    Defs defs;
+    std::string errorMsg, warningMsg;
+    if (!defs.restore(path, errorMsg, warningMsg)) {
+        cout << errorMsg << "\n";
+        cout << warningMsg << "\n";
+        return 1;
+    }
+
+    //   std::vector<std::string> suites_to_remove;
+    //   suites_to_remove.push_back("codes_ui");
+    //   suites_to_remove.push_back("libemos_test");
+    //   suites_to_remove.push_back("metview");
+    //   suites_to_remove.push_back("ecflow");
+    //   suites_to_remove.push_back("mir_bundle");
+    // #ifdef DEBUG
+    //   cout << "remove dodgy suites, these are based on localhost\n";
+    // #endif
+    //   for(size_t i = 0; i < suites_to_remove.size(); ++i) {
+    //      suite_ptr suite = defs.findSuite(suites_to_remove[i]);
+    //      if (suite) suite->remove();
+    //   }
+    //   cout << defs ;
+    //   exit(0);
+
+    // Check number of tasks, if the submitted output below is too low
+    std::vector<Task*> tasks;
+    defs.getAllTasks(tasks);
+
+    // #ifdef DEBUG
+    //    cout << "Total number of tasks: " << tasks.size() << "\n";
+    //    cout << "begin-all\n";
+    // #endif
+
+    defs.beginAll();
+
+    // #ifdef DEBUG
+    //    cout << "Free all dependencies, free suspended time and trigger dependencies\n";
+    // #endif
+
+    std::vector<node_ptr> all_nodes;
+    defs.get_all_nodes(all_nodes);
+    for (size_t i = 0; i < all_nodes.size(); ++i) {
+        if (all_nodes[i]->isSuspended())
+            all_nodes[i]->resume();
+        all_nodes[i]->freeTrigger();
+        all_nodes[i]->freeHoldingDateDependencies();
+        all_nodes[i]->freeHoldingTimeDependencies();
+
+        const std::vector<InLimit>& inlimits = all_nodes[i]->inlimits();
+        for (const auto& inlim : inlimits)
+            all_nodes[i]->deleteInlimit(inlim.name());
+
+        if (all_nodes[i]->state() == NState::COMPLETE && all_nodes[i]->isTask()) {
+            all_nodes[i]->set_state(NState::QUEUED);
+        }
+    }
+
+    // Create a new log, file, place after begin to avoid queued state
+    TestLog test_log(log_path); // will create log file, and destroy log and remove file at end of scope
+
+    // This controls the log output when job generation > submitJobsInterval
+    JobProfiler::set_task_threshold(100); // 100ms where 1000ms is one second
+
+    JobsParam jobParam(20 /*submitJobsInterval*/, true /*createJobs*/, false /* spawn jobs */);
+    Jobs job(&defs);
+    if (!job.generate(jobParam))
+        cout << " generate failed: " << jobParam.getErrorMsg();
+    cout << "submitted " << jobParam.submitted().size() << " out of " << tasks.size() << "\n";
+
+    if (jobParam.submitted().size() != tasks.size()) {
+        for (size_t i = 0; i < tasks.size(); i++) {
+            if (tasks[i]->state() != NState::SUBMITTED &&
+                tasks[i]->findVariable("ECF_DUMMY_TASK") == Variable::EMPTY()) {
+                // We are NOT a dummy task
+                cout << "task " << tasks[i]->absNodePath() << " state: " << NState::toString(tasks[i]->state()) << "\n";
+
+                Node* parent = tasks[i]->parent();
+                while (parent) {
+                    cout << " node " << parent->absNodePath() << " state: " << NState::toString(parent->state())
+                         << "\n";
+                    parent = parent->parent();
+                }
+
+                std::vector<std::string> theReasonWhy;
+                tasks[i]->bottom_up_why(theReasonWhy, false /*html tags*/);
+                for (const auto& r : theReasonWhy) {
+                    cout << "  Reason: " << r << "\n";
+                }
+            }
+        }
+    }
+
+    return 0;
+}
diff -pruN 5.12.4-1/libs/base/test/TestLogCmd.cpp 5.13.0-1/libs/base/test/TestLogCmd.cpp
--- 5.12.4-1/libs/base/test/TestLogCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestLogCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,105 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/LogCmd.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace boost;
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_LogCmd)
+
+BOOST_AUTO_TEST_CASE(test_log_cmd) {
+    cout << "Base:: ...test_log_cmd\n";
+
+    {
+        LogCmd log_cmd;
+        BOOST_REQUIRE_MESSAGE(log_cmd.api() == LogCmd::GET, " expected GET as the default");
+        BOOST_REQUIRE_MESSAGE(log_cmd.new_path() == "", "expected empty path but found " << log_cmd.new_path());
+    }
+
+    {
+        LogCmd log_cmd("/a/path");
+        BOOST_REQUIRE_MESSAGE(log_cmd.api() == LogCmd::NEW, " expected NEW as the default api when path provided");
+        BOOST_REQUIRE_MESSAGE(log_cmd.new_path() == "/a/path", "expected 'a/path' but found " << log_cmd.new_path());
+    }
+
+    // ECFLOW-377
+    {
+        LogCmd log_cmd("/a/path ");
+        BOOST_CHECK_MESSAGE(log_cmd.new_path() == "/a/path",
+                            "expected '/a/path' but found '" << log_cmd.new_path() << "'");
+    }
+    {
+        LogCmd log_cmd(" /a/path");
+        BOOST_CHECK_MESSAGE(log_cmd.new_path() == "/a/path",
+                            "expected '/a/path' but found '" << log_cmd.new_path() << "'");
+    }
+    {
+        LogCmd log_cmd(" /a/path ");
+        BOOST_CHECK_MESSAGE(log_cmd.new_path() == "/a/path",
+                            "expected '/a/path' but found '" << log_cmd.new_path() << "'");
+    }
+
+    // Create a new log file, equivalent --log=new .../Base/test/new_logfile.txt
+    // LogCmd::doHandleRequest needs log file to have been created first
+    std::string old_log_file = File::test_data("libs/base/test/old_logfile.txt", "libs/base");
+    Log::instance()->create(old_log_file);
+
+    std::string new_log_file =
+        File::test_data("libs/base/test/new_logfile.txt ", "libs/base"); // ECFLOW-377 note extra space at the end
+    std::string expected_new_log_file = File::test_data("libs/base/test/new_logfile.txt", "libs/base"); // space removed
+
+    // ECFLOW-376 --log=new <path> should be treated same as changing ECF_LOG from the gui. i.e added as a user
+    // variable. hence visible in GUI
+    Defs defs;
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new LogCmd(new_log_file)), false /* check_change_numbers */);
+    BOOST_CHECK_MESSAGE(defs.server().find_variable("ECF_LOG") == expected_new_log_file,
+                        "expected to find ECF_LOG with value '" << expected_new_log_file << "' but found '"
+                                                                << defs.server().find_variable("ECF_LOG") << "'");
+    std::string value;
+    BOOST_CHECK_MESSAGE(defs.server().find_user_variable("ECF_LOG", value) && (value == expected_new_log_file),
+                        "expected to find ECF_LOG in the *USER* variables '" << expected_new_log_file << "' but found '"
+                                                                             << value << "'");
+    BOOST_CHECK_MESSAGE(Log::instance()->path() == expected_new_log_file,
+                        "expected to find ECF_LOG with value '" << expected_new_log_file << "' but found '"
+                                                                << defs.server().find_variable("ECF_LOG") << "'");
+
+    // Update ECF_LOG to have a *SPACE* at the end.  ECFLOW-377
+    defs.set_server().add_or_update_user_variables(Str::ECF_LOG(), new_log_file);
+    BOOST_CHECK_MESSAGE(defs.server().find_variable("ECF_LOG") == new_log_file,
+                        "expected to find ECF_LOG with value '" << new_log_file << "' but found '"
+                                                                << defs.server().find_variable("ECF_LOG") << "'");
+
+    // INVOKE log command where we update log file from ECF_LOG, equivalent --log=new
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new LogCmd(LogCmd::NEW)), false /* check_change_numbers */);
+    BOOST_CHECK_MESSAGE(Log::instance()->path() == expected_new_log_file,
+                        "expected to find Log::instance()->path() with value '"
+                            << expected_new_log_file << "' but found '" << defs.server().find_variable("ECF_LOG")
+                            << "'");
+
+    // tidy up
+    Log::instance()->destroy();
+    fs::remove(old_log_file);          // remove generated log file
+    fs::remove(expected_new_log_file); // remove generated log file
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestMeterCmd.cpp 5.13.0-1/libs/base/test/TestMeterCmd.cpp
--- 5.12.4-1/libs/base/test/TestMeterCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestMeterCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,123 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_MeterCmd)
+
+BOOST_AUTO_TEST_CASE(test_meter_cmd) {
+    cout << "Base:: ...test_meter_cmd\n";
+    TestLog test_log("test_meter_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    // Create the defs file.
+    // suite suite
+    //    family f
+    //          task t1
+    //              meter m 0 100 100
+    //    endfamily
+    // endsuite
+    Defs defs;
+    string suite_f_t1      = "suite/f/t1";
+    task_ptr t1            = Task::create("t1");
+    std::string meter_name = "m";
+    {
+        t1->addMeter(Meter(meter_name, 0, 100, 100));
+        suite_ptr s  = Suite::create("suite");
+        family_ptr f = Family::create("f");
+        f->addTask(t1);
+        s->addFamily(f);
+        defs.addSuite(s);
+    }
+
+    // Meter which doesn't exist should be silently ignore
+    int meter_value = 10;
+    TestHelper::invokeRequest(&defs,
+                              Cmd_ptr(new MeterCmd(suite_f_t1,
+                                                   Submittable::DUMMY_JOBS_PASSWORD(),
+                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                   1,
+                                                   "FRED",
+                                                   meter_value)),
+                              false /* expect change number not to change */
+    );
+
+    /// Test setting meter value
+    TestHelper::invokeRequest(&defs,
+                              Cmd_ptr(new MeterCmd(suite_f_t1,
+                                                   Submittable::DUMMY_JOBS_PASSWORD(),
+                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                   1,
+                                                   meter_name,
+                                                   meter_value)));
+    const Meter& the_meter = t1->findMeter(meter_name);
+    BOOST_CHECK_MESSAGE(!the_meter.empty(), "Meter not found");
+    BOOST_CHECK_MESSAGE(the_meter.value() == meter_value,
+                        "Expected meter value " << meter_value << " but found " << the_meter.value());
+
+    /// Set a meter value less than the current value.
+    meter_value = 9;
+    TestHelper::invokeRequest(&defs,
+                              Cmd_ptr(new MeterCmd(suite_f_t1,
+                                                   Submittable::DUMMY_JOBS_PASSWORD(),
+                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                   1,
+                                                   meter_name,
+                                                   meter_value)));
+    BOOST_CHECK_MESSAGE(the_meter.value() == meter_value,
+                        "Expected meter value " << meter_value << " but found " << the_meter.value());
+
+    /// Set a meter value greater than max meter, this should be ignored
+    /// Avoid failing task, if meter,  value is out of range. Just log a warning message
+    meter_value = 2000;
+    TestHelper::invokeRequest(&defs,
+                              Cmd_ptr(new MeterCmd(suite_f_t1,
+                                                   Submittable::DUMMY_JOBS_PASSWORD(),
+                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                   1,
+                                                   meter_name,
+                                                   meter_value)),
+                              false /* expect change number not to change */);
+    BOOST_CHECK_MESSAGE(the_meter.value() == 9, "Expected meter value 9 but found " << the_meter.value());
+
+    /// Set to valid value
+    meter_value = 20;
+    TestHelper::invokeRequest(&defs,
+                              Cmd_ptr(new MeterCmd(suite_f_t1,
+                                                   Submittable::DUMMY_JOBS_PASSWORD(),
+                                                   Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                   1,
+                                                   meter_name,
+                                                   meter_value)));
+    BOOST_CHECK_MESSAGE(the_meter.value() == meter_value,
+                        "Expected meter value " << meter_value << " but found " << the_meter.value());
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestProgramOptions.cpp 5.13.0-1/libs/base/test/TestProgramOptions.cpp
--- 5.12.4-1/libs/base/test/TestProgramOptions.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestProgramOptions.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,151 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/program_options.hpp>
+#include <boost/test/unit_test.hpp>
+
+using namespace std;
+namespace po = boost::program_options;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_ProgramOptions)
+
+BOOST_AUTO_TEST_CASE(test_program_options_implicit_value) {
+    cout << "Base:: ...test_program_options_implicit_value\n";
+
+    // Declare the supported options.
+    po::options_description desc("Allowed options");
+    desc.add_options()("help", "produce help message")(
+        "arg1", po::value<string>()->implicit_value(string("")), "optional arg1 description");
+
+    {
+        char* argv[] = {const_cast<char*>("test_program_options_implicit_value"),
+                        const_cast<char*>("--help"),
+                        const_cast<char*>("--arg1")};
+
+        po::variables_map vm;
+        po::store(po::parse_command_line(3, argv, desc), vm); // populate variable map
+        po::notify(vm);                                       // raise any errors
+
+        BOOST_CHECK_MESSAGE(vm.count("help"), "Expected help");
+        BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
+        BOOST_CHECK_MESSAGE(vm["arg1"].as<string>() == "", "Expected arg1 to be empty");
+    }
+    //   {
+    //      // This test fails on boost 1.59, can't cope --arg1 10, only --arg1=10 *******
+    //      // See: ECFLOW-509 and https://svn.boost.org/trac/boost/ticket/11893
+    //      char* argv[] = {
+    //            const_cast<char*>("test_program_options_implicit_value"),
+    //            const_cast<char*>("--arg1"),
+    //            const_cast<char*>("10")
+    //      };
+    //
+    //      po::variables_map vm;
+    ////      po::store(po::parse_command_line(3, argv, desc,
+    ////                        po::command_line_style::unix_style ^ po::command_line_style::allow_short ^
+    ////                        po::command_line_style::long_allow_adjacent |
+    ////                        po::command_line_style::short_allow_adjacent |
+    ////                        po::command_line_style::allow_long_disguise
+    ////                ), vm);
+    //
+    //      po::store(po::command_line_parser(3,argv).options(desc).style(
+    //                       po::command_line_style::long_allow_next |
+    //                       po::command_line_style::allow_long_disguise |
+    //                       po::command_line_style::long_allow_adjacent).run(),
+    //                vm);
+    //      po::notify(vm);
+    //
+    //      BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
+    //      BOOST_CHECK_MESSAGE(vm["arg1"].as<string>() == "10", "Expected arg1 with value of 10 but found '" <<
+    //      vm["arg1"].as<string>() << "'");
+    //   }
+
+    {
+        char* argv[] = {const_cast<char*>("test_program_options_implicit_value"), const_cast<char*>("--arg1=11")};
+
+        po::variables_map vm;
+        po::store(po::parse_command_line(2, argv, desc), vm);
+        po::notify(vm);
+
+        BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
+        BOOST_CHECK_MESSAGE(vm["arg1"].as<string>() == "11",
+                            "Expected arg1 with value of 11 but found " << vm["arg1"].as<string>());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_program_options_multitoken) {
+    cout << "Base:: ...test_program_options_multitoken\n";
+
+    // Declare the supported options.
+    po::options_description desc("Allowed options");
+    desc.add_options()("help",
+                       "produce help message")("arg1", po::value<vector<string>>()->multitoken(), "arg1 description");
+
+    char* argv[] = {const_cast<char*>("test_program_options_multitoken"),
+                    const_cast<char*>("--help"),
+                    const_cast<char*>("--arg1"),
+                    const_cast<char*>("a"),
+                    const_cast<char*>("b")};
+
+    po::variables_map vm;
+    po::store(po::parse_command_line(5, argv, desc), vm);
+    po::notify(vm);
+
+    BOOST_CHECK_MESSAGE(vm.count("help"), "Expected help");
+    BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
+
+    std::vector<string> expected;
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    BOOST_CHECK_MESSAGE(vm["arg1"].as<vector<string>>() == expected, "multi-token not as expected");
+}
+
+BOOST_AUTO_TEST_CASE(test_program_options_multitoken_with_negative_values) {
+    cout << "Base:: ...test_program_options_multitoken_with_negative_values\n";
+
+    // Declare the supported options.
+    po::options_description desc("Allowed options");
+    desc.add_options()("help",
+                       "produce help message")("arg1", po::value<vector<string>>()->multitoken(), "arg1 description");
+
+    char* argv[] = {const_cast<char*>("test_program_options_multitoken_1"),
+                    const_cast<char*>("--help"),
+                    const_cast<char*>("--arg1"),
+                    const_cast<char*>("-1"),
+                    const_cast<char*>("-w")};
+
+    //  --alter delete cron -w 0,1 10:00 /s1     # -w treated as option
+    //  --alter=/s1 change meter name -1         # -1 treated as option
+    // Note: negative numbers get treated as options: i.e trying to change meter value to a negative number
+    //  To avoid negative numbers from being treated as option use, we need to change command line style:
+    //       po::command_line_style::unix_style ^ po::command_line_style::allow_short
+
+    po::variables_map vm;
+    po::store(
+        po::parse_command_line(5, argv, desc, po::command_line_style::unix_style ^ po::command_line_style::allow_short),
+        vm);
+    po::notify(vm);
+
+    BOOST_CHECK_MESSAGE(vm.count("help"), "Expected help");
+    BOOST_CHECK_MESSAGE(vm.count("arg1"), "Expected arg1");
+
+    std::vector<string> expected;
+    expected.emplace_back("-1");
+    expected.emplace_back("-w");
+    BOOST_CHECK_MESSAGE(vm["arg1"].as<vector<string>>() == expected, "multi-token not as expected");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestQueryCmd.cpp 5.13.0-1/libs/base/test/TestQueryCmd.cpp
--- 5.12.4-1/libs/base/test/TestQueryCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestQueryCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,216 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/task/LabelCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/cts/user/QueryCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_QueryCmd)
+
+BOOST_AUTO_TEST_CASE(test_query_cmd) {
+    cout << "Base:: ...test_query_cmd\n";
+    TestLog test_log("test_query_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    // Create the defs file.
+    // suite suite
+    //    limit limit_x 12
+    //    repeat date YMD 20090916 20200916
+    //    family f
+    //          edit var2 var2
+    //          task t1
+    //              edit var1 var1
+    //              meter m 0 100 100
+    //              event event
+    //              trigger t2 == complete
+    //          task t2
+    //              label name value new_value
+    //              label name2 value2
+    //    endfamily
+    //    task task
+    // endsuite
+    Defs defs;
+    string suite_f_t1 = "suite/f/t1";
+    task_ptr t1       = Task::create("t1");
+    task_ptr t2;
+    task_ptr task          = Task::create("task");
+    string suite_task      = "suite/task";
+    std::string meter_name = "m";
+    std::string event_name = "event";
+    std::string label_name = "name";
+    std::string limit_name = "limit_x";
+    {
+        t1->addMeter(Meter(meter_name, 0, 100, 100));
+        t1->addEvent(Event(event_name));
+        t1->add_variable("var1", "var1");
+
+        suite_ptr s = defs.add_suite("suite");
+        s->addLimit(Limit(limit_name, 12));
+
+        s->addRepeat(RepeatDate("YMD", 20090916, 20200916, 1));
+        family_ptr f = s->add_family("f");
+        f->add_variable("var2", "var2");
+        f->addTask(t1);
+        t2 = f->add_task("t2");
+        t2->add_label(label_name, "value", "");
+        s->addTask(task);
+    }
+
+    defs.beginAll(); // this will clear label new_value
+
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("state", "/suite/f/t11", "", "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("dstate", "/suite/f/t11", "", "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(
+        &defs, Cmd_ptr(new QueryCmd("repeat", "/suite/f/t1", "", "/suite/f/t1"))); // no repeat on /suite/f/t1
+    TestHelper::invokeFailureRequest(
+        &defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "fred", "/suite"))); // Only next | prev are valid
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("event", "/suite/f/t1", "eventxx", "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("event", "/suite", event_name, "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("event", "xxxx/f/t1", event_name, "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("limit", "xxxx/f/t1", limit_name, "/suite")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("limit_max", "xxxx/f/t1", limit_name, "/suite")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("meter", "/suite/f/t1", "meterxx", "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("meter", "/suite", meter_name, "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(
+        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t1", label_name, "/suite/f/t1"))); // no label on t1
+    TestHelper::invokeFailureRequest(
+        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t2", "fred", "/suite/f/t2"))); // wrong label name
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("trigger", "/suite", "1 == ", "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "1 == ", "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "XXXX", "/suite/f/t1")));
+    TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new QueryCmd("xxxxx", "/suite/f/t1", event_name, "/suite/f/t1")));
+
+    // t3 does not exist
+    TestHelper::invokeFailureRequest(&defs,
+                                     Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "t3 == complete", "/suite/f/t1")));
+
+    // QueryCmd is read only, hence change numbers should not change
+    std::string res;
+    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("state", "/suite", "", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "queued", "expected query state to return queued but found: " << res);
+
+    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("dstate", "/suite/f", "", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "queued", "expected query state to return queued but found: " << res);
+
+    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "", "/suite")), false);
+    BOOST_CHECK_MESSAGE(res == "20090916", "expected query repeat to return '20090916' but found : " << res);
+
+    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "prev", "/suite")), false);
+    BOOST_CHECK_MESSAGE(res == "20090916", "expected query repeat to return '20090916' but found : " << res);
+
+    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("repeat", "/suite", "next", "/suite")), false);
+    BOOST_CHECK_MESSAGE(res == "20090917", "expected query repeat to return '20090917' but found : " << res);
+
+    // Note: we pick a task outside of a repeat, since setting a task to complete, inside a repeat will cause it to
+    // requeue Avoid using ForceCmd to avoid side affects
+    std::vector<std::string> states = NState::allStates();
+    for (const auto& state : states) {
+        task->setStateOnly(NState::toState(state));
+        res = TestHelper::invokeRequest(
+            &defs, Cmd_ptr(new QueryCmd("state", task->absNodePath(), "", task->absNodePath())), false);
+        BOOST_CHECK_MESSAGE(res == state, "expected query state to return " << state << " but found: " << res);
+    }
+
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, task->absNodePath())));
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("dstate", task->absNodePath(), "", task->absNodePath())), false);
+    BOOST_CHECK_MESSAGE(res == "suspended", "expected query state to return suspend but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("event", "/suite/f/t1", event_name, "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "clear", "expected query event to return clear but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("meter", "/suite/f/t1", meter_name, "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "0", "expected query meter to return 0 but found: " << res);
+
+    res = TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("limit", "/suite", limit_name, "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "0", "expected query limit to return 0 but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("limit_max", "/suite", limit_name, "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "12", "expected query limit_max to return 12 but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t2", label_name, "/suite/f/t2")), false);
+    BOOST_CHECK_MESSAGE(res == "value", "expected query label to return 'value' but found: " << res);
+    res = TestHelper::invokeRequest(&defs,
+                                    Cmd_ptr(new LabelCmd("/suite/f/t2",
+                                                         Submittable::DUMMY_JOBS_PASSWORD(),
+                                                         Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                         1,
+                                                         label_name,
+                                                         "new_value")));
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("label", "/suite/f/t2", label_name, "/suite/f/t2")), false);
+    BOOST_CHECK_MESSAGE(res == "new_value", "expected query label to return 'new_value' but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "t2 == complete", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "false", "expected query trigger to return false but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "1 == 1", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f/t1:var1 == 0", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f:var2 == 0", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f/t1:m == 0", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite/f/t1", "/suite/f/t1:event", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "false", "expected query trigger to return false but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("trigger", "/suite", "/suite:YMD == 20090916", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "true", "expected query trigger to return true but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "var1", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "var1", "expected query variable to return var2 but found: " << res);
+
+    res = TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "var2", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "var2", "expected query variable to return var2 but found: " << res);
+
+    res =
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new QueryCmd("variable", "/suite/f/t1", "YMD", "/suite/f/t1")), false);
+    BOOST_CHECK_MESSAGE(res == "20090916", "expected query variable to return 20090916 but found: " << res);
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestQueueCmd.cpp 5.13.0-1/libs/base/test/TestQueueCmd.cpp
--- 5.12.4-1/libs/base/test/TestQueueCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestQueueCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,251 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/base/cts/task/QueueCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_QueueCmd)
+
+BOOST_AUTO_TEST_CASE(test_queue_cmd) {
+    cout << "Base:: ...test_queue_cmd\n";
+    TestLog test_log("test_queue_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    // Create the defs file.
+    // suite suite
+    //    queue q1 s1 s2 s3
+    //    family f
+    //          queue q2 f1 f2 f3
+    //          task t
+    //             queue q3 t1 t2 t3
+    //    endfamily
+    // endsuite
+    Defs defs;
+    string suite_f_t = "/suite/f/t";
+
+    suite_ptr s = defs.add_suite("suite");
+    QueueAttr q1("q1", {"s1", "s2", "s3"});
+    s->add_queue(q1);
+    QueueAttr& q1_ref = s->findQueue("q1");
+    BOOST_REQUIRE_MESSAGE(!q1_ref.empty(), "queue not found");
+    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 0, "Expected to 0 index but found " << q1_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q1_ref.value() == "s1", "Expected to s1 but found " << q1_ref.value());
+
+    family_ptr f = s->add_family("f");
+    QueueAttr q2("q2", {"f1", "f2", "f3"});
+    f->add_queue(q2);
+    QueueAttr& q2_ref = f->findQueue("q2");
+    BOOST_REQUIRE_MESSAGE(!q2_ref.empty(), "queue not found");
+    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 0, "Expected to 0 index but found " << q2_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q2_ref.value() == "f1", "Expected to f1 but found " << q2_ref.value());
+
+    task_ptr t = f->add_task("t");
+    QueueAttr q3("q3", {"t1", "t2", "t3"});
+    t->add_queue(q3);
+    QueueAttr& q3_ref = t->findQueue("q3");
+    BOOST_REQUIRE_MESSAGE(!q3_ref.empty(), "queue not found");
+    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 0, "Expected to 0 index but found " << q3_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q3_ref.value() == "t1", "Expected to t1 but found " << q3_ref.value());
+
+    // cout << defs;
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////
+    // Update q1, this on the suite. hence we should find it up the hierarchy
+    std::string step = TestHelper::invokeRequest(&defs,
+                                                 Cmd_ptr(new QueueCmd(suite_f_t,
+                                                                      Submittable::DUMMY_JOBS_PASSWORD(),
+                                                                      Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                                      1,
+                                                                      "q1",
+                                                                      "active")));
+    BOOST_CHECK_MESSAGE(step == "s1", "Expected step s1 but found " << step);
+    BOOST_CHECK_MESSAGE(NState::ACTIVE == q1_ref.state(step),
+                        "Expected ACTIVE step but found " << NState::toString(q1_ref.state(step)));
+    q1_ref.aborted(step);
+    BOOST_CHECK_MESSAGE(NState::ABORTED == q1_ref.state(step),
+                        "Expected ABORTED step but found " << NState::toString(q1_ref.state(step)));
+    q1_ref.complete(step);
+    BOOST_CHECK_MESSAGE(NState::COMPLETE == q1_ref.state(step),
+                        "Expected COMPLETE step but found " << NState::toString(q1_ref.state(step)));
+    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 1, "Expected 1 for index but found " << q1_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q1_ref.value() == "s2", "Expected s2 for value but found " << q1_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q1",
+                                                          "active")));
+    BOOST_CHECK_MESSAGE(step == "s2", "Expected step s2 but found " << step);
+    BOOST_CHECK_MESSAGE(NState::ACTIVE == q1_ref.state(step),
+                        "Expected ACTIVE step but found " << NState::toString(q1_ref.state(step)));
+    q1_ref.aborted(step);
+    BOOST_CHECK_MESSAGE(NState::ABORTED == q1_ref.state(step),
+                        "Expected ABORTED step but found " << NState::toString(q1_ref.state(step)));
+    BOOST_CHECK_MESSAGE(q1_ref.no_of_aborted() == "1", "Expected  1 aborted step but found " << q1_ref.no_of_aborted());
+    q1_ref.complete(step);
+    BOOST_CHECK_MESSAGE(q1_ref.no_of_aborted() == "",
+                        "Expected *NO* aborted step but found " << q1_ref.no_of_aborted());
+    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 2, "Expected 2 for index but found " << q1_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q1_ref.value() == "s3", "Expected to s3 but found " << q1_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q1",
+                                                          "active")));
+    BOOST_CHECK_MESSAGE(step == "s3", "Expected step s3 but found " << step);
+    BOOST_CHECK_MESSAGE(NState::ACTIVE == q1_ref.state(step),
+                        "Expected ACTIVE step but found " << NState::toString(q1_ref.state(step)));
+    q1_ref.aborted(step);
+    BOOST_CHECK_MESSAGE(NState::ABORTED == q1_ref.state(step),
+                        "Expected ABORTED step but found " << NState::toString(q1_ref.state(step)));
+    q1_ref.complete(step);
+    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 3, "Expected 3 for index but found " << q1_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q1_ref.value() == "<NULL>", "Expected to <NULL> but found " << q1_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q1",
+                                                          "active")),
+                                     false);
+    BOOST_CHECK_MESSAGE(step == "<NULL>", "Expected step <NULL> but found " << step);
+    BOOST_CHECK_MESSAGE(q1_ref.index_or_value() == 3, "Expected 3 for index but found " << q1_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q1_ref.value() == "<NULL>", "Expected to <NULL> but found " << q1_ref.value());
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////
+    // Update q2, this on the family, In this we sill specify path to the queue
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q2",
+                                                          "active",
+                                                          "",
+                                                          "/suite/f")));
+    BOOST_CHECK_MESSAGE(step == "f1", "Expected step f1 but found " << step);
+    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 1, "Expected 1 for index but found " << q2_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q2_ref.value() == "f2", "Expected to f2 but found " << q2_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q2",
+                                                          "active",
+                                                          "",
+                                                          "/suite/f")));
+    BOOST_CHECK_MESSAGE(step == "f2", "Expected step f2 but found " << step);
+    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 2, "Expected 2 for index but found " << q2_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q2_ref.value() == "f3", "Expected to f3 but found " << q2_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q2",
+                                                          "active",
+                                                          "",
+                                                          "/suite/f")));
+    BOOST_CHECK_MESSAGE(step == "f3", "Expected step f3 but found " << step);
+    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 3, "Expected 3 for index but found " << q2_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q2_ref.value() == "<NULL>", "Expected to <NULL> but found " << q2_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q2",
+                                                          "active",
+                                                          "",
+                                                          "/suite/f")),
+                                     false);
+    BOOST_CHECK_MESSAGE(q2_ref.index_or_value() == 3, "Expected 3 for index but found " << q2_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q2_ref.value() == "<NULL>", "Expected to <NULL> but found " << q2_ref.value());
+
+    /////////////////////////////////////////////////////////////////////////////////////////////////////
+    // Update q3, this on the task
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q3",
+                                                          "active")));
+    BOOST_CHECK_MESSAGE(step == "t1", "Expected step t1 but found " << step);
+    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 1, "Expected 1 for index but found " << q3_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q3_ref.value() == "t2", "Expected to t2 but found " << q3_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q3",
+                                                          "active")));
+    BOOST_CHECK_MESSAGE(step == "t2", "Expected step t2 but found " << step);
+    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 2, "Expected 2 for index but found " << q3_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q3_ref.value() == "t3", "Expected to t3 but found " << q3_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q3",
+                                                          "active")));
+    BOOST_CHECK_MESSAGE(step == "t3", "Expected step t3 but found " << step);
+    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 3, "Expected 3 for index but found " << q3_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q3_ref.value() == "<NULL>", "Expected to <NULL> but found " << q3_ref.value());
+
+    step = TestHelper::invokeRequest(&defs,
+                                     Cmd_ptr(new QueueCmd(suite_f_t,
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          "q3",
+                                                          "active")),
+                                     false);
+    BOOST_CHECK_MESSAGE(step == "<NULL>", "Expected step <NULL> but found " << step);
+    BOOST_CHECK_MESSAGE(q3_ref.index_or_value() == 3, "Expected 3 for index but found " << q3_ref.index_or_value());
+    BOOST_CHECK_MESSAGE(q3_ref.value() == "<NULL>", "Expected to <NULL> but found " << q3_ref.value());
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestRequest.cpp 5.13.0-1/libs/base/test/TestRequest.cpp
--- 5.12.4-1/libs/base/test/TestRequest.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestRequest.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,472 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "TestHelper.hpp"
+#include "ecflow/base/ServerToClientResponse.hpp"
+#include "ecflow/base/cts/task/AbortCmd.hpp"
+#include "ecflow/base/cts/task/CompleteCmd.hpp"
+#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
+#include "ecflow/base/cts/task/EventCmd.hpp"
+#include "ecflow/base/cts/task/InitCmd.hpp"
+#include "ecflow/base/cts/task/LabelCmd.hpp"
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+#include "ecflow/base/cts/task/QueueCmd.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/CFileCmd.hpp"
+#include "ecflow/base/cts/user/CSyncCmd.hpp"
+#include "ecflow/base/cts/user/CheckPtCmd.hpp"
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
+#include "ecflow/base/cts/user/EditScriptCmd.hpp"
+#include "ecflow/base/cts/user/ForceCmd.hpp"
+#include "ecflow/base/cts/user/FreeDepCmd.hpp"
+#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
+#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
+#include "ecflow/base/cts/user/LogCmd.hpp"
+#include "ecflow/base/cts/user/LogMessageCmd.hpp"
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/cts/user/PlugCmd.hpp"
+#include "ecflow/base/cts/user/QueryCmd.hpp"
+#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/base/cts/user/RunNodeCmd.hpp"
+#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
+#include "ecflow/base/cts/user/ShowCmd.hpp"
+#include "ecflow/base/cts/user/ZombieCmd.hpp"
+#include "ecflow/base/stc/BlockClientZombieCmd.hpp"
+#include "ecflow/base/stc/DefsCmd.hpp"
+#include "ecflow/base/stc/ErrorCmd.hpp"
+#include "ecflow/base/stc/GroupSTCCmd.hpp"
+#include "ecflow/base/stc/SNewsCmd.hpp"
+#include "ecflow/base/stc/SNodeCmd.hpp"
+#include "ecflow/base/stc/SServerLoadCmd.hpp"
+#include "ecflow/base/stc/SStringCmd.hpp"
+#include "ecflow/base/stc/SSyncCmd.hpp"
+#include "ecflow/base/stc/StcCmd.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_FIXTURE_TEST_SUITE(U_Base, MyDefsFixture)
+
+BOOST_AUTO_TEST_SUITE(T_Request)
+
+// Can't delete the fixture defs, hence use a NULL deleter to avoid freeing memory twice.
+// Required since DefsCmd and LoadDefsCmd requires a shared_ptr.
+struct null_deleter
+{
+    void operator()(void const*) const {}
+};
+
+static void
+populateCmdVec(std::vector<Cmd_ptr>& cmd_vec, std::vector<STC_Cmd_ptr>& stc_cmd_vec, MockServer* mock_server) {
+    std::vector<std::string> suite_names;
+    suite_names.emplace_back("suiteName");
+    MyDefsFixture fixture;
+    defs_ptr client_defs = fixture.create_defs();
+    client_defs->clear_externs(); // server defs should not have externs
+
+    // Client --> Server commands
+    // make sure begin cmd is first. As this will init calendar. + other commands rely on it
+    // i.e RequeueNodeCmd assumes calendar has been initialized
+    cmd_vec.push_back(Cmd_ptr(new ShowCmd()));
+    cmd_vec.push_back(Cmd_ptr(new ServerVersionCmd()));
+    cmd_vec.push_back(Cmd_ptr(new ReplaceNodeCmd("suiteName", false, client_defs, true)));
+    cmd_vec.push_back(Cmd_ptr(new LoadDefsCmd(client_defs, true /*force*/)));
+    cmd_vec.push_back(
+        Cmd_ptr(new BeginCmd("suiteName"))); // after loading new defs, must call begin, for downstream cmds
+    cmd_vec.push_back(
+        Cmd_ptr(new BeginCmd("EmptySuite"))); // after loading new defs, must call begin for downstream cmds
+    cmd_vec.push_back(Cmd_ptr(new LogMessageCmd("LogMessageCmd")));
+    cmd_vec.push_back(Cmd_ptr(new LogCmd(LogCmd::CLEAR))); // server replies back OK/Error Cmd
+    cmd_vec.push_back(Cmd_ptr(new LogCmd(LogCmd::GET)));   // server replies back OK/Error | SStringCmd
+    cmd_vec.push_back(Cmd_ptr(new LogCmd(LogCmd::PATH)));  // server replies back Error |SStringCmd
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RESTORE_DEFS_FROM_CHECKPT)));
+    cmd_vec.push_back(Cmd_ptr(new CheckPtCmd()));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::PING)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::DEBUG_SERVER_ON)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::DEBUG_SERVER_OFF)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::SHUTDOWN_SERVER)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::HALT_SERVER)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::TERMINATE_SERVER)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_WHITE_LIST_FILE)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_PASSWD_FILE)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::STATS)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::STATS_SERVER)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::STATS_RESET)));
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(CtsCmd::SUITES)));
+    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(CSyncCmd::NEWS, 0, 0, 0)));
+    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(CSyncCmd::SYNC, 0, 0, 0)));
+    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(CSyncCmd::SYNC_CLOCK, 0, 0, 0)));
+    cmd_vec.push_back(Cmd_ptr(new CSyncCmd(0))); // SYNC_FULL
+    cmd_vec.push_back(Cmd_ptr(new RequeueNodeCmd("/suiteName", RequeueNodeCmd::NO_OPTION)));
+    cmd_vec.push_back(Cmd_ptr(new OrderNodeCmd("/suiteName", NOrder::ALPHA)));
+    cmd_vec.push_back(Cmd_ptr(new RunNodeCmd("/suiteName", true /* force for test */, true /* for test */)));
+    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, "EmptySuite")));
+    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::RESUME, "EmptySuite")));
+    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::KILL, "EmptySuite")));
+    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::STATUS, "EmptySuite")));
+    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::CHECK, "/suiteName")));
+    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::CHECK, "")));                  // check the full defs
+    cmd_vec.push_back(Cmd_ptr(new PathsCmd(PathsCmd::EDIT_HISTORY, "/suiteName"))); // check the full defs
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::WHY, "/suiteName")));
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET, "/suiteName")));
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE, "/suiteName")));
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE, "/suiteName")));
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::CHECK_JOB_GEN_ONLY, "EmptySuite"))); // will *reset* begin
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET, "")));                          // return the full defs
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE, "")));
+    cmd_vec.push_back(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE, "")));
+    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::FOB,
+                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                            Submittable::DUMMY_JOBS_PASSWORD())));
+    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::FAIL,
+                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                            Submittable::DUMMY_JOBS_PASSWORD())));
+    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::ADOPT,
+                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                            Submittable::DUMMY_JOBS_PASSWORD())));
+    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::REMOVE,
+                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                            Submittable::DUMMY_JOBS_PASSWORD())));
+    cmd_vec.push_back(Cmd_ptr(new ZombieCmd(ecf::User::KILL,
+                                            std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                            Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                            Submittable::DUMMY_JOBS_PASSWORD())));
+    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(0, suite_names, true)));                    // register
+    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1, suite_names, ClientHandleCmd::ADD)));    // add
+    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1, suite_names, ClientHandleCmd::REMOVE))); // remove
+    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1, true)));                                 // auto_add new suites
+    cmd_vec.push_back(Cmd_ptr(new ClientHandleCmd(1)));                                       // de-register/drop
+
+    cmd_vec.push_back(Cmd_ptr(new CtsCmd(
+        CtsCmd::RESTART_SERVER))); // make sure server is restarted or child cmds fail, as server will not allow comms
+
+    cmd_vec.push_back(Cmd_ptr(new InitCmd("suiteName/familyName/taskName",
+                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                          1)));
+    cmd_vec.push_back(Cmd_ptr(new EventCmd("suiteName/familyName/taskName",
+                                           Submittable::DUMMY_JOBS_PASSWORD(),
+                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                           1,
+                                           "eventName")));
+    cmd_vec.push_back(Cmd_ptr(new MeterCmd("suiteName/familyName/heir_familyName/taskName",
+                                           Submittable::DUMMY_JOBS_PASSWORD(),
+                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                           1,
+                                           "myMeter",
+                                           100)));
+    cmd_vec.push_back(Cmd_ptr(new CompleteCmd("suiteName/familyName/taskName",
+                                              Submittable::DUMMY_JOBS_PASSWORD(),
+                                              Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                              1)));
+    cmd_vec.push_back(Cmd_ptr(new AbortCmd("suiteName/familyName/taskName",
+                                           Submittable::DUMMY_JOBS_PASSWORD(),
+                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                           1)));
+    cmd_vec.push_back(Cmd_ptr(new CtsWaitCmd("suiteName/familyName/taskName",
+                                             Submittable::DUMMY_JOBS_PASSWORD(),
+                                             Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                             1,
+                                             "1 eq 1")));
+    cmd_vec.push_back(Cmd_ptr(new LabelCmd("suiteName/familyName/taskName",
+                                           Submittable::DUMMY_JOBS_PASSWORD(),
+                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                           1,
+                                           "labelName",
+                                           "label value")));
+    cmd_vec.push_back(Cmd_ptr(new QueueCmd("/suiteName/familyName/taskName",
+                                           Submittable::DUMMY_JOBS_PASSWORD(),
+                                           Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                           1,
+                                           "queue1",
+                                           "active",
+                                           "",
+                                           "/suiteName")));
+
+    std::vector<Variable> to_add{Variable("name", "value"), Variable("name2", "value")};
+    std::vector<std::string> to_del{"name", "name2"};
+    cmd_vec.push_back(Cmd_ptr(new InitCmd("suiteName/familyName/taskName",
+                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                          1,
+                                          to_add)));
+    cmd_vec.push_back(Cmd_ptr(new CompleteCmd("suiteName/familyName/taskName",
+                                              Submittable::DUMMY_JOBS_PASSWORD(),
+                                              Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                              1,
+                                              to_del)));
+
+    cmd_vec.push_back(Cmd_ptr(new ForceCmd("/suiteName", "complete", true, true)));
+    cmd_vec.push_back(Cmd_ptr(new FreeDepCmd("/suiteName")));
+    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::ECF, 10)));
+    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::JOB, 100)));
+    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::JOBOUT, 100)));
+    cmd_vec.push_back(Cmd_ptr(new CFileCmd("/suiteName", CFileCmd::MANUAL, 100)));
+    cmd_vec.push_back(Cmd_ptr(new EditScriptCmd()));
+    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_DATE, "12.*.*")));
+    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_DAY, "sunday")));
+    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_TIME, "+12:00")));
+    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_TIME, "+10:00 20:00 00:30")));
+    cmd_vec.push_back(Cmd_ptr(new AlterCmd("/suiteName/t1", AlterCmd::ADD_TODAY, "10:00 20:00 00:30")));
+    cmd_vec.push_back(Cmd_ptr(new PlugCmd()));
+    cmd_vec.push_back(Cmd_ptr(new QueryCmd("event", "/suiteName/t1", "event", "")));
+
+    std::shared_ptr<GroupCTSCmd> theGroupCmd = std::make_shared<GroupCTSCmd>();
+    theGroupCmd->addChild(Cmd_ptr(new ServerVersionCmd()));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::PING)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::SHUTDOWN_SERVER)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::HALT_SERVER)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::TERMINATE_SERVER)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_WHITE_LIST_FILE)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_PASSWD_FILE)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::SERVER_LOAD)));
+    theGroupCmd->addChild(Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, "EmptySuite")));
+    theGroupCmd->addChild(Cmd_ptr(new PathsCmd(PathsCmd::RESUME, "EmptySuite")));
+    theGroupCmd->addChild(Cmd_ptr(new PathsCmd(PathsCmd::KILL, "EmptySuite")));
+    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET, "EmptySuite")));
+    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE, "EmptySuite")));
+    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE, "EmptySuite")));
+    theGroupCmd->addChild(Cmd_ptr(new ShowCmd()));
+    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::FOB,
+                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                Submittable::DUMMY_JOBS_PASSWORD())));
+    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::FAIL,
+                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                Submittable::DUMMY_JOBS_PASSWORD())));
+    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::ADOPT,
+                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                Submittable::DUMMY_JOBS_PASSWORD())));
+    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::REMOVE,
+                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                Submittable::DUMMY_JOBS_PASSWORD())));
+    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::KILL,
+                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                Submittable::DUMMY_JOBS_PASSWORD())));
+    theGroupCmd->addChild(Cmd_ptr(new ZombieCmd(ecf::User::BLOCK,
+                                                std::vector<std::string>(1, "/suiteName/familyName/taskName"),
+                                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                Submittable::DUMMY_JOBS_PASSWORD())));
+    theGroupCmd->addChild(Cmd_ptr(new RequeueNodeCmd("/suiteName", RequeueNodeCmd::NO_OPTION)));
+    theGroupCmd->addChild(Cmd_ptr(new OrderNodeCmd("/suiteName", NOrder::ALPHA)));
+    theGroupCmd->addChild(Cmd_ptr(new RunNodeCmd("/suiteName", true /*force for test*/, true /* for test */)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsCmd(CtsCmd::RESTART_SERVER)));
+    theGroupCmd->addChild(Cmd_ptr(new InitCmd("suiteName/familyName/taskName",
+                                              Submittable::DUMMY_JOBS_PASSWORD(),
+                                              Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                              1)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::CHECK_JOB_GEN_ONLY, "EmptySuite"))); // will *reset* begin
+    theGroupCmd->addChild(Cmd_ptr(new EventCmd("suiteName/familyName/taskName",
+                                               Submittable::DUMMY_JOBS_PASSWORD(),
+                                               Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                               1,
+                                               "eventName")));
+    theGroupCmd->addChild(Cmd_ptr(new MeterCmd("suiteName/familyName/heir_familyName/taskName",
+                                               Submittable::DUMMY_JOBS_PASSWORD(),
+                                               Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                               1,
+                                               "myMeter",
+                                               100)));
+    theGroupCmd->addChild(Cmd_ptr(new CompleteCmd("suiteName/familyName/taskName",
+                                                  Submittable::DUMMY_JOBS_PASSWORD(),
+                                                  Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                  1)));
+    theGroupCmd->addChild(Cmd_ptr(new AbortCmd("suiteName/familyName/taskName",
+                                               Submittable::DUMMY_JOBS_PASSWORD(),
+                                               Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                               1)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::GET_STATE)));
+    theGroupCmd->addChild(Cmd_ptr(new CtsNodeCmd(CtsNodeCmd::MIGRATE)));
+    theGroupCmd->addChild(
+        Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL))); // will force deletion of any Node which has autocomplete
+    theGroupCmd->addChild(Cmd_ptr(new LoadDefsCmd(client_defs, true /*force*/)));
+    theGroupCmd->addChild(Cmd_ptr(new BeginCmd("suiteName")));
+    theGroupCmd->addChild(Cmd_ptr(new BeginCmd("EmptySuite")));
+    theGroupCmd->addChild(Cmd_ptr(new LogCmd(LogCmd::GET)));
+    theGroupCmd->addChild(Cmd_ptr(new LogCmd(LogCmd::CLEAR)));
+    theGroupCmd->addChild(Cmd_ptr(new LogMessageCmd("LogMessageCmd")));
+    theGroupCmd->addChild(Cmd_ptr(new ForceCmd("/suiteName", "complete", true, true)));
+    theGroupCmd->addChild(Cmd_ptr(new FreeDepCmd("/suiteName", false, true)));
+
+    BOOST_CHECK_MESSAGE(theGroupCmd->isWrite(), "Expected isWrite() to return true");
+    BOOST_CHECK_MESSAGE(theGroupCmd->get_cmd(), "Expected get_cmd() to return true");
+    BOOST_CHECK_MESSAGE(theGroupCmd->task_cmd(), "Expected task_cmd() to return true");
+    BOOST_CHECK_MESSAGE(theGroupCmd->terminate_cmd(), "Expected terminate_cmd() to return true");
+    BOOST_CHECK_MESSAGE(theGroupCmd->group_cmd(), "Expected group_cmd() to return true");
+    cmd_vec.push_back(theGroupCmd);
+
+    // Server --> Client commands
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new ErrorCmd("The error")));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new StcCmd(StcCmd::OK)));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_SERVER_HALTED)));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_ON_HOME_SERVER)));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new BlockClientZombieCmd(ecf::Child::ECF)));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new SStringCmd("Dummy contents")));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new SServerLoadCmd("/path/to/log_file")));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new SSyncCmd(0, 0, 0, mock_server)));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new SNewsCmd(0, 0, 0, mock_server)));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new DefsCmd(mock_server)));
+    stc_cmd_vec.push_back(STC_Cmd_ptr(new SNodeCmd(mock_server, node_ptr())));
+
+    std::shared_ptr<GroupSTCCmd> theSTCGroupCmd = std::make_shared<GroupSTCCmd>();
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new ErrorCmd()));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new StcCmd(StcCmd::OK)));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_SERVER_HALTED)));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new StcCmd(StcCmd::BLOCK_CLIENT_ON_HOME_SERVER)));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new BlockClientZombieCmd(ecf::Child::ECF)));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new SStringCmd()));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new SServerLoadCmd()));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new DefsCmd(mock_server)));
+    theSTCGroupCmd->addChild(STC_Cmd_ptr(new SNodeCmd(mock_server, node_ptr())));
+    stc_cmd_vec.push_back(theSTCGroupCmd);
+}
+
+static void test_persistence(const Defs& theFixtureDefs) {
+    auto* fixtureDefs = const_cast<Defs*>(&theFixtureDefs);
+    fixtureDefs->clear_externs();       // server does not have externs
+    MockServer mockServer(fixtureDefs); // creates shared ptr with a NULL deleter
+
+    std::vector<Cmd_ptr> cmd_vec;
+    std::vector<STC_Cmd_ptr> stc_cmd_vec;
+    populateCmdVec(cmd_vec, stc_cmd_vec, &mockServer);
+
+    int getRequest       = 0;
+    int terminateRequest = 0;
+    int groupRequest     = 0;
+    for (const Cmd_ptr& theCmd : cmd_vec) {
+
+        // std::cout << "TheCmd "; theCmd->print(std::cout); std::cout << "\n";
+        if (theCmd->connect_to_different_servers()) {
+            BOOST_CHECK_MESSAGE(theCmd->task_cmd(),
+                                "Currently only tasks commands, are allowed to connect to different servers");
+        }
+
+        ClientToServerRequest cmd_request;
+        cmd_request.set_cmd(theCmd);
+        {
+            if (theCmd.get()->handleRequestIsTestable()) {
+                // test handleRequest while were at it.
+                // Avoid TERMINATE_SERVER cmd as this will prematurely cause an exit, wont appear as an error
+                // cerr << "cmd_request = " << cmd_request << "\n";
+                try {
+                    STC_Cmd_ptr ok_or_error_cmd = cmd_request.handleRequest(&mockServer);
+                    if (ok_or_error_cmd) {
+                        // Commands like ErrorCmd, OkCmd don't return a cmd_ptr from handleRequest
+                        // those that do, check OkCmd returned, else if ErrorCmd show the error
+                        BOOST_CHECK_MESSAGE(ok_or_error_cmd->ok(),
+                                            "Request '" << cmd_request << "' returned " << ok_or_error_cmd->error());
+                    }
+                }
+                catch (std::exception& e) {
+                    BOOST_CHECK_MESSAGE(false, "Unexpected exception : " << e.what() << " : " << cmd_request);
+                }
+            }
+        }
+
+        // cout << " Saving = " << cmd_request << "\n";
+        std::string saved_request;
+        {
+            BOOST_REQUIRE_NO_THROW(ecf::save("request.txt", cmd_request)); // save as filename
+            ecf::save_as_string(saved_request, cmd_request);               // save as string
+            // cout << saved_request << "\n";                                // Take a peek at json output
+        }
+
+        // cout << " Restoring = " << cmd_request << "\n";
+        {
+            ClientToServerRequest restoredRequest;
+            BOOST_REQUIRE_NO_THROW(ecf::restore("request.txt", restoredRequest));
+            BOOST_REQUIRE_MESSAGE(restoredRequest == cmd_request,
+                                  "restoredRequest " << restoredRequest << " cmd_request " << cmd_request);
+
+            if (restoredRequest.getRequest())
+                getRequest++;
+            if (restoredRequest.terminateRequest())
+                terminateRequest++;
+            if (restoredRequest.groupRequest())
+                groupRequest++;
+        }
+        {
+            ClientToServerRequest restoredRequest;
+            ecf::restore_from_string(saved_request, restoredRequest);
+            BOOST_REQUIRE_MESSAGE(restoredRequest == cmd_request,
+                                  "restoredRequest " << restoredRequest << " cmd_request " << cmd_request);
+        }
+
+        fs::remove("request.txt");
+    }
+
+    BOOST_CHECK_MESSAGE(getRequest == 3, " expected 3 get Request  but found " << getRequest);
+    BOOST_CHECK_MESSAGE(terminateRequest == 2, " expected 2 terminate Request but found " << terminateRequest);
+    BOOST_CHECK_MESSAGE(groupRequest == 1, " expected 1 group Request but found " << groupRequest);
+
+    for (const STC_Cmd_ptr& theCmd : stc_cmd_vec) {
+        //		std::cout << "TheCmd "; theCmd->print(std::cout); std::cout << "\n";
+
+        const ServerToClientResponse cmd_request(theCmd); // MUST be const to avoid AIX compiler warning
+        BOOST_REQUIRE_NO_THROW(ecf::save("request.txt", cmd_request));
+
+        ServerToClientResponse restoredRequest;
+        BOOST_REQUIRE_NO_THROW(ecf::restore("request.txt", restoredRequest));
+        BOOST_REQUIRE_MESSAGE(restoredRequest == cmd_request,
+                              "restoredRequest " << restoredRequest << " cmd_request " << cmd_request);
+        fs::remove("request.txt");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_all_request_persistence_text) {
+    cout << "Base:: ...test_all_request_persistence_text\n";
+    TestLog test_log("test_all_request_persistence_text.log"); // will create log file, and destroy log and remove file
+                                                               // at end of scope
+
+    test_persistence(fixtureDefsFile());
+}
+
+BOOST_AUTO_TEST_CASE(test_request_authenticate) {
+    cout << "Base:: ...test_request_authenticate\n";
+    TestLog test_log(
+        "test_request_authenticate.log"); // will create log file, and destroy log and remove file at end of scope
+
+    // the path "suiteName0/familyName0/taskName0" must exist in the defsfile_ fixture
+    Cmd_ptr cmd_ptr(new InitCmd("suiteName/familyName/taskName",
+                                Submittable::DUMMY_JOBS_PASSWORD(),
+                                Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                1));
+
+    // The invokeRequest will return check if the path and password exist in the Node tree
+    TestHelper::invokeRequest(&defsfile_, cmd_ptr);
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestRequeueNodeCmd.cpp 5.13.0-1/libs/base/test/TestRequeueNodeCmd.cpp
--- 5.12.4-1/libs/base/test/TestRequeueNodeCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestRequeueNodeCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,383 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/ForceCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Pid.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_RequeueNodeCmd)
+
+BOOST_AUTO_TEST_CASE(test_requeue_with_suspend) {
+    cout << "Base:: ...test_requeue_with_suspend\n";
+    TestLog test_log(
+        "test_requeue_with_suspend.log"); // will create log file, and destroy log and remove file at end of scope
+
+    defs_ptr the_defs = Defs::create();
+    suite_ptr s1      = the_defs->add_suite("s1");
+    family_ptr f1     = s1->add_family("f1");
+    task_ptr t1       = f1->add_task("t1");
+    task_ptr t2       = f1->add_task("t2");
+    task_ptr t3       = f1->add_task("t3");
+    t3->addDefStatus(DState::SUSPENDED);
+
+    the_defs->beginAll();
+
+    // After begin/requeue we must honour defs status
+    BOOST_CHECK_MESSAGE(t3->isSuspended(), "Expected node to be suspended");
+
+    // Suspend all nodes
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, s1->absNodePath())));
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, f1->absNodePath())));
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t1->absNodePath())));
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t2->absNodePath())));
+    BOOST_CHECK_MESSAGE(s1->isSuspended(), "Expected node to be suspended");
+    BOOST_CHECK_MESSAGE(f1->isSuspended(), "Expected node to be suspended");
+    BOOST_CHECK_MESSAGE(t1->isSuspended(), "Expected node to be suspended");
+    BOOST_CHECK_MESSAGE(t2->isSuspended(), "Expected node to be suspended");
+
+    // Re-queue of the nodes, that are suspended, they should *stay* suspended
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(t1->absNodePath())));
+    BOOST_CHECK_MESSAGE(t1->isSuspended(), "Expected node to stay suspended");
+
+    // Now re-queue the top level suite, this is suspended.
+    // This should stay suspended *BUT* child nodes which are suspend should be cleared
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(s1->absNodePath())));
+    BOOST_CHECK_MESSAGE(s1->isSuspended(), "Suite should stay suspend");
+    BOOST_CHECK_MESSAGE(!f1->isSuspended(), "Expected child nodes to be un-suspended");
+    BOOST_CHECK_MESSAGE(!t1->isSuspended(), "Expected child nodes to be un-suspended");
+    BOOST_CHECK_MESSAGE(!t2->isSuspended(), "Expected child nodes to be un-suspended");
+    BOOST_CHECK_MESSAGE(t3->isSuspended(), "Requeue must honour def status");
+}
+
+BOOST_AUTO_TEST_CASE(test_requeue_family_clears_children_SUP_909) {
+    cout << "Base:: ...test_requeue_family_clears_children_SUP_909\n";
+    TestLog test_log("test_requeue_family_clears_children_SUP_909.log"); // will create log file, and destroy log and
+                                                                         // remove file at end of scope
+
+    //   suite s1
+    //    family f1
+    //       task t1
+    //          time 23:30
+    //     endFamily
+    //   endsuite
+    // make sure time is set *before* 23:30, so that time dependency holds the task
+
+    defs_ptr the_defs = Defs::create();
+    suite_ptr suite   = the_defs->add_suite("s1");
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
+    suite->addClock(clockAttr);
+
+    family_ptr f1 = suite->add_family("f1");
+    task_ptr t1   = f1->add_task("t1");
+    t1->addTime(TimeAttr(23, 30));
+
+    const TimeSeries& theTime = t1->timeVec().back().time_series();
+
+    the_defs->beginAll();
+
+    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    BOOST_CHECK_MESSAGE(!theTime.is_valid(), "Expected time to have expired");
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set");
+
+    // Now reque the family, this should clear the time, so that it now holding again
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(f1->absNodePath())));
+    TestHelper::test_state(f1, NState::QUEUED);
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be reset");
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_based_requeue_clears_children) {
+    cout << "Base:: ...test_repeat_based_requeue_clears_children\n";
+    TestLog test_log("test_repeat_based_requeue_clears_children.log"); // will create log file, and destroy log and
+                                                                       // remove file at end of scope
+
+    //   suite s1
+    //    repeat day 1
+    //    family f1
+    //       task t1
+    //          time 23:30
+    //     endfamily
+    //   endsuite
+    // make sure time is set *before* 23:30, so that time dependency holds the task
+
+    defs_ptr the_defs = Defs::create();
+    suite_ptr suite   = the_defs->add_suite("s1");
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // start at 09:30
+    suite->addClock(clockAttr);
+
+    suite->addRepeat(RepeatDay(1));
+
+    family_ptr f1 = suite->add_family("f1");
+    task_ptr t1   = f1->add_task("t1");
+    t1->addTime(TimeAttr(23, 30));
+
+    const TimeSeries& theTime = t1->timeVec().back().time_series();
+
+    the_defs->beginAll();
+
+    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
+
+    // Forcing task t1 to complete, should cause the top, level repeat to REQEUE
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "complete", true /*recursive */, false /* set Repeat to last value */)));
+
+    TestHelper::test_state(t1, NState::QUEUED);
+    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear");
+}
+
+BOOST_AUTO_TEST_CASE(test_ecflow_359) {
+    cout << "Base:: ...test_ECFLOW-359\n";
+    TestLog test_log("test_ecflow_359.log"); // will create log file, and destroy log and remove file at end of scope
+
+    //   suite s1
+    //     family f1
+    //       repeat date YMD 20090916 20090928
+    //       family parent
+    //          task dummy
+    //             time 16:00
+    //       endfamily
+    //       task complete
+    //          defstatus complete
+
+    //   set defstatus complete /s1/f1/parent/dummy
+    //   requeue s1/f1/parent
+    //   f1 gets set complete through status inheritance
+    //   YMD is not increment at the moment...
+
+    defs_ptr the_defs = Defs::create();
+    suite_ptr suite   = the_defs->add_suite("s1");
+    family_ptr f1     = suite->add_family("f1");
+    f1->addRepeat(RepeatDate("YMD", 20090916, 20090928, 1));
+
+    family_ptr parent = f1->add_family("parent");
+    task_ptr dummy    = parent->add_task("dummy");
+    dummy->addTime(TimeAttr(16, 0));
+
+    task_ptr complete = f1->add_task("complete");
+    complete->addDefStatus(DState::COMPLETE);
+
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs;
+
+    the_defs->beginAll();
+
+    //   cout << "----->set defstatus complete /s1/f1/parent/dummy\n";
+    BOOST_CHECK_MESSAGE(dummy->defStatus() == DState::QUEUED,
+                        "Expected dstate to be queued but found " << DState::toString(dummy->dstate()));
+    TestHelper::invokeRequest(the_defs.get(),
+                              Cmd_ptr(new AlterCmd(dummy->absNodePath(), AlterCmd::DEFSTATUS, "complete")));
+    BOOST_CHECK_MESSAGE(dummy->defStatus() == DState::COMPLETE,
+                        "Expected dstate to be complete but found " << DState::toString(dummy->dstate()));
+    //   cout << the_defs;
+
+    //   cout << "----->requeue parent since all children are now complete, we expect the repeat on the f1 to
+    //   increment\n";
+    BOOST_CHECK_MESSAGE(f1->repeat().value() == 20090916,
+                        "Expected repeat value of 20090916 but found " << f1->repeat().value());
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(parent->absNodePath())));
+    BOOST_CHECK_MESSAGE(f1->repeat().value() == 20090917,
+                        "Expected repeat value of 20090917 but found " << f1->repeat().value());
+    //   cout << the_defs;
+
+    //   cout << "----->requeue again\n";
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(parent->absNodePath())));
+    BOOST_CHECK_MESSAGE(f1->repeat().value() == 20090918,
+                        "Expected repeat value of 20090918 but found " << f1->repeat().value());
+    //   cout << the_defs;
+}
+
+BOOST_AUTO_TEST_CASE(test_ecflow_428) {
+    cout << "Base:: ...test_ECFLOW-428\n";
+    TestLog test_log("test_ecflow_428.log"); // will create log file, and destroy log and remove file at end of scope
+
+    //   suite s1
+    //     family f1
+    //       family f2
+    //          task t1
+    //          task t2
+
+    // Set t1 to aborted, then call reque aborted on suite s1
+    // This should result ALL nodes to be in a queued state
+
+    defs_ptr the_defs = Defs::create();
+    suite_ptr suite   = the_defs->add_suite("s1");
+    suite->addDefStatus(DState::SUSPENDED);
+    family_ptr f1 = suite->add_family("f1");
+    family_ptr f2 = f1->add_family("f1");
+    task_ptr t1   = f2->add_task("t1");
+    task_ptr t2   = f2->add_task("t2");
+
+    //   PrintStyle style(PrintStyle::STATE); cout << the_defs;
+
+    the_defs->beginAll();
+
+    // set t1 to aborted state
+    TestHelper::invokeRequest(
+        the_defs.get(),
+        Cmd_ptr(
+            new ForceCmd(t1->absNodePath(), "aborted", false /*recursive */, false /* set Repeat to last value */)));
+    TestHelper::test_state(t1, NState::ABORTED);
+    TestHelper::test_state(t2, NState::QUEUED);
+    TestHelper::test_state(f1, NState::ABORTED);
+    TestHelper::test_state(f2, NState::ABORTED);
+    TestHelper::test_state(suite, NState::ABORTED);
+
+    // Now reque aborted tasks for suite
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(suite->absNodePath(), RequeueNodeCmd::ABORT)));
+
+    // *Suite* should now be queued
+    TestHelper::test_state(suite, NState::QUEUED);
+    TestHelper::test_state(f1, NState::QUEUED);
+    TestHelper::test_state(f2, NState::QUEUED);
+    TestHelper::test_state(t1, NState::QUEUED);
+    TestHelper::test_state(t2, NState::QUEUED);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_based_requeue_resets_relative_duration) {
+    cout << "Base:: ...test_repeat_based_requeue_resets_relative_duration\n";
+    TestLog test_log("test_repeat_based_requeue_resets_relative_duration.log"); // will create log file, and destroy log
+                                                                                // and remove file at end of scope
+
+    //   suite ecflow_1182
+    //    family f
+    //      repeat integer HYEAR 1993 2017 1
+    //      time +00:01
+    //      task uk2fdb
+
+    defs_ptr the_defs = Defs::create();
+    suite_ptr suite   = the_defs->add_suite("ecflow_1182");
+    family_ptr f      = suite->add_family("f");
+    f->addRepeat(RepeatInteger("rep", 1993, 2017));
+    f->addTime(TimeAttr("+00:01"));
+
+    task_ptr t1 = f->add_task("uk2fsb");
+
+    auto& theTime = const_cast<TimeSeries&>(f->timeVec().back().time_series());
+
+    the_defs->beginAll();
+    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be holding");
+
+    // forward time, so that time expires
+    // The calendar is *only* updated if the suite have been begun. Hence make sure this test scaffold
+    // starts the test, with all the suites in a begun state
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+    {
+        CalendarUpdateParams cal(time_now, minutes(1), true /* server running */, false /* for Test*/);
+        the_defs->updateCalendar(cal); // cout << suite->calendar().toString() << "\n";
+        time_now += minutes(1);
+    }
+    {
+        CalendarUpdateParams cal(time_now, minutes(1), true /* server running */, false /* for Test*/);
+        the_defs->updateCalendar(cal); // cout << suite->calendar().toString() << "\n";
+    }
+    theTime.requeue(suite->calendar(), true); // will expire time
+    BOOST_CHECK_MESSAGE(!theTime.is_valid(), "Expected time to be expired");
+
+    // Now re-queue the suite/family
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(suite->absNodePath())));
+    BOOST_CHECK_MESSAGE(theTime.is_valid(), "Expected time to be valid");
+
+    // PrintStyle style(PrintStyle::MIGRATE);
+    // cout << the_defs;
+}
+
+BOOST_AUTO_TEST_CASE(test_reque_with_repeat_and_defstatus_complete) {
+    cout << "Base:: ...test_reque_with_repeat_and_defstatus_complete\n";
+
+    // This will test that when we have a family with a repeat AND defstatus complete
+    // We ONLY log the state change complete in the log file when re-queuing
+
+    //   suite test_reque_with_repeat_and_defstatus_complete
+    //     family f1
+    //       repeat date YMD 20000101 20100101 1
+    //       task t1
+    //       task t2
+    ///      defstatus complete
+
+    defs_ptr the_defs = Defs::create();
+    suite_ptr suite   = the_defs->add_suite("test_reque_with_repeat_and_defstatus_complete");
+    family_ptr f1     = suite->add_family("f1");
+    f1->addRepeat(RepeatDate("YMD", 20090531, 20101231, 1));
+    f1->addDefStatus(DState::COMPLETE);
+    task_ptr t1 = f1->add_task("t1");
+    task_ptr t2 = f1->add_task("t2");
+
+    // PrintStyle style(PrintStyle::STATE); cout << the_defs;
+
+    the_defs->beginAll();
+
+    // Create a log file with a unique name, to avoid problems when running in paralle
+    // This test relies on log file contents to be flushed.
+    std::string log_file = "libs/base/test/test_reque_with_repeat_and_defstatus_complete_";
+    log_file += Pid::getpid(); // can throw
+    log_file += ".log";
+    log_file = File::test_data(log_file, "libs/base");
+
+    Log::create(log_file);
+
+    // Re-queue the family. In past we queued all nodes, then set to complete
+    // We still do this, but we now longer LOG the setting the the queued state
+    // Hence in the log file we only expected to see nodes in the complete state
+    // See: ECFLOW-1239. When dealing with thousands of nodes, this was causing performance problems
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new RequeueNodeCmd(f1->absNodePath())));
+    TestHelper::test_state(t1, NState::COMPLETE);
+    TestHelper::test_state(t2, NState::COMPLETE);
+    TestHelper::test_state(f1, NState::COMPLETE);
+    TestHelper::test_state(suite, NState::COMPLETE);
+
+    // This should also flush the log file.
+    Log::destroy();
+
+    // Open the log file and look for 'queued:' if we find it then this is a regression.
+    std::string error_msg;
+    std::string log_contents = File::get_first_n_lines(log_file, 1000, error_msg);
+    BOOST_REQUIRE_MESSAGE(error_msg.empty(), "could not open log file " << log_file);
+    BOOST_CHECK_MESSAGE(log_contents.find("complete:") != std::string::npos,
+                        "defstatus complete failed.\n'" << log_contents << "'");
+    BOOST_CHECK_MESSAGE(log_contents.find("queued:") == std::string::npos,
+                        "RequeNode with repeat and defstatus complete should only log the complete state change");
+
+    fs::remove(log_file);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestResolveDependencies.cpp 5.13.0-1/libs/base/test/TestResolveDependencies.cpp
--- 5.12.4-1/libs/base/test/TestResolveDependencies.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestResolveDependencies.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,296 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_ResolveDependencies)
+
+BOOST_AUTO_TEST_CASE(test_resolve_dependencies) {
+    cout << "Base:: ...test_resolve_dependencies\n";
+    TestLog test_log(
+        "test_resolve_dependencies.log"); // will create log file, and destroy log and remove file at end of scope
+
+    ////////////////////////////////////////////////////////////////////////////////////////////////////
+    // Create the defs file
+    //   suite suite
+    //     family f
+    //       task t
+    //         meter step 0 240 120
+    //         task tt
+    //           complete t:step ge 120
+    //           trigger t == complete
+    //     endfamily
+    //   endsuite
+    Defs defs;
+    std::string metername  = "step";
+    std::string suitename  = "suite";
+    std::string familyname = "f";
+    {
+        suite_ptr suite = defs.add_suite(suitename);
+        family_ptr fam  = suite->add_family(familyname);
+
+        task_ptr task = fam->add_task("t");
+        task->addMeter(Meter(metername, 0, 240, 120));
+
+        task_ptr task_tt = fam->add_task("tt");
+        task_tt->add_complete("t:step ge 120");
+        task_tt->add_trigger("t == complete");
+
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+
+    // Ensure initial state is unknown
+    string suite_f_t  = "/suite/f/t";
+    string suite_f_tt = "/suite/f/tt";
+    node_ptr node_t   = defs.findAbsNode(suite_f_t);
+    node_ptr node_tt  = defs.findAbsNode(suite_f_tt);
+    suite_ptr suite   = defs.findSuite(suitename);
+    family_ptr fam    = suite->findFamily(familyname);
+    BOOST_CHECK_MESSAGE(suite->state() == NState::UNKNOWN,
+                        "expected state NState::UNKNOWN, but found to be " << NState::toString(suite->state()));
+    BOOST_CHECK_MESSAGE(node_t->state() == NState::UNKNOWN,
+                        "expected state NState::UNKNOWN, but found to be " << NState::toString(node_t->state()));
+    BOOST_CHECK_MESSAGE(node_tt->state() == NState::UNKNOWN,
+                        "expected state NState::UNKNOWN, but found to be " << NState::toString(node_tt->state()));
+    BOOST_CHECK_MESSAGE(fam->state() == NState::UNKNOWN,
+                        "expected state NState::UNKNOWN, but found to be " << NState::toString(fam->state()));
+
+    // ***********************************************************************
+    // Create a request to begin suite
+    // make sure chosen suite can begin to resolve dependencies.
+    // beginning the suite will :
+    //     1/ set all children to the QUEUED state
+    //     2/ Begin job submission, and hence changes state to ACTIVE for submitted jobs
+    {
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd(suitename)));
+        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(suite->state()));
+        BOOST_CHECK_MESSAGE(fam->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(fam->state()));
+        BOOST_CHECK_MESSAGE(node_t->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(node_t->state()));
+        BOOST_CHECK_MESSAGE(node_tt->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(node_tt->state()));
+    }
+
+    //*******************************************************************************
+    // Resolve dependencies.
+    //   task t
+    //     meter step 0 240 120       EXPECTED to be sumbitted
+    //
+    //   task tt
+    //     complete t:step ge 120     Expected to HOLD, since we ain't done nothing yet
+    //     trigger t == complete
+    {
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
+        BOOST_CHECK_MESSAGE(node_t->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(node_t->state()));
+        BOOST_CHECK_MESSAGE(node_tt->state() == NState::QUEUED,
+                            "expected state NState::QUEUED, but found to be " << NState::toString(node_tt->state()));
+    }
+
+    //**********************************************************************
+    // Create a request to set the Meter node t. This should force node tt
+    // to complete immediately
+    {
+        int meterValue = 120;
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new MeterCmd(suite_f_t,
+                                                       Submittable::DUMMY_JOBS_PASSWORD(),
+                                                       Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                       1,
+                                                       metername,
+                                                       meterValue)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
+        const Meter& theMeter = node_t->findMeter(metername);
+        BOOST_CHECK_MESSAGE(!theMeter.empty(), "Could not find the meter ");
+        BOOST_CHECK_MESSAGE(theMeter.value() == meterValue, "Meter value not set");
+
+        BOOST_CHECK_MESSAGE(node_t->state() == NState::ACTIVE,
+                            "expected state NState::ACTIVE, but found to be " << NState::toString(node_t->state()));
+        BOOST_CHECK_MESSAGE(node_tt->state() == NState::COMPLETE,
+                            "expected state NState::COMPLETE, but found to be " << NState::toString(node_tt->state()));
+    }
+
+    {
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_trigger_after_delete) {
+    cout << "Base:: ...test_trigger_after_delete\n";
+    ////////////////////////////////////////////////////////////////////////////////////////////////////
+    // Create the defs file
+    //   suite suite1    # the limit we want delete
+    //     family f
+    //       task t0
+    //         defstatus complete
+    //       task t1
+    //         event event
+    //       task t2
+    //         meter meter 0 100 100
+    //       task t3
+    //         edit user_var 1
+    //       task t4
+    //         repeat integer repeat_var 0 10 2
+    //     endfamily
+    //   endsuite
+    //   suite suite2
+    //     family f
+    //       task t0
+    //         trigger /suite1/f/t0 == complete
+    //       task t1
+    //         trigger /suite1/f/t1:event == set
+    //       task t2
+    //         trigger /suite1/f/t2:meter == 10
+    //       task t3
+    //         trigger /suite1/f/t2:user_var == 1
+    //       task t4
+    //         trigger /suite1/f/t2:repeat_var == 2
+    //     endfamily
+    //   endsuite
+    //
+    // In this test case all triggers in suite2 will evaluate true, we then delete suite1 and
+    // all the triggers should evaluate false; This is used to test the shared ptr in
+    // the expression, which hold the reference nodes. When the reference nodes are deleted
+    // then the expression should not evaluate
+    Defs defs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr f    = Family::create("f");
+        task_ptr t0     = Task::create("t0");
+        task_ptr t1     = Task::create("t1");
+        task_ptr t2     = Task::create("t2");
+        task_ptr t3     = Task::create("t3");
+        task_ptr t4     = Task::create("t4");
+        t0->addDefStatus(DState::COMPLETE);
+        t1->addEvent(Event(0, "event", true));
+        t2->addMeter(Meter("meter", 0, 100, 100));
+        t3->addVariable(Variable("user_var", "1"));
+        t4->addRepeat(RepeatInteger("repeat_var", 0, 10, 2));
+
+        f->addTask(t0);
+        f->addTask(t1);
+        f->addTask(t2);
+        f->addTask(t3);
+        f->addTask(t4);
+        suite->addFamily(f);
+        defs.addSuite(suite);
+    }
+    {
+        suite_ptr suite = Suite::create("suite2");
+        family_ptr f    = Family::create("f");
+        task_ptr t0     = Task::create("t0");
+        task_ptr t1     = Task::create("t1");
+        task_ptr t2     = Task::create("t2");
+        task_ptr t3     = Task::create("t3");
+        task_ptr t4     = Task::create("t4");
+        t0->add_trigger("/suite1/f/t0 == complete");
+        t1->add_trigger("/suite1/f/t1:event == set");
+        t2->add_trigger("/suite1/f/t2:meter == 10");
+        t3->add_trigger("/suite1/f/t3:user_var == 1");
+        t4->add_trigger("/suite1/f/t4:repeat_var == 2");
+
+        f->addTask(t0);
+        f->addTask(t1);
+        f->addTask(t2);
+        f->addTask(t3);
+        f->addTask(t4);
+        suite->addFamily(f);
+        defs.addSuite(suite);
+    }
+
+    // begin. This will reset all attributes
+    defs.beginAll();
+
+    // setup attrbutes in suite1 so that evalaution will succeed in suite 2
+    // *** this must be in its own scope otherwise the shared_ptr will keep the node alive
+    {
+        node_ptr t1 = defs.findAbsNode("/suite1/f/t1");
+        t1->changeEvent("event", "set");
+        node_ptr t2 = defs.findAbsNode("/suite1/f/t2");
+        t2->changeMeter("meter", 10);
+        node_ptr t4 = defs.findAbsNode("/suite1/f/t4");
+        t4->changeRepeat("2");
+        // cout << defs;
+    }
+
+    // evalate the triggers in suite2
+    {
+        node_ptr suite2 = defs.findAbsNode("/suite2");
+        std::vector<task_ptr> suite2_tasks;
+        suite2->get_all_tasks(suite2_tasks);
+        BOOST_REQUIRE_MESSAGE(suite2_tasks.size() == 5, "Expected 5 tasks on suite2 but found " << suite2_tasks.size());
+
+        for (auto& suite2_task : suite2_tasks) {
+            BOOST_REQUIRE_MESSAGE(suite2_task->triggerAst()->evaluate(),
+                                  "Expected task " << suite2_task->absNodePath() << " to evaluate");
+        }
+    }
+
+    // Ok Now delete suite1,
+    // *** It is extremely important that shared_ptr for '/suite1' is in its own
+    // *** scope, otherwise it will keep the 'suite' live, and NOT delete the limits
+    {
+        node_ptr suite1 = defs.findAbsNode("/suite1");
+        BOOST_REQUIRE_MESSAGE(suite1.get(), "Could not find the suite we want to delete?");
+        BOOST_REQUIRE_MESSAGE(defs.deleteChild(suite1.get()), "Deletion failed?");
+        BOOST_REQUIRE_MESSAGE(!defs.findAbsNode("/suite1").get(), "Deletion failed?");
+    }
+
+    // revaluate the triggers in suite2. This should fail, since we have delete suite1
+    {
+        node_ptr suite2 = defs.findAbsNode("/suite2");
+        std::vector<task_ptr> suite2_tasks;
+        suite2->get_all_tasks(suite2_tasks);
+        BOOST_REQUIRE_MESSAGE(suite2_tasks.size() == 5, "Expected 5 tasks on suite2 but found " << suite2_tasks.size());
+
+        for (auto& suite2_task : suite2_tasks) {
+            BOOST_REQUIRE_MESSAGE(!suite2_task->triggerAst()->evaluate(),
+                                  "Expected task " << suite2_task->absNodePath() << " to fail evaluation");
+        }
+    }
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestSSyncCmd.cpp 5.13.0-1/libs/base/test/TestSSyncCmd.cpp
--- 5.12.4-1/libs/base/test/TestSSyncCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestSSyncCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,484 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MockServer.hpp"
+#include "MyDefsFixture.hpp"
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/DeleteCmd.hpp"
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
+#include "ecflow/base/cts/user/PlugCmd.hpp"
+#include "ecflow/base/stc/SNewsCmd.hpp"
+#include "ecflow/base/stc/SSyncCmd.hpp"
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_SSyncCmd)
+
+/// define a function which returns nothing, and takes a defs_ptr parameter
+typedef boost::function<void(defs_ptr)> defs_change_cmd;
+
+/// Re-use the same test scaffold to modify and then resync, by passing
+/// in a function that will modify the defs
+static void test_sync_scaffold(defs_change_cmd the_defs_change_command,
+                               const std::string& test_name,
+                               bool full_sync        = false,
+                               bool start_with_begin = false) {
+    MyDefsFixture clientFixture;
+    MyDefsFixture serverFixture;
+    defs_ptr server_defs = serverFixture.create_defs();
+    if (start_with_begin)
+        server_defs->beginAll();
+    server_defs->set_server().set_state(
+        SState::HALTED); // if defs default state is RUNNING, whereas for server it is HALTED
+
+    ServerReply server_reply;
+    defs_ptr client_defs = clientFixture.create_defs();
+    if (start_with_begin)
+        client_defs->beginAll();
+    client_defs->set_server().set_state(
+        SState::HALTED); // if defs default state is RUNNING, whereas for server it is HALTED
+    server_reply.set_client_defs(client_defs);
+
+    Ecf::set_debug_equality(true); // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
+                        "Test:" << test_name << ": Starting point client and server defs should be the same");
+    Ecf::set_debug_equality(false); // only has affect in DEBUG build
+
+    // Get change number before any changes
+    unsigned int client_state_change_no  = Ecf::state_change_no();
+    unsigned int client_modify_change_no = Ecf::modify_change_no();
+
+    // make some change to the server
+    {
+        Ecf::set_server(true);
+
+        the_defs_change_command(server_defs);
+
+        std::string error_msg;
+        BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(error_msg),
+                              "Test:" << test_name << ": Invariants failed: " << error_msg);
+        BOOST_REQUIRE_MESSAGE(!(*server_reply.client_defs() == *server_defs),
+                              "Test:" << test_name << ": Expected client and server defs to differ\n"
+                                      << *server_reply.client_defs() << "\n"
+                                      << "server defs   = " << *server_defs);
+        Ecf::set_server(false);
+    }
+
+    MockServer mock_server(server_defs);
+    unsigned int client_handle = 0;
+    SNewsCmd news_cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
+    SSyncCmd cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
+
+    std::string error_msg;
+    BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(error_msg),
+                          "Test:" << test_name << ": Invariants failed: " << error_msg);
+    BOOST_CHECK_MESSAGE(news_cmd.get_news(), "Test:" << test_name << ": Expected server to change");
+    BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), "Test:" << test_name << ": Expected server to change");
+    BOOST_CHECK_MESSAGE(server_reply.in_sync(), "Test:" << test_name << ": Expected server to change");
+    BOOST_CHECK_MESSAGE(server_reply.full_sync() == full_sync,
+                        "Test:" << test_name << ": Expected sync not as expected");
+
+    error_msg.clear();
+    BOOST_REQUIRE_MESSAGE(server_reply.client_defs()->checkInvariants(error_msg),
+                          "Test:" << test_name << ": Invariants failed: " << error_msg);
+
+    DebugEquality debug_equality; // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
+                        "Test:" << test_name << ": Server and client should be same after sync");
+    //	if (! (*server_defs == *server_reply.client_defs()) ) {
+    //	   cout << "Server====================================================================\n";
+    //	   cout << server_defs;
+    //    cout << "Client====================================================================\n";
+    //    cout << server_reply.client_defs();
+    //	}
+}
+
+// The modifiers
+void delete_some_attributes(defs_ptr defs) {
+    std::vector<Task*> tasks;
+    defs->getAllTasks(tasks);
+    for (Task* task : tasks) {
+
+        SuiteChanged1 changed(task->suite());
+
+        /// Take a copy, of the objects we want to delete. since there are returned by reference
+        std::vector<Event> events = task->events();
+        std::vector<Meter> meters = task->meters();
+        std::vector<Label> labels = task->labels();
+
+        for (const Event& e : events) {
+            task->deleteEvent(e.name_or_number());
+        }
+        for (const Meter& m : meters) {
+            task->deleteMeter(m.name());
+        }
+        for (const Label& l : labels) {
+            task->deleteLabel(l.name());
+        }
+
+        BOOST_REQUIRE_MESSAGE(task->events().empty(), "Expected all events to be deleted");
+        BOOST_REQUIRE_MESSAGE(task->meters().empty(), "Expected all meters to be deleted");
+        BOOST_REQUIRE_MESSAGE(task->labels().empty(), "Expected all labels to be deleted");
+    }
+}
+
+void delete_time_attributes(defs_ptr defs) {
+    std::vector<Node*> nodes;
+    defs->getAllNodes(nodes);
+    for (Node* node : nodes) {
+
+        SuiteChanged1 changed(node->suite());
+
+        /// Take a copy, of the objects we want to delete. since there are returned by reference
+        std::vector<TimeAttr> times   = node->timeVec();
+        std::vector<TodayAttr> todays = node->todayVec();
+        std::vector<DayAttr> days     = node->days();
+        std::vector<DateAttr> dates   = node->dates();
+        std::vector<CronAttr> crons   = node->crons();
+
+        for (const TimeAttr& t : times) {
+            node->delete_time(t);
+        }
+        for (const TodayAttr& t : todays) {
+            node->delete_today(t);
+        }
+        for (const DayAttr& t : days) {
+            node->delete_day(t);
+        }
+        for (const DateAttr& t : dates) {
+            node->delete_date(t);
+        }
+        for (const CronAttr& t : crons) {
+            node->delete_cron(t);
+        }
+
+        BOOST_REQUIRE_MESSAGE(node->timeVec().empty(), "Expected all times to be deleted");
+        BOOST_REQUIRE_MESSAGE(node->todayVec().empty(), "Expected all todays to be deleted");
+        BOOST_REQUIRE_MESSAGE(node->days().empty(), "Expected all days to be deleted");
+        BOOST_REQUIRE_MESSAGE(node->dates().empty(), "Expected all dates to be deleted");
+        BOOST_REQUIRE_MESSAGE(node->crons().empty(), "Expected all crons to be deleted");
+    }
+}
+
+void delete_misc_attributes(defs_ptr defs) {
+    std::vector<Node*> nodes;
+    defs->getAllNodes(nodes);
+    for (Node* node : nodes) {
+
+        SuiteChanged1 changed(node->suite());
+
+        /// Take a copy, of the objects we want to delete. since there are returned by reference
+        std::vector<ZombieAttr> zombies = node->zombies();
+        // std::vector<VerifyAttr> verifys = node->verifys()();
+
+        for (const ZombieAttr& t : zombies) {
+            node->delete_zombie(t.zombie_type());
+        }
+        // for(const VerifyAttr & t: verifys ) { node->delete_verify( t );}
+
+        BOOST_REQUIRE_MESSAGE(node->zombies().empty(), "Expected all zombies to be deleted");
+        // BOOST_REQUIRE_MESSAGE( node->verifys().empty(),"Expected all verifys to be deleted");
+    }
+}
+
+void add_some_attributes(defs_ptr defs) {
+    std::vector<task_ptr> tasks;
+    defs->get_all_tasks(tasks);
+    for (task_ptr task : tasks) {
+        SuiteChanged1 changed(task->suite());
+        task->addDay(DayAttr(DayAttr::TUESDAY));
+    }
+}
+
+void begin(defs_ptr defs) {
+    defs->beginAll();
+} // reset all attributes
+
+void add_alias(defs_ptr defs) {
+
+    std::vector<task_ptr> tasks;
+    defs->get_all_tasks(tasks);
+    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
+
+    SuiteChanged1 changed(tasks[0]->suite());
+    tasks[0]->add_alias_only();
+}
+
+void remove_all_aliases(defs_ptr defs) {
+
+    std::vector<alias_ptr> aliases;
+    defs->get_all_aliases(aliases);
+    BOOST_REQUIRE_MESSAGE(!aliases.empty(), "Expected at least one alias");
+
+    for (alias_ptr alias : aliases) {
+        TestHelper::invokeRequest(defs.get(), Cmd_ptr(new DeleteCmd(alias->absNodePath())));
+    }
+
+    aliases.clear();
+    defs->get_all_aliases(aliases);
+    BOOST_REQUIRE_MESSAGE(aliases.empty(), "Expected at no  alias");
+}
+
+void remove_all_tasks(defs_ptr defs) {
+
+    // Remove tasks should force a incremental sync
+    std::vector<task_ptr> tasks;
+    defs->get_all_tasks(tasks);
+    for (task_ptr task : tasks) {
+        SuiteChanged1 changed(task->suite());
+        task->remove();
+    }
+
+    tasks.clear();
+    defs->get_all_tasks(tasks);
+    BOOST_REQUIRE_MESSAGE(tasks.empty(), "Failed to delete tasks");
+}
+
+void remove_a_family(defs_ptr defs) {
+
+    // Remove tasks should force a incremental sync
+    std::vector<Family*> vec;
+    defs->getAllFamilies(vec);
+    size_t family_size = vec.size();
+    BOOST_REQUIRE_MESSAGE(!vec.empty(), "Expected at least one family");
+    if (!vec.empty()) {
+        SuiteChanged1 changed(vec[0]->suite());
+        vec[0]->remove();
+    }
+
+    vec.clear();
+    defs->getAllFamilies(vec);
+    BOOST_REQUIRE_MESSAGE(vec.size() < family_size, "Failed to delete family");
+}
+
+void change_clock_gain(defs_ptr defs) {
+    for (suite_ptr suite : defs->suiteVec()) {
+        if (suite->clockAttr().get()) {
+            SuiteChanged changed(suite);
+            suite->changeClockGain("100001");
+        }
+    }
+}
+void change_clock_type_to_real(defs_ptr defs) {
+
+    for (suite_ptr suite : defs->suiteVec()) {
+        if (suite->clockAttr().get()) {
+            SuiteChanged changed(suite);
+            suite->changeClockType("real");
+        }
+    }
+}
+void change_clock_type_to_hybrid(defs_ptr defs) {
+
+    for (suite_ptr suite : defs->suiteVec()) {
+        if (suite->clockAttr().get()) {
+            SuiteChanged changed(suite);
+            suite->changeClockType("hybrid");
+        }
+    }
+}
+void change_clock_date(defs_ptr defs) {
+
+    for (suite_ptr suite : defs->suiteVec()) {
+        if (suite->clockAttr().get()) {
+            SuiteChanged changed(suite);
+            suite->changeClockDate("1.1.2001");
+        }
+    }
+}
+void change_clock_sync(defs_ptr defs) {
+
+    for (suite_ptr suite : defs->suiteVec()) {
+        if (suite->clockAttr().get()) {
+            SuiteChanged changed(suite);
+            suite->changeClockSync();
+        }
+    }
+}
+
+/// This has been split into two functions, as changing both together could mask an error
+/// i.e found bug where we forgot to update state_change number when changing the limit
+/// max value, however because we had, changed value as well it got masked.
+void change_limit_max(defs_ptr defs) {
+
+    for (suite_ptr s : defs->suiteVec()) {
+        std::vector<limit_ptr> theLimits = s->limits();
+        for (limit_ptr l : theLimits) {
+            // std::cout << "found " << l->toString() << "\n";
+            TestHelper::invokeRequest(defs.get(),
+                                      Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_MAX, l->name(), "90")));
+            limit_ptr v = s->find_limit(l->name());
+            BOOST_CHECK_MESSAGE(v.get() && v->theLimit() == 90, "expected to find limit with max value of 90");
+        }
+    }
+}
+void change_limit_value(defs_ptr defs) {
+
+    for (suite_ptr s : defs->suiteVec()) {
+        std::vector<limit_ptr> theLimits = s->limits();
+        for (limit_ptr l : theLimits) {
+            TestHelper::invokeRequest(defs.get(),
+                                      Cmd_ptr(new AlterCmd(s->absNodePath(), AlterCmd::LIMIT_VAL, l->name(), "33")));
+            limit_ptr v = s->find_limit(l->name());
+            BOOST_CHECK_MESSAGE(v.get() && v->value() == 33, "expected to find limit with value of 33");
+        }
+    }
+}
+
+void update_repeat(defs_ptr defs) {
+
+    std::vector<Node*> nodes;
+    defs->getAllNodes(nodes);
+
+    for (Node* n : nodes) {
+        if (!n->repeat().empty()) {
+            SuiteChanged1 changed(n->suite());
+            n->increment_repeat();
+        }
+    }
+}
+
+void update_calendar(defs_ptr defs) {
+
+    // The calendar is *only* updated if the suite have been begun. Hence make sure this test scaffold
+    // starts the test, with all the suites in a begun state
+    CalendarUpdateParams p(Calendar::second_clock_time(), minutes(1), true /* server running */, false /* for Test*/);
+    defs->updateCalendar(p);
+
+    // Currently updating the calendar, does not cause change, Hence force a change
+    for (suite_ptr suite : defs->suiteVec()) {
+        SuiteChanged changed(suite);
+        suite->add_variable("name", "value");
+    }
+
+    // Note: In the real server, persisting that calendar, the clock type is not persisted.
+    //       i.e when we have hybrid calendar, when restored on the client side it will be 'real' clock since
+    //       that is the default now. This is not correct and will fail invariant checking.
+    //       however the memento should reset clock type on the calenadar form the clok attribute.
+}
+
+void delete_suite(defs_ptr defs) {
+    std::vector<suite_ptr> vec = defs->suiteVec();
+    BOOST_REQUIRE_MESSAGE(!vec.empty(), "Expected suites");
+    vec[0]->remove();
+}
+
+void set_server_state_shutdown(defs_ptr defs) {
+    defs->set_server().set_state(SState::SHUTDOWN);
+}
+void set_server_state_running(defs_ptr defs) {
+    defs->set_server().set_state(SState::RUNNING);
+}
+
+void add_server_variable(defs_ptr defs) {
+    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "_fred_", "value")));
+}
+void change_server_variable(defs_ptr defs) {
+    // Because the scaffold create client/server defs each time.
+    // To test change/delete variables we modify the default set
+    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::VARIABLE, "ECF_TRIES", "4")));
+}
+void delete_server_variable(defs_ptr defs) {
+    // Because the scaffold create client/server defs each time.
+    // To test change/delete variables we modify the default set
+    // ***NOTE*** we cannot delete server variables like ECF_TRIES, can only change them
+    // However we can delete user variables added to the server
+    TestHelper::invokeRequest(defs.get(),
+                              Cmd_ptr(new AlterCmd("/", AlterCmd::DEL_VARIABLE, "MyDefsFixture_user_variable")));
+}
+
+void reorder_suites(defs_ptr defs) {
+    std::vector<suite_ptr> suiteVec = defs->suiteVec();
+    BOOST_REQUIRE_MESSAGE(!suiteVec.empty(), "Expected suites");
+    std::string path = "/" + suiteVec[0]->name();
+    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new OrderNodeCmd(path, NOrder::ALPHA)));
+}
+
+void move_peers(defs_ptr defs) {
+    std::vector<suite_ptr> suiteVec = defs->suiteVec();
+    BOOST_REQUIRE_MESSAGE(suiteVec.size() >= 2, "Expected suites");
+    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new PlugCmd(suiteVec[0]->absNodePath(), suiteVec[1]->absNodePath())));
+}
+void move_peers1(defs_ptr defs) {
+    std::vector<suite_ptr> suiteVec = defs->suiteVec();
+    BOOST_REQUIRE_MESSAGE(suiteVec.size() >= 2, "Expected suites");
+    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new PlugCmd(suiteVec[1]->absNodePath(), suiteVec[0]->absNodePath())));
+}
+
+void set_defs_flag(defs_ptr defs) {
+    defs->flag().set(ecf::Flag::MESSAGE);
+}
+
+void set_defs_state(defs_ptr defs) {
+    defs->set_state(NState::ABORTED);
+}
+
+BOOST_AUTO_TEST_CASE(test_ssync_cmd) {
+    // To DEBUG: enable the defines in Memento.hpp
+    cout << "Base:: ...test_ssync_cmd\n";
+    TestLog test_log("test_ssync_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    test_sync_scaffold(update_repeat, "update_repeat");
+    test_sync_scaffold(delete_some_attributes, "delete_some_attributes");
+    test_sync_scaffold(delete_time_attributes, "delete_time_attributes");
+    test_sync_scaffold(delete_misc_attributes, "delete_misc_attributes");
+    test_sync_scaffold(add_some_attributes, "add_some_attributes");
+    test_sync_scaffold(begin, "begin", true /* expect full_sync */);
+    test_sync_scaffold(add_alias, "add_alias");
+    test_sync_scaffold(remove_all_aliases, "remove_all_aliases");
+    test_sync_scaffold(remove_all_tasks, "remove_all_tasks");
+    test_sync_scaffold(remove_a_family, "remove_a_family");
+    test_sync_scaffold(change_clock_gain, "change_clock_gain", true /* expect full_sync */);
+    test_sync_scaffold(change_clock_type_to_real, "change_clock_type_to_real", true /* expect full_sync */);
+    test_sync_scaffold(change_clock_type_to_hybrid, "change_clock_type_to_hybrid", true /* expect full_sync */);
+    test_sync_scaffold(change_clock_date, "change_clock_date", true /* expect full_sync */);
+    test_sync_scaffold(change_clock_sync, "change_clock_sync", true /* expect full_sync */);
+    test_sync_scaffold(
+        update_calendar, "update_calendar", false /* expect full_sync */, true /* start test with begin */);
+    test_sync_scaffold(change_limit_max, "change_limit_max");
+    test_sync_scaffold(change_limit_value, "change_limit_value");
+    test_sync_scaffold(delete_suite, "delete_suite", true /* expect full_sync */);
+
+    // Test Changes in Defs
+    // The default server state is HALTED, hence setting to halted will not show a change
+    test_sync_scaffold(set_server_state_shutdown, "set_server_state_shutdown");
+    test_sync_scaffold(set_server_state_running, "set_server_state_running");
+
+    test_sync_scaffold(add_server_variable, "add_server_variable");
+    test_sync_scaffold(change_server_variable, "change_server_variable");
+    test_sync_scaffold(delete_server_variable, "delete_server_variable");
+
+    test_sync_scaffold(reorder_suites, "reorder_suites");
+    test_sync_scaffold(move_peers, "move_peers");
+    test_sync_scaffold(move_peers1, "move_peers1");
+
+    test_sync_scaffold(set_defs_flag, "set_defs_flag");
+    test_sync_scaffold(set_defs_state, "set_defs_state");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestSSyncCmdOrder.cpp 5.13.0-1/libs/base/test/TestSSyncCmdOrder.cpp
--- 5.12.4-1/libs/base/test/TestSSyncCmdOrder.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestSSyncCmdOrder.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,254 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MockServer.hpp"
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
+#include "ecflow/base/stc/SSyncCmd.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// The client handle commands do not change state & modify change number, hence need to bypass these checks
+static bool bypass_state_modify_change_check = false;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_SSyncCmdOrder)
+
+/// define a function which returns nothing, and takes a defs_ptr parameter
+typedef boost::function<void(defs_ptr)> defs_change_cmd;
+
+static std::vector<std::string> vector_abcd() {
+    std::vector<std::string> names;
+    names.reserve(4);
+    names.emplace_back("a");
+    names.emplace_back("b");
+    names.emplace_back("c");
+    names.emplace_back("d");
+    return names;
+}
+static std::vector<std::string> vector_dcba() {
+    std::vector<std::string> names;
+    names.reserve(4);
+    names.emplace_back("d");
+    names.emplace_back("c");
+    names.emplace_back("b");
+    names.emplace_back("a");
+    return names;
+}
+
+static defs_ptr create_defs() {
+    std::vector<std::string> names = vector_dcba();
+    defs_ptr defs                  = Defs::create();
+    for (size_t j = 0; j < names.size(); j++) {
+        suite_ptr s = defs->add_suite(names[j]);
+        if (0 == j) { // only add family to first suite
+            for (size_t k = 0; k < names.size(); k++) {
+                family_ptr f = s->add_family(names[k]);
+                for (const auto& name : names) {
+                    task_ptr t = f->add_task(name);
+                    //               t->add_alias_only(); // alias0
+                    //               t->add_alias_only(); // alias1
+                    //               t->add_alias_only(); // alias2
+                }
+            }
+        }
+    }
+    return defs;
+}
+
+/// Re-use the same test scaffold to modify and then resync, by passing in a function that will modify the defs
+static void test_sync_scaffold(defs_change_cmd the_defs_change_command,
+                               unsigned int test_equality, /*0 means test equality, any other number test size*/
+                               bool full_sync,
+                               unsigned int client_handle) {
+    defs_ptr server_defs = create_defs();
+    ServerReply server_reply;
+    server_reply.set_client_defs(create_defs());
+
+    Ecf::set_debug_equality(true); // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
+                        "Starting point client and server defs should be the same");
+    Ecf::set_debug_equality(false); // only has affect in DEBUG build
+
+    // Get change number before any changes
+    Ecf::set_state_change_no(0);
+    Ecf::set_modify_change_no(0);
+    unsigned int client_state_change_no  = Ecf::state_change_no();
+    unsigned int client_modify_change_no = Ecf::modify_change_no();
+
+    // make some change to the server
+    {
+        Ecf::set_server(true);
+
+        the_defs_change_command(server_defs);
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(errorMsg), "Invariants failed " << errorMsg);
+        BOOST_REQUIRE_MESSAGE(!(*server_reply.client_defs() == *server_defs),
+                              "Expected client and server defs to differ " << *server_reply.client_defs() << "\n"
+                                                                           << "server defs   = " << *server_defs);
+        Ecf::set_server(false);
+    }
+
+    //   cout << "test_sync_scaffold AFTER Command before SYNC: Server:\n" << *server_defs << "\n";
+    //   cout << "test_sync_scaffold AFTER Command before SYNC: Client:\n" << *server_reply.client_defs() << "\n";
+
+    MockServer mock_server(server_defs);
+    SSyncCmd cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
+    string error_msg;
+    BOOST_REQUIRE_MESSAGE(mock_server.defs()->checkInvariants(error_msg), error_msg);
+    BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), "Expected server to change");
+    BOOST_CHECK_MESSAGE(server_reply.in_sync(), "Expected to be in sync");
+    BOOST_CHECK_MESSAGE(server_reply.full_sync() == full_sync, "Expected full sync");
+
+    DebugEquality debug_equality; // only has affect in DEBUG build
+    if (0 == test_equality) {
+        BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(), "Server and client should be same after sync");
+    }
+    else {
+        BOOST_CHECK_MESSAGE(server_reply.client_defs()->suiteVec().size() == test_equality,
+                            "Expected suite of size " << test_equality << " but found "
+                                                      << server_reply.client_defs()->suiteVec().size());
+    }
+}
+
+static void reorder_suites(defs_ptr theDefs) {
+
+    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/a", NOrder::ALPHA)));
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec()) == vector_abcd(),
+                          "NOrder::ALPHA expected "
+                              << ecf::algorithm::join(vector_abcd()) << " but found: "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec())));
+}
+
+static void reorder_family(defs_ptr theDefs) {
+    //   std::cout << "reorder_family\n" << *theDefs << "\n";
+
+    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/d/d", NOrder::ALPHA)));
+
+    std::vector<Family*> families;
+    theDefs->findSuite("d")->getAllFamilies(families);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(families) == vector_abcd(),
+                          "NOrder::ALPHA  expected "
+                              << ecf::algorithm::join(vector_abcd()) << " but found: "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(families)));
+}
+
+static void reorder_task(defs_ptr theDefs) {
+    // std::cout << "reorder_task\n" << *theDefs << "\n";
+
+    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/d/d/d", NOrder::ALPHA)));
+
+    std::vector<Task*> tasks;
+    theDefs->findAbsNode("/d/d")->getAllTasks(tasks);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(tasks) == vector_abcd(),
+                          "NOrder::ALPHA  expected "
+                              << ecf::algorithm::join(vector_abcd()) << " but found: "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(tasks)));
+}
+
+// static void reorder_alias(defs_ptr theDefs) {
+//    //std::cout << "reorder_task\n" << *theDefs << "\n";
+//
+//    TestHelper::invokeRequest(theDefs.get(),Cmd_ptr( new OrderNodeCmd("/d/d/d/alias0",NOrder::ALPHA)));
+//
+//    std::vector<alias_ptr> aliases;
+//    theDefs->findAbsNode("/d/d/d")->get_all_aliases(aliases);
+//    BOOST_REQUIRE_MESSAGE( ecf::algorithm::transform_to_name_vector(aliases) == vector_abcd(),"NOrder::ALPHA  expected
+//    " << ecf::algorithm::join(vector_abcd())<< " but found: " <<
+//    ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(tasks)));
+// }
+
+static void reorder_suites_using_handles(defs_ptr theDefs) {
+
+    // *** NOTE ****: Whenever we register a handle, we get a *FULL* sync
+
+    // create client handle which references all the suites
+    // It should be noted that invokeRequest, uses a MockServer, which set/unsets
+    // Hence after this call Ecf::server_ is false. Hence we need to ensure that following
+    // commands/ DM function set Ecf::server_ to true.
+    std::vector<std::string> suite_names = vector_abcd();
+    TestHelper::invokeRequest(
+        theDefs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
+    BOOST_CHECK_MESSAGE(theDefs->client_suite_mgr().clientSuites().size() == 1,
+                        "Expected 1 Client suites but found " << theDefs->client_suite_mgr().clientSuites().size());
+
+    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/a", NOrder::ALPHA)));
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec()) == vector_abcd(),
+                          "NOrder::ALPHA  expected "
+                              << ecf::algorithm::join(vector_abcd()) << " but found: "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec())));
+}
+
+static void reorder_family_using_handles(defs_ptr theDefs) {
+
+    // *** NOTE ****: Whenever we register a handle, we get a *FULL* sync
+
+    // create client handle which references all the suites
+    // It should be noted that invokeRequest, uses a MockServer, which set/unsets
+    // Hence after this call Ecf::server_ is false. Hence we need to ensure that following
+    // commands/ DM function set Ecf::server_ to true.
+    std::vector<std::string> suite_names;
+    suite_names.emplace_back("d"); // clinet handle for suite 'd' ONLY
+    TestHelper::invokeRequest(
+        theDefs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
+    BOOST_CHECK_MESSAGE(theDefs->client_suite_mgr().clientSuites().size() == 1,
+                        "Expected 1 Client suites but found " << theDefs->client_suite_mgr().clientSuites().size());
+
+    /// Don't call, data model function directly, since Ecf::server_ is false. *here*
+    /// The suite should stay the same, only suite d's family should change
+    TestHelper::invokeRequest(theDefs.get(), Cmd_ptr(new OrderNodeCmd("/d/d", NOrder::ALPHA)));
+    BOOST_REQUIRE_MESSAGE(
+        ecf::algorithm::transform_to_name_vector(theDefs->suiteVec()) == vector_dcba(),
+        "expected " << ecf::algorithm::join(vector_dcba()) << " but found: "
+                    << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs->suiteVec())));
+
+    suite_ptr suite_a = theDefs->findSuite("d");
+    std::vector<Family*> families;
+    suite_a->getAllFamilies(families);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(families) == vector_abcd(),
+                          "NOrder::ALPHA  expected "
+                              << ecf::algorithm::join(vector_abcd()) << " but found: "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(families)));
+}
+
+BOOST_AUTO_TEST_CASE(test_ssync_cmd_test_order) {
+    cout << "Base:: ...test_ssync_cmd_test_order\n";
+    TestLog test_log(
+        "test_ssync_cmd_test_order.log"); // will create log file, and destroy log and remove file at end of scope
+
+    test_sync_scaffold(reorder_suites, 0 /* test equality */, false /* expect full_sync */, 0);
+    test_sync_scaffold(reorder_family, 0 /* test equality */, false /* expect full_sync */, 0);
+    test_sync_scaffold(reorder_task, 0 /* test equality */, false /* expect full_sync */, 0);
+    //   test_sync_scaffold(reorder_alias,  0 /* test equality */, false /* expect full_sync */, 0);
+
+    test_sync_scaffold(
+        reorder_suites_using_handles, 0 /* test equality */, true /* expect full_sync */, 1 /* client handle */);
+    test_sync_scaffold(
+        reorder_family_using_handles, 1 /* test size     */, true /* expect full_sync */, 1 /* client handle */);
+
+    /// Keep valgrind happy
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestSSyncCmd_CH1.cpp 5.13.0-1/libs/base/test/TestSSyncCmd_CH1.cpp
--- 5.12.4-1/libs/base/test/TestSSyncCmd_CH1.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestSSyncCmd_CH1.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,714 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MockServer.hpp"
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+#include "ecflow/base/stc/SNewsCmd.hpp"
+#include "ecflow/base/stc/SSyncCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+/// This test, is used to check sync with the client handles.
+/// The client handles will register interest in a set of suites
+/// When calling sync, check will only receive notification on our
+/// our suites
+// In particular when a set of suites are registered to a handle
+// and we add/delete/check point/order the server passes back to the client
+// the a *new* defs with all the suites corresponding to the handle
+// There is a complication however, the suite are not copied/cloned
+// This causes a problem, since if we create a new defs, and add
+// the suites, the suite defs pointer is *NOW* corrupted, as it will point
+// to the new defs. This is not an issue in real apps, since searisation
+// fixes up these ptrs.
+
+// The client handle commands do not change state & modify change number, hence need to bypass these checks
+static bool bypass_state_modify_change_check = false;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_SSyncCmd_CH1)
+
+static defs_ptr create_client_defs(defs_ptr defs) {
+    for (size_t j = 0; j < 5; j++) {
+        suite_ptr suite = defs->add_suite("s" + ecf::convert_to<std::string>(j));
+        family_ptr f    = suite->add_family("f");
+        f->add_task("t");
+        if (j == 0) {
+            suite->addLimit(Limit("suiteLimit", 10));
+            suite->addRepeat(RepeatDate("YMD", 20090916, 20090916, 1));
+        }
+    }
+    return defs;
+}
+
+static defs_ptr create_server_defs() {
+    defs_ptr defs = Defs::create();
+
+    // Create server defs, with a port other than default.
+    // This allows additional testing. i.e server variables
+    std::vector<Variable> server_variables;
+    ServerState::setup_default_server_variables(server_variables, "3141");
+    defs->set_server().set_server_variables(server_variables);
+
+    // ensure client/server start out the same
+    return create_client_defs(defs);
+}
+
+/// define a function which returns nothing, and takes a defs_ptr parameter
+typedef boost::function<bool(defs_ptr)> defs_change_cmd;
+
+/// Re-use the same test scaffold to modify and then resync, by passing
+/// in a function that will modify the defs
+void test_sync_scaffold(defs_change_cmd the_defs_change_command, const std::string& test_name, bool full_sync = false) {
+    // Create the defs
+    defs_ptr server_defs = create_server_defs();
+    ServerReply server_reply;
+    server_reply.set_client_defs(create_client_defs(Defs::create()));
+
+    Ecf::set_debug_equality(true); // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
+                        test_name << ": Starting point client and server defs should be the same : "
+                                  << "SERVER\n"
+                                  << server_defs << "CLIENT\n"
+                                  << server_reply.client_defs());
+    Ecf::set_debug_equality(false); // only has affect in DEBUG build
+
+    // set handle and change numbers, before any changes
+    Ecf::set_state_change_no(0);
+    Ecf::set_modify_change_no(0);
+    unsigned int client_state_change_no  = Ecf::state_change_no();
+    unsigned int client_modify_change_no = Ecf::modify_change_no();
+    unsigned int client_handle           = 0;
+
+    bool expected_change;
+
+    // make some change to the server
+    {
+        /// create client handle which references suites s0 and s4, in the server defs
+        /// Registering suites should change handle_changed boolean
+        std::vector<std::string> suite_names;
+        suite_names.emplace_back("s0");
+        suite_names.emplace_back("s4");
+        TestHelper::invokeRequest(
+            server_defs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
+
+        BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().clientSuites().size() == 1,
+                            test_name << ": Expected 1 Client suites but found "
+                                      << server_defs->client_suite_mgr().clientSuites().size());
+        client_handle = server_defs->client_suite_mgr().clientSuites().front().handle();
+        BOOST_CHECK_MESSAGE(client_handle == 1, "");
+
+        /// Check that handle_changed set, required for syncing, i.e needed for full sync , without change state/modify
+        /// numbers
+        BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().handle_changed(client_handle) == true,
+                            "Expected handle_changed to be set when suites are registered ");
+
+        /// called create Defs should clear the flag. make sure server state, is synced
+        defs_ptr the_client_defs = server_defs->client_suite_mgr().create_defs(client_handle, server_defs);
+        BOOST_CHECK_MESSAGE(the_client_defs->suiteVec().size() == 2, test_name << ": Expected 2 suites");
+        BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().handle_changed(client_handle) == false,
+                            test_name << ": Expected handle_changed to be cleared after create_defs()");
+        BOOST_CHECK_MESSAGE(server_defs->server().compare(the_client_defs->server()),
+                            test_name << ": Server state does not match");
+
+        Ecf::set_server(true);
+        expected_change = the_defs_change_command(server_defs);
+        std::string error_msg;
+        BOOST_REQUIRE_MESSAGE(server_defs->checkInvariants(error_msg),
+                              test_name << ": Invariants failed: " << error_msg);
+        Ecf::set_server(false);
+
+        /// Call create defs again, after change in server defs, check server state is synced
+        the_client_defs = server_defs->client_suite_mgr().create_defs(client_handle, server_defs);
+        BOOST_CHECK_MESSAGE(server_defs->server().compare(the_client_defs->server()),
+                            test_name << ": Server state does not match");
+        BOOST_CHECK_MESSAGE(server_defs->get_flag() == the_client_defs->get_flag(),
+                            test_name << ": Server flags do not match");
+    }
+
+    MockServer mock_server(server_defs);
+    SNewsCmd news_cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
+    SSyncCmd cmd(client_handle, client_state_change_no, client_modify_change_no, &mock_server);
+
+    if (expected_change) {
+        BOOST_CHECK_MESSAGE(news_cmd.get_news(), test_name << " : get_news : Expected server to change");
+        BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), test_name << " : do_sync : Expected server to change");
+        BOOST_CHECK_MESSAGE(server_reply.in_sync(), test_name << " : in_sync : Expected client server to be in sync");
+        BOOST_CHECK_MESSAGE(server_reply.full_sync() == full_sync,
+                            test_name << ": Expected sync not as expected. client: " << server_reply.full_sync()
+                                      << " full_sync: " << full_sync);
+        BOOST_CHECK_MESSAGE(server_defs->state() == server_reply.client_defs()->state(),
+                            test_name << ": Expected server State(" << NState::toString(server_defs->state())
+                                      << ") to be same as client state("
+                                      << NState::toString(server_reply.client_defs()->state()) << ")");
+        if (full_sync) {
+            Ecf::set_debug_equality(true); // only has affect in DEBUG build
+            BOOST_CHECK_MESSAGE(server_defs->server().compare(server_reply.client_defs()->server()),
+                                test_name << ": Server state does not match");
+        }
+
+        // * Note we expect client defs to fail invariant checking when doing a full sync with handles
+        // * Under real server this should be ok since, we fix up the defs ptr, during serialisation
+
+        // * note. We can't really compare server and client defs, since when we sync with
+        // * with handles, we only return a sub set of the suites, in our handle
+
+        // DO a sync again. hence we should expect no changes
+        server_reply.clear_for_invoke(false);
+        Ecf::set_server(true);
+        /* server side */ SNewsCmd news_cmd1(client_handle,
+                                             server_reply.client_defs()->state_change_no(),
+                                             server_reply.client_defs()->modify_change_no(),
+                                             &mock_server);
+        /* server side */ SSyncCmd cmd1(client_handle,
+                                        server_reply.client_defs()->state_change_no(),
+                                        server_reply.client_defs()->modify_change_no(),
+                                        &mock_server);
+        Ecf::set_server(false);
+        /* client side */ BOOST_CHECK_MESSAGE(!news_cmd1.get_news(),
+                                              test_name << ": Expected no changes to client, we should be in sync");
+        /* client side */ BOOST_CHECK_MESSAGE(!cmd1.do_sync(server_reply),
+                                              test_name << ": Expected no changes to client, we should be in sync");
+    }
+    else {
+
+        BOOST_CHECK_MESSAGE(!news_cmd.get_news(), test_name << ": Expected no change");
+        BOOST_CHECK_MESSAGE(!cmd.do_sync(server_reply), test_name << ": Expected no change");
+        BOOST_CHECK_MESSAGE(!server_reply.in_sync(), test_name << ": Expected no change");
+        BOOST_CHECK_MESSAGE(!(*server_defs == *server_reply.client_defs()),
+                            test_name << ": Server and client defs expected to differ");
+    }
+}
+
+static bool set_server_state_shutdown(defs_ptr defs) {
+    defs->set_server().set_state(SState::SHUTDOWN);
+    return true; // expect changes
+}
+static bool set_server_state_running(defs_ptr defs) {
+    defs->set_server().set_state(SState::RUNNING);
+    return true; // expect changes
+}
+
+static bool set_defs_flag(defs_ptr defs) {
+    defs->flag().set(ecf::Flag::BYRULE);
+    defs->flag().set(ecf::Flag::EDIT_FAILED);
+    return true; // expect changes
+}
+
+static bool change_suites_s3_outside_of_handle(defs_ptr defs) {
+    /// Make a state change to suites s3, in the server. This is *not* in the client handle
+    /// Note: we do *NOT* make a state change as this will be propagated to the defs, and hence will be synced
+    /// We *NEED* MockSuiteChangedServer, so that change is propagated to the suite.
+    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
+    defs->findSuite("s3")->suspend();                         // small scale state change
+    return false;                                             // expect no changes
+}
+
+static bool change_suites_s3_outside_of_handle_add_variable(defs_ptr defs) {
+    /// make a state change to suites s3, in the server. This is *not* in the client handle
+    /// We *NEED* MockSuiteChangedServer, so that change is propagated to the suite.
+    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
+    defs->findSuite("s3")->add_variable("Var", "value");      // small scale state change
+    return false;                                             // expect no changes in sync
+}
+
+static bool add_task_to_suite_s3(defs_ptr defs) {
+    /// make a modify change to suites s3, in the server. This is *not* in the client handle
+    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
+    defs->findSuite("s3")->addTask(Task::create("s3_task"));  // small scale change
+    return false;                                             //  expect no changes, since suite s3 not in handle
+}
+
+static bool delete_task_on_suite_s3(defs_ptr defs) {
+    /// make a modify change to suites s3, in the server. This is *not* in the client handle
+    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
+    defs->findAbsNode("/s3/f/t")->remove();                   // small scale change
+    return false;                                             // expect no changes, since suite s3 not in handle
+}
+static bool delete_family_on_suite_s3(defs_ptr defs) {
+    /// make a modify change to suites s3, in the server. This is *not* in the client handle
+    MockSuiteChangedServer mockServer(defs->findSuite("s3")); // Increment suite state/modify change number
+    defs->findAbsNode("/s3/f")->remove();                     // small scale change
+    return false;                                             // expect no changes, since suite s3 not in handle
+}
+
+static bool change_state_of_s4(defs_ptr defs) {
+    /// Ok now make state change to s4, which **is** in the handle
+    /// We need MockSuiteChangedServer, so that change is propagated to the suite.
+    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
+    defs->findSuite("s4")->set_state(NState::SUBMITTED);      // small scale change
+    return true;                                              // expect changes
+}
+
+static bool add_variable_to_suite_s4(defs_ptr defs) {
+    /// Ok now make state change to s4, which **is** in the handle
+    /// We need MockSuiteChangedServer, so that change is propagated to the suite.
+    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
+    defs->findSuite("s4")->add_variable("Var", "value");      // small scale state change
+    return true;                                              // expect changes
+}
+
+static bool add_server_user_variables(defs_ptr defs) {
+    // Change server. This is outside of any suites
+    std::vector<Variable> user_variables;
+    user_variables.emplace_back("a", "b");
+    user_variables.emplace_back("c", "d");
+    defs->set_server().set_user_variables(user_variables);
+    return true; // expect change
+}
+
+static bool add_task_to_suite_s4(defs_ptr defs) {
+    /// Ok now make modify change to s4, which **is** in the handle
+    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
+    defs->findSuite("s4")->addTask(Task::create("s4_task"));  // small scale change
+    return true;                                              // expect changes
+}
+
+static bool delete_task_on_suite_s4(defs_ptr defs) {
+    /// Ok now make modify change to s4, which **is** in the handle
+    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
+    defs->findAbsNode("/s4/f/t")->remove();                   // small scale change
+    return true;                                              // expect changes, since suite s4 is in handle
+}
+
+static bool delete_family_on_suite_s4(defs_ptr defs) {
+    /// Ok now make modify change to s4, which **is** in the handle
+    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
+    defs->findAbsNode("/s4/f")->remove();                     // small scale change
+    return true;                                              // expect changes, since suite s4 is in handle
+}
+
+static bool change_order_of_s4_top(defs_ptr defs) {
+    /// Ok make modify change to s4, which **is** in the handle
+    suite_ptr s4 = defs->findSuite("s4");
+    MockSuiteChangedServer mockServer(s4); // Increment suite state/modify change number
+    defs->order(s4.get(), NOrder::TOP);    // small scale scale change
+    return true;
+}
+
+static bool change_order_of_s4_bottom(defs_ptr defs) {
+    /// Ok make modify change to s4, which **is** in the handle
+    suite_ptr s4 = defs->findSuite("s4");
+    MockSuiteChangedServer mockServer(s4); // Increment suite state/modify change number
+    defs->order(s4.get(), NOrder::BOTTOM); // small scale change
+    return true;
+}
+
+static bool delete_suite_s4(defs_ptr defs) {
+    /// Ok now make delete s4 which, which **is** in the handle
+    MockSuiteChangedServer mockServer(defs->findSuite("s4")); // Increment suite state/modify change number
+    defs->findSuite("s4")->remove();                          // large scale change
+    return true;                                              // expect changes
+}
+
+static bool set_defs_state(defs_ptr defs) {
+    defs->set_state(NState::ABORTED); // changes the defs state
+    return true;                      // expect changes
+}
+
+static bool set_defs_state_2(defs_ptr defs) {
+    defs->set_state(NState::ABORTED); // changes the defs state
+    return delete_suite_s4(defs);     // large scale change
+}
+
+static bool add_server_variable(defs_ptr defs) {
+    // Change defs server state. small scale change
+    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::ADD_VARIABLE, "_fred_", "value")));
+    return true;
+}
+
+static bool change_server_variable(defs_ptr defs) {
+    // Because the scaffold create client/server defs each time.
+    // To test change/delete variables we modify the default set
+    TestHelper::invokeRequest(defs.get(), Cmd_ptr(new AlterCmd("/", AlterCmd::VARIABLE, "ECF_TRIES", "4")));
+    return true;
+}
+
+// ===============================================================================
+// The modifiers, do this for suite s0 which is in a handle
+// ===============================================================================
+
+static bool s0_delete_some_attributes(defs_ptr defs) {
+    /// Ok now make state change to s4, which **is** in the handle
+    /// We need MockSuiteChangedServer, so that change is propagated to the suite.
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    std::vector<Task*> tasks;
+    suite->getAllTasks(tasks);
+    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
+
+    for (Task* task : tasks) {
+        SuiteChanged1 changed(task->suite());
+        task->addMeter(Meter("meter", 0, 100));
+    }
+    return true;
+}
+
+static bool s0_add_some_attributes(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    std::vector<task_ptr> tasks;
+    suite->get_all_tasks(tasks);
+    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
+
+    for (task_ptr task : tasks) {
+        SuiteChanged1 changed(suite.get());
+        task->addDay(DayAttr(DayAttr::TUESDAY));
+    }
+    return true;
+}
+
+static bool s0_begin(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    suite->begin();
+    return true;
+}
+
+static bool s0_add_alias(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    std::vector<task_ptr> tasks;
+    suite->get_all_tasks(tasks);
+    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
+
+    SuiteChanged1 changed(tasks[0]->suite());
+    tasks[0]->add_alias_only();
+    return true;
+}
+
+static bool s0_remove_all_tasks(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    // Remove tasks should force a incremental sync
+    std::vector<task_ptr> tasks;
+    suite->get_all_tasks(tasks);
+    BOOST_REQUIRE_MESSAGE(!tasks.empty(), "Expected at least one task");
+    for (task_ptr task : tasks) {
+        SuiteChanged1 changed(task->suite());
+        task->remove();
+    }
+
+    tasks.clear();
+    suite->get_all_tasks(tasks);
+    BOOST_REQUIRE_MESSAGE(tasks.empty(), "Failed to delete tasks");
+    return true;
+}
+
+static bool s0_remove_a_family(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    std::vector<Family*> vec;
+    suite->getAllFamilies(vec);
+    size_t family_size = vec.size();
+    BOOST_REQUIRE_MESSAGE(!vec.empty(), "Expected at least one family");
+    if (!vec.empty()) {
+        SuiteChanged1 changed(vec[0]->suite());
+        vec[0]->remove();
+    }
+
+    vec.clear();
+    suite->getAllFamilies(vec);
+    BOOST_REQUIRE_MESSAGE(vec.size() < family_size, "Failed to delete family");
+    return true;
+}
+
+static bool s0_change_clock_gain(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    suite->changeClockGain("100001");
+    return true;
+}
+
+static bool s0_change_clock_type_to_real(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    suite->changeClockType("hybrid");
+    return true;
+}
+
+static bool s0_change_clock_date(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+
+    suite->changeClockDate("1.1.2001");
+    return true;
+}
+
+static bool s0_change_clock_sync(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    suite->changeClockSync();
+    return true;
+}
+
+/// This has been split into two functions, as changing both together could mask an error
+/// i.e found bug where we forgot to update state_change number when changing the limit
+/// max value, however because we had, changed value as well it got masked.
+static bool s0_change_limit_max(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    // Note: we ONLY* need MockSuiteChangedServer, when we make changes via functions and not commands
+
+    std::vector<limit_ptr> theLimits = suite->limits();
+    BOOST_REQUIRE_MESSAGE(!theLimits.empty(), "The limit are empty on suite s0 " << defs);
+    for (limit_ptr l : theLimits) {
+        // std::cout << "found " << l->toString() << "\n";
+        TestHelper::invokeRequest(defs.get(),
+                                  Cmd_ptr(new AlterCmd(suite->absNodePath(), AlterCmd::LIMIT_MAX, l->name(), "90")));
+        limit_ptr v = suite->find_limit(l->name());
+        BOOST_CHECK_MESSAGE(v.get() && v->theLimit() == 90, "expected to find limit with max value of 90");
+    }
+    return true;
+}
+
+static bool s0_change_limit_value(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    // Note: we ONLY* need MockSuiteChangedServer, when we make changes via functions and not commands
+
+    std::vector<limit_ptr> theLimits = suite->limits();
+    for (limit_ptr l : theLimits) {
+        TestHelper::invokeRequest(defs.get(),
+                                  Cmd_ptr(new AlterCmd(suite->absNodePath(), AlterCmd::LIMIT_VAL, l->name(), "33")));
+        limit_ptr v = suite->find_limit(l->name());
+        BOOST_CHECK_MESSAGE(v.get() && v->value() == 33, "expected to find limit with value of 33");
+    }
+    return true;
+}
+
+static bool s0_update_repeat(defs_ptr defs) {
+    suite_ptr suite = defs->findSuite("s0");
+    BOOST_REQUIRE_MESSAGE(suite, "Could not find suite");
+    MockSuiteChangedServer mockServer(suite); // Increment suite state/modify change number
+
+    SuiteChanged1 changed(suite.get());
+    suite->increment_repeat();
+    return true;
+}
+
+BOOST_AUTO_TEST_CASE(test_ssync_using_handle) {
+    cout << "Base:: ...test_ssync_using_handle\n";
+    TestLog test_log(
+        "test_ssync_using_handle.log"); // will create log file, and destroy log and remove file at end of scope
+
+    // =======================================================================================
+    // Note: where we update Suite::modify_change_no()  we should *EXPECT* a full sync
+    // =======================================================================================
+
+    // test_sync_scaffold will created 5 suites  s0,s1,s2,s3,s4,s5 and add suites s0 & s4 to a handle
+    // The following test will perform changes in/out of handles
+
+    { // Change defs state in the presence of handles. These should sync regardless of handles
+        // The default server state is HALTED, hence setting to halted will not show a change
+        test_sync_scaffold(set_server_state_shutdown, "set_server_state_shutdown");
+        test_sync_scaffold(set_server_state_running, "set_server_state_running");
+        test_sync_scaffold(set_defs_flag, "set_defs_flag");
+
+        test_sync_scaffold(add_server_variable, "add_server_variable");
+        test_sync_scaffold(change_server_variable, "change_server_variable");
+
+        test_sync_scaffold(set_defs_state, "set_defs_state");
+        test_sync_scaffold(set_defs_state_2, "set_defs_state_2", true /* expect a full sync */);
+    }
+
+    test_sync_scaffold(change_suites_s3_outside_of_handle, "change_suites_s3_outside_of_handle");
+    test_sync_scaffold(change_suites_s3_outside_of_handle_add_variable,
+                       "change_suites_s3_outside_of_handle_add_variable");
+    test_sync_scaffold(add_task_to_suite_s3, "add_task_to_suite_s3");
+    test_sync_scaffold(delete_task_on_suite_s3, "delete_task_on_suite_s3");
+    test_sync_scaffold(delete_family_on_suite_s3, "delete_family_on_suite_s3");
+
+    test_sync_scaffold(change_order_of_s4_top, "change_order_of_s4_top");       // change order is an incremental sync
+    test_sync_scaffold(change_order_of_s4_bottom, "change_order_of_s4_bottom"); // change order is an incremental sync
+
+    test_sync_scaffold(change_state_of_s4, "change_state_of_s4");
+    test_sync_scaffold(add_variable_to_suite_s4, "add_variable_to_suite_s4");
+    test_sync_scaffold(add_server_user_variables, "add_server_user_variables");
+    test_sync_scaffold(add_task_to_suite_s4, "add_task_to_suite_s4");
+    test_sync_scaffold(delete_task_on_suite_s4, "delete_task_on_suite_s4");
+    test_sync_scaffold(delete_family_on_suite_s4, "delete_family_on_suite_s4");
+    test_sync_scaffold(delete_suite_s4, "delete_suite_s4", true /* expect a full sync */);
+
+    test_sync_scaffold(s0_delete_some_attributes, "s0_delete_some_attributes");
+    test_sync_scaffold(s0_add_some_attributes, "s0_add_some_attributes");
+    test_sync_scaffold(s0_add_alias, "s0_add_alias");
+    test_sync_scaffold(s0_update_repeat, "s0_update_repeat");
+    test_sync_scaffold(s0_change_limit_max, "s0_change_limit_max");
+    test_sync_scaffold(s0_change_limit_value, "s0_change_limit_value");
+    test_sync_scaffold(s0_begin, "s0_begin", true /* expect a full sync */);
+
+    test_sync_scaffold(s0_remove_all_tasks, "s0_remove_all_tasks");
+    test_sync_scaffold(s0_remove_a_family, "s0_remove_a_family");
+
+    test_sync_scaffold(s0_change_clock_gain, "s0_change_clock_gain", true /* expect a full sync */);
+    test_sync_scaffold(s0_change_clock_type_to_real, "s0_change_clock_type_to_real", true /* expect a full sync */);
+    test_sync_scaffold(s0_change_clock_date, "s0_change_clock_date", true /* expect a full sync */);
+    test_sync_scaffold(s0_change_clock_sync, "s0_change_clock_sync", true /* expect a full sync */);
+}
+
+// =============================================================================================
+
+static defs_ptr create_the_server_defs() {
+    defs_ptr defs                    = create_server_defs();
+    std::vector<suite_ptr> suite_vec = defs->suiteVec();
+    for (size_t j = 0; j < suite_vec.size(); j++) {
+        suite_vec[j]->set_state_change_no(j);
+        suite_vec[j]->set_modify_change_no(j);
+    }
+    return defs;
+}
+
+BOOST_AUTO_TEST_CASE(test_ssync_full_sync_using_handle) {
+    /// This test checks that when user has registered with all the suites.
+    /// Syncing should use the global change numbers
+    /// **ADDITIONALLY* the newsCmd  must reflect this.
+    /// This is handled in ClientSuites::create_defs, in that we *MUST* update the
+    /// local change numbers to be the same as the global change numbers
+    /// This is important since the NewsCmd must be in *SYNC* with SYNCCmd
+
+    cout << "Base:: ...test_ssync_full_sync_using_handle\n";
+    TestLog test_log("test_ssync_full_sync_using_handle.log"); // will create log file, and destroy log and remove file
+                                                               // at end of scope
+
+    // Create the server defs with some changes, in state & modify numbers
+    defs_ptr server_defs = create_the_server_defs();
+
+    // Create Client defs, without any changes
+    ServerReply server_reply;
+    server_reply.set_client_defs(create_client_defs(Defs::create()));
+
+    // Server & client should be the same, since we ignore change numbers in the comparison
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    BOOST_CHECK_MESSAGE(*server_defs == *server_reply.client_defs(),
+                        "Starting point client and server defs should be the same"
+                            << "SERVER\n"
+                            << server_defs << "CLIENT\n"
+                            << server_reply.client_defs());
+
+    /// register interest in **ALL** the suites
+    std::vector<std::string> suite_names;
+    suite_names.emplace_back("s0");
+    suite_names.emplace_back("s1");
+    suite_names.emplace_back("s2");
+    suite_names.emplace_back("s3");
+    suite_names.emplace_back("s4");
+    TestHelper::invokeRequest(
+        server_defs.get(), Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), bypass_state_modify_change_check);
+
+    /// make sure handle created.
+    BOOST_CHECK_MESSAGE(server_defs->client_suite_mgr().clientSuites().size() == 1,
+                        "Expected 1 Client suites but found " << server_defs->client_suite_mgr().clientSuites().size());
+    unsigned int client_handle = server_defs->client_suite_mgr().clientSuites().front().handle();
+    BOOST_CHECK_MESSAGE(client_handle == 1, "");
+
+    // make sure server suites have different state/modify numbers from the client
+    {
+        unsigned int server_state_change_no  = 0;
+        unsigned int server_modify_change_no = 0;
+        server_defs->client_suite_mgr().max_change_no(client_handle, server_state_change_no, server_modify_change_no);
+        BOOST_CHECK_MESSAGE(server_state_change_no == 4, "");
+        BOOST_CHECK_MESSAGE(server_modify_change_no == 4, "");
+
+        // *MAKE* sure global change numbers are different to handle suite change numbers
+        // This is the key part of this test.
+        // Since syncing should transfer these change numbers to the client
+        Ecf::set_state_change_no(server_state_change_no + 10);
+        Ecf::set_modify_change_no(server_modify_change_no + 20);
+    }
+
+    // Now sync from server
+    Ecf::set_server(true);
+    MockServer mock_server(server_defs);
+    /* server side */ SNewsCmd news_cmd(client_handle,
+                                        server_reply.client_defs()->state_change_no(),
+                                        server_reply.client_defs()->modify_change_no(),
+                                        &mock_server);
+    /* server side */ SSyncCmd cmd(client_handle,
+                                   server_reply.client_defs()->state_change_no(),
+                                   server_reply.client_defs()->modify_change_no(),
+                                   &mock_server);
+    Ecf::set_server(false);
+
+    // make sure SSyncCmd updated the server change numbers, to use global change numbers
+    unsigned int server_state_change_no  = 0;
+    unsigned int server_modify_change_no = 0;
+    {
+        server_defs->client_suite_mgr().max_change_no(client_handle, server_state_change_no, server_modify_change_no);
+        BOOST_CHECK_MESSAGE(server_state_change_no == 14, "");
+        BOOST_CHECK_MESSAGE(server_modify_change_no == 24, "");
+    }
+
+    // SYNC the client, via do_sync( this should transfer change numbers to the client )
+    BOOST_CHECK_MESSAGE(news_cmd.get_news(), "Expected server to change");
+    BOOST_CHECK_MESSAGE(cmd.do_sync(server_reply), "Expected server to change");
+    BOOST_CHECK_MESSAGE(server_reply.in_sync(), "Expected server to change");
+    BOOST_CHECK_MESSAGE(server_defs->state() == server_reply.client_defs()->state(),
+                        "Expected server State(" << NState::toString(server_defs->state())
+                                                 << ") to be same as client state("
+                                                 << NState::toString(server_reply.client_defs()->state()) << ")");
+
+    // After do_sync client and server change number should be in sync
+    BOOST_CHECK_MESSAGE(server_reply.client_defs()->state_change_no() == server_state_change_no,
+                        "Expected " << server_reply.client_defs()->state_change_no()
+                                    << " state change number but found " << server_state_change_no);
+    BOOST_CHECK_MESSAGE(server_reply.client_defs()->modify_change_no() == server_modify_change_no,
+                        "Expected " << server_reply.client_defs()->modify_change_no()
+                                    << " modify change number but found " << server_modify_change_no);
+
+    // Do final sync, there should not be ANY changes
+    Ecf::set_server(true);
+    /* server side */ SNewsCmd news_cmd1(client_handle,
+                                         server_reply.client_defs()->state_change_no(),
+                                         server_reply.client_defs()->modify_change_no(),
+                                         &mock_server);
+    /* server side */ SSyncCmd cmd1(client_handle,
+                                    server_reply.client_defs()->state_change_no(),
+                                    server_reply.client_defs()->modify_change_no(),
+                                    &mock_server);
+    Ecf::set_server(false);
+    /* client side */ BOOST_CHECK_MESSAGE(!news_cmd1.get_news(), "Expected no changes to client, we should be in sync");
+    /* client side */ BOOST_CHECK_MESSAGE(!cmd1.do_sync(server_reply),
+                                          "Expected no changes to client, we should be in sync");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestSpecificIssues.cpp 5.13.0-1/libs/base/test/TestSpecificIssues.cpp
--- 5.12.4-1/libs/base/test/TestSpecificIssues.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestSpecificIssues.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,81 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_SpecificIssues)
+
+static defs_ptr create_defs() {
+    // suite s1
+    //   family f1
+    //     trigger f2 == complete
+    //     task t1
+    //     task t2
+    //   endfamily
+    //   family f2
+    //     task t1
+    //     task t2
+    //   endfamily
+    // endsuite
+    defs_ptr theDefs = Defs::create();
+    suite_ptr suite  = theDefs->add_suite("s1");
+    family_ptr f1    = suite->add_family("f1");
+    family_ptr f2    = suite->add_family("f2");
+    f1->add_trigger("f2 == complete");
+    f1->add_task("t1");
+    f1->add_task("t2");
+    f2->add_task("t1");
+    f2->add_task("t2");
+
+    return theDefs;
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_189) {
+    cout << "Base:: ...test_ECFLOW_189\n";
+    TestLog test_log("test_ECFLOW_189.log"); // will create log file, and destroy log and remove file at end of scope
+
+    defs_ptr the_defs = create_defs();
+    the_defs->beginAll();
+    node_ptr t1 = the_defs->findAbsNode("/s1/f1/t1");
+    node_ptr t2 = the_defs->findAbsNode("/s1/f1/t2");
+
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t1->absNodePath())));
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::SUSPEND, t2->absNodePath())));
+
+    TestHelper::test_state(t1, DState::SUSPENDED);
+    TestHelper::test_state(t2, DState::SUSPENDED);
+
+    // Now resume /s1/f1/t1 and /s1/f1/t2
+    TestHelper::invokeRequest(the_defs.get(), Cmd_ptr(new PathsCmd(PathsCmd::RESUME, t1->absNodePath())));
+
+    // We expect state to be queued since the trigger on /s1/f1 should prevent jobs from running
+    // If we find submitted or aborted(i.e it was free to run, but could not generate the jobs), then its an error
+    TestHelper::test_state(t1, NState::QUEUED);
+    TestHelper::test_state(t2, NState::QUEUED);
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/base/test/TestStatsCmd.cpp 5.13.0-1/libs/base/test/TestStatsCmd.cpp
--- 5.12.4-1/libs/base/test/TestStatsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/base/test/TestStatsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,136 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MockServer.hpp"
+#include "MyDefsFixture.hpp"
+#include "ecflow/base/ClientToServerRequest.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/base/stc/ServerToClientCmd.hpp"
+#include "ecflow/core/Log.hpp"
+
+///
+///   Tests for `Stats` command
+///    - check that the 'number of suits' is correctly reported
+///    - check that the 'requests per second' is correctly reported
+///
+
+namespace {
+
+std::string extract_report_value(const std::string& report, const std::string& label) {
+    boost::char_separator<char> sep("\n"); // splitting report by lines
+    using tokenizer_t = boost::tokenizer<boost::char_separator<char>>;
+    tokenizer_t tokens(report, sep);
+    for (const auto& token : tokens) {
+        if (token.find(label) != std::string::npos) {
+            // Important!
+            //   By convention, the labels in report by `Stats` have width 35
+            //   If this convention changes, the test will fail
+            return token.substr(35);
+        }
+    }
+    throw std::runtime_error("Unable to find requested label");
+}
+
+int extract_number_of_suites(const std::string& report) {
+    auto entry = extract_report_value(report, "Number of Suites");
+    return ecf::convert_to<int>(entry);
+}
+
+std::string extract_request_per_second(const std::string& report) {
+    auto entry = extract_report_value(report, "Request/s per 1,5,15,30,60 min");
+    return entry;
+}
+
+} // namespace
+
+BOOST_AUTO_TEST_SUITE(U_Base)
+
+BOOST_AUTO_TEST_SUITE(T_StatsCmd)
+
+BOOST_AUTO_TEST_CASE(test_stats_cmd__reports_number_of_suites) {
+
+    ecf::TestLog test_log("test_stats_cmd__reports_number_of_suites.log");
+
+    Defs defs;
+    // Considering 3 suites, to be reported by `Stats`
+    defs.addSuite(Suite::create("some_suite"));
+    defs.addSuite(Suite::create("another_suite"));
+    defs.addSuite(Suite::create("yet_another_suite"));
+
+    MockServer server(&defs);
+
+    // Execute `Stats` command
+    {
+        auto command = std::make_shared<CtsCmd>(CtsCmd::STATS);
+
+        ClientToServerRequest request;
+        request.set_cmd(command);
+
+        try {
+            auto reply = request.handleRequest(&server);
+            if (reply) {
+                BOOST_REQUIRE(reply->ok());
+
+                auto no_of_suites = extract_number_of_suites(reply->get_string());
+                BOOST_REQUIRE(no_of_suites == 3);
+            }
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Unexpected exception : " << e.what() << " : " << request);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_stats_cmd__reports_requests_per_second) {
+
+    ecf::TestLog test_log("test_stats_cmd__reports_requests_per_second.log");
+
+    Defs defs;
+
+    MockServer server(&defs);
+
+    // Simulate some fictitious server load to report statistics
+    int polling = 60; // every 60 seconds
+    int samples = 60; // to cover 1 hour 'uptime'
+    for (int i = 0; i < samples; ++i) {
+        int sample = 30 + (samples - i - 1);
+        // Note: the request counter sample varies to allow checking that the
+        // measurements are processed in the correct order
+        server.stats().request_count_ = sample;
+        server.stats().update_stats(polling);
+    }
+
+    // Execute `Stats` command
+    {
+        auto command = std::make_shared<CtsCmd>(CtsCmd::STATS);
+
+        ClientToServerRequest request;
+        request.set_cmd(command);
+
+        try {
+            auto reply = request.handleRequest(&server);
+            if (reply) {
+                BOOST_REQUIRE(reply->ok());
+
+                auto requests_per_second = extract_request_per_second(reply->get_string());
+                BOOST_REQUIRE(requests_per_second == "0.50 0.53 0.62 0.74 0.99");
+            }
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Unexpected exception : " << e.what() << " : " << request);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/.gitignore 5.13.0-1/libs/client/.gitignore
--- 5.12.4-1/libs/client/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/.gitignore	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+/gnuplot.script
diff -pruN 5.12.4-1/libs/client/CMakeLists.txt 5.13.0-1/libs/client/CMakeLists.txt
--- 5.12.4-1/libs/client/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,186 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+# ========================================================================
+# EXE ecflow_client, if OpenSSL not enabled ${OPENSSL_LIBRARIES}, is empty
+
+ecbuild_add_executable(
+  TARGET
+    ecflow_client
+  SOURCES
+    src/ecflow/client/ClientMain.cpp
+  LIBS
+    ecflow_all
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+)
+target_clangformat(ecflow_client)
+
+# Override default behaviour that add RPATHS during install
+# The only thing that seem to work is set INSTALL_RPATH to ""
+# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
+# had no effect
+#          
+SET_TARGET_PROPERTIES(ecflow_client
+  PROPERTIES
+    INSTALL_RPATH ""
+)
+
+
+
+# use, i.e. don't skip the full RPATH for the build tree
+#SET(CMAKE_SKIP_BUILD_RPATH  FALSE)
+
+# when building, don't use the install RPATH already
+# (but later on when installing)
+#SET(CMAKE_BUILD_WITH_INSTALL_RPATH FALSE) 
+
+# the RPATH to be used when installing
+#SET(CMAKE_INSTALL_RPATH "")
+
+# don't add the automatically determined parts of the RPATH
+# which point to directories outside the build tree to the install RPATH
+#SET(CMAKE_INSTALL_RPATH_USE_LINK_PATH FALSE)
+
+
+# ================================================================================                         
+# TEST
+set(test_srcs
+  # Headers
+  test/InvokeServer.hpp
+  # Sources
+  test/TestClient_main.cpp # test entry point
+  test/TestClientEnvironment.cpp
+  test/TestClientOptions.cpp
+  test/TestClientInterface.cpp
+  test/TestJobGenOnly.cpp
+  test/TestLifeCycle.cpp
+  test/TestInitAddVariables.cpp
+  test/TestRtt.cpp
+  test/TestUrlCmd.cpp
+)
+
+if (ENABLE_SERVER)
+  list(APPEND test_srcs
+    # Headers
+    test/SCPort.hpp
+    # Sources
+    test/SCPort.cpp
+    test/TestClientTimeout.cpp
+    test/TestClientHandleCmd.cpp
+    test/TestCheckPtDefsCmd.cpp
+    test/TestCustomUser.cpp
+    test/TestGroupCmd.cpp
+    test/TestLoadDefsCmd.cpp
+    test/TestLogAndCheckptErrors.cpp
+    test/TestPasswdFile.cpp
+    test/TestPlugCmd.cpp
+    test/TestServer.cpp
+    test/TestServerAndLifeCycle.cpp
+    test/TestServerLoad.cpp
+    test/TestSignalSIGTERM.cpp
+    test/TestWhiteListFile.cpp
+  )
+endif()
+
+ecbuild_add_test(
+  TARGET
+    s_client
+  LABELS
+    integration nightly
+  SOURCES
+    ${test_srcs}
+  INCLUDES
+    ../base/test
+    ../node/test
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+    Boost::timer
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+  DEPENDS
+    ecflow_server # the server is launched to support tests
+  TEST_DEPENDS
+    u_base
+  CONDITION
+    ENABLE_SERVER # AND ENABLE_TESTS
+)
+target_clangformat(s_client
+  CONDITION ENABLE_SERVER AND ENABLE_TESTS
+)
+
+if (ENABLE_ALL_TESTS AND ENABLE_SERVER)
+  #
+  # Simple stand alone test
+  #
+  ecbuild_add_test(
+    TARGET
+      p_large_defs
+    LABELS
+      performance
+      manual # requires manual definition of env var ECF_TEST_DEFS_DIR
+    SOURCES
+      # Headers
+      test/SCPort.hpp
+      # Sources
+      test/SCPort.cpp
+      test/TestSinglePerf.cpp
+      test/TestSinglePerf_main.cpp # test entry point
+    INCLUDES
+      ../base/test
+    LIBS
+      ecflow_all
+      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    DEPENDS
+      ecflow_server # the server is launched to support tests
+    TEST_DEPENDS
+      u_base
+  )
+  target_clangformat(p_large_defs
+    CONDITION ENABLE_TESTS
+  )
+
+  #
+  # test migration
+  #
+  ecbuild_add_test(
+    TARGET
+      m_migration
+    LABELS
+      migration
+      manual # requires command line argument: m_test_migration <>
+    SOURCES
+      # Headers
+      test/SCPort.hpp
+      # Sources
+      test/SCPort.cpp
+      test/TestMigration.cpp
+      test/TestMigration_main.cpp # test entry point
+    INCLUDES
+      ../base/test
+    LIBS
+      ecflow_all
+      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    DEPENDS
+      ecflow_server # the server is launched to support tests
+    TEST_DEPENDS
+      u_base
+  )
+  target_clangformat(m_migration
+    CONDITION ENABLE_TESTS
+  )
+
+endif()
+
+# ===================================================================
+# install
+# ===================================================================
+install (TARGETS ecflow_client DESTINATION bin)
diff -pruN 5.12.4-1/libs/client/ecf_hostsfile 5.13.0-1/libs/client/ecf_hostsfile
--- 5.12.4-1/libs/client/ecf_hostsfile	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/ecf_hostsfile	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+
+host1:3142
+host2:3143
+
+host3
+
+host4:3147
+
+host5
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientCmdCache.cpp 5.13.0-1/libs/client/src/ecflow/client/ClientCmdCache.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientCmdCache.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientCmdCache.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/client/ClientCmdCache.hpp"
+
+std::shared_ptr<CSyncCmd> ClientCmdCache::csync_cmd(CSyncCmd::Api api,
+                                                    unsigned int client_handle,
+                                                    unsigned int client_state_change_no,
+                                                    unsigned int client_modify_change_no) const {
+    if (!csync_cmd_)
+        csync_cmd_ = std::make_shared<CSyncCmd>();
+    // csync_cmd_->init(api,client_handle,client_state_change_no,client_modify_change_no);
+    return csync_cmd_;
+}
+
+std::shared_ptr<CSyncCmd> ClientCmdCache::csync_cmd(unsigned int client_handle) const {
+    if (!csync_cmd_)
+        csync_cmd_ = std::make_shared<CSyncCmd>();
+    // csync_cmd_->init(client_handle);
+    return csync_cmd_;
+}
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientCmdCache.hpp 5.13.0-1/libs/client/src/ecflow/client/ClientCmdCache.hpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientCmdCache.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientCmdCache.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,35 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_ClientCmdCache_HPP
+#define ecflow_client_ClientCmdCache_HPP
+
+#include "ecflow/base/cts/user/CSyncCmd.hpp"
+
+class ClientCmdCache {
+public:
+    ClientCmdCache() = default;
+    // Disable copy (and move) semantics
+    ClientCmdCache(const ClientCmdCache&)                  = delete;
+    const ClientCmdCache& operator=(const ClientCmdCache&) = delete;
+
+    ~ClientCmdCache() = default;
+
+    std::shared_ptr<CSyncCmd> csync_cmd(CSyncCmd::Api,
+                                        unsigned int client_handle,
+                                        unsigned int client_state_change_no,
+                                        unsigned int client_modify_change_no) const;
+    std::shared_ptr<CSyncCmd> csync_cmd(unsigned int client_handle) const;
+
+private:
+    mutable std::shared_ptr<CSyncCmd> csync_cmd_;
+};
+
+#endif /* ecflow_client_ClientCmdCache_HPP */
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientEnvironment.cpp 5.13.0-1/libs/client/src/ecflow/client/ClientEnvironment.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientEnvironment.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,426 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/client/ClientEnvironment.hpp"
+
+#include <cstdlib> // for getenv()
+#include <iostream>
+#include <iterator>
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/PasswdFile.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeStamp.hpp"
+#include "ecflow/core/Version.hpp"
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/Openssl.hpp"
+#endif
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+// Provide upper and lower bounds for timeouts
+/// The timeout is used control for how long we continue to iterate over the hosts
+/// attempting to connect to the servers.
+#ifdef DEBUG
+    #define MAX_TIMEOUT 120            // Max time in seconds for client to deliver message
+    #define DEFAULT_ZOMBIE_TIMEOUT 120 // Max time in seconds for client to deliver message
+    #define MIN_TIMEOUT 5              // Some reasonable value
+#else
+    #define MAX_TIMEOUT 24 * 3600            // We don't try forever, only 24 hours
+    #define DEFAULT_ZOMBIE_TIMEOUT 12 * 3600 // We don't try forever, only 12 hours
+    #define MIN_TIMEOUT 10 * 60              // Some reasonable value
+#endif
+
+// #define DEBUG_ENVIRONMENT 1
+
+template <class T>
+ostream& operator<<(ostream& os, const vector<T>& v) {
+    copy(v.begin(), v.end(), ostream_iterator<T>(cout, "\n"));
+    return os;
+}
+
+ClientEnvironment::ClientEnvironment(bool gui)
+    : AbstractClientEnv(),
+      timeout_(MAX_TIMEOUT),
+      zombie_timeout_(DEFAULT_ZOMBIE_TIMEOUT),
+      gui_(gui) {
+    init();
+}
+
+ClientEnvironment::ClientEnvironment(bool gui, const std::string& host, const std::string& port)
+    : AbstractClientEnv(),
+      timeout_(MAX_TIMEOUT),
+      zombie_timeout_(DEFAULT_ZOMBIE_TIMEOUT),
+      gui_(gui) {
+    init();
+    set_host_port(host, port); // assumes we NOT going to read host file
+}
+
+// test constructor
+ClientEnvironment::ClientEnvironment(const std::string& hostFile, const std::string& host, const std::string& port)
+    : AbstractClientEnv(),
+      timeout_(MAX_TIMEOUT),
+      zombie_timeout_(DEFAULT_ZOMBIE_TIMEOUT) {
+    init();
+
+    /// The host file passed in takes *precedence* over ECF_HOSTFILE environment variable read in init()
+    host_file_ = hostFile;
+
+    /// Override config, and environment.
+    if (!host.empty()) {
+        host_vec_.clear();
+        host_vec_.emplace_back(host, port);
+    }
+}
+
+void ClientEnvironment::init() {
+    read_environment_variables();
+#ifdef DEBUG_ENVIRONMENT
+    std::cout << toString() << std::endl;
+#endif
+
+    // If no host specified default to local host and default port number
+    if (host_vec_.empty())
+        host_vec_.emplace_back(Str::LOCALHOST(), Str::DEFAULT_PORT_NUMBER());
+
+    // Program option are read in last, and will override any previous setting
+    // However program option are delayed until later. See notes in header
+    if (debug_)
+        std::cout << toString() << "\n";
+}
+
+void ClientEnvironment::set_debug(bool flag) {
+    // show client environment when debug is enabled
+    debug_ = flag;
+    if (debug_)
+        std::cout << toString() << "\n";
+}
+
+bool ClientEnvironment::get_next_host(std::string& errorMsg) {
+    if (debug_)
+        cout << "ClientEnvironment::get_next_host() host_file_read_ = " << host_file_read_
+             << " host_file_ = " << host_file_ << "\n";
+    if (!host_file_read_ && !host_file_.empty()) {
+
+        if (!parseHostsFile(errorMsg)) {
+            return false;
+        }
+        host_file_read_ = true;
+        // SKIP OVER THE FIRST HOST, hence both paths need to increment host_vec_index_
+    }
+
+    host_vec_index_++;
+    if (host_vec_index_ >= static_cast<int>(host_vec_.size())) {
+        host_vec_index_ = 0;
+    }
+
+    return true;
+}
+
+// AbstractClientEnv functions: ============================================================================
+const std::string& ClientEnvironment::host() const {
+#ifdef DEBUG_ENVIRONMENT
+// cout << "ClientEnvironment::host()  host_vec_index_ = " << host_vec_index_
+//      << " host_vec_[host_vec_index_] = " << host_vec_[host_vec_index_] << "\n";
+#endif
+    assert(!host_vec_.empty());
+    assert(host_vec_index_ >= 0 && host_vec_index_ < static_cast<int>(host_vec_.size()));
+    return host_vec_[host_vec_index_].first;
+}
+
+const std::string& ClientEnvironment::port() const {
+    assert(!host_vec_.empty());
+    assert(host_vec_index_ >= 0 && host_vec_index_ < static_cast<int>(host_vec_.size()));
+    return host_vec_[host_vec_index_].second;
+}
+
+void ClientEnvironment::set_host_port(const std::string& the_host, const std::string& the_port) {
+    if (the_host.empty())
+        throw std::runtime_error("ClientEnvironment::set_host_port: Empty host specified ?");
+    if (the_port.empty())
+        throw std::runtime_error("ClientEnvironment::set_host_port: Empty port specified ?");
+    try {
+        ecf::convert_to<int>(the_port);
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error("ClientEnvironment::set_host_port: Invalid port number " + the_port);
+    }
+
+    // Override default
+    host_vec_.clear();
+
+    // make sure there only one host:port in host_vec_
+    host_vec_.emplace_back(the_host, the_port);
+
+    // Make sure we don't look in hosts file.
+    // When there is only one host:port in host_vec_, calling get_next_host() will always return host_vec_[0]
+    host_file_read_ = true;
+
+#ifdef ECF_OPENSSL
+    // Must be done *AFTER* host and port set
+    // Avoid enabling SSL for the GUI, via environment, this must be done explicitly by the GUI
+    if (!gui_)
+        enable_ssl_if_defined();
+#endif
+}
+
+bool ClientEnvironment::checkTaskPathAndPassword(std::string& errorMsg) const {
+    if (task_path_.empty()) {
+        errorMsg = "No task path specified for ECF_NAME \n";
+        return false;
+    }
+    if (jobs_password_.empty()) {
+        errorMsg = "No jobs password specified for ECF_PASS \n";
+        return false;
+    }
+    return true;
+}
+
+std::string ClientEnvironment::toString() const {
+    std::stringstream ss;
+    ss << "ClientEnvironment:\n";
+    ss << TimeStamp::now() << Version::description() << "\n";
+    ss << "   ECF_HOST/ECF_PORT : host_vec_index_ = " << host_vec_index_ << " host_vec_.size() = " << host_vec_.size()
+       << "\n";
+    if (!host_vec_.empty()) {
+        for (std::pair<std::string, std::string> i : host_vec_) {
+            ss << "   " << i.first << Str::COLON() << i.second << "\n";
+        }
+    }
+    ss << "   ECF_NAME = " << task_path_ << "\n";
+    ss << "   ECF_PASS = " << jobs_password_ << "\n";
+    ss << "   ECF_RID = " << remote_id_ << "\n";
+    ss << "   ECF_TRYNO = " << task_try_num_ << "\n";
+    ss << "   ECF_HOSTFILE = " << host_file_ << "\n";
+    ss << "   ECF_TIMEOUT = " << timeout_ << "\n";
+    ss << "   ECF_ZOMBIE_TIMEOUT = " << zombie_timeout_ << "\n";
+    ss << "   ECF_CONNECT_TIMEOUT = " << connect_timeout_ << "\n";
+    ss << "   ECF_DENIED = " << denied_ << "\n";
+    ss << "   NO_ECF = " << no_ecf_ << "\n";
+    for (const auto& i : env_) {
+        ss << "   " << i.first << " = " << i.second << "\n";
+    }
+
+    ss << "   ECF_DEBUG_CLIENT = " << debug_ << "\n";
+#ifdef ECF_OPENSSL
+    if (ssl())
+        ss << "   ECF_SSL = " << ssl_ << "\n";
+#endif
+    return ss.str();
+}
+
+std::string ClientEnvironment::hostSpecified() {
+    char* the_host = getenv(Str::ECF_HOST().c_str());
+    if (the_host)
+        return std::string(the_host);
+    return std::string();
+}
+
+std::string ClientEnvironment::portSpecified() {
+    char* theEnv = getenv(Str::ECF_PORT().c_str());
+    if (theEnv) {
+        return std::string(theEnv);
+    }
+    return Str::DEFAULT_PORT_NUMBER();
+}
+
+void ClientEnvironment::read_environment_variables() {
+#ifdef DEBUG_ENVIRONMENT
+    std::cout << "ClientEnvironment::read_environment_variables()\n";
+#endif
+
+    if (getenv(Str::ECF_NAME().c_str()))
+        task_path_ = getenv(Str::ECF_NAME().c_str());
+    if (getenv(Str::ECF_PASS().c_str()))
+        jobs_password_ = getenv(Str::ECF_PASS().c_str());
+    if (getenv(Str::ECF_TRYNO().c_str()))
+        task_try_num_ = atoi(getenv(Str::ECF_TRYNO().c_str()));
+    if (getenv("ECF_HOSTFILE"))
+        host_file_ = getenv("ECF_HOSTFILE");
+    if (getenv(Str::ECF_RID().c_str()))
+        remote_id_ = getenv(Str::ECF_RID().c_str());
+    if (getenv("ECF_USER"))
+        user_name_ = getenv("ECF_USER");
+
+    if (getenv("ECF_TIMEOUT"))
+        timeout_ = atoi(getenv("ECF_TIMEOUT")); // host file timeout
+    if (timeout_ > MAX_TIMEOUT)
+        timeout_ = MAX_TIMEOUT;
+    if (timeout_ < MIN_TIMEOUT)
+        timeout_ = MIN_TIMEOUT;
+
+    if (getenv("ECF_ZOMBIE_TIMEOUT"))
+        zombie_timeout_ = atoi(getenv("ECF_ZOMBIE_TIMEOUT")); // time out for zombies
+    if (zombie_timeout_ > MAX_TIMEOUT)
+        zombie_timeout_ = MAX_TIMEOUT;
+    if (zombie_timeout_ < MIN_TIMEOUT)
+        zombie_timeout_ = MIN_TIMEOUT;
+
+    if (getenv("ECF_CONNECT_TIMEOUT"))
+        connect_timeout_ = atoi(getenv("ECF_CONNECT_TIMEOUT")); // for test only
+
+    if (getenv("ECF_DENIED"))
+        denied_ = true;
+    if (getenv("NO_ECF"))
+        no_ecf_ = true;
+    if (getenv("ECF_DEBUG_CLIENT"))
+        debug_ = true;
+
+    char* debug_level = getenv("ECF_DEBUG_LEVEL");
+    if (debug_level) {
+        try {
+            Ecf::set_debug_level(ecf::convert_to<unsigned int>(debug_level));
+        }
+        catch (...) {
+            throw std::runtime_error("The environment variable ECF_DEBUG_LEVEL must be an unsigned integer.");
+        }
+    }
+
+    /// Override the config settings *IF* any
+    std::string port = Str::DEFAULT_PORT_NUMBER();
+    std::string host = Str::LOCALHOST();
+    if (!host_vec_.empty()) {
+        host = host_vec_[0].first;  //  first entry is the config host
+        port = host_vec_[0].second; //  first entry is the config port
+    }
+
+    if (getenv(Str::ECF_PORT().c_str())) {
+        port = getenv(Str::ECF_PORT().c_str());
+        host_vec_.clear(); // remove config settings, net effect is overriding
+        host_vec_.emplace_back(host, port);
+    }
+
+    // Add the ECF_HOST host into list of hosts. Make sure its first in host_vec_
+    // as we want environment setting to take priority.
+    string env_host = hostSpecified();
+    if (!env_host.empty()) {
+        host = env_host;
+        host_vec_.clear(); // remove previous setting if any
+        host_vec_.emplace_back(host, port);
+    }
+
+#ifdef ECF_OPENSSL
+    // Note: This must be placed here for child commands, where we we typically only use environment variables
+    // Must be done last *AFTER* host and port set
+    // Can't use enable_sll(), since that calls host()/port() which use host_vec_, which may be empty
+    // Avoid enabling SSL for the GUI, via environment, this must be done explicitly by the GUI
+    if (!gui_)
+        ssl_.enable_if_defined(host, port);
+#endif
+}
+
+bool ClientEnvironment::parseHostsFile(std::string& errorMsg) {
+    std::vector<std::string> lines;
+    if (!File::splitFileIntoLines(host_file_, lines, true /*IGNORE EMPTY LINES*/)) {
+        std::stringstream ss;
+        ss << "ClientEnvironment:: Could not open the hosts file " << host_file_;
+        errorMsg += ss.str();
+        return false;
+    }
+
+    // The Home server and port should be at index 0.
+    std::string job_supplied_port = Str::DEFAULT_PORT_NUMBER();
+    if (!host_vec_.empty())
+        job_supplied_port = host_vec_[0].second;
+
+    // Each line should have the format: We only read in the first token.
+    //       host        # comment
+    //       host:port   # another comment
+    // If no port is specified we default to port read in from the environment
+    // if that was not specified we default to Str::DEFAULT_PORT_NUMBER()
+    auto theEnd = lines.end();
+    for (auto i = lines.begin(); i != theEnd; ++i) {
+
+        std::vector<std::string> tokens;
+        Str::split((*i), tokens);
+        if (tokens.empty())
+            continue;
+        if (tokens[0][0] == '#') {
+            //			std::cout << "Ignoring line:'" << *i << "'\n";
+            continue;
+        }
+
+        std::string theBackupHost;
+        std::string thePort;
+
+        size_t colonPos = tokens[0].find_first_of(':');
+        if (colonPos == string::npos) {
+            // When the port is *NOT* specified, we must use the job supplied port.
+            // i.e. the one read in from the environment
+            theBackupHost = tokens[0];
+            thePort       = job_supplied_port;
+            //			std::cout << "Host = " << theBackupHost << " Port is  " << thePort << "\n";
+        }
+        else {
+            theBackupHost = tokens[0].substr(0, colonPos);
+            thePort       = tokens[0].substr(colonPos + 1);
+            //			std::cout << "Host = " << theBackupHost << " Port is specified " << thePort << "\n";
+        }
+
+        // std::cout << "Host = " << theBackupHost << "  " << thePort << "\n";
+        host_vec_.emplace_back(theBackupHost, thePort);
+    }
+
+    return true;
+}
+
+const std::string& ClientEnvironment::get_user_password(const std::string& user) const {
+    return get_password("ECF_PASSWD", user);
+}
+
+const std::string& ClientEnvironment::get_custom_user_password(const std::string& user) const {
+    return get_password("ECF_CUSTOM_PASSWD", user);
+}
+
+const std::string& ClientEnvironment::get_password(const char* env, const std::string& user) const {
+    // cout << "ClientEnvironment::get_password() env:" << env << " user:" << user << " passwd_(" << passwd_ << ")\n";
+    if (user.empty())
+        throw std::runtime_error("ClientEnvironment::get_user_password: No user specified");
+    if (!passwd_.empty()) {
+        // cout << "  ClientEnvironment::get_password() CACHED returning " << passwd_ << "\n";
+        return passwd_;
+    }
+
+    char* file = getenv(env);
+    if (file) {
+        std::string user_passwd_file = file;
+        // cout << "  ClientEnvironment::get_password() ECF_CUSTOM_PASSWD " << user_passwd_file  << "\n";
+        if (!user_passwd_file.empty() && fs::exists(user_passwd_file)) {
+            // cout << "  ClientEnvironment::get_password() LOADING password file\n";
+            PasswdFile passwd_file;
+            std::string errorMsg;
+            if (!passwd_file.load(user_passwd_file, debug(), errorMsg)) {
+                std::stringstream ss;
+                ss << "Could not parse ECF_CUSTOM_PASSWD file. " << errorMsg;
+                throw std::runtime_error(ss.str());
+            }
+            // std::cout << "ClientEnvironment::get_password() PasswdFile.dump()\n" << passwd_file.dump() << "\n";
+            // std::cout << "ClientEnvironment::get_password() user(" << user << ")" << " host(" << host() << ") port("
+            // << port() << ")\n";
+
+            passwd_ = passwd_file.get_passwd(user, host(), port()); // host() may return localhost.
+            if (passwd_.empty()) {
+                Host host;
+                passwd_ = passwd_file.get_passwd(user, host.name(), port());
+            }
+            // cout << "  ClientEnvironment::get_password() returning(" << passwd_ << ")\n";
+            return passwd_;
+        }
+    }
+
+    // cout << "  ClientEnvironment::get_user_password() returning EMPTY \n";
+    return Str::EMPTY();
+}
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientEnvironment.hpp 5.13.0-1/libs/client/src/ecflow/client/ClientEnvironment.hpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientEnvironment.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientEnvironment.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,200 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_ClientEnvironment_HPP
+#define ecflow_client_ClientEnvironment_HPP
+
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/base/AbstractClientEnv.hpp"
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/Openssl.hpp"
+#endif
+
+class ClientEnvironment final : public AbstractClientEnv {
+public:
+    /// The constructor will load the environment
+    explicit ClientEnvironment(bool gui);
+    explicit ClientEnvironment(bool gui, const std::string& host, const std::string& port);
+
+    /// This constructor is only used in Test environment, as it allow the host file to be set
+    explicit ClientEnvironment(const std::string& hostFile, const std::string& host = "", const std::string& port = "");
+
+    /// This controls for how long child commands continue trying to connect to Server before failing.
+    /// Maximum time in seconds for client to deliver message to server/servers. This is
+    /// typically 24 hours in a real environment. It is this long to allow operators to
+    /// recover from any crashes.
+    /// for the CHILD/task commands *ONLY*
+    /// Can be overridden by  changing environment variable ECF_TIMEOUT
+    long max_child_cmd_timeout() const { return timeout_; }
+
+    /// This controls for how long child zombie commands continue trying to connect to Server before failing.
+    /// Maximum time in seconds for client to deliver message to server/servers. This is
+    /// typically 12 hours in a real environment.
+    /// for the CHILD/task commands *ONLY*
+    /// Can be overridden by  changing environment variable ECF_ZOMBIE_TIMEOUT
+    long max_zombie_child_cmd_timeout() const { return zombie_timeout_; }
+
+    /// Allow pure python jobs to override the ECF_TIMEOUT & ECF_ZOMBIE_TIMEOUT
+    void set_child_cmd_timeout(unsigned int t) { timeout_ = t; }
+    void set_zombie_child_cmd_timeout(unsigned int t) { zombie_timeout_ = t; }
+
+    /// The timeout feature allow the client to fail gracefully in the case
+    /// where the server has died/crashed. The timeout will ensure the socket is closed.
+    /// allowing the server to be restarted without getting the address is use error.
+    /// Set the timeout for each client->server communication:
+    //    connect        : timeout_ second
+    //    send request   : timeout_ second
+    //    receive reply  : timeout_ second
+    // default is 0 second, which means take the timeout from the command/request
+    // The default can be overridden with ECF_CONNECT_TIMEOUT.
+    // This is useful when running valgrind --tool=callgrind which leads to
+    // massive slow down and disconnection from the client, when the server is still
+    // running.
+    // used for **test only**
+    int connect_timeout() const { return connect_timeout_; }
+
+    /// When called will demand load the ecf host file, and read the hosts.
+    /// Will then iterate over the host, when the end is reached will start over
+    /// If host cannot be opened or errors occur returns false;
+    bool get_next_host(std::string& errorMsg);
+
+    /// If server denies client communication and this flag is set, exit with an error
+    /// Avoids 24hr hour connection attempt to server. Aids zombie control.
+    bool denied() const { return denied_; }
+
+    /// if NO_ECF is set then abort client immediately.  Client should return success
+    /// useful when we want to test jobs stand-alone
+    bool no_ecf() const { return no_ecf_; }
+
+    /// for debug
+    std::string toString() const;
+
+    /// Return contents of ECF_HOST environment variable, Otherwise an EMPTY string
+    static std::string hostSpecified();
+
+    /// Returns of ECF_PORT,environment variable, otherwise returns Str::DEFAULT_PORT_NUMBER
+    static std::string portSpecified();
+
+    // Set the rid. Only needed to override in regression test, to avoid interference
+    // Should use a better name, as this is really the Process identifier of the running job.
+    // Needs to be the same value as supplied to child command init
+    void set_remote_id(const std::string& rid) { remote_id_ = rid; }
+
+    // Used by python to enable debug of client api
+    void set_debug(bool flag);
+
+#ifdef ECF_OPENSSL
+    /// return true if this is a ssl enabled server
+    ecf::Openssl& openssl() { return ssl_; }
+    bool ssl() const { return ssl_.enabled(); }
+    void enable_ssl_if_defined() {
+        ssl_.enable_if_defined(host(), port());
+    }                                                  // IF ECF_SSL=1,search server.crt, ELSE search <host>.<port>.crt
+    void enable_ssl() { ssl_.enable(host(), port()); } // search server.crt first, then <host>.<port>.crt
+    bool enable_ssl_no_throw() {
+        return ssl_.enable_no_throw(host(), port());
+    }                                      // search server.crt first, then <host>.<port>.crt
+    void disable_ssl() { ssl_.disable(); } // override environment setting for ECF_SSL
+#endif
+
+    // AbstractClientEnv functions:
+    void set_cli(bool f) override { cli_ = f; }
+    bool get_cli() const override { return cli_; }
+    bool checkTaskPathAndPassword(std::string& errorMsg) const override;
+    const std::string& task_path() const override { return task_path_; }
+    int task_try_no() const override { return task_try_num_; }
+    const std::string& jobs_password() const override { return jobs_password_; }
+    const std::string& process_or_remote_id() const override { return remote_id_; }
+    void set_host_port(const std::string& host, const std::string& port) override;
+    const std::string& host() const override;
+    const std::string& port() const override;
+    const std::vector<std::pair<std::string, std::string>>& env() const override { return env_; }
+    const std::string& get_user_password(const std::string& user) const override;
+    const std::string& get_custom_user_password(const std::string& user) const override;
+    void clear_user_password() override { passwd_.clear(); }
+    const std::string& get_user_name() const override { return user_name_; }
+    void set_user_name(const std::string& name) override { user_name_ = name; }
+    void set_password(const std::string& password) override { passwd_ = password; }
+    bool debug() const override { return debug_; } // enabled if ECF_DEBUG_CLIENT set
+    void set_test() override { under_test_ = true; }
+    bool under_test() const override { return under_test_; }
+
+    // Support for python child commands, and python jobs
+    void set_child_path(const std::string& path) { task_path_ = path; }
+    void set_child_password(const std::string& pass) { jobs_password_ = pass; }
+    void set_child_pid(const std::string& pid) { remote_id_ = pid; }
+    void set_child_try_no(unsigned int try_no) { task_try_num_ = try_no; }
+    void set_child_init_add_vars(const std::vector<Variable>& vars) { init_add_vars_ = vars; }
+    void set_child_complete_del_vars(std::vector<std::string>& vars) { complete_del_vars_ = vars; }
+    void set_child_host_file(const std::string& host_file) { host_file_ = host_file; }
+    void set_child_denied(bool denied) { denied_ = denied; }
+    void set_child_no_ecf(bool no_ecf) { no_ecf_ = no_ecf; }
+
+    const std::vector<Variable>& init_add_vars() const { return init_add_vars_; }
+    const std::vector<std::string>& complete_del_vars() const { return complete_del_vars_; }
+
+private:
+    std::string task_path_;     // ECF_NAME = /aSuit/aFam/aTask
+    std::string jobs_password_; // ECF_PASS jobs password
+    std::string remote_id_;     // ECF_RID process id of running job
+    std::string host_file_;     // ECF_HOSTFILE. File that lists the backup hosts, port numbers must match
+    std::string user_name_;
+    mutable std::string passwd_;
+
+    long timeout_;        // ECF_TIMEOUT. Host file iteration time out
+    long zombie_timeout_; // ECF_ZOMBIE_TIMEOUT. Host file iteration time out for zombies, default same as ECF_TIMEOUT
+    std::vector<Variable> init_add_vars_;
+    std::vector<std::string> complete_del_vars_;
+
+    std::vector<std::pair<std::string, std::string>> env_;      // For test allow env variable to be set on defs
+    std::vector<std::pair<std::string, std::string>> host_vec_; // The list of host:port pairs
+
+#ifdef ECF_OPENSSL
+    ecf::Openssl ssl_;
+#endif
+
+    unsigned int task_try_num_{1}; // ECF_TRYNO. The task try number. The number of times the job has been run
+    int connect_timeout_{0};       // default 0, ECF_CONNECT_TIMEOUT, connection timeout
+    int host_vec_index_{0};        // index into host_vec;
+
+    bool cli_{false};    // Command Line Interface
+    bool denied_{false}; // ECF_DENIED.If the server denies the communication, then the child command can be set to fail
+                         // immediately
+    bool no_ecf_{false}; // NO_ECF. if defined then abort cmd immediately. useful when test jobs stand-alone
+    bool debug_{false};  // For live debug, enabled by env variable ECF_CLIENT_DEBUG or set by option -d|--debug
+    bool under_test_{false};     // Used in testing client interface
+    bool host_file_read_{false}; // to ensure we read host file only once
+    bool gui_{false};
+
+    /// The option read from the command line.
+    friend class ClientOptions;
+
+    // Allow testing to override the task path set in the environment. In this constructor
+    friend class ClientInvoker;
+
+private:
+    void init();
+
+    void read_environment_variables(); /// Get the standard environment variables
+
+    void taskPath(const std::string& s) { task_path_ = s; }
+    void set_jobs_password(const std::string& s) { jobs_password_ = s; }
+    void set_connect_timeout(int t) { connect_timeout_ = t; }
+
+    // Allow testing to add or update the environment in the Defs file
+    // Each pair is ( variable name, variable value )
+    void setEnv(const std::vector<std::pair<std::string, std::string>>& e) { env_ = e; }
+
+    bool parseHostsFile(std::string& errorMsg);
+
+    const std::string& get_password(const char*, const std::string& user) const;
+};
+
+#endif /* ecflow_client_ClientEnvironment_HPP */
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientInvoker.cpp 5.13.0-1/libs/client/src/ecflow/client/ClientInvoker.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientInvoker.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientInvoker.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1768 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/client/ClientInvoker.hpp"
+
+#include <iostream>
+#include <iterator>
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
+
+#include "ecflow/base/Client.hpp"
+#include "ecflow/base/cts/task/AbortCmd.hpp"
+#include "ecflow/base/cts/task/CompleteCmd.hpp"
+#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
+#include "ecflow/base/cts/task/EventCmd.hpp"
+#include "ecflow/base/cts/task/InitCmd.hpp"
+#include "ecflow/base/cts/task/LabelCmd.hpp"
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+#include "ecflow/base/cts/task/QueueCmd.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/CFileCmd.hpp"
+#include "ecflow/base/cts/user/CSyncCmd.hpp"
+#include "ecflow/base/cts/user/CheckPtCmd.hpp"
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/base/cts/user/CtsNodeCmd.hpp"
+#include "ecflow/base/cts/user/DeleteCmd.hpp"
+#include "ecflow/base/cts/user/EditScriptCmd.hpp"
+#include "ecflow/base/cts/user/ForceCmd.hpp"
+#include "ecflow/base/cts/user/FreeDepCmd.hpp"
+#include "ecflow/base/cts/user/GroupCTSCmd.hpp"
+#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
+#include "ecflow/base/cts/user/LogCmd.hpp"
+#include "ecflow/base/cts/user/LogMessageCmd.hpp"
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/base/cts/user/PlugCmd.hpp"
+#include "ecflow/base/cts/user/QueryCmd.hpp"
+#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"
+#include "ecflow/base/cts/user/RunNodeCmd.hpp"
+#include "ecflow/base/cts/user/ServerVersionCmd.hpp"
+#include "ecflow/base/cts/user/ZombieCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/SslClient.hpp"
+#endif
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/Rtt.hpp"
+#include "ecflow/core/CommandLine.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeStamp.hpp"
+#include "ecflow/node/Defs.hpp"
+#ifdef DEBUG_PERF
+    #include "ecflow/core/DebugPerf.hpp"
+#endif
+
+#ifdef DEBUG
+
+    #if defined(HPUX) || defined(_AIX)
+        #define RETRY_CONNECTION_PERIOD 2
+        #define NEXT_HOST_POLL_PERIOD 2
+    #else
+        #define RETRY_CONNECTION_PERIOD 1
+        #define NEXT_HOST_POLL_PERIOD 1
+    #endif
+
+#else
+    #define RETRY_CONNECTION_PERIOD 10
+    #define NEXT_HOST_POLL_PERIOD 30
+#endif
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+
+// ==================================================================================
+// class ClientInvoker
+ClientInvoker::ClientInvoker() : clientEnv_(false), retry_connection_period_(RETRY_CONNECTION_PERIOD) {
+    if (clientEnv_.debug())
+        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 1=================start=================\n";
+}
+
+ClientInvoker::ClientInvoker(const std::string& host_port)
+    : clientEnv_(false),
+      retry_connection_period_(RETRY_CONNECTION_PERIOD) {
+    if (clientEnv_.debug())
+        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 2=================start=================\n";
+    set_hostport(host_port);
+}
+
+ClientInvoker::ClientInvoker(bool gui, const std::string& host, const std::string& port)
+    : clientEnv_(gui, host, port),
+      retry_connection_period_(RETRY_CONNECTION_PERIOD),
+      gui_(gui) {
+    if (clientEnv_.debug())
+        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 3=================start=================\n";
+}
+
+ClientInvoker::ClientInvoker(const std::string& host, const std::string& port)
+    : clientEnv_(false, host, port),
+      retry_connection_period_(RETRY_CONNECTION_PERIOD) {
+    if (clientEnv_.debug())
+        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 3=================start=================\n";
+}
+
+ClientInvoker::ClientInvoker(const std::string& host, int port)
+    : clientEnv_(false, host, ecf::convert_to<std::string>(port)),
+      retry_connection_period_(RETRY_CONNECTION_PERIOD) {
+    if (clientEnv_.debug())
+        cout << TimeStamp::now() << "ClientInvoker::ClientInvoker(): 4=================start=================\n";
+}
+
+void ClientInvoker::set_host_port(const std::string& host, const std::string& port) {
+    // Allow host and port to be overridden.
+    // o Override environment setting
+    // o For child commands will override opening of ecf_hosts file
+    clientEnv_.set_host_port(host, port);
+}
+
+void ClientInvoker::set_hostport(const std::string& host_port) {
+    // assume format <host>:<port> || <host>@<port>
+    size_t colonPos = host_port.find_first_of(':');
+    if (colonPos == string::npos) {
+        colonPos = host_port.find_first_of('@');
+        if (colonPos == string::npos)
+            throw std::runtime_error("ClientInvoker::set_host_port: expected <host>:<port> || <host>@<port> in " +
+                                     host_port);
+    }
+    std::string host = host_port.substr(0, colonPos);
+    std::string port = host_port.substr(colonPos + 1);
+    set_host_port(host, port);
+}
+
+const std::string& ClientInvoker::host() const {
+    return clientEnv_.host();
+}
+const std::string& ClientInvoker::port() const {
+    return clientEnv_.port();
+}
+
+void ClientInvoker::set_user_name(const std::string& user) {
+    clientEnv_.set_user_name(user);
+    clientEnv_.clear_user_password(); // force re-check of password
+}
+
+void ClientInvoker::set_password(const std::string& password) {
+    clientEnv_.set_password(password);
+}
+
+void ClientInvoker::taskPath(const std::string& s) {
+    test_ = true;
+    clientEnv_.taskPath(s);
+}
+void ClientInvoker::set_jobs_password(const std::string& djp) {
+    test_ = true;
+    clientEnv_.set_jobs_password(djp);
+}
+
+void ClientInvoker::setEnv(const std::vector<std::pair<std::string, std::string>>& e) {
+    assert(!e.empty());
+    test_ = true;
+    clientEnv_.setEnv(e); // For test allow env variable to be set on defs
+}
+
+void ClientInvoker::testInterface() {
+    testInterface_ = true;
+    clientEnv_.set_test();
+}
+
+const std::string& ClientInvoker::process_or_remote_id() const {
+    return clientEnv_.process_or_remote_id();
+}
+
+void ClientInvoker::enable_logging(const std::string& log_file_name) {
+    Rtt::create(log_file_name);
+}
+
+void ClientInvoker::disable_logging() {
+    Rtt::destroy();
+}
+
+void ClientInvoker::set_connect_timeout(int t) {
+    clientEnv_.set_connect_timeout(t);
+}
+
+void ClientInvoker::set_connection_attempts(unsigned int attempts) {
+    connection_attempts_ = attempts;
+    if (connection_attempts_ < 1)
+        connection_attempts_ = 1;
+}
+
+int ClientInvoker::get_cmd_from_args(const CommandLine& cl, Cmd_ptr& cts_cmd) const {
+    try {
+        // read in program option, and construct the client to server commands from them.
+        // This will extract host/port from the environment/ args
+        // This will throw std::runtime_error for invalid arguments or options
+        cts_cmd = args_.parse(cl, &clientEnv_);
+
+        // For --help and --debug, --load defs check_only no command is created
+        // When testInterface avoid writing to standard out.
+        if (!cts_cmd.get()) {
+            if (!testInterface_ && clientEnv_.debug()) {
+                cout << "args: ";
+                for (const auto& token : cl.tokens()) {
+                    cout << token << " ";
+                }
+                cout << "\n";
+            }
+        }
+        return 0;
+    }
+    catch (std::exception& e) {
+        stringstream ss;
+        if (cl.size() == 1) {
+            ss << Ecf::CLIENT_NAME() << ": No options specified\n";
+            ss << "Usage: " << Ecf::CLIENT_NAME() << " [OPTION]...\n";
+            ss << "Try '" << Ecf::CLIENT_NAME() << " --help' for list of options\n";
+        }
+        else {
+            ss << Ecf::CLIENT_NAME() << ": Caught exception whilst parsing arguments:\n" << e.what() << "\n";
+            ss << cl << "\n";
+        }
+        server_reply_.set_error_msg(ss.str());
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+    }
+    catch (...) {
+        server_reply_.set_error_msg("ClientInvoker: caught exception: Parsing arguments: unknown type!\n");
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+    }
+    return 1;
+}
+
+int ClientInvoker::invoke(int argc, char* argv[]) const {
+    return invoke(CommandLine(argc, argv));
+}
+
+int ClientInvoker::invoke(const CommandLine& cl) const {
+    // Allow request to logged & allow logging of round trip time, Hence must be placed *before* RoundTripRecorder
+    RequestLogger request_logger(this);
+
+    // initialise start_time_ and rtt_,
+    RoundTripRecorder round_trip_recorder(this);
+
+    /// If NO_ECF set then abort immediately. returning success. Useful in testing  jobs stand-alone.
+    if (clientEnv_.no_ecf()) {
+        cout << "NO_ECF\n";
+        return 0;
+    } // success
+
+    // Clear error message. For test. Don't keep previous error.
+    // i.e If next test passes when it shouldn't the wrong message is output
+    server_reply_.get_error_msg().clear();
+
+    Cmd_ptr cts_cmd;
+    if (get_cmd_from_args(cl, cts_cmd) == 1)
+        return 1;
+    if (!cts_cmd)
+        return 0; // For --help and --debug, --load defs check_only,  no command is created
+
+    // Under debug we display round trip time for each request
+    request_logger.set_cts_cmd(cts_cmd);
+
+    int res = do_invoke_cmd(cts_cmd);
+    if (res == 1 && on_error_throw_exception_)
+        throw std::runtime_error(server_reply_.error_msg());
+    return res;
+}
+
+int ClientInvoker::invoke(const std::string& arg) const {
+    int argc     = 2;
+    char* argv[] = {const_cast<char*>("ClientInvoker"), const_cast<char*>(arg.c_str())};
+    return invoke(argc, argv);
+}
+
+int ClientInvoker::invoke(const std::vector<std::string>& args) const {
+    return invoke(CommandLine(args));
+}
+
+int ClientInvoker::invoke(Cmd_ptr cts_cmd) const {
+    // assumes clients of Cmd_ptr constructor has caught exceptions
+
+    // Allow request to be logged & allow logging of round trip time, Hence must be placed *before* RoundTripRecorder
+    RequestLogger request_logger(this);
+
+    // initialise start_time_ and rtt_,
+    RoundTripRecorder round_trip_recorder(this);
+
+    // allow display of round trip time for each request
+    request_logger.set_cts_cmd(cts_cmd);
+
+    int res = do_invoke_cmd(cts_cmd);
+    if (res == 1 && on_error_throw_exception_)
+        throw std::runtime_error(server_reply_.error_msg());
+    return res;
+}
+
+int ClientInvoker::do_invoke_cmd(Cmd_ptr cts_cmd) const {
+#ifdef DEBUG_PERF
+    ecf::ScopedDurationTimer timer("  ClientInvoker::do_invoke_cmd");
+#endif
+
+    if (clientEnv_.debug())
+        cout << "\n"
+             << TimeStamp::now() << "ClientInvoker::do_invoke_cmd : on_error_throw_exception_("
+             << on_error_throw_exception_ << ")" << std::endl;
+    if (clientEnv_.no_ecf()) {
+        cout << "NO_ECF\n";
+        return 0;
+    } // success If NO_ECF set then abort immediately. returning success. Useful in testing  jobs stand-alone.
+    if (testInterface_)
+        return 0; // The testInterface_ flag allows testing of client interface, parsing of args, without needing to
+                  // contact server
+    assert(!clientEnv_.host().empty()); // make sure host is NOT empty.
+
+    // Add support for AUTO sync(using the group command), used by GUI and python *ONLY*
+    // only add to group those commands that actually update the defs
+    if (auto_sync_ && !cli() && cts_cmd->cmd_updates_defs() && !cts_cmd->group_cmd()) {
+
+        std::shared_ptr<GroupCTSCmd> grp_cmd = std::make_shared<GroupCTSCmd>(cts_cmd);
+        defs_ptr defs                        = server_reply_.client_defs();
+
+        if (defs.get())
+            grp_cmd->addChild(std::make_shared<CSyncCmd>(
+                CSyncCmd::SYNC, server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
+        else
+            grp_cmd->addChild(std::make_shared<CSyncCmd>(server_reply_.client_handle()));
+
+        cts_cmd = grp_cmd;
+    }
+
+    /// retry_connection_period_ specifies the time to wait, before retrying to connect to server.
+    /// Added to get round glitches in the network.
+    /// However for ping() always default to 1 second. This avoids 10 second wait in release mode.
+    /// We do this both for the CLI(command level interface) and python api
+    unsigned int retry_connection_period = retry_connection_period_;
+    if (cts_cmd->ping_cmd())
+        retry_connection_period = 1;
+
+    try {
+        /// report this message at least once. So client has a clue what's going on
+        bool report_block_client_on_home_server  = false;
+        bool report_block_client_server_halted   = false;
+        bool report_block_client_zombie_detected = false;
+        // We do not want to loop over the sms host list indefinitely hence we use a timer.
+        // The time out period is supplied via ClientEnvironment
+        bool never_polled = true; // don't wait for the first host only subsequent ones
+
+        while (true) {
+
+            // for each host try connecting several times. To compensate for network glitches.
+            int no_of_tries = connection_attempts_;
+            while (no_of_tries > 0) {
+                try {
+                    /// *** Each call to io_service.run(); is a *REQUEST* to the server ***
+                    /// *** Hence we *MUST* clear the server_reply before each call *******
+                    /// *** Found during zombie test. i.e when blocking, we were responding to previous, reply, since
+                    /// server_reply was not being reset *Note* server_reply_.client_handle_ is kept until the next call
+                    /// to register a new client_handle The client invoker can be used multiple times, hence keep value
+                    /// of defs, and client handle in server reply However this is only done, if we are not using the
+                    /// Command Level Interface(cli)
+                    server_reply_.clear_for_invoke(cli());
+
+                    if (!cts_cmd->setup_user_authentification(clientEnv_)) {
+                        server_reply_.set_error_msg("Invalid custom user(ECF_USER || --user <user>) or authentication "
+                                                    "failed for ECF_CUSTOM_PASSWD | ECF_PASSWD");
+                        return 1;
+                    }
+
+                    if (clientEnv_.debug()) {
+                        cout << TimeStamp::now() << "ClientInvoker: >>> " << cts_cmd->print_short();
+                        cout << " on " << client_env_host_port() << " : retry_connection_period("
+                             << retry_connection_period << ") no_of_tries(" << no_of_tries << ") cmd_connect_timeout("
+                             << cts_cmd->timeout() << ") ECF_CONNECT_TIMEOUT(" << clientEnv_.connect_timeout()
+#ifdef ECF_OPENSSL
+                             << ") SSL(" << clientEnv_.ssl()
+#endif
+                             << ")<<<" << endl;
+                    }
+
+                    boost::asio::io_service io_service;
+#ifdef ECF_OPENSSL
+                    if (clientEnv_.ssl()) {
+
+                        clientEnv_.openssl().init_for_client();
+
+                        SslClient theClient(io_service,
+                                            clientEnv_.openssl().context(),
+                                            cts_cmd,
+                                            clientEnv_.host(),
+                                            clientEnv_.port(),
+                                            clientEnv_.connect_timeout());
+                        {
+    #ifdef DEBUG_PERF
+                            ecf::ScopedDurationTimer my_timer("   io_service.run()");
+    #endif
+                            io_service.run();
+                        }
+                        if (clientEnv_.debug())
+                            cout << TimeStamp::now() << "ClientInvoker: >>> After: io_service.run() <<<" << endl;
+
+                        /// Let see how the server responded if at all.
+                        try {
+                            /// will return false if further action required
+                            if (theClient.handle_server_response(server_reply_, clientEnv_.debug())) {
+                                // The normal response.  RoundTriprecorder will record in rtt_
+                                return 0; // the normal exit path
+                            }
+                        }
+                        catch (std::exception& e) {
+                            server_reply_.set_error_msg(e.what());
+                            return 1;
+                        }
+                    }
+                    else {
+#endif
+                        Client theClient(
+                            io_service, cts_cmd, clientEnv_.host(), clientEnv_.port(), clientEnv_.connect_timeout());
+                        {
+#ifdef DEBUG_PERF
+                            ecf::ScopedDurationTimer my_timer("   io_service.run()");
+#endif
+                            io_service.run();
+                        }
+                        if (clientEnv_.debug())
+                            cout << TimeStamp::now() << "ClientInvoker: >>> After: io_service.run() <<<" << endl;
+
+                        /// Let see how the server responded if at all.
+                        try {
+                            /// will return false if further action required
+                            if (theClient.handle_server_response(server_reply_, clientEnv_.debug())) {
+                                // The normal response.  RoundTriprecorder will record in rtt_
+                                return 0; // the normal exit path
+                            }
+                        }
+                        catch (std::exception& e) {
+                            server_reply_.set_error_msg(e.what());
+                            return 1;
+                        }
+#ifdef ECF_OPENSSL
+                    }
+#endif
+
+                    if (server_reply_.block_client_on_home_server()) {
+                        // Valid reply from server. Typically waiting on a expression
+                        // Ok _Block_ on _current_ server, and continue waiting, until server reply is ok
+                        if (!report_block_client_on_home_server || clientEnv_.debug()) {
+                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " : "
+                                 << client_env_host_port() << " : WAITING on home server, continue waiting\n";
+                            report_block_client_on_home_server = true;
+                        }
+                        no_of_tries++;
+                    }
+                    else if (server_reply_.block_client_server_halted()) {
+                        // Valid reply from server.
+                        // fall through try again, then try other hosts
+                        if (!report_block_client_server_halted || clientEnv_.debug()) {
+                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " : "
+                                 << client_env_host_port() << " : blocking : server is HALTED, continue waiting\n";
+                            report_block_client_server_halted = true;
+                        }
+                    }
+                    else if (server_reply_.block_client_zombie_detected()) {
+                        // Valid reply from server.
+                        // fall through try again, then try other hosts
+                        if (!report_block_client_zombie_detected || clientEnv_.debug()) {
+                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " : "
+                                 << client_env_host_port() << " : blocking : zombie detected, continue waiting\n";
+                            report_block_client_zombie_detected = true;
+                        }
+                    }
+                    else if (server_reply_.invalid_argument()) {
+                        // Server could not decode client message and/or client could not decode server reply
+                        if (clientEnv_.debug()) {
+                            cout << TimeStamp::now() << "ClientInvoker:";
+                            cout << " failed : " << client_env_host_port() << " : " << server_reply_.error_msg()
+                                 << "\n";
+                        }
+                        return 1;
+                    }
+                    else if (server_reply_.eof()) {
+                        // Server did not reply or mixing ssl and non ssl
+                        if (clientEnv_.debug()) {
+                            cout << TimeStamp::now() << "ClientInvoker:";
+                            cout << " failed : " << client_env_host_port() << " : " << server_reply_.error_msg()
+                                 << "\n";
+                        }
+                        return 1;
+                    }
+                    else if (server_reply_.client_request_failed()) {
+                        // Valid reply from server
+                        // This error is ONLY valid if we got a real reply from the server
+                        // as opposed to some kind of connection errors. For connections errors
+                        // we fall through and try again.
+                        if (clientEnv_.debug()) {
+                            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short()
+                                 << " failed : " << client_env_host_port() << " : " << server_reply_.error_msg()
+                                 << "\n";
+                        }
+                        return 1;
+                    }
+                    else {
+                        std::cout << TimeStamp::now() << "ClientInvoker: missed response? for request "
+                                  << cts_cmd->print_short() << " oops" << endl;
+                    }
+                }
+                catch (std::exception& e) {
+                    // *Some kind of connection error*: fall through and try again. Avoid this message when pinging, i.e
+                    // to see if server is alive.
+                    if (clientEnv_.debug()) {
+                        cerr << TimeStamp::now() << "ClientInvoker: Connection error: (" << e.what() << ")" << endl;
+                    }
+                    if (!cts_cmd->ping_cmd()) {
+                        cerr << TimeStamp::now() << "ClientInvoker: Connection error: (" << e.what() << ")" << endl;
+                    }
+                }
+
+                // Wait a bit before trying to connect again, but only if no_of_tries > 0
+                no_of_tries--;
+                if (no_of_tries > 0)
+                    sleep(retry_connection_period);
+            }
+
+            // Don't bother with other hosts when:
+            //  1/ Testing
+            //  2/ ping-ing
+            //  3/ ECF_DENIED has been set
+            //  4/ Dealing with non tasks based request
+            if (!cts_cmd->connect_to_different_servers() || test_ || cts_cmd->ping_cmd() || clientEnv_.denied()) {
+                std::stringstream ss;
+                ss << TimeStamp::now() << "Request( " << cts_cmd->print_short() << " )";
+                if (clientEnv_.denied())
+                    ss << " ECF_DENIED ";
+                ss << ", Failed to connect to " << client_env_host_port() << ". After " << connection_attempts_
+                   << " attempts. Is the server running ?\n";
+                // Only print client environment if not pinging
+                if (!cts_cmd->ping_cmd())
+                    ss << clientEnv_.toString() << endl;
+                server_reply_.set_error_msg(ss.str());
+                return 1;
+            }
+
+            boost::posix_time::time_duration duration = microsec_clock::universal_time() - start_time_;
+            if (clientEnv_.debug()) {
+                cout << "ClientInvoker: Time duration = " << duration.total_seconds()
+                     << " clientEnv_.max_child_cmd_timeout() = " << clientEnv_.max_child_cmd_timeout() << endl;
+            }
+
+            if (duration.total_seconds() >= clientEnv_.max_child_cmd_timeout()) {
+                std::stringstream ss;
+                ss << TimeStamp::now() << "ClientInvoker: Timed out after ECF_TIMOUT("
+                   << clientEnv_.max_child_cmd_timeout() << ") seconds : for " << client_env_host_port() << "\n";
+                std::string msg = ss.str();
+                cout << msg;
+                server_reply_.set_error_msg(msg);
+                return 1;
+            }
+            if (server_reply_.block_client_zombie_detected() &&
+                duration.total_seconds() >= clientEnv_.max_zombie_child_cmd_timeout()) {
+                std::stringstream ss;
+                ss << TimeStamp::now() << "ClientInvoker: *ZOMBIE* Timed out after ECF_ZOMBIE_TIMEOUT("
+                   << clientEnv_.max_zombie_child_cmd_timeout() << ") seconds : for " << client_env_host_port() << "\n";
+                std::string msg = ss.str();
+                cout << msg;
+                server_reply_.set_error_msg(msg);
+                return 1;
+            }
+
+            // The host is not playing ball, try the next host, will *restart* with home server, if end reached
+            // *get_next_host* *only* returns false if host exists, and parsing it fails
+            std::string current_host_port = client_env_host_port();
+
+            std::string local_error_msg;
+            if (!clientEnv_.get_next_host(local_error_msg)) {
+                /// Instead of exiting, Just spit out a warning
+                cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short()
+                     << " get next host failed because: " << local_error_msg << endl;
+            }
+
+            cout << TimeStamp::now() << "ClientInvoker: " << cts_cmd->print_short() << " current host("
+                 << current_host_port << ") trying next host(" << client_env_host_port() << ")" << endl;
+
+            if (never_polled)
+                never_polled = false; // To avoid the first wait
+            else
+                sleep(NEXT_HOST_POLL_PERIOD);
+        }
+    }
+    catch (std::exception& e) {
+        stringstream ss;
+        ss << TimeStamp::now() << "ClientInvoker: caught exception: " << e.what() << "\n";
+        server_reply_.set_error_msg(ss.str());
+    }
+    catch (...) {
+        stringstream ss;
+        ss << TimeStamp::now() << "ClientInvoker: Caught Exception of unknown type!\n";
+        server_reply_.set_error_msg(ss.str());
+    }
+    return 1;
+}
+
+void ClientInvoker::reset() const {
+    server_reply_.set_client_defs(defs_ptr());
+    server_reply_.set_client_node(node_ptr());
+    server_reply_.set_client_handle(0);
+}
+
+//=====================================================================================
+// By using the command directly, it is a lot faster than using argc/argv
+// preserve old method to test api/command level interface.
+
+int ClientInvoker::sync(defs_ptr& client_defs) const {
+    if (client_defs.get()) {
+        server_reply_.set_client_defs(client_defs);
+        if (testInterface_)
+            return invoke(CtsApi::sync(
+                server_reply_.client_handle(), client_defs->state_change_no(), client_defs->modify_change_no()));
+        return invoke(std::make_shared<CSyncCmd>(CSyncCmd::SYNC,
+                                                 server_reply_.client_handle(),
+                                                 client_defs->state_change_no(),
+                                                 client_defs->modify_change_no()));
+    }
+
+    if (testInterface_)
+        return invoke(CtsApi::get());
+    int res = invoke(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET));
+    if (res == 0) {
+        client_defs = server_reply_.client_defs(); // update change number
+    }
+    return res;
+}
+
+int ClientInvoker::sync_local(bool sync_suite_clock) const {
+    defs_ptr defs = server_reply_.client_defs();
+    if (defs.get()) {
+
+        // Prevent infinite loops in change observers.
+        if (defs->in_notification()) {
+            std::cout << "ClientInvoker::sync_local() called in the middle of notification. Ignoring..... \n";
+            return 0;
+        }
+
+        if (testInterface_) {
+            if (sync_suite_clock)
+                return invoke(CtsApi::sync_clock(
+                    server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
+            return invoke(
+                CtsApi::sync(server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
+        }
+        if (sync_suite_clock)
+            return invoke(std::make_shared<CSyncCmd>(CSyncCmd::SYNC_CLOCK,
+                                                     server_reply_.client_handle(),
+                                                     defs->state_change_no(),
+                                                     defs->modify_change_no()));
+        return invoke(std::make_shared<CSyncCmd>(
+            CSyncCmd::SYNC, server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
+    }
+    // If we have a handle return the defs, with the registered suites, else returns the full defs
+    if (testInterface_)
+        return invoke(CtsApi::sync_full(server_reply_.client_handle()));
+
+    return invoke(std::make_shared<CSyncCmd>(server_reply_.client_handle()));
+}
+
+int ClientInvoker::news(defs_ptr& client_defs) const {
+    if (client_defs.get()) {
+        if (testInterface_)
+            return invoke(CtsApi::news(
+                server_reply_.client_handle(), client_defs->state_change_no(), client_defs->modify_change_no()));
+        return invoke(std::make_shared<CSyncCmd>(CSyncCmd::NEWS,
+                                                 server_reply_.client_handle(),
+                                                 client_defs->state_change_no(),
+                                                 client_defs->modify_change_no()));
+    }
+    server_reply_.set_error_msg("The client definition is empty.");
+    if (on_error_throw_exception_)
+        throw std::runtime_error(server_reply_.error_msg());
+    return 1;
+}
+
+int ClientInvoker::news_local() const {
+    defs_ptr defs = server_reply_.client_defs();
+    if (defs.get()) {
+        if (testInterface_)
+            return invoke(
+                CtsApi::news(server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
+        return invoke(std::make_shared<CSyncCmd>(
+            CSyncCmd::NEWS, server_reply_.client_handle(), defs->state_change_no(), defs->modify_change_no()));
+    }
+
+    // There is no local defs, i.e first time call, The default client handle should be 0.
+    // go with defaults for state and modify change numbers
+    // User is expected to call sync_local(), which will update local defs.
+    if (testInterface_)
+        return invoke(CtsApi::news(server_reply_.client_handle(), 0, 0));
+    return invoke(std::make_shared<CSyncCmd>(CSyncCmd::NEWS, server_reply_.client_handle(), 0, 0));
+}
+//=====================================================================================
+
+int ClientInvoker::getDefs() const {
+    if (testInterface_)
+        return invoke(CtsApi::get());
+    return invoke(std::make_shared<CtsNodeCmd>(CtsNodeCmd::GET));
+}
+
+int ClientInvoker::loadDefs(const std::string& filePath,
+                            bool force,      /* true means overwrite suite of same name */
+                            bool check_only, /* client side, true means don't send to server, just check only */
+                            bool print,      /* client side, print the defs */
+                            bool stats       /* client side, print the defs statitics */
+) const {
+    if (testInterface_)
+        return invoke(CtsApi::loadDefs(filePath, force, check_only, print));
+    Cmd_ptr cmd = LoadDefsCmd::create(filePath, force, check_only, print, stats, &clientEnv_);
+    // If check_only cmd will be empty
+    if (cmd)
+        return invoke(cmd);
+    return 0;
+}
+
+int ClientInvoker::restartServer() const {
+    if (testInterface_)
+        return invoke(CtsApi::restartServer());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::RESTART_SERVER));
+}
+int ClientInvoker::haltServer() const {
+    if (testInterface_)
+        return invoke(CtsApi::haltServer(true /*auto_confirm*/));
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::HALT_SERVER));
+}
+int ClientInvoker::pingServer() const {
+    if (testInterface_)
+        return invoke(CtsApi::pingServer());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::PING));
+}
+int ClientInvoker::shutdownServer() const {
+    if (testInterface_)
+        return invoke(CtsApi::shutdownServer(true /*auto_confirm*/));
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::SHUTDOWN_SERVER));
+}
+int ClientInvoker::terminateServer() const {
+    if (testInterface_)
+        return invoke(CtsApi::terminateServer(true /*auto_confirm*/));
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::TERMINATE_SERVER));
+}
+int ClientInvoker::stats() const {
+    if (testInterface_)
+        return invoke(CtsApi::stats());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::STATS));
+}
+int ClientInvoker::stats_server() const {
+    if (testInterface_)
+        return invoke(CtsApi::stats_server());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::STATS_SERVER));
+}
+int ClientInvoker::stats_reset() const {
+    if (testInterface_)
+        return invoke(CtsApi::stats_reset());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::STATS_RESET));
+}
+int ClientInvoker::suites() const {
+    if (testInterface_)
+        return invoke(CtsApi::suites());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::SUITES));
+}
+int ClientInvoker::server_version() const {
+    if (testInterface_)
+        return invoke(CtsApi::server_version());
+    return invoke(std::make_shared<ServerVersionCmd>());
+}
+int ClientInvoker::debug_server_on() const {
+    if (testInterface_)
+        return invoke(CtsApi::debug_server_on());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_ON));
+}
+int ClientInvoker::debug_server_off() const {
+    if (testInterface_)
+        return invoke(CtsApi::debug_server_off());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::DEBUG_SERVER_OFF));
+}
+
+//=====================================================================================
+
+int ClientInvoker::ch_register(bool auto_add_new_suites, const std::vector<std::string>& suites) const {
+    reset();
+    if (testInterface_)
+        return invoke(CtsApi::ch_register(0, auto_add_new_suites, suites));
+    return invoke(std::make_shared<ClientHandleCmd>(0, suites, auto_add_new_suites));
+}
+int ClientInvoker::ch1_register(bool auto_add_new_suites, const std::vector<std::string>& suites) const {
+    int client_handle = server_reply_.client_handle();
+    reset();
+    if (testInterface_)
+        return invoke(CtsApi::ch_register(client_handle, auto_add_new_suites, suites));
+    return invoke(std::make_shared<ClientHandleCmd>(client_handle, suites, auto_add_new_suites));
+}
+
+int ClientInvoker::ch_suites() const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_suites());
+    return invoke(std::make_shared<ClientHandleCmd>(ClientHandleCmd::SUITES));
+}
+int ClientInvoker::ch_drop(int client_handle) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_drop(client_handle));
+    return invoke(std::make_shared<ClientHandleCmd>(client_handle));
+}
+int ClientInvoker::ch_drop_user(const std::string& user) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_drop_user(user));
+    return invoke(std::make_shared<ClientHandleCmd>(user));
+}
+int ClientInvoker::ch_add(int client_handle, const std::vector<std::string>& suites) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_add(client_handle, suites));
+    return invoke(std::make_shared<ClientHandleCmd>(client_handle, suites, ClientHandleCmd::ADD));
+}
+int ClientInvoker::ch_remove(int client_handle, const std::vector<std::string>& suites) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_remove(client_handle, suites));
+    return invoke(std::make_shared<ClientHandleCmd>(client_handle, suites, ClientHandleCmd::REMOVE));
+}
+int ClientInvoker::ch_auto_add(int client_handle, bool auto_add_new_suites) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_auto_add(client_handle, auto_add_new_suites));
+    return invoke(std::make_shared<ClientHandleCmd>(client_handle, auto_add_new_suites));
+}
+int ClientInvoker::ch1_drop() const {
+    if (0 == server_reply_.client_handle())
+        return 0;
+    if (testInterface_)
+        return invoke(CtsApi::ch_drop(server_reply_.client_handle()));
+    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle()));
+}
+int ClientInvoker::ch1_add(const std::vector<std::string>& suites) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_add(server_reply_.client_handle(), suites));
+    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle(), suites, ClientHandleCmd::ADD));
+}
+int ClientInvoker::ch1_remove(const std::vector<std::string>& suites) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_remove(server_reply_.client_handle(), suites));
+    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle(), suites, ClientHandleCmd::REMOVE));
+}
+int ClientInvoker::ch1_auto_add(bool auto_add_new_suites) const {
+    if (testInterface_)
+        return invoke(CtsApi::ch_auto_add(server_reply_.client_handle(), auto_add_new_suites));
+    return invoke(std::make_shared<ClientHandleCmd>(server_reply_.client_handle(), auto_add_new_suites));
+}
+
+// ======================================================================================================
+
+int ClientInvoker::begin(const std::string& suiteName, bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::begin(suiteName, force));
+    return invoke(std::make_shared<BeginCmd>(suiteName, force));
+}
+int ClientInvoker::begin_all_suites(bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::begin("", force));
+    return invoke(std::make_shared<BeginCmd>("", force));
+}
+// ======================================================================================================
+
+int ClientInvoker::zombieGet() const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieGet());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::GET_ZOMBIES));
+}
+int ClientInvoker::zombieFob(const Zombie& z) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieFob(
+            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+    return invoke(std::make_shared<ZombieCmd>(
+        User::FOB, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+}
+int ClientInvoker::zombieFail(const Zombie& z) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieFail(
+            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+    return invoke(std::make_shared<ZombieCmd>(
+        User::FAIL, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+}
+int ClientInvoker::zombieAdopt(const Zombie& z) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieAdopt(
+            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+    return invoke(std::make_shared<ZombieCmd>(
+        User::ADOPT, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+}
+int ClientInvoker::zombieBlock(const Zombie& z) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieBlock(
+            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+    return invoke(std::make_shared<ZombieCmd>(
+        User::BLOCK, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+}
+int ClientInvoker::zombieRemove(const Zombie& z) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieRemove(
+            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+    return invoke(std::make_shared<ZombieCmd>(
+        User::REMOVE, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+}
+int ClientInvoker::zombieKill(const Zombie& z) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieKill(
+            std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+    return invoke(std::make_shared<ZombieCmd>(
+        User::KILL, std::vector<std::string>(1, z.path_to_task()), z.process_or_remote_id(), z.jobs_password()));
+}
+int ClientInvoker::zombieFobCli(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieFobCli(absNodePath));
+    return invoke(std::make_shared<ZombieCmd>(User::FOB, std::vector<std::string>(1, absNodePath), "", ""));
+}
+int ClientInvoker::zombieFailCli(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieFailCli(absNodePath));
+    return invoke(std::make_shared<ZombieCmd>(User::FAIL, std::vector<std::string>(1, absNodePath), "", ""));
+}
+int ClientInvoker::zombieAdoptCli(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieAdoptCli(absNodePath));
+    return invoke(std::make_shared<ZombieCmd>(User::ADOPT, std::vector<std::string>(1, absNodePath), "", ""));
+}
+int ClientInvoker::zombieBlockCli(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieBlockCli(absNodePath));
+    return invoke(std::make_shared<ZombieCmd>(User::BLOCK, std::vector<std::string>(1, absNodePath), "", ""));
+}
+int ClientInvoker::zombieRemoveCli(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieRemoveCli(absNodePath));
+    return invoke(std::make_shared<ZombieCmd>(User::REMOVE, std::vector<std::string>(1, absNodePath), "", ""));
+}
+int ClientInvoker::zombieKillCli(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieKillCli(absNodePath));
+    return invoke(std::make_shared<ZombieCmd>(User::KILL, std::vector<std::string>(1, absNodePath), "", ""));
+}
+
+int ClientInvoker::zombieFobCliPaths(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieFobCli(paths));
+    return invoke(std::make_shared<ZombieCmd>(User::FOB, paths, "", ""));
+}
+int ClientInvoker::zombieFailCliPaths(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieFailCli(paths));
+    return invoke(std::make_shared<ZombieCmd>(User::FAIL, paths, "", ""));
+}
+int ClientInvoker::zombieAdoptCliPaths(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieAdoptCli(paths));
+    return invoke(std::make_shared<ZombieCmd>(User::ADOPT, paths, "", ""));
+}
+int ClientInvoker::zombieBlockCliPaths(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieBlockCli(paths));
+    return invoke(std::make_shared<ZombieCmd>(User::BLOCK, paths, "", ""));
+}
+int ClientInvoker::zombieRemoveCliPaths(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieRemoveCli(paths));
+    return invoke(std::make_shared<ZombieCmd>(User::REMOVE, paths, "", ""));
+}
+int ClientInvoker::zombieKillCliPaths(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::zombieKillCli(paths));
+    return invoke(std::make_shared<ZombieCmd>(User::KILL, paths, "", ""));
+}
+
+// ======================================================================================================
+
+int ClientInvoker::job_gen(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::job_gen(absNodePath));
+    return invoke(std::make_shared<CtsNodeCmd>(CtsNodeCmd::JOB_GEN, absNodePath));
+}
+
+int ClientInvoker::edit_history(const std::string& path) const {
+    if (testInterface_)
+        return invoke(CtsApi::edit_history(path));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::EDIT_HISTORY, path));
+}
+int ClientInvoker::kill(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::kill(paths));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::KILL, paths));
+}
+int ClientInvoker::kill(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::kill(absNodePath));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::KILL, absNodePath));
+}
+int ClientInvoker::status(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::status(paths));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::STATUS, paths));
+}
+int ClientInvoker::status(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::status(absNodePath));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::STATUS, absNodePath));
+}
+int ClientInvoker::suspend(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::suspend(paths));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::SUSPEND, paths));
+}
+int ClientInvoker::suspend(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::suspend(absNodePath));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::SUSPEND, absNodePath));
+}
+int ClientInvoker::resume(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::resume(paths));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESUME, paths));
+}
+int ClientInvoker::resume(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::resume(absNodePath));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESUME, absNodePath));
+}
+int ClientInvoker::check(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::check(paths));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::CHECK, paths));
+}
+int ClientInvoker::check(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::check(absNodePath));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::CHECK, absNodePath));
+}
+int ClientInvoker::delete_nodes(const std::vector<std::string>& paths, bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::delete_node(paths, force, true /*auto_confirm*/));
+    return invoke(std::make_shared<DeleteCmd>(paths, force));
+}
+int ClientInvoker::delete_node(const std::string& absNodePath, bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::delete_node(absNodePath, force, true /*auto_confirm*/));
+    return invoke(std::make_shared<DeleteCmd>(absNodePath, force));
+}
+int ClientInvoker::delete_all(bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::delete_node(std::vector<std::string>(), force));
+    return invoke(std::make_shared<DeleteCmd>(std::vector<std::string>(), force));
+}
+
+int ClientInvoker::archive(const std::vector<std::string>& paths, bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::archive(paths, force));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::ARCHIVE, paths, force));
+}
+int ClientInvoker::archive(const std::string& absNodePath, bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::archive(absNodePath, force));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::ARCHIVE, absNodePath, force));
+}
+int ClientInvoker::restore(const std::vector<std::string>& paths) const {
+    if (testInterface_)
+        return invoke(CtsApi::restore(paths));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESTORE, paths));
+}
+int ClientInvoker::restore(const std::string& absNodePath) const {
+    if (testInterface_)
+        return invoke(CtsApi::restore(absNodePath));
+    return invoke(std::make_shared<PathsCmd>(PathsCmd::RESTORE, absNodePath));
+}
+
+// ======================================================================================================
+
+int ClientInvoker::replace(const std::string& absNodePath,
+                           const std::string& path_to_client_defs,
+                           bool create_parents_as_required,
+                           bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::replace(absNodePath, path_to_client_defs, create_parents_as_required, force));
+
+    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
+    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+    server_reply_.clear_for_invoke(cli());
+
+    /// Handle command constructors that can throw
+    Cmd_ptr cts_cmd;
+    try {
+        // For test allow the defs environment to changed, i.e. allow us to inject  ECF_CLIENT ???
+        cts_cmd = std::make_shared<ReplaceNodeCmd>(absNodePath, create_parents_as_required, path_to_client_defs, force);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "ClientInvoker::replace(" << absNodePath << "," << path_to_client_defs << ", ...) failed: " << e.what();
+        server_reply_.set_error_msg(ss.str());
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+
+    return invoke(cts_cmd);
+}
+
+int ClientInvoker::replace_1(const std::string& absNodePath,
+                             defs_ptr client_defs,
+                             bool create_parents_as_required,
+                             bool force) const {
+    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
+    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+    server_reply_.clear_for_invoke(cli());
+
+    /// Handle command constructors that can throw
+    Cmd_ptr cts_cmd;
+    try {
+        cts_cmd = std::make_shared<ReplaceNodeCmd>(absNodePath, create_parents_as_required, client_defs, force);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "ClientInvoker::replace_1(" << absNodePath << " ...) failed: " << e.what();
+        server_reply_.set_error_msg(ss.str());
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+
+    return invoke(cts_cmd);
+}
+
+int ClientInvoker::requeue(const std::vector<std::string>& paths, const std::string& option) const {
+    if (testInterface_)
+        return invoke(CtsApi::requeue(paths, option));
+
+    RequeueNodeCmd::Option the_option = RequeueNodeCmd::NO_OPTION;
+    if (!option.empty()) {
+        if (option == "abort")
+            the_option = RequeueNodeCmd::ABORT;
+        else if (option == "force")
+            the_option = RequeueNodeCmd::FORCE;
+        else {
+            server_reply_.set_error_msg("ClientInvoker::requeue: Expected option = [ force | abort ]");
+            if (on_error_throw_exception_) {
+                throw std::runtime_error(server_reply_.error_msg());
+            }
+            return 1;
+        }
+    }
+    return invoke(std::make_shared<RequeueNodeCmd>(paths, the_option));
+}
+
+int ClientInvoker::requeue(const std::string& absNodePath, const std::string& option) const {
+    if (testInterface_)
+        return invoke(CtsApi::requeue(absNodePath, option));
+
+    RequeueNodeCmd::Option the_option = RequeueNodeCmd::NO_OPTION;
+    if (!option.empty()) {
+        if (option == "abort")
+            the_option = RequeueNodeCmd::ABORT;
+        else if (option == "force")
+            the_option = RequeueNodeCmd::FORCE;
+        else {
+            server_reply_.set_error_msg("ClientInvoker::requeue: Expected option = [ force | abort ]");
+            if (on_error_throw_exception_)
+                throw std::runtime_error(server_reply_.error_msg());
+            return 1;
+        }
+    }
+    return invoke(std::make_shared<RequeueNodeCmd>(absNodePath, the_option));
+}
+
+int ClientInvoker::run(const std::vector<std::string>& paths, bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::run(paths, force));
+    return invoke(std::make_shared<RunNodeCmd>(paths, force));
+}
+int ClientInvoker::run(const std::string& absNodePath, bool force) const {
+    if (testInterface_)
+        return invoke(CtsApi::run(absNodePath, force));
+    return invoke(std::make_shared<RunNodeCmd>(absNodePath, force));
+}
+int ClientInvoker::order(const std::string& absNodePath, const std::string& order) const {
+    if (testInterface_)
+        return invoke(CtsApi::order(absNodePath, order));
+
+    if (!NOrder::isValid(order)) {
+        server_reply_.set_error_msg(
+            "ClientInvoker::order: please specify one of [ top, bottom, alpha, order, up, down, runtime ]\n");
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+    return invoke(std::make_shared<OrderNodeCmd>(absNodePath, NOrder::toOrder(order)));
+}
+int ClientInvoker::order(const std::string& absNodePath, NOrder::Order order) const {
+    return invoke(std::make_shared<OrderNodeCmd>(absNodePath, order));
+}
+
+// ======================================================================================================
+
+int ClientInvoker::checkPtDefs(ecf::CheckPt::Mode m, int check_pt_interval, int check_pt_save_time_alarm) const {
+    if (testInterface_)
+        return invoke(CtsApi::checkPtDefs(m, check_pt_interval, check_pt_save_time_alarm));
+    return invoke(std::make_shared<CheckPtCmd>(m, check_pt_interval, check_pt_save_time_alarm));
+}
+int ClientInvoker::restoreDefsFromCheckPt() const {
+    if (testInterface_)
+        return invoke(CtsApi::restoreDefsFromCheckPt());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::RESTORE_DEFS_FROM_CHECKPT));
+}
+
+int ClientInvoker::force(const std::string& absNodePath,
+                         const std::string& state_or_event,
+                         bool recursive,
+                         bool set_repeats_to_last_value) const {
+    if (testInterface_)
+        return invoke(CtsApi::force(absNodePath, state_or_event, recursive, set_repeats_to_last_value));
+    return invoke(std::make_shared<ForceCmd>(absNodePath, state_or_event, recursive, set_repeats_to_last_value));
+}
+int ClientInvoker::force(const std::vector<std::string>& paths,
+                         const std::string& state_or_event,
+                         bool recursive,
+                         bool set_repeats_to_last_value) const {
+    if (testInterface_)
+        return invoke(CtsApi::force(paths, state_or_event, recursive, set_repeats_to_last_value));
+    return invoke(std::make_shared<ForceCmd>(paths, state_or_event, recursive, set_repeats_to_last_value));
+}
+
+int ClientInvoker::freeDep(const std::vector<std::string>& paths,
+                           bool trigger,
+                           bool all,
+                           bool date,
+                           bool the_time) const {
+    if (testInterface_)
+        return invoke(CtsApi::freeDep(paths, trigger, all, date, the_time));
+    return invoke(std::make_shared<FreeDepCmd>(paths, trigger, all, date, the_time));
+}
+int ClientInvoker::freeDep(const std::string& absNodePath, bool trigger, bool all, bool date, bool the_time) const {
+    if (testInterface_)
+        return invoke(CtsApi::freeDep(absNodePath, trigger, all, date, the_time));
+    return invoke(std::make_shared<FreeDepCmd>(absNodePath, trigger, all, date, the_time));
+}
+
+int ClientInvoker::file(const std::string& absNodePath,
+                        const std::string& fileType,
+                        const std::string& max_lines) const {
+    if (testInterface_)
+        return invoke(CtsApi::file(absNodePath, fileType, max_lines));
+
+    /// Handle command constructors that can throw
+    Cmd_ptr cts_cmd;
+    try {
+        cts_cmd = std::make_shared<CFileCmd>(absNodePath, fileType, max_lines);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "ClientInvoker::file(" << absNodePath << "," << fileType << "," << max_lines << ") failed:\n" << e.what();
+        server_reply_.set_error_msg(ss.str());
+        if (on_error_throw_exception_) {
+            throw std::runtime_error(server_reply_.error_msg());
+        }
+        return 1;
+    }
+
+    return invoke(cts_cmd);
+}
+
+int ClientInvoker::plug(const std::string& sourcePath, const std::string& destPath) const {
+    if (testInterface_)
+        return invoke(CtsApi::plug(sourcePath, destPath));
+    return invoke(std::make_shared<PlugCmd>(sourcePath, destPath));
+}
+
+int ClientInvoker::query(const std::string& query_type,
+                         const std::string& path_to_attribute,
+                         const std::string& attribute) {
+    if (testInterface_)
+        return invoke(CtsApi::query(query_type, path_to_attribute, attribute));
+    return invoke(std::make_shared<QueryCmd>(query_type, path_to_attribute, attribute, clientEnv_.task_path()));
+}
+
+// ======================================================================================================
+
+int ClientInvoker::alter(const std::vector<std::string>& paths,
+                         const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+                         const std::string& attrType,
+                         const std::string& name,
+                         const std::string& value) const {
+    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
+    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+    server_reply_.clear_for_invoke(cli());
+
+    /// Handle command constructors that can throw
+    Cmd_ptr cts_cmd;
+    try {
+        cts_cmd = std::make_shared<AlterCmd>(paths, alterType, attrType, name, value);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "ClientInvoker::alter failed: " << e.what();
+        server_reply_.set_error_msg(ss.str());
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+    return invoke(cts_cmd);
+}
+
+int ClientInvoker::alter(const std::string& path,
+                         const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+                         const std::string& attrType,
+                         const std::string& name,
+                         const std::string& value) const {
+    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
+    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+    server_reply_.clear_for_invoke(cli());
+
+    /// Handle command constructors that can throw
+    Cmd_ptr cts_cmd;
+    try {
+        cts_cmd = std::make_shared<AlterCmd>(std::vector<std::string>(1, path), alterType, attrType, name, value);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "ClientInvoker::alter failed: " << e.what();
+        server_reply_.set_error_msg(ss.str());
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+    return invoke(cts_cmd);
+}
+
+int ClientInvoker::alter_sort(const std::vector<std::string>& paths,
+                              const std::string& sortable_attribute_name,
+                              bool recursive) const {
+    if (testInterface_)
+        return invoke(CtsApi::alter_sort(paths, sortable_attribute_name, recursive));
+    std::string value;
+    if (recursive)
+        value = "recursive";
+    return invoke(std::make_shared<AlterCmd>(paths, sortable_attribute_name, value));
+}
+int ClientInvoker::alter_sort(const std::string& path,
+                              const std::string& sortable_attribute_name,
+                              bool recursive) const {
+    if (testInterface_)
+        invoke(CtsApi::alter_sort(std::vector<std::string>(1, path), sortable_attribute_name, recursive));
+    std::string value;
+    if (recursive)
+        value = "recursive";
+    return invoke(std::make_shared<AlterCmd>(std::vector<std::string>(1, path), sortable_attribute_name, value));
+}
+
+// ======================================================================================================
+
+int ClientInvoker::reloadwsfile() const {
+    if (testInterface_)
+        return invoke(CtsApi::reloadwsfile());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::RELOAD_WHITE_LIST_FILE));
+}
+
+int ClientInvoker::reloadpasswdfile() const {
+    if (testInterface_)
+        return invoke(CtsApi::reloadpasswdfile());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::RELOAD_PASSWD_FILE));
+}
+
+int ClientInvoker::reloadcustompasswdfile() const {
+    if (testInterface_)
+        return invoke(CtsApi::reloadcustompasswdfile());
+    return invoke(std::make_shared<CtsCmd>(CtsCmd::RELOAD_CUSTOM_PASSWD_FILE));
+}
+
+int ClientInvoker::group(const std::string& groupRequest) const {
+    if (testInterface_)
+        return invoke(CtsApi::group(groupRequest));
+    return invoke(std::make_shared<GroupCTSCmd>(groupRequest, &clientEnv_));
+}
+
+int ClientInvoker::logMsg(const std::string& msg) const {
+    if (testInterface_)
+        return invoke(CtsApi::logMsg(msg));
+    return invoke(std::make_shared<LogMessageCmd>(msg));
+}
+int ClientInvoker::new_log(const std::string& new_path) const {
+    if (testInterface_)
+        return invoke(CtsApi::new_log(new_path));
+
+    /// Handle command constructors that can throw
+    Cmd_ptr cts_cmd;
+    try {
+        cts_cmd = std::make_shared<LogCmd>(new_path);
+    }
+    catch (std::exception& e) {
+        server_reply_.set_error_msg(e.what());
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+    return invoke(cts_cmd);
+}
+int ClientInvoker::getLog(int lastLines) const {
+    if (lastLines == 0)
+        lastLines = Log::get_last_n_lines_default();
+    if (testInterface_)
+        return invoke(CtsApi::getLog(lastLines));
+    return invoke(std::make_shared<LogCmd>(LogCmd::GET, lastLines));
+}
+int ClientInvoker::clearLog() const {
+    if (testInterface_)
+        return invoke(CtsApi::clearLog());
+    return invoke(std::make_shared<LogCmd>(LogCmd::CLEAR));
+}
+int ClientInvoker::flushLog() const {
+    if (testInterface_)
+        return invoke(CtsApi::flushLog());
+    return invoke(std::make_shared<LogCmd>(LogCmd::FLUSH));
+}
+int ClientInvoker::get_log_path() const {
+    if (testInterface_)
+        return invoke(CtsApi::get_log_path());
+    return invoke(std::make_shared<LogCmd>(LogCmd::PATH));
+}
+
+int ClientInvoker::forceDependencyEval() const {
+    return invoke(CtsApi::forceDependencyEval());
+}
+
+// ======================================================================================================
+
+int ClientInvoker::edit_script_edit(const std::string& path_to_task) {
+    return invoke(std::make_shared<EditScriptCmd>(path_to_task, EditScriptCmd::EDIT));
+}
+
+int ClientInvoker::edit_script_preprocess(const std::string& path_to_task) {
+    return invoke(std::make_shared<EditScriptCmd>(path_to_task, EditScriptCmd::PREPROCESS));
+}
+
+int ClientInvoker::edit_script_preprocess(const std::string& path_to_task,
+                                          const std::vector<std::string>& file_contents) {
+    return invoke(std::make_shared<EditScriptCmd>(path_to_task, file_contents));
+}
+
+int ClientInvoker::edit_script_submit(const std::string& path_to_task, const NameValueVec& used_variables) {
+    return invoke(std::make_shared<EditScriptCmd>(path_to_task, used_variables));
+}
+
+int ClientInvoker::edit_script_submit(const std::string& path_to_task,
+                                      const NameValueVec& used_variables,
+                                      const std::vector<std::string>& file_contents,
+                                      bool create_alias,
+                                      bool run_alias) {
+    return invoke(
+        std::make_shared<EditScriptCmd>(path_to_task, used_variables, file_contents, create_alias, run_alias));
+}
+
+std::string ClientInvoker::client_env_host_port() const {
+    std::string host_port = clientEnv_.host();
+    host_port += Str::COLON();
+    host_port += clientEnv_.port();
+    return host_port;
+}
+
+std::string ClientInvoker::find_free_port(int seed_port_number, bool debug) {
+    // Ping failed, We need to distinguish between:
+    //    a/ Server does not exist : <FREE> port
+    //    b/ Address in use        : <BUSY> port on existing server
+    // Using server_version() but then get error messages
+    // ******** Until this is done we can't implement port hopping **********
+
+    if (debug)
+        cout << "  ClientInvoker::find_free_port: starting with port " << seed_port_number << "\n";
+    int the_port = seed_port_number;
+    std::string free_port;
+    ClientInvoker client;
+    client.set_retry_connection_period(1); // avoid long wait
+    client.set_connection_attempts(1);     // avoid long wait
+    while (true) {
+        free_port = ecf::convert_to<std::string>(the_port);
+        try {
+            if (debug)
+                cout << "   Trying to connect to server on '" << Str::LOCALHOST() << ":" << free_port << "'\n";
+            client.set_host_port(Str::LOCALHOST(), free_port);
+            client.pingServer();
+            if (debug)
+                cout << "   Connected to server on port " << free_port << " trying next port\n";
+            the_port++;
+        }
+        catch (std::runtime_error& e) {
+            std::string error_msg = e.what();
+            if (debug)
+                cout << "   " << error_msg;
+            if (error_msg.find("authentication failed") != std::string::npos) {
+                if (debug)
+                    cout << "   Could not connect, due to authentication failure, hence port " << the_port
+                         << " is used, trying next port\n";
+                the_port++;
+                continue;
+            }
+            if (error_msg.find("invalid_argument") != std::string::npos) {
+                if (debug)
+                    cout << "   Mixing 4 and 5 series ?, hence port " << the_port << " is used, trying next port\n";
+                the_port++;
+                continue;
+            }
+            else {
+                if (debug)
+                    cout << "   Found free port " << free_port << "\n";
+                break;
+            }
+        }
+    }
+    return free_port;
+}
+
+bool ClientInvoker::wait_for_server_reply(int time_out) const {
+    DurationTimer timer;
+    while (true) {
+        sleep(2);
+
+        if (on_error_throw_exception_) {
+            try {
+                pingServer(); // will throw exception
+                return true;  // no exception, server lives
+            }
+            catch (...) {
+            }
+        }
+        else {
+            if (pingServer() == 0) {
+                return true; // ping OK,
+            }
+        }
+        if (timer.duration() > time_out) {
+            return false;
+        }
+    }
+    return false;
+}
+
+bool ClientInvoker::wait_for_server_death(int time_out) const {
+    DurationTimer timer;
+    while (true) {
+
+        if (on_error_throw_exception_) {
+            try {
+                pingServer(); // will throw exception
+            }
+            catch (...) {
+                // server died
+                return true;
+            }
+        }
+        else {
+            if (pingServer() == 1) {
+                return true; // ping failed, server has died,
+            }
+        }
+        if (timer.duration() > time_out) {
+            return false; // server still lives
+        }
+
+        // Ping ok, server lives, continue pinging, until timeout
+        sleep(2);
+    }
+    return false;
+}
+
+int ClientInvoker::load_in_memory_defs(const defs_ptr& clientDefs, bool force) const {
+    /// *Note* server_reply_.client_handle_ is kept until the next call to register_client_handle
+    /// The client invoker can be used multiple times, hence keep value of defs, and client handle in server reply
+    server_reply_.clear_for_invoke(cli());
+
+    if (!clientDefs.get()) {
+        server_reply_.set_error_msg("The client definition is empty.");
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+
+    // Client defs  has been created in memory.
+    // warn about naff expression and unresolved in-limit references to Limit's
+    // Don't allow defs to be loaded into server, with trigger parser errors.
+    std::string warningMsg;
+    if (!clientDefs->check(server_reply_.get_error_msg(), warningMsg)) {
+        if (on_error_throw_exception_)
+            throw std::runtime_error(server_reply_.error_msg());
+        return 1;
+    }
+
+    return invoke(std::make_shared<LoadDefsCmd>(clientDefs, force /*force overwrite suite of same name*/));
+}
+
+void ClientInvoker::check_child_parameters() const {
+    if (clientEnv_.debug()) {
+        std::cout << "  child_task_path = '" << clientEnv_.task_path() << "'\n";
+        std::cout << "  child_task_password = '" << clientEnv_.jobs_password() << "'\n";
+        std::cout << "  child_task_pid = '" << clientEnv_.process_or_remote_id() << "'\n";
+        std::cout << "  child_task_try_no = " << clientEnv_.task_try_no() << "\n";
+    }
+    if (clientEnv_.task_path().empty())
+        throw std::runtime_error("Child Path not set");
+    if (clientEnv_.jobs_password().empty())
+        throw std::runtime_error("Child password not set");
+    if (clientEnv_.process_or_remote_id().empty())
+        throw std::runtime_error("Child pid not set");
+    if (clientEnv_.task_try_no() == 0)
+        throw std::runtime_error("Child try_no not set");
+}
+
+void ClientInvoker::child_init() {
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<InitCmd>(clientEnv_.task_path(),
+                                     clientEnv_.jobs_password(),
+                                     clientEnv_.process_or_remote_id(),
+                                     clientEnv_.task_try_no(),
+                                     clientEnv_.init_add_vars()));
+}
+
+void ClientInvoker::child_abort(const std::string& reason) {
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<AbortCmd>(clientEnv_.task_path(),
+                                      clientEnv_.jobs_password(),
+                                      clientEnv_.process_or_remote_id(),
+                                      clientEnv_.task_try_no(),
+                                      reason));
+}
+
+void ClientInvoker::child_event(const std::string& event_name_or_number, bool event_value) {
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<EventCmd>(clientEnv_.task_path(),
+                                      clientEnv_.jobs_password(),
+                                      clientEnv_.process_or_remote_id(),
+                                      clientEnv_.task_try_no(),
+                                      event_name_or_number,
+                                      event_value));
+}
+
+void ClientInvoker::child_meter(const std::string& meter_name, int meter_value) {
+    if (meter_name.empty())
+        throw std::runtime_error("Meter name not set");
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<MeterCmd>(clientEnv_.task_path(),
+                                      clientEnv_.jobs_password(),
+                                      clientEnv_.process_or_remote_id(),
+                                      clientEnv_.task_try_no(),
+                                      meter_name,
+                                      meter_value));
+}
+
+void ClientInvoker::child_label(const std::string& label_name, const std::string& label_value) {
+    if (label_name.empty())
+        throw std::runtime_error("Label name not set");
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<LabelCmd>(clientEnv_.task_path(),
+                                      clientEnv_.jobs_password(),
+                                      clientEnv_.process_or_remote_id(),
+                                      clientEnv_.task_try_no(),
+                                      label_name,
+                                      label_value));
+}
+
+void ClientInvoker::child_wait(const std::string& expression) {
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<CtsWaitCmd>(clientEnv_.task_path(),
+                                        clientEnv_.jobs_password(),
+                                        clientEnv_.process_or_remote_id(),
+                                        clientEnv_.task_try_no(),
+                                        expression));
+}
+
+std::string ClientInvoker::child_queue(const std::string& queue_name,
+                                       const std::string& action,
+                                       const std::string& step,
+                                       const std::string& path_to_node_with_queue) {
+    if (queue_name.empty())
+        throw std::runtime_error("ClientInvoker::child_queue: Queue name not set");
+    if (action.empty())
+        throw std::runtime_error("ClientInvoker::child_queue: action not set");
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<QueueCmd>(clientEnv_.task_path(),
+                                      clientEnv_.jobs_password(),
+                                      clientEnv_.process_or_remote_id(),
+                                      clientEnv_.task_try_no(),
+                                      queue_name,
+                                      action,
+                                      step,
+                                      path_to_node_with_queue));
+    return server_reply_.get_string();
+}
+
+void ClientInvoker::child_complete() {
+    check_child_parameters();
+    on_error_throw_exception_ = true; // for python always throw exception
+    invoke(std::make_shared<CompleteCmd>(clientEnv_.task_path(),
+                                         clientEnv_.jobs_password(),
+                                         clientEnv_.process_or_remote_id(),
+                                         clientEnv_.task_try_no(),
+                                         clientEnv_.complete_del_vars()));
+}
+
+// ==========================================================================
+// class RequestLogger:
+// ==========================================================================
+RequestLogger::RequestLogger(const ClientInvoker* ci) : ci_(ci) {
+}
+RequestLogger::~RequestLogger() {
+
+    // *assumes* destructor of RoundTripRecorder was invoked first, to allow recording of the time rtt_
+    if (cmd_.get()) {
+        if (ci_->clientEnv_.debug() && ci_->server_reply_.error_msg().empty()) {
+            cout << TimeStamp::now() << "ClientInvoker: " << cmd_->print_short() << " SUCCEEDED "
+                 << to_simple_string(ci_->rtt_) << "\n";
+        }
+
+        if (Rtt::instance()) {
+            std::string ss;
+            ss += ci_->client_env_host_port();
+            ss += " ";
+            cmd_->print(ss);
+            ss += " ";
+            ss += Rtt::tag();
+            ss += to_simple_string(ci_->rtt_); // Note: endl added rtt(..)
+            ss += " : ";
+            ss += ci_->server_reply_.error_msg();
+            rtt(ss);
+        }
+
+        if (ci_->cli() && cmd_->ping_cmd() && ci_->server_reply_.error_msg().empty()) {
+            cout << "ping server(" << ci_->client_env_host_port() << ") succeeded in " << to_simple_string(ci_->rtt_)
+                 << "  ~" << ci_->rtt_.total_milliseconds() << " milliseconds\n";
+        }
+    }
+}
+
+// ==========================================================================
+// class RoundTripRecorder:
+// ==========================================================================
+RoundTripRecorder::RoundTripRecorder(const ClientInvoker* ci) : ci_(ci) {
+    // get the current time from the clock -- one second resolution
+    ci_->start_time_ = microsec_clock::universal_time();
+    ci_->rtt_        = boost::posix_time::time_duration();
+}
+
+RoundTripRecorder::~RoundTripRecorder() {
+    ci_->rtt_ = microsec_clock::universal_time() - ci_->start_time_;
+}
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientInvoker.hpp 5.13.0-1/libs/client/src/ecflow/client/ClientInvoker.hpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientInvoker.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientInvoker.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,471 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_ClientInvoker_HPP
+#define ecflow_client_ClientInvoker_HPP
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/base/Cmd.hpp"
+#include "ecflow/base/ServerReply.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientOptions.hpp"
+#include "ecflow/core/NOrder.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+class CommandLine;
+
+/// Invokes the client depending on the arguments
+/// This has been separated from main, to allow us to invoke the client
+/// from a test suite.
+/// Important: We can make *many* calls with the same ClientInvoker.
+/// This is more efficient than creating a ClientInvoker for each request
+class ClientInvoker {
+public:
+    ClientInvoker(const ClientInvoker&)                  = delete;
+    const ClientInvoker& operator=(const ClientInvoker&) = delete;
+
+    /// Will create the *ClientEnvironment* once on construction
+    /// By default will throw exception std::runtime_error for errors
+    ClientInvoker();
+    explicit ClientInvoker(const std::string& host_port);
+    ClientInvoker(bool GUI, const std::string& host, const std::string& port);
+    ClientInvoker(const std::string& host, const std::string& port);
+    ClientInvoker(const std::string& host, int port);
+
+    /// for debug allow the current client environment to be printed
+    std::string to_string() const { return clientEnv_.toString(); }
+
+    /// if throw_exception_on_error = false, then
+    ///    invoke() will return 0 for success and 1 for error.
+    ///    The error message can be retrieved from errorMsg()
+    /// if throw_exception_on_error = true,
+    ///	  then invoke() for errors will throw std::runtime_error
+    ///   will still return 0 for success.
+    void set_throw_on_error(bool f) { on_error_throw_exception_ = f; }
+
+    /// Enable auto sync on each command that can modify the Defs state in the server
+    void set_auto_sync(bool f) { auto_sync_ = f; }
+    bool is_auto_sync_enabled() const { return auto_sync_; }
+
+    /// Return the time it takes to contact server and get a reply.
+    const boost::posix_time::time_duration& round_trip_time() const { return rtt_; }
+
+    /// Configure to using command line interface
+    /// This affect commands like ping, log & file, so that, output is written to standard out
+    /// Can also be used to check argument arguments
+    void set_cli(bool f) { clientEnv_.set_cli(f); }
+    bool cli() const { return clientEnv_.get_cli(); }
+
+#ifdef ECF_OPENSSL
+    /// Override any ssl read from environment(ECF_SSL) or command line args(-ssl)
+    void enable_ssl() { clientEnv_.enable_ssl(); }
+    bool enable_ssl_no_throw() { return clientEnv_.enable_ssl_no_throw(); }
+    void disable_ssl() { clientEnv_.disable_ssl(); } // override environment setting for ECF_SSL
+#endif
+
+    /// This will override the environment setting.
+    /// In particular setting host explicitly will avoid cycling through server list,
+    /// if connection fails. hence will bomb out earlier
+    /// If applied to child command's will continue attempting this host/port until timeout
+    void set_host_port(const std::string& h, const std::string& p);
+    void set_hostport(const std::string& host_port);
+    const std::string& host() const;
+    const std::string& port() const;
+
+    /// This will override the environment setting. ECF_USER or --user
+    /// Clear password, so that re-validate users password from password file
+    void set_user_name(const std::string& user);
+    void set_password(const std::string& password);
+
+    /// Whenever there is a connections failure we wait a number of seconds
+    /// before trying again. ( i.e. to get round glitches in the network.)
+    /// For the ping command this is set as 1 second
+    /// This wait between connection attempts can be configured here.
+    /// i.e for the GUI & python interface this can be reduced to increase responsiveness.
+    /// Default: In debug this period in set to 1 second and in release mode 10 seconds
+    void set_retry_connection_period(unsigned int period) { retry_connection_period_ = period; }
+
+    /// Set the number of times to connect to server, in case of failure
+    /// The period between connection attempts is handled by set_retry_connection_period
+    /// i.e for the GUI & python interface this can be reduced to increase responsiveness.
+    /// Default value is set as 2. Setting a value less than 1 is ignored, will default to 1 in this case
+    void set_connection_attempts(unsigned int attempts);
+
+    /// returns 1 on error and 0 on success. The errorMsg can be accessed via errorMsg()
+    /// Will attempt to connect to the server a number of times. If this fails it will
+    /// try the next server, and so on until a timeout period is reached.
+    int invoke(int argc, char* argv[]) const;
+    int invoke(const CommandLine& cl) const;
+
+    /// If testing, overwrite the task path set in the environment, required for
+    /// testing the task based commands.
+    /// By allowing environment to be changed, we allow smsinit,smscomplete, etc to be replaced
+    /// with ECF_CLIENT path executable
+    /// The following functions are only used for testing purposes.
+    /// Override task paths,env' & job creation at begin time
+    void taskPath(const std::string& s);
+    void set_jobs_password(const std::string&);
+    void setEnv(const std::vector<std::pair<std::string, std::string>>& e);
+    void testInterface(); // allow cmd construction to be aware thats it under test
+    const std::string& process_or_remote_id() const;
+
+    /// record each request its arguments and the round trip time to and from server
+    /// If the file cannot opened for create/append then an runtime error exception is thrown
+    void enable_logging(const std::string& log_file_name);
+    void disable_logging();
+
+    void debug(bool flag) { clientEnv_.set_debug(flag); }
+
+    /// The timeout feature allow the client to fail gracefully in the case
+    /// where the server has died/crashed. The timeout will ensure the socket is closed.
+    /// allowing the server to be restarted without getting the address is use error.
+    /// Set the timeout for each client->server communication:
+    //    connect        : timeout_ second
+    //    send request   : timeout_ second
+    //    receive reply  : timeout_ second
+    // default is 0 second, which means take the timeout from the command/request
+    // used for test only
+    void set_connect_timeout(int t);
+
+    /// ServerReply Holds the reply from the server
+    void reset() const; // will clear local client definition and handle
+    const ServerReply& server_reply() const { return server_reply_; }
+    defs_ptr defs() const { return server_reply_.client_defs(); }
+    const std::string& get_string() const { return server_reply_.get_string(); }
+    bool in_sync() const { return server_reply_.in_sync(); }
+    bool get_news() const { return (server_reply_.get_news() != ServerReply::NO_NEWS); }
+    int client_handle() const { return server_reply_.client_handle(); }
+
+    /// If invoke returns 1, the error message can be retrieved with this function
+    const std::string& errorMsg() const { return server_reply_.error_msg(); }
+
+    // ***************************************************************************
+    // Task/child based api. Only added here for test.
+    // Relies on environment for the other args
+    int initTask(const std::string& process_id) const { return invoke(TaskApi::init(process_id)); }
+    int abortTask(const std::string& reason_why = "") const { return invoke(TaskApi::abort(reason_why)); }
+    int eventTask(const std::string& eventName, const std::string& value = "set") const {
+        return invoke(TaskApi::event(eventName, value));
+    }
+    int meterTask(const std::string& meterName, const std::string& new_meter_value) const {
+        return invoke(TaskApi::meter(meterName, new_meter_value));
+    }
+    int labelTask(const std::string& labelName, const std::vector<std::string>& labels) const {
+        return invoke(TaskApi::label(labelName, labels));
+    }
+    int waitTask(const std::string& on_expression) const { return invoke(TaskApi::wait(on_expression)); }
+    int queueTask(const std::string& queue_name,
+                  const std::string& action,
+                  const std::string& step                    = "",
+                  const std::string& path_to_node_with_queue = "") const {
+        return invoke(TaskApi::queue(queue_name, action, step, path_to_node_with_queue));
+    }
+    int completeTask() const { return invoke(TaskApi::complete()); }
+
+    // Support for python child commands, and python jobs
+    void set_child_path(const std::string& path) { clientEnv_.set_child_path(path); }
+    void set_child_password(const std::string& pass) { clientEnv_.set_child_password(pass); }
+    void set_child_pid(const std::string& pid) { clientEnv_.set_child_pid(pid); }
+    void set_child_try_no(unsigned int try_no) { clientEnv_.set_child_try_no(try_no); }
+    void set_child_timeout(unsigned int seconds) {
+        clientEnv_.set_child_cmd_timeout(seconds);
+    } // ECF_TIMEOUT default is 24 hours allow python jobs to override
+    void set_child_host_file(const std::string& host_file) { clientEnv_.set_child_host_file(host_file); }
+    void set_child_denied(bool denied) { clientEnv_.set_child_denied(denied); }
+    void set_child_no_ecf(bool no_ecf) { clientEnv_.set_child_no_ecf(no_ecf); }
+
+    void set_child_init_add_vars(const std::vector<Variable>& vars) { clientEnv_.set_child_init_add_vars(vars); }
+    void set_child_complete_del_vars(std::vector<std::string>& vars) { clientEnv_.set_child_complete_del_vars(vars); }
+    void set_zombie_child_timeout(unsigned int seconds) {
+        clientEnv_.set_zombie_child_cmd_timeout(seconds);
+    } // ECF_ZOMBIE_TIMEOUT default is 24 hours allow python jobs to override
+
+    void child_init();
+    void child_abort(const std::string& reason = "");
+    void child_event(const std::string& event_name_or_number, bool value = true);
+    void child_meter(const std::string& meter_name, int meter_value);
+    void child_label(const std::string& label_name, const std::string& label_value);
+    void child_wait(const std::string& on_expression);
+    std::string child_queue(const std::string& queue_name,
+                            const std::string& ation,
+                            const std::string& step,
+                            const std::string& path_to_node_with_queue = "");
+    void child_complete();
+
+    // ********************************************************************************
+    // The client api. Mirrors CtsApi on the whole
+    int getDefs() const;
+    int loadDefs(const std::string& filePath,
+                 bool force      = false, /* true means overwrite suite of same name */
+                 bool check_only = false, /* client side only, true means don't send to server, just check only */
+                 bool print      = false, /* client side only, print the defs */
+                 bool stats      = false  /* client side only, print the defs statitics */
+    ) const;
+    int load(const defs_ptr& defs, bool force = false /*true means overwrite suite of same name*/) const {
+        return load_in_memory_defs(defs, force);
+    }
+    int sync(defs_ptr& client_defs) const;
+    int sync_local(bool sync_suite_clock = false) const;
+    int news(defs_ptr& client_defs) const;
+    int news_local() const;
+
+    // find free port on local host. Not 100% accurate, use in test
+    static std::string find_free_port(int seed_port_number, bool debug = false);
+
+    bool wait_for_server_reply(int time_out = 60) const; // wait for server reply, returning false means timed out.
+    bool wait_for_server_death(
+        int time_out = 60) const; // wait for server reply, returning true means server died,false means timed out.
+    int restartServer() const;
+    int haltServer() const;
+    int shutdownServer() const;
+    int terminateServer() const;
+    int pingServer() const;
+    int server_load(const std::string& path_to_log_file = "") const {
+        return invoke(CtsApi::server_load(path_to_log_file));
+    }
+    int debug_server_on() const;
+    int debug_server_off() const;
+    int stats() const; // returns stats as string, server does formatting, & hence is free to change ECFLOW-880
+    int stats_reset() const;
+    int stats_server() const; // for test only, as stats returned may change for each release ECFLOW-880
+    int server_version() const;
+
+    int suites() const;
+    int ch_register(bool auto_add_new_suites, const std::vector<std::string>& suites) const;
+    int ch_suites() const;
+    int ch_drop(int client_handle) const;
+    int ch_drop_user(const std::string& user = "") const;
+    int ch_add(int client_handle, const std::vector<std::string>& suites) const;
+    int ch_remove(int client_handle, const std::vector<std::string>& suites) const;
+    int ch_auto_add(int client_handle, bool auto_add_new_suites) const;
+    int ch1_register(bool auto_add_new_suites,
+                     const std::vector<std::string>& suites) const; // uses existing handle on client if any
+    int ch1_drop() const;                                           // uses existing handle on client
+    int ch1_add(const std::vector<std::string>& suites) const;      // uses existing handle on client
+    int ch1_remove(const std::vector<std::string>& suites) const;   // uses existing handle on client
+    int ch1_auto_add(bool auto_add_new_suites) const;               // uses existing handle on client
+
+    int begin(const std::string& suiteName, bool force = false) const;
+    int begin_all_suites(bool force = false) const;
+
+    int zombieGet() const;
+    int zombieFob(const Zombie& z) const;
+    int zombieFail(const Zombie& z) const;
+    int zombieAdopt(const Zombie& z) const;
+    int zombieBlock(const Zombie& z) const;
+    int zombieRemove(const Zombie& z) const;
+    int zombieKill(const Zombie& z) const;
+    int zombieFobCli(const std::string& absNodePath) const;
+    int zombieFailCli(const std::string& absNodePath) const;
+    int zombieAdoptCli(const std::string& absNodePath) const;
+    int zombieBlockCli(const std::string& absNodePath) const;
+    int zombieRemoveCli(const std::string& absNodePath) const;
+    int zombieKillCli(const std::string& absNodePath) const;
+    int zombieFobCliPaths(const std::vector<std::string>& paths) const;
+    int zombieFailCliPaths(const std::vector<std::string>& paths) const;
+    int zombieAdoptCliPaths(const std::vector<std::string>& paths) const;
+    int zombieBlockCliPaths(const std::vector<std::string>& paths) const;
+    int zombieRemoveCliPaths(const std::vector<std::string>& paths) const;
+    int zombieKillCliPaths(const std::vector<std::string>& paths) const;
+
+    int job_gen(const std::string& absNodePath) const;
+
+    int edit_history(const std::string& path) const;
+    int kill(const std::vector<std::string>& paths) const;
+    int kill(const std::string& absNodePath) const;
+    int status(const std::vector<std::string>& paths) const;
+    int status(const std::string& absNodePath) const;
+    int suspend(const std::vector<std::string>& paths) const;
+    int suspend(const std::string& absNodePath) const;
+    int resume(const std::vector<std::string>& paths) const;
+    int resume(const std::string& absNodePath) const;
+    int check(const std::vector<std::string>& paths) const;
+    int check(const std::string& absNodePath) const;
+    int delete_nodes(const std::vector<std::string>& paths, bool force = false) const;
+    int delete_node(const std::string& absNodePath, bool force = false) const;
+    int delete_all(bool force = false) const;
+    int archive(const std::vector<std::string>& paths, bool force = false) const;
+    int archive(const std::string& absNodePath, bool force = false) const;
+    int restore(const std::vector<std::string>& paths) const;
+    int restore(const std::string& absNodePath) const;
+
+    int replace(const std::string& absNodePath,
+                const std::string& path_to_client_defs,
+                bool create_parents_as_required = true,
+                bool force                      = false) const;
+    int replace_1(const std::string& absNodePath,
+                  defs_ptr client_defs,
+                  bool create_parents_as_required = true,
+                  bool force                      = false) const;
+
+    int requeue(const std::vector<std::string>& paths, const std::string& option = "") const;
+    int requeue(const std::string& absNodePath, const std::string& option = "") const;
+    int run(const std::vector<std::string>& paths, bool force = false) const;
+    int run(const std::string& absNodePath, bool force = false) const;
+    int order(const std::string& absNodePath, const std::string& order) const; // slow
+    int order(const std::string& absNodePath, NOrder::Order) const;            // fast
+
+    // Note: if *ALL* arguments are defaulted only then do we do a explicit save.
+    int checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
+                    int check_pt_interval        = 0,
+                    int check_pt_save_time_alarm = 0) const;
+    int restoreDefsFromCheckPt() const;
+
+    int force(const std::string& absNodePath,
+              const std::string& state_or_event,
+              bool recursive                 = false,
+              bool set_repeats_to_last_value = false) const;
+    int force(const std::vector<std::string>& paths,
+              const std::string& state_or_event,
+              bool recursive                 = false,
+              bool set_repeats_to_last_value = false) const;
+
+    int freeDep(const std::vector<std::string>& paths,
+                bool trigger = true,
+                bool all     = false,
+                bool date    = false,
+                bool time    = false) const;
+    int freeDep(const std::string& absNodePath,
+                bool trigger = true,
+                bool all     = false,
+                bool date    = false,
+                bool time    = false) const;
+
+    int file(const std::string& absNodePath, const std::string& fileType, const std::string& max_lines = "10000") const;
+
+    int plug(const std::string& sourcePath, const std::string& destPath) const;
+
+    int query(const std::string& query_type, const std::string& path_to_attribute, const std::string& attribute);
+
+    int alter(const std::vector<std::string>& paths,
+              const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+              const std::string& attrType,
+              const std::string& name  = "",
+              const std::string& value = "") const;
+    int alter(const std::string& path,
+              const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+              const std::string& attrType,
+              const std::string& name  = "",
+              const std::string& value = "") const;
+    int alter_sort(const std::vector<std::string>& paths,
+                   const std::string& sortable_attribute_name,
+                   bool recursive = true) const;
+    int alter_sort(const std::string& path, const std::string& sortable_attribute_name, bool recursive = true) const;
+
+    int reloadwsfile() const;
+    int reloadpasswdfile() const;
+    int reloadcustompasswdfile() const;
+
+    int group(const std::string& groupRequest) const;
+
+    int logMsg(const std::string& msg) const;
+    int new_log(const std::string& new_path = "") const;
+    int getLog(int lastLines = 0) const;
+    int clearLog() const;
+    int flushLog() const;
+    int get_log_path() const;
+
+    int forceDependencyEval() const;
+
+    /// The first is for use by CLI(Commend level interface), the other are for ecFlowview/Python
+    int edit_script(const std::string& path_to_task,
+                    const std::string& edit_type,
+                    const std::string& path_to_script = "",
+                    bool create_alias                 = false,
+                    bool run                          = true) {
+        return invoke(CtsApi::edit_script(path_to_task, edit_type, path_to_script, create_alias, run));
+    }
+    int edit_script_edit(const std::string& path_to_task);       // ecFlowview EDIT
+    int edit_script_preprocess(const std::string& path_to_task); // ecFlowview PRE_PROCESS
+    int edit_script_submit(const std::string& path_to_task, const NameValueVec& used_variables); // ecFlowview SUBMIT
+    int edit_script_preprocess(const std::string& path_to_task,
+                               const std::vector<std::string>& file_contents); // ecFlowview PRE_PROCESS USER File
+    int edit_script_submit(const std::string& path_to_task,
+                           const NameValueVec& used_variables,
+                           const std::vector<std::string>& file_contents,
+                           bool alias = false,
+                           bool run   = true); // ecFlowview SUBMIT_FILE
+
+private:
+    int get_cmd_from_args(const CommandLine& cl, Cmd_ptr& cts_cmd) const;
+
+    /// returns 1 on error and 0 on success. The errorMsg can be accessed via errorMsg()
+    int invoke(const std::string& arg) const;
+    int invoke(const std::vector<std::string>& args) const;
+    int invoke(Cmd_ptr) const; // assumes clients of Cmd_ptr constructor has caught exceptions
+
+    int do_invoke_cmd(Cmd_ptr) const;
+    int load_in_memory_defs(const defs_ptr& clientDefs,
+                            bool force) const; /// For clients that want to load a in memory definition into the server.
+    std::string client_env_host_port() const;
+    void check_child_parameters() const;
+
+private:
+    friend class RoundTripRecorder;
+    friend class RequestLogger;
+
+    /// For use by python interface,
+    std::vector<std::string>::const_iterator changed_node_paths_begin() const {
+        return server_reply_.changed_nodes().begin();
+    }
+    std::vector<std::string>::const_iterator changed_node_paths_end() const {
+        return server_reply_.changed_nodes().end();
+    }
+    friend void export_Client();
+
+private:
+    mutable ClientEnvironment
+        clientEnv_;              // Will read the environment *once* on construction. Must be before Client options
+    mutable ClientOptions args_; // Used for argument parsing & creating client request
+    mutable ServerReply server_reply_;     // stores the local defs, client_handle, & all server replies
+    unsigned int connection_attempts_{2};  // No of attempts to establish connection with the server
+    unsigned int retry_connection_period_; // No of seconds to wait before trying to connect in case of failure.
+
+    mutable boost::posix_time::time_duration rtt_; // record latency for each cmd.
+    mutable boost::posix_time::ptime start_time_;  // Used for time out and measuring latency
+
+    bool gui_{false};
+    bool on_error_throw_exception_{true};
+    bool auto_sync_{false};
+    bool test_{false};          // used in testing only
+    bool testInterface_{false}; // used in testing only
+};
+
+// Allow logging and debug output of request round trip times
+class RequestLogger {
+public:
+    RequestLogger(const RequestLogger&)                  = delete;
+    const RequestLogger& operator=(const RequestLogger&) = delete;
+
+    explicit RequestLogger(const ClientInvoker* ci);
+    ~RequestLogger();
+    void set_cts_cmd(Cmd_ptr cmd) { cmd_ = cmd; }
+
+private:
+    const ClientInvoker* ci_;
+    Cmd_ptr cmd_;
+};
+
+class RoundTripRecorder {
+public:
+    RoundTripRecorder(const RoundTripRecorder&)                  = delete;
+    const RoundTripRecorder& operator=(const RoundTripRecorder&) = delete;
+
+    explicit RoundTripRecorder(const ClientInvoker* ci);
+    ~RoundTripRecorder();
+
+private:
+    const ClientInvoker* ci_;
+};
+
+#endif /* ecflow_client_ClientInvoker_HPP */
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientMain.cpp 5.13.0-1/libs/client/src/ecflow/client/ClientMain.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientMain.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientMain.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,29 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/CommandLine.hpp"
+
+int main(int argc, char* argv[]) {
+
+    /// By default, error condition will throw exception.
+    try {
+        ClientInvoker client;
+        client.set_cli(true); // output log and file commands to standard out
+        (void)client.invoke(CommandLine(argc, argv));
+    }
+    catch (std::exception& e) {
+        std::cerr << e.what() << std::endl;
+        return 1;
+    }
+    return 0;
+}
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientOptions.cpp 5.13.0-1/libs/client/src/ecflow/client/ClientOptions.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientOptions.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientOptions.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,302 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+///
+/// \brief Delegates argument parsing to the registered commands
+///
+
+#include "ecflow/client/ClientOptions.hpp"
+
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/program_options.hpp>
+
+#include "ecflow/base/ClientOptionsParser.hpp"
+#include "ecflow/base/cts/task/TaskApi.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/Help.hpp"
+#include "ecflow/core/CommandLine.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/PasswordEncryption.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+namespace po = boost::program_options;
+
+static std::string print_variable_map(const boost::program_options::variables_map& vm);
+
+ClientOptions::ClientOptions() {
+    // This could have been moved to parse(). However since the same ClienttInvoker can be
+    // be used for multiple commands. We have separated out the parts the need only be done once.
+    // hence improving the performance:
+    std::string title_help = "Client options, ";
+    title_help += Version::description();
+    title_help += "   ";
+    desc_ = new po::options_description(title_help, po::options_description::m_default_line_length + 80);
+
+    // This will iterate over all the registered client to server commands and
+    // Each command will add to the option description, its required arguments
+    cmdRegistry_.addAllOptions(*desc_);
+
+    // Allow the host,port and rid to be  overridden by the command line
+    // This allows the jobs, which make other calls to ecflow_client from interfering with each other
+    // clang-format off
+    desc_->add_options()(
+        "rid",
+        po::value<string>()->implicit_value(string("")),
+        "When specified overrides the environment variable ECF_RID. Can only be used for child commands.");
+    desc_->add_options()(
+        "port",
+        po::value<string>()->implicit_value(string("")),
+        "When specified overrides the environment variable ECF_PORT and default port: '3141'");
+    desc_->add_options()(
+        "host",
+        po::value<string>()->implicit_value(string("")),
+        "When specified overrides the environment variable ECF_HOST and default host: 'localhost'");
+    desc_->add_options()(
+        "user",
+        po::value<string>()->implicit_value(string("")),
+        "Specifies the user name used to contact the server. Must be used in combination with option --password.");
+    desc_->add_options()(
+        "password",
+        po::value<string>()->implicit_value(string("")),
+        "Specifies the password used to contact the server. Must be used in combination with option --user.");
+#ifdef ECF_OPENSSL
+    desc_->add_options()(
+        "ssl",
+        "Enables the use of SSL when contacting the server.\n"
+        "When specified overrides the environment variable ECF_SSL.");
+#endif
+    // clang-format on
+}
+
+ClientOptions::~ClientOptions() {
+    delete desc_;
+}
+
+Cmd_ptr ClientOptions::parse(const CommandLine& cl, ClientEnvironment* env) const {
+    // We expect two hyphen/minus, However sometimes we get a weird/rogue kind of hyphen
+    // This rogue hyphen can mess up the parsing.
+    // # ecflow_client ––group="halt=yes; check_pt; terminate=yes"  // *BAD* hyphens 2 of them
+    // # ecflow_client –-group="halt=yes; check_pt; terminate=yes"  // *BAD* hyphens 1 of them, i.e. first
+    // # ecflow_client --group="halt=yes; check_pt; terminate=yes"  // *GOOD*
+    //
+    //   dec:  -30 ffffffe2 37777777742 \342
+    //   hex: -128 ffffff80 37777777600 \200
+    //   oct: -109 ffffff93 37777777623 \223
+    //
+    // The correct hyphen has:
+    //   dec:45 hex:2D oct:55 -
+    if (env->debug()) {
+        cout << "  ClientOptions::parse " << cl << "\n";
+        std::cout << "  help column width = " << po::options_description::m_default_line_length + 80 << "\n";
+    }
+
+    // parse arguments into 'vm'.
+    //       --alter delete cron -w 0,1 10:00 /s1     # -w treated as option
+    //       --alter=/s1 change meter name -1         # -1 treated as option
+    // Note: negative numbers get treated as options: i.e trying to change meter value to a negative number
+    //       To avoid negative numbers from being treated as option use, we need to change command line style:
+    //       po::command_line_style::unix_style ^ po::command_line_style::allow_short
+    boost::program_options::variables_map vm;
+
+    // 1) Parse the CLI options
+    po::parsed_options parsed_options = po::command_line_parser(cl.tokens())
+                                            .options(*desc_)
+                                            .style(po::command_line_style::default_style)
+                                            .extra_style_parser(ClientOptionsParser{})
+                                            .run();
+
+    // 2) Store the CLI options into the variable map
+    po::store(parsed_options, vm);
+    po::notify(vm);
+
+    // If explicitly requested by user, set environment in DEBUG mode
+    if (vm.count("debug")) {
+        env->set_debug(true);
+    }
+
+    // Check to see if host or port, specified. This will override the environment variables
+    std::string host, port;
+    if (vm.count("port")) {
+        port = vm["port"].as<std::string>();
+        if (env->debug())
+            std::cout << "  port " << port << " overridden at the command line\n";
+        try {
+            ecf::convert_to<int>(port);
+        }
+        catch (ecf::bad_conversion& e) {
+            std::stringstream ss;
+            ss << "ClientOptions::parse: The specified port(" << port << ") must be convertible to an integer";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    if (vm.count("host")) {
+        host = vm["host"].as<std::string>();
+        if (env->debug())
+            std::cout << "   host " << host << " overridden at the command line\n";
+    }
+    if (!host.empty() || !port.empty()) {
+        if (host.empty())
+            host = env->hostSpecified(); // get the environment variable ECF_HOST
+        if (port.empty())
+            port = env->portSpecified(); // get the environment variable ECF_PORT || Str::DEFAULT_PORT_NUMBER()
+        if (host.empty())
+            host = Str::LOCALHOST(); // if ECF_HOST not specified default to localhost
+        if (port.empty())
+            port = Str::DEFAULT_PORT_NUMBER(); // if ECF_PORT not specified use default
+        env->set_host_port(host, port);
+    }
+    if (vm.count("rid")) {
+        std::string rid = vm["rid"].as<std::string>();
+        if (env->debug())
+            std::cout << "  rid " << rid << " overridden at the command line\n";
+        env->set_remote_id(rid);
+    }
+    if (vm.count("user")) {
+        std::string user = vm["user"].as<std::string>();
+        if (env->debug())
+            std::cout << "  user " << user << " overridden at the command line\n";
+        env->set_user_name(user);
+    }
+    if (vm.count("password")) {
+        std::string password = vm["password"].as<std::string>();
+        if (env->debug())
+            std::cout << "  password overridden at the command line\n";
+        env->set_password(PasswordEncryption::encrypt(password, env->get_user_name()));
+    }
+
+#ifdef ECF_OPENSSL
+    if (vm.count("ssl")) {
+        if (env->debug())
+            std::cout << "  ssl set via command line\n";
+        env->enable_ssl();
+    }
+#endif
+
+    // Defer the parsing of the command , to the command. This allows
+    // all cmd functionality to be centralised with the command
+    // This can throw std::runtime_error if arg's don't parse
+    Cmd_ptr client_request;
+    if (!cmdRegistry_.parse(client_request, vm, env)) {
+
+        // The arguments did *NOT* match with any of the registered command.
+        // Hence, if arguments don't match help, debug or version it's an error
+        // Note: we did *NOT* check for a NULL client_request since *NOT* all
+        //       requests need to create it. Some commands are client specific.
+        //       For example:
+        //         --server_load         // this is sent to server
+        //         --server_load=<path>  // no command returned, command executed by client
+        if (vm.count("help")) {
+            string topic = vm["help"].as<std::string>();
+            std::cout << Help{*desc_, topic};
+            return client_request;
+        }
+
+        if (vm.count("version")) {
+            cout << Version::description() << "\n";
+            exit(0);
+        }
+
+        std::stringstream ss;
+        ss << print_variable_map(vm) << "\n";
+        ss << "ClientOptions::parse: Arguments did not match any commands.\n";
+        ss << "  argc=" << cl.size() << "\n";
+        for (size_t i = 0; i < cl.size(); i++) {
+            const std::string& arg = cl.tokens()[i];
+            ss << "  arg" << i << "=" << arg;
+
+            for (size_t s = 0; s < arg.size(); s++) {
+                if (static_cast<int>(arg[s]) < 0) {
+                    ss << "\nUnrecognised character not in ASCII range(0-127) " << std::dec << "dec("
+                       << static_cast<int>(arg[s]) << ") char:" << arg[s];
+                    ss << " found at index " << s << " for string '" << arg << "'\n";
+                    if (static_cast<int>(arg[s]) == -30)
+                        ss << "check for bad hyphen/minus";
+                    throw std::runtime_error(ss.str());
+                }
+            }
+        }
+        ss << "\nUse --help to see all the available commands\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    return client_request;
+}
+
+static std::string print_variable_map(const boost::program_options::variables_map& vm) {
+    std::stringstream ss;
+    ss << "boost::program_options::variables_map:    vm.size() " << vm.size() << "\n";
+    for (po::variables_map::const_iterator it = vm.begin(); it != vm.end(); it++) {
+        std::cout << "> " << it->first;
+        if (((boost::any)it->second.value()).empty())
+            ss << "(empty)";
+        if (vm[it->first].defaulted() || it->second.defaulted())
+            ss << "(default)";
+
+        ss << "=";
+
+        bool is_char;
+        try {
+            boost::any_cast<const char*>(it->second.value());
+            is_char = true;
+        }
+        catch (const boost::bad_any_cast&) {
+            is_char = false;
+        }
+        bool is_str;
+        try {
+            boost::any_cast<std::string>(it->second.value());
+            is_str = true;
+        }
+        catch (const boost::bad_any_cast&) {
+            is_str = false;
+        }
+
+        if (((boost::any)it->second.value()).type() == typeid(int)) {
+            ss << vm[it->first].as<int>() << std::endl;
+        }
+        else if (((boost::any)it->second.value()).type() == typeid(bool)) {
+            ss << vm[it->first].as<bool>() << std::endl;
+        }
+        else if (((boost::any)it->second.value()).type() == typeid(double)) {
+            ss << vm[it->first].as<double>() << std::endl;
+        }
+        else if (is_char) {
+            ss << vm[it->first].as<const char*>() << std::endl;
+        }
+        else if (is_str) {
+            std::string temp = vm[it->first].as<std::string>();
+            if (temp.size()) {
+                ss << temp << std::endl;
+            }
+            else {
+                ss << "true" << std::endl;
+            }
+        }
+        else { // Assumes that the only remainder is vector<string>
+            try {
+                std::vector<std::string> vect = vm[it->first].as<std::vector<std::string>>();
+                size_t i                      = 0;
+                for (std::vector<std::string>::iterator oit = vect.begin(); oit != vect.end(); oit++, ++i) {
+                    ss << "\r> " << it->first << "[" << i << "]=" << (*oit) << std::endl;
+                }
+            }
+            catch (const boost::bad_any_cast&) {
+                ss << "UnknownType(" << ((boost::any)it->second.value()).type().name() << ")" << std::endl;
+            }
+        }
+    }
+    return ss.str();
+}
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/ClientOptions.hpp 5.13.0-1/libs/client/src/ecflow/client/ClientOptions.hpp
--- 5.12.4-1/libs/client/src/ecflow/client/ClientOptions.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/ClientOptions.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_ClientOptions_HPP
+#define ecflow_client_ClientOptions_HPP
+
+#include "ecflow/base/cts/CtsCmdRegistry.hpp"
+class ClientEnvironment;
+class CommandLine;
+
+///
+/// \brief Will parse the client argument line, and construct a command that will be sent to the server.
+///
+/// The environment must be read in before the program options. The program options
+/// will construct the commands, some of which require the environment
+/// We could have just done this as last part of constructor. However we need a
+/// separation between reading the environment and reading the option for:
+/// a/ testing purposes. i.e as this allows us to inject/override the task path
+///    read in from the environment.
+/// b/ override host and port number.
+/// will throw std::runtime_error for invalid arguments
+///
+
+class ClientOptions {
+public:
+    ClientOptions(const ClientOptions&)                  = delete;
+    const ClientOptions& operator=(const ClientOptions&) = delete;
+
+    /// Will create command register, & ask each cmd to describe their arguments
+    ClientOptions();
+    ~ClientOptions();
+
+    /// parse the arguments and create the client request that is to be sent
+    /// to the server. Will throw std::runtime_error if invalid arguments specified
+    Cmd_ptr parse(const CommandLine& cl, ClientEnvironment*) const;
+
+private:
+    CtsCmdRegistry cmdRegistry_;
+    boost::program_options::options_description* desc_;
+};
+
+#endif /* ecflow_client_ClientOptions_HPP */
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/Help.cpp 5.13.0-1/libs/client/src/ecflow/client/Help.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/Help.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/Help.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,329 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/client/Help.hpp"
+
+#include <iomanip>
+
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+
+namespace /* __anonymous__ */ {
+
+using description_t = boost::program_options::option_description;
+using options_t     = std::vector<boost::shared_ptr<boost::program_options::option_description>>;
+
+struct CommandFilter
+{
+    template <typename PREDICATE>
+    static void select_by(options_t& options, PREDICATE select) {
+        // filter non-command options
+        options_t filtered;
+        std::copy_if(std::begin(options),
+                     std::end(options),
+                     std::back_inserter(filtered),
+                     [&select](const auto& description) { return select(description->long_name()); });
+
+        // consider only filtered options
+        std::swap(options, filtered);
+    }
+
+    static bool is_option(const std::string& value) {
+        return std::find(std::begin(known_options), std::end(known_options), value) != std::end(known_options);
+    }
+
+    static bool is_user_command(const std::string& value) { return !is_option(value) && !is_task_command(value); }
+
+    static bool is_task_command(const std::string& value) { return ecf::Child::valid_child_cmd(value); }
+
+    static bool is_command(const std::string& value) { return is_task_command(value) || is_user_command(value); }
+
+private:
+    constexpr static std::array known_options{"add", "debug", "host", "password", "port", "rid", "ssl", "user"};
+};
+
+const char* client_env_description =
+    "The client reads in the following environment variables. These are read by user and child command\n\n"
+    "|----------|----------|------------|-------------------------------------------------------------------|\n"
+    "| Name     |  Type    | Required   | Description                                                       |\n"
+    "|----------|----------|------------|-------------------------------------------------------------------|\n"
+    "| ECF_HOST | <string> | Mandatory* | The host name of the main server. defaults to 'localhost'         |\n"
+    "| ECF_PORT |  <int>   | Mandatory* | The TCP/IP port to call on the server. Must be unique to a server |\n"
+#ifdef ECF_OPENSSL
+    "| ECF_SSL  |  <any>   | Optional*  | Enable encrypted comms with SSL enabled server.                   |\n"
+#endif
+    "|----------|----------|------------|-------------------------------------------------------------------|"
+    "\n\n"
+    "* The host and port must be specified in order for the client to communicate with the server, this can \n"
+    "  be done by setting ECF_HOST, ECF_PORT or by specifying --host=<host> --port=<int> on the command line\n";
+
+const char* client_task_env_description =
+    "The following environment variables are specific to child commands.\n"
+    "The scripts should export the mandatory variables. Typically defined in the head/tail includes files\n\n"
+    "|--------------|----------|-----------|---------------------------------------------------------------|\n"
+    "| Name         |  Type    | Required  | Description                                                   |\n"
+    "|--------------|----------|-----------|---------------------------------------------------------------|\n"
+    "| ECF_NAME     | <string> | Mandatory | Full path name to the task                                    |\n"
+    "| ECF_PASS     | <string> | Mandatory | The jobs password, allocated by server, then used by server to|\n"
+    "|              |          |           | authenticate client request                                   |\n"
+    "| ECF_TRYNO    |  <int>   | Mandatory | The number of times the job has run. This is allocated by the |\n"
+    "|              |          |           | server, and used in job/output file name generation.          |\n"
+    "| ECF_RID      | <string> | Mandatory | The process identifier. Helps zombies identification and      |\n"
+    "|              |          |           | automated killing of running jobs                             |\n"
+    "| ECF_TIMEOUT  |  <int>   | optional  | Max time in *seconds* for client to deliver message to main   |\n"
+    "|              |          |           | server. The default is 24 hours                               |\n"
+    "| ECF_HOSTFILE | <string> | optional  | File that lists alternate hosts to try, if connection to main |\n"
+    "|              |          |           | host fails                                                    |\n"
+    "| ECF_DENIED   |  <any>   | optional  | Provides a way for child to exit with an error, if server     |\n"
+    "|              |          |           | denies connection. Avoids 24hr wait. Note: when you have      |\n"
+    "|              |          |           | hundreds of tasks, using this approach requires a lot of      |\n"
+    "|              |          |           | manual intervention to determine job status                   |\n"
+    "| NO_ECF       |  <any>   | optional  | If set exit's ecflow_client immediately with success. This    |\n"
+    "|              |          |           | allows the scripts to be tested independent of the server     |\n"
+    "|--------------|----------|-----------|---------------------------------------------------------------|\n";
+
+int get_options_max_width(const options_t& options) {
+    size_t vec_size  = options.size();
+    size_t max_width = 0;
+    for (size_t i = 0; i < vec_size; i++) {
+        max_width = std::max(max_width, options[i]->long_name().size());
+    }
+    max_width += 1;
+    return static_cast<int>(max_width);
+}
+
+void sort_options_by_long_name(options_t& options) {
+    std::sort(
+        options.begin(), options.end(), [](const auto& a, const auto& b) { return a->long_name() < b->long_name(); });
+}
+
+class Documentation {
+public:
+    using descriptions_t = boost::program_options::options_description;
+
+    explicit Documentation(const descriptions_t& descriptions) : descriptions_{descriptions} {}
+
+    void show(std::ostream& os, const std::string& topic) const;
+
+private:
+    void show_help(std::ostream& os) const;
+    void show_list_options(std::ostream& os) const;
+    void show_all_commands_summary(std::ostream& os, std::string_view title) const;
+    void show_task_commands_summary(std::ostream& os, std::string_view title) const;
+    void show_user_commands_summary(std::ostream& os, std::string_view title) const;
+    void show_options_summary(std::ostream& os, std::string_view title) const;
+    void show_command_help(std::ostream& os, const std::string& command) const;
+    void show_all_commands(std::ostream& os, std::string_view title) const;
+    void show_all_options(std::ostream& os) const;
+
+    template <typename PREDICATE>
+    void show_table(std::ostream& os, PREDICATE select, size_t columns) const;
+
+    template <typename PREDICATE>
+    void show_summary(std::ostream& os, PREDICATE select) const;
+
+    static std::string get_name_kind(const std::string& name) {
+        if (CommandFilter::is_option(name)) {
+            return "option  ";
+        }
+        else if (CommandFilter::is_task_command(name)) {
+            return "child   ";
+        }
+        else if (CommandFilter::is_user_command(name)) {
+            return "user    ";
+        }
+        else {
+            throw std::runtime_error("Unable to determine the kind of option/command");
+        }
+    }
+
+private:
+    const descriptions_t& descriptions_;
+};
+
+void Documentation::show(std::ostream& os, const std::string& topic) const {
+    // WARNING!!
+    //   This assumes that there are no user/child commands named: 'summary', 'all', 'child', 'user'
+    //
+
+    if (topic.empty()) {
+        show_help(os);
+    }
+    else if (topic == "all") {
+        show_list_options(os);
+    }
+    else if (topic == "summary") {
+        show_all_commands_summary(os, "\nEcflow client commands:\n");
+    }
+    else if (topic == "child") {
+        show_task_commands_summary(os, "\nEcflow child client commands:\n");
+    }
+    else if (topic == "user") {
+        show_user_commands_summary(os, "\nEcflow user client commands:\n");
+    }
+    else if (topic == "option") {
+        show_options_summary(os, "\nEcflow generic options:\n");
+    }
+    else {
+        show_command_help(os, topic);
+    }
+}
+
+void Documentation::show_help(std::ostream& os) const {
+    os << "\nClient/server based work flow package:\n\n";
+    os << ecf::Version::description() << "\n\n";
+    os << Ecf::CLIENT_NAME() << " provides the command line interface, for interacting with the server:\n";
+
+    os << "Try:\n\n";
+    os << "   " << Ecf::CLIENT_NAME() << " --help=all       # List all commands, verbosely\n";
+    os << "   " << Ecf::CLIENT_NAME() << " --help=summary   # One line summary of all commands\n";
+    os << "   " << Ecf::CLIENT_NAME() << " --help=child     # One line summary of child commands\n";
+    os << "   " << Ecf::CLIENT_NAME() << " --help=user      # One line summary of user command\n";
+    os << "   " << Ecf::CLIENT_NAME() << " --help=<cmd>     # Detailed help on each command\n\n";
+
+    show_all_commands(os, "Commands:");
+
+    show_all_options(os);
+}
+
+void Documentation::show_list_options(std::ostream& os) const {
+    os << descriptions_ << "\n";
+}
+
+template <typename PREDICATE>
+void Documentation::show_table(std::ostream& os, PREDICATE select, size_t columns) const {
+    // take a copy, since we need to sort
+    options_t options = descriptions_.options();
+
+    // filter for real commands
+    CommandFilter::select_by(options, select);
+
+    // sort using long_name
+    sort_options_by_long_name(options);
+
+    size_t max_width = get_options_max_width(options);
+    for (size_t i = 0; i < options.size(); i++) {
+        if (i == 0 || i % columns == 0) {
+            os << "\n   ";
+        }
+        os << std::left << std::setw(max_width) << options[i]->long_name();
+    }
+    os << "\n\n";
+}
+
+template <typename PREDICATE>
+void Documentation::show_summary(std::ostream& os, PREDICATE select) const {
+
+    // take a copy, since we need to sort
+    options_t options = descriptions_.options();
+
+    // filter for real commands
+    CommandFilter::select_by(options, select);
+
+    // sort using long_name
+    sort_options_by_long_name(options);
+
+    int max_width = get_options_max_width(options);
+    for (const auto& option : options) {
+        std::vector<std::string> lines;
+        ecf::Str::split(option->description(), lines, "\n");
+        if (!lines.empty()) {
+            std::string name = option->long_name();
+            os << "  " << std::left << std::setw(max_width) << name << " ";
+            os << Documentation::get_name_kind(name);
+            os << lines[0] << "\n";
+        }
+    }
+    os << "\n";
+}
+
+void Documentation::show_all_commands_summary(std::ostream& os, std::string_view title) const {
+    os << title << '\n';
+    show_summary(os, CommandFilter::is_command);
+}
+
+void Documentation::show_task_commands_summary(std::ostream& os, std::string_view title) const {
+    os << title << '\n';
+    show_summary(os, CommandFilter::is_task_command);
+}
+
+void Documentation::show_user_commands_summary(std::ostream& os, std::string_view title) const {
+    os << title << '\n';
+    show_summary(os, CommandFilter::is_user_command);
+}
+
+void Documentation::show_options_summary(std::ostream& os, std::string_view title) const {
+    os << title << '\n';
+    show_summary(os, CommandFilter::is_option);
+}
+
+void Documentation::show_command_help(std::ostream& os, const std::string& command) const {
+    // Help on individual command
+    const boost::program_options::option_description* od =
+        descriptions_.find_nothrow(command,
+                                   true,  /* approx, will find nearest match */
+                                   false, /* long_ignore_case = false*/
+                                   false  /* short_ignore_case = false*/
+        );
+    if (od) {
+        os << "\n";
+        os << od->long_name() << "\n";
+        for (size_t i = 0; i < od->long_name().size(); i++) {
+            os << "-";
+        }
+        os << "\n\n";
+        os << od->description() << "\n\n";
+        if (!CommandFilter::is_option(od->long_name())) {
+            os << client_env_description;
+            if (ecf::Child::valid_child_cmd(od->long_name())) {
+                os << "\n";
+                os << client_task_env_description;
+            }
+        }
+    }
+    else {
+        show_all_commands(os, "No matching command found, please choose from:");
+    }
+}
+
+void Documentation::show_all_commands(std::ostream& os, std::string_view title) const {
+    os << title << "\n";
+    show_table(os, CommandFilter::is_command, 5);
+}
+
+void Documentation::show_all_options(std::ostream& os) const {
+    os << "Generic Options:\n";
+    show_table(os, CommandFilter::is_option, 8);
+}
+
+} // namespace
+
+struct Help::Impl
+{
+    Documentation documentation_;
+    std::string topic_;
+
+    Impl(const descriptions_t& descriptions, std::string topic)
+        : documentation_(descriptions),
+          topic_(std::move(topic)) {}
+};
+
+Help::Help(const descriptions_t& descriptions, const std::string& topic)
+    : impl_(std::make_unique<Help::Impl>(descriptions, topic)) {
+}
+
+Help::~Help() = default;
+
+std::ostream& operator<<(std::ostream& os, const Help& help) {
+    help.impl_->documentation_.show(os, help.impl_->topic_);
+    return os;
+}
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/Help.hpp 5.13.0-1/libs/client/src/ecflow/client/Help.hpp
--- 5.12.4-1/libs/client/src/ecflow/client/Help.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/Help.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_Help_HPP
+#define ecflow_client_Help_HPP
+
+#include <memory>
+
+#include <boost/program_options.hpp>
+
+class Help {
+public:
+    using descriptions_t = boost::program_options::options_description;
+
+    Help(const descriptions_t& descriptions, const std::string& topic);
+    ~Help();
+
+    friend std::ostream& operator<<(std::ostream& os, const Help& help);
+
+private:
+    struct Impl;
+    std::unique_ptr<Impl> impl_;
+};
+
+#endif /* ecflow_client_Help_HPP */
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/Rtt.cpp 5.13.0-1/libs/client/src/ecflow/client/Rtt.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/Rtt.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/Rtt.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,170 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/client/Rtt.hpp"
+
+#include <iostream>
+#include <stdexcept>
+#include <vector>
+
+#include <boost/date_time/posix_time/posix_time.hpp> //include all types plus i/o
+
+#include "ecflow/core/File.hpp"
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+namespace ecf {
+
+Rtt* Rtt::instance_ = nullptr;
+
+void Rtt::create(const std::string& filename) {
+    if (instance_ == nullptr) {
+        instance_ = new Rtt(filename);
+    }
+}
+
+void Rtt::destroy() {
+    delete instance_;
+    instance_ = nullptr;
+}
+
+Rtt::Rtt(const std::string& filename) : file_(filename.c_str(), ios::out | ios::app) {
+    if (!file_.is_open()) {
+        std::cerr << "Rtt::Rtt Could not open file '" << filename << "'\n";
+        throw std::runtime_error("Rtt::Rtt: Could not open file " + filename);
+    }
+}
+
+Rtt::~Rtt() = default;
+
+void Rtt::log(const std::string& message) {
+    file_ << message << endl;
+}
+
+void rtt(const std::string& message) {
+    if (Rtt::instance()) {
+        Rtt::instance()->log(message);
+    }
+}
+
+std::string Rtt::analyis(const std::string& filename) {
+    std::vector<std::string> lines;
+    if (!File::splitFileIntoLines(filename, lines)) {
+        std::cout << "Rtt::analyis: could not open file " << filename << " (" << strerror(errno) << ")\n";
+        return string();
+    }
+
+    // Typical format
+    // localhost:3141 --ping :ma0 rtt:00:00:00.001082
+    // localhost:3141 --log=new Test/data/ECF_HOME/test_wait_cmd/test_wait_cmd.def_log  :ma0 rtt:00:00:00.000930
+    // localhost:3141 --zombie_get :ma0 rtt:00:00:00.003982
+
+    /// Extract the command name and time, and add to map, to compute averages, min,max & standard deviation
+    map<string, vector<time_duration>> cmd_time_map;
+    size_t max_cmd_size = 0;
+    for (auto& line : lines) {
+
+        if (line.empty())
+            continue;
+        //      cout << i << ":" << lines[i] << "   ";
+        string::size_type dash    = line.find("--");
+        string::size_type rtt_pos = line.find(Rtt::tag());
+        if (dash == std::string::npos)
+            continue;
+        if (rtt_pos == std::string::npos)
+            continue;
+
+        int cmd_length           = 0;
+        string::size_type equals = line.find("=", dash);
+        string::size_type space  = line.find(" ", dash);
+        if (equals != std::string::npos)
+            cmd_length = equals;
+        else if (space != std::string::npos)
+            cmd_length = space;
+        string cmd   = line.substr(0, cmd_length);
+        max_cmd_size = std::max(max_cmd_size, cmd.size());
+
+        string time = line.substr(rtt_pos + 4);
+        time_duration td(duration_from_string(time));
+        //      cout << "  cmd:(" << cmd << ") time(" << to_simple_string(td) << ")\n";
+
+        auto cmd_iterator = cmd_time_map.find(cmd);
+        if (cmd_iterator == cmd_time_map.end()) {
+            vector<time_duration> vec;
+            vec.push_back(td);
+            std::pair<string, vector<time_duration>> p = std::make_pair(cmd, vec);
+            cmd_time_map.insert(p);
+        }
+        else {
+            (*cmd_iterator).second.push_back(td);
+        }
+    }
+
+    time_duration total(0, 0, 0, 0);
+    int total_requests = 0;
+
+    // Create title
+    std::stringstream ss;
+    ss << left << setw(max_cmd_size + 1) << "Command" << right << setw(5) << "count" << setw(9) << "min" << setw(9)
+       << "average" << setw(9) << "max" << setw(9) << right << "std\n";
+    for (std::pair<string, vector<time_duration>> p : cmd_time_map) {
+
+        time_duration average_td(0, 0, 0, 0);
+        time_duration min(24, 59, 59, 0);
+        time_duration max(0, 0, 0, 0);
+        for (const auto& i : p.second) {
+            average_td += i;
+            total_requests++;
+            total += i;
+            min = std::min(min, i);
+            max = std::max(max, i);
+        }
+
+        ss << left << setw(max_cmd_size + 1) << p.first << setw(5) << right << p.second.size();
+        if (p.second.empty()) {
+            ss << setw(9) << right << p.second[0].total_microseconds() << " ? ";
+        }
+        else if (p.second.size() == 1) {
+            ss << setw(9) << right << p.second[0].total_microseconds();
+        }
+        else {
+            int average = average_td.total_microseconds() / p.second.size();
+
+            //          bool debug = false;
+            //          if (p.first == "begin")   debug = true;
+
+            // compute standard deviation
+            unsigned int total_diff_from_avg = 0;
+            for (auto& i : p.second) {
+                int diff         = i.total_microseconds() - average;
+                int diff_squared = diff * diff;
+                total_diff_from_avg += diff_squared;
+                //             if (debug) cout << "diff: " << diff << " diff_squared: " << diff_squared << "
+                //             total_diff_from_avg: " << total_diff_from_avg << "\n";
+            }
+
+            double avg = total_diff_from_avg / p.second.size();
+            auto stdd  = (int)sqrt(avg);
+            //          if (debug) cout << "avg: " << avg << " stdd: " << stdd << "\n";
+
+            ss << setw(9) << right << min.total_microseconds();
+            ss << setw(9) << right << average;
+            ss << setw(9) << right << max.total_microseconds();
+            ss << setw(9) << right << stdd;
+        }
+        ss << "\n";
+    }
+    ss << "\ntotal round trip time " << to_simple_string(total) << " for " << total_requests << " requests\n";
+    return ss.str();
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/Rtt.hpp 5.13.0-1/libs/client/src/ecflow/client/Rtt.hpp
--- 5.12.4-1/libs/client/src/ecflow/client/Rtt.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/Rtt.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_Rtt_HPP
+#define ecflow_client_Rtt_HPP
+
+#include <fstream>
+#include <sstream>
+#include <string>
+
+///
+/// \brief Simple client based singleton for recording round trip times of all client based command
+///
+
+namespace ecf {
+
+class Rtt {
+public:
+    Rtt(const Rtt&)                  = delete;
+    const Rtt& operator=(const Rtt&) = delete;
+
+    static void create(const std::string& filename);
+    static void destroy();
+    static Rtt* instance() { return instance_; }
+
+    void log(const std::string& message);
+
+    /// Open the file, and create average times for all client invoker round trip times
+    static std::string analyis(const std::string& filename);
+
+    /// Used in output and parsing, when computing averages
+    static const char* tag() { return "rtt:"; }
+
+private:
+    ~Rtt();
+    explicit Rtt(const std::string& filename);
+    static Rtt* instance_;
+    mutable std::ofstream file_;
+};
+
+void rtt(const std::string& message);
+
+// allow user to do the following:
+// RTT("this is " << path << " ok ");
+//
+// helper, see STRINGIZE() macro
+template <typename Functor>
+std::string stringize_rtt(Functor const& f) {
+    std::ostringstream out;
+    f(out);
+    return out.str();
+}
+#define STRINGIZE_RTT(EXPRESSION) (ecf::stringize_rtt([](std::ostringstream& os) { os << EXPRESSION };))
+#define RTT(EXPRESSION) ecf::rtt(STRINGIZE_RTT(EXPRESSION))
+} // namespace ecf
+#endif
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/UrlCmd.cpp 5.13.0-1/libs/client/src/ecflow/client/UrlCmd.cpp
--- 5.12.4-1/libs/client/src/ecflow/client/UrlCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/UrlCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/client/UrlCmd.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+
+UrlCmd::UrlCmd(defs_ptr defs, const std::string& absNodePath) : defs_(defs), node_(nullptr) {
+    if (!defs_.get()) {
+        throw std::runtime_error("UrlCmd: The definition parameter is empty");
+    }
+
+    if (absNodePath.empty()) {
+        throw std::runtime_error("UrlCmd: The node path parameter is empty");
+    }
+
+    node_ = defs_->findAbsNode(absNodePath).get();
+    if (!node_) {
+        std::string errorMsg = "UrlCmd: The node path parameter '";
+        errorMsg += absNodePath;
+        errorMsg += "' cannot be found.";
+        throw std::runtime_error(errorMsg);
+    }
+}
+
+std::string UrlCmd::getUrl() const {
+    std::string url;
+    node_->findParentUserVariableValue("ECF_URL_CMD", url);
+    if (url.empty()) {
+        std::string errorMsg = "UrlCmd: Could not find variable ECF_URL_CMD from node ";
+        errorMsg += node_->absNodePath();
+        throw std::runtime_error(errorMsg);
+    }
+
+    if (!node_->variableSubstitution(url)) {
+        std::string errorMsg = "UrlCmd:: Variable substitution failed for ";
+        errorMsg += url;
+        throw std::runtime_error(errorMsg);
+    }
+    return url;
+}
+
+void UrlCmd::execute() const {
+    // invoke as a system command, we don't use System::instance()
+    // since this is on the client side. hence no need manage the spawned process
+    system(getUrl().c_str());
+}
diff -pruN 5.12.4-1/libs/client/src/ecflow/client/UrlCmd.hpp 5.13.0-1/libs/client/src/ecflow/client/UrlCmd.hpp
--- 5.12.4-1/libs/client/src/ecflow/client/UrlCmd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/src/ecflow/client/UrlCmd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_UrlCmd_HPP
+#define ecflow_client_UrlCmd_HPP
+
+#include <string>
+
+#include "ecflow/node/NodeFwd.hpp"
+
+///
+/// \note Client side command only.
+/// \note Placed in this category, since the server does not need to link with it.
+///
+
+class UrlCmd {
+public:
+    UrlCmd()              = delete;
+    UrlCmd(const UrlCmd&) = delete;
+    UrlCmd(UrlCmd&&)      = delete;
+
+    /// Will throw std::runtime_error if defs or node path is not correct
+    UrlCmd(defs_ptr defs, const std::string& absNodePath);
+
+    UrlCmd& operator=(const UrlCmd&) = delete;
+    UrlCmd& operator=(UrlCmd&&)      = delete;
+
+    /// Will throw std::runtime_error if url cannot be formed
+    std::string getUrl() const;
+
+    /// Execute the url command
+    void execute() const;
+
+private:
+    defs_ptr defs_;
+    Node* node_;
+};
+
+#endif /* ecflow_client_UrlCmd_HPP */
diff -pruN 5.12.4-1/libs/client/test/InvokeServer.hpp 5.13.0-1/libs/client/test/InvokeServer.hpp
--- 5.12.4-1/libs/client/test/InvokeServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/InvokeServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,194 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_test_InvokeServer_HPP
+#define ecflow_client_test_InvokeServer_HPP
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/EcfPortLock.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Str.hpp"
+
+class InvokeServer {
+public:
+    InvokeServer()                    = delete;
+    InvokeServer(const InvokeServer&) = delete;
+    explicit InvokeServer(const std::string& msg,
+                          const std::string& port                      = ecf::Str::DEFAULT_PORT_NUMBER(),
+                          bool disable_job_generation                  = false,
+                          bool remove_checkpt_file_before_server_start = true,
+                          bool remove_checkpt_file_after_server_exit   = true)
+        : port_(port),
+          host_(ClientEnvironment::hostSpecified()),
+          remove_checkpt_file_after_server_exit_(remove_checkpt_file_after_server_exit) {
+        if (host_.empty()) {
+            if (!msg.empty()) {
+                std::cout << msg << "   port(" << port_ << ")";
+#ifdef ECF_OPENSSL
+                if (getenv("ECF_SSL"))
+                    std::cout << " (ssl)";
+#endif
+                std::cout << std::endl;
+            }
+
+            doStart(msg, port_, server_started_, disable_job_generation, remove_checkpt_file_before_server_start);
+        }
+        else {
+            // Start of test, clear any existing defs on remote/localhost server
+            // Assuming this has been started on input port
+            std::string test_name = msg;
+            test_name += " on ";
+            test_name += host_;
+            test_name += ecf::Str::COLON();
+            test_name += port_;
+
+            std::cout << test_name << std::endl;
+
+            ClientInvoker theClient(host_, port_);
+            theClient.logMsg(test_name);
+            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                                  CtsApi::to_string(CtsApi::delete_node())
+                                      << " failed should return 0. Should Delete ALL existing defs in the server\n"
+                                      << theClient.errorMsg());
+            server_started_ = true;
+        }
+    }
+
+    InvokeServer(const std::string& port,
+                 bool stop_ambiguaty,
+                 bool disable_job_generation                  = false,
+                 bool remove_checkpt_file_before_server_start = true,
+                 bool remove_checkpt_file_after_server_exit   = true)
+        : port_(port),
+          remove_checkpt_file_after_server_exit_(remove_checkpt_file_after_server_exit) {
+        // host_ is empty.
+        doStart("", port_, server_started_, disable_job_generation, remove_checkpt_file_before_server_start);
+    }
+
+    ~InvokeServer() {
+        // This will also remove the generated files.
+        // Will only terminate local server, host_ is *EMPTY* for local server, using two constructors above
+        if (host_.empty()) {
+            doEnd(ecf::Str::LOCALHOST(),
+                  port_,
+                  remove_checkpt_file_after_server_exit_,
+                  remove_log_file_after_server_exit_);
+        }
+    }
+
+    InvokeServer& operator=(const InvokeServer&) = delete;
+
+    const std::string& port() const { return port_; }
+    const std::string& host() const {
+        if (host_.empty())
+            return ecf::Str::LOCALHOST();
+        return host_;
+    }
+
+    std::string ecf_log_file() const { return host_name_.ecf_log_file(port_); }
+    std::string ecf_checkpt_file() const { return host_name_.ecf_checkpt_file(port_); }
+    std::string ecf_backup_checkpt_file() const { return host_name_.ecf_backup_checkpt_file(port_); }
+    bool server_started() const { return server_started_; }
+    void keep_log_file_after_server_exit() { remove_log_file_after_server_exit_ = false; }
+
+private:
+    static void doStart(const std::string& msg,
+                        const std::string& port,
+                        bool& server_started,
+                        bool disable_job_generation                  = false,
+                        bool remove_checkpt_file_before_server_start = true) {
+        /// Remove check pt and backup check pt file, else server will load it & remove log file
+        ecf::Host h;
+        if (remove_checkpt_file_before_server_start) {
+            fs::remove(h.ecf_checkpt_file(port));
+            fs::remove(h.ecf_backup_checkpt_file(port));
+        }
+        fs::remove(h.ecf_log_file(port));
+
+        // start the server in the background
+        std::string theServerInvokePath = ecf::File::find_ecf_server_path();
+        BOOST_REQUIRE_MESSAGE(!theServerInvokePath.empty(),
+                              "InvokeServer::doStart: `ecflow_server` executable must be available");
+        BOOST_REQUIRE_MESSAGE(fs::exists(theServerInvokePath),
+                              "InvokeServer::doStart: `ecflow_server` executable available at:" << theServerInvokePath);
+
+        // Create a port file. To avoid creating multiple servers on the same port number
+        ecf::EcfPortLock::create(port);
+
+        // Make sure server starts in the background to avoid hanging test
+        theServerInvokePath += " --port=" + port;
+        if (disable_job_generation) {
+            theServerInvokePath += " --dis_job_gen";
+        }
+        theServerInvokePath += " &";
+
+        // std::cout << "InvokeServer::doStart port = " << port << " server path = " <<  theServerInvokePath << "\n";
+        (void)system(theServerInvokePath.c_str());
+
+        // Allow time for server process to kick in.
+        ClientInvoker theClient(ecf::Str::LOCALHOST(), port);
+        if (theClient.wait_for_server_reply()) {
+            server_started = true;
+            if (!msg.empty())
+                theClient.logMsg(msg);
+        }
+        else {
+            server_started = false;
+        }
+    }
+
+    static void doEnd(const std::string& host,
+                      const std::string& port,
+                      bool remove_checkpt_file_after_server_exit,
+                      bool remove_log_file_after_server_exit) {
+        //    std::cout << "*****InvokeServer::doEnd    Closing server on  " << host << ecf::Str::COLON() << port <<
+        //    "\n";
+        {
+            ClientInvoker theClient(host, port);
+            BOOST_REQUIRE_NO_THROW(theClient.terminateServer());
+            BOOST_REQUIRE_MESSAGE(theClient.wait_for_server_death(), "Failed to terminate server after 60 seconds\n");
+        }
+
+        // remove port file. This prevented multiple different process from opening servers with same port number
+        ecf::EcfPortLock::remove(port);
+
+        // Remove generated file comment for debug
+        ecf::Host h;
+        if (remove_log_file_after_server_exit) {
+            fs::remove(h.ecf_log_file(port));
+            BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_log_file(port)),
+                                "log file " << h.ecf_log_file(port) << " not deleted\n");
+        }
+
+        if (remove_checkpt_file_after_server_exit) {
+            fs::remove(h.ecf_checkpt_file(port));
+            fs::remove(h.ecf_backup_checkpt_file(port));
+            BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_checkpt_file(port)),
+                                "file " << h.ecf_checkpt_file(port) << " not deleted\n");
+            BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_backup_checkpt_file(port)),
+                                "file " << h.ecf_backup_checkpt_file(port) << " not deleted\n");
+        }
+    }
+
+private:
+    std::string port_;
+    std::string host_;
+    ecf::Host host_name_;
+    bool remove_checkpt_file_after_server_exit_{true};
+    bool remove_log_file_after_server_exit_{true};
+    bool server_started_{false};
+};
+
+#endif /* ecflow_client_test_InvokeServer_HPP */
diff -pruN 5.12.4-1/libs/client/test/SCPort.cpp 5.13.0-1/libs/client/test/SCPort.cpp
--- 5.12.4-1/libs/client/test/SCPort.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/SCPort.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,95 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "SCPort.hpp"
+
+#include <iostream>
+
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/EcfPortLock.hpp"
+#include "ecflow/core/Str.hpp"
+
+namespace ecf {
+
+// init the globals. Note we dont use 3141, so that in the case where we already
+// have a remote/local server started external to the test, it does not clash
+// Also debug and release version use different port numbers to avoid clashes, if both tests run at same time
+
+#ifdef DEBUG
+int SCPort::thePort_ = 3161;
+#else
+int SCPort::thePort_ = 3144;
+#endif
+
+std::string SCPort::next() {
+    bool debug = false;
+    if (getenv("ECF_DEBUG_TEST"))
+        debug = true;
+
+    if (debug)
+        std::cout << "\nSCPort::next() : ";
+
+    // Allow parallel tests
+    char* ECF_FREE_PORT = getenv("ECF_FREE_PORT");
+    if (ECF_FREE_PORT) {
+        if (debug)
+            std::cout << " seed_port=ECF_FREE_PORT=(" << ECF_FREE_PORT << ")";
+        std::string port = ECF_FREE_PORT;
+        try {
+            thePort_ = ecf::convert_to<int>(port);
+        }
+        catch (...) {
+            std::cout << "SCPort::next()  ECF_FREE_PORT(" << ECF_FREE_PORT << ") not convertible to an integer\n";
+        }
+    }
+
+    // This is used to test remote servers(or legacy server with new client). Here ECF_HOST=localhost in the test
+    // scripts
+    std::string host = ClientEnvironment::hostSpecified();
+    if (debug)
+        std::cout << " ECF_HOST('" << host << "')";
+
+    if (host == Str::LOCALHOST()) {
+        char* ecf_port = getenv("ECF_PORT");
+        if (ecf_port) {
+            std::string port = ecf_port;
+            if (!port.empty()) {
+                if (debug)
+                    std::cout << " ECF_PORT('" << ecf_port << "')\n";
+                return port;
+            }
+        }
+        if (debug)
+            std::cout << " !!!!!! ERROR when ECF_HOST=localhost  EXPECTED ECF_PORT to be set !!!!!! ";
+    }
+
+    if (debug)
+        std::cout << "\n";
+    std::string the_port = next_only(debug);
+    if (debug)
+        std::cout << " SCPort::next() returning free port=" << the_port << "\n";
+    return the_port;
+}
+
+std::string SCPort::next_only(bool debug) {
+    if (debug)
+        std::cout << " SCPort::next_only : starting seed_port(" << thePort_ << ")\n";
+
+    // Use a combination of local lock file, and pinging the server
+    while (!EcfPortLock::is_free(thePort_, debug))
+        thePort_++;
+
+    if (debug)
+        std::cout << " SCPort::next_only() seed_port(" << thePort_ << ")\n";
+    return ClientInvoker::find_free_port(thePort_, debug);
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/client/test/SCPort.hpp 5.13.0-1/libs/client/test/SCPort.hpp
--- 5.12.4-1/libs/client/test/SCPort.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/SCPort.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_client_test_SCPort_HPP
+#define ecflow_client_test_SCPort_HPP
+
+#include <string>
+
+namespace ecf {
+
+// If two different process/servers both try to use the same port number, you
+// get an "Address in use" error, even if one the process is dead. This is
+// because the kernel does not immediately release the resource and there is
+// time out period. To get round this we will start the new server/client
+// and use a different port number.
+
+class SCPort {
+public:
+    /// Check ECF_HOST and ECF_PORT first, otherwise calls next_only
+    static std::string next();
+
+    /// make sure we have a unique port, each time next_only() is called;
+    static std::string next_only(bool debug = false);
+
+private:
+    SCPort()  = delete;
+    ~SCPort() = delete;
+
+    static int thePort_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_client_test_SCPort_HPP */
diff -pruN 5.12.4-1/libs/client/test/TestCheckPtDefsCmd.cpp 5.13.0-1/libs/client/test/TestCheckPtDefsCmd.cpp
--- 5.12.4-1/libs/client/test/TestCheckPtDefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestCheckPtDefsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,394 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "MyDefsFixture.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_CheckPtDefsCmd)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+// ************************************************************************************
+BOOST_AUTO_TEST_CASE(test_check_pt_defs_cmd) {
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+    InvokeServer invokeServer("Client:: ...test_check_pt_defs_cmd", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
+                                                  << theClient.errorMsg());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+
+    // First time. Should create a ecf_checkpt_file, but _no_ backup file
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                          CtsApi::checkPtDefs() << " failed should return 0\n"
+                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
+                          CtsApi::checkPtDefs() << " failed file(" << invokeServer.ecf_checkpt_file() << ") not saved");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
+                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
+                                                       << "), to have file size > 0");
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // This check only valid if server was invoked locally. Ignore for remote servers
+        BOOST_REQUIRE_MESSAGE(!fs::exists(invokeServer.ecf_backup_checkpt_file()),
+                              "Backup check point file(" << invokeServer.ecf_backup_checkpt_file()
+                                                         << ")should not exist,for very first time.");
+    }
+
+    // Save checkpoint file again. This should create a backup file, we should have ecf_checkpt_file and
+    // ecf_backup_checkpt_file
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                          CtsApi::checkPtDefs() << " failed should return 0\n"
+                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
+                          CtsApi::checkPtDefs()
+                              << " failed No check pt file(" << invokeServer.ecf_checkpt_file() << ") saved");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
+                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
+                                                       << ") to have file size > 0  ");
+    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_backup_checkpt_file()),
+                          "Backup check point file(" << invokeServer.ecf_backup_checkpt_file() << ") not created");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_backup_checkpt_file()) != 0,
+                          "Expected backup check point file(" << invokeServer.ecf_backup_checkpt_file()
+                                                              << "), to have file size > 0");
+
+    // Check the defaults for mode , interval and alarm time before making any changes
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
+                          " Expected default check pt mode to be ON_TIME");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == CheckPt::default_interval(),
+                          " Expected default check pt interval of "
+                              << CheckPt::default_interval() << " but found "
+                              << theClient.server_reply().stats().checkpt_interval_);
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // This check only valid if server was invoked locally. Ignore for remote servers
+        // From ecflow 4.7.0 checkpt_save_time_alarm went from 30 -> 20 seconds, hence will fail for old servers
+        BOOST_REQUIRE_MESSAGE(
+            theClient.server_reply().stats().checkpt_save_time_alarm_ == CheckPt::default_save_time_alarm(),
+            " Expected default check pt alarm time of " << CheckPt::default_save_time_alarm() << " but found "
+                                                        << theClient.server_reply().stats().checkpt_save_time_alarm_);
+    }
+
+    // Test change of check_pt interval and mode and alarm
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::NEVER) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::NEVER) << " failed should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::NEVER,
+                          " Expected check pt mode of NEVER");
+
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
+                                                                     << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
+                          " Expected check pt mode of ON_TIME");
+
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ALWAYS) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::ALWAYS) << " failed should return 0\n"
+                                                                    << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ALWAYS,
+                          " Expected check pt mode of ALWAYS");
+
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, 30) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME, 30) << " failed should return 0\n"
+                                                                         << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
+                          " Expected check pt mode of ON_TIME");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == 30,
+                          " Expected check pt interval of 30 but found "
+                              << theClient.server_reply().stats().checkpt_interval_);
+
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 56) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::UNDEFINED, 56) << " failed should return 0\n"
+                                                                           << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
+                          " Expected check pt mode of ON_TIME");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == 56,
+                          " Expected check pt interval of 56 but found "
+                              << theClient.server_reply().stats().checkpt_interval_);
+
+    // Mode and interval should remain unchanged only the alarm time should be changed
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 0, 10) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::UNDEFINED, 0, 10) << " failed should return 0\n"
+                                                                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
+                          " Expected check pt mode of ON_TIME");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == 56,
+                          " Expected check pt interval of 56 but found "
+                              << theClient.server_reply().stats().checkpt_interval_);
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_save_time_alarm_ == 10,
+                          " Expected check pt alarm time of 10 but found "
+                              << theClient.server_reply().stats().checkpt_save_time_alarm_);
+
+    // restore default check pointing for test that follow.
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, CheckPt::default_interval()) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
+                                                                     << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 0, CheckPt::default_save_time_alarm()) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
+                                                                     << theClient.errorMsg());
+
+    // check defaults were set
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_mode_ == ecf::CheckPt::ON_TIME,
+                          " Expected default check pt mode to be ON_TIME");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().stats().checkpt_interval_ == CheckPt::default_interval(),
+                          " Expected default check pt interval of "
+                              << CheckPt::default_interval() << " but found "
+                              << theClient.server_reply().stats().checkpt_interval_);
+    BOOST_REQUIRE_MESSAGE(
+        theClient.server_reply().stats().checkpt_save_time_alarm_ == CheckPt::default_save_time_alarm(),
+        " Expected default check pt alarm time of " << CheckPt::default_save_time_alarm() << " but found "
+                                                    << theClient.server_reply().stats().checkpt_save_time_alarm_);
+}
+
+BOOST_AUTO_TEST_CASE(test_restore_from_check_pt) {
+    InvokeServer invokeServer("Client:: ...test_restore_from_check_pt", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    defs_ptr the_defs = Defs::create();
+    the_defs->add_suite("s0");
+    the_defs->add_suite("s1");
+    the_defs->add_suite("s2");
+    the_defs->add_suite("s3");
+    the_defs->add_suite("s4");
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.load(the_defs) == 0, "load defs failed \n" << theClient.errorMsg());
+
+    size_t expected_no_of_suites = 5;
+    for (int i = 0; i < 5; i++) {
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                              CtsApi::checkPtDefs() << " failed should return 0\n"
+                                                    << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              "Expected delete all nodes to succeed\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0, "Expected halt server to succeed\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restoreDefsFromCheckPt() == 0, "Expected restoreDefsFromCheckPt succeed\n");
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0, "Expected getDefs() to succeed, i.e expected empty defs\n");
+        BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == expected_no_of_suites,
+                              "Expected " << expected_no_of_suites << " suites, after restoreDefsFromCheckPt but found "
+                                          << theClient.defs()->suiteVec().size() << "\n");
+
+        std::string suite = "/s" + ecf::convert_to<std::string>(i);
+        BOOST_REQUIRE_MESSAGE(theClient.delete_node(suite) == 0,
+                              "Expected delete single suite to succeed\n"
+                                  << theClient.errorMsg());
+        expected_no_of_suites--;
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_restore_from_check_pt_using_new_server) {
+    // This test relies on a NEW server invocation. Hence if ECF_HOST/remote server is used
+    // the test will will invalid. hence ignore.
+    if (!ClientEnvironment::hostSpecified().empty()) {
+        cout << "Client:: ...test_restore_from_check_pt_using_new_server: ignoring test when ECF_HOST specified\n";
+        return;
+    }
+
+    PrintStyle style(PrintStyle::STATE);
+    std::string port = SCPort::next();
+
+    MyDefsFixture theDefsFixture; // make sure generated server variable use this port.
+    defs_ptr defs_to_be_check_pointed = theDefsFixture.create_defs(port);
+
+    BOOST_REQUIRE_MESSAGE(defs_to_be_check_pointed->suiteVec().size() >= 2, "expected at least 2 suites");
+
+    {
+        // Start a new server. However make sure that on server exit, we not delete check pt files
+        InvokeServer invokeServer("Client:: ...test_restore_from_check_pt_using_new_server",
+                                  port,
+                                  false, /* bool disable_job_generation = false */
+                                  true,  /* bool remove_checkpt_file_before_server_start = true */
+                                  false  /* bool remove_checkpt_file_after_server_exit = true */
+        );
+        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+        BOOST_REQUIRE_MESSAGE(theClient.load(defs_to_be_check_pointed) == 0,
+                              "load defs failed \n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                              CtsApi::checkPtDefs() << " failed should\n"
+                                                    << theClient.errorMsg());
+    }
+
+    // start a new server, using same port. Make sure on start, we do not delete any checkpt files on start up
+    // server should *LOAD* check pt file on start up
+    InvokeServer invokeServer("", /* for debug use -new server- as msg */
+                              port,
+                              false, /* bool disable_job_generation = false */
+                              false, /* bool remove_checkpt_file_before_server_start = true */
+                              true   /* bool remove_checkpt_file_after_server_exit = true */
+    );
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Expected sync_local() to succeed \n");
+    BOOST_REQUIRE_MESSAGE(theClient.defs(), "Expected sync_local() to succeed defs is empty\n");
+
+    // To compare the defs, we need to massage theDefsFixture
+    // update server state to match server, and update flag, caused by restoreDefsFromCheckPt
+    defs_to_be_check_pointed->set_server().set_state(SState::HALTED);
+    defs_to_be_check_pointed->flag().set(ecf::Flag::MESSAGE);
+
+    // Specifically ignore server variables, as the port numbers are different( and therefore checkpt,log, etc will not
+    // match)
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    DebugEquality::set_ignore_server_variables(true);
+
+    BOOST_CHECK_MESSAGE(*theClient.defs() == *defs_to_be_check_pointed,
+                        "expected defs to be the same.\nServer defs:\n"
+                            << *theClient.defs() << "\nExpected defs:\n"
+                            << *defs_to_be_check_pointed);
+}
+
+BOOST_AUTO_TEST_CASE(test_check_pt_edit_history) {
+    // This test relies on a NEW server invocation. Hence if ECF_HOST/remote server is used
+    // the test will will invalid. hence ignore.
+    if (!ClientEnvironment::hostSpecified().empty()) {
+        cout << "Client:: ...test_check_pt_edit_history: ignoring test when ECF_HOST specified\n";
+        return;
+    }
+
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+    InvokeServer invokeServer("Client:: ...test_check_pt_edit_history", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
+                          CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
+                                                                                    << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 0,
+                          "Expected edit history of size 0 after server start, but found "
+                              << theClient.server_reply().get_string_vec().size());
+
+    // make 5 edits
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
+                                                  << theClient.errorMsg());
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+
+    // make sure edit history updated
+    BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
+                          CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
+                                                                                    << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 5,
+                          "Expected edit history of size 5, but found "
+                              << theClient.server_reply().get_string_vec().size());
+
+    // make sure edit history was *NOT* serialized, It is only serialized when check pointing
+    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->get_edit_history(Str::ROOT_PATH()).size() == 0,
+                          "Expected edit history of size 0, but found "
+                              << theClient.defs()->get_edit_history(Str::ROOT_PATH()).size());
+
+    // This should write the edit history
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                          CtsApi::checkPtDefs() << " failed should return 0\n"
+                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
+                          CtsApi::checkPtDefs()
+                              << " failed No check pt file(" << invokeServer.ecf_checkpt_file() << ") saved");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
+                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
+                                                       << ") to have file size > 0  ");
+
+    // Create a defs file from the check pt file & check edit history
+    {
+        Defs defs;
+        defs.restore(invokeServer.ecf_checkpt_file()); // restore defs from checkpoint
+        BOOST_REQUIRE_MESSAGE(defs.get_edit_history(Str::ROOT_PATH()).size() == 5,
+                              "Expected edit history of size 5, but found "
+                                  << defs.get_edit_history(Str::ROOT_PATH()).size());
+    }
+
+    {
+        // clear edit history
+        BOOST_REQUIRE_MESSAGE(theClient.edit_history("clear") == 0,
+                              CtsApi::to_string(CtsApi::edit_history("clear")) << " should return 0\n"
+                                                                               << theClient.errorMsg());
+
+        // write checkpoint file, NOTE: theClient.checkPtDefs(ecf::CheckPt::ALWAYS) *ONLY* changes the mode.
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                              CtsApi::checkPtDefs() << " failed should return 0\n"
+                                                    << theClient.errorMsg());
+
+        // restore defs from checkpoint file
+        Defs defs;
+        defs.restore(invokeServer.ecf_checkpt_file()); // restore defs from checkpoint
+        BOOST_REQUIRE_MESSAGE(defs.get_edit_history().size() == 0,
+                              "Expected edit history of size 0, but found " << defs.get_edit_history().size());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestClientEnvironment.cpp 5.13.0-1/libs/client/test/TestClientEnvironment.cpp
--- 5.12.4-1/libs/client/test/TestClientEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestClientEnvironment.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,153 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+#include <vector>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_ClientEnvironment)
+
+// **************************************************************************************
+// test the client environment:
+// In particular test host file parsing
+// **************************************************************************************
+BOOST_AUTO_TEST_CASE(test_client_environment_host_file_parsing) {
+    std::cout << "Client:: ...test_client_environment_host_file_parsing" << endl;
+
+    std::string good_host_file = File::test_data("libs/client/test/data/good_hostfile", "libs/client");
+
+    // local host should be implicitly added to internal host list
+    std::string the_host = ClientEnvironment::hostSpecified();
+    if (the_host.empty())
+        the_host = Str::LOCALHOST();
+
+    std::vector<std::string> expectedHost;
+    expectedHost.push_back(the_host);
+    expectedHost.emplace_back("host1");
+    expectedHost.emplace_back("host2");
+    expectedHost.emplace_back("host3");
+    expectedHost.emplace_back("host4");
+    expectedHost.emplace_back("host5");
+    expectedHost.emplace_back("host6");
+
+    ClientEnvironment client_env(good_host_file);
+    //	cout << "client_env " << client_env.toString() << "\n";
+    std::string home_host = client_env.host();
+    std::string host;
+    //	cout << "client_env home host " << client_env.host() << " job supplied port " << client_env.port() << "\n";
+    size_t count = 0;
+    BOOST_CHECK_MESSAGE(home_host == expectedHost[count],
+                        "Expected home host " << expectedHost[count] << " but found " << home_host);
+
+    bool home_host_fnd = false;
+    while (home_host != host) {
+        // Cycle through the host until we reach the home host
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
+        //	   cout << "client_env host " << client_env.host() << "  port " << client_env.port() << "\n";
+        host = client_env.host();
+        count++;
+        if (host == home_host) {
+            home_host_fnd = true;
+            count         = 0;
+        }
+        BOOST_REQUIRE_MESSAGE(count < expectedHost.size(), "Test file out of date");
+        BOOST_CHECK_MESSAGE(host == expectedHost[count],
+                            "Expected host " << expectedHost[count] << " but found " << host);
+    }
+    BOOST_CHECK_MESSAGE(home_host_fnd, "Cycling through host file, should lead to home host");
+}
+
+BOOST_AUTO_TEST_CASE(test_client_environment_host_file_defaults) {
+    std::cout << "Client:: ...test_client_environment_host_file_defaults" << endl;
+
+    // When the HOST file does *NOT* indicate the port, it should be taken
+    // from the config/environment.
+    // In file good_hostfile, host3 and host5 do not specify a port, hence
+    // this port is assumed to be the job supplied port, that was read from
+    // config or environment. To test this correctly we need to specify a port
+    // other than the default
+
+    std::string good_host_file = File::test_data("libs/client/test/data/good_hostfile", "libs/client");
+
+    // local host should be implicitly added to internal host list
+    std::vector<std::pair<std::string, std::string>> expectedHost;
+    expectedHost.emplace_back(Str::LOCALHOST(), string("5111")); // here 5111 is job supplied port
+    expectedHost.emplace_back(string("host1"), string("3142"));
+    expectedHost.emplace_back(string("host2"), string("3141"));
+    expectedHost.emplace_back(string("host3"), string("5111")); // not specified in host file, hence expect 5111
+    expectedHost.emplace_back(string("host4"), string("4001"));
+    expectedHost.emplace_back(string("host5"), string("5111")); // not specified in host file, hence expect 5111
+    expectedHost.emplace_back(string("host6"), string("4081"));
+
+    // Create the ClientEnvironment overriding the config & environment. To specify host and port
+    ClientEnvironment client_env(good_host_file, Str::LOCALHOST(), "5111");
+    //   cout << "client_env " << client_env.toString() << "\n";
+    std::string home_host = client_env.host();
+    std::string home_port = client_env.port();
+    BOOST_CHECK_MESSAGE(Str::LOCALHOST() == home_host && "5111" == home_port, "host host & port not as expected");
+
+    std::string host;
+    //   cout << "client_env home host " << client_env.host() << "  job supplied port " << client_env.port() << "\n";
+    size_t count       = 0;
+    bool home_host_fnd = false;
+    while (home_host != host) {
+        // Cycle through the host until we reach the home host
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
+        //      cout << "client_env host " << client_env.host() << "  port " << client_env.port() << "\n";
+        host             = client_env.host();
+        std::string port = client_env.port();
+        count++;
+        if (host == home_host) {
+            BOOST_CHECK_MESSAGE(count - 1 == 6,
+                                "Expected 6 hosts in host file"); // ignore last increment of count, hence -1
+            home_host_fnd = true;
+            count         = 0;
+        }
+        BOOST_REQUIRE_MESSAGE(count < expectedHost.size(), "Test file out of date");
+        BOOST_CHECK_MESSAGE(host == expectedHost[count].first,
+                            "Expected host " << expectedHost[count].first << " but found " << host);
+        BOOST_CHECK_MESSAGE(port == expectedHost[count].second,
+                            "Expected port " << expectedHost[count].second << " but found " << port);
+    }
+    BOOST_CHECK_MESSAGE(home_host_fnd, "Cycling through host file, should lead to home host");
+}
+
+BOOST_AUTO_TEST_CASE(test_client_environment_empty_host_file) {
+    std::cout << "Client:: ...test_client_environment_empty_host_file" << endl;
+
+    std::string empty_host_file = File::test_data("libs/client/test/data/empty_hostfile", "libs/client");
+
+    std::string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(empty_host_file, "", errormsg), "Failed to create empty host file " << errormsg);
+
+    ClientEnvironment client_env(empty_host_file);
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
+    BOOST_CHECK_MESSAGE(client_env.get_next_host(errorMsg), errorMsg);
+
+    fs::remove(empty_host_file);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestClientHandleCmd.cpp 5.13.0-1/libs/client/test/TestClientHandleCmd.cpp
--- 5.12.4-1/libs/client/test/TestClientHandleCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestClientHandleCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,75 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_ClientHandleCmd)
+
+BOOST_AUTO_TEST_CASE(test_client_handle_cmd) {
+    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+    InvokeServer invokeServer("Client:: ...test_client_handle_cmd ", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    theClient.set_auto_sync(true);
+
+    std::vector<std::string> suites = {"s1", "s2"};
+    defs_ptr defs                   = Defs::create();
+    for (auto s : suites) {
+        defs->add_suite(s);
+    }
+
+    BOOST_REQUIRE_MESSAGE(theClient.load(defs) == 0, "load defs failed \n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "load failed");
+
+    BOOST_REQUIRE_MESSAGE(theClient.ch1_register(true, suites) == 0, "ch1_register failed\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "register group sync failed");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 1, " ch1_register failed expected handle 1");
+
+    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0, "delete_all failed\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == 0, "delete all failed");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 0,
+                          "delete all failed expected handle 0 but found " << theClient.server_reply().client_handle());
+
+    // repeat test without auto_sync
+    theClient.set_auto_sync(false);
+    BOOST_REQUIRE_MESSAGE(theClient.load(defs) == 0, "load defs failed \n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "load failed");
+
+    BOOST_REQUIRE_MESSAGE(theClient.ch1_register(true, suites) == 0, "ch1_register failed\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == suites.size(), "register group sync failed");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 1, " ch1_register failed expected handle 1");
+
+    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0, "delete_all failed\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() == 0, "delete all failed");
+    BOOST_REQUIRE_MESSAGE(theClient.server_reply().client_handle() == 0,
+                          "delete all failed expected handle 0 but found " << theClient.server_reply().client_handle());
+
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestClientInterface.cpp 5.13.0-1/libs/client/test/TestClientInterface.cpp
--- 5.12.4-1/libs/client/test/TestClientInterface.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestClientInterface.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1577 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+#include <vector>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/base/cts/user/CFileCmd.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_ClientInterface)
+
+// **************************************************************************************
+// test the interface, this will create the cmd without actually submitting to the server
+// This will test argument parsing.
+// **************************************************************************************
+BOOST_AUTO_TEST_CASE(test_client_interface) {
+    std::cout << "Client:: ...test_client_interface" << endl;
+
+    ClientInvoker theClient;
+    theClient.testInterface(); // stops submission to server
+    std::vector<std::string> paths;
+    paths.emplace_back("/s1/t1");
+    paths.emplace_back("/s2/t2");
+
+    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.terminateServer() == 0,
+                          CtsApi::terminateServer() << " should return 0\n"
+                                                    << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.server_version() == 0,
+                          CtsApi::server_version() << " should return 0\n"
+                                                   << theClient.errorMsg());
+
+    {
+        defs_ptr dummy_defs = Defs::create();
+        BOOST_REQUIRE_MESSAGE(theClient.sync(dummy_defs) == 0,
+                              std::string(CtsApi::syncArg()) << " should return 0\n"
+                                                             << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.news(dummy_defs) == 0,
+                              std::string(CtsApi::newsArg()) << " should return 0\n"
+                                                             << theClient.errorMsg());
+    }
+
+    BOOST_REQUIRE_MESSAGE(theClient.server_load("/path/to_log/file") == 0,
+                          CtsApi::server_load("/path/to_log/file") << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.server_load() == 0,
+                          CtsApi::server_load("") << " should return 0\n"
+                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.pingServer() == 0,
+                          CtsApi::pingServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.debug_server_on() == 0,
+                          CtsApi::debug_server_on() << " should return 0\n"
+                                                    << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.debug_server_off() == 0,
+                          CtsApi::debug_server_off() << " should return 0\n"
+                                                     << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats() == 0, CtsApi::stats() << " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                          CtsApi::stats_server() << " should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.stats_reset() == 0,
+                          CtsApi::stats_reset() << " should return 0\n"
+                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.suites() == 0, CtsApi::suites() << " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0, CtsApi::get() << " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.begin("/suite") == 0,
+                          CtsApi::begin("/suite") << " should return 0\n"
+                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.begin("/suite", true) == 0,
+                          CtsApi::begin("/suite", true) << " should return 0\n"
+                                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.begin("/suite", false) == 0,
+                          CtsApi::begin("/suite", false) << " should return 0\n"
+                                                         << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.begin_all_suites() == 0,
+                          CtsApi::begin() << " should return 0\n"
+                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "next") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "prev") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("event", "/suite", "event") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("meter", "/suite", "meter") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("variable", "/suite", "var") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("trigger", "/suite", "1 == 1") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("state", "/suite", "") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("dstate", "/suite", "") == 0,
+                          CtsApi::queryArg() << " should return 0\n"
+                                             << theClient.errorMsg());
+
+    Zombie z(Child::USER,
+             ecf::Child::INIT,
+             ZombieAttr::get_default_attr(Child::USER),
+             "/path/to/task",
+             "DUMMY_JOBS_PASSWORD",
+             "DUMMY_PROCESS_OR_REMOTE_ID",
+             1,
+             "host");
+    BOOST_REQUIRE_MESSAGE(theClient.zombieGet() == 0,
+                          CtsApi::zombieGet() << " should return 0\n"
+                                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieFob(z) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieFail(z) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieAdopt(z) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieBlock(z) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieRemove(z) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieKill(z) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieFobCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieFailCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieAdoptCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieBlockCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieRemoveCli("/path/to/task") == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieKillCli("/path/to/task") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieFobCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieFailCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieAdoptCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieBlockCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieRemoveCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.zombieKillCliPaths(paths) == 0, " should return 0\n" << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.job_gen("") == 0,
+                          CtsApi::job_gen("") << " should return 0\n"
+                                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.job_gen("/s") == 0,
+                          CtsApi::job_gen("/s") << " should return 0\n"
+                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.check("") == 0,
+                          CtsApi::to_string(CtsApi::check("")) << " should return 0\n"
+                                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.check("/") == 0,
+                          CtsApi::to_string(CtsApi::check("/")) << " should return 0\n"
+                                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.check("_all_") == 0,
+                          CtsApi::to_string(CtsApi::check("_all_")) << " should return 0\n"
+                                                                    << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.check("/s") == 0,
+                          CtsApi::to_string(CtsApi::check("/s")) << " should return 0\n"
+                                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.check(paths) == 0,
+                          CtsApi::to_string(CtsApi::check(paths)) << " should return 0\n"
+                                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.kill("/s") == 0,
+                          CtsApi::to_string(CtsApi::kill("/s")) << " should return 0\n"
+                                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.kill(paths) == 0,
+                          CtsApi::to_string(CtsApi::kill(paths)) << " should return 0\n"
+                                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.status("/s") == 0,
+                          CtsApi::to_string(CtsApi::status("/s")) << " should return 0\n"
+                                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.status(paths) == 0,
+                          CtsApi::to_string(CtsApi::status(paths)) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.suspend("/s") == 0,
+                          CtsApi::to_string(CtsApi::suspend("/s")) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.suspend(paths) == 0,
+                          CtsApi::to_string(CtsApi::suspend(paths)) << " should return 0\n"
+                                                                    << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.resume("/s") == 0,
+                          CtsApi::to_string(CtsApi::resume("/s")) << " should return 0\n"
+                                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.resume(paths) == 0,
+                          CtsApi::to_string(CtsApi::resume(paths)) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.edit_history("/s") == 0,
+                          CtsApi::to_string(CtsApi::edit_history("/s")) << " should return 0\n"
+                                                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.edit_history("clear") == 0,
+                          CtsApi::to_string(CtsApi::edit_history("clear")) << " should return 0\n"
+                                                                           << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.archive("/s") == 0,
+                          CtsApi::to_string(CtsApi::archive("/s")) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.archive(paths) == 0,
+                          CtsApi::to_string(CtsApi::archive(paths)) << " should return 0\n"
+                                                                    << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.archive("/s", true) == 0,
+                          CtsApi::to_string(CtsApi::archive("/s", true)) << " should return 0\n"
+                                                                         << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.archive(paths, true) == 0,
+                          CtsApi::to_string(CtsApi::archive(paths, true)) << " should return 0\n"
+                                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restore("/s") == 0,
+                          CtsApi::to_string(CtsApi::restore("/s")) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restore(paths) == 0,
+                          CtsApi::to_string(CtsApi::restore(paths)) << " should return 0\n"
+                                                                    << theClient.errorMsg());
+
+    // empty string should be same as delete all
+    BOOST_REQUIRE_MESSAGE(theClient.delete_node("") == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_node("_all_") == 0,
+                          CtsApi::to_string(CtsApi::delete_node("_all")) << " should return 0\n"
+                                                                         << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_node("_all_", true) == 0,
+                          CtsApi::to_string(CtsApi::delete_node("_all", true)) << " should return 0\n"
+                                                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_node("_all_", false) == 0,
+                          CtsApi::to_string(CtsApi::delete_node("_all", false)) << " should return 0\n"
+                                                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_node("/s") == 0,
+                          CtsApi::to_string(CtsApi::delete_node("/s")) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_node("/s", true) == 0,
+                          CtsApi::to_string(CtsApi::delete_node("/s", true)) << " should return 0\n"
+                                                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_node("/s", false) == 0,
+                          CtsApi::to_string(CtsApi::delete_node("/s", false)) << " should return 0\n"
+                                                                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_nodes(paths, false) == 0,
+                          CtsApi::to_string(CtsApi::delete_node(paths, false)) << " should return 0\n"
+                                                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_nodes(paths, true) == 0,
+                          CtsApi::to_string(CtsApi::delete_node(paths, false)) << " should return 0\n"
+                                                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.requeue("/s", "") == 0,
+                          CtsApi::to_string(CtsApi::requeue("/s", "")) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.requeue("/s", "force") == 0,
+                          CtsApi::to_string(CtsApi::requeue("/s", "force")) << " should return 0\n"
+                                                                            << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.requeue("/s", "abort") == 0,
+                          CtsApi::to_string(CtsApi::requeue("/s", "abort")) << " should return 0\n"
+                                                                            << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.requeue(paths, "") == 0,
+                          CtsApi::to_string(CtsApi::requeue(paths, "")) << " should return 0\n"
+                                                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.requeue(paths, "force") == 0,
+                          CtsApi::to_string(CtsApi::requeue(paths, "force")) << " should return 0\n"
+                                                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.requeue(paths, "abort") == 0,
+                          CtsApi::to_string(CtsApi::requeue(paths, "abort")) << " should return 0\n"
+                                                                             << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.run("/s") == 0,
+                          CtsApi::to_string(CtsApi::run("/s")) << " should return 0\n"
+                                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.run("/s", true) == 0,
+                          CtsApi::to_string(CtsApi::run("/s", true)) << " should return 0\n"
+                                                                     << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.run(paths) == 0,
+                          CtsApi::to_string(CtsApi::run(paths)) << " should return 0\n"
+                                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.run(paths, true) == 0,
+                          CtsApi::to_string(CtsApi::run(paths, true)) << " should return 0\n"
+                                                                      << theClient.errorMsg());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, true /*force*/) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, true /*force*/, true /*check_only*/) == 0,
+                          "should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true, true) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, false, true) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "top") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "bottom") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "alpha") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "order") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "up") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.order("/s", "down") == 0, " should return 0\n" << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                          CtsApi::checkPtDefs() << " should return 0\n"
+                                                << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::NEVER) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, 180) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ALWAYS) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED, 0, 35) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restoreDefsFromCheckPt() == 0,
+                          CtsApi::restoreDefsFromCheckPt() << " should return 0\n"
+                                                           << theClient.errorMsg());
+
+    std::vector<std::string> event_paths;
+    event_paths.emplace_back("/s1:e");
+    event_paths.emplace_back("/s2/f1/t1:e");
+    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths[0], "set") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths[1], "clear") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths, "set") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.force(event_paths, "clear") == 0, " should return 0\n" << theClient.errorMsg());
+    std::vector<std::string> validStates = NState::allStates(); // HPUX barfs if use NState::allStates() directly
+    for (const string& state : validStates) {
+        BOOST_REQUIRE_MESSAGE(theClient.force("/s", state, true, true) == 0,
+                              "force " << state << " should return 0\n"
+                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force(paths, state, true, true) == 0,
+                              "force " << state << " should return 0\n"
+                                       << theClient.errorMsg());
+    }
+
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s") == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", true, true, true, true) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", true) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", false, true) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", false, false, true) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep("/s", false, false, false, true) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep(paths) == 0, " should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.freeDep(paths, true, true, true, true) == 0,
+                          " should return 0\n"
+                              << theClient.errorMsg());
+
+    std::vector<CFileCmd::File_t> fileTypesVec = CFileCmd::fileTypesVec();
+    for (auto& i : fileTypesVec) {
+        BOOST_REQUIRE_MESSAGE(theClient.file("/s", CFileCmd::toString(i), string("100")) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+    }
+
+    BOOST_REQUIRE_MESSAGE(theClient.plug("/source", "/dest") == 0, " should return 0\n" << theClient.errorMsg());
+
+    {
+        BOOST_REQUIRE_MESSAGE(theClient.getLog(10) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.clearLog() == 0,
+                              CtsApi::clearLog() << " should return 0\n"
+                                                 << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.flushLog() == 0,
+                              CtsApi::flushLog() << " should return 0\n"
+                                                 << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.get_log_path() == 0,
+                              CtsApi::get_log_path() << " should return 0\n"
+                                                     << theClient.errorMsg());
+
+        std::string new_log_path = File::test_data("libs/client/test/data/new_log.log", "libs/client");
+        BOOST_REQUIRE_MESSAGE(theClient.new_log(new_log_path) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.new_log("") == 0, " should return 0\n" << theClient.errorMsg());
+    }
+
+    BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
+                          CtsApi::reloadwsfile() << " should return 0\n"
+                                                 << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                          CtsApi::forceDependencyEval() << " should return 0\n"
+                                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.group("shutdown yes;halt yes;restart") == 0,
+                          "--group should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.group("shutdown=yes;halt=yes;restart") == 0,
+                          "--group should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show") == 0, "--group should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show state") == 0,
+                          "--group should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show defs") == 0, "--group should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.group("get ; show migrate") == 0,
+                          "--group should return 0\n"
+                              << theClient.errorMsg());
+
+    {
+        std::string path_to_script = "dummy_ecf_file" + File::ECF_EXTN();
+        std::string contents       = "%comment\n"
+                                     "VAR =  fred\n"
+                                     "%end\n"
+                                     "# rest of the ecf file\n";
+        std::string error_msg;
+        BOOST_CHECK_MESSAGE(File::create(path_to_script, contents, error_msg), error_msg);
+
+        std::vector<std::string> file_contents;
+        NameValueVec used_variables;
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script_edit("/s") == 0,
+                              "--edit_script_edit should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script_preprocess("/s") == 0,
+                              "--edit_script_preprocess should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script_preprocess("/s", file_contents) == 0,
+                              "--edit_script_preprocess should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script_submit("/s", used_variables) == 0,
+                              "--edit_script_submit should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script_submit("/s", used_variables, file_contents) == 0,
+                              "--edit_script_submit should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script_submit("/s", used_variables, file_contents, true /*alias*/) == 0,
+                              "--edit_script_submit should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(
+            theClient.edit_script_submit("/s", used_variables, file_contents, true /*alias*/, true /*run*/) == 0,
+            "--edit_script_submit should return 0\n"
+                << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "edit") == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "pre_process") == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit", path_to_script) == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script) == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, true) == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, false) == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, false, true) == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "submit_file", path_to_script, false, false) == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_script("/s", "pre_process_file", path_to_script) == 0,
+                              "--edit_script should return 0\n"
+                                  << theClient.errorMsg());
+        fs::remove(path_to_script);
+    }
+
+    {
+        std::vector<std::string> suites;
+        suites.emplace_back("a");
+        suites.emplace_back("b");
+        BOOST_REQUIRE_MESSAGE(theClient.ch_register(true, suites) == 0, "--ch_register \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_register(false, suites) == 0, "--ch_register \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_suites() == 0, "--ch_suites should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_drop(1) == 0, "--ch_drop should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_drop_user("user") == 0,
+                              "--ch_drop_user should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_add(1, suites) == 0, "--ch_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_remove(1, suites) == 0, "--ch_remove \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, true) == 0, "--ch_auto_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, false) == 0, "--ch_auto_add \n" << theClient.errorMsg());
+
+        // need test interface that allows client handle to set on ClinetInvoker
+        // ch1_add needs a non zero handle
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_register(true, suites) == 0, "--ch1_drop \n" << theClient.errorMsg());
+        auto& svr = const_cast<ServerReply&>(theClient.server_reply());
+        svr.set_client_handle(1);
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_drop() == 0, "--ch1_drop \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_add(suites) == 0, "--ch1_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_remove(suites) == 0, "--ch1_remove \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(true) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(false) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
+    }
+
+    {
+        defs_ptr theDefs = Defs::create();
+        theDefs->addSuite(Suite::create("s1"));
+        BOOST_REQUIRE_MESSAGE(theClient.load(theDefs) == 0, "-- load should return 0\n" << theClient.errorMsg());
+    }
+
+    /// test alter
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:fob::10") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:fob::") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf_pid:fob::") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf_passwd:fob::") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf_pid_passwd:fob::") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "user:fob::10") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "path:fob::10") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "path:fob::") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter(
+                              "/s1", "add", "zombie", "ecf:fob:init,event,meter,label,wait,complete,abort:10") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:fob:init,event,meter,label,wait,complete:10") ==
+                              0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter(
+                              "/s1", "add", "zombie", "ecf:fail:init,event,meter,label,wait,complete:10000") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter(
+                              "/s1", "add", "zombie", "ecf:adopt:init,event,meter,label,wait,complete:23") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter(
+                              "/s1", "add", "zombie", "ecf:remove:init,event,meter,label,wait,complete:0") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "zombie", "ecf:block:init,event,meter,label,wait,complete:") ==
+                              0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter(
+                              "/s1", "add", "zombie", "ecf:kill:init,event,meter,label,wait,complete:103333333") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+12:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:00 20:00 00:30") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "12:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "10:00 20:00 00:30") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.12.2009") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*.12.2009") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*.*.2009") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*.*.*") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "-") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "--") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "-- --") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "--fred") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "--fred --bill") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "value") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "name", "/value/with/path") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "name", "value") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "name", "/value/with/path2") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s +00:15 -a 20:00 -c +02:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -a 20:00 -c +02:00 -s +00:15") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -c +02:00 -a 20:00  -s +00:15") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s 00:02 -c +00:05") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s 00:01 -a 14:30 -c +00:01") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s +00:15 -a 20:00 -c +02:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-a 20:00 -c +02:00 -s +00:15") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-c +02:00 -a 20:00  -s +00:15") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s 00:02 -c +00:05") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s 00:01 -a 14:30 -c +00:01") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "limit", "limit_name", "10") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "limit_name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "limit_name", "10") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "/path/to/limit:limit_name2") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "inlimit", "/path/to/limit:limit_name2", "10") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "label", "name", "value") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "label", "name", "/value/with/paths") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+
+    for (const string& day : DayAttr::allDays()) {
+        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", day) == 0,
+                              "--alter should return 0\n"
+                                  << theClient.errorMsg());
+    }
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "variable") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "variable", "varName") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "variable", "varName", "/var/with/path/for/delete") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "variable") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "variable", "varName") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "variable", "varName", "/s1/with/path/for/delete") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+12:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:00 20:00 00:30") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "12:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "10:00 20:00 00:30") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.12.2009") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*.12.2009") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*.*.2009") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*.*.*") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day", "sunday") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "23:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "10:00 20:00 01:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0,1 10:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 10,11,12 12:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 10:00 20:00 01:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "1") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "meter", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "meter") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "trigger") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "complete") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "repeat") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit_path", "limit_name", "path") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit_path", "limit_name", "/path/with/slash") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "inlimit", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "zombie", "user") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "zombie", "ecf") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "zombie", "path") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "late") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "label", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "variable", "name", "newValue") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "variable", "name", "/new/value/with/path") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "variable", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "hybrid") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "real") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "12.6.2013") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "20") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_sync") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "22", "set") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "33", "clear") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "4") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name", "set") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name", "clear") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "20") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "-1") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "name", "newValue") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "name", "/value/with/path/ECFLOW-480") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "name", "") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "(t:step + 20) ge (t:step1 - 20)") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "/suite/fred == complete") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "/suite/fred:event") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "not ( a == complete )") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "/trigger/with/leading/slash == aborted") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "/trigger/with/leading/slash:event") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "repeat", "1") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "repeat", "blue") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_max", "limit_name", "12") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_value", "limit_name", "12") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s +00:15 -a 20:00 -c +02:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s 00:02 -c +00:05") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s 00:01 -a 14:30 -c +00:01") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a 20:00 -c +02:00") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-a 20:00 -c +02:00 -s +00:15") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-c +02:00 -a 20:00  -s +00:15") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+
+    std::vector<std::string> dstates = DState::allStates();
+    for (const auto& dstate : dstates) {
+        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "defstatus", dstate) == 0,
+                              "--alter should return 0\n"
+                                  << theClient.errorMsg());
+    }
+
+    std::vector<std::string> flag_types;
+    Flag::valid_flag_type(flag_types);
+    for (const auto& flag_type : flag_types) {
+        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "set_flag", flag_type) == 0,
+                              "--alter should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "clear_flag", flag_type) == 0,
+                              "--alter should return 0\n"
+                                  << theClient.errorMsg());
+    }
+
+    // sort
+    std::vector<std::string> sortable_attributes = Attr::all_attrs();
+    BOOST_REQUIRE_MESSAGE(!sortable_attributes.empty(), "Expected to find attributes");
+    for (const auto& sortable_attribute : sortable_attributes) {
+        BOOST_REQUIRE_MESSAGE(theClient.alter_sort("/s1", sortable_attribute, true) == 0,
+                              "--alter should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.alter_sort("/s1", sortable_attribute, false) == 0,
+                              "--alter should return 0\n"
+                                  << theClient.errorMsg());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_client_interface_for_fail) {
+    std::cout << "Client:: ...test_client_interface_for_fail" << endl;
+
+    ClientInvoker theClient;
+    theClient.testInterface(); // stops submission to server
+    theClient.set_throw_on_error(false);
+
+    std::vector<std::string> paths;
+    paths.emplace_back("/s1");
+    paths.emplace_back("/s2");
+
+    BOOST_REQUIRE_MESSAGE(theClient.check("fred") == 1,
+                          CtsApi::to_string(CtsApi::check("fred")) << " should return 1\n"
+                                                                   << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "deleted", "label", "name") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "changed", "late", "-c +02:00 -a 20:00  -s +00:15") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "added", "label", "name", "/value/with/paths") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    /// test alter
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "012:00") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "1200") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "fred") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:0020:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:00 2000 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+1000 20:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "+10:00 20:00 0030") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "time", "any old rubbish") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+10:0020:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+10:00 2000 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+1000 20:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "+10:00 20:00 0030") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "any old rubbish") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "today", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "0.12.2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.0.2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.12.g") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "*..2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12..2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "12.12.") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "fred") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "date", "any old rubbish") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", "frenday") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "day", "opps ") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "variable", "na me", "value") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "na me", "value") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "add", "variable", "", "value") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -a") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -c") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s +00:15 -a") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "late -s +00:15 -a 20:00 -c") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-a") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-c") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s +00:15 -a") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-s +00:15 -a 20:00 -c") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "late", "-c +02:000 -a 20:00  -s +00:15") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "add", "label", " 1 2") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "delete", "vari able", "varName") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "v ariable", "varName") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "l able", "name") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "label", "na me") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "012:00") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "1200") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "fred") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:0020:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:00 2000 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+1000 20:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "+10:00 20:00 0030") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "time", "any old rubbish") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+10:0020:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+10:00 2000 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+1000 20:00 00:30") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "+10:00 20:00 0030") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "today", "any old rubbish") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "0.12.2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.0.2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.12.g") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "*..2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12..2009") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "12.12.") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "fred") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "date", "any old rubbish") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day", "su nday") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "day", "fryday") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "any old rubbish") == 1,
+                          "Expected fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "2300") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "1000 20:00 01:00") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0,1 1000'") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 1000") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 10,11,12 1200") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 10,11,12") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-d 1200") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 10:00 20:00 01:000") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 10:00 20:00 0100") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w -m 20:00 01:00") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8 1000 20:00 01:00") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 20 -m 5,6,7,8 10:00 20:00 01:00") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "cron", "-w 0 -m 5,6,7,8,24 10:00 20:00 01:00") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "name df") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "event", "22  56  ") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "meter", "na me") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "limit", " name") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "delete", "inlimit", "na me") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "vari able", "name", "newValue") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "", "name", "/new/value/with/path") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "hyb rid") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "hybrid ") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "ybrid") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "re al") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_type", "rreal") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "*.6.2013") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "12.0.2013") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "any old rubbish") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_date", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "string") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "clock_gain", "fred") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "name", "fr ed") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "event", "na me") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "na me", "20") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "meter", "name", "-") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "label", "na me", "newValue") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "trigger", "t:step + 20) ge (t:step1 - 20)") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "complete", "not  a == complete )") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_max", "limit_  name", "12") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "limit_value", "limit_  name", "12") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "defstatus", "complete-34") == 1,
+                          "--alter expected to fail\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -s") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -a") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "late -c") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a 20:00 -c") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:15 -a 20:00 -c") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-s +00:152") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-c +00:152") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/s1", "change", "late", "-a +00:152") == 1,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.query("event", "/suite", "") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("meter", "/suite", "") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("variable", "/suite", "") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("trigger", "/suite", "") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("event", "", "event") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("meter", "", "meter") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("variable", "", "var") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("trigger", "", "1 == 1") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("xxxx", "/suite", "1 == 1") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("", "/suite", "1 == 1") == 1,
+                          std::string(CtsApi::queryArg()) << " should return 0\n"
+                                                          << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "xx") == 1,
+                          CtsApi::queryArg() << " should return 1\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "nextyyy") == 1,
+                          CtsApi::queryArg() << " should return 1\n"
+                                             << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.query("repeat", "/suite", "prevyyy") == 1,
+                          CtsApi::queryArg() << " should return 1\n"
+                                             << theClient.errorMsg());
+}
+
+BOOST_AUTO_TEST_CASE(test_client_task_interface) {
+    std::cout << "Client:: ...test_client_task_interface" << endl;
+
+    ClientInvoker theClient;
+    theClient.testInterface(); // stops submission to server
+    theClient.taskPath("/a/made/up/path");
+    theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
+
+    BOOST_REQUIRE_MESSAGE(theClient.initTask(Submittable::DUMMY_PROCESS_OR_REMOTE_ID()) == 0,
+                          "--init should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.abortTask("reason for abort") == 0,
+                          "--abort should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.eventTask("event_name", "set") == 0,
+                          "--event should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.eventTask("event_name", "clear") == 0,
+                          "--event should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.meterTask("meter_name", "20") == 0,
+                          "--meter should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.waitTask("a == complete") == 0, "--wait should return 0\n" << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "active") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "complete", "4") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "aborted", "4") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "no_of_aborted") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "reset") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "active", "", "/path/to/node/with/queue") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "complete", "4", "/path/to/node/with/queue") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "aborted", "4", "/path/to/node/with/queue") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "no_of_aborted", "", "/path/to/node/with/queue") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.queueTask("queue", "reset", "", "/path/to/node/with/queue") == 0,
+                          "--queue should return 0\n"
+                              << theClient.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0, "--complete should return 0\n" << theClient.errorMsg());
+    std::vector<std::string> labels;
+    labels.emplace_back("test_client_task_interface");
+    BOOST_REQUIRE_MESSAGE(theClient.labelTask("label_name", labels) == 0,
+                          "--label should return 0\n"
+                              << theClient.errorMsg());
+}
+
+BOOST_AUTO_TEST_CASE(test_client_task_interface_for_fail) {
+    std::cout << "Client:: ...test_client_task_interface_for_fail" << endl;
+
+    {
+        ClientInvoker theClient;
+        theClient.testInterface(); // stops submission to server
+        theClient.taskPath("/a/made/up/path");
+        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
+        BOOST_REQUIRE_THROW(theClient.waitTask("a == "),
+                            std::runtime_error); //  --wait with a bad expression 'a == ' should fail
+    }
+    { // No Jobs password expect exception.
+        ClientInvoker theClient;
+        theClient.testInterface(); // stops submission to server
+        theClient.taskPath("/a/made/up/path");
+        theClient.set_jobs_password(
+            ""); // The password(ECF_PASS) will be READ from the environment. Hence set to empty here
+
+        BOOST_REQUIRE_THROW(theClient.initTask(Submittable::DUMMY_PROCESS_OR_REMOTE_ID()), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.abortTask("reason for abort"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.eventTask("event_name"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.meterTask("meter_name", "20"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.waitTask("a == complete"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.completeTask(), std::runtime_error);
+        std::vector<std::string> labels;
+        labels.emplace_back("test_client_task_interface");
+        BOOST_REQUIRE_THROW(theClient.labelTask("label_name", labels), std::runtime_error);
+    }
+    {
+        ClientInvoker theClient;
+        theClient.testInterface(); // stops submission to server
+        theClient.taskPath("/a/made/up/path");
+        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
+
+        BOOST_REQUIRE_THROW(theClient.eventTask("", "set"), std::runtime_error);   // event name is empty
+        BOOST_REQUIRE_THROW(theClient.eventTask("event", ""), std::runtime_error); // value is empty must be set | clear
+        BOOST_REQUIRE_THROW(theClient.eventTask("event", "true"), std::runtime_error);  // value must be set | clear
+        BOOST_REQUIRE_THROW(theClient.eventTask("event", "false"), std::runtime_error); // value must be set | clear
+        BOOST_REQUIRE_THROW(theClient.meterTask("", "20"), std::runtime_error);         // meter name is empty
+        BOOST_REQUIRE_THROW(theClient.meterTask("meter", ""), std::runtime_error);      // meter value is empty
+        BOOST_REQUIRE_THROW(theClient.meterTask("meter", "fred"),
+                            std::runtime_error); // meter value not convertible to an integer
+    }
+    { // No task path set expect exception
+        ClientInvoker theClient;
+        theClient.testInterface(); // stops submission to server
+        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
+        theClient.taskPath(""); // The task path(ECF_NAME) could read from the environment, hence clear here.
+
+        BOOST_REQUIRE_THROW(theClient.initTask(Submittable::DUMMY_PROCESS_OR_REMOTE_ID()), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.abortTask("reason for abort"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.eventTask("event_name"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.meterTask("meter_name", "20"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.waitTask("a == complete"), std::runtime_error);
+        BOOST_REQUIRE_THROW(theClient.completeTask(), std::runtime_error);
+        std::vector<std::string> labels;
+        labels.emplace_back("test_client_task_interface");
+        BOOST_REQUIRE_THROW(theClient.labelTask("label_name", labels), std::runtime_error);
+    }
+    { // test bad queue
+        ClientInvoker theClient;
+        theClient.testInterface(); // stops submission to server
+        theClient.taskPath("/a/made/up/path");
+        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
+
+        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "fred"), std::runtime_error); // unknown action
+        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "active", "", "should be path"),
+                            std::runtime_error);                                           // bad path no '/'
+        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "complete"), std::runtime_error); // no step specified
+        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "complete", "3", "path"), std::runtime_error); // bad path
+        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "aborted"), std::runtime_error); // no step specified
+        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "aborted", "3", "path"), std::runtime_error); // bad path
+        BOOST_REQUIRE_THROW(theClient.queueTask("queue", "reset", "", "no path"),
+                            std::runtime_error); //  bad path no '/'
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestClientOptions.cpp 5.13.0-1/libs/client/test/TestClientOptions.cpp
--- 5.12.4-1/libs/client/test/TestClientOptions.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestClientOptions.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1347 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/base/cts/task/AbortCmd.hpp"
+#include "ecflow/base/cts/task/CompleteCmd.hpp"
+#include "ecflow/base/cts/task/CtsWaitCmd.hpp"
+#include "ecflow/base/cts/task/EventCmd.hpp"
+#include "ecflow/base/cts/task/InitCmd.hpp"
+#include "ecflow/base/cts/task/LabelCmd.hpp"
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+#include "ecflow/base/cts/task/QueueCmd.hpp"
+#include "ecflow/base/cts/user/AlterCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/PathsCmd.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/client/ClientOptions.hpp"
+#include "ecflow/core/CommandLine.hpp"
+#include "ecflow/core/PasswordEncryption.hpp"
+
+///
+/// \brief Tests the capabilities of ClientOptions
+///
+
+template <typename COMMAND, typename REQUIRE>
+void test_user_command(const CommandLine& cl, REQUIRE check) {
+    std::cout << "Testing command line: " << cl.original() << std::endl;
+
+    ClientOptions options;
+    ClientEnvironment environment(false);
+    try {
+        auto base_command    = options.parse(cl, &environment);
+        auto derived_command = dynamic_cast<COMMAND*>(base_command.get());
+
+        BOOST_REQUIRE(derived_command);
+        check(*derived_command, environment);
+    }
+    catch (boost::program_options::unknown_option& e) {
+        BOOST_CHECK_MESSAGE(false, std::string("Unexpected exception caught: ") + e.what());
+    }
+}
+
+template <typename COMMAND, typename REQUIRE>
+void test_task_command(const CommandLine& cl, REQUIRE check) {
+    std::cout << "Testing command line: " << cl.original() << std::endl;
+
+    ClientOptions options;
+    ClientEnvironment environment(false);
+    // Setup environment with some defaults
+    environment.set_child_path("/path/to/child");
+    environment.set_child_password("password");
+    try {
+        auto base_command    = options.parse(cl, &environment);
+        auto derived_command = dynamic_cast<COMMAND*>(base_command.get());
+
+        BOOST_REQUIRE(derived_command);
+        check(*derived_command, environment);
+    }
+    catch (boost::program_options::unknown_option& e) {
+        BOOST_CHECK_MESSAGE(false, std::string("Unexpected exception caught: ") + e.what());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_ClientOptions)
+
+BOOST_AUTO_TEST_SUITE(T_Generic) // test generic options
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_process_username_and_password) {
+    const char* expected_username = "username";
+    const char* plain_password    = "password";
+    std::string expected_password = PasswordEncryption::encrypt(plain_password, expected_username);
+
+    // Make command line
+    auto cl = CommandLine::make_command_line(
+        "ecflow_client", "--user", expected_username, "--password", plain_password, "--ping");
+
+    ClientOptions options;
+    ClientEnvironment environment(false);
+    options.parse(cl, &environment);
+
+    std::string actual_username = environment.get_user_name();
+    BOOST_REQUIRE(expected_username == actual_username);
+
+    std::string actual_password = environment.get_user_password(expected_username);
+    BOOST_REQUIRE(expected_password == actual_password);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Abort) // --abort (AbortCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_abort) {
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=somereason");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "somereason");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort", "some reason with spaces");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "some reason with spaces");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=some reason with spaces ");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "some reason with spaces ");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=some", "reason");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "some"); // Important: the reason is only "some"!
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort=--dashed reason");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "--dashed reason");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort", "--dashed reason");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "--dashed reason");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--abort", "--dashed reason", "--debug");
+        test_task_command<AbortCmd>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.reason(), "--dashed reason");
+            BOOST_CHECK(env.debug());
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Alter) // --alter (AlterCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_handle_alter_change) {
+
+    /*
+     * --alter change <type> <name> <value> <path> [<path>...]
+     * ************************************************************************************************************** */
+
+    std::vector<std::vector<std::string>> paths_set = {
+        {"/node1"}, {"/node1", "/node2"}, {"/node1", "/node2", "/node3"}};
+
+    for (const auto& paths : paths_set) {
+
+        using Expected = AlterCmd::Change_attr_type;
+
+        /*
+         * --alter change variable <name> <value> <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+
+        std::vector<std::string> variable_values = {"",
+                                                    "--dashes at beginning of value",
+                                                    "a value with --dashes inside",
+                                                    "    value starting with spaces",
+                                                    "value ending with spaces      ",
+                                                    "   some value surrounded by spaces      ",
+                                                    "/some/valid/path"};
+
+        for (const auto& value : variable_values) {
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "change", "variable", "name", value, paths);
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::VARIABLE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "change", "variable", "name", value, paths, "--debug");
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::VARIABLE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), true);
+                });
+            }
+        }
+
+        /*
+         * --alter change label <name> <value> <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        std::vector<std::string> label_values = {"",
+                                                 "--dashes at beginning of value",
+                                                 "a value with --dashes inside",
+                                                 "    value starting with spaces",
+                                                 "value ending with spaces      ",
+                                                 "   some value surrounded by spaces      ",
+                                                 "/some/valid/path"};
+
+        for (const auto& value : label_values) {
+            {
+                auto cl =
+                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "label", "name", value, paths);
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LABEL);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "change", "label", "name", value, paths, "--debug");
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LABEL);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), true);
+                });
+            }
+        }
+
+        /*
+         * --alter change event <name> <value> <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        // No value provided
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "change", "event", "name", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl =
+                CommandLine::make_command_line("ecflow_client", "--alter", "change", "event", "name", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+        // Explicitly provided value
+        std::vector<std::string> event_values = {"set", "clear"};
+        for (const auto& value : event_values) {
+            {
+                auto cl =
+                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "event", "name", value, paths);
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "change", "event", "name", value, paths, "--debug");
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::EVENT);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), true);
+                });
+            }
+        }
+
+        /*
+         * --alter change meter <name> <value> <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        std::vector<std::string> meter_values = {"0", "100"};
+        for (const auto& value : meter_values) {
+            {
+                auto cl =
+                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "meter", "name", value, paths);
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::METER);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "change", "meter", "name", value, paths, "--debug");
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::METER);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), true);
+                });
+            }
+        }
+
+        /*
+         * --alter change clock_type ( hybrid | real ) <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        std::vector<std::string> clock_type_values = {"hybrid", "real"};
+        for (const auto& value : clock_type_values) {
+            {
+                auto cl =
+                    CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_type", value, paths);
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), value);
+                    BOOST_REQUIRE_EQUAL(command.value(), "");
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_TYPE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "change", "clock_type", value, paths, "--port", "1234");
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), value);
+                    BOOST_REQUIRE_EQUAL(command.value(), "");
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_TYPE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "1234");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+        }
+
+        /*
+         * --alter change clock_gain <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        {
+            auto cl =
+                CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_gain", "2023.01.01", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "2023.01.01");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_GAIN);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line(
+                "ecflow_client", "--alter", "change", "clock_gain", "2023.01.01", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "2023.01.01");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_GAIN);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+
+        /*
+         * --alter change clock_sync <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_sync", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_SYNC);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl =
+                CommandLine::make_command_line("ecflow_client", "--alter", "change", "clock_sync", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::CLOCK_SYNC);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+
+        /*
+         * --alter change late <value>  <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        std::vector<std::string> late_values = {"late -s +00:15  -a  20:00  -c +02:00"};
+        for (const auto& value : late_values) {
+            {
+                auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "change", "late", value, paths);
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), value);
+                    BOOST_REQUIRE_EQUAL(command.value(), "");
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LATE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "change", "late", value, paths, "--debug");
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), value);
+                    BOOST_REQUIRE_EQUAL(command.value(), "");
+                    BOOST_REQUIRE_EQUAL(command.change_attr_type(), Expected::LATE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), true);
+                });
+            }
+        }
+
+    } // paths
+}
+
+BOOST_AUTO_TEST_CASE(test_is_able_handle_alter_add) {
+
+    /*
+     * --alter add <type> <name> <value> <path> [<path>...]
+     * ************************************************************************************************************** */
+
+    std::vector<std::vector<std::string>> paths_set = {
+        {"/node1"}, {"/node1", "/node2"}, {"/node1", "/node2", "/node3"}};
+
+    for (const auto& paths : paths_set) {
+
+        using Expected = AlterCmd::Add_attr_type;
+
+        std::vector<std::string> variable_values = {"",
+                                                    "--dashes at beginning of value",
+                                                    "a value with --dashes inside",
+                                                    "    value starting with spaces",
+                                                    "value ending with spaces      ",
+                                                    "   some value surrounded by spaces      ",
+                                                    "/some/valid/path"};
+
+        /*
+         * --alter add variable <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        for (const auto& value : variable_values) {
+            {
+                auto cl =
+                    CommandLine::make_command_line("ecflow_client", "--alter", "add", "variable", "name", value, paths);
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.add_attr_type(), Expected::ADD_VARIABLE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), false);
+                });
+            }
+            {
+                auto cl = CommandLine::make_command_line(
+                    "ecflow_client", "--alter", "add", "variable", "name", value, paths, "--debug");
+                test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                    BOOST_REQUIRE_EQUAL(command.name(), "name");
+                    BOOST_REQUIRE_EQUAL(command.value(), value);
+                    BOOST_REQUIRE_EQUAL(command.add_attr_type(), Expected::ADD_VARIABLE);
+                    BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                    for (size_t i = 0; i < paths.size(); ++i) {
+                        BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                    }
+                    BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                    BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                    BOOST_REQUIRE_EQUAL(env.debug(), true);
+                });
+            }
+        }
+    } // paths
+}
+
+BOOST_AUTO_TEST_CASE(test_is_able_handle_alter_delete) {
+    /*
+     * --alter delete <type> <name> <path> [<path>...]
+     * ************************************************************************************************************** */
+
+    std::vector<std::vector<std::string>> paths_set = {
+        {"/node1"}, {"/node1", "/node2"}, {"/node1", "/node2", "/node3"}};
+
+    for (const auto& paths : paths_set) {
+
+        using Expected = AlterCmd::Delete_attr_type;
+
+        /*
+         * --alter delete <type> <name> <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        // No explicit name, means delete all variables
+        {
+            auto cl =
+                CommandLine::make_command_line("ecflow_client", "--alter", "delete", "variable", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_VARIABLE);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "variable", "name", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_VARIABLE);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line(
+                "ecflow_client", "--alter", "delete", "variable", "name", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_VARIABLE);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+
+        /*
+         * --alter delete label <name> <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        // No explicit name, means delete all labels
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "label", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_LABEL);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "label", "name", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_LABEL);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl =
+                CommandLine::make_command_line("ecflow_client", "--alter", "delete", "label", "name", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_LABEL);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+
+        /*
+         * --alter delete event <name> <path> [<path>...]
+         * ---------------------------------------------------------------------------------------------------------- */
+        // No explicit name, means delete all events
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", "name", paths);
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), false);
+            });
+        }
+        {
+            auto cl =
+                CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", "name", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client",
+                                                     "--host=default",
+                                                     "--port",
+                                                     "8888",
+                                                     "--alter",
+                                                     "delete",
+                                                     "event",
+                                                     "name",
+                                                     paths,
+                                                     "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "default");
+                BOOST_REQUIRE_EQUAL(env.port(), "8888");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client",
+                                                     "--alter",
+                                                     "delete",
+                                                     "event",
+                                                     "name",
+                                                     paths,
+                                                     "--host",
+                                                     "default",
+                                                     "--debug",
+                                                     "--port",
+                                                     "8888");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "name");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "default");
+                BOOST_REQUIRE_EQUAL(env.port(), "8888");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+        {
+            auto cl = CommandLine::make_command_line("ecflow_client", "--alter", "delete", "event", paths, "--debug");
+            test_user_command<AlterCmd>(cl, [&](const AlterCmd& command, const ClientEnvironment& env) {
+                BOOST_REQUIRE_EQUAL(command.name(), "");
+                BOOST_REQUIRE_EQUAL(command.value(), "");
+                BOOST_REQUIRE_EQUAL(command.delete_attr_type(), Expected::DEL_EVENT);
+                BOOST_REQUIRE_EQUAL(command.paths().size(), paths.size());
+                for (size_t i = 0; i < paths.size(); ++i) {
+                    BOOST_REQUIRE(command.paths()[i] == paths[i]);
+                }
+                BOOST_REQUIRE_EQUAL(env.host(), "localhost");
+                BOOST_REQUIRE_EQUAL(env.port(), "3141");
+                BOOST_REQUIRE_EQUAL(env.debug(), true);
+            });
+        }
+    } // paths
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Begin) // --begin (BeginCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_begin) {
+    using Command = BeginCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--begin");
+        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.suiteName(), "");
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--begin=somesuite");
+        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.suiteName(), "somesuite");
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--begin=suite --force");
+        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.suiteName(), "suite");
+            BOOST_CHECK_EQUAL(command.force(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", R"(--begin="suite --force")");
+        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.suiteName(), "suite");
+            BOOST_CHECK_EQUAL(command.force(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--begin", "suite --force");
+        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.suiteName(), "suite");
+            BOOST_CHECK_EQUAL(command.force(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", R"(--begin="--force")");
+        test_task_command<Command>(cl, [&](const BeginCmd& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.suiteName(), "");
+            BOOST_CHECK_EQUAL(command.force(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--begin", "--force");
+        // This is an invalid, as --begin only takes a single argument (potentialy with --force as second value)
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Check) // --check (PathsCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_check) {
+    using Command = PathsCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--check=_all_");
+        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
+            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--check", "_all_");
+        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
+            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--check=/");
+        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
+            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--check", "/");
+        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
+            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(0));
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--check=/s1", "/s2/f2", "/s3/f3/t3");
+        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
+            BOOST_REQUIRE_EQUAL(command.paths().size(), static_cast<size_t>(3));
+            BOOST_CHECK_EQUAL(command.paths()[0], "/s1");
+            BOOST_CHECK_EQUAL(command.paths()[1], "/s2/f2");
+            BOOST_CHECK_EQUAL(command.paths()[2], "/s3/f3/t3");
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--check", "/s1", "/s2/f2", "/s3/f3/t3");
+        test_user_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.api(), PathsCmd::CHECK);
+            BOOST_CHECK_EQUAL(command.paths().size(), static_cast<size_t>(3));
+            BOOST_CHECK_EQUAL(command.paths()[0], "/s1");
+            BOOST_CHECK_EQUAL(command.paths()[1], "/s2/f2");
+            BOOST_CHECK_EQUAL(command.paths()[2], "/s3/f3/t3");
+            BOOST_CHECK_EQUAL(command.force(), false);
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Complete) // --complete (CompleteCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_complete) {
+    using Command = CompleteCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--complete");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK(command.variables_to_delete().empty());
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--complete", "--remove", "var1");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_REQUIRE_EQUAL(command.variables_to_delete().size(), static_cast<size_t>(1));
+            BOOST_REQUIRE_EQUAL(command.variables_to_delete()[0], "var1");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--complete", "--remove", "var1", "var2");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_REQUIRE_EQUAL(command.variables_to_delete().size(), static_cast<size_t>(2));
+            BOOST_REQUIRE_EQUAL(command.variables_to_delete()[0], "var1");
+            BOOST_REQUIRE_EQUAL(command.variables_to_delete()[1], "var2");
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Event) // --event (EventCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_event) {
+    using Command = EventCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--event=name");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--event", "name");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--event=name", "set");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--event", "name", "set");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), true);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--event=name", "clear");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), false);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--event", "name", "clear");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), false);
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Init) // --init (InitCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_init) {
+    using Command = InitCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--init=1234");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
+            BOOST_CHECK_EQUAL(command.variables_to_add().size(), static_cast<size_t>(0));
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--init", "1234");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
+            BOOST_CHECK_EQUAL(command.variables_to_add().size(), static_cast<size_t>(0));
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--init=1234", "--add", "name1=value1");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
+            BOOST_REQUIRE_EQUAL(command.variables_to_add().size(), static_cast<size_t>(1));
+            BOOST_CHECK_EQUAL(command.variables_to_add()[0].name(), "name1");
+            BOOST_CHECK_EQUAL(command.variables_to_add()[0].theValue(), "value1");
+        });
+    }
+    {
+        auto cl =
+            CommandLine::make_command_line("ecflow_client", "--init=1234", "--add", "name1=--value1", "name2=--value2");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.process_or_remote_id(), "1234");
+            BOOST_REQUIRE_EQUAL(command.variables_to_add().size(), static_cast<size_t>(2));
+            BOOST_CHECK_EQUAL(command.variables_to_add()[0].name(), "name1");
+            BOOST_CHECK_EQUAL(command.variables_to_add()[0].theValue(), "--value1");
+            BOOST_CHECK_EQUAL(command.variables_to_add()[1].name(), "name2");
+            BOOST_CHECK_EQUAL(command.variables_to_add()[1].theValue(), "--value2");
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Label) // --label (LabelCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_label) {
+    using Command = LabelCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "some value with spaces");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), "some value with spaces");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label", "name", "some value with spaces");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), "some value with spaces");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", R"(some "quoted" value)");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), R"(some "quoted" value)");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label", "name", R"(some "quoted" value)");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), R"(some "quoted" value)");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "-j64");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), "-j64");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--long-option");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), "--long-option");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--option=value");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), "--option=value");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--debug", "--debug");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), "--debug");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--label=name", "--port", "--debug", "--port", "123");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.label(), "--port");
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Meter) // --meter (MeterCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_meter) {
+    using Command = MeterCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "0");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), 0);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter", "name", "0");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), 0);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "-1");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), -1);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter", "name", "-1");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), -1);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "10");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), 10);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "20", "--debug");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), 20);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter", "name", "-20", "--debug");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), -20);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--meter=name", "-100", "--debug", "--port", "1234");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), -100);
+        });
+    }
+    {
+        auto cl =
+            CommandLine::make_command_line("ecflow_client", "--meter", "name", "-100", "--debug", "--port", "1234");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.value(), -100);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line(
+            "ecflow_client", "--port", "3141", "--host", "ecflow", "--meter", "step", "-1", "--debug");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "step");
+            BOOST_CHECK_EQUAL(command.value(), -1);
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line(
+            "ecflow_client", "--port", "3141", "--host", "ecflow", "--meter", "step", "-1", "--debug");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "step");
+            BOOST_CHECK_EQUAL(command.value(), -1);
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Queue) // --queue (QueueCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_queue) {
+    using Command = QueueCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "active");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "active");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "active");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "active");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "active", "/s/f/t");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "active");
+            BOOST_CHECK_EQUAL(command.path_to_node_with_queue(), "/s/f/t");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "complete", "42");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "complete");
+            BOOST_CHECK_EQUAL(command.step(), "42");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "complete", "42");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "complete");
+            BOOST_CHECK_EQUAL(command.step(), "42");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "aborted", "42");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "aborted");
+            BOOST_CHECK_EQUAL(command.step(), "42");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "aborted", "42");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "aborted");
+            BOOST_CHECK_EQUAL(command.step(), "42");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "no_of_aborted");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "no_of_aborted");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue", "name", "no_of_aborted");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "no_of_aborted");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "no_of_aborted", "/s/f/t");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "no_of_aborted");
+            BOOST_CHECK_EQUAL(command.path_to_node_with_queue(), "/s/f/t");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "reset");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "reset");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--queue=name", "reset", "/s/f/t");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.name(), "name");
+            BOOST_CHECK_EQUAL(command.action(), "reset");
+            BOOST_CHECK_EQUAL(command.path_to_node_with_queue(), "/s/f/t");
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_Wait) // --wait (WaitCmd)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_handle_wait) {
+    using Command = CtsWaitCmd;
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--wait=/suite/taskx == complete");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.expression(), "/suite/taskx == complete");
+        });
+    }
+    {
+        auto cl = CommandLine::make_command_line("ecflow_client", "--wait", "/suite/taskx == complete");
+        test_task_command<Command>(cl, [&](const auto& command, const ClientEnvironment& env) {
+            BOOST_CHECK_EQUAL(command.expression(), "/suite/taskx == complete");
+        });
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestClientTimeout.cpp 5.13.0-1/libs/client/test/TestClientTimeout.cpp
--- 5.12.4-1/libs/client/test/TestClientTimeout.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestClientTimeout.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_ClientTimeout)
+
+// ************************************************************************************
+// Note : If you make edits to node tree, they will have no effect until the server is rebuilt /
+// ************************************************************************************
+
+// This test will check the timeoout feature of the Client
+//
+// The timeout feature allows the client to fail gracefully in the case where the server has died/crashed.
+// After timeout, the socket is closed allowing the server to be restarted without getting the `address in use` error.
+//
+BOOST_AUTO_TEST_CASE(test_client_timeout, *boost::unit_test::disabled()) {
+
+    //
+    // Important: This test is disabled because ClientInvoker doesn't actually allow to set an overall timeout
+    //            Until this functionality is available, this test cannot be effectively implemented
+    //
+
+    // The following removes check pt and backup file before server start,
+    // to avoid the server from loading previous test data
+    InvokeServer invokeServer("Client:: ...test_client_timeout", SCPort::next());
+
+    // The timeout is configured to vary according the the client request
+    // however we can override for testing.
+    // Here we set a timeout for 1 second, then attempt to load a very large definition into the server.
+    // Note: the timeout of 1 second means we have 1 second for each communication, hence:
+    //    connect        : 1 second
+    //    send request   : 1 second
+    //    receive reply  : 1 second
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    theClient.set_connect_timeout(0);
+
+    std::string path = File::test_data("ANode/test/parser/data/single_defs/mega.def", "parser");
+    BOOST_REQUIRE_THROW(theClient.loadDefs(path),
+                        std::runtime_error); // Expect load defs to fail with a timeout of 1 second
+
+    /// Now see what timeout value we succeed with
+    bool loaded_defs = false;
+    for (int i = 2; i < 30; ++i) {
+        theClient.set_connect_timeout(i);
+        try {
+            cout << "Trying with timeout of " << i << " seconds\n";
+            theClient.loadDefs(path);
+            cout << "   loaded mega defs with a timeout of " << i << " seconds\n";
+            loaded_defs = true;
+            break;
+        }
+        catch (...) {
+        }
+    }
+    BOOST_REQUIRE_MESSAGE(loaded_defs, "Expected load of defs to succeed\n");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestClient_main.cpp 5.13.0-1/libs/client/test/TestClient_main.cpp
--- 5.12.4-1/libs/client/test/TestClient_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestClient_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Client
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/client/test/TestCustomUser.cpp 5.13.0-1/libs/client/test/TestCustomUser.cpp
--- 5.12.4-1/libs/client/test/TestCustomUser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestCustomUser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,159 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/PasswdFile.hpp"
+#include "ecflow/core/User.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_CustomUser)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+//
+// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
+//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
+//       is specified then *don't* shutdown the server
+// ************************************************************************************
+
+class Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env {
+public:
+    explicit Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env(const std::string& passwd_file)
+        : ecf_passwd_("ECF_CUSTOM_PASSWD="),
+          ecf_user_("ECF_USER=") {
+        ecf_passwd_ += passwd_file;
+        auto* put = const_cast<char*>(ecf_passwd_.c_str());
+        BOOST_CHECK_MESSAGE(putenv(put) == 0, "putenv failed for " << put);
+
+        ecf_user_ += User::login_name();
+        auto* put2 = const_cast<char*>(ecf_user_.c_str());
+        BOOST_CHECK_MESSAGE(putenv(put2) == 0, "putenv failed for " << put2);
+    }
+    ~Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env() {
+        putenv(const_cast<char*>("ECF_CUSTOM_PASSWD")); // remove from env, otherwise valgrind complains
+        putenv(const_cast<char*>("ECF_USER"));          // remove from env, otherwise valgrind complains
+    }
+
+private:
+    std::string ecf_passwd_;
+    std::string ecf_user_;
+};
+
+BOOST_AUTO_TEST_CASE(test_custom_user) {
+    Host the_host;
+    std::string host        = ClientEnvironment::hostSpecified();
+    std::string port        = SCPort::next();
+    std::string passwd_file = the_host.ecf_custom_passwd_file(port);
+    std::string passwd      = "xxxx";
+    if (host.empty()) {
+        // make sure NO passed file is present before the server is started.
+        // Only do this locally, as passwd file on remote machine may not be accessible
+        fs::remove(passwd_file);
+    }
+    else {
+        // The test only works if server is started locally.
+        std::cout << "...Client:: ...test_custom_user ignoring when HOST specified\n";
+        return;
+    }
+
+    {
+        // Create a valid passwd file; Before server start; make sure server closes before password file is deleted:
+        // cout << "\nCreating CUSTOM passwd_file " << passwd_file << "\n\n";
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(PasswdFile::createWithAccess(passwd_file, the_host.name(), port, passwd, errorMsg),
+                              errorMsg);
+        BOOST_REQUIRE_MESSAGE(fs::exists(passwd_file), "passwd file NOT created");
+    }
+
+    { // *** Need a separate scope so that server shuts down whilst password file is *STILL* present
+        // *** Otherwise terminate of server will fail. i.e ECF_PASSWORD is still valid
+
+        // Set ECF_USER and ECF_PASSWD environment variable. Use same file for client and server
+        // add on construction, and remove at destruction.
+        Add_ECF_CUSTOM_PASSWD_and_ECF_USER_env custom_user(passwd_file);
+
+        // This will remove check pt and backup file before server start,
+        // to avoid the server from loading previous test data
+        // make sure server closes before password file is deleted:
+        InvokeServer invokeServer("Client:: ...test_custom_user", port);
+        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+        theClient.set_throw_on_error(false);
+
+        // Invoking a client request that requires authorisation
+        BOOST_REQUIRE_MESSAGE(theClient.reloadcustompasswdfile() == 0,
+                              CtsApi::reloadcustompasswdfile() << " should return 0\n"
+                                                               << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                              CtsApi::shutdownServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                              CtsApi::haltServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+
+        // Change to a user not in password file
+        theClient.set_user_name(
+            "dodgy_geezer"); // this should clear password, so that its reloaded when *next* cmd runs
+
+        // all client command should now *FAIL*.
+        BOOST_CHECK_MESSAGE(theClient.reloadcustompasswdfile() == 1,
+                            CtsApi::reloadcustompasswdfile() << " should return 1\n");
+        BOOST_CHECK_MESSAGE(theClient.delete_all() == 1,
+                            CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                     << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 1,
+                            CtsApi::shutdownServer() << " should return 0\n"
+                                                     << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.haltServer() == 1,
+                            CtsApi::haltServer() << " should return 0\n"
+                                                 << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.restartServer() == 1,
+                            CtsApi::restartServer() << " should return 0\n"
+                                                    << theClient.errorMsg());
+
+        // reset to a valid user again:
+        theClient.set_user_name(
+            User::login_name()); // this should clear password, so that its reloaded when *next* cmd runs
+
+        // all client command should now pass. Invoking a client request that requires authorisation
+        BOOST_CHECK_MESSAGE(theClient.reloadcustompasswdfile() == 0,
+                            CtsApi::reloadcustompasswdfile() << " should return 0\n");
+        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
+
+        // terminate server with a valid valid user since ECF_PASSWORD/ECF_USER is still in effect.
+    }
+
+    // Remove the white list file. Comment out for debug
+    fs::remove(passwd_file);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestGroupCmd.cpp 5.13.0-1/libs/client/test/TestGroupCmd.cpp
--- 5.12.4-1/libs/client/test/TestGroupCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestGroupCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,263 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_GroupCmd)
+
+BOOST_AUTO_TEST_CASE(test_group_cmd) {
+    // The previous test's has created/destroyed a server process
+    // If two different process both try to use the same port number, you
+    // get an "Address in use" error, even if one the process is dead. This is
+    // because the kernel does not immediately release the resource and there is
+    // time out period. To get round this we will start the new server/client
+    // and use a different port number. the default is 3141
+
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+    InvokeServer invokeServer("Client:: ...test_group_cmd", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.group("shutdown yes;halt yes;restart") == 0,
+                          "--group should return 0\n"
+                              << theClient.errorMsg());
+}
+
+BOOST_AUTO_TEST_CASE(test_client_group_lifecyle) {
+    /// *** This test is the same as in file TestServerAndLifeCyle.cpp only this time
+    /// *** we use the group command where ever possible
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+
+    // ** NOTE: We disable job generation in the server **/
+    InvokeServer invokeServer(
+        "Client:: ...test_client_group_lifecyle", SCPort::next(), true /*disable job generation in server*/);
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+
+    size_t expected_var = 0;
+    {
+        // restart server, load lifecycle, and get the defs tree from the server
+        std::string groupRequest = "--restart; load=";
+        groupRequest += File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+        groupRequest += "; get";
+
+        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
+                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
+                                               << theClient.errorMsg());
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "Server returned a NULL defs");
+        BOOST_REQUIRE_MESSAGE(serverDefs->suiteVec().size() >= 1, "  no suite ?");
+        const std::vector<suite_ptr>& suites   = serverDefs->suiteVec();
+        const std::vector<Variable>& variables = suites[0]->variables();
+        expected_var                           = variables.size();
+    }
+
+    {
+        // add some var's with spaces ECFLOW-1265
+        expected_var += 1;
+        std::string groupRequest = "alter add variable VAR 'space s' /suite1; get";
+
+        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
+                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
+                                               << theClient.errorMsg());
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "Server returned a NULL defs");
+        const std::vector<suite_ptr>& suites = serverDefs->suiteVec();
+        BOOST_REQUIRE_MESSAGE(suites.size() >= 1, "  no suite ?");
+        const std::vector<Variable>& variables = suites[0]->variables();
+        BOOST_REQUIRE_MESSAGE(variables.size() == expected_var,
+                              "Expected " << expected_var << " variables but found " << variables.size());
+        BOOST_REQUIRE_MESSAGE(variables[expected_var - 1].theValue() == "'space s'",
+                              "Expected 'space s' but found " << variables[expected_var - 1].theValue());
+    }
+
+    // Now go through and simulate client request to change Node tree state.
+    // This is **highly** dependent on lifecycle.txt
+    //	suite suite1
+    //	  family family1
+    //	   	task a
+    //	        event 1 myEvent
+    //	        meter myMeter 0 100
+    //	   	task b
+    //	   		trigger a == complete
+    //	   endfamily
+    //	   family family2
+    //	   		task aa
+    //	   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
+    //	   		task bb
+    //	   			trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
+    //	    endfamily
+    //	endsuite
+    string suite1_family1_a  = "suite1/family1/a";
+    string suite1_family1_b  = "suite1/family1/b";
+    string suite1_family2_aa = "suite1/family2/aa";
+    string suite1_family2_bb = "suite1/family2/bb";
+
+    // ***********************************************************************
+    // Create a request to initialise Node: suite1/family1/a
+    // Create a request to set the event on Node suite1/family1/a
+    // This should place suite1_family2_bb immediately into submitted state
+    // Since we at least one node in ACTIVE, suite should be in ACTIVE state
+    {
+        theClient.taskPath(suite1_family1_a);
+        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
+
+        // make sure to use same ECF_RID if its specified
+        std::string remote_id = "process_or_remote_id";
+        if (!theClient.process_or_remote_id().empty())
+            remote_id = theClient.process_or_remote_id();
+        std::string groupRequest = "begin=suite1;  init=";
+        groupRequest += remote_id;
+        groupRequest += "; event=myEvent; force-dep-eval; get";
+
+        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
+                              "Group request " << groupRequest << " failed should return 0\n"
+                                               << theClient.errorMsg());
+
+        defs_ptr serverDefs = theClient.defs();
+        // PrintStyle style(PrintStyle::STATE);
+        // cerr << *serverDefs.get() << "\n";
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        node_ptr node = serverDefs->findAbsNode(suite1_family1_a);
+        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(node->state()));
+        node_ptr nodeb = serverDefs->findAbsNode(suite1_family2_bb);
+        BOOST_REQUIRE_MESSAGE(nodeb->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeb->state()));
+    }
+
+    //**********************************************************************
+    // Create a request to set the Meter on Node suite1/family1/a
+    // This should force suite1_family2_aa immediately into submitted state
+    // This should force suite1_family2_bb immediately into submitted state
+    {
+        theClient.taskPath(suite1_family1_a);
+        std::string groupRequest = "meter=myMeter 100; force-dep-eval; get";
+        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
+                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
+                                               << theClient.errorMsg());
+
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        node_ptr nodeaa = serverDefs->findAbsNode(suite1_family2_aa);
+        BOOST_REQUIRE_MESSAGE(nodeaa->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeaa->state()));
+
+        node_ptr nodebb = serverDefs->findAbsNode(suite1_family2_bb);
+        BOOST_REQUIRE_MESSAGE(nodebb->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodebb->state()));
+    }
+
+    //**********************************************************************
+    // Create a request to complete task suite1/family1/a
+    // This should force suite1_family1_b to complete
+    // 	Resolve dependencies
+    // 	We could either wait 60 second or
+    // 	added a custom command that will force dependency evaluation
+    {
+        theClient.taskPath(suite1_family1_a);
+        std::string groupRequest = "complete;force-dep-eval;get";
+        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
+                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
+                                               << theClient.errorMsg());
+
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        node_ptr node = serverDefs->findAbsNode(suite1_family1_b);
+        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
+                              "Expected NState::ACTIVE, but found " << NState::toString(node->state()));
+    }
+
+    //********************************************************************************
+    // Complete the remaining tasks. Should really call init first, but what the eck.
+    //
+    // Get the node tree back from the server, and check its node state
+    // All node state should be complete. + check meter/event value was set properly
+
+    {
+        theClient.taskPath(suite1_family1_b);
+        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
+                              TaskApi::complete() << " failed should return 0\n"
+                                                  << theClient.errorMsg());
+
+        theClient.taskPath(suite1_family2_aa);
+        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
+                              TaskApi::complete() << " failed should return 0\n"
+                                                  << theClient.errorMsg());
+
+        theClient.taskPath(suite1_family2_bb);
+        std::string groupRequest = "complete;force-dep-eval;get";
+        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
+                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
+                                               << theClient.errorMsg());
+
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        std::string metername = "myMeter";
+        int meterValue        = 100;
+        node_ptr node         = serverDefs->findAbsNode(suite1_family1_a);
+        const Meter& theMeter = node->findMeter(metername);
+        BOOST_REQUIRE_MESSAGE(!theMeter.empty(), "Could not find the meter");
+        BOOST_REQUIRE_MESSAGE(theMeter.value() == meterValue,
+                              "Expected meter value " << meterValue << " but found " << theMeter.value());
+        {
+            std::string errorMsg;
+            BOOST_REQUIRE_MESSAGE(serverDefs->checkInvariants(errorMsg), errorMsg);
+        }
+
+        std::string eventname = "myEvent";
+        const Event& theEvent = node->findEventByNameOrNumber(eventname);
+        BOOST_REQUIRE_MESSAGE(!theEvent.empty(), "Could not find the event myEvent");
+        BOOST_REQUIRE_MESSAGE(theEvent.value(), "The event was not set");
+
+        const std::vector<suite_ptr>& suiteVec = serverDefs->suiteVec();
+        suite_ptr suite                        = suiteVec.back();
+        BOOST_REQUIRE_MESSAGE(suite->state() == NState::COMPLETE,
+                              "Suite expected NState::COMPLETE, but found to be " << NState::toString(suite->state()));
+    }
+
+    {
+        // Check that a log file was created, by asking the server for it.
+        BOOST_REQUIRE_MESSAGE(theClient.getLog() == 0, "get log  failed should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(!theClient.get_string().empty(), "The log file returned from the server is empty!!");
+
+        // Clear the log
+        BOOST_REQUIRE_MESSAGE(theClient.clearLog() == 0,
+                              CtsApi::clearLog() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestInitAddVariables.cpp 5.13.0-1/libs/client/test/TestInitAddVariables.cpp
--- 5.12.4-1/libs/client/test/TestInitAddVariables.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestInitAddVariables.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,93 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/task/CompleteCmd.hpp"
+#include "ecflow/base/cts/task/InitCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_InitAddVariables)
+
+BOOST_AUTO_TEST_CASE(test_init_add_variables) {
+    cout << "Client:: ...test_init_add_variables " << endl;
+    TestLog test_log(
+        "test_init_add_variables.log"); // will create log file, and destroy log and remove file at end of scope
+
+    Defs defs;
+    suite_ptr suite = defs.add_suite("test_init_add_variables");
+    family_ptr f    = suite->add_family("f");
+    task_ptr t1     = f->add_task("t1");
+    t1->add_trigger(":name == 1 and :name2 == 2");
+    {
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+    {
+        std::string errorMsg, warningMsg;
+        BOOST_CHECK_MESSAGE(!defs.check(errorMsg, warningMsg),
+                            "Expected error since variable name and name2 are not defined");
+    }
+
+    BOOST_CHECK_MESSAGE(suite->state() == NState::UNKNOWN, " Initial suite state should be NState::UNKNOWN");
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("test_init_add_variables")));
+
+    {
+        // Test that init command with --add, will add variables
+        std::vector<Variable> vec{Variable("name", "1"), Variable("name2", "2")};
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new InitCmd(t1->absNodePath(),
+                                                      Submittable::DUMMY_JOBS_PASSWORD(),
+                                                      Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                      1,
+                                                      vec)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)), false);
+        const Variable& v  = t1->findVariable("name");
+        const Variable& v2 = t1->findVariable("name2");
+        BOOST_CHECK_MESSAGE(!v.empty(), "Expected --init to add variable");
+        BOOST_CHECK_MESSAGE(!v2.empty(), "Expected --init to add variable");
+
+        std::string errorMsg, warningMsg;
+        BOOST_CHECK_MESSAGE(defs.check(errorMsg, warningMsg),
+                            "Expected check to pass since variable name and name2 are defined " << errorMsg);
+    }
+
+    {
+        // Test that comeplete command with --remove, will delete variables
+        std::vector<std::string> vec{"name", "name2"};
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new CompleteCmd(t1->absNodePath(),
+                                                          Submittable::DUMMY_JOBS_PASSWORD(),
+                                                          Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                          1,
+                                                          vec)));
+        const Variable& v  = t1->findVariable("name");
+        const Variable& v2 = t1->findVariable("name2");
+        BOOST_CHECK_MESSAGE(v.empty(), "Expected --complete to delete variable");
+        BOOST_CHECK_MESSAGE(v2.empty(), "Expected --complete to delete variable");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestJobGenOnly.cpp 5.13.0-1/libs/client/test/TestJobGenOnly.cpp
--- 5.12.4-1/libs/client/test/TestJobGenOnly.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestJobGenOnly.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,92 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp> // IWYU pragma: keep
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/JobCreationCtrl.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_JobGenOnly)
+
+//  Tests the Job generation against the OLD sms
+BOOST_AUTO_TEST_CASE(test_jobgenonly) {
+    cout << "Client:: ...test_jobgenonly" << endl;
+
+    // Define paths to ECF_HOME and location of the defs file
+
+    std::string defsFile = File::test_data("libs/client/test/data/jobgenonly.def", "libs/client");
+    std::string ecf_home = File::test_data("libs/client/test/data/ECF_HOME", "libs/client");
+
+    /// Remove existing job file if any.
+    /// 	Job file location may NOT be same as ecf file.
+    /// 	The default Job location is defined by generated variable ECF_JOB
+    /// 	ECF_JOB = ECF_HOME/<abs node path>.job<try_no>.
+    std::vector<std::string> generatedFiles;
+    generatedFiles.reserve(5);
+    std::string t1_job = ecf_home + "/suite/family/t1.job0";
+    generatedFiles.push_back(t1_job);
+    std::string t2_job = ecf_home + "/suite/family/t2.job0";
+    generatedFiles.push_back(t2_job);
+    std::string t3_job = ecf_home + "/suite/family/t3.job0";
+    generatedFiles.push_back(t3_job);
+
+    // See EcfFile.cpp: To enable generation of man files, for test. i.e DEBUG_MAN_FILE
+#ifdef DEBUG_MAN_FILE
+    std::string t1_man = ecf_home + "/suite/family/t1.man";
+    generatedFiles.push_back(t1_man);
+    std::string t3_man = ecf_home + "/suite/family/t3.man";
+    generatedFiles.push_back(t3_man);
+#endif
+    for (const std::string& s : generatedFiles) {
+        fs::remove(s);
+    }
+    for (const std::string& s : generatedFiles) {
+        BOOST_REQUIRE_MESSAGE(!fs::exists(s), "Could not delete file " << s);
+    }
+
+    // Load the defs file 'jobgenonly.def'
+    Defs theDefs;
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(theDefs.restore(defsFile, errorMsg, warningMsg), errorMsg);
+
+    // Override ECF_HOME. ECF_HOME is needed to locate to the .ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    // provide definition of ECF_CLIENT. This should replace smsinit, smscomplete, smsevent,etc
+    // with path to the ecf client
+    std::string clientPath = File::find_ecf_client_path();
+    BOOST_REQUIRE_MESSAGE(!clientPath.empty(), "Could not find path to client executable");
+    theDefs.set_server().add_or_update_user_variables("ECF_CLIENT", clientPath);
+
+    // JobCreationCtrl is used control what node we generate the jobs for:
+    // Since we have not set the node on it, we force job generation for all tasks
+    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
+    theDefs.check_job_creation(jobCtrl);
+    BOOST_REQUIRE_MESSAGE(jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
+    BOOST_REQUIRE_MESSAGE(jobCtrl->fail_submittables().empty(), "Expected no failing tasks");
+
+    // Check if jobs file were generated.
+    for (const std::string& s : generatedFiles) {
+        BOOST_REQUIRE_MESSAGE(fs::exists(s), "File " << s << " should have been created");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestLifeCycle.cpp 5.13.0-1/libs/client/test/TestLifeCycle.cpp
--- 5.12.4-1/libs/client/test/TestLifeCycle.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestLifeCycle.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,245 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/task/CompleteCmd.hpp"
+#include "ecflow/base/cts/task/EventCmd.hpp"
+#include "ecflow/base/cts/task/InitCmd.hpp"
+#include "ecflow/base/cts/task/MeterCmd.hpp"
+#include "ecflow/base/cts/user/BeginCmd.hpp"
+#include "ecflow/base/cts/user/CtsCmd.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_LifeCycle)
+
+BOOST_AUTO_TEST_CASE(test_node_tree_lifecycle) {
+    cout << "Client:: ...test_node_tree_lifecycle" << endl;
+    TestLog test_log(
+        "test_node_tree_lifecycle.log"); // will create log file, and destroy log and remove file at end of scope
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    Defs defs;
+    std::string errorMsg, warningMsg;
+    bool parse = defs.restore(path, errorMsg, warningMsg);
+    if (!parse)
+        std::cerr << errorMsg;
+    BOOST_CHECK(parse);
+
+    // Now go through and simulate client request to change Node tree state.
+    // This is **highly** dependent on lifecycle.txt
+    //	suite suite1
+    //	  family family1
+    //	   	task a
+    //	        event 1 myEvent
+    //	        meter myMeter 0 100
+    //	   	task b
+    //	   		trigger a == complete
+    //	   endfamily
+    //	   family family2
+    //	   		task aa
+    //	   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
+    //	   		task bb
+    //	   			trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
+    //	    endfamily
+    //	endsuite
+
+    // get the suite, before we do anything initial state should be UNKNOWN
+    const std::vector<suite_ptr>& suiteVec = defs.suiteVec();
+    suite_ptr suite                        = suiteVec.back();
+    BOOST_CHECK_MESSAGE(suite->state() == NState::UNKNOWN, " Initial suite state should be NState::UNKNOWN");
+
+    string suite1_family1_a  = "suite1/family1/a";
+    string suite1_family1_b  = "suite1/family1/b";
+    string suite1_family2_aa = "suite1/family2/aa";
+    string suite1_family2_bb = "suite1/family2/bb";
+
+    // Pick the suite that is allowed to resolve dependencies
+    // The suite must be loaded and be in state UNKNOWN or COMPLETE
+    TestHelper::invokeRequest(&defs, Cmd_ptr(new BeginCmd("suite1")));
+
+    // ***********************************************************************
+    // Create a request to initialise Node: suite1/family1/a
+    {
+        TestHelper::invokeRequest(
+            &defs,
+            Cmd_ptr(new InitCmd(
+                suite1_family1_a, Submittable::DUMMY_JOBS_PASSWORD(), Submittable::DUMMY_PROCESS_OR_REMOTE_ID(), 1)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)), false);
+
+        node_ptr node = defs.findAbsNode(suite1_family1_a);
+        BOOST_CHECK_MESSAGE(node, "Could not find node");
+        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE, "Init request should place node in NState::ACTIVE");
+        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE, "Suite should be in NState::ACTIVE after init cmd");
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+
+    //**********************************************************************
+    // Create a request to set the event on Node suite1/family1/a
+    // This should force suite1_family2_bb immediately into submitted/active state
+    {
+        std::string eventname = "myEvent";
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new EventCmd(suite1_family1_a,
+                                                       Submittable::DUMMY_JOBS_PASSWORD(),
+                                                       Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                       1,
+                                                       eventname)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
+        node_ptr node = defs.findAbsNode(suite1_family1_a);
+
+        const Event& theEvent = node->findEventByNameOrNumber(eventname);
+        BOOST_CHECK_MESSAGE(!theEvent.empty(), "Could not find the event myEvent");
+        BOOST_CHECK_MESSAGE(theEvent.value(), "The event was not set");
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+
+        // cerr << "Defs " << defs << "\n";
+        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE,
+                            "State should be NState::ACTIVE but found to be " << NState::toString(node->state()));
+        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
+                            "Suite should be in NState::ACTIVE but found to be " << NState::toString(suite->state()));
+
+        node_ptr nodebb = defs.findAbsNode(suite1_family2_bb);
+        BOOST_CHECK_MESSAGE(nodebb->state() == NState::ACTIVE,
+                            "State should be NState::ACTIVE but found to be " << NState::toString(nodebb->state()));
+    }
+
+    //*******************************************************************************
+    // Resolve dependencies. After previous event suite1_family2_bb should have
+    //                       been put into ACTIVE state.
+    //                       ** Tests trigger/AST OR functionality **
+    //                       Since we at least one node in active, suite should
+    //                       be in avtive state
+    {
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        for (Submittable* t : jobsParam.submitted()) {
+            BOOST_CHECK_MESSAGE(t->state() == NState::SUBMITTED, "jobSubmission should change Node state");
+        }
+
+        {
+            node_ptr node = defs.findAbsNode(suite1_family1_a);
+            BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE, "resolve dependencies should change Node state here");
+        }
+        node_ptr node = defs.findAbsNode(suite1_family2_bb);
+        BOOST_CHECK_MESSAGE(node, "Could Not find Node " << suite1_family2_bb);
+        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE, "resolve dependencies should change Node state");
+        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
+                            "Suite expected NState::ACTIVE, but found to be " << NState::toString(suite->state()));
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+
+    //**********************************************************************
+    // Create a request to set the Meter on Node suite1/family1/a
+    // This should immediately change suite1_family2_aa into submitted state
+    {
+        std::string metername = "myMeter";
+        int meterValue        = 100;
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new MeterCmd(suite1_family1_a,
+                                                       Submittable::DUMMY_JOBS_PASSWORD(),
+                                                       Submittable::DUMMY_PROCESS_OR_REMOTE_ID(),
+                                                       1,
+                                                       metername,
+                                                       meterValue)));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
+
+        node_ptr node = defs.findAbsNode(suite1_family1_a);
+        BOOST_CHECK_MESSAGE(node->state() == NState::ACTIVE,
+                            "Expected Node '" << node->absNodePath() << "' to be NState::ACTIVE, but found "
+                                              << NState::toString(node->state()) << "\n");
+        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
+                            "Suite expected NState::ACTIVE, but found to be " << NState::toString(suite->state()));
+
+        const Meter& theMeter = node->findMeter(metername);
+        BOOST_CHECK_MESSAGE(!theMeter.empty(), "Could not find the meter");
+        BOOST_CHECK_MESSAGE(theMeter.value() == meterValue, "Meter value not set");
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+
+        node_ptr nodeaa = defs.findAbsNode(suite1_family2_aa);
+        BOOST_CHECK_MESSAGE(nodeaa, "Could Not find Node " << suite1_family2_aa);
+        BOOST_CHECK_MESSAGE(nodeaa->state() == NState::ACTIVE, "resolve dependencies should change Node state");
+    }
+
+    //**********************************************************************
+    // Create a request to complete task suite1/family1/a
+    // A is complete, which means evaluation dependencies should force:
+    //      suite1/family1/b   :->to be submitted.
+    // since the complete command does an immediate job submission afterwards
+    {
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new CompleteCmd(suite1_family1_a, Submittable::DUMMY_JOBS_PASSWORD())));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new CtsCmd(CtsCmd::FORCE_DEP_EVAL)));
+
+        node_ptr node = defs.findAbsNode(suite1_family1_a);
+        BOOST_CHECK_MESSAGE(node, "Could not find node");
+        BOOST_CHECK_MESSAGE(node->state() == NState::COMPLETE,
+                            "Complete request should place node in NState::COMPLETE");
+        BOOST_CHECK_MESSAGE(suite->state() == NState::ACTIVE,
+                            "Expected NState::ACTIVE, but found to be " << NState::toString(suite->state()));
+
+        node_ptr nodeb = defs.findAbsNode(suite1_family1_b);
+        BOOST_CHECK_MESSAGE(nodeb, "Could not find node");
+        BOOST_CHECK_MESSAGE(nodeb->state() == NState::ACTIVE,
+                            "Expected NState::ACTIVE, but found to be " << NState::toString(nodeb->state()));
+
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+
+    //*******************************************************************************
+    // Job submission, should not send any jobs for submission.
+    //         This will evaluate dependencies( ie day,date, trigger ast)
+    {
+        JobsParam jobsParam; // create jobs = false, spawn jobs = false
+        Jobs jobs(&defs);
+        BOOST_CHECK_MESSAGE(jobs.generate(jobsParam), jobsParam.getErrorMsg());
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "Expected 0 task to submit but found " << jobsParam.submitted().size());
+    }
+
+    //********************************************************************************
+    // Complete the remaining tasks
+    {
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new CompleteCmd("suite1/family1/b", Submittable::DUMMY_JOBS_PASSWORD())));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new CompleteCmd(suite1_family2_aa, Submittable::DUMMY_JOBS_PASSWORD())));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new CompleteCmd(suite1_family2_bb, Submittable::DUMMY_JOBS_PASSWORD())));
+
+        BOOST_CHECK_MESSAGE(suite->state() == NState::COMPLETE, "Suite should be in NState::COMPLETE state");
+        std::string errorMsg;
+        BOOST_CHECK_MESSAGE(defs.checkInvariants(errorMsg), errorMsg);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestLoadDefsCmd.cpp 5.13.0-1/libs/client/test/TestLoadDefsCmd.cpp
--- 5.12.4-1/libs/client/test/TestLoadDefsCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestLoadDefsCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,166 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/base/cts/user/LoadDefsCmd.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_LoadDefsCmd)
+
+//=============================================================================
+// This test the LoadDefsCmd. This command will merge/absorb a defs file
+// Since we are merging 2 files. It will give us an opportunity to resolve
+// the extern node paths in the trigger expressions.
+//
+// ********************************************************************
+// In the real server, we dont store, externs
+// *******************************************************************
+BOOST_AUTO_TEST_CASE(test_load_defs_cmd_handleRequest) {
+    cout << "Client:: ...test_load_defs_cmd_handleRequest" << endl;
+    TestLog test_log("test_load_defs_cmd_handleRequest.log"); // will create log file, and destroy log and remove file
+                                                              // at end of scope
+
+    std::string firstDef = File::test_data("libs/client/test/data/first.def", "libs/client");
+
+    // Load the FIRST file with a set of unresolved extrens
+    defs_ptr firstDefs = Defs::create();
+    {
+        std::string errorMsg, warningMsg;
+        bool parse = firstDefs->restore(firstDef, errorMsg, warningMsg);
+        BOOST_CHECK_MESSAGE(parse, "Parse failed. " << errorMsg);
+        firstDefs->clear_externs(); // server defs should not have externs.
+    }
+    size_t noOfSuites = firstDefs->suiteVec().size();
+
+    // load the SECOND file, which should resolve the externs
+    std::string secondDef = File::test_data("libs/client/test/data/second.def", "libs/client");
+    Defs secondDefs;
+    {
+        std::string errorMsg, warningMsg;
+        bool parse = secondDefs.restore(secondDef, errorMsg, warningMsg);
+        BOOST_CHECK_MESSAGE(parse, "Parse failed. " << errorMsg);
+    }
+    noOfSuites += secondDefs.suiteVec().size();
+
+    // Create a LoadDefsCmd. This capable of merging defs files
+    // Externs are NOT loaded into the server.
+    LoadDefsCmd cmd(firstDefs);
+    cmd.setup_user_authentification();
+
+    // Calling handelRequest will absorb the first defs into second & server user variables
+    // AND resolve any references to node paths in the trigger expressions
+    //
+    // Test that the merge was OK as well
+    // Note: The firstDefs is recreated in the SERVER (via LoadDefsCmd), hence out of sync with this firstDefs
+    MockServer mockServer(&secondDefs);
+    STC_Cmd_ptr requestStatus = cmd.handleRequest(&mockServer);
+    BOOST_CHECK_MESSAGE(requestStatus, "Handle Request " << cmd << " returned NULL\n");
+    BOOST_CHECK_MESSAGE(requestStatus->error().empty(), requestStatus->error());
+    BOOST_CHECK_MESSAGE(secondDefs.suiteVec().size() == noOfSuites, "Merge failed to add suites");
+
+    // Modify the Defs file to add a task/trigger that references the undefined
+    // extern path defined in file 'first.def' This should fail.
+    task_ptr task = Task::create("AMadeUpName");
+    task->add_trigger("/a/b/c/d/e/f/g/h/j == complete");
+    secondDefs.suiteVec().back()->familyVec().back()->addTask(task);
+
+    // we just added an expression, re-parse to create AST
+    // This should also attempt to resolve the extern node path /a/b/c/d/e/f/g/h/j
+    // The suite 'a' should exist. But the full path is non existent
+    // hence we expect the PARSE to fail.
+    std::string errormsg, warningMsg;
+    BOOST_CHECK_MESSAGE(!secondDefs.check(errormsg, warningMsg), errormsg);
+}
+
+BOOST_AUTO_TEST_CASE(test_load_defs_check_only) {
+    /// Test that when check only is called the definition is NOT loaded
+    InvokeServer invokeServer("Client:: ...test_load_defs_check_only", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    // Do not load the defs do a check only
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    {
+        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, false, true /* check only*/) == 0,
+                              "Expected load to succeed\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Expected sync to succeed\n" << theClient.errorMsg());
+
+        // Note: when running with ECF_HOST=localhost the defs may exist, but the number of suites should be empty
+        BOOST_REQUIRE_MESSAGE(!theClient.defs() || theClient.defs()->suiteVec().empty(),
+                              "Expected no defs, since nothing should have been loaded\n"
+                                  << theClient.errorMsg());
+    }
+    {
+        theClient.set_auto_sync(true);
+        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path, false, true /* check only*/) == 0,
+                              "Expected load to succeed\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(!theClient.defs() || theClient.defs()->suiteVec().empty(),
+                              "Expected no defs, since nothing should have been loaded\n"
+                                  << theClient.errorMsg());
+    }
+    // provide path to definition that should fail to parse
+    std::string path_bad_def = File::test_data("libs/client/test/data/bad.def", "libs/client");
+    BOOST_REQUIRE_THROW(theClient.loadDefs(path_bad_def, false, true /* check only*/), std::runtime_error);
+}
+
+BOOST_AUTO_TEST_CASE(test_load_defs) {
+    /// Test that loading a defs a second time, with the same suite, throws a errors
+    /// unless the -force option is used.
+    InvokeServer invokeServer("Client:: ...test_load_defs", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    // create a defs with a single suite 's1'
+    defs_ptr theDefs = Defs::create();
+    {
+        suite_ptr suite = Suite::create("s1");
+        theDefs->addSuite(suite);
+    }
+
+    // Load the defs into the server
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    theClient.set_throw_on_error(false);
+    BOOST_REQUIRE_MESSAGE(theClient.load(theDefs) == 0, "Expected load to succeed\n" << theClient.errorMsg());
+
+    // load the defs again. This should fail. as it stops accidental overwrites
+    BOOST_REQUIRE_MESSAGE(theClient.load(theDefs) == 1, "Expected load to fail\n" << theClient.errorMsg());
+
+    // Try again but with force
+    BOOST_REQUIRE_MESSAGE(theClient.load(theDefs, true /*force*/) == 0,
+                          "Expected load to succeed\n"
+                              << theClient.errorMsg());
+
+    /// Destroy singleton's to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestLogAndCheckptErrors.cpp 5.13.0-1/libs/client/test/TestLogAndCheckptErrors.cpp
--- 5.12.4-1/libs/client/test/TestLogAndCheckptErrors.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestLogAndCheckptErrors.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,170 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+#include <sys/stat.h>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Pid.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/User.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_LogAndCheckptErrors)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+// ************************************************************************************
+BOOST_AUTO_TEST_CASE(test_log_and_checkpt_write_errors) {
+    // This test needs to change directory *BEFORE* before the server starts.
+    // Hence if the server is already running ignore this test.
+    if (!ClientEnvironment::hostSpecified().empty()) {
+        cout << "Client:: ...test_log_and_checkpt_write_errors. IGNORING when server is already running" << endl;
+        return;
+    }
+
+    // When this test is run in Bamboo/Docker, the users is root, hence the chmod below will not work and test will fail
+    if (User::login_name() == "root") {
+        cout << "Client:: ...test_log_and_checkpt_write_errors. IGNORING when user is root." << endl;
+        return;
+    }
+
+    bool debug_me = false;
+    if (debug_me)
+        cout << "->Create a directory from where we will start the server\n";
+    std::string ecf_home = "test_log_and_checkpt_write_errors" + Pid::getpid();
+    fs::create_directory(ecf_home);
+
+    if (debug_me)
+        cout << "->change directory, before server start\n";
+    BOOST_CHECK_MESSAGE(chdir(ecf_home.c_str()) == 0,
+                        "Can't change directory to " << ecf_home << "  error: " << strerror(errno));
+    if (debug_me)
+        cout << "->current path = " << fs::current_path() << "\n";
+
+    {
+        if (debug_me)
+            cout << "->start the server\n";
+        InvokeServer invokeServer("Client:: ...test_log_and_checkpt_write_errors", SCPort::next());
+        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+        if (debug_me)
+            invokeServer.keep_log_file_after_server_exit();
+
+        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+        theClient.set_throw_on_error(false);
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
+                                                      << theClient.errorMsg());
+
+        if (debug_me)
+            cout << "->load a defs file to the server\n";
+        std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+        BOOST_CHECK_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+        if (debug_me) {
+            BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
+            PrintStyle style(PrintStyle::STATE);
+            cout << theClient.defs() << "\n";
+        }
+
+        if (debug_me)
+            cout << "->flush the log file, this will close the log file in the server\n";
+        BOOST_CHECK_MESSAGE(theClient.flushLog() == 0, "flushLog failed \n" << theClient.errorMsg());
+
+        if (debug_me)
+            cout << "->remove write permission for " << ecf_home << "\n";
+        BOOST_CHECK_MESSAGE(chdir("..") == 0, "Can't change directory to parent  error: " << strerror(errno));
+        BOOST_CHECK_MESSAGE(chmod(ecf_home.c_str(), strtol("0444", 0, 8)) == 0, "Can't chmod : " << strerror(errno));
+
+        if (debug_me)
+            cout << "->write the checkpoint file, should fail, this should also try to re-open the log file and fail\n";
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 1,
+                              CtsApi::checkPtDefs() << " Checkpoint expected to fail\n"
+                                                    << theClient.errorMsg());
+
+        if (debug_me)
+            cout << "->get the defs from server, Check flags, check server variables\n";
+        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.defs()->get_flag().is_set(Flag::CHECKPT_ERROR),
+                            "Expected Flag::CHECKPT_ERROR to be set");
+        BOOST_CHECK_MESSAGE(theClient.defs()->get_flag().is_set(Flag::LOG_ERROR), "Expected Flag::LOG_ERROR to be set");
+        BOOST_CHECK_MESSAGE(theClient.defs()->server().variable_exists("ECF_CHECKPT_ERROR"),
+                            "Expected to find ECF_CHECKPT_ERROR as a server variable");
+        BOOST_CHECK_MESSAGE(theClient.defs()->server().variable_exists("ECF_LOG_ERROR"),
+                            "Expected to find ECF_LOG_ERROR as a server variable");
+
+        const Variable& var  = theClient.defs()->server().findVariable("ECF_LOG_ERROR");
+        const Variable& var1 = theClient.defs()->server().findVariable("ECF_CHECKPT_ERROR");
+        BOOST_CHECK_MESSAGE(!var1.theValue().empty(), "Expected ECF_CHECKPT_ERROR to have a value");
+        BOOST_CHECK_MESSAGE(!var.theValue().empty(), "Expected ECF_LOG_ERROR to have a value");
+        if (debug_me)
+            cout << "->ECF_CHECKPT_ERROR=" << var1.theValue() << "\n";
+        if (debug_me)
+            cout << "->ECF_LOG_ERROR =" << var.theValue() << "\n";
+
+        if (debug_me)
+            cout << "->add write permission to " << ecf_home << "\n";
+        BOOST_CHECK_MESSAGE(chmod(ecf_home.c_str(), strtol("0755", 0, 8)) == 0, "Can't chmod : " << strerror(errno));
+
+        if (debug_me)
+            cout << "->flush log file again\n";
+        BOOST_CHECK_MESSAGE(theClient.flushLog() == 0, "flushLog failed \n" << theClient.errorMsg());
+
+        if (debug_me)
+            cout << "->clear the flags -> this should *ALSO* delete the server user variables\n";
+        BOOST_CHECK_MESSAGE(theClient.alter("/", "clear_flag", "log_error") == 0,
+                            "alter / clear_flag log_error : failed \n"
+                                << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.alter("/", "clear_flag", "checkpt_error") == 0,
+                            "alter / clear_flag checkpt_error : failed \n"
+                                << theClient.errorMsg());
+
+        if (debug_me)
+            cout << "->checkpoint again\n";
+        BOOST_CHECK_MESSAGE(theClient.checkPtDefs() == 0,
+                            CtsApi::checkPtDefs() << " Checkpoint expected to pass\n"
+                                                  << theClient.errorMsg());
+
+        if (debug_me)
+            cout << "->Get the defs, Check flags are cleared and server variables are deleted\n";
+        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "sync_local failed \n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(!theClient.defs()->get_flag().is_set(Flag::CHECKPT_ERROR),
+                            "Expected Flag::CHECKPT_ERROR to be cleared");
+        BOOST_CHECK_MESSAGE(!theClient.defs()->get_flag().is_set(Flag::LOG_ERROR),
+                            "Expected Flag::LOG_ERROR to be cleared");
+        BOOST_CHECK_MESSAGE(!theClient.defs()->server().variable_exists("ECF_CHECKPT_ERROR"),
+                            "Expected to NOT find ECF_CHECKPT_ERROR as a server variable");
+        BOOST_CHECK_MESSAGE(!theClient.defs()->server().variable_exists("ECF_LOG_ERROR"),
+                            "Expected to NOT find ECF_LOG_ERROR as a server variable");
+    }
+
+    if (debug_me)
+        cout << "->remove created directory " << ecf_home << "\n";
+    if (debug_me)
+        cout << "->current path = " << fs::current_path() << "\n";
+    if (!debug_me) {
+        BOOST_CHECK_MESSAGE(File::removeDir(ecf_home),
+                            "Failed to remove dir " << ecf_home << "  error: " << strerror(errno));
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestMigration.cpp 5.13.0-1/libs/client/test/TestMigration.cpp
--- 5.12.4-1/libs/client/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestMigration.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,113 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "TestHelper.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/client/Rtt.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+/**
+ * Make available program's arguments to all tests, recieving
+ * this fixture.
+ */
+struct ArgsFixture
+{
+    ArgsFixture()
+        : argc(boost::unit_test::framework::master_test_suite().argc),
+          argv(boost::unit_test::framework::master_test_suite().argv) {}
+    int argc;
+    char** argv;
+};
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_Migration)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+// ************************************************************************************
+
+void do_test_migration(ClientInvoker& theClient,
+                       const std::string& host,
+                       const std::string& port,
+                       const std::string& directory,
+                       int& error_cnt) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (is_directory(dir_itr->status())) {
+                do_test_migration(theClient, host, port, relPath.string(), error_cnt);
+                continue;
+            }
+
+            cout << relPath.string() << "  : file size " << fs::file_size(relPath) << "\n\n";
+            if (fs::file_size(relPath) > 0) {
+                try {
+                    theClient.loadDefs(relPath.string());
+                    theClient.delete_all(true);
+                }
+                catch (std::exception& e) {
+                    error_cnt++;
+                    BOOST_CHECK_MESSAGE(false, theClient.errorMsg() << " : " << e.what());
+                }
+            }
+        }
+        catch (const std::exception& ex) {
+            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_FIXTURE_TEST_CASE(test_migration, ArgsFixture) {
+    if (argc != 2) {
+        std::cout << "Ignoring test! Since test directory is not provided\n";
+    }
+    else if (!fs::exists(argv[1])) {
+        std::cout << "Ignoring test! Since provided test directory does not exist\n";
+    }
+    else {
+        /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+        InvokeServer invokeServer("Client:: ...test_migration:", SCPort::next());
+        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                              "Migration test failed server failed to start on: " << invokeServer.host() << ":"
+                                                                                  << invokeServer.port());
+
+        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+        int error_cnt = 0;
+        do_test_migration(theClient, invokeServer.host(), invokeServer.port(), argv[1], error_cnt);
+        BOOST_REQUIRE_MESSAGE(error_cnt == 0, "Migration test failed " << error_cnt << " times ");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestMigration_main.cpp 5.13.0-1/libs/client/test/TestMigration_main.cpp
--- 5.12.4-1/libs/client/test/TestMigration_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestMigration_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Migration
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/client/test/TestPasswdFile.cpp 5.13.0-1/libs/client/test/TestPasswdFile.cpp
--- 5.12.4-1/libs/client/test/TestPasswdFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestPasswdFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,187 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/PasswdFile.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_PasswdFile)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+//
+// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
+//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
+//       is specified then *don't* shutdown the server
+// ************************************************************************************
+
+class Add_ECF_PASSWD_env {
+public:
+    explicit Add_ECF_PASSWD_env(const std::string& passwd_file) : env_("ECF_PASSWD=") {
+        env_ += passwd_file;
+        auto* put = const_cast<char*>(env_.c_str());
+        BOOST_CHECK_MESSAGE(putenv(put) == 0, "putenv failed for " << put);
+    }
+    ~Add_ECF_PASSWD_env() {
+        putenv(const_cast<char*>("ECF_PASSWD")); // remove from env, otherwise valgrind complains
+    }
+
+private:
+    std::string env_;
+};
+
+BOOST_AUTO_TEST_CASE(test_loading_of_passwd) {
+    Host the_host;
+    std::string host        = ClientEnvironment::hostSpecified();
+    std::string port        = SCPort::next();
+    std::string passwd_file = the_host.ecf_passwd_file(port);
+    std::string passwd      = "xxxx";
+    if (host.empty()) {
+        // make sure NO passed file is present before the server is started.
+        // Only do this locally, as passwd file on remote machine may not be accessible
+        fs::remove(passwd_file);
+    }
+    else {
+        // The test only works if server is started locally.
+        std::cout << "...Client:: ...test_loading_of_passwd ignoring when HOST specified\n";
+        return;
+    }
+
+    // cout << "passwd_file " << passwd_file << "\n";
+
+    // Set ECF_PASSWD environment variable. Use same file for client and server
+    // add on construction, and remove at destruction.
+    Add_ECF_PASSWD_env ecf_passwd(passwd_file);
+
+    // Create a valid passwd file; Before server start
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(PasswdFile::createWithAccess(passwd_file, the_host.name(), port, passwd, errorMsg), errorMsg);
+
+    // This will remove check pt and backup file before server start,
+    // to avoid the server from loading previous test data
+    InvokeServer invokeServer("Client:: ...test_loading_of_passwd", port);
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    theClient.set_throw_on_error(false);
+
+    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+
+    // reloading the same passwd file succeed.
+    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 0, CtsApi::reloadpasswdfile() << " should return 1\n");
+
+    // Invoking a client request that requires authorisation
+    BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
+    BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
+    BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
+    BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
+
+    // clear the password file.
+    errorMsg.clear();
+    BOOST_REQUIRE_MESSAGE(PasswdFile::clear(passwd_file, errorMsg), errorMsg);
+
+    // reload the password file, which is now empty
+    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 0, CtsApi::reloadpasswdfile() << " should return 1\n");
+
+    // all client command should now *FAIL*.
+    BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 1, "should return 1\n");
+    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 1, CtsApi::reloadpasswdfile() << " should return 1\n");
+
+    // Remove the white list file. Comment out for debug
+    fs::remove(passwd_file);
+}
+
+BOOST_AUTO_TEST_CASE(test_loading_of_passwd_fail) {
+    // TEST user *MUST* be in ECF_PASSWD file, into order to *ALLOW* reloadpasswdfile
+    Host the_host;
+    std::string host        = ClientEnvironment::hostSpecified();
+    std::string port        = SCPort::next();
+    std::string passwd_file = the_host.ecf_passwd_file(port);
+    std::string passwd      = "xxxx";
+    if (host.empty()) {
+        // make sure NO passed file is present before the server is started.
+        // Only do this locally, as passwd file on remote machine may not be accessible
+        fs::remove(passwd_file);
+    }
+    else {
+        // The test only works if server is started locally.
+        std::cout << "...Client:: ...test_loading_of_passwd_fail ignoring when HOST specified\n";
+        return;
+    }
+
+    // Set ECF_PASSWD environment variable. Use same file for client and server
+    // add on construction, and remove at destruction.
+    Add_ECF_PASSWD_env ecf_passwd(passwd_file);
+
+    // This will remove check pt and backup file before server start,
+    // to avoid the server from loading previous test data
+    InvokeServer invokeServer("Client:: ...test_loading_of_passwd_fail", port);
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    /// Passwd file is specified but does not exist. Command to succeed
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    theClient.set_throw_on_error(false);
+
+    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+
+    // OK now test passwd file functionality
+    // The passwd file should not exist, hence reload SHOULD fail. i.e because we deleted it earlier
+    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 1, CtsApi::reloadpasswdfile() << " should return 1\n");
+
+    // Create a valid passwd file; For the FIRST time:
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(PasswdFile::createWithAccess(passwd_file, the_host.name(), port, passwd, errorMsg), errorMsg);
+
+    //  Reload should STILL fail. Since reloadpasswdfile *ITSELF* requires authentication.
+    //  Hence user *MUST* be in ECF_PASSWD file, into order to *ALLOW* reloadpasswdfile
+    BOOST_REQUIRE_MESSAGE(theClient.reloadpasswdfile() == 1,
+                          CtsApi::reloadpasswdfile() << " should return 1\n"
+                                                     << theClient.errorMsg());
+
+    // Remove the white list file. Comment out for debug
+    fs::remove(passwd_file);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestPlugCmd.cpp 5.13.0-1/libs/client/test/TestPlugCmd.cpp
--- 5.12.4-1/libs/client/test/TestPlugCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestPlugCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,390 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"
+#include "ecflow/base/cts/user/PlugCmd.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+static void get_defs(Defs& defs) {
+    // suite suite1
+    //   family family1
+    //       task a
+    //         event 1 myEvent
+    //         meter myMeter 0 100
+    //       task b
+    //          trigger a == complete
+    //    endfamily
+    //    family family2
+    //          task aa
+    //             trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
+    //          task bb
+    //             trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
+    //     endfamily
+    // endsuite
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+    std::string errorMsg, warningMsg;
+    bool parse = defs.restore(path, errorMsg, warningMsg);
+    if (!parse)
+        std::cerr << errorMsg;
+    BOOST_CHECK(parse);
+}
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_PlugCmd)
+
+BOOST_AUTO_TEST_CASE(test_plug_cmd) {
+    cout << "Client:: ...test_plug_cmd" << endl;
+    TestLog test_log("test_plug_cmd.log"); // will create log file, and destroy log and remove file at end of scope
+
+    {
+        Defs defs;
+        get_defs(defs);
+
+        /// Test failure modes, MockServer defaults to localhost:3141
+        // test source node that does not exist, fails
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new PlugCmd("I/dont/exist/on/the server", "suite1/family2")));
+
+        // test dest node that does not exist, fails
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "i/dont/exist/on/server")));
+
+        // test source node same as dest node, fails
+        TestHelper::invokeFailureRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family1/a")));
+
+        // test dest node that matches local server host and port, but where path does not exist, fails
+        TestHelper::invokeFailureRequest(
+            &defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "//localhost:3141/i/dont/exist/on/local_server")));
+    }
+    {
+        Defs defs;
+        get_defs(defs);
+
+        // Lock server as another user. Invoke a valid request that should fail, due to a lock
+        MockServer server(&defs);
+        BOOST_REQUIRE_MESSAGE(server.lock("A user"), "Lock expected to succeed");
+        TestHelper::invokeFailureRequest(server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
+    }
+    {
+        Defs defs;
+        get_defs(defs);
+        MockServer server(&defs);
+
+        // Move the TASKS: on family1 --> family2
+        // Note: if on the destination node we select a task 'suite1/family2/aa', then node is moved to its parent
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new PlugCmd("suite1/family1/b", "//localhost:3141/suite1/family2/aa")));
+
+        node_ptr node = defs.findAbsNode("suite1/family1");
+        BOOST_REQUIRE_MESSAGE(node.get() && node->isFamily(), "Could not find suite1/family1");
+        BOOST_REQUIRE_MESSAGE(node->isFamily()->taskVec().size() == 0, "Failed to move task to other family");
+
+        node_ptr node2 = defs.findAbsNode("suite1/family2");
+        BOOST_REQUIRE_MESSAGE(node2.get() && node->isFamily(), "Could not find suite1/family2");
+        BOOST_REQUIRE_MESSAGE(node2->isFamily()->taskVec().size() == 4, "family2 two should have 4 tasks");
+    }
+
+    {
+        Defs defs;
+        get_defs(defs);
+        MockServer server(&defs);
+
+        // Move FAMILIES: Add a new suite and move family1 and  family2 to it.
+        defs.addSuite(Suite::create("suite2"));
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1", "suite2")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family2", "suite2")));
+
+        node_ptr suite1 = defs.findAbsNode("suite1");
+        BOOST_REQUIRE_MESSAGE(suite1.get() && suite1->isSuite(), "Could not find suite1");
+        BOOST_REQUIRE_MESSAGE(suite1->isSuite()->familyVec().size() == 0,
+                              "Expected suite1 to have '0' families as they should have been moved to suite2");
+
+        node_ptr suite2 = defs.findAbsNode("suite2");
+        BOOST_REQUIRE_MESSAGE(suite2.get() && suite2->isSuite(), "Could not find suite2");
+        BOOST_REQUIRE_MESSAGE(suite2->isSuite()->familyVec().size() == 2, "Expected suite2 to have '2' families");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_plug_cmd_preserves_server_state) {
+    cout << "Client:: ...test_plug_cmd_preserves_server_state" << endl;
+    TestLog test_log("test_plug_cmd_preserves_server_state.log"); // will create log file, and destroy log and remove
+                                                                  // file at end of scope
+
+    {
+        Defs defs;
+        get_defs(defs);
+        MockServer server(&defs);
+        server.shutdown();
+
+        // Move the TASKS: on family1 --> family2
+        TestHelper::invokeRequest(&server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
+
+        BOOST_CHECK_MESSAGE(server.state() == SState::SHUTDOWN,
+                            "Expected server state SHUTDOWN to be preserved after plug, but found state "
+                                << SState::to_string(server.state()));
+    }
+    {
+        Defs defs;
+        get_defs(defs);
+        MockServer server(&defs);
+        server.halted();
+
+        // Move the TASKS: on family1 --> family2
+        TestHelper::invokeRequest(&server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
+
+        BOOST_CHECK_MESSAGE(server.state() == SState::HALTED,
+                            "Expected server state HALTED to be preserved after plug, but found state "
+                                << SState::to_string(server.state()));
+    }
+    {
+        Defs defs;
+        get_defs(defs);
+        MockServer server(&defs);
+        server.restart();
+
+        // Move the TASKS: on family1 --> family2
+        TestHelper::invokeRequest(&server, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
+
+        BOOST_CHECK_MESSAGE(server.state() == SState::RUNNING,
+                            "Expected server state RUNNING to be preserved after plug, but found state "
+                                << SState::to_string(server.state()));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_plug_cmd_with_handles) {
+    cout << "Client:: ...test_plug_cmd_with_handles" << endl;
+    TestLog test_log(
+        "test_plug_cmd_with_handles.log"); // will create log file, and destroy log and remove file at end of scope
+
+    Defs defs;
+    get_defs(defs);
+
+    /// create client handle which references suites suite in the server defs
+    std::vector<std::string> suite_names;
+    suite_names.emplace_back("suite");
+    suite_names.emplace_back("suite2");
+    TestHelper::invokeRequest(
+        &defs, Cmd_ptr(new ClientHandleCmd(0, suite_names, false)), false /* bypass_state_modify_change_check */);
+
+    { // Move the TASKS: on family1 --> family2
+        // Note: if on the destination node we select a task 'suite1/family2/aa', then node is moved to its parent
+        Suite* suite                  = defs.findAbsNode("suite1")->isSuite();
+        unsigned int state_change_no  = suite->state_change_no();
+        unsigned int modify_change_no = suite->modify_change_no();
+
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1/a", "suite1/family2")));
+        TestHelper::invokeRequest(&defs,
+                                  Cmd_ptr(new PlugCmd("suite1/family1/b", "//localhost:3141/suite1/family2/aa")));
+
+        BOOST_CHECK_MESSAGE(state_change_no != suite->state_change_no() ||
+                                modify_change_no != suite->modify_change_no(),
+                            "state and modify change numbers unaltered by plug command when using handles");
+    }
+
+    { // Move FAMILIES: Add a new suite and move family1 and  family2 to it.
+        suite_ptr suite2              = defs.add_suite("suite2");
+        unsigned int state_change_no  = suite2->state_change_no();
+        unsigned int modify_change_no = suite2->modify_change_no();
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family1", "suite2")));
+        TestHelper::invokeRequest(&defs, Cmd_ptr(new PlugCmd("suite1/family2", "suite2")));
+        BOOST_CHECK_MESSAGE(state_change_no != suite2->state_change_no() ||
+                                modify_change_no != suite2->modify_change_no(),
+                            "state and modify change numbers unaltered by plug command when using handles");
+    }
+}
+
+static void test_plug_on_multiple_server(const std::string& host1,
+                                         const std::string& port1,
+                                         const std::string& host2,
+                                         const std::string& port2) {
+    std::cout << " on host1(" << host1 << ":" << port1 << ") host2(" << host2 << ":" << port2 << ")" << endl;
+    ClientInvoker server1Client(host1, port1);
+    server1Client.set_throw_on_error(false);
+    ClientInvoker server2Client(host2, port2);
+    server2Client.set_throw_on_error(false);
+
+    // std::cout << " restartServer the FIRST and SECOND servers" << endl;
+    BOOST_REQUIRE_MESSAGE(server1Client.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
+                                                  << server1Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server2Client.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
+                                                  << server2Client.errorMsg());
+
+    // std::cout << " LOAD the defs into FIRST server(" << host1 << ":" << port1 << ") There is NO DEFS in the second
+    // server." << endl;
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+    BOOST_REQUIRE_MESSAGE(server1Client.loadDefs(path) == 0, "load defs failed \n" << server1Client.errorMsg());
+
+    // cout << " Test the ERROR conditions in MoveCmd" << endl;
+    std::string sourcePath = "/suite1";
+    std::string secondServerHostPort =
+        "//localhost:" + port2; // The destination path must encode the host:port path to the second server
+
+    std::string destPath = secondServerHostPort + "/A/made/up/dest/path/that/does/not/exist/on/server2";
+    // cout << " Plug/Move from server1(" << host1 << ":" << port1 << ") to destination server " << destPath << endl;
+    int theResult = server1Client.plug(sourcePath, destPath);
+    BOOST_REQUIRE_MESSAGE(theResult == 1, CtsApi::plugArg() << "Expected to fail since no defs in server 2\n");
+    // 	std::cout << "Error message = " << server1Client.errorMsg() << "\n";
+
+    // cout << " *** Load Defs into SECOND server ***, ie both servers have the same definitions" << endl;
+    BOOST_REQUIRE_MESSAGE(server2Client.loadDefs(path) == 0, "load defs failed \n" << server2Client.errorMsg());
+
+    destPath  = secondServerHostPort + "/suite1";
+    theResult = server1Client.plug(sourcePath, destPath);
+    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
+    BOOST_REQUIRE_MESSAGE(theResult == 1,
+                          CtsApi::plugArg() << " Expected to fail, since 'suite1' already exists in the server  \n");
+
+    destPath  = secondServerHostPort + "/suite1/family1";
+    theResult = server1Client.plug(sourcePath, destPath);
+    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
+    BOOST_REQUIRE_MESSAGE(theResult == 1,
+                          CtsApi::plugArg() << " Expected to fail, since can't move a suite into a family\n");
+
+    destPath  = secondServerHostPort + "/suite1";
+    theResult = server1Client.plug("/suite1/family1", destPath);
+    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
+    BOOST_REQUIRE_MESSAGE(theResult == 1,
+                          CtsApi::plugArg() << " Expected to fail, Destination already has a family1 \n");
+
+    destPath  = secondServerHostPort + "/A/made/up/dest/path/that/does/not/exist/on/server2";
+    theResult = server1Client.plug(sourcePath, destPath);
+    //  	cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
+    BOOST_REQUIRE_MESSAGE(theResult == 1,
+                          CtsApi::plugArg() << " Expected to fail, since destination path does not exist\n");
+
+    destPath  = secondServerHostPort;
+    theResult = server1Client.plug("/suite1/family1", destPath);
+    //  cout << "server1Client.errorMsg() = " << server1Client.errorMsg() << "\n";
+    BOOST_REQUIRE_MESSAGE(
+        theResult == 1,
+        CtsApi::plugArg()
+            << " Expected to fail,since source path must be a suite, if the destination path name is empty\n");
+
+    // ==========================================================================================
+    // Test Plug command works
+    // ==========================================================================================
+
+    // Completely remove the 'suite1' file in the second server
+    BOOST_REQUIRE_MESSAGE(server2Client.delete_node(sourcePath) == 0,
+                          CtsApi::to_string(CtsApi::delete_node(sourcePath)) << " failed \n"
+                                                                             << server2Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server2Client.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << server2Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server2Client.defs().get(), "Server returned a NULL defs");
+    BOOST_REQUIRE_MESSAGE(server2Client.defs()->suiteVec().size() == 0, " Expected server2 to have zero suite");
+
+    // Move the suite FROM the FIRST server TO the SECOND server and check that it worked
+    destPath  = secondServerHostPort;
+    theResult = server1Client.plug(sourcePath, destPath);
+    BOOST_REQUIRE_MESSAGE(theResult == 0, CtsApi::plugArg() << " failed \n" << server1Client.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(server1Client.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << server1Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server1Client.defs().get(), "Server returned a NULL defs");
+    BOOST_REQUIRE_MESSAGE(server1Client.defs()->suiteVec().size() == 0, " Expected server1 to have no suites");
+
+    BOOST_REQUIRE_MESSAGE(server2Client.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << server2Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server2Client.defs().get(), "Server returned a NULL defs");
+    BOOST_REQUIRE_MESSAGE(server2Client.defs()->suiteVec().size() == 1, " Expected server2 to have one suite");
+
+    // ==========================================================================
+    // Do it again, but with no defs file in second server. reload defs into server1
+    BOOST_REQUIRE_MESSAGE(server1Client.delete_all() == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " failed \n"
+                                                                   << server1Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server2Client.delete_all() == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " failed \n"
+                                                                   << server2Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server1Client.loadDefs(path) == 0, "load defs failed \n" << server1Client.errorMsg());
+
+    destPath  = secondServerHostPort;
+    theResult = server1Client.plug(sourcePath, destPath);
+    BOOST_REQUIRE_MESSAGE(theResult == 0, CtsApi::plugArg() << " failed \n" << server1Client.errorMsg());
+
+    BOOST_REQUIRE_MESSAGE(server1Client.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << server1Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server1Client.defs().get(), "Server returned a NULL defs");
+    BOOST_REQUIRE_MESSAGE(server1Client.defs()->suiteVec().size() == 0, " Expected server1 to have no suites");
+
+    BOOST_REQUIRE_MESSAGE(server2Client.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << server2Client.errorMsg());
+    BOOST_REQUIRE_MESSAGE(server2Client.defs().get(), "Server returned a NULL defs");
+    BOOST_REQUIRE_MESSAGE(server2Client.defs()->suiteVec().size() == 1, " Expected server2 to have one suite");
+}
+
+BOOST_AUTO_TEST_CASE(test_server_plug_cmd) {
+    if (ClientEnvironment::hostSpecified().empty()) {
+
+        cout << "Client:: ...test_server_plug_cmd";
+
+        // Invoke two servers. *which* will both terminate at the end of this scope
+        // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+        // data
+        InvokeServer invokeServer1("", SCPort::next());
+        InvokeServer invokeServer2("", SCPort::next());
+        BOOST_REQUIRE_MESSAGE(invokeServer1.server_started(),
+                              "Server failed to start on " << invokeServer1.host() << ":" << invokeServer1.port());
+        BOOST_REQUIRE_MESSAGE(invokeServer2.server_started(),
+                              "Server failed to start on " << invokeServer2.host() << ":" << invokeServer2.port());
+
+        test_plug_on_multiple_server(
+            invokeServer1.host(), invokeServer1.port(), invokeServer2.host(), invokeServer2.port());
+    }
+    else {
+
+        cout << "Client:: ...test_server_plug_cmd";
+
+        // Remote server all ready running, start one more additional server
+        {
+            // remove any suites on the remote server. Since this test requires it.
+            ClientInvoker theClient(ClientEnvironment::hostSpecified(), ClientEnvironment::portSpecified());
+            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                                  CtsApi::to_string(CtsApi::delete_node())
+                                      << " failed should return 0. Should Delete ALL existing defs in the server\n"
+                                      << theClient.errorMsg());
+        }
+
+        // Start additional local server, special constructor. need false flag, to avoid ambiguity, with the other
+        // constructor.
+        std::string port2 = SCPort::next_only();
+        InvokeServer invokeServer2(port2, false);
+        BOOST_REQUIRE_MESSAGE(invokeServer2.server_started(),
+                              "Server failed to start on " << invokeServer2.host() << ":" << invokeServer2.port());
+
+        test_plug_on_multiple_server(
+            ClientEnvironment::hostSpecified(), ClientEnvironment::portSpecified(), Str::LOCALHOST(), port2);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestRtt.cpp 5.13.0-1/libs/client/test/TestRtt.cpp
--- 5.12.4-1/libs/client/test/TestRtt.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestRtt.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,51 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/client/Rtt.hpp"
+#include "ecflow/core/File.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_Rtt)
+
+BOOST_AUTO_TEST_CASE(test_client_invoker_round_trip_times) {
+    cout << "Client:: ...test_client_invoker_round_trip_times" << endl;
+
+    std::string root_path = File::test_data("libs/client/test/data/", "libs/client");
+
+    /// Open file rtt.dat and compute average round trip times
+    std::string result = Rtt::analyis(root_path + "rtt.dat");
+    // cout << result << "\n";
+
+    /// generated a file with results
+    std::string errorMsg;
+    string generated_file = root_path + "rtt_analysis.dat";
+    BOOST_CHECK_MESSAGE(File::create(generated_file, result, errorMsg), errorMsg);
+
+    /// Compare with a reference file
+    std::vector<std::string> ignoreVec;
+    errorMsg.clear();
+    std::string diffs = File::diff(generated_file, root_path + "ref_analysis.dat", ignoreVec, errorMsg);
+    BOOST_CHECK_MESSAGE(diffs.empty(), diffs << "\n" << errorMsg);
+
+    if (diffs.empty())
+        fs::remove(generated_file);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestServer.cpp 5.13.0-1/libs/client/test/TestServer.cpp
--- 5.12.4-1/libs/client/test/TestServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,607 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
+#include <boost/test/unit_test.hpp>
+#include <boost/timer/timer.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/core/perf_timer.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_Server)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+//
+// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
+//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
+//       is specified then *don't* shutdown the server
+// ************************************************************************************
+
+BOOST_AUTO_TEST_CASE(test_server_version) {
+    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+    InvokeServer invokeServer("Client:: ...test_server_version:", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.server_version() == 0, "server version\n" << theClient.errorMsg());
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // This check only valid if server was invoked locally. Ignore for remote servers
+        BOOST_REQUIRE_MESSAGE(theClient.get_string() == Version::raw(),
+                              "Expected client version(" << Version::raw() << ") to match server version("
+                                                         << theClient.get_string() << ")");
+    }
+    else {
+        // remote server, version may be different
+        BOOST_WARN_MESSAGE(theClient.get_string() == Version::raw(),
+                           "Client version(" << Version::raw() << ") does not match server version("
+                                             << theClient.get_string() << ")");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_server_state_changes) {
+    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+    InvokeServer invokeServer("Client:: ...test_server_state_changes:", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << theClient.errorMsg());
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // server started locally
+        BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
+                              "Expected INITIAL server state HALTED but found "
+                                  << SState::to_string(theClient.defs()->server().get_state()));
+    }
+
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::SHUTDOWN,
+                          "Expected server state SHUTDOWN but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
+                          "Expected server state HALTED but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                          CtsApi::get() << " failed should return 0\n"
+                                        << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::RUNNING,
+                          "Expected server state RUNNING but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    /// Repeat test using sync_local() to test incremental changes of server
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, " failed should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::SHUTDOWN,
+                          "Expected server state SHUTDOWN but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, " failed should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
+                          "Expected server state HALTED but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, " failed should return 0\n" << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::RUNNING,
+                          "Expected server state RUNNING but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // This check only valid if server was invoked locally. Ignore for remote servers
+
+        // make sure edit history updated
+        BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
+                              CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
+                                                                                        << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 7,
+                              "Expected edit history of size 7, but found "
+                                  << theClient.server_reply().get_string_vec().size());
+
+        // make sure edit history was *NOT* serialized, It is only serialized when check pointing
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.defs()->get_edit_history(Str::ROOT_PATH()).size() == 0,
+                              "Expected edit history of size 0, but found "
+                                  << theClient.defs()->get_edit_history(Str::ROOT_PATH()).size());
+
+        // clear edit history
+        BOOST_REQUIRE_MESSAGE(theClient.edit_history("clear") == 0,
+                              CtsApi::to_string(CtsApi::edit_history("clear")) << " should return 0\n"
+                                                                               << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
+                              CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
+                                                                                        << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 0,
+                              "Expected no edit history " << theClient.server_reply().get_string_vec().size());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_server_state_changes_with_auto_sync) {
+    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+    InvokeServer invokeServer("Client:: ...test_server_state_changes_with_auto_sync:", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    theClient.set_auto_sync(true);
+
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // server started locally
+        BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
+                              "Expected INITIAL server state HALTED but found "
+                                  << SState::to_string(theClient.defs()->server().get_state()));
+    }
+
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::SHUTDOWN,
+                          "Expected server state SHUTDOWN but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::HALTED,
+                          "Expected server state HALTED but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.defs()->server().get_state() == SState::RUNNING,
+                          "Expected server state RUNNING but found "
+                              << SState::to_string(theClient.defs()->server().get_state()));
+
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // This check only valid if server was invoked locally. Ignore for remote servers
+
+        // make sure edit history updated
+        BOOST_REQUIRE_MESSAGE(theClient.edit_history(Str::ROOT_PATH()) == 0,
+                              CtsApi::to_string(CtsApi::edit_history(Str::ROOT_PATH())) << " should return 0\n"
+                                                                                        << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.server_reply().get_string_vec().size() == 8 &&
+                                  theClient.server_reply().get_string_vec().size() <=
+                                      Defs::max_edit_history_size_per_node(),
+                              "Expected edit history of size 8, but found "
+                                  << theClient.server_reply().get_string_vec().size() << "\n"
+                                  << Str::dump_string_vec(theClient.server_reply().get_string_vec()));
+
+        // make sure edit history was *NOT* serialized, It is only serialized when check pointing
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.defs()->get_edit_history(Str::ROOT_PATH()).size() == 0,
+                              "Expected edit history of size 0, but found "
+                                  << theClient.defs()->get_edit_history(Str::ROOT_PATH()).size());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_server_stress_test) {
+    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+    InvokeServer invokeServer("Client:: ...test_server_stress_test:", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    int load = 125;
+#ifdef ECF_OPENSSL
+    if (getenv("ECF_SSL"))
+        load = 30;
+#endif
+
+    {
+        boost::timer::cpu_timer boost_timer;
+        DurationTimer duration_timer;
+        Timer<std::chrono::milliseconds> chrono_timer;
+        for (int i = 0; i < load; i++) {
+
+            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                                  CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                           << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.suspend("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.resume("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                                  CtsApi::shutdownServer() << " should return 0\n"
+                                                           << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                                  CtsApi::haltServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                                  CtsApi::restartServer() << " should return 0\n"
+                                                          << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "unknown", true) == 0,
+                                  "check should return 0\n"
+                                      << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+
+            BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
+            BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
+        }
+        cout << " Server handled " << load * 16 << " requests in boost_timer("
+             << boost_timer.format(3, Str::cpu_timer_format()) << ")"
+             << " DurationTimer(" << to_simple_string(duration_timer.elapsed()) << ")"
+             << " Chrono_timer(" << std::chrono::duration<double, std::milli>(chrono_timer.elapsed()).count()
+             << " milli)" << endl;
+    }
+    {
+        theClient.set_auto_sync(true);
+        boost::timer::cpu_timer
+            boost_timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        DurationTimer duration_timer;
+        Timer<std::chrono::milliseconds> chrono_timer;
+        for (int i = 0; i < load; i++) {
+
+            BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                                  CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                           << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.suspend("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.resume("/suite1") == 0, "should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                                  CtsApi::shutdownServer() << " should return 0\n"
+                                                           << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                                  CtsApi::haltServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                                  CtsApi::restartServer() << " should return 0\n"
+                                                          << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "unknown", true) == 0,
+                                  "check should return 0\n"
+                                      << theClient.errorMsg());
+
+            BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
+            BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
+        }
+        cout << " Server handled " << load * 8 << " requests in boost_timer("
+             << boost_timer.format(3, Str::cpu_timer_format()) << ")"
+             << " DurationTimer(" << to_simple_string(duration_timer.elapsed()) << ")"
+             << " Chrono_timer(" << std::chrono::duration<double, std::milli>(chrono_timer.elapsed()).count()
+             << " milli)"
+             << " *with* AUTO SYNC" << endl;
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_server_group_stress_test) {
+    /// This is exactly the same test as above, but uses the group command
+    /// This should be faster as the network traffic should be a lot less
+    InvokeServer invokeServer("Client:: ...test_server_group_stress_test:", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    boost::timer::cpu_timer
+        boost_timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+    DurationTimer duration_timer;
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+
+    std::string groupRequest = CtsApi::to_string(CtsApi::delete_node());
+    groupRequest += ";";
+    groupRequest += CtsApi::to_string(CtsApi::loadDefs(path, true /*force*/, false /*check_only*/, false /*print*/));
+    groupRequest += ";";
+    groupRequest += CtsApi::shutdownServer();
+    groupRequest += ";";
+    groupRequest += CtsApi::haltServer();
+    groupRequest += ";";
+    groupRequest += CtsApi::restartServer();
+    groupRequest += ";";
+    groupRequest += CtsApi::restartServer();
+    groupRequest += ";";
+    groupRequest += CtsApi::checkPtDefs();
+    groupRequest += ";";
+    groupRequest += CtsApi::get();
+
+    // cout << "groupRequest = " << groupRequest << "\n";
+
+    int load = 125;
+#ifdef ECF_OPENSSL
+    if (getenv("ECF_SSL"))
+        load = 30;
+#endif
+
+    for (int i = 0; i < load; i++) {
+        BOOST_REQUIRE_MESSAGE(theClient.group(groupRequest) == 0,
+                              "Group request " << CtsApi::group(groupRequest) << " failed should return 0\n"
+                                               << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
+        BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
+    }
+    cout << " Server handled " << load * 8 << " commands using " << load << " group requests in boost_timer("
+         << boost_timer.format(3, Str::cpu_timer_format()) << ") DurationTimer("
+         << to_simple_string(duration_timer.elapsed()) << ")" << endl;
+}
+
+BOOST_AUTO_TEST_CASE(test_server_stress_test_2) {
+    /// More extensive stress test, using as many user based command as possible.
+    ///
+    /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+    InvokeServer invokeServer("Client:: ...test_server_stress_test_2:", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    Zombie z(Child::USER,
+             ecf::Child::INIT,
+             ZombieAttr::get_default_attr(Child::USER),
+             "path_to_task",
+             "DUMMY_JOBS_PASSWORD",
+             "DUMMY_PROCESS_OR_REMOTE_ID",
+             1,
+             "host");
+    std::vector<std::string> suites;
+    suites.emplace_back("suite1");
+    suites.emplace_back("made_up_suite");
+
+    std::vector<std::string> nodes_to_delete;
+    nodes_to_delete.emplace_back("/suite1/family2/aa"); // these should exist in lifecycle.txt
+    nodes_to_delete.emplace_back("/suite1/family2/bb");
+
+#if defined(HPUX)
+    int load = 10; // On non linux systems use different load otherwise it takes to long
+#elif defined(_AIX)
+    int load = 65; // On non linux systems use different load otherwise it takes to long
+#else
+    int load = 130;
+#endif
+
+#ifdef ECF_OPENSSL
+    if (getenv("ECF_SSL"))
+        load = 10;
+#endif
+
+    boost::timer::cpu_timer
+        boost_timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+    DurationTimer duration_timer;
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    theClient.set_throw_on_error(false);
+
+    for (int i = 0; i < load; i++) {
+
+        BOOST_REQUIRE_MESSAGE(theClient.pingServer() == 0, " ping should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                              CtsApi::shutdownServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                              CtsApi::haltServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.news_local() == 0,
+                              " new local failed should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "failed should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.stats() == 0, CtsApi::stats() << " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.stats_server() == 0,
+                              CtsApi::stats_server() << " should return 0\n"
+                                                     << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.suites() == 0,
+                              CtsApi::suites() << " should return 0\n"
+                                               << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.server_version() == 0,
+                              CtsApi::server_version() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.debug_server_off() == 0,
+                              CtsApi::debug_server_off() << " should return 0\n"
+                                                         << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.check("/suite1") == 0, "check should return 0\n" << theClient.errorMsg()); // 13
+
+        BOOST_REQUIRE_MESSAGE(theClient.logMsg("start") == 0, "log msg should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.get_log_path() == 0, "get_log_path should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.getLog(1) == 0, "get_log last line should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.flushLog() == 0, "flushLog should return 0\n" << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "unknown", true) == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "complete", true) == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "submitted", true) == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "active", true) == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "aborted", true) == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1", "queued", true) == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1/family1/a:myEvent", "set") == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.force("/suite1/family1/a:myEvent", "clear") == 0,
+                              "check should return 0\n"
+                                  << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.zombieGet() == 0,
+                              CtsApi::zombieGet() << " should return 0\n"
+                                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.zombieFob(z) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.zombieFail(z) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.zombieAdopt(z) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.zombieBlock(z) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.zombieRemove(z) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.zombieKill(z) == 0, " should return 0\n" << theClient.errorMsg()); // 19
+
+        BOOST_REQUIRE_MESSAGE(theClient.suspend("/suite1") == 0,
+                              CtsApi::to_string(CtsApi::suspend("/suite1")) << " should return 0\n"
+                                                                            << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.resume("/suite1") == 0,
+                              CtsApi::to_string(CtsApi::resume("/suite1")) << " should return 0\n"
+                                                                           << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.edit_history("/suite1") == 0,
+                              CtsApi::to_string(CtsApi::edit_history("/suite1")) << " should return 0\n"
+                                                                                 << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, true, true) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.replace("/suite1", path, false, true) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg()); // 26
+
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs() == 0,
+                              CtsApi::checkPtDefs() << " should return 0\n"
+                                                    << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::NEVER) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ALWAYS) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, 180) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::UNDEFINED) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg()); // 32
+        BOOST_REQUIRE_MESSAGE(theClient.checkPtDefs(ecf::CheckPt::ON_TIME, CheckPt::default_interval()) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1") == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", true, true, true, true) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", true) == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", false, true) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", false, false, true) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.freeDep("/suite1", false, false, false, true) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg()); // 38
+
+        BOOST_REQUIRE_MESSAGE(theClient.ch_register(true, suites) == 0, "--ch_register \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_suites() == 0, "--ch_suites should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_add(1, suites) == 0, "--ch_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_remove(1, suites) == 0, "--ch_remove \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, true) == 0, "--ch_auto_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_auto_add(1, false) == 0, "--ch_auto_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch_drop(1) == 0, "--ch_drop should return 0\n" << theClient.errorMsg()); // 45
+
+        BOOST_REQUIRE_MESSAGE(theClient.ch_register(true, suites) == 0, "--ch_register \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_add(suites) == 0, "--ch1_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(true) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_auto_add(false) == 0, "--ch1_auto_add \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_remove(suites) == 0, "--ch1_remove \n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.ch1_drop() == 0, "--ch1_drop \n" << theClient.errorMsg()); // 51
+
+        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", "top") == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", "bottom") == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", "alpha") == 0, " should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", NOrder::ORDER) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", NOrder::UP) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.order("/suite1", NOrder::DOWN) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg()); // 57
+
+        BOOST_REQUIRE_MESSAGE(theClient.delete_node("/suite1/family1/a") == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.delete_nodes(nodes_to_delete) == 0,
+                              " should return 0\n"
+                                  << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg()); // 60
+        BOOST_REQUIRE_MESSAGE(theClient.defs().get(), "Server returned a NULL defs");
+        BOOST_REQUIRE_MESSAGE(theClient.defs()->suiteVec().size() >= 1, "  no suite ?");
+    }
+
+    int no_of_client_calls = 74;
+
+    cout << " Server handled " << load * no_of_client_calls << " requests in boost_timer("
+         << boost_timer.format(3, Str::cpu_timer_format()) << ") DurationTimer("
+         << to_simple_string(duration_timer.elapsed()) << ")" << endl;
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestServerAndLifeCycle.cpp 5.13.0-1/libs/client/test/TestServerAndLifeCycle.cpp
--- 5.12.4-1/libs/client/test/TestServerAndLifeCycle.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestServerAndLifeCycle.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,296 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp" // kill singleton for valgrind
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_ServerAndLifeCycle)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+//
+// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
+//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
+//       is specified then *don't* shutdown the server
+// ************************************************************************************
+
+BOOST_AUTO_TEST_CASE(test_client_lifecyle) {
+    // *******************************************************************************************
+    // This test will *ONLY* work when testing with new server invocation, since it relies
+    // on disabling job generation. Hence ignore test if ECF_HOST has been defined
+    // *******************************************************************************************
+    std::string host = ClientEnvironment::hostSpecified();
+    if (!host.empty()) {
+        // Server allready started, since we cant disable job generation ignore this test
+        std::cout << "Client:: ...test_client_lifecycle, ignoring test when ECF_HOST specified..." << endl;
+        return;
+    }
+
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+    // ** NOTE: We disable job generation in the server **/
+    InvokeServer invokeServer(
+        "Client:: ...test_client_lifecycle", SCPort::next(), true /*disable job generation in server*/);
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
+                                                  << theClient.errorMsg());
+
+    // load the defs into the server
+    {
+        std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "Load defs failed \n" << theClient.errorMsg());
+    }
+    {
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "Server returned a NULL defs");
+        BOOST_REQUIRE_MESSAGE(serverDefs->suiteVec().size() >= 1, "  no suite ?");
+    }
+
+    // Now go through and simulate client request to change Node tree state.
+    // This is **highly** dependent on lifecycle.txt
+    //	suite suite1
+    //	  family family1
+    //	   	task a
+    //	        event 1 myEvent
+    //	        meter myMeter 0 100
+    //	   	task b
+    //	   		trigger a == complete
+    //	   endfamily
+    //	   family family2
+    //	   		task aa
+    //	   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent
+    //	   		task bb
+    //	   			trigger ../family1/a:myMeter >= 50 || ../family1/a:myEvent
+    //	    endfamily
+    //	endsuite
+
+    string suite1_family1_a  = "suite1/family1/a";
+    string suite1_family1_b  = "suite1/family1/b";
+    string suite1_family2_aa = "suite1/family2/aa";
+    string suite1_family2_bb = "suite1/family2/bb";
+
+    {
+        // Begin will set all states to queued and then start job submission placing
+        // any submitted jobs into the active state. Note server setup has disabled job generation
+        BOOST_REQUIRE_MESSAGE(theClient.begin("suite1") == 0,
+                              CtsApi::begin("suite1") << " failed should return 0\n"
+                                                      << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+        defs_ptr serverDefs = theClient.defs();
+        node_ptr node       = serverDefs->findAbsNode(suite1_family1_a);
+
+        // Occasionally we get a random failure here. I suspect this is because the job generation caused by the
+        // BeginCmd, is such that the
+        //     time_now >= next_poll_time_   //* next_poll_time_ should always be at the minute interval
+        // When this happens, we defer job generation for a second:  See
+        // NodeTreeTraverser::traverse_node_tree_and_job_generate: line 343 Added time to confirm. If this the case, run
+        // test when not at/near minute interval
+        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be "
+                                  << NState::toString(node->state()) << " time now:" << Calendar::second_clock_time());
+    }
+
+    //**********************************************************************
+    // Create a request to set the event on Node suite1/family1/a
+    // This should place suite1_family2_bb immediately into submitted state
+    // Since we at least one node in submitted, suite should be in SUBMITTED state
+    {
+        theClient.taskPath(suite1_family1_a);
+        theClient.set_jobs_password(Submittable::DUMMY_JOBS_PASSWORD());
+        BOOST_REQUIRE_MESSAGE(theClient.eventTask("myEvent") == 0, " failed should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                              CtsApi::forceDependencyEval() << " failed should return 0\n"
+                                                            << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+        defs_ptr serverDefs = theClient.defs();
+        // PrintStyle style(PrintStyle::STATE);
+        // 		cerr << *serverDefs.get() << "\n";
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        node_ptr node = serverDefs->findAbsNode(suite1_family1_a);
+        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(node->state()));
+        node_ptr nodeb = serverDefs->findAbsNode(suite1_family2_bb);
+        BOOST_REQUIRE_MESSAGE(nodeb->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeb->state()));
+    }
+
+    //**********************************************************************
+    // Create a request to set the Meter on Node suite1/family1/a
+    // This should force suite1_family2_aa immediately into submitted state
+    // This should force suite1_family2_bb immediately into submitted state
+    {
+        theClient.taskPath(suite1_family1_a);
+        {
+            char* argv[] = {
+                const_cast<char*>("ClientInvoker"), const_cast<char*>("--meter=myMeter"), const_cast<char*>("100")};
+            BOOST_REQUIRE_MESSAGE(theClient.invoke(3, argv) == 0, " should return 0\n" << theClient.errorMsg());
+            BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                                  CtsApi::forceDependencyEval() << " failed should return 0\n"
+                                                                << theClient.errorMsg());
+        }
+
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        node_ptr nodeaa = serverDefs->findAbsNode(suite1_family2_aa);
+        BOOST_REQUIRE_MESSAGE(nodeaa->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodeaa->state()));
+
+        node_ptr nodebb = serverDefs->findAbsNode(suite1_family2_bb);
+        BOOST_REQUIRE_MESSAGE(nodebb->state() == NState::ACTIVE,
+                              "Node expected NState::ACTIVE, but found to be " << NState::toString(nodebb->state()));
+    }
+
+    //**********************************************************************
+    // Create a request to complete task suite1/family1/a
+    // This should force suite1_family1_b to complete
+    {
+        theClient.taskPath(suite1_family1_a);
+        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
+                              TaskApi::complete() << " failed should return 0\n"
+                                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                              CtsApi::forceDependencyEval() << " failed should return 0\n"
+                                                            << theClient.errorMsg());
+
+        // Resolve dependencies
+        // We could either wait 60 second or
+        // added a custom command that will force dependency evaluation
+        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                              "--force-dep-eval failed should return 0\n"
+                                  << theClient.errorMsg());
+
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        node_ptr node = serverDefs->findAbsNode(suite1_family1_b);
+        BOOST_REQUIRE_MESSAGE(node->state() == NState::ACTIVE,
+                              "Expected NState::ACTIVE, but found " << NState::toString(node->state()));
+    }
+
+    //********************************************************************************
+    // Complete the remaining tasks. Should really call init first, but what the eck.
+    {
+        theClient.taskPath(suite1_family1_b);
+        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
+                              TaskApi::complete() << " failed should return 0\n"
+                                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                              CtsApi::forceDependencyEval() << " failed should return 0\n"
+                                                            << theClient.errorMsg());
+
+        theClient.taskPath(suite1_family2_aa);
+        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
+                              TaskApi::complete() << " failed should return 0\n"
+                                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                              CtsApi::forceDependencyEval() << " failed should return 0\n"
+                                                            << theClient.errorMsg());
+
+        theClient.taskPath(suite1_family2_bb);
+        BOOST_REQUIRE_MESSAGE(theClient.completeTask() == 0,
+                              TaskApi::complete() << " failed should return 0\n"
+                                                  << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.forceDependencyEval() == 0,
+                              CtsApi::forceDependencyEval() << " failed should return 0\n"
+                                                            << theClient.errorMsg());
+    }
+
+    {
+        // Get the node tree back from the server, and check its node state
+        // All node state should be complete. + check meter/event value was set properly
+        BOOST_REQUIRE_MESSAGE(theClient.getDefs() == 0,
+                              CtsApi::get() << " failed should return 0\n"
+                                            << theClient.errorMsg());
+
+        defs_ptr serverDefs = theClient.defs();
+        BOOST_REQUIRE_MESSAGE(serverDefs.get(), "get command failed to get node tree from server");
+
+        std::string metername = "myMeter";
+        int meterValue        = 100;
+        node_ptr node         = serverDefs->findAbsNode(suite1_family1_a);
+        const Meter& theMeter = node->findMeter(metername);
+        BOOST_REQUIRE_MESSAGE(!theMeter.empty(), "Could not find the meter");
+        BOOST_REQUIRE_MESSAGE(theMeter.value() == meterValue,
+                              "Expected meter value " << meterValue << " but found " << theMeter.value());
+        {
+            std::string errorMsg;
+            BOOST_REQUIRE_MESSAGE(serverDefs->checkInvariants(errorMsg), errorMsg);
+        }
+
+        std::string eventname = "myEvent";
+        const Event& theEvent = node->findEventByNameOrNumber(eventname);
+        BOOST_REQUIRE_MESSAGE(!theEvent.empty(), "Could not find the event myEvent");
+        BOOST_REQUIRE_MESSAGE(theEvent.value(), "The event was not set");
+
+        const std::vector<suite_ptr>& suiteVec = serverDefs->suiteVec();
+        suite_ptr suite                        = suiteVec.back();
+        BOOST_REQUIRE_MESSAGE(suite->state() == NState::COMPLETE,
+                              "Suite expected NState::COMPLETE, but found to be " << NState::toString(suite->state()));
+    }
+
+    {
+        // Check that a log file was created, by asking the server for it.
+        BOOST_REQUIRE_MESSAGE(theClient.getLog() == 0, "get log failed should return 0\n" << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(!theClient.get_string().empty(), "The log file returned from the server is empty!!");
+
+        // Clear the log
+        BOOST_REQUIRE_MESSAGE(theClient.flushLog() == 0,
+                              CtsApi::flushLog() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.clearLog() == 0,
+                              CtsApi::clearLog() << " failed should return 0\n"
+                                                 << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+    }
+
+    /// Destroy singleton's to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestServerLoad.cpp 5.13.0-1/libs/client/test/TestServerLoad.cpp
--- 5.12.4-1/libs/client/test/TestServerLoad.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestServerLoad.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,138 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/File.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_ServerLoad)
+
+BOOST_AUTO_TEST_CASE(test_server_load) {
+    // Check if gnuplot is found on the path, on the RPM machines gnuplot not always installed
+    std::string path_to_gnuplot = File::which("gnuplot");
+    if (path_to_gnuplot.empty()) {
+        cout << "Client:: ...test_server_load -----> gnuplot not found on $PATH *IGNORING* test\n";
+        return;
+    }
+
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+    InvokeServer invokeServer("Client:: ...test_server_load", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+
+    // add some text in log file, need at least 4 different time-stamps for plotting
+    int load = 2;
+    for (int i = 0; i < load; i++) {
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                              CtsApi::shutdownServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                              CtsApi::haltServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+    }
+    sleep(1); // need a time gap
+    for (int i = 0; i < load; i++) {
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                              CtsApi::shutdownServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                              CtsApi::haltServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+    }
+    sleep(1); // need a time gap
+    for (int i = 0; i < load; i++) {
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                              CtsApi::shutdownServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                              CtsApi::haltServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+    }
+    sleep(1); // need a time gap
+    for (int i = 0; i < load; i++) {
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                              CtsApi::shutdownServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                              CtsApi::haltServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+    }
+
+    // Now generate gnuplot files.
+    BOOST_REQUIRE_MESSAGE(theClient.server_load() == 0,
+                          CtsApi::server_load_arg() << " should return 0 server not started, or connection refused\n"
+                                                    << theClient.errorMsg());
+
+    // Check files were created
+    Host the_host(invokeServer.host());
+    std::string gnuplot_dat_file    = the_host.prefix_host_and_port(invokeServer.port(), "gnuplot.dat");
+    std::string gnuplot_script_file = the_host.prefix_host_and_port(invokeServer.port(), "gnuplot.script");
+    std::string gnuplot_png_file    = the_host.prefix_host_and_port(invokeServer.port(), "png");
+
+    BOOST_REQUIRE_MESSAGE(fs::exists(gnuplot_dat_file),
+                          CtsApi::server_load_arg() << " failed file(" << gnuplot_dat_file << ") not generated");
+    BOOST_REQUIRE_MESSAGE(fs::exists(gnuplot_script_file),
+                          CtsApi::server_load_arg() << " failed file(" << gnuplot_script_file << ") not generated");
+    BOOST_REQUIRE_MESSAGE(fs::exists(gnuplot_png_file),
+                          CtsApi::server_load_arg() << " failed file(" << gnuplot_png_file << ") not generated");
+
+    BOOST_REQUIRE_MESSAGE(fs::file_size(gnuplot_dat_file) != 0,
+                          "Expected file(" << gnuplot_dat_file << ") to have file size > 0  ");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(gnuplot_script_file) != 0,
+                          "Expected file(" << gnuplot_script_file << ") to have file size > 0  ");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(gnuplot_png_file) != 0,
+                          "Expected file(" << gnuplot_png_file << ") to have file size > 0  ");
+
+    // remove generated gnuplot files.
+    fs::remove(gnuplot_dat_file);
+    fs::remove(gnuplot_script_file);
+    fs::remove(gnuplot_png_file);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestSignalSIGTERM.cpp 5.13.0-1/libs/client/test/TestSignalSIGTERM.cpp
--- 5.12.4-1/libs/client/test/TestSignalSIGTERM.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestSignalSIGTERM.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,113 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_SignalSIGTERM)
+
+static void wait_for_sigterm_in_server(ClientInvoker& theClient) {
+    int count = 0;
+    while (1) {
+        count++;
+        sleep(1);
+        BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Sync local failed\n" << theClient.errorMsg());
+        if (theClient.defs()->get_flag().is_set(ecf::Flag::ECF_SIGTERM)) {
+            // cout << "break after " << count << "s\n";
+            break;
+        }
+        BOOST_REQUIRE_MESSAGE(count > 9, "Server never received SIGTERM after 9 seconds");
+    }
+}
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+//
+// This test will send a signal SIGTERM, i.e (via kill -15 pid) and check to ensure
+// that a check point file is saved.
+// ************************************************************************************
+BOOST_AUTO_TEST_CASE(test_signal_SIGTERM) {
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+    InvokeServer invokeServer("Client:: ...test_signal_SIGTERM", SCPort::next());
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0 server not started, or connection refused\n"
+                                                  << theClient.errorMsg());
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+    BOOST_REQUIRE_MESSAGE(theClient.loadDefs(path) == 0, "load defs failed \n" << theClient.errorMsg());
+
+    // Get the definition
+    BOOST_REQUIRE_MESSAGE(theClient.sync_local() == 0, "Sync local failed\n" << theClient.errorMsg());
+
+    // Get the process id of the server
+    const std::string& ecf_pid = theClient.defs()->server().find_variable("ECF_PID");
+    BOOST_REQUIRE_MESSAGE(!ecf_pid.empty(), "ECF_PID not set in the server");
+
+    // Send a SIGTERM to the server and ensure that a check point file is created
+    std::string sigterm = "kill -15 " + ecf_pid;
+    system(sigterm.c_str());
+    wait_for_sigterm_in_server(theClient);
+
+    // Clear sigterm flag
+    BOOST_REQUIRE_MESSAGE(theClient.alter("/", "clear_flag", "sigterm") == 0,
+                          "--alter should return 0\n"
+                              << theClient.errorMsg());
+
+    // We expect a check point file to be save to disk, but *no* backup
+    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
+                          CtsApi::checkPtDefs() << " failed file(" << invokeServer.ecf_checkpt_file() << ") not saved");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
+                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
+                                                       << "), to have file size > 0");
+    if (ClientEnvironment::hostSpecified().empty()) {
+        // This check only valid if server was invoked locally. Ignore for remote servers
+        BOOST_REQUIRE_MESSAGE(!fs::exists(invokeServer.ecf_backup_checkpt_file()),
+                              "Backup check point file(" << invokeServer.ecf_backup_checkpt_file()
+                                                         << ")should not exist,for very first time.");
+    }
+
+    // Send a SIGTERM again. This time we expect the backup check point file to be created.
+    system(sigterm.c_str());
+    wait_for_sigterm_in_server(theClient);
+
+    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_checkpt_file()),
+                          CtsApi::checkPtDefs()
+                              << " failed No check pt file(" << invokeServer.ecf_checkpt_file() << ") saved");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_checkpt_file()) != 0,
+                          "Expected check point file(" << invokeServer.ecf_checkpt_file()
+                                                       << ") to have file size > 0  ");
+    BOOST_REQUIRE_MESSAGE(fs::exists(invokeServer.ecf_backup_checkpt_file()),
+                          "Expected backup check point file(" << invokeServer.ecf_backup_checkpt_file()
+                                                              << ") to be created");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(invokeServer.ecf_backup_checkpt_file()) != 0,
+                          "Expected backup check point file(" << invokeServer.ecf_backup_checkpt_file()
+                                                              << "), to have file size > 0");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestSinglePerf.cpp 5.13.0-1/libs/client/test/TestSinglePerf.cpp
--- 5.12.4-1/libs/client/test/TestSinglePerf.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestSinglePerf.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,381 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib> // getenv
+#include <fstream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "TestHelper.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/client/Rtt.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_SinglePerf)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+// ************************************************************************************
+
+// These thresholds are based on the largest definition in the tests.
+static int load_threshold_ms          = 4500;
+static int begin_threshold_ms         = 550;
+static double sync_full_threshold_s   = 2.6;
+static double full_threshold_s        = 2.9;
+static double suspend_threshold_s     = 3.5;
+static double resume_threshold_s      = 3.5;
+static double force_threshold_s       = 8.5;
+static double check_pt_threshold_s    = 1.0;
+static double client_cmds_threshold_s = 8.5;
+
+static void sync_and_news_local(ClientInvoker& theClient) {
+    {
+        cout << "   news_local() : ";
+        DurationTimer duration_timer;
+        theClient.news_local();
+        cout << duration_timer.elapsed_seconds();
+    }
+    {
+        cout << "   sync_local() : ";
+        DurationTimer duration_timer;
+        theClient.sync_local();
+        cout << duration_timer.elapsed_seconds() << endl;
+    }
+}
+
+void time_load_and_downloads(ClientInvoker& theClient,
+                             const std::string& host,
+                             const std::string& port,
+                             const std::string& directory) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+    int count = 10;
+    std::vector<std::string> paths;
+
+    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (is_directory(dir_itr->status())) {
+                time_load_and_downloads(theClient, host, port, relPath.string());
+                continue;
+            }
+
+            cout << "\n" << relPath.string() << "  : file size " << fs::file_size(relPath) << endl;
+            {
+                DurationTimer duration_timer;
+                BOOST_REQUIRE_MESSAGE(theClient.loadDefs(relPath.string()) == 0,
+                                      "load defs failed \n"
+                                          << theClient.errorMsg());
+                cout << " Load:                " << duration_timer.elapsed().total_milliseconds() << "ms" << endl;
+                BOOST_CHECK_MESSAGE(duration_timer.elapsed().total_milliseconds() < load_threshold_ms,
+                                    "regression load(" << duration_timer.elapsed().total_milliseconds()
+                                                       << "), exceeded threshold of " << load_threshold_ms);
+            }
+            {
+                DurationTimer duration_timer;
+                BOOST_REQUIRE_MESSAGE(theClient.begin_all_suites() == 0, "begin failed \n" << theClient.errorMsg());
+                cout << " Begin:               " << duration_timer.elapsed().total_milliseconds() << "ms" << endl;
+                BOOST_CHECK_MESSAGE(duration_timer.elapsed().total_milliseconds() < begin_threshold_ms,
+                                    "regression begin(" << duration_timer.elapsed().total_milliseconds()
+                                                        << "), exceeded threshold of " << begin_threshold_ms);
+            }
+
+            {
+                cout << " Download(news_local):";
+                cout.flush();
+                ClientInvoker client_news(host, port);
+                DurationTimer duration_timer;
+                for (int i = 0; i < count; i++) {
+                    if (i == 0 || i != 1) {
+                        client_news.news_local();
+                        switch (client_news.server_reply().get_news()) {
+                            case ServerReply::DO_FULL_SYNC:
+                                cout << "FULL ";
+                                break;
+                            case ServerReply::NEWS:
+                                cout << "NEWS ";
+                                break;
+                            case ServerReply::NO_NEWS:
+                                cout << "NO_NEWS ";
+                                break;
+                        }
+                    }
+                    else if (i == 1)
+                        client_news.sync_local();
+                }
+                cout << ": 1:news_local(),2:sync_local(),n:news_local with the new Client: "
+                     << duration_timer.elapsed().total_milliseconds() << "(ms)" << endl;
+            }
+            {
+                cout << " Download(Sync):      ";
+                cout.flush();
+                for (int i = 0; i < count; i++) {
+                    DurationTimer duration_timer;
+                    theClient.sync_local();
+                    int seconds = duration_timer.elapsed().total_milliseconds();
+                    cout << seconds << " ";
+                }
+                cout << ":(milli-seconds) sync_local() with the same Client. First call updates cache." << endl;
+            }
+            {
+                // On construction of Defs, hence should be slightly faster
+                cout << " Download(Sync-FULL): ";
+                cout.flush();
+                double total = 0;
+                for (int i = 0; i < count; i++) {
+                    ClientInvoker client(host, port);
+                    DurationTimer duration_timer;
+                    client.sync_local();
+                    int mil_secs = duration_timer.elapsed().total_milliseconds();
+                    cout << mil_secs << " ";
+                    total += mil_secs;
+                }
+                double average = (double)(total) / ((double)count * 1000);
+                cout << ": Avg:" << average << "(sec)  : sync_local() with *different* clients.uses cache!" << endl;
+                BOOST_CHECK_MESSAGE(average < sync_full_threshold_s,
+                                    "regression Sync-FULL(" << average << "), exceeded threshold of "
+                                                            << sync_full_threshold_s);
+            }
+            {
+                cout << " Download(FULL):      ";
+                cout.flush();
+                double total = 0;
+                for (int i = 0; i < count; i++) {
+                    ClientInvoker client(host, port);
+                    DurationTimer duration_timer;
+                    theClient.getDefs();
+                    int seconds = duration_timer.elapsed().total_milliseconds();
+                    cout << seconds << " ";
+                    total += seconds;
+                }
+                double average = (double)(total) / ((double)count * 1000);
+                cout << ": Avg:" << average << "(sec)  : get_defs() from different client" << endl;
+                BOOST_CHECK_MESSAGE(average < full_threshold_s,
+                                    "regression FULL(sync)(" << average << ") exceeded threshold of "
+                                                             << full_threshold_s);
+            }
+            {
+                std::vector<task_ptr> all_tasks;
+                if (!theClient.defs())
+                    theClient.sync_local();
+                theClient.defs()->get_all_tasks(all_tasks);
+                paths.clear();
+                paths.reserve(all_tasks.size());
+                for (size_t i = 0; i < all_tasks.size(); i++)
+                    paths.push_back(all_tasks[i]->absNodePath());
+
+                {
+                    cout << " Suspend " << paths.size() << " tasks : ";
+                    cout.flush();
+                    DurationTimer duration_timer;
+                    theClient.suspend(paths);
+                    cout << duration_timer.elapsed_seconds();
+                    sync_and_news_local(theClient);
+                }
+                {
+                    cout << " Resume " << paths.size() << " tasks  : ";
+                    cout.flush();
+                    DurationTimer duration_timer;
+                    theClient.resume(paths);
+                    cout << duration_timer.elapsed_seconds();
+                    sync_and_news_local(theClient);
+                }
+                {
+                    cout << " Suspend " << paths.size() << " tasks : ";
+                    cout.flush();
+                    theClient.set_auto_sync(true);
+                    DurationTimer duration_timer;
+                    theClient.suspend(paths);
+                    cout << duration_timer.elapsed_seconds() << " : auto-sync" << endl;
+                    BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < suspend_threshold_s,
+                                        "regression suspend(" << duration_timer.elapsed_seconds()
+                                                              << ") exceeded threshold of " << suspend_threshold_s);
+                    theClient.set_auto_sync(false);
+                }
+                {
+                    cout << " Resume " << paths.size() << " tasks  : ";
+                    cout.flush();
+                    theClient.set_auto_sync(true);
+                    DurationTimer duration_timer;
+                    theClient.resume(paths);
+                    cout << duration_timer.elapsed_seconds() << " : auto-sync" << endl;
+                    BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < resume_threshold_s,
+                                        "regression resume(" << duration_timer.elapsed_seconds()
+                                                             << ") exceeded threshold of " << resume_threshold_s);
+                    theClient.set_auto_sync(false);
+                }
+                {
+                    cout << " check  " << paths.size() << " tasks  : ";
+                    cout.flush();
+                    DurationTimer duration_timer;
+                    theClient.check(paths);
+                    cout << duration_timer.elapsed_seconds();
+                    sync_and_news_local(theClient);
+                }
+                {
+                    cout << " kill   " << paths.size() << " tasks  : ";
+                    cout.flush();
+                    DurationTimer duration_timer;
+                    theClient.kill(paths);
+                    cout << duration_timer.elapsed_seconds();
+                    sync_and_news_local(theClient);
+                }
+                {
+                    // force complete on all tasks, on some suites(3199.def), can cause infinite recursion, i.e cause
+                    // repeats to loop Hence we will call force aborted instead. Also AVOID active/submitted otherwise
+                    // we spend a huge time adding zombies, for the subsequent force cmd below. Node: state change
+                    // memento, will also persist duration time of state change.
+                    cout << " force  " << paths.size() << " tasks  : ";
+                    cout.flush();
+                    DurationTimer duration_timer;
+                    theClient.force(paths, "aborted");
+                    cout << duration_timer.elapsed_seconds() << " force(aborted)";
+                    sync_and_news_local(theClient);
+                }
+                {
+                    cout << " force  " << paths.size() << " tasks  : ";
+                    cout.flush();
+                    theClient.set_auto_sync(true);
+                    DurationTimer duration_timer;
+                    theClient.force(
+                        paths, "queued"); // can't use aborted again, as it already aborted, and hence will be ignored
+                    cout << duration_timer.elapsed_seconds() << " : auto-sync :  force(queued)" << endl;
+                    BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < force_threshold_s,
+                                        "regression force(" << duration_timer.elapsed_seconds()
+                                                            << ") exceeded threshold of " << force_threshold_s);
+                    theClient.set_auto_sync(false);
+                }
+            }
+            {
+                cout << " Check pt:            ";
+                cout.flush();
+                double total = 0;
+                for (int i = 0; i < count; i++) {
+                    DurationTimer duration_timer;
+                    theClient.checkPtDefs();
+                    int seconds = duration_timer.elapsed().total_milliseconds();
+                    cout << seconds << " ";
+                    total += seconds;
+                }
+                double average = (double)(total) / ((double)count * 1000);
+                cout << ": Avg:" << average << "(s)" << endl;
+                BOOST_CHECK_MESSAGE(average < check_pt_threshold_s,
+                                    "regression in check_pt(" << average << ") exceeded threshold of "
+                                                              << check_pt_threshold_s);
+            }
+            {
+                cout << " client cmds:         ";
+                cout.flush();
+                DurationTimer duration_timer;
+                size_t i;
+                for (i = 0; i < paths.size() && i < 2000; i++) {
+                    theClient.suspend(paths[i]);
+                    theClient.sync_local();
+                    theClient.resume(paths[i]);
+                    theClient.sync_local();
+                    theClient.force(paths[i], "aborted");
+                    theClient.sync_local();
+                    theClient.alter(paths[i], "add", "variable", "XXXX", "XXXX");
+                    theClient.sync_local();
+                    theClient.requeue(paths[i]);
+                    theClient.sync_local();
+                }
+                cout << i << " times " << duration_timer.elapsed_seconds()
+                     << "(s) (sync_local) with same client (suspend,resume,force,alter,requeue)" << endl;
+                BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < client_cmds_threshold_s,
+                                    "regression, exceeded threshold of " << client_cmds_threshold_s);
+            }
+            {
+                cout << " client cmds:         ";
+                cout.flush();
+                theClient.set_auto_sync(true);
+                DurationTimer duration_timer;
+                size_t i;
+                for (i = 0; i < paths.size() && i < 2000; i++) {
+                    theClient.suspend(paths[i]);
+                    theClient.resume(paths[i]);
+                    theClient.force(paths[i], "aborted");
+                    theClient.alter(paths[i], "add", "variable", "ZZZZ", "XXXX");
+                    theClient.requeue(paths[i]);
+                }
+                cout << i << " times " << duration_timer.elapsed_seconds()
+                     << "(s) (auto_sync ) with same client (suspend,resume,force,alter,requeue)" << endl;
+                BOOST_CHECK_MESSAGE(duration_timer.elapsed_seconds() < client_cmds_threshold_s,
+                                    "regression, exceeded threshold of " << client_cmds_threshold_s);
+                theClient.set_auto_sync(false);
+            }
+
+            {
+                DurationTimer duration_timer;
+                BOOST_REQUIRE_MESSAGE(theClient.delete_all(true) == 0,
+                                      "delete all defs failed \n"
+                                          << theClient.errorMsg());
+                cout << " Delete:              " << duration_timer.elapsed().total_milliseconds() << "ms" << endl;
+            }
+        }
+        catch (const std::exception& ex) {
+            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_perf_for_large_defs) {
+    if (const char* ecf_ssl = getenv("ECF_SSL"); ecf_ssl) {
+        load_threshold_ms       = 8000; // 4500;
+        begin_threshold_ms      = 800;  // 400;
+        sync_full_threshold_s   = 4.5;  // 2.6;
+        full_threshold_s        = 4.5;  // 2.8;
+        suspend_threshold_s     = 5.8;  // 3.5;
+        resume_threshold_s      = 6.5;  // 3.5;
+        force_threshold_s       = 15;   // 8.5;
+        check_pt_threshold_s    = 1.5;  // 1.0;
+        client_cmds_threshold_s = 950;  // 8.5;
+    }
+
+    if (const char* ecf_test_defs_dir = getenv("ECF_TEST_DEFS_DIR"); !ecf_test_defs_dir) {
+        std::cout << "Ignoring test! Environment variable ECF_TEST_DEFS_DIR is not defined\n";
+    }
+    else if (!fs::exists(ecf_test_defs_dir)) {
+        std::cout << "Ignoring test! Test definitions directory " << ecf_test_defs_dir << " does not exist\n";
+    }
+    else {
+        /// This will remove checkpt and backup , to avoid server from loading it. (i.e from previous test)
+        InvokeServer invokeServer("Client:: ...test_perf_for_large_defs:", SCPort::next());
+        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+        time_load_and_downloads(theClient, invokeServer.host(), invokeServer.port(), ecf_test_defs_dir);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestSinglePerf_main.cpp 5.13.0-1/libs/client/test/TestSinglePerf_main.cpp
--- 5.12.4-1/libs/client/test/TestSinglePerf_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestSinglePerf_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_SinglePerf
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/client/test/TestUrlCmd.cpp 5.13.0-1/libs/client/test/TestUrlCmd.cpp
--- 5.12.4-1/libs/client/test/TestUrlCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestUrlCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/client/UrlCmd.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_UrlCmd)
+
+//=============================================================================
+// This will test the UrlCmd.
+BOOST_AUTO_TEST_CASE(test_url_cmd) {
+    cout << "Client:: ...test_url_cmd" << endl;
+
+    std::string path = File::test_data("libs/client/test/data/lifecycle.txt", "libs/client");
+
+    defs_ptr defs = Defs::create();
+
+    std::string errorMsg, warningMsg;
+    bool parse = defs->restore(path, errorMsg, warningMsg);
+    BOOST_CHECK_MESSAGE(parse, errorMsg);
+
+    // Check error conditions
+    BOOST_REQUIRE_THROW(UrlCmd(defs, "a made up name"), std::runtime_error);
+    BOOST_REQUIRE_THROW(UrlCmd(defs_ptr(), "/suite1/family1/a"), std::runtime_error);
+
+    // The Url command relies on variable substitution, hence we must ensure that
+    // generated variables are created.
+    defs->beginAll();
+
+    UrlCmd urlCmd(defs, "/suite1/family1/a");
+    std::string expected = "${BROWSER:=firefox} -new-tab https://confluence.ecmwf.int/display/ECFLOW/ecflow+home";
+    std::string actual   = urlCmd.getUrl();
+    BOOST_CHECK_MESSAGE(expected == actual, "Expected '" << expected << "' but found " << actual);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/TestWhiteListFile.cpp 5.13.0-1/libs/client/test/TestWhiteListFile.cpp
--- 5.12.4-1/libs/client/test/TestWhiteListFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/TestWhiteListFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,180 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "InvokeServer.hpp"
+#include "SCPort.hpp"
+#include "ecflow/client/ClientEnvironment.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/WhiteListFile.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Client)
+
+BOOST_AUTO_TEST_SUITE(T_WhiteListFile)
+
+// ************************************************************************************
+// Note: If you make edits to node tree, they will have no effect until the server is rebuilt
+//
+// Note: To test HPUX->Linux, invoke serve on (Linux/HPUX) and the client cmds on other system
+//       On the client side set ECF_HOST to machine name. To allow further testing if ECF_HOST
+//       is specified then *don't* shutdown the server
+// ************************************************************************************
+
+BOOST_AUTO_TEST_CASE(test_loading_of_white_list_file) {
+    Host the_host;
+    std::string port = SCPort::next();
+    std::string host = ClientEnvironment::hostSpecified();
+    if (host.empty()) {
+
+        // make sure NO whitelist file is present before the server is started.
+        // This allows any user to send requests to the server
+        // Only do this locally, as white list file on remote machine may not be accessible
+        fs::remove(the_host.ecf_lists_file(port));
+    }
+
+    // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+    // data
+    InvokeServer invokeServer("Client:: ...test_loading_of_white_list_file", port);
+    BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                          "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+    ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+    BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                          CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                          CtsApi::haltServer() << " should return 0\n"
+                                               << theClient.errorMsg());
+    BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                          CtsApi::restartServer() << " should return 0\n"
+                                                  << theClient.errorMsg());
+
+    // OK now test white list file functionality, but only if server was invoked locally
+    if (host.empty()) {
+
+        // The white list file should not exist, hence reload white list SHOULD fail.
+        // i.e because we deleted it earlier
+        BOOST_REQUIRE_THROW(theClient.reloadwsfile(), std::runtime_error);
+
+        // Create a valid white list file; For the FIRST time:
+        // **** IMPORTANT: if we had reloaded a white list file where the user has read access
+        // **************: _FIRST_ it will not be possible reload white file with write access, afterwards
+        // **************: since subsequent RELOAD command itself will require write access
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(WhiteListFile::createWithWriteAccess(the_host.ecf_lists_file(port), errorMsg), errorMsg);
+
+        //  Reload should pass, as its the _first_ time
+        BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
+                              CtsApi::reloadwsfile() << " should return 0\n"
+                                                     << theClient.errorMsg());
+
+        // Invoking a client request that requires write access, should pass
+        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
+
+        // Invoking a client request that requires read access, should also pass
+        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
+
+        // Remove the white list file. Comment out for debug
+        fs::remove(the_host.ecf_lists_file(port));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_server_has_write_access_in_non_empty_whitelist) {
+    Host the_host;
+    std::string host = ClientEnvironment::hostSpecified();
+    if (host.empty()) {
+        // OK now test white list file functionality, but only if server was invoked locally
+
+        // make sure NO whitelist file is present before the server is started.
+        // This allows any user to send requests to the server
+        // Only do this locally, as white list file on remote machine may not be accessible
+        std::string port = SCPort::next();
+        fs::remove(the_host.ecf_lists_file(port));
+
+        // This will remove check pt and backup file before server start, to avoid the server from loading previous test
+        // data
+        InvokeServer invokeServer("Client:: ...test_server_has_write_access_in_non_empty_whitelist", port);
+        BOOST_REQUIRE_MESSAGE(invokeServer.server_started(),
+                              "Server failed to start on " << invokeServer.host() << ":" << invokeServer.port());
+
+        ClientInvoker theClient(invokeServer.host(), invokeServer.port());
+        BOOST_REQUIRE_MESSAGE(theClient.delete_all() == 0,
+                              CtsApi::to_string(CtsApi::delete_node()) << " should return 0\n"
+                                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.shutdownServer() == 0,
+                              CtsApi::shutdownServer() << " should return 0\n"
+                                                       << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.haltServer() == 0,
+                              CtsApi::haltServer() << " should return 0\n"
+                                                   << theClient.errorMsg());
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+
+        // The white list file should not exist, hence reload white list SHOULD fail.
+        // i.e because we deleted it earlier
+        BOOST_REQUIRE_THROW(theClient.reloadwsfile(), std::runtime_error);
+
+        // Create a valid white list file where the server HAS NO write access.
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(WhiteListFile::createWithNoAccess(the_host.ecf_lists_file(port), errorMsg), errorMsg);
+
+        // Reload whitelist. The server will adapt white list so the server user always has write access
+        BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
+                              CtsApi::reloadwsfile() << " should return 0\n"
+                                                     << theClient.errorMsg());
+
+        // Invoking a client request that requires write access, should still pass
+        BOOST_CHECK_MESSAGE(theClient.shutdownServer() == 0, "should return 0\n" << theClient.errorMsg());
+
+        // Invoking a client request that requires read access, should also pass
+        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
+
+        // ###############################################################################################################
+        // Remove the white list file. Comment out for debug
+        fs::remove(the_host.ecf_lists_file(port));
+
+        // Reload with empty white list. All users should have read/write access
+        BOOST_REQUIRE_MESSAGE(WhiteListFile::createEmpty(the_host.ecf_lists_file(port), errorMsg), errorMsg);
+        BOOST_REQUIRE_MESSAGE(theClient.reloadwsfile() == 0,
+                              CtsApi::reloadwsfile() << " should return 0\n"
+                                                     << theClient.errorMsg());
+
+        // Invoking a client request that requires write access, should still pass
+        BOOST_REQUIRE_MESSAGE(theClient.restartServer() == 0,
+                              CtsApi::restartServer() << " should return 0\n"
+                                                      << theClient.errorMsg());
+
+        // Invoking a client request that requires read access, should also pass
+        BOOST_CHECK_MESSAGE(theClient.getDefs() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.sync_local() == 0, "should return 0\n" << theClient.errorMsg());
+        BOOST_CHECK_MESSAGE(theClient.news_local() == 0, "should return 0\n" << theClient.errorMsg());
+
+        // Remove the white list file. Comment out for debug
+        fs::remove(the_host.ecf_lists_file(port));
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/client/test/data/ECF_HOME/includes/head.h 5.13.0-1/libs/client/test/data/ECF_HOME/includes/head.h
--- 5.12.4-1/libs/client/test/data/ECF_HOME/includes/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/ECF_HOME/includes/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,53 @@
+#!/bin/ksh
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+set -o pipefail # fail if last(rightmost) command exits with a non-zero status
+
+# Defines the three variables that are needed for any
+# communication with ECF_
+
+export ECF_PORT=%ECF_PORT%    # The port number on the ecflow server
+export ECF_HOST=%ECF_HOST%    # Thehostname where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%
+fi
+
+# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
+os_name=$(uname -s)
+if [[ $os_name = Linux ]] ; then
+   host %ECF_HOST%
+fi
+
+# Tell ECF_ we have stated
+# The ECF_ variable ECF_RID will be set to parameter of smsinit
+# Here we give the current PID.
+
+smsinit $$
+
+# Defined a error hanlder
+
+ERROR() {
+   # wait for background process to stop.
+   # If we did not have background jobs, closly called foreround jobs
+   # may arrive out of order at the server, causing unnecessary zombies
+   # The wait should prevent this.
+   echo "ERROR() called"
+	set +e        # Clear -e flag, so we don't fail
+	wait          # wait for background process to stop
+   smsabort      # Notify ECF_ that something went wrong
+	trap 0        # Remove the trap
+	exit 0        # End the script
+}
+
+# Trap any calls to exit and errors caught by the -e flag
+
+trap ERROR 0
+
+# Trap any signal that may cause the script to fail
+
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/libs/client/test/data/ECF_HOME/includes/tail.h 5.13.0-1/libs/client/test/data/ECF_HOME/includes/tail.h
--- 5.12.4-1/libs/client/test/data/ECF_HOME/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/ECF_HOME/includes/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+# wait for background process to stop.
+# If we did not have background jobs, closly called foreround jobs
+# may arrive out of order at the server, causing unnecessary zombies
+# The wait should prevent this.
+
+wait         # wait for background process to stop
+smscomplete  # Notify ECF of a normal end
+trap 0       # Remove all traps
+exit 0       # End the shell
diff -pruN 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/head.h 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/head.h
--- 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+#!/bin/ksh
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+
+# Defines the three variables that are needed for any
+# communication with ECF_
+
+export ECF_PORT=%ECF_PORT%    # The port number on the server
+export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%
+fi
+
+# Tell ECF_ we have stated
+# The ECF_ variable ECF_RID will be set to parameter of smsinit
+# Here we give the current PID.
+
+smsinit $$
+
+# Defined a error hanlder
+
+ERROR() {
+	set +e        # Clear -e flag, so we don't fail
+	smsabort      # Notify ECF_ that something went wrong
+	trap 0        # Remove the trap
+	exit 0        # End the script
+}
+
+# Trap any calls to exit and errors caught by the -e flag
+
+trap ERROR 0
+
+# Trap any signal that may cause the script to fail
+
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/t1.ecf 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/t1.ecf
--- 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/t1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/t1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,72 @@
+%manual
+	OPERATORS: This is an example of using a manual
+	
+	This is used to also test variable subsitution of 
+	generated variables
+	SUITE     = %SUITE%
+	DATE      = %DATE%
+	DAY       = %DAY%
+	DD        = %DD%
+	DOW       = %DOW%
+	DOY       = %DOY%
+	MM        = %MM%
+	MONTH     = %MONTH%
+	YYYY      = %YYYY%
+	ECF_DATE   = %ECF_DATE%
+	ECF_TIME   = %ECF_TIME%
+	ECF_CLOCK  = %ECF_CLOCK%
+
+	FAMILY    = %FAMILY%
+	FAMILY1   = %FAMILY1%
+
+	TASK      = %TASK%
+	ECF_RID    = %ECF_RID:<not defined yet, since empty string in task>%
+	ECF_TRYNO  = %ECF_TRYNO%
+	ECF_NAME   = %ECF_NAME%
+	ECF_PASS   = %ECF_PASS%
+	ECF_SCRIPT = %ECF_SCRIPT%
+	ECF_JOB    = %ECF_JOB%
+	ECF_JOBOUT = %ECF_JOBOUT%
+    
+    Other ECF_ variables
+	ECF_KILL_CMD  = %ECF_KILL_CMD:<not defined yet>%
+	ECF_JOB_CMD   = %ECF_JOB_CMD%
+	ECF_HOME      = %ECF_HOME%
+	ECF_TRIES     = %ECF_TRIES:<Error>%
+	SMFILES      = %SMFILES:<not defined yet>%
+	ECF_INCLUDE   = %ECF_INCLUDE:<not defined yet>%
+	ECF_FETCH     = %ECF_FETCH:<not defined yet>%
+	ECF_OUT       = %ECF_OUT:<not defined yet>%
+	ECF_MICRO     = %ECF_MICRO%
+%end
+
+#============================================================
+# Using angle brackets should use ECF_INCLUDE
+#=========================================================
+%include <head.h>
+
+
+echo do some work
+# SLEEPTIME is defined thedefs.def file. Test variable substituition
+sleep %SLEEPTIME%
+echo end of job
+
+# test smsevent. smsmeter replaced with path to client exe
+smsevent  eventname
+smsmeter  metername 10
+
+%include <tail.h>
+
+
+%manual
+	Rest of the manual page is placed here, closer to the code
+%end
+%comment
+  Comment start
+%end
+%comment
+  Comment end
+%end
+%nopp
+  ignore everything in here
+%end
diff -pruN 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/t2.ecf 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/t2.ecf
--- 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/t2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/t2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+ 
+# using %include "filename"
+# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
+#
+# since we are using quotes we expect to find 'head.h' and 'tail.h'
+# in the same directory as the sms files.
+#======================================================================
+%include "head.h"
+
+
+echo do some work
+# SLEEPTIME is defined thedefs.def file. Test variable substituition
+sleep 10
+echo end of job
+
+
+%include "tail.h"
+
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/t3.ecf 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/t3.ecf
--- 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/t3.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/t3.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,39 @@
+# using %include "filename"
+# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
+#
+# since we are using quotes we expect to find 'head.h' and 'tail.h'
+# in the same directory as the sms files.
+#======================================================================
+%include "head.h"
+
+
+echo do some work
+sleep 10
+echo end of job
+
+#=====================================================
+# change the ecfmicro character
+%ecfmicro &
+
+&manual
+	START Rest of the manual page is placed here, closer to the code
+&end
+&comment
+  Comment start
+  &SUITE&
+&end
+&comment
+  Comment end
+&end
+&nopp
+  ignore everything in here
+&end
+&manual
+	END of the manual
+&end
+#=====================================================
+# change the ecfmicro character back
+&ecfmicro %
+
+
+%include "tail.h"
diff -pruN 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/tail.h 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/tail.h
--- 5.12.4-1/libs/client/test/data/ECF_HOME/suite/family/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/ECF_HOME/suite/family/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+smscomplete  # Notify ECF of a normal end
+trap 0       # Remove all traps
+exit 0       # End the shell
diff -pruN 5.12.4-1/libs/client/test/data/bad.def 5.13.0-1/libs/client/test/data/bad.def
--- 5.12.4-1/libs/client/test/data/bad.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/bad.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite suite1
+   task dodgy
+      trigger a non sensical trigger and that should fail to parse 
+endsuite
+
diff -pruN 5.12.4-1/libs/client/test/data/first.def 5.13.0-1/libs/client/test/data/first.def
--- 5.12.4-1/libs/client/test/data/first.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/first.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+#
+# This defines extern which are defined in second.def
+#
+extern /a/b/c/d         
+extern /a/b/c/d/e:event        
+extern /a/b/c/d/e:meter       
+
+extern /a/b/c/d/e/f/g/h/j     # this does not exist in second.def
+
+suite suiteName
+   family familyName
+   		task p
+   			trigger /a/b/c/d == complete  		                                   # extern path
+  		task q
+   			trigger /a/b/c/d/e:event == set  		                               # extern event path
+ 		task r
+   			trigger /a/b/c/d/e:meter le 30		                                   # extern meter path	
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/client/test/data/good_hostfile 5.13.0-1/libs/client/test/data/good_hostfile
--- 5.12.4-1/libs/client/test/data/good_hostfile	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/good_hostfile	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+
+host1:3142    # some description of the port
+host2:3141    # another description
+
+host3
+
+host4:4001
+
+host5
+host6:4081
+
+# a comment
+#a comment
\ No newline at end of file
diff -pruN 5.12.4-1/libs/client/test/data/jobgenonly.def 5.13.0-1/libs/client/test/data/jobgenonly.def
--- 5.12.4-1/libs/client/test/data/jobgenonly.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/jobgenonly.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+#
+# We can define a variable ECF_HOME as want to use relative paths
+# i.e since the test must be relocatble to other platforms
+#
+suite suite
+	edit SLEEPTIME 10
+	edit ECF_INCLUDE $ECF_HOME/includes
+	family family
+	   task t1
+	   	event eventname
+	   	meter metername 0 100 100
+	   task t2
+	   task t3
+	endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/client/test/data/lifecycle.txt 5.13.0-1/libs/client/test/data/lifecycle.txt
--- 5.12.4-1/libs/client/test/data/lifecycle.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/lifecycle.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+suite suite1
+  edit ECF_URL_CMD  "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%"
+  edit ECF_URL_BASE "https://confluence.ecmwf.int"
+  edit ECF_URL      "display/ECFLOW/ecflow+home"
+  family family1
+   	task a
+        event 1 myEvent
+        meter myMeter 0 100
+   	task b
+   		trigger a == complete
+   endfamily
+   family family2
+   		task aa
+   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent 
+   		task bb
+   			trigger ../family1/a:myMeter >= 50  or  ../family1/a:myEvent
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/client/test/data/second.def 5.13.0-1/libs/client/test/data/second.def
--- 5.12.4-1/libs/client/test/data/second.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/client/test/data/second.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+ 
+#
+# The defs is used conjunction with first.def to test resolution of externs
+#
+
+suite a
+   family b
+   		family c
+   			family d
+   				task e
+   					event event
+           	    	meter meter  0 100 100  # meter <name> <min> <max> [optional color change]
+           	endfamily
+    	endfamily
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/core/CMakeLists.txt 5.13.0-1/libs/core/CMakeLists.txt
--- 5.12.4-1/libs/core/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,79 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+##
+## Notice: test_support is an INTERFACE-only test utility library.
+##
+
+ecbuild_add_library(
+  TARGET
+    test_support
+  NOINSTALL
+  TYPE INTERFACE
+  SOURCES
+    test/TestSerialisation.hpp
+  PUBLIC_INCLUDES
+    test
+)
+target_clangformat(test_support)
+
+set(test_srcs
+  # Headers
+  test/TestVersioning.hpp
+  # Sources
+  test/TestCalendar.cpp
+  test/TestCereal.cpp
+  test/TestCerealOptionalNVP.cpp
+  test/TestCerealWithHierarchy.cpp
+  test/TestChrono.cpp
+  test/TestClassDataMemberInit.cpp
+  test/TestCommandLine.cpp
+  test/TestCore_main.cpp # contains main() function for test driver
+  test/TestExtract.cpp
+  test/TestFile.cpp
+  test/TestGetUserDetails.cpp
+  test/TestLog.cpp
+  test/TestMessage.cpp
+  test/TestMigration.cpp
+  test/TestNodePath.cpp
+  test/TestPasswdFile.cpp
+  test/TestPasswordEncryption.cpp
+  test/TestPerfTimer.cpp
+  test/TestRealCalendar.cpp
+  test/TestSanitizerAS.cpp
+  test/TestSanitizerUB.cpp
+  test/TestSerialisation.cpp
+  test/TestStr.cpp
+  test/TestStringSplitPerf.cpp
+  test/TestStringSplitter.cpp
+  test/TestTimeSeries.cpp
+  test/TestTimeSlot.cpp
+  test/TestVersion.cpp
+  test/TestVersioning.cpp
+  test/TestWhiteListFile.cpp
+)
+
+ecbuild_add_test(
+  TARGET
+    u_core
+  LABELS
+    unit
+    nightly
+  SOURCES
+    ${test_srcs}
+  LIBS
+    test_support
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+    Boost::timer
+)
+target_clangformat(u_core
+  CONDITION ENABLE_TESTS
+)
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/AssertTimer.cpp 5.13.0-1/libs/core/src/ecflow/core/AssertTimer.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/AssertTimer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/AssertTimer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/AssertTimer.hpp"
+
+#include <iostream>
+
+#include "ecflow/core/Log.hpp"
+
+namespace ecf {
+
+AssertTimer::~AssertTimer() {
+    if (doAssert_ && timeConstraint_ > 0) {
+        int d = duration();
+        if (d >= timeConstraint_) {
+            std::cout << "AssertTimer::~AssertTimer() duration(" << d << ") >= timeConstraint(" << timeConstraint_
+                      << ")\n";
+        }
+        LOG_ASSERT(d < timeConstraint_, "AssertTimer::~AssertTimer()");
+    }
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/AssertTimer.hpp 5.13.0-1/libs/core/src/ecflow/core/AssertTimer.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/AssertTimer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/AssertTimer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_AssertTimer_HPP
+#define ecflow_core_AssertTimer_HPP
+
+///
+/// \brief Simple class that asserts when a time constraint is not met
+///
+
+#include "ecflow/core/Calendar.hpp"
+
+namespace ecf {
+
+// Local timer class used to ensure a job submission takes less than 60 seconds
+class AssertTimer {
+public:
+    explicit AssertTimer(int t, bool doAssert = true)
+        : timeConstraint_(t),
+          doAssert_(doAssert),
+          start_time_(Calendar::second_clock_time()) {}
+    ~AssertTimer();
+
+    int timeConstraint() const { return timeConstraint_; }
+
+    int duration() const {
+        boost::posix_time::time_duration duration = Calendar::second_clock_time() - start_time_;
+        return duration.total_seconds();
+    }
+
+private:
+    int timeConstraint_;
+    bool doAssert_;
+    boost::posix_time::ptime start_time_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_AssertTimer_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Cal.cpp 5.13.0-1/libs/core/src/ecflow/core/Cal.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Cal.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Cal.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,70 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Cal.hpp"
+
+long Cal::julian_to_date(long jdate) {
+    long x, y, d, m, e;
+    long day, month, year;
+
+    x = 4 * jdate - 6884477;
+    y = (x / 146097) * 100;
+    e = x % 146097;
+    d = e / 4;
+
+    x = 4 * d + 3;
+    y = (x / 1461) + y;
+    e = x % 1461;
+    d = e / 4 + 1;
+
+    x = 5 * d - 3;
+    m = x / 153 + 1;
+    e = x % 153;
+    d = e / 5 + 1;
+
+    if (m < 11)
+        month = m + 2;
+    else
+        month = m - 10;
+
+    day  = d;
+    year = y + m / 11;
+
+    return year * 10000 + month * 100 + day;
+}
+
+long Cal::date_to_julian(long ddate) {
+    long m1, y1, a, b, c, d, j1;
+    long month, day, year;
+
+    year = ddate / 10000;
+    ddate %= 10000;
+    month = ddate / 100;
+    ddate %= 100;
+    day = ddate;
+
+    if (month > 2) {
+        m1 = month - 3;
+        y1 = year;
+    }
+    else {
+        m1 = month + 9;
+        y1 = year - 1;
+    }
+    a  = 146097 * (y1 / 100) / 4;
+    d  = y1 % 100;
+    b  = 1461 * d / 4;
+    c  = (153 * m1 + 2) / 5 + day + 1721119;
+    j1 = a + b + c;
+
+    return (j1);
+}
+
+// int main(int ac, char** av){ int a=Cal::date_to_julian(20170219) % 7; printf("%d", a); return 0;}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Cal.hpp 5.13.0-1/libs/core/src/ecflow/core/Cal.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Cal.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Cal.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,26 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Cal_HPP
+#define ecflow_core_Cal_HPP
+
+class Cal {
+public:
+    // Disable default construction
+    Cal() = delete;
+    // Disable copy (and move) semantics
+    Cal(const Cal&)                  = delete;
+    const Cal& operator=(const Cal&) = delete;
+
+    static long date_to_julian(long);
+    static long julian_to_date(long);
+};
+
+#endif /* ecflow_core_Cal_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Calendar.cpp 5.13.0-1/libs/core/src/ecflow/core/Calendar.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Calendar.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Calendar.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,489 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Calendar.hpp"
+
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
+
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/cereal_boost_time.hpp"
+
+#ifdef DEBUG
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+// #define DEBUG_CALENDAR 1;
+
+namespace ecf {
+
+Calendar::Calendar() = default;
+
+Calendar::Calendar(const Calendar& rhs) {
+    assign(rhs);
+}
+
+Calendar& Calendar::operator=(const Calendar& rhs) {
+    assign(rhs);
+    return *this;
+}
+
+bool Calendar::operator==(const Calendar& rhs) const {
+    // Only used for testing the persistence of calendar
+    // Note: We specifically ignore initLocalTime_  and lastTime_ since they are initialised with the current time.
+    //       Otherwise For migration testing, it will fail
+
+    if (ctype_ != rhs.ctype_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "Calendar::operator== ctypes don't match\n";
+#endif
+        return false;
+    }
+    if (initTime_ != rhs.initTime_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "Calendar::operator== initTime_ don't match\n";
+#endif
+        return false;
+    }
+    if (suiteTime_ != rhs.suiteTime_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "Calendar::operator== suiteTime_  don't match\n";
+#endif
+        return false;
+    }
+    if (duration_ != rhs.duration_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "Calendar::operator== duration_  don't match\n";
+#endif
+        return false;
+    }
+    if (dayChanged_ != rhs.dayChanged_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "Calendar::operator== dayChanged_  don't match\n";
+#endif
+        return false;
+    }
+    if (increment_ != rhs.increment_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "Calendar::operator== increment_  don't match\n";
+#endif
+        return false;
+    }
+
+    return true;
+}
+
+void Calendar::assign(const Calendar& rhs) {
+    ctype_         = rhs.ctype_;
+    initTime_      = rhs.initTime_;
+    suiteTime_     = rhs.suiteTime_;
+    duration_      = rhs.duration_;
+    dayChanged_    = rhs.dayChanged_;
+    initLocalTime_ = rhs.initLocalTime_;
+    lastTime_      = rhs.lastTime_;
+    increment_     = rhs.increment_;
+
+    day_of_week_  = rhs.day_of_week_;  // Cache
+    day_of_year_  = rhs.day_of_year_;  // Cache
+    day_of_month_ = rhs.day_of_month_; // Cache
+    month_        = rhs.month_;        // Cache
+    year_         = rhs.year_;         // Cache
+}
+
+void Calendar::init(Clock_t clock) {
+    ctype_ = clock;
+}
+
+void Calendar::init(const boost::posix_time::ptime& time, Clock_t clock) {
+    init(clock);
+    begin(time);
+}
+
+/// Start the Calendar.  Parameter time can include gain.
+void Calendar::begin(const boost::posix_time::ptime& the_time) {
+    duration_  = time_duration(0, 0, 0, 0);
+    increment_ = time_duration(0, 1, 0, 0); // This will get overwritten on update
+                                            // But allows some tests to run
+    suiteTime_     = the_time;              // includes gain _IF_ it was specified
+    initTime_      = the_time;              // includes gain
+    dayChanged_    = false;
+    initLocalTime_ = second_clock_time(); // for real time clock
+    lastTime_      = initLocalTime_;      // for real time clock
+
+    // Cache the most common requests
+    update_cache();
+}
+
+void Calendar::update(const ecf::CalendarUpdateParams& calUpdateParams) {
+    assert(!suiteTime_.is_special()); // begin has not been called.
+
+    // Get the day of week before we update calendar, then same after to determine if the day changed
+    boost::gregorian::date currentdate = suiteTime_.date();
+    int theDayOfWeek                   = currentdate.day_of_week().as_number();
+
+    // However there are two ways of incremented/updating calendar.
+    if (!calUpdateParams.forTest()) {
+
+        if (calUpdateParams.serverPollPeriod().total_seconds() < 60) {
+            // 0/ We are still testing. User wants to speed up calendar.
+            //    i.e. if server poll period is 2 seconds, we increment calendar by 1 minute
+
+            time_duration one_minute(0, 1, 0, 0);
+            duration_ += one_minute;
+            suiteTime_ += one_minute;
+            increment_ = one_minute;
+
+#ifdef DEBUG_CALENDAR
+            std::cout << "Calendar::update:  if (calUpdateParams.serverPollPeriod().total_seconds() < 60) { \n";
+#endif
+        }
+        else {
+            // 1. Always Maintain phase with system clock. The calUpdateParams.timeNow()
+            //    time was constructed from a system call in the server.
+            //
+            // Take a difference, which means we can ignore dates
+            const ptime& time_now = calUpdateParams.timeNow();
+            assert(!time_now.is_special()); // This should have been set
+            duration_  = time_period(initLocalTime_, time_now).length();
+            increment_ = time_now - lastTime_;
+            suiteTime_ += increment_;
+            lastTime_ = time_now;
+#ifdef DEBUG_CALENDAR
+            std::cout << "Calendar::update:  if ( !calUpdateParams.forTest() ) { \n";
+#endif
+        }
+    }
+    else {
+        // 2. Update calendar based on server poll period/ Job submission interval
+        // _OR_ For TESTING allow calendar to be speeded up.
+        // Note: for simulation serverPollPeriod could be 1 hour
+        duration_ += calUpdateParams.serverPollPeriod();
+        suiteTime_ += calUpdateParams.serverPollPeriod();
+        increment_ = calUpdateParams.serverPollPeriod();
+#ifdef DEBUG_CALENDAR
+        std::cout << "Calendar::update:  calUpdateParams.serverPollPeriod() = " << calUpdateParams.serverPollPeriod()
+                  << "\n";
+#endif
+    }
+
+    // Day change required for both REAL and HYBRID. See TimeDependencies.ddoc for reason
+    // This must be done before change date back. (i.e in hybrid case, below)
+    int new_day_of_week = suiteTime_.date().day_of_week().as_number();
+    if (theDayOfWeek != new_day_of_week)
+        dayChanged_ = true;
+    else
+        dayChanged_ = false;
+
+    // With the hybrid calendar the date does not change
+    if (ctype_ == Calendar::HYBRID) {
+        if (suiteTime_.date() != initTime_.date()) {
+
+#ifdef DEBUG_CALENDAR
+            cout << "HYBRID: (suiteTime_.date() != initTime_.date()) suiteTime_ = " << to_simple_string(suiteTime_)
+                 << "\n";
+#endif
+
+            time_duration td = suiteTime_.time_of_day();
+
+            suiteTime_ = ptime(initTime_.date(), td);
+
+#ifdef DEBUG_CALENDAR
+            cout << "suiteTime_ = " << to_simple_string(suiteTime_) << "\n";
+#endif
+        }
+    }
+
+    // update_cache *MUST* be last, so we can take into account hybrid. Date does NOT change.
+    // See ECFLOW-458
+    update_cache();
+
+#ifdef DEBUG_CALENDAR
+    cout << "   Calendar::update serverPollPeriod = " << to_simple_string(calUpdateParams.serverPollPeriod()) << " "
+         << toString() << endl;
+#endif
+}
+
+void Calendar::update_duration_only(boost::posix_time::ptime& time_now) {
+    // 1. Always Maintain phase with system clock. The calUpdateParams.timeNow()
+    //    time was constructed from a system call in the server.
+    //
+    // Take a difference, which means we can ignore dates
+    boost::posix_time::time_duration dur = time_period(initLocalTime_, time_now).length();
+    if (dur > duration_) {
+        duration_ = dur;
+    }
+}
+
+void Calendar::update_cache() const {
+    // begin() has not been called yet
+    if (suiteTime_.is_special())
+        return;
+
+    boost::gregorian::date newDate = suiteTime_.date();
+    day_of_week_                   = newDate.day_of_week().as_number();
+    day_of_year_                   = newDate.day_of_year();
+    day_of_month_                  = newDate.day();
+    month_                         = newDate.month();
+    year_                          = newDate.year();
+}
+int Calendar::day_of_week() const {
+    if (day_of_week_ == -1)
+        update_cache();
+    return day_of_week_;
+}
+int Calendar::day_of_year() const {
+    if (day_of_week_ == -1)
+        update_cache();
+    return day_of_year_;
+}
+int Calendar::day_of_month() const {
+    if (day_of_week_ == -1)
+        update_cache();
+    return day_of_month_;
+}
+int Calendar::month() const {
+    if (day_of_week_ == -1)
+        update_cache();
+    return month_;
+}
+int Calendar::year() const {
+    if (day_of_week_ == -1)
+        update_cache();
+    return year_;
+}
+
+void Calendar::update(const boost::posix_time::time_duration& serverPollPeriod) {
+    CalendarUpdateParams p(serverPollPeriod);
+    update(p);
+}
+
+void Calendar::update(const boost::posix_time::ptime& time_now) {
+    // Used for test even though for_test is false, as we want to test that path in UNIT tests
+    // Tests: path 1. shown above. Note: we pass minutes(1), to ensure path 1. is taken
+    CalendarUpdateParams p(time_now, minutes(1), true /* server running */, false /* for Test*/);
+    update(p);
+}
+
+boost::gregorian::date Calendar::date() const {
+    return suiteTime_.date();
+}
+
+/// for debug
+void Calendar::dump(const std::string& title) const {
+    LOG(Log::LOG,
+        title << " duration_(" << to_simple_string(duration_) << ") initTime_(" << to_simple_string(initTime_)
+              << ") suiteTime_(" << to_simple_string(suiteTime_) << ")");
+}
+
+std::string Calendar::suite_time_str() const {
+    std::string ss;
+    if (day_of_week_ == 0)
+        ss += " SUNDAY";
+    else if (day_of_week_ == 1)
+        ss += " MONDAY";
+    else if (day_of_week_ == 2)
+        ss += " TUESDAY";
+    else if (day_of_week_ == 3)
+        ss += " WEDNESDAY";
+    else if (day_of_week_ == 4)
+        ss += " THURSDAY";
+    else if (day_of_week_ == 5)
+        ss += " FRIDAY";
+    else if (day_of_week_ == 6)
+        ss += " SATURDAY";
+    ss += " ";
+    ss += to_simple_string(suiteTime_);
+    return ss;
+}
+
+std::string Calendar::toString() const {
+    std::stringstream ss;
+    ss << "hybrid(" << hybrid() << ") duration_(" << to_simple_string(duration_) << ") initTime_("
+       << to_simple_string(initTime_) << ") suiteTime_(" << to_simple_string(suiteTime_) << ") dayChanged_("
+       << dayChanged_ << ")";
+    ss << " increment_(" << to_simple_string(increment_) << ")";
+
+    if (day_of_week_ == 0)
+        ss << " SUNDAY";
+    else if (day_of_week_ == 1)
+        ss << " MONDAY";
+    else if (day_of_week_ == 2)
+        ss << " TUESDAY";
+    else if (day_of_week_ == 3)
+        ss << " WEDNESDAY";
+    else if (day_of_week_ == 4)
+        ss << " THURSDAY";
+    else if (day_of_week_ == 5)
+        ss << " FRIDAY";
+    else if (day_of_week_ == 6)
+        ss << " SATURDAY";
+
+    return ss.str();
+}
+
+void Calendar::write_state(std::string& ret) const {
+    if (initTime_.is_special())
+        return;
+
+    bool increment__changed = (!increment_.is_special() && increment_.total_seconds() != 0);
+
+    // cType is obtained from the suite clock attribute, and not persisted
+    ret += " initTime:";
+    ret += to_simple_string(initTime_);
+    ret += " suiteTime:";
+    ret += to_simple_string(suiteTime_);
+    ret += " duration:";
+    ret += to_simple_string(duration_);
+    ret += " initLocalTime:";
+    ret += to_simple_string(initLocalTime_);
+    ret += " lastTime:";
+    ret += to_simple_string(lastTime_);
+    if (increment__changed) {
+        ret += " calendarIncrement:";
+        ret += to_simple_string(increment_);
+    }
+
+    if (dayChanged_)
+        ret += " dayChanged:1";
+}
+
+void Calendar::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
+    // initTime:2012-Jul-16 16:19:35 suiteTime:2012-Jul-16 16:19:35 duration:00:00:00 dayChanged:0
+    // initLocalTime:2012-Jul-16 16:19:35 lastTime:2012-Jul-16 16:19:35 calendarIncrement:00:00:00
+    //   std::cout << "Calendar::read_state:"  << line << "\n";
+    std::string time;
+    size_t line_tokens_size = lineTokens.size();
+    for (size_t i = 0; i < line_tokens_size; i++) {
+        time.clear();
+        const std::string& line_token = lineTokens[i];
+        if (line_token.find("initTime:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token, time))
+                throw std::runtime_error("Calendar::read_state failed: (initTime)");
+            if (i + 1 < line_tokens_size) {
+                time += " ";
+                time += lineTokens[i + 1];
+            }
+            else
+                throw std::runtime_error("Calendar::read_state failed: 1");
+            initTime_ = time_from_string(time);
+        }
+        else if (line_token.find("suiteTime:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token, time))
+                throw std::runtime_error("Calendar::read_state failed: (suiteTime)");
+            if (i + 1 < line_tokens_size) {
+                time += " ";
+                time += lineTokens[i + 1];
+            }
+            else
+                throw std::runtime_error("Calendar::read_state failed: 1");
+            suiteTime_ = time_from_string(time);
+        }
+        else if (line_token.find("initLocalTime:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token, time))
+                throw std::runtime_error("Calendar::read_state failed: (initLocalTime)");
+            if (i + 1 < line_tokens_size) {
+                time += " ";
+                time += lineTokens[i + 1];
+            }
+            else
+                throw std::runtime_error("Calendar::read_state failed: 1");
+            initLocalTime_ = time_from_string(time);
+        }
+        else if (line_token.find("lastTime:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token, time))
+                throw std::runtime_error("Calendar::read_state failed: (lastTime)");
+            if (i + 1 < line_tokens_size) {
+                time += " ";
+                time += lineTokens[i + 1];
+            }
+            else
+                throw std::runtime_error("Calendar::read_state failed: 1");
+            lastTime_ = time_from_string(time);
+        }
+        else if (line_token.find("duration:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token, time))
+                throw std::runtime_error("Calendar::read_state failed: (duration)");
+            duration_ = duration_from_string(time);
+        }
+        else if (line_token.find("calendarIncrement:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token, time))
+                throw std::runtime_error("Calendar::read_state failed: (calendarIncrement)");
+            increment_ = duration_from_string(time);
+        }
+        else if (line_token == "dayChanged:1")
+            dayChanged_ = true;
+    }
+}
+
+bool Calendar::checkInvariants(std::string& errorMsg) const {
+    if (!duration_.is_special()) {
+        if (duration_.is_negative()) {
+            errorMsg += "Calendar::checkInvariants duration is negative " + toString() + "\n";
+            return false;
+        }
+    }
+    return true;
+}
+
+boost::posix_time::ptime Calendar::second_clock_time() {
+    /// Chose UTC since it s compatible with boost deadline timer
+    return second_clock::universal_time(); // UTC
+}
+
+// ==================================================================================
+
+template <class Archive>
+void Calendar::serialize(Archive& ar, std::uint32_t const /*version*/) {
+    if (Archive::is_saving::value) {
+        if (initTime_.is_special()) {
+            // Initialise the ptimes to avoid serialisation exceptions
+            // The serialisation of ptime makes use of exceptions, especially
+            // when dealing with a date that has *not* been initialised.
+            // To avoid this we take a small hit to initialise the calendar with
+            // time now. This will get overridden with suite clock at begin
+            begin(second_clock_time());
+        }
+    }
+    ar(CEREAL_NVP(initTime_));
+    CEREAL_OPTIONAL_NVP(ar, suiteTime_, [this]() { return suiteTime_ != initTime_; });
+    CEREAL_OPTIONAL_NVP(ar, initLocalTime_, [this]() { return initLocalTime_ != initTime_; });
+    CEREAL_OPTIONAL_NVP(ar, lastTime_, [this]() { return lastTime_ != initTime_; });
+    CEREAL_OPTIONAL_NVP(ar, dayChanged_, [this]() { return dayChanged_; });
+    CEREAL_OPTIONAL_NVP(ar, duration_, [this]() { return duration_ != boost::posix_time::time_duration(0, 0, 0, 0); });
+    CEREAL_OPTIONAL_NVP(
+        ar, increment_, [this]() { return increment_ != boost::posix_time::time_duration(0, 1, 0, 0); });
+
+    if (Archive::is_loading::value) {
+        if (lastTime_.is_special())
+            lastTime_ = initTime_;
+        if (initLocalTime_.is_special())
+            initLocalTime_ = initTime_;
+        if (suiteTime_.is_special())
+            suiteTime_ = initTime_;
+    }
+}
+
+CEREAL_TEMPLATE_SPECIALIZE_V(Calendar);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Calendar.hpp 5.13.0-1/libs/core/src/ecflow/core/Calendar.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Calendar.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Calendar.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,229 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Calendar_HPP
+#define ecflow_core_Calendar_HPP
+
+///
+/// \brief The calendar encapsulates date and time. The date is derived from the time.
+///        The calendar object is initialised when the suite begins.
+///
+/// After each update the calendar will store the time_duration between the init() function
+/// call and the update() function call.
+/// The calendar is to be used for all reference to time and date
+/// This will stop different time functionality from getting out of step.
+///
+/// Examples of Use of calendar are:
+///   o Generated time variables
+///   o Time dependent attributes: TimeAttr,TodaySeries,CronAttr,DateAttr,DayAttr
+///     ****************************************************************************
+///     ** A time attribute can have a +, which means time relative to suite start
+///     ** This is stored on the TimeSeries, as it isNode/Attribute specific.
+///     ** i.e repeated families will have its own relative start time.
+///     *****************************************************************************
+///
+/// DESIGN CONSIDERATIONS:
+///   Real and Hybrid:
+///   Real
+///     calendar is like a normal calendar where time and date are related
+///     and day/date changes at midnight.
+///   Hybrid:
+///     There is currently confusion about how this is supposed to work.
+///     The date is not supposed to change. (According to John date updates at suite restart?)
+///     This has important implications, i.e does the day change ?
+///     If the day does not change, then many of suites will never complete.
+///       i.e if we use repeat, with a single time series,  "time 10:00"
+///     *** This relies on a day change to reset time attribute at midnight. ****
+///  Conclusion: Will support day change for both REAL and HYBRID (date does not change)
+///
+/// Calendar Updates:
+///   How and when should we update the calendar?
+///     In both the approaches below we need to make a distinction/separation
+///     between the server poll and calendar update. This is required for testing
+///
+///   o Poll/Job submission interval in server is used to update calendar .
+///     +: No time slots will be missed. even if server is suspended/restarted.
+///        since suspending the server, also suspends the calendar updates
+///     +: Suite relative times will continue to work even after server stopped/started
+///     +: Avoids additional system call.
+///     +: Lead's to more deterministic behaviour
+///     -: If server is suspended and restarted the calendar will NOT be in
+///        phase with system clock. (Its not clear to me why this should be an issue?)
+///     ?: If the server is run for several days is there a possibility for the poll
+///        update to get out of skew with real time. This is only possible if
+///        job dependencies take more the 60 seconds to resolve.
+///      *** THIS FUNCTIONALITY NEEDS TO BE ADVERTISED, SO THAT USERS ARE AWARE OF IT
+///      *** THIS FUNCTIONALITY IS AVAILABLE VIA -s flag on the clock attribute .i.e
+///      *** the -s stand's for stop start clock in line with the server
+///            clock real 20.1.2007 +01:00 -s
+///            clock hybrid -s
+///
+///   o Poll/Job submission interval in server is used Initiate an update of calendar via a system call.
+///     +: calendar is always in phase with system clock.
+///        Many task job dependencies depend on ordering based on real time.
+///     -: Requires additional system call for each poll in the server
+///     -: Time slots can be missed. (i.e if server suspended/restarted).
+///        There is no catch up. (?? See TimeDependencies.ddoc)
+///     -: Relative times will not be adhered too, when server stopped/started.
+///     -: Will require more manual intervention ?
+///
+///  Conclusion:: The clock attribute will be changed to add both capabilities
+///
+///  Resolution: Will support 1 minute resolution
+///
+
+#include <cstdint>
+
+#include <boost/date_time/posix_time/posix_time.hpp>
+
+namespace cereal {
+class access;
+}
+
+namespace ecf {
+
+class CalendarUpdateParams; // forward declare
+
+class Calendar {
+public:
+    enum Clock_t {
+        REAL,  // like a normal clock
+        HYBRID // date does not change, but will support day change. See Above.
+    };
+
+    /// Defaults to the REAL clock
+    Calendar();
+    Calendar(const Calendar&);
+    Calendar& operator=(const Calendar&);
+    bool operator==(const Calendar&) const;
+
+    /// Initialise the Calendar.
+    void init(Clock_t clock);
+
+    // for test init and begin calendar
+    void init(const boost::posix_time::ptime& time, Clock_t clock = Calendar::REAL);
+
+    /// Start the Calendar.  Parameter time can include gain.
+    void begin(const boost::posix_time::ptime&);
+
+    /// Update the calendar using the input. Will Store internally the time duration
+    /// between the init() function call and the last update.
+    /// The for_test parameter is *ONLY* used if we are using real time calendar
+    void update(const ecf::CalendarUpdateParams&);
+
+    /// This is used to improve resolution of state change time. ECFLOW-1512
+    void update_duration_only(boost::posix_time::ptime& time_now);
+
+    // Used for test only, will call the function above
+    void update(const boost::posix_time::time_duration&);
+    void update(const boost::posix_time::ptime& time_now);
+
+    // The following were added as a performance optimisation
+    // Represent a day within a week (range 0==Sun to 6==Sat)
+    int day_of_week() const;  // same as suiteTime().date().day_of_week().as_number()
+    int day_of_year() const;  // same as suiteTime().date().day_of_year()
+    int day_of_month() const; // same as suiteTime().date().day()
+    int month() const;        // same as suiteTime().date().month()
+    int year() const;         // same as suiteTime().date().year()
+
+    /// returns true if the day changed, this will update for REAL and HYBRID .
+    bool dayChanged() const { return dayChanged_; }
+
+    /// returns the last calendar increment
+    const boost::posix_time::time_duration& calendarIncrement() const { return increment_; }
+
+    /// return the init() time + the accumulated duration from calls to update(...)
+    /// This should only be used when this calendar is real.
+    const boost::posix_time::ptime& suiteTime() const { return suiteTime_; }
+    std::string suite_time_str() const;
+
+    // duration since last call to init, essentially suite duration
+    const boost::posix_time::time_duration& duration() const { return duration_; }
+
+    /// return real time, when the calendar was begun/initialised.
+    /// This is used to update the duration_, which is recorded for each state change in the node
+    /// Hence to when we can compute when a state change occurred by using:
+    ///   boost::posix_time::ptime time_of_state_change = begin_time() + node->get_state().second(duration)
+    const boost::posix_time::ptime& begin_time() const { return initLocalTime_; }
+
+    /// return the date, for real calendar this corresponds to the date on suiteTime_
+    /// for hybrid,  the date does not change, and hence we return date for initTime_
+    boost::gregorian::date date() const;
+
+    /// The calendar type. For hybrid clocks the date does not update.
+    bool hybrid() const { return (ctype_ == Calendar::HYBRID) ? true : false; }
+
+    /// for debug,  must link with boost date and time library
+    void dump(const std::string& title) const;
+
+    /// for debug,  must link with boost date and time library
+    std::string toString() const;
+
+    void write_state(std::string&) const;
+    void read_state(const std::string& line, const std::vector<std::string>& lineTokens);
+
+    bool checkInvariants(std::string& errorMsg) const;
+
+    // allow Suite memento to update calendar type
+    void set_clock_type(Clock_t ct) { ctype_ = ct; }
+
+    /// Will return either second_clock::universal_time()/UTC ( the other alternative is second_clock::local_time() )
+    /// This is because boost deadline timer is based on UTC clock
+    /// >>> The deadline_timer typedef is based on a UTC clock, and all operations (expires_at, expires_from_now) work
+    /// in UTC time.
+    /// >>> If you want it to use a different clock (such as the local time clock), you can use basic_deadline_timer<>
+    /// with your own traits class.
+    /// >>> Please see the "Timers" example.
+    /// Taken from boost date/time doc
+    /// If you want exact agreement with wall-clock time, you must use either UTC or local time. If you compute a
+    /// duration by subtracting one UTC time from another and you want an answer accurate to the second, the two times
+    /// must not be too far in the future because leap seconds affect the count but are only determined about 6 months
+    /// in advance. With local times a future duration calculation could be off by an entire hour, since legislatures
+    /// can and do change DST rules at will. If you want to handle wall-clock times in the future, you won't be able (in
+    /// the general case) to calculate exact durations, for the same reasons described above. If you want accurate
+    /// calculations with future times, you will have to use TAI or an equivalent, but the mapping from TAI to UTC or
+    /// local time depends on leap seconds, so you will not have exact agreement with wall-clock time.
+    static boost::posix_time::ptime second_clock_time();
+
+    bool is_special() const { return initTime_.is_special(); }
+
+private:
+    void assign(const Calendar& rhs);
+
+    boost::posix_time::ptime initTime_;      // When calendar was started, suite time(could be in the past OR real time)
+    boost::posix_time::ptime suiteTime_;     // The suite time for hybrid DATE does not change.
+    boost::posix_time::ptime initLocalTime_; // Real Time: When calendar was started, used to work out duration_
+    boost::posix_time::ptime lastTime_;      // Real Time: Used to calculate calendarIncrement
+    boost::posix_time::time_duration
+        duration_; // duration since last call to init/begin, used on Node for late and autocancel
+    boost::posix_time::time_duration increment_{0, 1, 0, 0};
+
+private:
+    void update_cache() const;
+    mutable int day_of_week_{-1};  // Cache
+    mutable int day_of_year_{-1};  // Cache
+    mutable int day_of_month_{-1}; // Cache
+    mutable int month_{-1};        // Cache
+    mutable int year_{-1};         // Cache
+
+    Clock_t ctype_{Calendar::REAL}; // *NOT* persisted: can be derived from suite clock attribute
+    bool dayChanged_{false};
+
+private:
+    // Note: The *only* reason to serialise the calendar is so that we can support
+    // why() command on the client side. By default, calendar is initialised in the *server*
+    // at begin time, from the clock attribute
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/);
+};
+} // namespace ecf
+
+#endif /* ecflow_core_Calendar_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/CalendarUpdateParams.hpp 5.13.0-1/libs/core/src/ecflow/core/CalendarUpdateParams.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/CalendarUpdateParams.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/CalendarUpdateParams.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_CalendarUpdateParams_HPP
+#define ecflow_core_CalendarUpdateParams_HPP
+
+///
+/// \brief Collate list of arguments used to update calendar
+///
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+namespace ecf {
+
+class CalendarUpdateParams {
+public:
+    // For use in the server
+    CalendarUpdateParams(const boost::posix_time::ptime& time_now,
+                         const boost::posix_time::time_duration& serverPollPeriod,
+                         bool serverRunning)
+        : timeNow_(time_now),
+          serverPollPeriod_(serverPollPeriod),
+          serverRunning_(serverRunning),
+          forTest_(false) {}
+
+    // For use in the simulator/ unit tests
+    explicit CalendarUpdateParams(const boost::posix_time::time_duration& serverPollPeriod)
+        : timeNow_(boost::date_time::not_a_date_time),
+          serverPollPeriod_(serverPollPeriod),
+          serverRunning_(true),
+          forTest_(true) {}
+
+    // For use in test
+    CalendarUpdateParams(const boost::posix_time::ptime& time_now,
+                         const boost::posix_time::time_duration& serverPollPeriod,
+                         bool serverRunning,
+                         bool forTest)
+        : timeNow_(time_now),
+          serverPollPeriod_(serverPollPeriod),
+          serverRunning_(serverRunning),
+          forTest_(forTest) {}
+
+    // Disable copy (and move) semantics
+    CalendarUpdateParams(const CalendarUpdateParams&)                  = delete;
+    const CalendarUpdateParams& operator=(const CalendarUpdateParams&) = delete;
+
+    const boost::posix_time::ptime& timeNow() const { return timeNow_; }
+    const boost::posix_time::time_duration& serverPollPeriod() const { return serverPollPeriod_; }
+    bool serverRunning() const { return serverRunning_; }
+    bool forTest() const { return forTest_; }
+
+private:
+    boost::posix_time::ptime timeNow_;                  // Current time and date, not used in simulator
+    boost::posix_time::time_duration serverPollPeriod_; // equivalent to calendar increment
+    bool serverRunning_;                                // Is the server running or stopped
+    bool forTest_;                                      // Used with Simulator
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_CalendarUpdateParams_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/CheckPt.hpp 5.13.0-1/libs/core/src/ecflow/core/CheckPt.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/CheckPt.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/CheckPt.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,44 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_CheckPt_HPP
+#define ecflow_core_CheckPt_HPP
+
+///
+/// \brief This class serialises the edit history when storing a check point.
+///        Provides also check point status enumerates.
+///
+
+namespace ecf {
+
+class CheckPt {
+public:
+    /// NEVER   - the check pt file is never saved
+    /// ON_TIME - the check pt file is saved periodically. specified by checkPtInterval.
+    /// ALWAYS  - the check pt file is saved after any state change
+    /// UNDEFINED   - Internal use only
+    enum Mode { NEVER, ON_TIME, ALWAYS, UNDEFINED };
+
+    // Disable default construction
+    CheckPt() = delete;
+    // Disable copy (and move) semantics
+    CheckPt(const CheckPt&)                  = delete;
+    const CheckPt& operator=(const CheckPt&) = delete;
+
+    /// The interval between automatic saves of check point by server
+    static int default_interval() { return 120; }
+
+    /// If saving check point takes longer than the alarm time, raise late flag on the server
+    static int default_save_time_alarm() { return 20; }
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_CheckPt_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Child.cpp 5.13.0-1/libs/core/src/ecflow/core/Child.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Child.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Child.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,146 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Child.hpp"
+
+#include <cassert>
+
+#include "ecflow/core/Enumerate.hpp"
+#include "ecflow/core/Str.hpp"
+
+namespace ecf {
+
+namespace detail {
+
+template <>
+struct EnumTraits<Child::ZombieType>
+{
+    using underlying_t = std::underlying_type_t<Child::ZombieType>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(Child::ZombieType::USER, "user"),
+        std::make_pair(Child::ZombieType::ECF, "ecf"),
+        std::make_pair(Child::ZombieType::ECF_PID, "ecf_pid"),
+        std::make_pair(Child::ZombieType::ECF_PASSWD, "ecf_passwd"),
+        std::make_pair(Child::ZombieType::ECF_PID_PASSWD, "ecf_pid_passwd"),
+        std::make_pair(Child::ZombieType::PATH, "path"),
+        std::make_pair(Child::ZombieType::NOT_SET, "not_set"),
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<Child::ZombieType>::size == map.back().first + 1);
+};
+
+template <>
+struct EnumTraits<Child::CmdType>
+{
+    using underlying_t = std::underlying_type_t<Child::CmdType>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(Child::CmdType::INIT, "init"),
+        std::make_pair(Child::CmdType::EVENT, "event"),
+        std::make_pair(Child::CmdType::METER, "meter"),
+        std::make_pair(Child::CmdType::LABEL, "label"),
+        std::make_pair(Child::CmdType::WAIT, "wait"),
+        std::make_pair(Child::CmdType::QUEUE, "queue"),
+        std::make_pair(Child::CmdType::ABORT, "abort"),
+        std::make_pair(Child::CmdType::COMPLETE, "complete"),
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<Child::CmdType>::size == map.back().first + 1);
+};
+
+} // namespace detail
+
+std::string Child::to_string(Child::ZombieType zt) {
+    if (auto found = Enumerate<Child::ZombieType>::to_string(zt); found) {
+        return std::string{found.value()};
+    }
+    return std::string{};
+}
+
+Child::ZombieType Child::zombie_type(const std::string& s) {
+    return Enumerate<Child::ZombieType>::to_enum(s).value_or(Child::NOT_SET);
+}
+
+bool Child::valid_zombie_type(const std::string& s) {
+    return Enumerate<Child::ZombieType>::is_valid(s);
+}
+
+std::string Child::to_string(const std::vector<Child::CmdType>& vec) {
+    std::string ret;
+    for (size_t i = 0; i < vec.size(); ++i) {
+        if (i != 0) {
+            ret += ",";
+        }
+        ret += to_string(vec[i]);
+    }
+    return ret;
+}
+
+std::string Child::to_string(Child::CmdType ct) {
+    if (auto found = Enumerate<Child::CmdType>::to_string(ct); found) {
+        return std::string{found.value()};
+    }
+    assert(false);
+    return std::string{Enumerate<Child::CmdType>::to_string(Child::INIT).value()};
+}
+
+std::vector<Child::CmdType> Child::child_cmds(const std::string& s) {
+    // expect single or , separated tokens
+    std::vector<std::string> tokens;
+    Str::split(s, tokens, ",");
+    std::vector<Child::CmdType> ret;
+    ret.reserve(tokens.size());
+    for (const auto& token : tokens) {
+        ret.push_back(child_cmd(token));
+    }
+    return ret;
+}
+
+Child::CmdType Child::child_cmd(const std::string& s) {
+    if (auto found = Enumerate<Child::CmdType>::to_enum(s); found) {
+        return found.value();
+    }
+    assert(false);
+    return Child::INIT;
+}
+
+bool Child::valid_child_cmds(const std::string& s) {
+    // empty means all children
+    if (s.empty()) {
+        return true;
+    }
+
+    // expect single or , separated tokens
+    std::vector<std::string> tokens;
+    Str::split(s, tokens, ",");
+    for (const auto& token : tokens) {
+        if (!valid_child_cmd(token)) {
+            return false;
+        }
+    }
+    return true;
+}
+
+bool Child::valid_child_cmd(const std::string& s) {
+    return Enumerate<Child::CmdType>::is_valid(s);
+}
+
+std::vector<Child::CmdType> Child::list() {
+    return Enumerate<Child::CmdType>::enums();
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Child.hpp 5.13.0-1/libs/core/src/ecflow/core/Child.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Child.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Child.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Child_HPP
+#define ecflow_core_Child_HPP
+
+///
+/// \brief Specifies the different kinds of child commands, as specified in the
+///        job file and communicated to the server.
+///
+
+#include <string>
+#include <vector>
+
+namespace ecf {
+
+class Child {
+public:
+    enum CmdType {
+        INIT,    // Notify Task start
+        EVENT,   // Notify Task event update
+        METER,   // Notify Task meter update
+        LABEL,   // Notify Task label update
+        WAIT,    // Request to wait until given expression evaluates to true
+        QUEUE,   // Request to interact with Queue (active|complete|abort|...)
+        ABORT,   // Notify Task abortion
+        COMPLETE // Notify Task completion
+    };
+
+    enum ZombieType {
+        USER,           // zombie created by user action
+        ECF,            // two init commands, or aborted and complete, and received any other child command
+        ECF_PID,        // pid miss-match, but password matches,  -> same job submitted twice |
+        ECF_PASSWD,     // password miss-match, but pid matches   -> WTF, user edited ECF_PASS in job file ?
+        ECF_PID_PASSWD, // pid and password missmatch             -> Job re-queued and submitted again
+        PATH,           // zombie, because path to task does not exist in the server
+        NOT_SET
+    };
+
+    // Disable default construction
+    Child() = delete;
+    // Disable copy (and move) semantics
+    Child(const Child&)                  = delete;
+    const Child& operator=(const Child&) = delete;
+
+    static std::string to_string(ZombieType);
+    static bool valid_zombie_type(const std::string&);
+    static ZombieType zombie_type(const std::string&);
+
+    static std::string to_string(const std::vector<Child::CmdType>&);
+    static std::string to_string(Child::CmdType);
+    static std::vector<Child::CmdType> child_cmds(const std::string&);
+    static Child::CmdType child_cmd(const std::string&);
+
+    static std::vector<Child::CmdType> list();
+
+    /// Expect a , separated string
+    static bool valid_child_cmds(const std::string&);
+    static bool valid_child_cmd(const std::string&);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_Child_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Chrono.cpp 5.13.0-1/libs/core/src/ecflow/core/Chrono.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Chrono.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Chrono.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,240 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "Chrono.hpp"
+
+#include <algorithm>
+#include <array>
+#include <iomanip>
+#include <sstream>
+
+#include <boost/lexical_cast.hpp>
+
+namespace ecf {
+
+namespace {
+
+template <typename C, typename T>
+bool contains(const C& collection, const T& value) {
+    return std::find(std::begin(collection), std::end(collection), value) != std::end(collection);
+}
+
+int days_of_month(int month /* [0-11] */, int year) {
+    if (contains(std::array{0, 2, 4, 6, 7, 9, 11}, month)) {
+        return 31;
+    }
+    if (contains(std::array{3, 5, 8, 10}, month)) {
+        return 30;
+    }
+    if (month == 1) {
+        return (year % 4 == 0 && year % 100) || year % 400 == 0 ? 29 : 28;
+    }
+    throw std::runtime_error("Invalid month detected, while calculating the number of days");
+}
+
+bool is_valid_days_of_month(int day /* [1-31] */, int month /* [0-11] */, int year) {
+    return ((1 <= day) && (day <= days_of_month(month, year)));
+}
+
+} // namespace
+
+Instant Instant::parse(const std::string& value) {
+    std::tm tm = {};
+    std::stringstream ss(value);
+    ss >> std::get_time(&tm, "%Y%m%dT%H%M%S");
+    // Validate if parsing was successful
+    if (ss.fail()) {
+        throw std::runtime_error("Unable to parse invalid instant value: " + value);
+    }
+    // Extra validation of the parsed values (n.b. parsing doesn't ensure number of days is in agreement with the month)
+    if (!is_valid_days_of_month(tm.tm_mday, tm.tm_mon, tm.tm_year + 1900)) {
+        throw std::runtime_error("Detected invalid number of days for instant value: " + value);
+    }
+
+    // Unfortunately, std::mktime does the conversion considering locale, and thus considering timezones e.g. BST.
+    // The following convert std::tm to time_t (i.e. seconds since Posix epoch disregarding the timezone,
+    // adapted from Howard Hinnant's algorithms: http://howardhinnant.github.io/date_algorithms.html (days_from_civil).
+    //
+    // Note: All this can eventually be replaced by using C++20's std::chrono::parse.
+    std::time_t time;
+    {
+        int y      = tm.tm_year + 1900;
+        unsigned m = tm.tm_mon + 1;
+        unsigned d = tm.tm_mday;
+        y -= m <= 2;
+        const int era      = (y >= 0 ? y : y - 399) / 400;
+        const unsigned yoe = static_cast<unsigned>(y - era * 400);           // [0, 399]
+        const unsigned doy = (153 * (m + (m > 2 ? -3 : 9)) + 2) / 5 + d - 1; // [0, 365]
+        const unsigned doe = yoe * 365 + yoe / 4 - yoe / 100 + doy;          // [0, 146096]
+
+        time = (era * 146097 + static_cast<int>(doe) - 719468) * 86400 + tm.tm_hour * 3600 + tm.tm_min * 60 + tm.tm_sec;
+    }
+
+    return Instant{Instant::clock_t::from_time_t(time)};
+}
+
+std::string Instant::format(const Instant& value) {
+    auto tt    = std::chrono::system_clock::to_time_t(value.instant_);
+    std::tm tm = *std::gmtime(&tt);
+
+    std::ostringstream o;
+    o << std::put_time(&tm, "%Y%m%dT%H%M%S");
+    return o.str();
+}
+
+std::ostream& operator<<(std::ostream& o, const Instant& v) {
+    o << Instant::format(v);
+    return o;
+}
+
+bool operator==(const Instant& rhs, const Instant& lhs) {
+    return rhs.instant_ == lhs.instant_;
+}
+
+bool operator!=(const Instant& rhs, const Instant& lhs) {
+    return !(rhs == lhs);
+}
+
+bool operator<(const Instant& rhs, const Instant& lhs) {
+    return rhs.instant_ < lhs.instant_;
+}
+
+bool operator<=(const Instant& rhs, const Instant& lhs) {
+    return rhs == lhs || rhs < lhs;
+}
+
+bool operator>(const Instant& rhs, const Instant& lhs) {
+    return !(rhs <= lhs);
+}
+
+bool operator>=(const Instant& rhs, const Instant& lhs) {
+    return !(rhs < lhs);
+}
+
+Instant operator+(const Instant& rhs, const Duration& lhs) {
+    return Instant{rhs.instant_ + lhs.as_seconds()};
+}
+
+Instant operator-(const Instant& rhs, const Duration& lhs) {
+    return Instant{rhs.instant_ - lhs.as_seconds()};
+}
+
+Duration operator-(const Instant& rhs, const Instant& lhs) {
+    auto diff = rhs.instant_ - lhs.instant_;
+    return Duration{std::chrono::duration_cast<std::chrono::seconds>(diff)};
+}
+
+Instant coerce_to_instant(long value) {
+    auto seconds_since_reference = std::chrono::seconds{value};
+    auto instant                 = Instant{Instant::instant_t{seconds_since_reference}};
+    return instant;
+}
+
+long coerce_from_instant(const Instant& value) {
+    auto seconds_since_reference = std::chrono::duration_cast<std::chrono::seconds>(value.instant_.time_since_epoch());
+    return seconds_since_reference.count();
+}
+
+namespace detail {
+
+template <class DurationIn, class FirstDuration, class... RestDurations>
+std::string format_duration(DurationIn d) {
+    auto value = std::chrono::duration_cast<FirstDuration>(d);
+
+    std::ostringstream oss;
+    oss << std::setw(2) << std::setfill('0') << value.count(); // Ensure left 0-padded value with 2 digits
+    std::string out = oss.str();
+
+    if constexpr (sizeof...(RestDurations) > 0) {
+        // Important!
+        // The whole duration has the same sign as the first component
+        // e.g. -23:59:59, is interpreted as (-23 hours) + (-59 minutes) + (-59 seconds) = -86399 seconds
+        int sign = value >= FirstDuration{0} ? 1 : -1;
+        out += ":" + format_duration<DurationIn, RestDurations...>(sign * (d - value));
+    }
+
+    return out;
+}
+
+template <class DurationOut, class FirstDuration, class... RestDurations>
+DurationOut parse_duration(const std::string& d) {
+    auto found       = d.find(':');
+    std::string head = d.substr(0, found);
+
+    // Convert head (if any) to duration
+    auto value = FirstDuration(0);
+    if (!head.empty()) {
+        value = FirstDuration(boost::lexical_cast<int>(head.c_str()));
+    }
+    DurationOut out = std::chrono::duration_cast<DurationOut>(value);
+
+    if (found == std::string::npos) {
+        return out;
+    }
+
+    // Extract tail
+    std::string tail = d.substr(found + 1, std::string::npos);
+
+    if constexpr (sizeof...(RestDurations) > 0) {
+        // Important!
+        // The whole duration has the same sign as the first component
+        // e.g. -23:59:59, is interpreted as (-23 hours) + (-59 minutes) + (-59 seconds) = -86399 seconds
+        int sign = value >= FirstDuration{0} ? 1 : -1;
+
+        out = out + (sign)*parse_duration<DurationOut, RestDurations...>(tail);
+    }
+
+    return out;
+}
+
+} // namespace detail
+
+Duration Duration::parse(const std::string& value) {
+    return Duration{
+        detail::parse_duration<Duration::duration_t, std::chrono::hours, std::chrono::minutes, std::chrono::seconds>(
+            value)};
+}
+
+std::string Duration::format(const Duration& value) {
+    return detail::
+        format_duration<Duration::duration_t, std::chrono::hours, std::chrono::minutes, std::chrono::seconds>(
+            value.duration_);
+}
+
+std::ostream& operator<<(std::ostream& o, const Duration& v) {
+    o << Duration::format(v);
+    return o;
+}
+
+bool operator==(const Duration& rhs, const Duration& lhs) {
+    return rhs.duration_ == lhs.duration_;
+}
+
+bool operator!=(const Duration& rhs, const Duration& lhs) {
+    return !(rhs == lhs);
+}
+
+bool operator<(const Duration& rhs, const Duration& lhs) {
+    return rhs.duration_ < lhs.duration_;
+}
+
+bool operator<=(const Duration& rhs, const Duration& lhs) {
+    return rhs == lhs || rhs < lhs;
+}
+
+bool operator>(const Duration& rhs, const Duration& lhs) {
+    return !(rhs <= lhs);
+}
+
+bool operator>=(const Duration& rhs, const Duration& lhs) {
+    return !(rhs < lhs);
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Chrono.hpp 5.13.0-1/libs/core/src/ecflow/core/Chrono.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Chrono.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Chrono.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,92 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Chrono_HPP
+#define ecflow_core_Chrono_HPP
+
+#include <chrono>
+#include <string>
+
+namespace ecf {
+
+class Instant;
+class Duration;
+
+Instant coerce_to_instant(long value);
+long coerce_from_instant(const Instant& value);
+
+class Instant {
+public:
+    using clock_t   = std::chrono::system_clock;
+    using instant_t = std::chrono::time_point<Instant::clock_t>;
+
+    Instant() : instant_() {}
+    explicit Instant(instant_t instant)
+        : instant_(std::chrono::duration_cast<std::chrono::seconds>(instant.time_since_epoch())) {}
+    explicit Instant(std::chrono::seconds seconds_since_reference) : instant_(seconds_since_reference) {}
+
+    static Instant parse(const std::string& value);
+    static std::string format(const Instant& value);
+
+    friend bool operator==(const Instant& rhs, const Instant& lhs);
+    friend bool operator<(const Instant& rhs, const Instant& lhs);
+
+    friend Instant operator+(const Instant& rhs, const Duration& lhs);
+    friend Instant operator-(const Instant& rhs, const Duration& lhs);
+    friend Duration operator-(const Instant& rhs, const Instant& lhs);
+
+    friend Instant coerce_to_instant(long value);
+    friend long coerce_from_instant(const Instant& value);
+
+private:
+    instant_t instant_;
+};
+
+std::ostream& operator<<(std::ostream& o, const Instant& v);
+
+bool operator==(const Instant& rhs, const Instant& lhs);
+bool operator!=(const Instant& rhs, const Instant& lhs);
+bool operator<(const Instant& rhs, const Instant& lhs);
+bool operator<=(const Instant& rhs, const Instant& lhs);
+bool operator>(const Instant& rhs, const Instant& lhs);
+bool operator>=(const Instant& rhs, const Instant& lhs);
+
+class Duration {
+public:
+    using duration_t = std::chrono::seconds;
+
+    Duration() : duration_{} {}
+    template <typename DURATION>
+    explicit Duration(DURATION duration) : duration_{std::chrono::duration_cast<duration_t>(duration)} {}
+
+    [[nodiscard]] duration_t as_seconds() const { return duration_; }
+
+    static Duration parse(const std::string& value);
+    static std::string format(const Duration& value);
+
+    friend bool operator==(const Duration& rhs, const Duration& lhs);
+    friend bool operator<(const Duration& rhs, const Duration& lhs);
+
+private:
+    duration_t duration_;
+};
+
+std::ostream& operator<<(std::ostream& o, const Duration& v);
+
+bool operator==(const Duration& rhs, const Duration& lhs);
+bool operator!=(const Duration& rhs, const Duration& lhs);
+bool operator<(const Duration& rhs, const Duration& lhs);
+bool operator<=(const Duration& rhs, const Duration& lhs);
+bool operator>(const Duration& rhs, const Duration& lhs);
+bool operator>=(const Duration& rhs, const Duration& lhs);
+
+} // namespace ecf
+
+#endif // ECFLOW_CHRONO_HPP
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/CommandLine.cpp 5.13.0-1/libs/core/src/ecflow/core/CommandLine.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/CommandLine.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/CommandLine.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,229 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/CommandLine.hpp"
+
+#include <boost/program_options.hpp>
+#include <boost/tokenizer.hpp>
+
+namespace impl_detail {
+
+/**
+ * The `custom_unix_style_separator` implements a TokenizerFunction (from Boost.Tokenizer), and allows to separate the
+ * tokens of Unix style CLI calls. This separation is performed considering that repeated consecutive separators
+ * can appear. The following is an example of the expected tokenizing:
+ *   Given `   executable  --option    param  " --value "      ""   "\""  --options`, the expected tokens are:
+ *     - `executable`
+ *     - `--option`
+ *     - `param`
+ *     - ` --value `
+ *     - ``
+ *     - `"`
+ *     - `--options`
+ */
+class custom_unix_style_separator {
+
+private:
+    std::string escape_    = "\\";
+    std::string separator_ = " \t";
+    std::string quote_     = "'\"";
+    bool last_             = false;
+
+    bool is(char e, std::string set) {
+        return std::find_if(set.begin(), set.end(), [e](char c) { return c == e; }) != set.end();
+    }
+
+    bool is_escape(char e) { return is(e, escape_); }
+    bool is_separator(char e) { return is(e, separator_); }
+    bool is_quote(char e) { return is(e, quote_); }
+
+    template <typename iterator>
+    bool advance_separators(iterator& next, iterator& end) {
+
+        // Advance through all separators
+        while (is_separator(*next) && next != end) {
+            next++;
+        }
+
+        return (next == end);
+    }
+
+    template <typename iterator, typename Token>
+    void do_escape(iterator& next, iterator end, Token& tok) {
+        if (++next == end) {
+            throw std::runtime_error(std::string("Unexpected end of escape sequence"));
+        }
+        if (*next == 'n') {
+            tok += '\n';
+            return;
+        }
+        else if (is_quote(*next) || is_separator(*next) || is_escape(*next)) {
+            tok += *next;
+            return;
+        }
+        else {
+            throw std::runtime_error("Unexpected escape sequence");
+        }
+    }
+
+    std::vector<char> selected_quote_ = {};
+
+    bool in_quote() { return !selected_quote_.empty(); }
+
+public:
+    void reset() { last_ = false; }
+
+    template <typename InputIterator, typename Token>
+    bool operator()(InputIterator& next, InputIterator end, Token& tok) {
+        // Reset collected Token
+        tok        = Token();
+        bool valid = false;
+
+        // Consume pre-separators, and handle the case where we reach the end of the iterable
+        if (advance_separators(next, end)) {
+            if (last_) {
+                last_ = false;
+                return true;
+            }
+            return false;
+        }
+
+        // Otherwise, collect the token
+        last_ = false;
+        for (; next != end; ++next) {
+            if (is_escape(*next)) {
+                do_escape(next, end, tok);
+            }
+            else if (is_separator(*next)) {
+                if (!in_quote()) {
+                    // If we are not in quote, then we are done
+                    ++next;
+                    // The last character was a c, that means there is
+                    // 1 more blank field
+                    last_ = true;
+
+                    // Consume post-separators
+                    if (advance_separators(next, end)) {
+                        if (last_) {
+                            last_ = false;
+                            return true;
+                        }
+                        return false;
+                    }
+
+                    return true;
+                }
+                else {
+                    valid = true;
+                    tok += *next;
+                }
+            }
+            else if (is_quote(*next)) {
+
+                if (!in_quote()) {
+                    // Entering quoted sequence...
+                    selected_quote_.push_back(*next);
+                }
+                else if (selected_quote_.back() == *next) {
+                    // Matching quotation marks detected... Ending the quoted sequence!
+                    selected_quote_.pop_back();
+                }
+                else {
+                    // Unmatched quotation marks detected... Keep collecting the quoted sequence!
+                    tok += *next;
+                }
+            }
+            else {
+                valid = true;
+                tok += *next;
+            }
+        }
+
+        // Consume post-separators
+        if (advance_separators(next, end)) {
+            if (last_) {
+                last_ = false;
+                return true;
+            }
+            if (in_quote()) {
+                throw std::runtime_error("Unmatched quotation marks detected");
+            }
+            return valid;
+        }
+
+        if (in_quote()) {
+            throw std::runtime_error("Unmatched quotation marks detected");
+        }
+        return true;
+    }
+};
+
+CommandLine::cl_t reconstruct_command_line(const CommandLine::tokens_t& tokens, const std::string& separator = " ") {
+    std::ostringstream cl;
+    if (!tokens.empty()) {
+        cl << tokens.front();
+        for (size_t i = 1; i < tokens.size(); ++i) {
+            cl << separator << '"' << tokens[i] << '"';
+        }
+    }
+    return cl.str();
+}
+
+CommandLine::tokens_t reconstruct_tokens(int argc, const char** argv) {
+    CommandLine::tokens_t tokens;
+    for (int i = 0; i < argc; ++i) {
+        tokens.push_back(argv[i]);
+    }
+    return tokens;
+}
+
+std::vector<std::string> split_unix(const std::string& cmdline) {
+    using separator_t = custom_unix_style_separator;
+    using tokenizer_t = boost::tokenizer<separator_t, std::string::const_iterator, std::string>;
+
+    tokenizer_t tok(std::begin(cmdline), std::end(cmdline), separator_t());
+
+    std::vector<std::string> result;
+    for (typename tokenizer_t::iterator curT(tok.begin()), endT(tok.end()); curT != endT; ++curT) {
+        result.push_back(*curT);
+    }
+    return result;
+}
+
+} // namespace impl_detail
+
+CommandLine::CommandLine(int argc, char** argv) : CommandLine(argc, const_cast<const char**>(argv)) {
+}
+
+CommandLine::CommandLine(int argc, const char** argv) : tokens_{impl_detail::reconstruct_tokens(argc, argv)} {
+}
+
+CommandLine::CommandLine(const std::string& cl) : tokens_{impl_detail::split_unix(cl)} {
+}
+
+CommandLine::CommandLine(tokens_t tokens) : tokens_{std::move(tokens)} {
+}
+
+CommandLine::cl_t CommandLine::original() const {
+    return impl_detail::reconstruct_command_line(tokens_);
+}
+
+size_t CommandLine::size() const {
+    return tokens_.size();
+}
+
+const CommandLine::tokens_t& CommandLine::tokens() const {
+    return tokens_;
+}
+
+std::ostream& operator<<(std::ostream& os, const CommandLine& cl) {
+    os << "argc=" << cl.tokens_.size() << ", argv=[" << impl_detail::reconstruct_command_line(cl.tokens_, ", ") << "]";
+    return os;
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/CommandLine.hpp 5.13.0-1/libs/core/src/ecflow/core/CommandLine.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/CommandLine.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/CommandLine.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,111 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_CommandLine_HPP
+#define ecflow_core_CommandLine_HPP
+
+#include <ostream>
+#include <string>
+#include <vector>
+
+/**
+ * CommandLine is a thin wrapper/container for the contents of an ecFlow client command line.
+ *
+ * Note: This class is related to class ArgvCreator, which takes the vector of the command
+ * line tokens and converts them into argc+argv.
+ */
+class CommandLine {
+public:
+    using cl_t     = std::string;
+    using tokens_t = std::vector<std::string>;
+    using size_t   = tokens_t::size_type;
+
+public:
+    /**
+     * Create a Command Line instance based on argc + argv
+     *
+     * @param argc the number of tokens in the command line
+     * @param argv the tokens in the command line
+     */
+    CommandLine(int argc, char** argv);
+    CommandLine(int argc, const char** argv);
+
+    /**
+     * Create a Command Line instance based on a sequence of characters,
+     * considering that it might include single/double quotes.
+     *
+     * @param cl the command line as a sequence of characters
+     */
+    explicit CommandLine(const cl_t& cl);
+
+    /**
+     * Create a Command Line instance based on a sequence of tokens.
+     *
+     * @param tokens the command line as a sequence of tokens
+     */
+    explicit CommandLine(tokens_t tokens);
+
+    /**
+     * Create a Command Line instance based on multiple tokens.
+     * Tokens can be either strings or collections of strings. In the latter case, the collection of strings are
+     * added to the command line element-by-element.
+     *
+     * @param tokens the command line as multiple tokens
+     */
+    template <typename... TOKENS>
+    static CommandLine make_command_line(TOKENS... tokens) {
+        auto push = Overload{
+            [](std::vector<std::string>& collection, const std::vector<std::string>& tokens) {
+                std::copy(std::begin(tokens), std::end(tokens), std::back_inserter(collection));
+            },
+            [](std::vector<std::string>& collection, const std::string& token) { collection.push_back(token); }};
+
+        std::vector<std::string> ts;
+        ((push(ts, tokens)), ...);
+        return CommandLine(ts);
+    }
+
+    /**
+     * Access the original content of the command line.
+     */
+    [[nodiscard]] cl_t original() const;
+
+    /**
+     * Access the number of tokens composing the command line.
+     *
+     * @return the number of tokens
+     */
+    [[nodiscard]] size_t size() const;
+
+    /**
+     * Access the sequence of tokens composing the command line.
+     *
+     * @return the command line tokens
+     */
+    [[nodiscard]] const tokens_t& tokens() const;
+
+    /**
+     * Pretty print the command line
+     */
+    friend std::ostream& operator<<(std::ostream& os, const CommandLine& cl);
+
+private:
+    tokens_t tokens_;
+
+    // Utility to allow the combination of multiple lambdas
+    template <typename... L>
+    struct Overload : L...
+    {
+        using L::operator()...;
+        constexpr explicit Overload(L... lambda) : L(std::move(lambda))... {}
+    };
+};
+
+#endif /* ecflow_core_CommandLine_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Converter.hpp 5.13.0-1/libs/core/src/ecflow/core/Converter.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Converter.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Converter.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,73 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Converter_HPP
+#define ecflow_core_Converter_HPP
+
+#include <string>
+#include <utility>
+
+#include <boost/lexical_cast.hpp>
+
+namespace ecf {
+
+struct bad_conversion : public std::runtime_error
+{
+    explicit bad_conversion(const char* m) : std::runtime_error(m) {}
+    explicit bad_conversion(const std::string& m) : std::runtime_error(m) {}
+};
+
+namespace detail {
+
+template <typename To, typename From>
+inline static auto try_lexical_convert(From&& v) {
+    try {
+        return boost::lexical_cast<To>(v);
+    }
+    catch (const boost::bad_lexical_cast& e) {
+        throw bad_conversion(e.what());
+    }
+}
+
+} // namespace detail
+
+template <typename From, typename To>
+struct converter_traits
+{
+    inline static auto convert(From&& v) { return detail::try_lexical_convert<To>(std::forward<From>(v)); }
+};
+
+template <>
+struct converter_traits<char, std::string>
+{
+    inline static auto convert(char v) { return std::string{v}; }
+};
+
+template <>
+struct converter_traits<const char*, std::string>
+{
+    inline static auto convert(const char* v) { return std::string{v}; }
+};
+
+template <typename From>
+struct converter_traits<From, std::enable_if<std::is_integral_v<From> || std::is_floating_point_v<From>, std::string>>
+{
+    inline static auto convert(From&& v) { return std::to_string(v); }
+};
+
+template <typename To, typename From>
+inline auto convert_to(From&& v) {
+    using namespace ecf::detail;
+    return converter_traits<From, To>::convert(std::forward<From>(v));
+}
+
+} // namespace ecf
+
+#endif /* ecflow_core_Converter_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/DState.cpp 5.13.0-1/libs/core/src/ecflow/core/DState.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/DState.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/DState.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,119 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/DState.hpp"
+
+#include <cassert>
+#include <stdexcept>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Enumerate.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+namespace ecf::detail {
+
+template <>
+struct EnumTraits<DState::State>
+{
+    using underlying_t = std::underlying_type_t<DState::State>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(DState::State::UNKNOWN, "unknown"),
+        std::make_pair(DState::State::COMPLETE, "complete"),
+        std::make_pair(DState::State::QUEUED, "queued"),
+        std::make_pair(DState::State::ABORTED, "aborted"),
+        std::make_pair(DState::State::SUBMITTED, "submitted"),
+        std::make_pair(DState::State::ACTIVE, "active"),
+        std::make_pair(DState::State::SUSPENDED, "suspended"),
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<DState::State>::size == map.back().first + 1);
+};
+
+} // namespace ecf::detail
+
+void DState::setState(State s) {
+    st_              = s;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "DState::setState\n";
+#endif
+}
+
+NState::State DState::convert(DState::State display_state) {
+    switch (display_state) {
+        case DState::UNKNOWN:
+            return NState::UNKNOWN;
+        case DState::COMPLETE:
+            return NState::COMPLETE;
+        case DState::SUSPENDED:
+            return NState::UNKNOWN;
+        case DState::QUEUED:
+            return NState::QUEUED;
+        case DState::ABORTED:
+            return NState::ABORTED;
+        case DState::SUBMITTED:
+            return NState::SUBMITTED;
+        case DState::ACTIVE:
+            return NState::ACTIVE;
+    }
+    return NState::UNKNOWN;
+}
+
+const char* DState::toString(DState::State s) {
+    if (auto found = ecf::Enumerate<DState::State>::to_string(s); found) {
+        return found.value().data();
+    }
+    assert(false);
+    return {};
+}
+
+std::string DState::to_html(DState::State s) {
+    std::string res;
+    if (auto found = ecf::Enumerate<DState::State>::to_string(s); found) {
+        res += "<state>";
+        res += found.value();
+        res += "</state>";
+        return res;
+    }
+    assert(false);
+    return res;
+}
+
+DState::State DState::toState(const std::string& str) {
+    if (auto found = ecf::Enumerate<DState::State>::to_enum(str); found) {
+        return found.value();
+    }
+    throw std::runtime_error("DState::toState: Can change string to a DState :" + str);
+}
+
+bool DState::isValid(const std::string& state) {
+    return ecf::Enumerate<DState::State>::is_valid(state);
+}
+
+std::vector<std::string> DState::allStates() {
+    return ecf::Enumerate<DState::State>::designations();
+}
+
+std::vector<DState::State> DState::states() {
+    return ecf::Enumerate<DState::State>::enums();
+}
+
+// ==========================================================================
+
+template <class Archive>
+void DState::serialize(Archive& ar) {
+    ar(CEREAL_NVP(st_));
+}
+CEREAL_TEMPLATE_SPECIALIZE(DState);
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/DState.hpp 5.13.0-1/libs/core/src/ecflow/core/DState.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/DState.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/DState.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,77 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_DState_HPP
+#define ecflow_core_DState_HPP
+
+///
+/// \brief DState stores the state of a node.
+///
+/// The class DState is used to define the enum.
+/// The number of state changes in stored in `state_change_no`.
+///
+
+#include <string>
+
+#include "ecflow/core/NState.hpp"
+
+class DState {
+public:
+    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5, SUSPENDED = 6 };
+
+    explicit DState(State s) : st_(s), state_change_no_(0) {}
+    DState() : st_(default_state()) {}
+    static DState::State default_state() { return DState::QUEUED; } // NEVER change, or will break client/server
+
+    State state() const { return st_; }
+    void setState(State);
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    bool operator==(const DState& rhs) const { return st_ == rhs.st_; }
+    bool operator!=(const DState& rhs) const { return st_ != rhs.st_; }
+    bool operator==(State s) const { return s == st_; }
+    bool operator!=(State s) const { return s != st_; }
+
+    static NState::State convert(DState::State);
+    static const char* toString(DState::State);
+    static std::string to_html(DState::State);
+    static const char* toString(const DState& ns) { return toString(ns.state()); }
+    static std::string to_string(DState::State s) { return std::string(toString(s)); }
+    static DState::State toState(const std::string&);
+    static bool isValid(const std::string&);
+    static std::vector<std::string> allStates();
+    static std::vector<DState::State> states();
+
+private:
+    State st_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+    // *IMPORTANT* no version for a simple class
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+////////////////////////////////////////////////////////////////////////////////////////
+// Thin wrapper over DState, to aid python. i.e Task("t").add(Defstatus(DState.complete))
+class Defstatus {
+public:
+    explicit Defstatus(DState::State state) : st_(state) {}
+    explicit Defstatus(const std::string& ds) : st_(DState::toState(ds)) {}
+    DState::State state() const { return st_; }
+    std::string to_string() const { return DState::to_string(st_); }
+
+private:
+    DState::State st_;
+};
+
+#endif
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/DebugPerf.hpp 5.13.0-1/libs/core/src/ecflow/core/DebugPerf.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/DebugPerf.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/DebugPerf.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_DebugPerf_HPP
+#define ecflow_core_DebugPerf_HPP
+
+// #define DEBUG_PERF 1
+#ifdef DEBUG_PERF
+    #include "ecflow/core/DurationTimer.hpp"
+#endif
+
+#endif /* ecflow_core_DebugPerf_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/DurationTimer.cpp 5.13.0-1/libs/core/src/ecflow/core/DurationTimer.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/DurationTimer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/DurationTimer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/DurationTimer.hpp"
+
+#include <iostream>
+
+using namespace ecf;
+
+ScopedDurationTimer::~ScopedDurationTimer() {
+    std::cout << msg_ << " " << (double)elapsed().total_milliseconds() / (double)1000 << "s\n";
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/DurationTimer.hpp 5.13.0-1/libs/core/src/ecflow/core/DurationTimer.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/DurationTimer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/DurationTimer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,60 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_DurationTimer_HPP
+#define ecflow_core_DurationTimer_HPP
+
+///
+/// \brief Simple class to report wall clock time duration
+///
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+namespace ecf {
+
+class DurationTimer {
+public:
+    DurationTimer() : start_time_(boost::posix_time::microsec_clock::universal_time()) {}
+    ~DurationTimer() = default;
+
+    int duration() const {
+        boost::posix_time::time_duration duration = boost::posix_time::microsec_clock::universal_time() - start_time_;
+        return duration.total_seconds();
+    }
+
+    boost::posix_time::time_duration elapsed() const {
+        return boost::posix_time::microsec_clock::universal_time() - start_time_;
+    }
+
+    double elapsed_seconds() const { return (double)elapsed().total_milliseconds() / (double)1000; }
+
+private:
+    boost::posix_time::ptime start_time_;
+};
+
+class ScopedDurationTimer {
+public:
+    explicit ScopedDurationTimer(const char* msg)
+        : start_time_(boost::posix_time::microsec_clock::universal_time()),
+          msg_(msg) {}
+    ~ScopedDurationTimer();
+
+    boost::posix_time::time_duration elapsed() const {
+        return boost::posix_time::microsec_clock::universal_time() - start_time_;
+    }
+
+private:
+    boost::posix_time::ptime start_time_;
+    const char* msg_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_DurationTimer_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Ecf.cpp 5.13.0-1/libs/core/src/ecflow/core/Ecf.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Ecf.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Ecf.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,107 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Ecf.hpp"
+
+bool Ecf::server_                            = false;
+bool Ecf::debug_equality_                    = false;
+unsigned int Ecf::debug_level_               = 0;
+thread_local Ecf::atomic_counter_t Ecf::state_change_no_  = 0;
+thread_local Ecf::atomic_counter_t Ecf::modify_change_no_ = 0;
+bool DebugEquality::ignore_server_variables_ = false;
+
+const char* Ecf::SERVER_NAME() {
+    static const char* SERVER_NAME = "ecflow_server";
+    return SERVER_NAME;
+}
+const char* Ecf::CLIENT_NAME() {
+    static const char* CLIENT_NAME = "ecflow_client";
+    return CLIENT_NAME;
+}
+
+const std::string& Ecf::LOG_FILE() {
+    static const std::string LOG_FILE = "ecf.log";
+    return LOG_FILE;
+}
+const std::string& Ecf::CHECKPT() {
+    static const std::string CHECKPT = "ecf.check";
+    return CHECKPT;
+}
+const std::string& Ecf::BACKUP_CHECKPT() {
+    static const std::string BACKUP_CHECKPT = "ecf.check.b";
+    return BACKUP_CHECKPT;
+}
+const std::string& Ecf::MICRO() {
+    static const std::string MICRO = "%";
+    return MICRO;
+}
+const std::string& Ecf::JOB_CMD() {
+    static const std::string JOB_CMD = "%ECF_JOB% 1> %ECF_JOBOUT% 2>&1";
+    return JOB_CMD;
+}
+const std::string& Ecf::KILL_CMD() {
+    static const std::string KILL_CMD = "kill -15 %ECF_RID%";
+    return KILL_CMD;
+} // "${ECF_KILL:=/home/ma/emos/bin/ecfkill}   %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1";
+const std::string& Ecf::STATUS_CMD() {
+    static const std::string STATUS_CMD = "ps --pid %ECF_RID% -f > %ECF_JOB%.stat 2>&1";
+    return STATUS_CMD;
+} // "${ECF_STAT:=/home/ma/emos/bin/ecfstatus} %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.stat 2>&1";
+const std::string& Ecf::CHECK_CMD() {
+    static const std::string CHECK_CMD = "ps --pid %ECF_RID% -f";
+    return CHECK_CMD;
+}
+
+//-remote has been removed from firefox, since version 39
+//-remote openfile(file)                    -> -file <file>
+//-remote openurl(url)                      -> -url <url>
+//-remote openurl(url,new-window)           -> -new-window <url>
+//-remote openurl(url,new-tab)              -> -new-tab <url>
+//-remote xfedocommand(openbrowser,url)     -> -browser <url>
+//-remote xfedocommand(openinbox)           -> -mail
+//-remote xfedocommand(composemessage,args) -> -compose args
+const std::string& Ecf::URL_CMD() {
+    static const std::string URL_CMD = "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%";
+    return URL_CMD;
+}
+const std::string& Ecf::URL_BASE() {
+    static const std::string URL_BASE = "https://confluence.ecmwf.int";
+    return URL_BASE;
+}
+const std::string& Ecf::URL() {
+    static const std::string URL = "display/ECFLOW/ecflow+home";
+    return URL;
+}
+
+Ecf::counter_t Ecf::incr_state_change_no() {
+    if (server_) {
+        return ++state_change_no_;
+    }
+    return state_change_no_;
+}
+
+Ecf::counter_t Ecf::incr_modify_change_no() {
+    if (server_) {
+        return ++modify_change_no_;
+    }
+    return modify_change_no_;
+}
+
+// =======================================================
+
+EcfPreserveChangeNo::EcfPreserveChangeNo()
+    : state_change_no_(Ecf::state_change_no()),
+      modify_change_no_(Ecf::modify_change_no()) {
+}
+
+EcfPreserveChangeNo::~EcfPreserveChangeNo() {
+    Ecf::set_state_change_no(state_change_no_);
+    Ecf::set_modify_change_no(modify_change_no_);
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Ecf.hpp 5.13.0-1/libs/core/src/ecflow/core/Ecf.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Ecf.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Ecf.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,128 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Ecf_HPP
+#define ecflow_core_Ecf_HPP
+
+///
+/// \brief Provides globals used by server for determining change
+///
+
+#include <atomic>
+#include <string>
+
+/**
+ * This class holds *global data*, and is used in the server to determine incremental changes to the data model.
+ *
+ * This data is composed of two parts:
+ *  - `state_change_no_`: leads the number of node state changes on the currently loaded defs
+ *  - `modify_change_no_`: leads the number of structural changes to the currently loaded defs
+ *
+ * Each Node/Attribute stores a local `state_change_no_`, and whenever there is a change, this local number is
+ * assigned based on the incremented value of the `global state_change_no_`.
+ *
+ * When making large scale changes (e.g. adding or deleting nodes), we increment the global `modify_change_no_`.
+ *
+ * The synchronization strategy is such that when the client eventually copies over the full defs, the state_change_no_
+ * and modify_change_no_ are also copied. In future synchronization attempts, the client includes these two numbers in
+ * the sync request, and thus allows the server to determine what has changed.
+ */
+
+class Ecf {
+public:
+    using counter_t        = unsigned int;
+    using atomic_counter_t = std::atomic<counter_t>;
+
+    // Disable default construction
+    Ecf() = delete;
+    // Disable copy (and move) semantics
+    Ecf(const Ecf&)                  = delete;
+    const Ecf& operator=(const Ecf&) = delete;
+
+    /// Increment and then return state change no
+    static counter_t incr_state_change_no();
+    static counter_t state_change_no() { return state_change_no_; }
+    static void set_state_change_no(counter_t x) { state_change_no_ = x; }
+
+    /// The modify_change_no_ is used for node addition and deletion and re-ordering
+    static counter_t incr_modify_change_no();
+    static counter_t modify_change_no() { return modify_change_no_; }
+    static void set_modify_change_no(counter_t x) { modify_change_no_ = x; }
+
+    /// Returns true if we are on the server side.
+    /// Only in server side do we increment state/modify numbers
+    /// Also used in debug/test: Allows print to add know if in server/client
+    static bool server() { return server_; }
+
+    /// Should only be set by the server, made public so that testing can also set it
+    /// Only in server side do we increment state/modify numbers
+    static void set_server(bool f) { server_ = f; }
+
+    static bool debug_equality() { return debug_equality_; }
+    static void set_debug_equality(bool f) { debug_equality_ = f; }
+
+    // ECFLOW-99
+    static unsigned int debug_level() { return debug_level_; }
+    static void set_debug_level(unsigned int level) { debug_level_ = level; }
+
+    static const char* SERVER_NAME();
+    static const char* CLIENT_NAME();
+
+    static const std::string& LOG_FILE();
+    static const std::string& CHECKPT();
+    static const std::string& BACKUP_CHECKPT();
+    static const std::string& MICRO();
+    static const std::string& JOB_CMD();
+    static const std::string& KILL_CMD();
+    static const std::string& STATUS_CMD(); // Typical run on the server
+    static const std::string& CHECK_CMD();  // Typical run on the client
+    static const std::string& URL_CMD();
+    static const std::string& URL_BASE();
+    static const std::string& URL();
+
+private:
+    static bool server_;
+    static bool debug_equality_;
+    static unsigned int debug_level_;
+    static thread_local atomic_counter_t state_change_no_;
+    static thread_local atomic_counter_t modify_change_no_;
+};
+
+/// Make sure the Ecf number don't change
+class EcfPreserveChangeNo {
+public:
+    EcfPreserveChangeNo();
+    ~EcfPreserveChangeNo();
+
+private:
+    unsigned int state_change_no_;
+    unsigned int modify_change_no_;
+};
+
+class DebugEquality {
+public:
+    DebugEquality() { Ecf::set_debug_equality(true); }
+    // Disable copy (and move) semantics
+    DebugEquality(const DebugEquality&)                  = delete;
+    const DebugEquality& operator=(const DebugEquality&) = delete;
+
+    ~DebugEquality() {
+        Ecf::set_debug_equality(false);
+        set_ignore_server_variables(false);
+    }
+
+    static bool ignore_server_variables() { return ignore_server_variables_; }
+    static void set_ignore_server_variables(bool flg) { ignore_server_variables_ = flg; }
+
+private:
+    static bool ignore_server_variables_;
+};
+
+#endif /* ecflow_core_Ecf_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/EcfPortLock.hpp 5.13.0-1/libs/core/src/ecflow/core/EcfPortLock.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/EcfPortLock.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/EcfPortLock.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_EcfPortLock_HPP
+#define ecflow_core_EcfPortLock_HPP
+
+///
+/// \brief This class enables the creation of a lock file file, so that different processes
+///        avoid creating server with same port number.
+///
+///        IMPORTANT: This functionality is used in TESTS only.
+///
+
+#include <iostream>
+#include <sstream>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/File.hpp"
+
+namespace ecf {
+
+class EcfPortLock {
+public:
+    // Disable default construction
+    EcfPortLock() = delete;
+    // Disable copy (and move) semantics
+    EcfPortLock(const EcfPortLock&)                  = delete;
+    const EcfPortLock& operator=(const EcfPortLock&) = delete;
+
+    static bool is_free(int port, bool debug = false) {
+        std::string the_port = ecf::convert_to<std::string>(port);
+        if (fs::exists(port_file(the_port))) {
+            if (debug)
+                std::cout << "  EcfPortLock::is_free(" << port << ") returning FALSE\n ";
+            return false;
+        }
+        if (debug)
+            std::cout << "  EcfPortLock::is_free(" << port << ") returning TRUE\n ";
+        return true;
+    }
+
+    static void create(const std::string& the_port) {
+        std::string the_file = port_file(the_port);
+        std::string errorMsg;
+        if (!ecf::File::create(the_file, "", errorMsg)) {
+            std::stringstream sb;
+            sb << "EcfPortLock::create_free_port_file : could not create file " << the_file;
+            throw std::runtime_error(sb.str());
+        }
+    }
+
+    static void remove(const std::string& the_port) {
+        std::string the_file = port_file(the_port);
+        fs::remove(the_file);
+    }
+
+private:
+    static std::string port_file(const std::string& the_port) {
+        // We need the *SAME* location so that different process find the same file.
+        // When going across compiler the root_build_dir is not sufficient
+        char* ecf_port_lock_dir = getenv("ECF_PORT_LOCK_DIR");
+        std::string path;
+        if (ecf_port_lock_dir)
+            path = ecf_port_lock_dir;
+        else
+            path = File::root_source_dir();
+
+        path += "/";
+        path += the_port;
+        path += ".lock";
+
+        return path;
+    }
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_EcfPortLock_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Enumerate.hpp 5.13.0-1/libs/core/src/ecflow/core/Enumerate.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Enumerate.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Enumerate.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,128 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Enumerate_HPP
+#define ecflow_core_Enumerate_HPP
+
+#include <algorithm>
+#include <array>
+#include <optional>
+#include <string>
+#include <string_view>
+#include <vector>
+
+namespace ecf {
+
+namespace detail {
+
+/**
+ * EnumTraits defines the mapping between a set of enum values and their designation.
+ *
+ * EnumTraits must define:
+ *  - the mapping `map`, provided as an std::array composes of an std::pair<E, const char *> for each enum value
+ *  - the `size`, holding the number os entries in `map`
+ *
+ * @tparam E
+ */
+
+template <typename E>
+struct EnumTraits
+{
+};
+
+} // namespace detail
+
+template <typename E, typename TRAITS = detail::EnumTraits<E>>
+struct Enumerate
+{
+public:
+    using enum_t   = E;
+    using string_t = std::string_view;
+
+    /**
+     * Convert the given enum value to its designation
+     *
+     * @param e the enum value
+     * @return the designation, in case it exists; an empty optional, otherwise
+     */
+    static constexpr std::optional<string_t> to_string(enum_t e) noexcept {
+        if (auto found = std::find_if(
+                std::begin(TRAITS::map), std::end(TRAITS::map), [&](const auto& item) { return item.first == e; });
+            found != std::end(TRAITS::map)) {
+
+            return std::make_optional(found->second);
+        }
+        return std::nullopt;
+    }
+
+    /**
+     * Convert the given designation to the related enum value
+     *
+     * @param s the designation
+     * @return the enum value, in case it exists; an empty optional, otherwise
+     */
+    static constexpr std::optional<E> to_enum(string_t s) noexcept {
+        if (auto found = std::find_if(
+                std::begin(TRAITS::map), std::end(TRAITS::map), [&](const auto& item) { return item.second == s; });
+            found != std::end(TRAITS::map)) {
+
+            return std::make_optional(found->first);
+        }
+        return std::nullopt;
+    }
+
+    /**
+     * Checks if the given designation is valid (i.e. has a related enum value)
+     *
+     * @param s the designation
+     * @return true, if valid; false, otherwise
+     */
+    static constexpr bool is_valid(string_t s) {
+        auto found = std::find_if(
+            std::begin(TRAITS::map), std::end(TRAITS::map), [&](const auto& item) { return item.second == s; });
+        return found != std::end(TRAITS::map);
+    }
+
+    /**
+     * The number of mapped enum values
+     */
+    static const size_t size = TRAITS::size;
+
+    /**
+     * The vector of mapped enum values
+     */
+    static auto enums() {
+        std::vector<E> result;
+        result.reserve(TRAITS::size);
+        std::transform(std::begin(TRAITS::map),
+                       std::end(TRAITS::map),
+                       std::back_inserter(result),
+                       [](const auto& item) { return item.first; });
+        return result;
+    }
+
+    /**
+     * The vector of mapped designations
+     */
+    static auto designations() {
+        std::vector<std::string> result;
+        result.reserve(TRAITS::size);
+        std::transform(std::begin(TRAITS::map),
+                       std::end(TRAITS::map),
+                       std::back_inserter(result),
+                       [](const auto& item) { return std::string{item.second}; });
+
+        return result;
+    }
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_Enumerate_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Extract.cpp 5.13.0-1/libs/core/src/ecflow/core/Extract.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Extract.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Extract.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,102 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Extract.hpp"
+
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
+
+#include "ecflow/core/Converter.hpp"
+
+// #define DEBUG_PARSER 1
+
+using namespace std;
+using namespace boost;
+using namespace boost::gregorian;
+
+template <class T>
+ostream& operator<<(ostream& os, const vector<T>& v) {
+    copy(v.begin(), v.end(), ostream_iterator<T>(cout, ","));
+    return os;
+}
+
+bool Extract::pathAndName(const std::string& token, std::string& path, std::string& name) {
+    if (token.empty())
+        return false;
+
+    size_t colonPos = token.find_first_of(':');
+    if (colonPos == string::npos) {
+        if (token[0] == '/') {
+            path = token; // token of the form /a/b/c, ie no name
+        }
+        else {
+            name = token;
+        }
+    }
+    else {
+        path = token.substr(0, colonPos);
+        name = token.substr(colonPos + 1);
+    }
+
+    return true;
+}
+
+bool Extract::split_get_second(const std::string& str, std::string& ret, char separator) {
+    // HH:MM
+    // return MM;
+    size_t colonPos = str.find_first_of(separator);
+    if (colonPos == string::npos)
+        return false;
+    ret = str.substr(colonPos + 1);
+    return true;
+}
+
+/// extract integer or throw an std::runtime exception on failure
+int Extract::theInt(const std::string& token, const std::string& errorMsg) {
+    int the_int = -1;
+    try {
+        the_int = ecf::convert_to<int>(token);
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error(errorMsg);
+    }
+    return the_int;
+}
+
+/// extract YMD, integer of the form yyyymmdd
+int Extract::ymd(const std::string& ymdToken, std::string& errorMsg) {
+    if (ymdToken.size() != 8)
+        throw std::runtime_error(errorMsg + " YMD must be 8 characters i.e yyyymmdd");
+
+    // Use date lib to check YMD
+    try {
+        (void)boost::gregorian::date(from_undelimited_string(ymdToken));
+    }
+    catch (std::exception& e) {
+        errorMsg += "\n";
+        errorMsg += e.what();
+        throw std::runtime_error(errorMsg + " YMD is not a valid date");
+    }
+
+    return theInt(ymdToken, errorMsg);
+}
+
+int Extract::optionalInt(const std::vector<std::string>& tokens,
+                         int pos,
+                         int defaultValue,
+                         const std::string& errorMsg) {
+    int the_int = defaultValue;
+    if (static_cast<int>(tokens.size()) >= pos + 1 && tokens[pos][0] != '#') {
+
+        the_int = theInt(tokens[pos], errorMsg);
+    }
+    return the_int;
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Extract.hpp 5.13.0-1/libs/core/src/ecflow/core/Extract.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Extract.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Extract.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Extract_HPP
+#define ecflow_core_Extract_HPP
+
+#include <string>
+#include <vector>
+
+class Extract {
+public:
+    // Disable default construction
+    Extract() = delete;
+    // Disable copy (and move) semantics
+    Extract(const Extract&)                  = delete;
+    const Extract& operator=(const Extract&) = delete;
+
+    ///
+    /// Extract path and name from given token.
+    ///
+    /// Given
+    ///   "/suite/family:obj", extracts path = "/suite/family", and name = "obj"
+    ///   "/suite/family", extracts path = "/suite/family", and name = ""
+    ///   "obj", extracts path = "", and name = "obj"
+    /// @returns true if extraction succeeded; false, otherwise
+    ///
+    static bool pathAndName(const std::string& token, std::string& path, std::string& name);
+
+    ///
+    /// Extract 2nd token from the given string (considering provided separator)
+    ///
+    /// Given str = "HH:MM", extracts ret = "MM"
+    ///
+    /// @returns true if extraction succeeded; false, otherwise
+    ///
+    static bool split_get_second(const std::string& str, std::string& ret, char separator = ':');
+
+    ///
+    /// Extract an integer from the given token
+    ///
+    /// @returns the extracted integer
+    /// @throws std::runtime_error if extractions fails, with the provided error message included in exception message
+    ///
+    static int theInt(const std::string& token, const std::string& errorMsg);
+
+    ///
+    /// Extract YMD integer, of the form yyyymmdd, from the given token
+    ///
+    /// @throws std::runtime_error if extractions fails, with the provided error message included in exception message
+    ///
+    static int ymd(const std::string& ymdToken, std::string& errorMsg);
+
+    ///
+    /// Extract (optional) integer, from token in index pos
+    ///
+    /// Notice: when first character of selected token is '#', the return is the provided default value
+    ///
+    /// Example of tokens:
+    ///   ["repeat", "integer", "variable", "1", "2", "#a", "comment"]
+    ///    - extracting from "repeat", "integer", "variable", or "comment" throws std::runtime_error
+    ///    - extracting from "1", returns 1
+    ///    - extracting from "2", returns 3
+    ///    - extracting from "#a", returns the given default value
+    ///   ["repeat", "integer", "variable", "1", "2", "#", "a", "comment"]
+    ///    - extracting from "repeat", "integer", "variable", "a", or "comment" throws std::runtime_error
+    ///    - extracting from "1", returns 1
+    ///    - extracting from "2", returns 3
+    ///    - extracting from "#", returns the given default value
+    ///
+    /// @returns the extracted integer, if extraction succeeded; default value if selected token starts with '#'
+    /// @throws std::runtime_error if extractions fails, with the provided error message included in exception message
+    ///
+    static int optionalInt(const std::vector<std::string>& tokens, int pos, int defValue, const std::string& errorMsg);
+};
+
+#endif /* ecflow_core_Extract_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/File.cpp 5.13.0-1/libs/core/src/ecflow/core/File.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/File.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/File.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1131 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/File.hpp"
+
+#include <fstream>
+#include <stdexcept>
+
+#include <boost/filesystem.hpp>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/NodePath.hpp"
+#include "ecflow/core/Str.hpp"
+
+#ifdef CMAKE
+    #include "ecflow/core/ecflow_source_build_dir.h"
+#endif
+
+using namespace std;
+using namespace boost;
+
+// #define DEBUG_SERVER_PATH 1
+// #define DEBUG_CLIENT_PATH 1
+
+namespace ecf {
+
+size_t File::MAX_LINES() {
+    return 10000;
+}
+const std::string& File::JOB_EXTN() {
+    static const std::string JOB_EXTN = ".job";
+    return JOB_EXTN;
+}
+const std::string& File::MAN_EXTN() {
+    static const std::string MAN_EXTN = ".man";
+    return MAN_EXTN;
+}
+const std::string& File::USR_EXTN() {
+    static const std::string USR_EXTN = ".usr";
+    return USR_EXTN;
+}
+const std::string& File::ECF_EXTN() {
+    static const std::string ECF_EXTN = ".ecf";
+    return ECF_EXTN;
+}
+
+/// Search for the file, in $PATH return the first path that matches or an empty file, if not
+std::string File::which(const std::string& file) {
+    std::string env_paths = getenv("PATH");
+    if (!env_paths.empty()) {
+        std::string path;
+        std::vector<std::string> paths;
+        Str::split(env_paths, paths, ":");
+        size_t path_size = paths.size();
+        for (size_t i = 0; i < path_size; ++i) {
+            path.clear();
+            path = paths[i];
+            path += '/';
+            path += file;
+            try {
+                if (fs::exists(path)) {
+                    return paths[i];
+                }
+            }
+            catch (...) {
+                // could be permission denied.
+            }
+        }
+    }
+    return std::string();
+}
+
+std::string File::getExt(const std::string& file) {
+    size_t i = file.rfind('.', file.length());
+    if (i != std::string::npos) {
+        return file.substr(i + 1);
+    }
+    return string();
+}
+
+void File::replaceExt(std::string& file, const std::string& newExt) {
+    string::size_type i = file.rfind('.', file.length());
+    if (i != string::npos)
+        file.replace(i + 1, newExt.length(), newExt);
+}
+
+bool File::splitFileIntoLines(const std::string& filename, std::vector<std::string>& lines, bool ignoreEmptyLine) {
+    std::ifstream the_file(filename.c_str(), std::ios_base::in);
+    if (!the_file) {
+        return false;
+    }
+    lines.reserve(lines.size() + 100);
+
+    // Note if we use: while( getline( theEcfFile, line)), then we will miss the *last* *empty* line
+
+    //	int i = 0;
+    string line;
+    while (std::getline(the_file, line)) {
+        //		i++;
+        //		cout << i << ": " << line << "\n";
+        if (ignoreEmptyLine && line.empty())
+            continue;
+        lines.push_back(line); // c++11 - lines.emplace_back(std::move(line)) - actually slower, hence left
+    }
+
+    //	 METHOD1
+    //	 Note Another way to split lines of a file was to use a tokenizer.
+    //	 Much slower ~ 2.5 slower,
+    //	ifstream ifs(filename.c_str());
+    //	if (!ifs) return false;
+    //
+    //	// Note: ss.str() returns a temporary std::string.
+    //	// boost::tokenizer stores a reference to the string.
+    //	// The temporary string is destroyed and tokenizer is left with a dangling reference.
+    //	// hence take a copy
+    //	std::stringstream ss;  ss << ifs.rdbuf();  // Read the whole file into a string
+    //	std::string theFileAsString = ss.str();    // take a copy as ss.str() returns a temporary
+    //	//                                         // while tokenizer stores a reference
+    //	if (ignoreEmptyLine) {
+    //	   char_separator<char> sep("\n",0,boost::drop_empty_tokens);
+    //	   typedef boost::tokenizer<boost::char_separator<char> > tokenizer;
+    //	   tokenizer tokens(theFileAsString, sep);
+    //	   std::copy(tokens.begin(), tokens.end(), back_inserter(lines));
+    //	}
+    //	else {
+    //	   char_separator<char> sep("\n",0,boost::keep_empty_tokens);
+    //	   typedef boost::tokenizer<boost::char_separator<char> > tokenizer;
+    //	   tokenizer tokens(theFileAsString, sep);
+    //	   std::copy(tokens.begin(), tokens.end(), back_inserter(lines));
+    //	}
+
+    // METHOD 2:
+    // Note: The implementation below is 2.5 times slower
+    //	std::ifstream ifs(filename.c_str());
+    //	if (!ifs) return false;
+    //
+    //	std::istreambuf_iterator<char> file_iter(ifs);
+    //	std::istreambuf_iterator<char> end_of_stream;
+    //
+    //	typedef boost::tokenizer<boost::char_separator<char>,
+    //	std::istreambuf_iterator<char> > tokenizer;
+    //
+    //	boost::char_separator<char> sep("\n");
+    //	tokenizer tokens(file_iter,end_of_stream, sep);
+    // std::copy(tokens.begin(), tokens.end(), back_inserter(lines));
+
+    // The current implementation is 2.5 times faster than method 1, and ~4 times faster than method 2
+    return true;
+}
+
+std::string
+File::get_last_n_lines(const std::string& filename, int last_n_lines, size_t& file_size, std::string& error_msg) {
+    file_size = 0;
+    if (last_n_lines <= 0)
+        return string();
+
+    std::ifstream source(filename.c_str(), std::ios_base::in);
+    if (!source) {
+        error_msg = "File::get_last_n_lines: Could not open file " + filename;
+        error_msg += " (";
+        error_msg += strerror(errno);
+        error_msg += ")";
+        return string();
+    }
+
+    size_t const granularity = 100 * last_n_lines;
+    source.seekg(0, std::ios_base::end);
+    file_size = static_cast<size_t>(source.tellg());
+    std::vector<char> buffer;
+    int newlineCount = 0;
+    while (source && buffer.size() != file_size && newlineCount < last_n_lines) {
+        buffer.resize(std::min(buffer.size() + granularity, file_size));
+        source.seekg(-static_cast<std::streamoff>(buffer.size()), std::ios_base::end);
+        source.read(&(buffer.front()), buffer.size());
+        newlineCount = std::count(buffer.begin(), buffer.end(), '\n');
+    }
+
+    auto start = buffer.begin();
+    while (newlineCount > last_n_lines) {
+        start = std::find(start, buffer.end(), '\n') + 1;
+        --newlineCount;
+    }
+
+    // std::vector<char>::iterator end = remove( start, buffer.end(), '\r' ); // for windows
+    return std::string(start, buffer.end());
+}
+
+std::string File::get_last_n_lines(const std::string& filename, int last_n_lines, std::string& error_msg) {
+    size_t file_size = 0;
+    return File::get_last_n_lines(filename, last_n_lines, file_size, error_msg);
+}
+
+std::string File::get_first_n_lines(const std::string& filename, int n_lines, std::string& error_msg) {
+    if (n_lines <= 0)
+        return string();
+
+    std::ifstream source(filename.c_str(), std::ios_base::in);
+    if (!source) {
+        error_msg = "File::get_first_n_lines: Could not open file " + filename;
+        error_msg += " (";
+        error_msg += strerror(errno);
+        error_msg += ")";
+        return string();
+    }
+
+    std::string ret;
+    ret.reserve(1024);
+    std::string line;
+
+    int count = 0;
+    while (std::getline(source, line) && count < n_lines) {
+
+        ret += line;
+        ret += "\n";
+        count++;
+    }
+
+    return ret;
+}
+
+/// Opens the file and returns the contents
+bool File::open(const std::string& filePath, std::string& contents) {
+    std::ifstream infile(filePath.c_str(), std::ios_base::in);
+    if (!infile)
+        return false;
+
+    std::ostringstream temp;
+    temp << infile.rdbuf();
+    contents = temp.str();
+    return true;
+}
+
+bool File::create(const std::string& filename, const std::vector<std::string>& lines, std::string& errorMsg) {
+    // For very large file. This is about 1 second quicker. Then using streams
+    // See Test: TestFile.cpp:test_file_create_perf
+    FILE* theFile = fopen(filename.c_str(), "w");
+    if (theFile == nullptr) {
+        std::stringstream ss;
+        ss << "Could not create file '" << filename << " (" << strerror(errno) << "'\n";
+        errorMsg += ss.str();
+        return false;
+    }
+    size_t size = lines.size();
+    for (size_t i = 0; i < size; ++i) {
+        if (i != 0) {
+            if (fputs("\n", theFile) == EOF) {
+                std::stringstream ss;
+                ss << "Could not write to file '" << filename << "' (" << strerror(errno) << ")\n";
+                errorMsg += ss.str();
+                fclose(theFile);
+                return false;
+            }
+        }
+        if (fputs(lines[i].c_str(), theFile) == EOF) {
+            std::stringstream ss;
+            ss << "Could not write to file '" << filename << "' (" << strerror(errno) << ")\n";
+            errorMsg += ss.str();
+            fclose(theFile);
+            return false;
+        }
+    }
+    fclose(theFile);
+
+    //	std::ofstream theFile( filename.c_str() );
+    //	if ( !theFile ) {
+    //		/// Could be: [ no permissions | file system full | locked by another process ]
+    // 		std::stringstream ss;
+    //		ss << "Could not create file '" << filename << "'\n";
+    //		errorMsg += ss.str();
+    //		return false;
+    //	}
+    //	size_t size = lines.size();
+    //	for (size_t i = 0; i < size; ++i) {
+    //		if (i != 0) theFile << "\n";
+    //		theFile << lines[i];
+    //	}
+    //	if (!theFile.good()) {
+    //      std::stringstream ss;
+    //      ss << "Could not write to file '" << filename << "'\n";
+    //      errorMsg += ss.str();
+    //      theFile.close();
+    //      return false;
+    //	}
+    //	theFile.close();
+
+    return true;
+}
+
+bool File::create(const std::string& filename, const std::string& contents, std::string& errorMsg) {
+    std::ofstream theFile(filename.c_str());
+    if (!theFile) {
+        std::stringstream ss;
+        ss << "Could not create file '" << filename << "' (" << strerror(errno) << ")\n";
+        errorMsg += ss.str();
+        return false;
+    }
+
+    theFile << contents;
+    if (!theFile.good()) {
+        std::stringstream ss;
+        ss << "Could not write to file '" << filename << "' (" << strerror(errno) << ")\n";
+        errorMsg += ss.str();
+        theFile.close();
+        return false;
+    }
+    theFile.close();
+
+    // This is actually 12% slower for large file:
+    //	FILE * theFile = fopen (filename.c_str(),"w");
+    //	if (theFile==NULL) {
+    //		std::stringstream ss;
+    //		ss << "Could not create file '" << filename << "'\n";
+    //		errorMsg += ss.str();
+    //		return false;
+    //	}
+    //   if (fputs(contents.c_str(),theFile) == EOF) {
+    //      std::stringstream ss;
+    //      ss << "Could not write to file '" << filename << "'\n";
+    //      errorMsg += ss.str();
+    //      fclose (theFile);
+    //      return false;
+    //   }
+    //  	fclose (theFile);
+    return true;
+}
+
+std::string File::stream_error_condition(const std::ios& stream) {
+    std::string msg;
+    if (stream.fail())
+        msg += " Logical error on i/o operation";
+    if (stream.bad())
+        msg += " Read/Writing error on i/o operation";
+    if (stream.eof())
+        msg += " End-of-File reached on input operation";
+    if (errno) {
+        msg += ", errno:";
+        msg += std::string(strerror(errno));
+    }
+    return msg;
+}
+
+bool File::find(const fs::path& dir_path,     // from this directory downwards,
+                const std::string& file_name, // search for this name,
+                fs::path& path_found          // placing path here if found
+) {
+    //	std::cout << "Searching '" << dir_path << "' for  " << file_name  << "\n";
+    if (!fs::exists(dir_path))
+        return false;
+
+    fs::directory_iterator end_itr; // default construction yields past-the-end
+    for (fs::directory_iterator itr(dir_path); itr != end_itr; ++itr) {
+
+        if (fs::is_directory(itr->status())) {
+
+            if (File::find(itr->path(), file_name, path_found))
+                return true;
+        }
+        else if (itr->path().filename() == file_name) // see below
+        {
+            path_found = itr->path();
+            return true;
+        }
+    }
+    return false;
+}
+
+void File::findAll(const fs::path& dir_path,          // from this directory downwards
+                   const std::string& file_name,      // search for this name,
+                   std::vector<fs::path>& paths_found // placing path here if found
+) {
+    if (!fs::exists(dir_path))
+        return;
+
+    fs::directory_iterator end_itr; // default construction yields past-the-end
+    for (fs::directory_iterator itr(dir_path); itr != end_itr; ++itr) {
+
+        if (fs::is_directory(itr->status())) {
+
+            findAll(itr->path(), file_name, paths_found);
+        }
+        else if (itr->path().filename() == file_name) // see below
+        {
+            paths_found.push_back(itr->path());
+        }
+    }
+}
+
+void File::find_files_with_extn(const fs::path& dir_path,          // In this directory
+                                const std::string& extn,           // find files matching this extension
+                                std::vector<fs::path>& paths_found // placing path here if found
+) {
+    if (!fs::exists(dir_path)) {
+        return;
+    }
+    fs::directory_iterator end_itr; // default construction yields past-the-end
+    for (fs::directory_iterator itr(dir_path); itr != end_itr; ++itr) {
+        if (fs::is_directory(itr->status()))
+            continue;
+        else if (itr->path().extension() == extn) // see below
+        {
+            paths_found.push_back(itr->path());
+        }
+    }
+}
+
+std::string File::findPath(const fs::path& dir_path,     // from this directory downwards
+                           const std::string& file_name, // search for this name,
+                           const std::string& leafDir    // path must contain this string
+) {
+    std::vector<fs::path> paths;
+    File::findAll(dir_path, file_name, paths);
+    if (!paths.empty()) {
+
+        // find the path that has leafDir in it.
+        for (fs::path path : paths) {
+            std::string thePath = path.string();
+            if (thePath.rfind(leafDir) != std::string::npos)
+                return thePath;
+        }
+    }
+    return std::string();
+}
+
+std::string File::findPath(const fs::path& dir_path,              // from this directory downwards
+                           const std::string& file_name,          // search for this name,
+                           const std::vector<std::string>& tokens // path must contain all these tokens
+) {
+    std::vector<fs::path> paths;
+    File::findAll(dir_path, file_name, paths);
+    if (!paths.empty()) {
+
+        // find the path that has all the tokens specified by the vector tokens
+        for (fs::path path : paths) {
+            std::string thePath = path.string();
+            size_t matches      = 0;
+            for (const std::string& required_path_tokens : tokens) {
+                if (thePath.rfind(required_path_tokens) != std::string::npos)
+                    matches++;
+            }
+            if (matches == tokens.size())
+                return thePath;
+        }
+    }
+    return std::string();
+}
+
+// #define INTEL_DEBUG_ME 1
+bool File::createMissingDirectories(const std::string& pathToFileOrDir) {
+#ifdef INTEL_DEBUG_ME
+    std::cout << "File::createMissingDirectories  " << pathToFileOrDir << std::endl;
+#endif
+    if (pathToFileOrDir.empty())
+        return false;
+
+    // Avoid making unnecessary system calls, by checking to see if directory exists first
+    fs::path fs_path(pathToFileOrDir);
+    if (fs_path.extension().empty()) {
+
+#ifdef INTEL_DEBUG_ME
+        std::cout << "   pure directory no extension" << std::endl;
+#endif
+        // pure directory
+        if (fs::exists(pathToFileOrDir)) {
+
+#ifdef INTEL_DEBUG_ME
+            std::cout << "   " << pathToFileOrDir << " already exists " << std::endl;
+#endif
+
+            return true;
+        }
+    }
+    else {
+
+#ifdef INTEL_DEBUG_ME
+        std::cout << "   pure directory *has* extension" << std::endl;
+#endif
+        // could be /tmp/fred/sms.job, see if /tmp/fred exists
+        if (fs::exists(fs_path.parent_path())) {
+
+#ifdef INTEL_DEBUG_ME
+            std::cout << "   " << pathToFileOrDir << " already exists " << std::endl;
+#endif
+            return true;
+        }
+    }
+
+    std::vector<std::string> thePath;
+    NodePath::split(pathToFileOrDir, thePath);
+    try {
+        if (!thePath.empty()) {
+
+#ifdef INTEL_DEBUG_ME
+            std::cout << "   last file " << thePath.back() << std::endl;
+#endif
+
+            // pathToFileOrDir is of form: /tmp/fred/sms.job
+            //   we should only create directories for /tmp/fred
+            if (thePath.back().find(".") != std::string::npos) {
+                // assume the last token represents a file, hence don't create a directory
+#ifdef INTEL_DEBUG_ME
+                std::cout << "   last file " << thePath.back() << " has a *dot* ignoring " << std::endl;
+#endif
+                thePath.pop_back();
+            }
+
+            std::string pathToCreate;
+
+            // if original path had leading slash then add it here, to preserve path
+            if (pathToFileOrDir[0] == '/')
+                pathToCreate += Str::PATH_SEPERATOR();
+
+            for (const auto& i : thePath) {
+                pathToCreate += i;
+                if (!fs::exists(pathToCreate)) {
+#ifdef INTEL_DEBUG_ME
+                    std::cout << "   " << pathToCreate << " does not exist, creating directory " << std::endl;
+#endif
+                    fs::create_directory(pathToCreate);
+                }
+                pathToCreate += Str::PATH_SEPERATOR();
+            }
+        }
+        else {
+#ifdef INTEL_DEBUG_ME
+            std::cout << "   NO path component in " << pathToFileOrDir << std::endl;
+#endif
+
+            if (pathToFileOrDir.find(".") != std::string::npos) {
+                // assume represents a file, hence don't create a directory fred.job1
+#ifdef INTEL_DEBUG_ME
+                std::cout << "   assuming " << pathToFileOrDir
+                          << " is a file, found a dot, returning without creating dir " << std::endl;
+#endif
+                return true;
+            }
+
+            // assume is a dir
+#ifdef INTEL_DEBUG_ME
+            std::cout << "   about to create dir " << pathToFileOrDir << std::endl;
+#endif
+
+            fs::create_directory(pathToFileOrDir);
+        }
+    }
+    catch (const std::exception& ex) {
+#ifdef INTEL_DEBUG_ME
+        std::cout << "   Exception " << ex.what() << " could not create dir " << pathToFileOrDir << std::endl;
+#endif
+        return false;
+    }
+    return true;
+}
+
+/// Create directories the boost way, with additional check to see if directories exist first
+bool File::createDirectories(const std::string& pathToDir) {
+    if (pathToDir.empty())
+        return false;
+
+    try {
+        if (fs::exists(pathToDir))
+            return true;
+        return fs::create_directories(pathToDir);
+    }
+    catch (std::exception&) {
+    }
+    return false;
+}
+
+/// Returns the difference between 2 files.
+std::string File::diff(const std::string& file,
+                       const std::string& file2,
+                       const std::vector<std::string>& ignoreVec,
+                       std::string& errorMsg,
+                       bool ignoreBlanksLine) {
+    if (!fs::exists(file)) {
+        errorMsg += "First argument File " + file + " does not exist";
+        return std::string();
+    }
+    if (!fs::exists(file2)) {
+        errorMsg += "Second argument File " + file2 + " does not exist";
+        return std::string();
+    }
+
+    std::vector<std::string> fileLines;
+    std::vector<std::string> file2Lines;
+
+    if (!splitFileIntoLines(file, fileLines, ignoreBlanksLine)) {
+        errorMsg += "First argument File " + file + " could not be opened : " + strerror(errno);
+        return std::string();
+    }
+    if (!splitFileIntoLines(file2, file2Lines, ignoreBlanksLine)) {
+        errorMsg += "Second argument File " + file2 + " could not be opened : " + strerror(errno);
+        return std::string();
+    }
+
+    if (fileLines != file2Lines) {
+        std::stringstream ss;
+        if (fileLines.size() != file2Lines.size())
+            ss << "Expected size " << file2Lines.size() << " but found " << fileLines.size() << "\n";
+
+        for (size_t i = 0; i < fileLines.size() || i < file2Lines.size(); ++i) {
+
+            if (i < fileLines.size() && i < file2Lines.size()) {
+
+                if (fileLines[i] != file2Lines[i]) {
+                    bool doIgnore = false;
+                    for (const std::string& ignore : ignoreVec) {
+                        if (fileLines[i].find(ignore) != std::string::npos ||
+                            file2Lines[i].find(ignore) != std::string::npos) {
+                            doIgnore = true;
+                            break;
+                        }
+                    }
+                    if (doIgnore)
+                        continue;
+                    ss << "Mismatch at " << i << "(" << fileLines[i] << ")   ---->   (" << file2Lines[i] << ")\n";
+                }
+                //				else {
+                //					ss << "            " << i << " (" << fileLines[i] << ")   ---->
+                //("
+                //<< file2Lines[i] << ")\n";
+                //				}
+            }
+            else {
+                ss << "Mismatch at " << i;
+                if (i < fileLines.size())
+                    ss << " (" << fileLines[i] << ")   ";
+                else
+                    ss << " ( ---- )   ";
+
+                if (i < file2Lines.size())
+                    ss << "(" << file2Lines[i] << ")\n";
+                else
+                    ss << "( --- )\n";
+            }
+        }
+        return ss.str();
+    }
+    return std::string();
+}
+
+std::string
+File::backwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn) {
+    // Do a backward search of rootPath + nodePath
+    // If task path is of the form /suite/family/family2/task, then we keep
+    // on consuming the first path token this should leave:
+    //   	<root-path>/suite/family/family2/task.ecf
+    //   	<root-path>/family/family2/task.ecf
+    //  	<root-path>/family2/task.ecf
+    //   	<root-path>/task.ecf
+
+    vector<std::string> nodePathTokens;
+    NodePath::split(nodePath, nodePathTokens);
+    LOG_ASSERT(!nodePathTokens.empty(), "");
+
+    std::string leafName; // i.e. task in the example above
+    if (!nodePathTokens.empty())
+        leafName = nodePathTokens[nodePathTokens.size() - 1];
+
+#ifdef DEBUG_TASK_LOCATION
+    cout << "backwardSearch Node " << nodePath << " using root path " << rootPath
+         << " nodePathTokens.size() = " << nodePathTokens.size() << "\n";
+#endif
+    while (nodePathTokens.size() > 0) {
+
+        // Reconstitute the path
+        std::string path = NodePath::createPath(nodePathTokens);
+        path += fileExtn; // .ecf, .man , etc
+
+        std::string combinedPath = rootPath;
+        combinedPath += path;
+
+        try {
+            if (fs::exists(combinedPath)) {
+#ifdef DEBUG_TASK_LOCATION
+                cout << "backwardSearch Node " << nodePath << " the path " << combinedPath << " exists\n";
+#endif
+                return combinedPath;
+            }
+#ifdef DEBUG_TASK_LOCATION
+            else
+                cout << " backwardSearch Node " << nodePath << " the path " << combinedPath << " DOEST NOT EXIST\n";
+#endif
+        }
+        catch (fs::filesystem_error& e) {
+#ifdef DEBUG_TASK_LOCATION
+            std::cout << "Task::backwardSearch Caught exception for fs::exists('" << combinedPath << "')\n"
+                      << e.what() << "\n";
+#endif
+        }
+
+        nodePathTokens.erase(nodePathTokens.begin()); // consume first path token
+    }
+
+    // Look for file in the root path
+    std::string ecf_file  = leafName + fileExtn;
+    fs::path ecf_filePath = fs::path(fs::path(rootPath) / ecf_file);
+    if (fs::exists(ecf_filePath)) {
+#ifdef DEBUG_TASK_LOCATION
+        std::cout << "backwardSearch Node " << leafName << " Found " << ecf_file << " in root path '" << rootPath
+                  << "'\n";
+#endif
+        std::string result = ecf_filePath.string(); // is returned by reference hence must take a copy
+        return result;
+    }
+
+    // failed to find file via backward search
+    return string();
+}
+
+std::string File::forwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn) {
+    /// Do a forward search of rootPath + nodePath + fileExtn
+    /// If task path if of the form /suite/family/family2/task, then we keep
+    /// on consuming the last path token this should leave:
+    ///   <root-path>/suite/family/family2/task.ecf
+    ///   <root-path>/suite/family/task.ecf
+    ///   <root-path>/suite/task.ecf
+    ///   <root-path>/task.ecf
+
+    vector<std::string> nodePathTokens;
+    NodePath::split(nodePath, nodePathTokens);
+    LOG_ASSERT(!nodePathTokens.empty(), "");
+
+    std::string leafName;
+    if (!nodePathTokens.empty())
+        leafName = nodePathTokens[nodePathTokens.size() - 1];
+
+#ifdef DEBUG_TASK_LOCATION
+    cout << "forwardSearch Node " << nodePath << " using root path " << rootPath
+         << " nodePathTokens.size() = " << nodePathTokens.size() << "\n";
+#endif
+    while (nodePathTokens.size() > 0) {
+
+        // Reconstitute the path
+        std::string path = NodePath::createPath(nodePathTokens);
+        path += fileExtn; // .ecf, .man , etc
+
+        std::string combinedPath = rootPath;
+        combinedPath += path;
+
+        try {
+            if (fs::exists(combinedPath)) {
+#ifdef DEBUG_TASK_LOCATION
+                cout << "forwardSearch Node " << nodePath << " the path " << combinedPath << " exists\n";
+#endif
+                return combinedPath;
+            }
+#ifdef DEBUG_TASK_LOCATION
+            else
+                cout << " forwardSearch Node " << nodePath << " the path " << combinedPath << " DOEST NOT EXIST\n";
+#endif
+        }
+        catch (fs::filesystem_error& e) {
+#ifdef DEBUG_TASK_LOCATION
+            std::cout << "Task::forwardSearch Caught exception for fs::exists('" << combinedPath << "')\n"
+                      << e.what() << "\n";
+#endif
+        }
+
+        if (nodePathTokens.size() >= 2) {
+            nodePathTokens.erase(nodePathTokens.begin() + nodePathTokens.size() -
+                                 2); // consume one from last path token
+        }
+        else {
+            nodePathTokens.erase(nodePathTokens.begin());
+        }
+    }
+
+    // Look for file in the root path
+    std::string ecf_file  = leafName + fileExtn;
+    fs::path ecf_filePath = fs::path(fs::path(rootPath) / ecf_file);
+
+    try {
+        if (fs::exists(ecf_filePath)) {
+#ifdef DEBUG_TASK_LOCATION
+            std::cout << "Task::forwardSearch Node " << leafName << " Found " << ecf_file << " in root path '"
+                      << rootPath << "'\n";
+#endif
+            std::string result = ecf_filePath.string(); // is returned by reference hence must take a copy
+            return result;
+        }
+    }
+    catch (fs::filesystem_error& e) {
+#ifdef DEBUG_TASK_LOCATION
+        std::cout << "Task::forwardSearch Caught exception for root_path fs::exists('" << ecf_filePath << "')\n"
+                  << e.what() << "\n";
+#endif
+    }
+
+    // failed to find file via forward search
+    return string();
+}
+
+// Remove a directory recursively ****
+bool File::removeDir(const fs::path& p) {
+    try {
+        fs::directory_iterator end;
+        for (fs::directory_iterator it(p); it != end; ++it) {
+            if (fs::is_directory(*it)) {
+                if (!removeDir(*it)) {
+                    return false;
+                }
+            }
+            else {
+                fs::remove(*it);
+            }
+        }
+    }
+    catch (fs::filesystem_error& e) {
+        return false;
+    }
+
+    // Finally remove dir itself
+    fs::remove(p);
+
+    return true;
+}
+
+// =======================================================================================================
+// bjam
+// =======================================================================================================
+#ifndef CMAKE
+
+static std::string bjam_workspace_dir() {
+    // We need the *SAME* location so that different process find the same file. Get to the workspace directory
+    auto current_path = fs::current_path();
+    std::string stem  = current_path.stem().string();
+    int count         = 0;
+    while (stem.find("ecflow") == std::string::npos) {
+        current_path = current_path.parent_path();
+        stem         = current_path.stem().string();
+        count++;
+        if (count == 100) {
+            char* workspace = getenv("WK");
+            if (workspace == NULL) {
+                throw std::runtime_error("File::bjam_workspace_dir() failed to find ecflow in a directory name, up the "
+                                         "directory tree and WK undefined");
+            }
+            std::string the_workspace_dir = workspace;
+            return the_workspace_dir;
+        }
+    }
+    std::string the_workspace_dir = current_path.string(); // cos string is returned by reference
+    return the_workspace_dir;
+}
+
+static std::string find_bjam_ecf_server_path() {
+    #ifdef DEBUG_SERVER_PATH
+    cout << " File::find_ecf_server_path() using bjam\n";
+    #endif
+
+    // bjam uses in source tree, for build, which is in the workspace dir
+    std::string bin_dir = bjam_workspace_dir() + "/Server/bin/";
+
+    #ifdef DEBUG_SERVER_PATH
+    cout << "  Searching under: " << bin_dir << "\n";
+    #endif
+
+    // We need to take into account that on linux, we may have the GNU and CLANG executables
+    // Hence we need to distinguish between them.
+    std::vector<std::string> required_path_tokens;
+
+    // We have 3 variants debug,release,profile
+    #ifdef DEBUG
+
+    required_path_tokens.push_back(std::string("debug"));
+        #if defined(__clang__)
+    required_path_tokens.push_back(std::string("clang"));
+        #endif
+
+    return File::findPath(bin_dir, Ecf::SERVER_NAME(), required_path_tokens);
+
+    #else
+
+    required_path_tokens.push_back(std::string("release"));
+        #if defined(__clang__)
+    required_path_tokens.push_back(std::string("clang"));
+        #endif
+
+    std::string path = File::findPath(bin_dir, Ecf::SERVER_NAME(), required_path_tokens);
+    if (path.empty()) {
+
+        required_path_tokens.clear();
+        required_path_tokens.push_back(std::string("profile"));
+        #if defined(__clang__)
+        required_path_tokens.push_back(std::string("clang"));
+        #endif
+
+        path = File::findPath(bin_dir, Ecf::SERVER_NAME(), required_path_tokens);
+    }
+    return path;
+    #endif
+}
+
+static std::string find_bjam_ecf_client_path() {
+    #ifdef DEBUG_CLIENT_PATH
+    cout << " find_bjam_ecf_client_path \n";
+    #endif
+
+    // Bjam uses, in source build
+    std::string binDir = bjam_workspace_dir() + "/Client/bin/";
+
+    // We need to take into account that on linux, we may have the GNU and CLANG executables
+    // Hence we need to distinguish between them.
+    std::vector<std::string> required_path_tokens;
+
+    // We have 3 variants debug,release,profile
+    #ifdef DEBUG
+
+    required_path_tokens.push_back(std::string("debug"));
+        #if defined(__clang__)
+    required_path_tokens.push_back(std::string("clang"));
+        #endif
+
+    return File::findPath(binDir, Ecf::CLIENT_NAME(), required_path_tokens);
+
+    #else
+
+    required_path_tokens.push_back(std::string("release"));
+        #if defined(__clang__)
+    required_path_tokens.push_back(std::string("clang"));
+        #endif
+
+    std::string path = File::findPath(binDir, Ecf::CLIENT_NAME(), required_path_tokens);
+    if (path.empty()) {
+
+        required_path_tokens.clear();
+        required_path_tokens.push_back(std::string("profile"));
+        #if defined(__clang__)
+        required_path_tokens.push_back(std::string("clang"));
+        #endif
+
+        path = File::findPath(binDir, Ecf::CLIENT_NAME(), required_path_tokens);
+    }
+    return path;
+    #endif
+}
+#endif
+
+std::string File::find_ecf_server_path() {
+#ifdef CMAKE
+    std::string path = CMAKE_ECFLOW_BUILD_DIR;
+    path += "/bin/";
+    path += Ecf::SERVER_NAME();
+
+    #ifdef DEBUG_SERVER_PATH
+    cout << " File::find_ecf_server_path() path = " << path << "\n";
+    #endif
+
+    return path;
+
+#else
+
+    return find_bjam_ecf_server_path();
+#endif
+}
+
+std::string File::find_ecf_client_path() {
+#ifdef CMAKE
+    std::string path = CMAKE_ECFLOW_BUILD_DIR;
+    path += "/bin/";
+    path += Ecf::CLIENT_NAME();
+
+    #ifdef DEBUG_CLIENT_PATH
+    cout << " File::find_ecf_client_path() returning path " << path << "\n";
+    #endif
+
+    return path;
+
+#else
+
+    return find_bjam_ecf_client_path();
+#endif
+}
+
+std::string File::test_data(const std::string& rel_path, const std::string& dir) {
+    std::string test_file;
+    char* work_space = getenv("WK"); // for ecbuild
+    if (work_space != nullptr) {
+        test_file = std::string(work_space);
+        if (!rel_path.empty() && rel_path[0] != '/')
+            test_file += "/";
+        test_file += rel_path;
+    }
+    else {
+        std::string root_source = root_source_dir();
+        if (!root_source.empty()) {
+            test_file = root_source;
+            if (!rel_path.empty() && rel_path[0] != '/')
+                test_file += "/";
+            test_file += rel_path;
+        }
+        else {
+            fs::path current_path = fs::current_path();
+            if (current_path.stem() == dir) {
+
+                // remove first path, expecting "dir/path/path1" remove dir
+                std::string::size_type pos = rel_path.find("/", 1); // skip over any leading /
+                if (pos != std::string::npos) {
+                    test_file +=
+                        rel_path.substr(pos + 1); // skip over '/' to be left with path/path1, making it relative
+                }
+                else {
+                    test_file += rel_path;
+                }
+            }
+            else {
+                test_file += rel_path;
+            }
+        }
+    }
+    return test_file;
+}
+
+std::string File::test_data_in_current_dir(const std::string& rel_path) {
+    auto data = fs::current_path() / rel_path;
+    return fs::absolute(data).string();
+}
+
+std::string File::root_source_dir() {
+#ifdef CMAKE
+    return CMAKE_ECFLOW_SOURCE_DIR;
+#endif
+
+    // bjam
+    fs::path current_path        = fs::current_path();
+    std::string the_current_path = current_path.string();
+    std::string version_cmake    = the_current_path + "/Jamroot.jam";
+    if (fs::exists(version_cmake)) {
+        return the_current_path;
+    }
+
+    std::string stem = current_path.stem().string();
+    int count        = 0;
+    while (stem.find("ecflow") == std::string::npos) {
+        current_path = current_path.parent_path();
+
+        // bjam
+        std::string jamroot_file = std::string(current_path.string()) + "/Jamroot.jam";
+        if (fs::exists(jamroot_file)) {
+            std::string the_root_source_dir =
+                current_path.string(); // cos current_path.string() is returned by reference
+            return the_root_source_dir;
+        }
+
+        stem = current_path.stem().string();
+        count++;
+        if (count == 1000)
+            break;
+    }
+
+    return string();
+}
+
+std::string File::root_build_dir() {
+#ifdef CMAKE
+    return CMAKE_ECFLOW_BUILD_DIR;
+#endif
+
+    fs::path current_path        = fs::current_path();
+    std::string the_current_path = current_path.string();
+
+    // bjam
+    std::string version_cmake = the_current_path + "/Jamroot.jam";
+    if (fs::exists(version_cmake))
+        return the_current_path;
+
+    // cmake
+    std::string cmake_cache = the_current_path + "/CMakeCache.txt";
+    if (fs::exists(cmake_cache))
+        return the_current_path;
+
+    // bjam or cmake
+    std::string stem = current_path.stem().string();
+    int count        = 0;
+    while (stem.find("ecflow") == std::string::npos) {
+        current_path = current_path.parent_path();
+
+        the_current_path = current_path.string(); // cos current_path.string() is returned by reference
+
+        // bjam
+        std::string jamroot_file = the_current_path + "/Jamroot.jam";
+        if (fs::exists(jamroot_file))
+            return the_current_path;
+
+        // cmake
+        std::string cmake_cache1 = the_current_path + "/CMakeCache.txt";
+        if (fs::exists(cmake_cache1))
+            return the_current_path;
+
+        stem = current_path.stem().string();
+        count++;
+        if (count == 1000)
+            throw std::runtime_error(
+                "File::root_build_dir() failed to find ecflow in a directory name, up the directory tree");
+    }
+
+    throw std::runtime_error("File::root_build_dir() failed to find root build directory");
+    return std::string();
+}
+
+int File::max_open_file_allowed() {
+#ifdef OPEN_MAX
+    return OPEN_MAX;
+#else
+    static int max_open_file_allowed_ = -1;
+    if (max_open_file_allowed_ != -1)
+        return max_open_file_allowed_;
+
+    max_open_file_allowed_ = sysconf(_SC_OPEN_MAX);
+    if (max_open_file_allowed_ < 0) {
+        ecf::LogToCout logToCout;
+        std::string msg = "sysconf (_SC_OPEN_MAX) failed ";
+        msg += " (";
+        msg += strerror(errno);
+        msg += ")";
+        log(Log::ERR, msg);
+    }
+    return max_open_file_allowed_;
+#endif
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/File.hpp 5.13.0-1/libs/core/src/ecflow/core/File.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/File.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/File.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,177 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_File_HPP
+#define ecflow_core_File_HPP
+
+///
+/// \brief This class is used as a helper class for file utilities
+///
+
+#include <ios>
+#include <string>
+#include <vector>
+
+#include "ecflow/core/Filesystem.hpp"
+
+namespace ecf {
+
+class File {
+public:
+    // Disable default construction
+    File() = delete;
+    // Disable copy (and move) semantics
+    File(const File&)            = delete;
+    File& operator=(const File&) = delete;
+
+    static size_t MAX_LINES();            //  max number of lines, default to 10000
+    static const std::string& JOB_EXTN(); // ".job"
+    static const std::string& MAN_EXTN(); // ".man"
+    static const std::string& USR_EXTN(); // ".usr"
+    static const std::string& ECF_EXTN(); // ".ecf"
+
+    /// Search for the file, in $PATH return the first path that matches or an empty file, if not
+    static std::string which(const std::string& file);
+
+    /// expect string of the form ".ecf" or ".sms"
+    static void set_ecf_extn(const std::string&);
+    static const std::string& ecf_extn(); // return ".ecf" | ".sms" | ".py"
+
+    /// return the file extension
+    static std::string getExt(const std::string& file);
+
+    /// replace file extension with a new one
+    static void replaceExt(std::string& file, const std::string& newExt);
+
+    /// returns the input files, split into a vector of string, where each string
+    /// represent a line in the file. returns true if file open ok , false otherwise
+    /// The additional parameter ignoreEmptyLine  can be used to ignore empty lines
+    /// **Always reads _WHOLE_ file. Not suitable for very large files **
+    static bool
+    splitFileIntoLines(const std::string& filename, std::vector<std::string>& lines, bool ignoreEmptyLine = false);
+
+    /// This is suitable for large files. > several gigabytes, since it does load the entire file
+    static std::string get_last_n_lines(const std::string& filename, int last_n_lines, std::string& error_msg);
+    static std::string
+    get_last_n_lines(const std::string& filename, int last_n_lines, size_t& file_size, std::string& error_msg);
+
+    /// returns the first n line of a file, does not read all the file, hence suitable for very large files
+    static std::string get_first_n_lines(const std::string& filename, int n_lines, std::string& error_msg);
+
+    /// Opens the file and returns the contents
+    static bool open(const std::string& filePath, std::string& contents);
+
+    /// Given a file spath, and a vector of lines, creates a file. returns true if success
+    /// else returns false and an error message
+    static bool create(const std::string& filename, const std::vector<std::string>& lines, std::string& errorMsg);
+    static bool create(const std::string& filename, const std::string& contents, std::string& errorMsg);
+
+    /// When a stream fails, uses this construct the error message
+    static std::string stream_error_condition(const std::ios& stream);
+
+    /// recursively look for a file, given a starting directory
+    /// Return the first file that matches
+    /// return true if file found false otherwise
+    static bool find(const fs::path& dir_path,     // from this directory downwards
+                     const std::string& file_name, // search for this name,
+                     fs::path& path_found          // placing path here if found
+    );
+
+    /// recursively look for a file, given a starting directory
+    /// Returns _ALL_ files that match
+    static void findAll(const fs::path& dir_path,          // from this directory downwards
+                        const std::string& file_name,      // search for this name,
+                        std::vector<fs::path>& paths_found // placing path here if found
+    );
+
+    /// Find all files with given extension must include leading .
+    static void find_files_with_extn(const fs::path& dir_path,          // In this directory
+                                     const std::string& extn,           // find files matching this extension
+                                     std::vector<fs::path>& paths_found // placing path here if found
+    );
+
+    /// recursively look for a file, given a starting directory and path token
+    /// Returns the first match found
+    static std::string findPath(const fs::path& dir_path,     // from this directory downwards
+                                const std::string& file_name, // search for this name,
+                                const std::string& leafDir    // path must contain this string
+    );
+
+    static std::string findPath(const fs::path& dir_path,              // from this directory downwards
+                                const std::string& file_name,          // search for this name,
+                                const std::vector<std::string>& tokens // path must contain all these tokens
+    );
+
+    /// Create missing directories. This is *NOT* the same as boost::create_directories
+    /// as that only works with directories. This function assumes that if a "." exist
+    /// in the string it represents a file.
+    /// Hence this function handles:
+    ///   /tmp/some/dir/fred.job       // i.e the directories  /tmp/some/dir/ will be created
+    ///   /tmp/some/dir
+    ///   fred                         // will create the directory fred
+    ///   fred.job                     // just return true
+    static bool createMissingDirectories(const std::string& pathToFileOrDir);
+
+    /// Create directories the boost way, with additional check to see if directories exist first
+    static bool createDirectories(const std::string& pathToDir);
+
+    /// Returns the difference between 2 files.
+    /// Ignore lines that contain strings in the ignoreVec
+    static std::string diff(const std::string& file,
+                            const std::string& file2,
+                            const std::vector<std::string>& ignoreVec,
+                            std::string& errorMsg,
+                            bool ignoreBlanksLine = true);
+
+    /// Do a backward search of rootPath + nodePath + fileExtn
+    /// If task path if of the form /suite/family/family2/task, then we keep
+    /// on consuming the first path token this should leave:
+    ///     <root-path>/suite/family/family2/task.ecf
+    ///     <root-path>/family/family2/task.ecf
+    ///     <root-path>/family2/task.ecf
+    ///      <root-path>/task.ecf
+    /// Returns an empty string if file not found
+    static std::string
+    backwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn);
+
+    /// Do a forward search of rootPath + nodePath + fileExtn
+    /// If task path if of the form /suite/family/family2/task, then we keep
+    /// on consuming the last path token this should leave:
+    ///     <root-path>/suite/family/family2/task.ecf
+    ///     <root-path>/suite/family/task.ecf
+    ///     <root-path>/suite/task.ecf
+    ///     <root-path>/task.ecf
+    /// Returns an empty string if file not found
+    static std::string
+    forwardSearch(const std::string& rootPath, const std::string& nodePath, const std::string& fileExtn);
+
+    // Remove a directory recursively ****
+    static bool removeDir(const fs::path& p);
+
+    // Locate the path to the server exe
+    static std::string find_ecf_server_path();
+
+    // Locate the path to the client exe
+    static std::string find_ecf_client_path();
+
+    // Locate test data
+    static std::string test_data(const std::string& rel_path, const std::string& dir);
+    static std::string test_data_in_current_dir(const std::string& rel_path);
+    // return ecFlow project source code folder
+    static std::string root_source_dir();
+    // return ecFlow project build folder
+    static std::string root_build_dir();
+
+    static int max_open_file_allowed();
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_File_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/File_r.cpp 5.13.0-1/libs/core/src/ecflow/core/File_r.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/File_r.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/File_r.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,21 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/File_r.hpp"
+
+using namespace std;
+using namespace ecf;
+
+File_r::File_r(const std::string& file_name) : file_name_(file_name), fp_(file_name.c_str(), std::ios_base::in) {
+}
+
+File_r::~File_r() {
+    fp_.close();
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/File_r.hpp 5.13.0-1/libs/core/src/ecflow/core/File_r.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/File_r.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/File_r.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,43 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_File_r_HPP
+#define ecflow_core_File_r_HPP
+
+#include <fstream>
+#include <string>
+
+namespace ecf {
+
+class File_r {
+public:
+    explicit File_r(const std::string& file_name);
+    // Disable copy (and move) semantics
+    File_r(const File_r&)                  = delete;
+    const File_r& operator=(const File_r&) = delete;
+
+    ~File_r();
+
+    bool ok() const { return (fp_) ? true : false; }
+    std::streamoff pos() { return fp_.tellg(); }
+    //  deepcode ignore MissingOpenCheckOnFile: check called externally
+    void setPos(std::streamoff pos) { fp_.seekg(pos, fp_.beg); }
+    bool good() const { return fp_.good(); }
+    void getline(std::string& line) { std::getline(fp_, line); }
+    const std::string& file_name() const { return file_name_; }
+
+private:
+    std::string file_name_;
+    std::ifstream fp_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_File_r_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Filesystem.cpp 5.13.0-1/libs/core/src/ecflow/core/Filesystem.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Filesystem.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Filesystem.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+/*
+ * Copyright 2023- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "Filesystem.hpp"
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Filesystem.hpp 5.13.0-1/libs/core/src/ecflow/core/Filesystem.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Filesystem.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Filesystem.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2023- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ECFLOW_CORE_FILESYSTEM_HPP
+#define ECFLOW_CORE_FILESYSTEM_HPP
+
+#include <cassert>
+
+#include <boost/filesystem.hpp>
+
+namespace fs = boost::filesystem;
+
+#endif
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Host.cpp 5.13.0-1/libs/core/src/ecflow/core/Host.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Host.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Host.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Host.hpp"
+
+#include <cassert>
+#include <stdexcept>
+#include <unistd.h> // for gethostname
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+Host::Host() {
+    get_host_name();
+}
+
+Host::Host(const std::string& host) : the_host_name_(host) {
+    if (the_host_name_ == Str::LOCALHOST()) {
+        get_host_name();
+    }
+}
+
+void Host::get_host_name() {
+    static std::string the_host_name;
+    if (the_host_name.empty()) {
+        char hostNameArray[255];
+        if (gethostname(hostNameArray, 255) != -1) {
+            the_host_name = string(hostNameArray);
+        }
+        else {
+            throw std::runtime_error("Host::Host() failed, could not get host name?\n");
+        }
+    }
+    the_host_name_ = the_host_name;
+    assert(!the_host_name_.empty());
+}
+
+std::string Host::name() const {
+    return the_host_name_;
+}
+
+std::string Host::ecf_log_file(const std::string& port) const {
+    return prefix_host_and_port(port, Ecf::LOG_FILE());
+}
+
+std::string Host::ecf_checkpt_file(const std::string& port) const {
+    return prefix_host_and_port(port, Ecf::CHECKPT());
+}
+
+std::string Host::ecf_backup_checkpt_file(const std::string& port) const {
+    return prefix_host_and_port(port, Ecf::BACKUP_CHECKPT());
+}
+
+std::string Host::ecf_lists_file(const std::string& port) const {
+    return prefix_host_and_port(port, Str::WHITE_LIST_FILE());
+}
+
+std::string Host::ecf_passwd_file(const std::string& port) const {
+    return prefix_host_and_port(port, Str::ECF_PASSWD());
+}
+
+std::string Host::ecf_custom_passwd_file(const std::string& port) const {
+    return prefix_host_and_port(port, Str::ECF_CUSTOM_PASSWD());
+}
+
+std::string Host::prefix_host_and_port(const std::string& port, const std::string& file_name) const {
+    // The file name may include a path.  /user/avi/fred.log
+    //    fred.log             ->  <host>.<port>.fred.log
+    //    /user/avi/fred.log   ->  /user/avi/fred.log
+    if (!file_name.empty() && file_name.find("/") != std::string::npos) {
+        return file_name;
+    }
+    std::string ret = host_port_prefix(port);
+    ret += ".";
+    ret += file_name;
+    return ret;
+}
+
+std::string Host::host_port_prefix(const std::string& port) const {
+    std::string ret = the_host_name_;
+    if (!port.empty()) {
+        ret += ".";
+        ret += port;
+    }
+    return ret;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Host.hpp 5.13.0-1/libs/core/src/ecflow/core/Host.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Host.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Host.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,60 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Host_HPP
+#define ecflow_core_Host_HPP
+
+#include <string>
+
+namespace ecf {
+
+class Host {
+public:
+    /// can throw std::runtime_error if the gethostname fails
+    Host();
+    explicit Host(const std::string& host);
+
+    // Disable copy (and move) semantics
+    Host(const Host&)                  = delete;
+    const Host& operator=(const Host&) = delete;
+
+    /// return the host name
+    std::string name() const;
+
+    /// returns the log file name
+    std::string ecf_log_file(const std::string& port) const;
+
+    /// return checkPoint file
+    std::string ecf_checkpt_file(const std::string& port) const;
+
+    /// return backup checkPoint file
+    std::string ecf_backup_checkpt_file(const std::string& port) const;
+
+    /// return ecf.list file. White list file used for authentication & authorisation
+    std::string ecf_lists_file(const std::string& port) const;
+
+    /// return ecf.passwd file. Used for authentication
+    std::string ecf_passwd_file(const std::string& port) const;
+
+    /// return ecf.custom_passwd file. Used for authentication
+    std::string ecf_custom_passwd_file(const std::string& port) const;
+
+    /// Given a port and file name, will return <host>.<port>.file_name
+    std::string prefix_host_and_port(const std::string& port, const std::string& file_name) const;
+
+private:
+    std::string host_port_prefix(const std::string& port) const;
+    void get_host_name(); // will cache host name, to avoid multiple system calls
+    std::string the_host_name_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_Host_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Indentor.cpp 5.13.0-1/libs/core/src/ecflow/core/Indentor.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Indentor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Indentor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Indentor.hpp"
+
+#include <ostream>
+
+namespace ecf {
+
+int Indentor::index_   = 0;
+bool Indentor::indent_ = true;
+
+void Indentor::indent(std::string& os, int char_spaces) {
+    os += (indent_ ? std::string(index_ * char_spaces, ' ') : "");
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Indentor.hpp 5.13.0-1/libs/core/src/ecflow/core/Indentor.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Indentor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Indentor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,54 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Indentor_HPP
+#define ecflow_core_Indentor_HPP
+
+///
+/// \brief This class is used as a helper class to produce indented output
+///
+
+#include <iosfwd>
+#include <string>
+
+namespace ecf {
+
+class Indentor {
+public:
+    Indentor() { ++index_; }
+    ~Indentor() { --index_; }
+
+    static void indent(std::string& os, int char_spaces = 2);
+
+    template <typename Stream>
+    static Stream& indent(Stream& s, int char_spaces = 2) {
+        s << (indent_ ? std::string(index_ * char_spaces, ' ') : std::string(""));
+        return s;
+    }
+
+private:
+    static int index_;
+
+private:
+    friend class DisableIndentor;
+    static void disable_indent() { indent_ = false; }
+    static void enable_indent() { indent_ = true; }
+    static bool indent_;
+};
+
+class DisableIndentor {
+public:
+    DisableIndentor() { Indentor::disable_indent(); }
+    ~DisableIndentor() { Indentor::enable_indent(); }
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_Indentor_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Log.cpp 5.13.0-1/libs/core/src/ecflow/core/Log.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Log.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Log.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,413 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Log.hpp"
+
+#include <cassert>
+#include <iostream>
+#include <stdexcept>
+#include <vector>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeStamp.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+Log* Log::instance_   = nullptr;
+bool LogToCout::flag_ = false;
+
+void Log::create(const std::string& filename) {
+    if (instance_ == nullptr) {
+        instance_ = new Log(filename);
+    }
+}
+
+void Log::destroy() {
+    if (instance_)
+        instance_->flush();
+
+    delete instance_;
+    instance_ = nullptr;
+}
+
+Log::Log(const std::string& fileName) : logImpl_(std::make_unique<LogImpl>(fileName)), fileName_(fileName) {
+}
+
+void Log::create_logimpl() {
+    if (!logImpl_) {
+        logImpl_ = std::make_unique<LogImpl>(fileName_);
+    }
+}
+
+bool Log::log(Log::LogType lt, const std::string& message) {
+    create_logimpl();
+
+    //   if (!logImpl_->log_open_error().empty()) {
+    //      cerr << "Log::log: " << message << "\n";
+    //   }
+
+    if (!logImpl_->log(lt, message)) {
+        // handle write failure and Get the failure reason. This will delete logImpl_ & recreate
+        log_error_ = handle_write_failure();
+
+        (void)logImpl_->log(Log::ERR, log_error_);
+        (void)logImpl_->log(lt, message);
+        return false;
+    }
+    return true;
+}
+
+bool Log::log_no_newline(Log::LogType lt, const std::string& message) {
+    create_logimpl();
+
+    //   if (!logImpl_->log_open_error().empty()) {
+    //      cerr << "Log::log_no_newline : " << message << "\n";
+    //   }
+
+    if (!logImpl_->log_no_newline(lt, message)) {
+        // handle write failure and Get the failure reason. This will delete logImpl_ & recreate
+        log_error_ = handle_write_failure();
+
+        (void)logImpl_->log(Log::ERR, log_error_);
+        (void)logImpl_->log_no_newline(lt, message);
+        return false;
+    }
+    return true;
+}
+
+bool Log::append(const std::string& message) {
+    create_logimpl();
+
+    //   if (!logImpl_->log_open_error().empty()) {
+    //      cerr << "Log::append : " << message << "\n";
+    //   }
+
+    if (!logImpl_->append(message)) {
+        // handle write failure and Get the failure reason. This will delete logImpl_ & recreate
+        log_error_ = handle_write_failure();
+
+        (void)logImpl_->log(Log::ERR, log_error_);
+        (void)logImpl_->append(message);
+        return false;
+    }
+    return true;
+}
+
+void Log::cache_time_stamp() {
+    create_logimpl();
+    logImpl_->create_time_stamp();
+}
+
+const std::string& Log::get_cached_time_stamp() const {
+    return (logImpl_) ? logImpl_->get_cached_time_stamp() : Str::EMPTY();
+}
+
+void Log::flush() {
+    // will close ofstream and force data to be written to disk.
+    // Forcing writing to physical medium can't be guaranteed though!
+    logImpl_.reset();
+}
+
+void Log::flush_only() {
+    if (logImpl_)
+        logImpl_->flush();
+}
+
+void Log::clear() {
+    flush();
+
+    // Open and truncate the file.
+    std::ofstream logfile(fileName_.c_str(), ios::out | ios::trunc);
+    if (logfile.is_open()) {
+        logfile.close(); // force buffers to flush
+    }
+}
+
+void Log::new_path(const std::string& the_new_path) {
+    check_new_path(the_new_path);
+
+    // flush and close log file
+    flush();
+
+    fileName_ = the_new_path;
+}
+
+void Log::check_new_path(const std::string& new_path) {
+    if (new_path.empty()) {
+        throw std::runtime_error("Log::check_new_path: No path name specified for the new log file");
+    }
+
+    fs::path the_new_path = new_path;
+
+    // Allow paths like "fred.log"
+    fs::path parent_path = the_new_path.parent_path();
+    // std::cout << "the_new_path.parent_path() = " << parent_path << "\n";
+    if (!parent_path.empty()) {
+
+        if (!fs::exists(parent_path)) {
+            std::stringstream ss;
+            ss << "Log::check_new_path: Cannot create new log file, since the directory part " << parent_path
+               << " does not exist\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    // Now check that path does not correspond to a directory, can't use that as the new log file location
+    if (fs::is_directory(the_new_path)) {
+        std::stringstream ss;
+        ss << "LogCmd::LogCmd: Cannot create new log file, since the path correspond to a directory " << the_new_path
+           << "\n";
+        throw std::runtime_error(ss.str());
+    }
+}
+
+std::string Log::path() const {
+    if (!fileName_.empty() && fileName_[0] == '/') {
+        // Path is absolute return as is
+        return fileName_;
+    }
+    std::string the_path = fs::current_path().string();
+    the_path += "/";
+    the_path += fileName_;
+    return the_path;
+}
+
+std::string Log::contents(int get_last_n_lines) {
+    if (get_last_n_lines == 0) {
+        return string();
+    }
+
+    // Close the file. Log file may be buffered, hence flush first
+    flush();
+
+    std::string error_msg;
+    if (get_last_n_lines > 0) {
+        return File::get_last_n_lines(fileName_, get_last_n_lines, error_msg);
+    }
+    return File::get_first_n_lines(fileName_, std::abs(get_last_n_lines), error_msg);
+}
+
+std::string Log::handle_write_failure() {
+    std::string msg = logImpl_->log_open_error();
+    if (msg.empty()) {
+        msg += "\nFailed to write to log file: ";
+        msg += File::stream_error_condition(logImpl_->stream());
+    }
+    // Append 'regular' format timestamp to end of message
+    msg += " ";
+    msg += TimeStamp::now();
+
+    // handle write failure, by closing then re-opening log file
+    logImpl_.reset();
+    create_logimpl();
+
+    if (logImpl_->log_open_error().empty())
+        msg += "\nAttempting to close/reopen log file.";
+    else
+        msg += "\nAttempting to close/reopen log file did not work!";
+
+    if (LogToCout::ok())
+        Indentor::indent(cout) << msg << '\n';
+    return msg;
+}
+
+bool log(Log::LogType lt, const std::string& message) {
+    // For debug of simulator enable this
+    //	if (LogToCout::ok()) {
+    //		Indentor::indent(cout) << message << '\n';
+    //	}
+
+    if (Log::instance()) {
+        return Log::instance()->log(lt, message);
+    }
+    else {
+        if (LogToCout::ok()) {
+            Indentor::indent(cout) << message << '\n';
+        }
+    }
+    return true;
+}
+
+bool log_no_newline(Log::LogType lt, const std::string& message) {
+    if (Log::instance()) {
+        return Log::instance()->log_no_newline(lt, message);
+    }
+    else {
+        if (LogToCout::ok()) {
+            Indentor::indent(cout) << message << '\n';
+        }
+    }
+    return true;
+}
+
+bool log_append(const std::string& message) {
+    if (Log::instance()) {
+        return Log::instance()->append(message);
+    }
+    else {
+        if (LogToCout::ok()) {
+            Indentor::indent(cout) << message << '\n';
+        }
+    }
+    return true;
+}
+
+void log_assert(char const* expr, char const* file, long line, const std::string& message) {
+    std::stringstream ss;
+    ss << "ASSERT failure: " << expr << " at " << file << ":" << line << " " << message;
+    std::string assert_msg = ss.str();
+    cerr << assert_msg << "\n";
+    if (Log::instance()) {
+        Log::instance()->log(Log::ERR, assert_msg);
+        exit(1);
+    }
+}
+
+// returns vec = MSG, LOG, ERR, WAR, DBG, OTH
+void Log::get_log_types(std::vector<std::string>& vec) {
+    vec.reserve(6);
+    vec.emplace_back("MSG");
+    vec.emplace_back("LOG");
+    vec.emplace_back("ERR");
+    vec.emplace_back("WAR");
+    vec.emplace_back("DBG");
+    vec.emplace_back("OTH");
+}
+
+//======================================================================================================
+
+LogFlusher::~LogFlusher() {
+    Log* the_log = Log::instance();
+    if (the_log) {
+        the_log->flush_only(); // flush without closing log file.
+    }
+}
+
+//======================================================================================================
+
+TestLog::TestLog(const std::string& log_path) : log_path_(log_path) {
+    Log::create(log_path);
+}
+
+TestLog::~TestLog() {
+
+    // Remove the log file. Comment out for debugging
+    fs::remove(log_path_);
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+}
+
+//======================================================================================================
+
+LogTimer::~LogTimer() {
+    Log* the_log = Log::instance();
+    if (the_log) {
+        std::stringstream ss;
+        ss << " " << msg_ << " " << timer_.elapsed_seconds();
+        the_log->log(Log::DBG, ss.str());
+    }
+}
+
+//======================================================================================================
+LogImpl::LogImpl(const std::string& filename) : file_(filename.c_str(), ios::out | ios::app) {
+    if (!file_.is_open()) {
+        log_open_error_ = "Could not open log file '";
+        log_open_error_ += filename;
+        log_open_error_ += "'. ";
+        log_open_error_ += File::stream_error_condition(file_);
+        // std::cerr << log_open_error_ << "\n";
+        //  Do *NOT* throw std::runtime_error(log_open_error_), HERE as this can cause server to die.
+        //  This would diagnose ECFLOW-1558 but is not acceptable
+    }
+}
+
+LogImpl::~LogImpl() = default;
+
+static void append_log_type(std::string& str, Log::LogType lt) {
+    switch (lt) {
+        case Log::MSG:
+            str.append("MSG:");
+            break;
+        case Log::LOG:
+            str.append("LOG:");
+            break;
+        case Log::ERR:
+            str.append("ERR:");
+            break;
+        case Log::WAR:
+            str.append("WAR:");
+            break;
+        case Log::DBG:
+            str.append("DBG:");
+            break;
+        case Log::OTH:
+            str.append("OTH:");
+            break;
+        default:
+            assert(false);
+            break;
+    }
+}
+
+bool LogImpl::do_log(Log::LogType lt, const std::string& message, bool newline) {
+    count_++;
+
+    // XXX:[HH:MM:SS D.M.YYYY] chd:fullname [+additional information]
+    // XXX:[HH:MM:SS D.M.YYYY] --<user_cmd> [+additional information]
+    if (time_stamp_.empty() || lt == Log::ERR || lt == Log::WAR || lt == Log::DBG)
+        create_time_stamp();
+
+    // re-use memory allocated to log_type_and_time_stamp_
+    log_type_and_time_stamp_.clear();
+    append_log_type(log_type_and_time_stamp_, lt);
+    log_type_and_time_stamp_ += time_stamp_;
+
+    if (message.find("\n") == std::string::npos) {
+        file_ << log_type_and_time_stamp_ << message;
+        if (newline)
+            file_ << '\n';
+    }
+    else {
+        // If message has \n then split into multiple lines
+        std::vector<std::string> lines;
+        Str::split(message, lines, "\n");
+        size_t theSize = lines.size();
+        for (size_t i = 0; i < theSize; ++i) {
+            file_ << log_type_and_time_stamp_ << lines[i] << '\n';
+        }
+    }
+    return file_.good();
+}
+
+void LogImpl::flush() {
+    // cout << "LogImpl::flush() count = " << count_ << endl;
+    if (count_ != 0) {
+        file_.flush();
+        count_ = 0;
+    }
+}
+
+bool LogImpl::append(const std::string& message) {
+    count_++;
+    file_ << message << '\n';
+    return file_.good();
+}
+
+void LogImpl::create_time_stamp() {
+    TimeStamp::now(time_stamp_);
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Log.hpp 5.13.0-1/libs/core/src/ecflow/core/Log.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Log.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Log.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,233 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Log_HPP
+#define ecflow_core_Log_HPP
+
+///
+/// \brief Simple singleton implementation of log
+///
+/// Please note how do we guarantee that file is actually written to disk:
+///   a/ Each log entry should call std::endl
+///   b/ Call flush() on the ofstream
+///   c/ The two methods will force ofstream buffer to be written to disk
+///
+/// Well NOT REALLY dues to file caching by the OS.
+///
+/// The strongest hint we can give th OS to actually write to the physical medium
+/// is to close the file. (This does not guarantee it, but is the closest we can achieve)
+///
+/// Why is this an issue? Testing on cross platform HPUX/linux, requires that
+/// testing has access to the ECF log file. Initially the log file held an
+/// ofstream of log file as a data member. However this meant that flushing
+/// did not guarantee writing ECF log file to disk. Testing requires that we
+/// are able to clear and copy the log file for comparison.
+/// Hence we use another level of indirection, so that we able to close the
+/// log file, and hence can ensure that it gets written to disk
+///
+
+#include <fstream>
+#include <memory>
+#include <string>
+#include <vector>
+
+#include "ecflow/core/DurationTimer.hpp"
+
+namespace ecf {
+
+class LogImpl;
+
+class Log {
+public:
+    enum LogType { MSG, LOG, ERR, WAR, DBG, OTH };
+
+    static void create(const std::string& filename);
+    static void destroy();
+    static Log* instance() { return instance_; }
+
+    // Disable copy (and move) semantics
+    Log(const Log&)                  = delete;
+    const Log& operator=(const Log&) = delete;
+
+    /// If file is closed will open it
+    /// Outputs t the file a message of type XXX:[HH:MM:SS D.M.YYYY] message
+    /// where XXX is one of the LogType
+    ///
+    /// If the message has multiple newlines these are split
+    /// LogType ERR,WAR,DBG will create a time stamp, otherwise the last cached
+    /// time stamp is used.
+    bool log(LogType, const std::string& message);
+
+    /// Single line message is placed in log file without a newline
+    bool log_no_newline(LogType, const std::string& message);
+
+    /// Append to log file file and add newline
+    bool append(const std::string& message);
+
+    /// Set the time stamp once for each request.
+    void cache_time_stamp();
+
+    /// Return the last cached time stamp. Used for time stamping edit history
+    const std::string& get_cached_time_stamp() const;
+
+    /// returns the contents of the log file, or the last n lines
+    /// Will throw an std::runtime_error if the log file cannot be opened
+    /// Will close the file.
+    static int get_last_n_lines_default() { return 100; }
+    std::string contents(int get_last_n_lines);
+
+    /// Will call flush and close the file. See notes above
+    void flush();
+
+    /// will flush the log file without closing it.
+    void flush_only();
+
+    /// clear the log file. Required for testing
+    void clear();
+
+    /// Close the existing log file, and new start writing to the new location
+    void new_path(const std::string& the_new_path);
+
+    /// Returns the current log file path name
+    std::string path() const;
+
+    /// Errors in opening or writing to log file
+    const std::string& log_error() const { return log_error_; }
+
+    // returns vec = MSG, LOG, ERR, WAR, DBG, OTH
+    static void get_log_types(std::vector<std::string>&);
+
+private:
+    /// If writing to the log fails, close log file and re-create it.
+    std::string handle_write_failure();
+
+    /// make sure path is not a directory & path has a parent directory.
+    /// Will throw std::runtime_error for errors
+    static void check_new_path(const std::string& new_path);
+
+    void create_logimpl();
+
+private:
+    explicit Log(const std::string& fileName);
+    static Log* instance_;
+
+    std::unique_ptr<LogImpl> logImpl_;
+    std::string fileName_;
+    std::string log_error_;
+};
+
+// Flush log on destruction
+class LogFlusher {
+public:
+    LogFlusher() = default;
+    // Disable copy (and move) semantics
+    LogFlusher(const LogFlusher&)                  = delete;
+    const LogFlusher& operator=(const LogFlusher&) = delete;
+
+    ~LogFlusher();
+};
+
+class LogTimer {
+public:
+    explicit LogTimer(const char* msg) : msg_(msg) {}
+    // Disable copy (and move) semantics
+    LogTimer(const LogTimer&)                  = delete;
+    const LogTimer& operator=(const LogTimer&) = delete;
+
+    ~LogTimer();
+
+private:
+    const char* msg_;
+    DurationTimer timer_;
+};
+
+/// The LogImpl allows the ofstream object to be closed, and so provide strongest
+/// hint to OS that we want file to be written to physical medium.
+/// This is required for testing purposes, as each test run needs to clear/copy
+/// the log file
+class LogImpl {
+public:
+    explicit LogImpl(const std::string& filename);
+    // Disable copy (and move) semantics
+    LogImpl(const LogImpl&)                  = delete;
+    const LogImpl& operator=(const LogImpl&) = delete;
+
+    ~LogImpl();
+
+    bool log(Log::LogType lt, const std::string& message) { return do_log(lt, message, true); }
+    bool log_no_newline(Log::LogType lt, const std::string& message) { return do_log(lt, message, false); }
+    bool append(const std::string& message);
+
+    void create_time_stamp();
+    const std::string& get_cached_time_stamp() const { return time_stamp_; }
+
+    void flush();
+    const std::ofstream& stream() const { return file_; }
+    const std::string& log_open_error() const { return log_open_error_; }
+
+private:
+    bool do_log(Log::LogType, const std::string& message, bool newline);
+
+    std::string time_stamp_;
+    std::string log_type_and_time_stamp_; // re-use memory
+    std::string log_open_error_;
+    mutable std::ofstream file_;
+    unsigned int count_{0};
+};
+
+/// Utility class used for test, since server assumes log is always present
+class TestLog {
+public:
+    explicit TestLog(const std::string& log_path);
+    ~TestLog();
+
+private:
+    std::string log_path_;
+};
+
+/// Utility class used for debug. Enables log file messages to be written to standard out
+class LogToCout {
+public:
+    LogToCout() { flag_ = true; }
+    // Disable copy (and move) semantics
+    LogToCout(const LogToCout&)                  = delete;
+    const LogToCout& operator=(const LogToCout&) = delete;
+
+    ~LogToCout() { flag_ = false; }
+
+    static bool ok() { return flag_; }
+
+private:
+    static bool flag_;
+};
+
+bool log(Log::LogType, const std::string& message);
+bool log_no_newline(Log::LogType, const std::string& message);
+bool log_append(const std::string& message);
+void log_assert(char const* expr, char const* file, long line, const std::string& message);
+
+// allow user to do the following:
+// LOG(Log::WAR,"this is " << path << " ok ");
+//
+// helper, see STRINGIZE() macro
+template <typename Functor>
+std::string stringize_f(Functor const& f) {
+    std::ostringstream out;
+    f(out);
+    return out.str();
+}
+#define STRINGIZE(EXPRESSION) (ecf::stringize_f([&](std::ostringstream& os) { os << EXPRESSION; }))
+#define LOG(level, EXPRESSION) ecf::log(level, STRINGIZE(EXPRESSION))
+#define LOG_ASSERT(expr, EXPRESSION) \
+    ((expr) ? (static_cast<void>(0)) : ecf::log_assert(#expr, __FILE__, __LINE__, STRINGIZE(EXPRESSION)))
+
+} // namespace ecf
+
+#endif /* ecflow_core_Log_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/LogVerification.cpp 5.13.0-1/libs/core/src/ecflow/core/LogVerification.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/LogVerification.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/LogVerification.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,144 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/LogVerification.hpp"
+
+#include <sstream>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+bool LogVerification::extractNodePathAndState(const std::string& logfile,
+                                              std::vector<std::pair<std::string, std::string>>& pathStateVec,
+                                              std::string& errorMsg) {
+    // The log file format we are interested is :
+    //       0          1               2                 3
+    // LOG:[14:37:00 20.5.2010]    submitted: /test_abort_cmd/family0/abort duration_(00:00:00) initTime_(2010-May-20
+    // 14:37:00) suiteTime_(2010-May-20 14:37:00)
+
+    // Open log file, and collate of the node paths and corresponding states
+    std::vector<std::string> lines;
+    if (!File::splitFileIntoLines(logfile, lines)) {
+        errorMsg = "Could not open log file " + logfile + " for test verification (" + strerror(errno) + ")";
+        return false;
+    }
+
+    // int line_number = 0;
+    for (auto& line : lines) {
+
+        // line_number++;
+        if (line.find("LOG:") == std::string::npos) {
+            continue; // State changes have type Log::LOG
+        }
+
+        std::vector<std::string> lineTokens;
+        Str::split(line, lineTokens);
+        if (lineTokens.size() < 3) {
+            continue;
+        }
+
+        std::string theState = lineTokens[2];
+        theState.erase(theState.size() - 1); // remove ':' at the end
+        if (!NState::isValid(theState)) {
+            continue;
+        }
+        // cout << line_number << Str::COLON() << *i << "\n";
+
+        pathStateVec.emplace_back(lineTokens[3], theState);
+    }
+    return true;
+}
+
+static bool searchVec(const std::vector<std::pair<std::string, std::string>>& goldenLines,
+                      const std::pair<std::string, std::string>& line,
+                      size_t start_index) {
+    for (size_t i = start_index; i < goldenLines.size(); i++) {
+        if (goldenLines[i] == line) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool LogVerification::compareNodeStates(const std::string& logfile,
+                                        const std::string& goldenRefLogFile,
+                                        std::string& errorMsg) {
+    // Open log files, and extract just the state changes
+    std::vector<std::pair<std::string, std::string>> lines, goldenLines;
+    if (!extractNodePathAndState(logfile, lines, errorMsg))
+        return false;
+    if (!extractNodePathAndState(goldenRefLogFile, goldenLines, errorMsg))
+        return false;
+
+    if (lines != goldenLines) {
+        std::stringstream ss;
+        ss << "Log file " << logfile << " does not match golden reference file " << goldenRefLogFile << "\n";
+        if (lines.size() != goldenLines.size())
+            ss << "Expected log file size " << goldenLines.size() << " but found " << lines.size() << "\n";
+
+        bool errorFnd = false;
+        for (size_t i = 0; i < lines.size() || i < goldenLines.size(); ++i) {
+
+            std::string theLine, theGoldenLine;
+            if (i < lines.size())
+                theLine = lines[i].second + Str::COLON() + lines[i].first;
+            if (i < goldenLines.size())
+                theGoldenLine = goldenLines[i].second + Str::COLON() + goldenLines[i].first;
+
+            if (i < lines.size() && i < goldenLines.size()) {
+
+                if (lines[i] != goldenLines[i]) {
+                    // Please note that we can't do an exact comparison for certain state changes:
+                    //   - submitted --> active
+                    //   - active    --> complete
+                    // Since this can be OS/scheduler dependent and hence order dependent
+                    // To compensate, we search for a Golden file
+                    if (lines[i].second == "submitted" || lines[i].second == "active" ||
+                        lines[i].second == "complete") {
+                        // search for line in golden file
+                        if (searchVec(goldenLines, lines[i], 0)) {
+                            continue;
+                        }
+                    }
+
+                    ss << "Mismatch at " << i << " log(" << theLine << ")   golden(" << theGoldenLine << ")\n";
+                    errorFnd = true;
+                }
+                else {
+                    ss << "            " << i << " log(" << theLine << ")   golden(" << theGoldenLine << ")\n";
+                }
+            }
+            else {
+                errorFnd = true;
+                ss << "Mismatch at " << i;
+                if (i < lines.size())
+                    ss << " log(" << theLine << ")   ";
+                else
+                    ss << " log( ---- )   ";
+
+                if (i < goldenLines.size())
+                    ss << "golden(" << theGoldenLine << ")\n";
+                else
+                    ss << "golden( --- )\n";
+            }
+        }
+        if (errorFnd)
+            errorMsg = ss.str();
+    }
+
+    return errorMsg.empty();
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/LogVerification.hpp 5.13.0-1/libs/core/src/ecflow/core/LogVerification.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/LogVerification.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/LogVerification.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_LogVerification_HPP
+#define ecflow_core_LogVerification_HPP
+
+#include <string>
+#include <vector>
+
+namespace ecf {
+
+class LogVerification {
+public:
+    // Disable default construction
+    LogVerification() = delete;
+    // Disable copy (and move) semantics
+    LogVerification(const LogVerification&)                  = delete;
+    const LogVerification& operator=(const LogVerification&) = delete;
+
+    /// Given a log file, extract in order. The node_path and the state
+    static bool extractNodePathAndState(const std::string& logfile,
+                                        std::vector<std::pair<std::string, std::string>>& pathStateVec,
+                                        std::string& errorMsg);
+
+    /// Will compare the input log file, with gold reference.
+    /// Will compare the node state changes only
+    /// Compensate for states that are scheduler dependent
+    static bool
+    compareNodeStates(const std::string& logfile, const std::string& goldenRefLogFile, std::string& errorMsg);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_LogVerification_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Message.hpp 5.13.0-1/libs/core/src/ecflow/core/Message.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Message.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Message.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Message_HPP
+#define ecflow_core_Message_HPP
+
+#include <sstream>
+#include <string>
+
+namespace ecf {
+
+///
+/// \brief Message is a utility class that easily creates a string-based Message from an arbitrary set of inputs
+///
+/// The goal is to facilitate the construction/formatting of messages for error handling and logging.
+/// A Message implicitly allows conversion to std::string, and provides the streaming operator<<.
+///
+class Message {
+public:
+    template <typename... ARGS>
+    explicit Message(ARGS&&... args) {
+        ((buffer << std::forward<ARGS>(args)), ...);
+    }
+
+    [[nodiscard]] std::string str() const { return buffer.str(); }
+    [[nodiscard]] operator std::string() const { return buffer.str(); }
+
+private:
+    std::ostringstream buffer;
+};
+
+inline std::ostream& operator<<(std::ostream& o, const Message& m) {
+    o << std::string(m);
+    return o;
+}
+
+} // namespace ecf
+
+#endif /* ecflow_core_Message_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/NOrder.cpp 5.13.0-1/libs/core/src/ecflow/core/NOrder.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/NOrder.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/NOrder.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/NOrder.hpp"
+
+#include <cassert>
+
+#include "ecflow/core/Enumerate.hpp"
+
+namespace ecf::detail {
+
+template <>
+struct EnumTraits<NOrder::Order>
+{
+    using underlying_t = std::underlying_type_t<NOrder::Order>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(NOrder::Order::TOP, "top"),
+        std::make_pair(NOrder::Order::BOTTOM, "bottom"),
+        std::make_pair(NOrder::Order::ALPHA, "alpha"),
+        std::make_pair(NOrder::Order::ORDER, "order"),
+        std::make_pair(NOrder::Order::UP, "up"),
+        std::make_pair(NOrder::Order::DOWN, "down"),
+        std::make_pair(NOrder::Order::RUNTIME, "runtime")
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(std::is_same_v<NOrder::Order, decltype(map)::value_type::first_type>);
+    static_assert(std::is_same_v<const char*, decltype(map)::value_type::second_type>);
+
+    static_assert(EnumTraits<NOrder::Order>::size == map.back().first + 1);
+};
+
+} // namespace ecf::detail
+
+std::string NOrder::toString(NOrder::Order s) {
+    if (auto found = ecf::Enumerate<NOrder::Order>::to_string(s); found) {
+        return std::string{found.value()};
+    }
+    assert(false);
+    return std::string{};
+}
+
+NOrder::Order NOrder::toOrder(const std::string& str) {
+    if (auto found = ecf::Enumerate<NOrder::Order>::to_enum(str); found) {
+        return found.value();
+    }
+    assert(false);
+    return NOrder::TOP;
+}
+
+bool NOrder::isValid(const std::string& order) {
+    return ecf::Enumerate<NOrder::Order>::is_valid(order);
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/NOrder.hpp 5.13.0-1/libs/core/src/ecflow/core/NOrder.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/NOrder.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/NOrder.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,27 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_NOrder_HPP
+#define ecflow_core_NOrder_HPP
+
+#include <string>
+
+class NOrder {
+    NOrder() = default;
+
+public:
+    enum Order { TOP, BOTTOM, ALPHA, ORDER, UP, DOWN, RUNTIME /* state change runtime */ };
+
+    static std::string toString(NOrder::Order);
+    static NOrder::Order toOrder(const std::string&);
+    static bool isValid(const std::string& order);
+};
+
+#endif
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/NState.cpp 5.13.0-1/libs/core/src/ecflow/core/NState.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/NState.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/NState.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,103 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/NState.hpp"
+
+#include <cassert>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Enumerate.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+namespace ecf::detail {
+
+template <>
+struct EnumTraits<NState::State>
+{
+    using underlying_t = std::underlying_type_t<NState::State>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(NState::State::UNKNOWN, "unknown"),
+        std::make_pair(NState::State::COMPLETE, "complete"),
+        std::make_pair(NState::State::QUEUED, "queued"),
+        std::make_pair(NState::State::ABORTED, "aborted"),
+        std::make_pair(NState::State::SUBMITTED, "submitted"),
+        std::make_pair(NState::State::ACTIVE, "active")
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<NState::State>::size == map.back().first + 1);
+};
+
+} // namespace ecf::detail
+
+void NState::setState(State s) {
+    st_              = s;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "NState::setState\n";
+#endif
+}
+
+const char* NState::toString(NState::State s) {
+    if (auto found = ecf::Enumerate<NState::State>::to_string(s); found) {
+        return found.value().data();
+    }
+    assert(false);
+    return nullptr;
+}
+
+std::string NState::to_html(NState::State s) {
+    std::string res;
+    if (auto found = ecf::Enumerate<NState::State>::to_string(s); found) {
+        res += "<state>";
+        res += found.value();
+        res += "</state>";
+        return res;
+    }
+    assert(false);
+    return res;
+}
+
+NState::State NState::toState(const std::string& str) {
+    if (auto found = ecf::Enumerate<NState::State>::to_enum(str); found) {
+        return found.value();
+    }
+    assert(false);
+    return NState::UNKNOWN;
+}
+
+std::pair<NState::State, bool> NState::to_state(const std::string& str) {
+    if (auto found = ecf::Enumerate<NState::State>::to_enum(str); found) {
+        return std::make_pair(found.value(), true);
+    }
+    return std::make_pair(NState::UNKNOWN, false);
+}
+
+bool NState::isValid(const std::string& state) {
+    return ecf::Enumerate<NState::State>::is_valid(state);
+}
+
+std::vector<std::string> NState::allStates() {
+    return ecf::Enumerate<NState::State>::designations();
+}
+
+std::vector<NState::State> NState::states() {
+    return ecf::Enumerate<NState::State>::enums();
+}
+
+template <class Archive>
+void NState::serialize(Archive& ar) {
+    ar(CEREAL_NVP(st_));
+}
+CEREAL_TEMPLATE_SPECIALIZE(NState);
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/NState.hpp 5.13.0-1/libs/core/src/ecflow/core/NState.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/NState.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/NState.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,66 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_NState_HPP
+#define ecflow_core_NState_HPP
+
+#include <string>
+#include <vector>
+
+namespace cereal {
+class access;
+}
+
+// NState: stores the state of a node.
+// *The class NState just used to define the enum, however we also
+// needed to know when the state changed. Hence, the use of state_change_no
+// Uses default copy constructor and destructor, and equality
+//
+// The default_state() should *NEVER* change as it will impact client/server communications
+//
+class NState {
+public:
+    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5 };
+
+    explicit NState(State s) : st_(s), state_change_no_(0) {}
+    NState() : st_(default_state()) {}
+    static NState::State default_state() { return NState::UNKNOWN; }
+
+    State state() const { return st_; }
+    void setState(State);
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    bool operator==(const NState& rhs) const { return st_ == rhs.st_; }
+    bool operator!=(const NState& rhs) const { return st_ != rhs.st_; }
+    bool operator==(State s) const { return s == st_; }
+    bool operator!=(State s) const { return s != st_; }
+
+    static const char* toString(NState::State s);
+    static std::string to_html(NState::State s);
+    static const char* toString(const NState& ns) { return toString(ns.state()); }
+    static NState::State toState(const std::string&);
+    static bool isValid(const std::string& state);
+    static std::pair<NState::State, bool> to_state(const std::string&);
+    static std::vector<std::string> allStates();
+    static std::vector<NState::State> states();
+
+private:
+    State st_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+    // *IMPORTANT* no version for a simple class
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_core_NState_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/NodePath.cpp 5.13.0-1/libs/core/src/ecflow/core/NodePath.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/NodePath.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/NodePath.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,69 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/NodePath.hpp"
+
+#include "ecflow/core/Str.hpp"
+
+using namespace ecf;
+
+void NodePath::split(const std::string& path, std::vector<std::string>& thePath) {
+    /// The path is of the form "/suite/family/task"
+    Str::split(path, thePath, Str::PATH_SEPERATOR());
+}
+
+bool NodePath::extractHostPort(const std::string& path, std::string& host, std::string& port) {
+    if (path.empty())
+        return false;
+
+    std::vector<std::string> thePath;
+    NodePath::split(path, thePath);
+
+    if (thePath.empty())
+        return false;
+
+    //<host>:<port>/suite/family/task
+    // first path should be of form <host>:<port>
+    size_t colonPos = thePath[0].find_first_of(':');
+    if (colonPos == std::string::npos)
+        return false;
+
+    host = thePath[0].substr(0, colonPos);
+    port = thePath[0].substr(colonPos + 1);
+
+    ecf::algorithm::trim(host);
+    ecf::algorithm::trim(port);
+    if (host.empty())
+        return false;
+    if (port.empty())
+        return false;
+
+    return true;
+}
+
+std::string NodePath::createPath(const std::vector<std::string>& vec) {
+    if (vec.empty())
+        return std::string();
+
+    std::string ret;
+    size_t size = vec.size();
+    for (size_t i = 0; i < size; i++) {
+        ret += Str::PATH_SEPERATOR();
+        ret += vec[i];
+    }
+    return ret;
+}
+
+std::string NodePath::removeHostPortFromPath(const std::string& path) {
+    std::vector<std::string> pathVec;
+    NodePath::split(path, pathVec);
+    pathVec.erase(pathVec.begin());
+    return NodePath::createPath(pathVec);
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/NodePath.hpp 5.13.0-1/libs/core/src/ecflow/core/NodePath.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/NodePath.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/NodePath.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,44 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_NodePath_HPP
+#define ecflow_core_NodePath_HPP
+
+#include <string>
+#include <vector>
+
+class NodePath {
+public:
+    // Disable default construction
+    NodePath() = delete;
+    // Disable copy (and move) semantics
+    NodePath(const NodePath&)                  = delete;
+    const NodePath& operator=(const NodePath&) = delete;
+
+    /// returns the path as a vector of strings, preserving the order
+    /// Note: multiple path separator '/' are treated as one separator.
+    /// Mimics unix path conventions. hence
+    /// '/suite//family///task' will be extracted as 'suite','family','task'
+    static void split(const std::string& path, std::vector<std::string>&);
+
+    /// If the path name if form:
+    ///     //<host>:<port>/suite/family/task
+    /// The extract the host and port, return OK if successful
+    static bool extractHostPort(const std::string& path, std::string& host, std::string& port);
+
+    /// Given a vector of strings , create a path. "suite","family", returns /suite/family
+    static std::string createPath(const std::vector<std::string>&);
+
+    /// Given a path like:   //localhost:3141/suite/family/task
+    /// returns              /suite/family/task
+    static std::string removeHostPortFromPath(const std::string& path);
+};
+
+#endif /* ecflow_core_NodePath_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Overload.hpp 5.13.0-1/libs/core/src/ecflow/core/Overload.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Overload.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Overload.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,27 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Overload_HPP
+#define ecflow_core_Overload_HPP
+
+namespace ecf {
+
+template <class... Ts>
+struct overload : Ts...
+{
+    using Ts::operator()...;
+};
+
+template <class... Ts>
+overload(Ts...) -> overload<Ts...>; // Deduction guideline not needed from C++20
+
+} // namespace ecf
+
+#endif /* ecflow_core_Overload_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Passwd.cpp 5.13.0-1/libs/core/src/ecflow/core/Passwd.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Passwd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Passwd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Passwd.hpp"
+
+#include <ctime>
+#include <unistd.h>
+
+double ecf_drand48();
+
+std::string Passwd::generate() {
+    char pw[9];
+    for (int i = 0; i < 8; i++) { /* generate a random password */
+
+        pw[i] = 64.0 * ecf_drand48() + '.'; /* Just crack this one! */
+        if (pw[i] > '9')
+            pw[i] += 7;
+        if (pw[i] > 'Z')
+            pw[i] += 6;
+    }
+    pw[8] = '\0';
+    return std::string(pw);
+}
+
+double ecf_drand48()
+/**************************************************************************
+ ?  Random number with time dependent seed.
+ =  [0.0 - 1.0)
+ ~  drand48(3) srand48(3) rand(3)
+ ************************************o*************************************/
+{
+    //  extern double drand48();
+    //  extern void   srand48();
+    static int been_here;
+
+    if (!been_here) {
+#if defined(RAND_ONLY)
+        srand((int)time(NULL) + getpid());
+#else
+        srand48((long)time(nullptr) + getpid());
+#endif
+        been_here = 1;
+    }
+
+#if defined(RAND_ONLY)
+    return (rand() & 0xffff) / 65535.0001;
+#else
+    return drand48();
+#endif
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Passwd.hpp 5.13.0-1/libs/core/src/ecflow/core/Passwd.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Passwd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Passwd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,43 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Passwd_HPP
+#define ecflow_core_Passwd_HPP
+
+///
+/// The tasks send by the ECF will have GENERATED PASSWORD that is not
+/// stored into the any file (except the job file). It only exists in the
+/// ECF_server-memory. If the ECF server fails and a new one is started,
+/// it must be told (by operator) to accept the messages from the unknown jobs.
+///
+/// The GENERATED PASSWORDs are stored into the CHECKPOINT file. So if the
+/// ECF fails and is RESTARTed from a valid CHECKPOINT file, the ECF gets
+/// to know about the tasks.
+///
+/// The user passwords are kept in a file. When ever an user logs into
+/// the ECF or changes the "level" of privileges while already in the
+/// file is consulted.
+///
+
+#include <string>
+
+class Passwd {
+public:
+    // Disable default construction
+    Passwd() = delete;
+    // Disable copy (and move) semantics
+    Passwd(const Passwd&)                  = delete;
+    const Passwd& operator=(const Passwd&) = delete;
+
+    /// generate a random password
+    static std::string generate();
+};
+
+#endif /* ecflow_core_Passwd_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/PasswdFile.cpp 5.13.0-1/libs/core/src/ecflow/core/PasswdFile.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/PasswdFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/PasswdFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,337 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/PasswdFile.hpp"
+
+#include <iostream>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/PasswordEncryption.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/User.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+PasswdFile::PasswdFile()  = default;
+PasswdFile::~PasswdFile() = default;
+
+// #define DEBUG_ME 1
+
+// Parse the file if any errors found return false and errorMsg
+// The parser expects version number  4.5.0
+bool PasswdFile::load(const std::string& file, bool debug, std::string& errorMsg) {
+#ifdef DEBUG_ME
+    debug = true;
+#endif
+    vec_.clear();
+    passwd_file_ = file;
+    if (debug)
+        std::cout << __func__ << "  " << passwd_file_ << " opening...\n";
+
+    std::vector<std::string> lines;
+    if (!File::splitFileIntoLines(passwd_file_, lines, true /* ignore empty lines */)) {
+        errorMsg += "Could not open file specified by ECF_PASSWD/ECF_CUSTOM_PASSWD ";
+        errorMsg += passwd_file_;
+        errorMsg += " (";
+        errorMsg += strerror(errno);
+        errorMsg += ")";
+        if (debug)
+            std::cout << dump() << "\n";
+        return false;
+    }
+
+    bool foundVersionNumber = false; // can read from version 4.4.0 onwards
+    size_t lines_size       = lines.size();
+    for (size_t i = 0; i < lines_size; ++i) {
+
+        if (lines[i].empty())
+            continue;
+
+        // ignore/remove all comments
+        if (lines[i][0] == '#')
+            continue;
+        std::string theLine           = lines[i];
+        string::size_type comment_pos = theLine.find("#");
+        if (comment_pos != std::string::npos) {
+            theLine.erase(comment_pos);
+        }
+
+        ecf::algorithm::trim(theLine); // remove leading and trailing spaces
+        std::vector<std::string> lineTokens;
+        Str::split(theLine, lineTokens);
+        if (lineTokens.empty())
+            continue;
+
+        // version should be at the start
+        if (!foundVersionNumber) {
+
+            if (!validateVersionNumber(lineTokens[0], errorMsg)) {
+                std::stringstream ss;
+                ss << " " << i + 1 << ": " << lines[i] << "\n";
+                ss << "for ECF_PASSWD/ECF_CUSTOM_PASSWD file " << passwd_file_ << "\n";
+                errorMsg += ss.str();
+                return false;
+            }
+            foundVersionNumber = true;
+            continue;
+        }
+        else {
+            if (!add_user(lineTokens, errorMsg)) {
+                errorMsg += theLine;
+                return false;
+            }
+        }
+    }
+
+    if (debug)
+        std::cout << dump();
+
+    // Now check the user is unique for a given host/port:
+    //   fred host 3141 xxxx
+    //   fred host 3141 yyyy  this is illegal.
+    size_t vec_size = vec_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        for (size_t k = 0; k < vec_size; k++) {
+            if (i == k)
+                continue;
+            if (vec_[i].user() == vec_[k].user() && vec_[i].host() == vec_[k].host() &&
+                vec_[i].port() == vec_[k].port()) {
+                std::stringstream ss;
+                ss << "user " << vec_[i].user() << " can only appear once for given host/port\n";
+                errorMsg += ss.str();
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
+bool PasswdFile::check_at_least_one_user_with_host_and_port(const std::string& host, const std::string& port) {
+    size_t vec_size = vec_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (vec_[i].host() == host && vec_[i].port() == port) {
+            return true;
+        }
+    }
+    return false;
+}
+
+std::string PasswdFile::get_passwd(const std::string& user, const std::string& host, const std::string& port) {
+#ifdef DEBUG_ME
+    cout << "PasswdFile::get_passwd user(" << user << ") host(" << host << ") port(" << port << ")\n";
+#endif
+    size_t vec_size = vec_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (vec_[i].user() == user && vec_[i].host() == host && vec_[i].port() == port) {
+            return vec_[i].passwd();
+        }
+    }
+    return string();
+}
+
+bool PasswdFile::authenticate(const std::string& user, const std::string& passwd) const {
+#ifdef DEBUG_ME
+    cout << "   PasswdFile::authenticate user:" << user << " passwd:" << passwd << " file:" << passwd_file_
+         << " vec_.size(): " << vec_.size() << "\n";
+    cout << dump() << "\n";
+#endif
+
+    if (user.empty()) {
+#ifdef DEBUG_ME
+        cout << "      PasswdFile::authenticate: user empty:  FAIL\n";
+#endif
+        return false;
+    }
+
+    // no password specified, and password file is empty
+    if (passwd.empty() && vec_.empty()) {
+#ifdef DEBUG_ME
+        cout << "      PasswdFile::authenticate no password and password file empty: PASS\n";
+#endif
+        return true;
+    }
+
+    // Only fail if user exists in the passwd file
+    size_t vec_size = vec_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (vec_[i].user() == user) {
+            if (vec_[i].passwd() == passwd) {
+#ifdef DEBUG_ME
+                cout << "      PasswdFile::authenticate user and password match: PASS\n";
+#endif
+                return true;
+            }
+            else {
+#ifdef DEBUG_ME
+                cout << "      PasswdFile::authenticate: user found but passwd did not match: FAIL\n";
+#endif
+                return false;
+            }
+        }
+    }
+
+    // Will ONLY reach here if user not found
+
+    // User not found, but if passwd is not empty, then fail.
+    if (!passwd.empty()) {
+#ifdef DEBUG_ME
+        cout << "      PasswdFile::authenticate: user NOT found, passwd is NOT EMPTY: FAIL\n";
+#endif
+        return false;
+    }
+
+    // Server has a password file, but user not found and passwd is empty.
+    if (vec_.empty()) {
+#ifdef DEBUG_ME
+        cout << "      PasswdFile::authenticate: true, user NOT found, and passwd EMPTY, and password file EMPTY\n";
+#endif
+        return true;
+    }
+
+#ifdef DEBUG_ME
+    cout << "      PasswdFile::authenticate false, user NOT found, and passwd EMPTY\n";
+#endif
+    return false;
+}
+
+bool PasswdFile::validateVersionNumber(const std::string& line, std::string& errorMsg) const {
+    // Expect 4.5.0
+    // If first character is NUMERIC and we have dots
+    bool firstCharIsNumeric = Str::NUMERIC().find(line[0], 0) != string::npos;
+    if (firstCharIsNumeric && line.find(".") != string::npos) {
+
+        std::vector<std::string> versionNumberTokens;
+        Str::split(line, versionNumberTokens, ".");
+        if (versionNumberTokens.size() != 3) {
+            std::stringstream ss;
+            ss << "Expected version of the form <int>.<int>.<int> i.e 4.4.0. but found invalid version number\n";
+            errorMsg += ss.str();
+            return false;
+        }
+
+        try {
+            auto major = ecf::convert_to<int>(versionNumberTokens[0]);
+            auto minor = ecf::convert_to<int>(versionNumberTokens[1]);
+            auto part  = ecf::convert_to<int>(versionNumberTokens[2]);
+            if (major < 4) {
+                errorMsg += "Only passwd files with a version >= 4.5.0 is supported\n";
+                return false;
+            }
+            if (major == 4 && minor < 5) {
+                errorMsg += "Only passwd files with a version >= 4.5.0 is supported\n";
+                return false;
+            }
+            if (major == 4 && minor == 5 && part > 0) {
+                errorMsg += "Only passwd files with a version >= 4.5.0 is supported\n";
+                return false;
+            }
+        }
+        catch (const ecf::bad_conversion&) {
+            errorMsg += "Invalid version number \n";
+            return false;
+        }
+
+        return true;
+    }
+
+    errorMsg += "The version number not found. The version number must appear before the users.\n";
+    return false;
+}
+
+bool PasswdFile::add_user(std::vector<std::string>& tokens, std::string& error_msg) {
+    // Expected format is:
+    // 4.5.0
+    // # comment
+    // <user> <host> <port> <passwd> # comment
+    // <user> <host> <port> <passwd> # comment
+
+    if (tokens.size() < 4) {
+        error_msg = "expected <user> <host> <port> <passwd> # comment\n";
+        return false;
+    }
+
+    try {
+        ecf::convert_to<int>(tokens[2]);
+    }
+    catch (const ecf::bad_conversion&) {
+        error_msg += "Port number must be integer's\n";
+        return false;
+    }
+
+    vec_.emplace_back(tokens[0], tokens[1], tokens[2], PasswordEncryption::encrypt(tokens[3], tokens[0]));
+
+    return true;
+}
+
+std::string PasswdFile::dump() const {
+    std::stringstream ss;
+    int count = 1;
+    for (const auto& i : vec_) {
+        ss << count << ": " << i.user() << " " << i.host() << " " << i.port() << "\n";
+        count++;
+    }
+    return ss.str();
+}
+
+bool PasswdFile::createWithAccess(const std::string& pathToFile,
+                                  const std::string& host,
+                                  const std::string& port,
+                                  const std::string& passwd,
+                                  std::string& errorMsg) {
+    std::vector<std::string> lines;
+    lines.reserve(3);
+
+    lines.emplace_back("4.5.0");
+
+    string line;
+    line += User::login_name();
+    line += " ";
+    line += host;
+    line += " ";
+    line += port;
+    line += " ";
+    line += passwd;
+    lines.push_back(line);
+
+    line.clear();
+    line += User::login_name();
+    line += " ";
+    line += Str::LOCALHOST();
+    line += " ";
+    line += port;
+    line += " ";
+    line += passwd;
+    lines.push_back(line);
+
+    return File::create(pathToFile, lines, errorMsg);
+}
+
+bool PasswdFile::clear(const std::string& pathToFile, std::string& errorMsg) {
+    std::vector<std::string> lines;
+    if (File::splitFileIntoLines(pathToFile, lines, true /* ignore empty lines */)) {
+        // Just leave the version, i.e. the first line.
+        if (lines.size() > 1) {
+            lines.erase(lines.begin() + 1, lines.end());
+
+            // Overwrite the file.
+            return File::create(pathToFile, lines, errorMsg);
+        }
+        return true;
+    }
+    errorMsg += "PasswdFile::clear: Could not open file ";
+    errorMsg += pathToFile;
+    errorMsg += " (";
+    errorMsg += strerror(errno);
+    errorMsg += ")";
+    return false;
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/PasswdFile.hpp 5.13.0-1/libs/core/src/ecflow/core/PasswdFile.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/PasswdFile.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/PasswdFile.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,97 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_PasswdFile_HPP
+#define ecflow_core_PasswdFile_HPP
+
+///
+/// \brief Parser for password file
+///
+
+#include <string>
+#include <vector>
+
+// ----------------------------------------------------------------
+//
+class Pass_wd {
+public:
+    Pass_wd(const std::string& user, const std::string& host, const std::string& port, const std::string& passwd)
+        : user_(user),
+          host_(host),
+          port_(port),
+          passwd_(passwd) {}
+    ~Pass_wd() = default;
+
+    bool operator==(const Pass_wd& rhs) const {
+        return rhs.user_ == user_ && rhs.host_ == host_ && rhs.port_ == port_ && rhs.passwd_ == passwd_;
+    }
+    const std::string& user() const { return user_; }
+    const std::string& host() const { return host_; }
+    const std::string& port() const { return port_; }
+    const std::string& passwd() const { return passwd_; }
+
+private:
+    std::string user_;
+    std::string host_;
+    std::string port_;
+    std::string passwd_; // always stored as ciphertext
+};
+
+// This class is used to authenticate, user commands, i.e. like ping,alter, etc
+class PasswdFile {
+public:
+    PasswdFile();
+    // Disable copy (and move) semantics
+    PasswdFile(const PasswdFile&)                  = delete;
+    const PasswdFile& operator=(const PasswdFile&) = delete;
+
+    ~PasswdFile();
+
+    bool empty() const { return vec_.empty(); }
+
+    // Parse the file if any errors found return false and errorMsg
+    // The parser expects version number  4.5.0
+    bool load(const std::string& file, bool debug, std::string& errorMsg);
+
+    // to be called by the server, to at least one user with given host and port
+    bool check_at_least_one_user_with_host_and_port(const std::string& host, const std::string& port);
+
+    // get the password for the given user, host and port. Otherwise, return an empty string
+    std::string get_passwd(const std::string& user, const std::string& host, const std::string& port);
+
+    // authenticate the user, given the password.
+    bool authenticate(const std::string& user, const std::string& passwd) const;
+
+    // ===========================================================================
+    // For test/debug
+
+    // Will overwrite the existing file
+    static bool createWithAccess(const std::string& pathToFile,
+                                 const std::string& host,
+                                 const std::string& port,
+                                 const std::string& passwd,
+                                 std::string& errorMsg);
+
+    // Open password file and make it empty
+    static bool clear(const std::string& pathToFile, std::string& errorMsg);
+
+    const std::vector<Pass_wd>& passwds() const { return vec_; }
+    std::string dump() const;
+
+private:
+    bool add_user(std::vector<std::string>& tokens, std::string& error_msg);
+    bool validateVersionNumber(const std::string& line, std::string& errorMsg) const;
+
+private:
+    std::string passwd_file_;
+    std::vector<Pass_wd> vec_;
+};
+
+#endif /* ecflow_core_PasswdFile_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/PasswordEncryption.hpp 5.13.0-1/libs/core/src/ecflow/core/PasswordEncryption.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/PasswordEncryption.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/PasswordEncryption.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,51 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_PasswordEncryption_HPP
+#define ecflow_core_PasswordEncryption_HPP
+
+///
+/// \brief Provides a generic password encryption mechanism + specific POSIX implementation
+///
+
+#include <stdexcept>
+#include <string>
+#include <unistd.h>
+
+struct PosixEncryption
+{
+    using salt_t      = std::string;
+    using key_t       = std::string;
+    using encrypted_t = std::string;
+
+    static encrypted_t encrypt(const key_t& key, const salt_t& salt) {
+        auto result = crypt(key.c_str(), salt.c_str());
+        if (!result) {
+            throw std::runtime_error("Error: unable to encrypt the given key");
+        }
+        return std::string{result};
+    }
+};
+
+template <typename ENGINE>
+struct BasePasswordEncryption
+{
+    using username_t           = std::string;
+    using plain_password_t     = std::string;
+    using encrypted_password_t = std::string;
+
+    static encrypted_password_t encrypt(const plain_password_t& password, const username_t& username) {
+        return ENGINE::encrypt(password, username);
+    }
+};
+
+using PasswordEncryption = BasePasswordEncryption<PosixEncryption>;
+
+#endif /* ecflow_core_PasswordEncryption_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Pid.cpp 5.13.0-1/libs/core/src/ecflow/core/Pid.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Pid.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Pid.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,34 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Pid.hpp"
+
+#include <stdexcept>
+#include <unistd.h> // for getpid
+
+#include "ecflow/core/Converter.hpp"
+
+std::string Pid::getpid() {
+    std::string pid;
+    try {
+        pid = ecf::convert_to<std::string>(::getpid());
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error("Pid::getpid(): Could not convert PID to a string\n");
+    }
+    return pid;
+}
+
+std::string Pid::unique_name(const std::string& prefix) {
+    std::string ret = prefix;
+    ret += "_";
+    ret += Pid::getpid();
+    return ret;
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Pid.hpp 5.13.0-1/libs/core/src/ecflow/core/Pid.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Pid.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Pid.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Pid_HPP
+#define ecflow_core_Pid_HPP
+
+#include <string>
+
+class Pid {
+public:
+    // Disable default construction
+    Pid() = delete;
+    // Disable copy (and move) semantics
+    Pid(const Pid&)                  = delete;
+    const Pid& operator=(const Pid&) = delete;
+
+    /// Returns the current Process ID (as a string); otherwise, throws exception(std::runtime_error)
+    static std::string getpid();
+
+    /// Returns a unique name, based on Process ID, composed of prefix + '_' + getpid();
+    /// otherwise, throws exception(std::runtime_error)
+    static std::string unique_name(const std::string& prefix);
+};
+
+#endif /* ecflow_core_Pid_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/PrintStyle.cpp 5.13.0-1/libs/core/src/ecflow/core/PrintStyle.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/PrintStyle.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/PrintStyle.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,75 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/PrintStyle.hpp"
+
+#include "ecflow/core/Enumerate.hpp"
+
+namespace ecf::detail {
+
+template <>
+struct EnumTraits<PrintStyle::Type_t>
+{
+    using underlying_t = std::underlying_type_t<PrintStyle::Type_t>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(PrintStyle::Type_t::NOTHING, "NOTHING"),
+        std::make_pair(PrintStyle::Type_t::DEFS, "DEFS"),
+        std::make_pair(PrintStyle::Type_t::STATE, "STATE"),
+        std::make_pair(PrintStyle::Type_t::MIGRATE, "MIGRATE"),
+        std::make_pair(PrintStyle::Type_t::NET, "NET"),
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<PrintStyle::Type_t>::size == map.back().first + 1);
+};
+
+} // namespace ecf::detail
+
+static PrintStyle::Type_t style_ = PrintStyle::NOTHING;
+
+PrintStyle::Type_t PrintStyle::getStyle() {
+    return style_;
+}
+
+void PrintStyle::setStyle(PrintStyle::Type_t f) {
+    style_ = f;
+}
+
+bool PrintStyle::defsStyle() {
+    if (getStyle() == PrintStyle::DEFS || getStyle() == PrintStyle::NOTHING) {
+        return true;
+    }
+    return false;
+}
+
+bool PrintStyle::persist_style() {
+    if (getStyle() == PrintStyle::MIGRATE || getStyle() == PrintStyle::NET) {
+        return true;
+    }
+    return false;
+}
+
+bool PrintStyle::is_persist_style(PrintStyle::Type_t t) {
+    if (t == PrintStyle::MIGRATE || t == PrintStyle::NET) {
+        return true;
+    }
+    return false;
+}
+
+std::string PrintStyle::to_string() {
+    return to_string(getStyle());
+}
+
+std::string PrintStyle::to_string(PrintStyle::Type_t t) {
+    return std::string{ecf::Enumerate<PrintStyle::Type_t>::to_string(t).value_or("")};
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/PrintStyle.hpp 5.13.0-1/libs/core/src/ecflow/core/PrintStyle.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/PrintStyle.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/PrintStyle.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,66 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_PrintStyle_HPP
+#define ecflow_core_PrintStyle_HPP
+
+#include <string>
+
+class PrintStyle {
+public:
+    // Use to control the print defs/node output to string or file
+    // Please note: with PrintStyle::NET is used to transfer Defs between client <-> server
+    //              as such there is no need extensive checking on recreating defs.
+    //              i.e. valid name, duplicate nodes, etc
+    enum Type_t {
+        // Does nothing
+        NOTHING = 0,
+
+        // Output the definition that is fully parse-able                       -> On reload *CHECK* everything
+        DEFS = 1,
+
+        // Output definition that includes Node state, and AST, fully parseable -> On reload *CHECK* everything
+        STATE = 2,
+
+        // Output the definition that is fully parse-able & includes state      -> On reload *CHECK* everything
+        MIGRATE = 3,
+
+        // Output the definition that is fully parse-able & includes state      -> On reload relax checking
+        NET = 4
+    };
+
+    explicit PrintStyle(Type_t t) : old_style_(getStyle()) { setStyle(t); }
+
+    // Disable default construction
+    PrintStyle() = delete;
+    // Disable copy (and move) semantics
+    PrintStyle(const PrintStyle&)            = delete;
+    PrintStyle& operator=(const PrintStyle&) = delete;
+
+    ~PrintStyle() { setStyle(old_style_); } // reset to old style on destruction
+
+    /// We want to control the output, so that we can dump in old style defs format
+    /// or choose to dump for debug.
+    static Type_t getStyle();
+    static void setStyle(Type_t);
+
+    static bool defsStyle();
+    static bool persist_style();
+    static bool is_persist_style(Type_t);
+
+    // return current style as a string
+    static std::string to_string();
+    static std::string to_string(PrintStyle::Type_t);
+
+private:
+    Type_t old_style_;
+};
+
+#endif /* ecflow_core_PrintStyle_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/SState.cpp 5.13.0-1/libs/core/src/ecflow/core/SState.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/SState.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/SState.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/SState.hpp"
+
+#include <cassert>
+
+#include "ecflow/core/Enumerate.hpp"
+
+namespace ecf::detail {
+
+template <>
+struct EnumTraits<SState::State>
+{
+    using underlying_t = std::underlying_type_t<SState::State>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(SState::State::HALTED, "HALTED"),
+        std::make_pair(SState::State::SHUTDOWN, "SHUTDOWN"),
+        std::make_pair(SState::State::RUNNING, "RUNNING")
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<SState::State>::size == map.back().first + 1);
+};
+
+} // namespace ecf::detail
+
+std::string SState::to_string(int status) {
+    return to_string(static_cast<SState::State>(status));
+}
+
+std::string SState::to_string(SState::State state) {
+    if (auto found = ecf::Enumerate<SState::State>::to_string(state); found) {
+        return std::string{found.value()};
+    }
+    return "UNKNOWN??";
+}
+
+SState::State SState::toState(const std::string& str) {
+    if (auto found = ecf::Enumerate<SState::State>::to_enum(str); found) {
+        return found.value();
+    }
+    assert(false);
+    return SState::HALTED;
+}
+
+bool SState::isValid(const std::string& state) {
+    return ecf::Enumerate<SState::State>::is_valid(state);
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/SState.hpp 5.13.0-1/libs/core/src/ecflow/core/SState.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/SState.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/SState.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_SState_HPP
+#define ecflow_core_SState_HPP
+
+#include <string>
+
+class SState {
+public:
+    /// The following table shows the effect of state, on server behaviour:
+    ///
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    enum State { HALTED, SHUTDOWN, RUNNING };
+
+    // Disable default construction
+    SState() = delete;
+    // Disable copy (and move) semantics
+    SState(const SState&)                  = delete;
+    const SState& operator=(const SState&) = delete;
+
+    /// Given an integer return the server state as a string.
+    /// if int is not  0,1,2 return "UNKNOWN
+    static std::string to_string(int status);
+    static std::string to_string(SState::State);
+
+    static SState::State toState(const std::string&);
+    static bool isValid(const std::string&);
+};
+
+#endif /* ecflow_core_SState_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Serialization.hpp 5.13.0-1/libs/core/src/ecflow/core/Serialization.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Serialization.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Serialization.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,90 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Serialization_HPP
+#define ecflow_core_Serialization_HPP
+
+///
+/// \brief Simple class that defines the Archive types used for Serialisation
+///
+
+#include <fstream>
+#include <iostream>
+#include <string>
+
+#include <cereal/archives/json.hpp>
+#include <cereal/types/deque.hpp>
+#include <cereal/types/map.hpp>
+#include <cereal/types/memory.hpp>
+#include <cereal/types/set.hpp>
+#include <cereal/types/utility.hpp>
+#include <cereal/types/vector.hpp>
+
+#include "ecflow/core/cereal_optional_nvp.hpp"
+
+namespace ecf {
+
+template <typename T>
+void save(const std::string& fileName, const T& t) {
+    std::ofstream os(fileName);
+#ifdef DEBUG
+    cereal::JSONOutputArchive oarchive(os); // Use default Indent can be very slow
+#else
+    cereal::JSONOutputArchive oarchive(os, cereal::JSONOutputArchive::Options::NoIndent()); // Create an output archive
+#endif
+    oarchive(cereal::make_nvp(typeid(t).name(), t)); // Write the data to the archive
+}
+
+template <typename T>
+void restore(const std::string& fileName, T& restored) {
+    std::ifstream is(fileName);
+    cereal::JSONInputArchive iarchive(is); // Create an input archive
+    iarchive(restored);                    // Read the data from the archive
+}
+
+template <typename T>
+void save_as_string(std::string& outbound_data, const T& t) {
+    std::ostringstream archive_stream;
+    {
+#ifdef DEBUG
+        cereal::JSONOutputArchive oarchive(archive_stream); // Use default Indent can be very slow
+#else
+        cereal::JSONOutputArchive oarchive(archive_stream,
+                                           cereal::JSONOutputArchive::Options::NoIndent()); // Create an output archive
+#endif
+        // when archive goes out of scope it is guaranteed to have flushed its
+        // contents to its stream.
+        oarchive(cereal::make_nvp(typeid(t).name(), t)); // Write the data to the archive
+    }
+    outbound_data = archive_stream.str();
+}
+
+template <typename T>
+void restore_from_string(const std::string& archive_data, T& restored) {
+    std::istringstream archive_stream(archive_data);
+    cereal::JSONInputArchive iarchive(archive_stream); // Create an input archive
+    iarchive(restored);                                // Read the data from the archive
+}
+
+} // namespace ecf
+
+//// Place archive in CPP file requires we template specialize the archives
+//// Note that we need to instantiate for both loading and saving, even
+//// if we use a single serialize function
+#define CEREAL_TEMPLATE_SPECIALIZE(T)                                                  \
+    template void T::serialize<cereal::JSONOutputArchive>(cereal::JSONOutputArchive&); \
+    template void T::serialize<cereal::JSONInputArchive>(cereal::JSONInputArchive&)
+
+#define CEREAL_TEMPLATE_SPECIALIZE_V(T)                                                     \
+    template void T::serialize<cereal::JSONOutputArchive>(cereal::JSONOutputArchive&,       \
+                                                          std::uint32_t const /*version*/); \
+    template void T::serialize<cereal::JSONInputArchive>(cereal::JSONInputArchive&, std::uint32_t const /*version*/)
+
+#endif
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Stl.hpp 5.13.0-1/libs/core/src/ecflow/core/Stl.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Stl.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Stl.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,106 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Stl_HPP
+#define ecflow_core_Stl_HPP
+
+#include <algorithm>
+#include <memory>
+
+namespace ecf {
+/// Helper struct that will aid the deletion of Pointer from a container
+template <typename T>
+struct TSeqDeletor
+{
+    void operator()(T pointer) const {
+        // std::cout << "Destroy of this pointer" << std::endl;
+        delete pointer;
+        pointer = 0;
+    }
+};
+/// This function can be used to delete the pointers in a container
+/// i.e int main (int argc, char **argv) {
+///        std::vector <std::string *> vect;
+///        vect.push_back (new std::string ("Stephane"));
+///        DeletePtrs (vect);
+///     }
+template <typename Container>
+void DeletePtrs(Container& pContainer) {
+    std::for_each(pContainer.begin(), pContainer.end(), TSeqDeletor<typename Container::value_type>());
+    pContainer.clear();
+}
+
+/// Helper struct that will aid the deletion of Pointer from a Associative container
+template <typename TPair>
+struct TAsoDeletor
+{
+    void operator()(TPair& tElem) const {
+        if (tElem.second) {
+            delete tElem.second;
+        }
+    }
+};
+/// This function can be used to delete the pointers in a Assoc container
+/// i.e int main (int argc, char **argv) {
+///        std::map <int,std::string *> theMap;
+///        theMap[0] =  new std::string ("Stephane");
+///        AssoDeletePtrs(theMap);
+///     }
+template <typename Container>
+void AssoDeletePtrs(Container& pContainer) {
+    std::for_each(pContainer.begin(), pContainer.end(), TAsoDeletor<typename Container::value_type>());
+    pContainer.clear();
+}
+
+namespace algorithm {
+
+namespace detail {
+
+template <typename T>
+struct is_shared_pointer : std::false_type
+{
+};
+
+template <typename T>
+struct is_shared_pointer<std::shared_ptr<T>> : std::true_type
+{
+};
+
+} // namespace detail
+
+template <typename T>
+constexpr bool is_shared_pointer_v = detail::is_shared_pointer<T>::value;
+
+template <typename C, typename Predicate>
+inline auto find_by(C& container, Predicate predicate) {
+    return std::find_if(std::begin(container), std::end(container), predicate);
+}
+
+template <typename C>
+inline auto find_by_name(C& container, std::string_view name) {
+    // Important: special handling to seamlessly handle containers of std::shared_ptr.
+    if constexpr (is_shared_pointer_v<typename C::value_type>) {
+        return find_by(container, [&](const auto& item) { return item->name() == name; });
+    }
+    else {
+        return find_by(container, [&](const auto& item) { return item.name() == name; });
+    }
+}
+
+template <typename C, typename I>
+inline auto find_by_number(C& container, I number) {
+    return find_by(container, [&](const auto& item) { return item.number() == number; });
+}
+
+} // namespace algorithm
+
+} // namespace ecf
+
+#endif /* ecflow_core_Stl_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Str.cpp 5.13.0-1/libs/core/src/ecflow/core/Str.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Str.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Str.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,614 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Str.hpp"
+
+#include "ecflow/core/Converter.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+const char* VALID_NODE_CHARS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_.";
+
+const char* Str::CHILD_CMD() {
+    static const char* CHILD_CMD = "chd:";
+    return CHILD_CMD;
+}
+const char* Str::USER_CMD() {
+    static const char* USER_CMD = "--";
+    return USER_CMD;
+}
+const char* Str::SVR_CMD() {
+    static const char* SVR_CMD = "svr:";
+    return SVR_CMD;
+} // Only for automatic check_pt
+
+const std::string& Str::EMPTY() {
+    static std::string empty = std::string();
+    return empty;
+}
+const std::string& Str::ROOT_PATH() {
+    static std::string root_path = "/";
+    return root_path;
+}
+const std::string& Str::PATH_SEPERATOR() {
+    static std::string path_sep = "/";
+    return path_sep;
+}
+const std::string& Str::COLON() {
+    static std::string colon = ":";
+    return colon;
+}
+
+const std::string& Str::STATE_CHANGE() {
+    static std::string state_change = "   state change ";
+    return state_change;
+}
+
+const std::string& Str::TASK() {
+    static std::string task = "TASK";
+    return task;
+}
+const std::string& Str::FAMILY() {
+    static std::string family = "FAMILY";
+    return family;
+}
+const std::string& Str::SUITE() {
+    static std::string suite = "SUITE";
+    return suite;
+}
+const std::string& Str::ALIAS() {
+    static std::string alias = "ALIAS";
+    return alias;
+}
+
+const std::string& Str::DEFAULT_PORT_NUMBER() {
+    static std::string port_number = "3141";
+    return port_number;
+}
+const std::string& Str::LOCALHOST() {
+    static std::string localhost = "localhost";
+    return localhost;
+}
+
+const std::string& Str::ECF_PORT() {
+    static std::string ECF_PORT = "ECF_PORT";
+    return ECF_PORT;
+}
+const std::string& Str::ECF_RID() {
+    static std::string ECF_RID = "ECF_RID";
+    return ECF_RID;
+}
+const std::string& Str::ECF_TRYNO() {
+    static std::string ECF_TRYNO = "ECF_TRYNO";
+    return ECF_TRYNO;
+}
+const std::string& Str::ECF_TRIES() {
+    static std::string ECF_TRIES = "ECF_TRIES";
+    return ECF_TRIES;
+}
+const std::string& Str::ECF_NAME() {
+    static std::string ECF_NAME = "ECF_NAME";
+    return ECF_NAME;
+}
+const std::string& Str::ECF_HOST() {
+    static std::string ECF_HOST = "ECF_HOST";
+    return ECF_HOST;
+}
+const std::string& Str::ECF_PASS() {
+    static std::string ECF_PASS = "ECF_PASS";
+    return ECF_PASS;
+}
+const std::string& Str::ECF_JOB() {
+    static std::string ECF_JOB = "ECF_JOB";
+    return ECF_JOB;
+}
+const std::string& Str::ECF_JOBOUT() {
+    static std::string ECF_JOBOUT = "ECF_JOBOUT";
+    return ECF_JOBOUT;
+}
+const std::string& Str::ECF_SCRIPT() {
+    static std::string ECF_SCRIPT = "ECF_SCRIPT";
+    return ECF_SCRIPT;
+}
+const std::string& Str::ECF_DUMMY_TASK() {
+    static std::string ECF_DUMMY_TASK = "ECF_DUMMY_TASK";
+    return ECF_DUMMY_TASK;
+}
+const std::string& Str::ECF_NO_SCRIPT() {
+    static std::string ECF_NO_SCRIPT = "ECF_NO_SCRIPT";
+    return ECF_NO_SCRIPT;
+}
+const std::string& Str::ECF_MICRO() {
+    static std::string ECF_MICRO = "ECF_MICRO";
+    return ECF_MICRO;
+}
+const std::string& Str::ECF_FILES() {
+    static std::string ECF_FILES = "ECF_FILES";
+    return ECF_FILES;
+}
+const std::string& Str::ECF_FETCH() {
+    static std::string ECF_FETCH = "ECF_FETCH";
+    return ECF_FETCH;
+}
+const std::string& Str::ECF_KILL_CMD() {
+    static std::string ECF_KILL_CMD = "ECF_KILL_CMD";
+    return ECF_KILL_CMD;
+}
+const std::string& Str::ECF_STATUS_CMD() {
+    static std::string ECF_STATUS_CMD = "ECF_STATUS_CMD";
+    return ECF_STATUS_CMD;
+}
+
+const std::string& Str::ECF_HOME() {
+    static std::string ECF_HOME = "ECF_HOME";
+    return ECF_HOME;
+}
+const std::string& Str::ECF_INCLUDE() {
+    static std::string ECF_INCLUDE = "ECF_INCLUDE";
+    return ECF_INCLUDE;
+}
+const std::string& Str::ECF_JOB_CMD() {
+    static std::string ECF_JOB_CMD = "ECF_JOB_CMD";
+    return ECF_JOB_CMD;
+}
+const std::string& Str::ECF_OUT() {
+    static std::string ECF_OUT = "ECF_OUT";
+    return ECF_OUT;
+}
+const std::string& Str::ECF_EXTN() {
+    static std::string ECF_EXTN = "ECF_EXTN";
+    return ECF_EXTN;
+}
+const std::string& Str::ECF_LOG() {
+    static std::string ECF_LOG = "ECF_LOG";
+    return ECF_LOG;
+}
+
+const std::string& Str::WHITE_LIST_FILE() {
+    static std::string WHITE_LIST_FILE = "ecf.lists";
+    return WHITE_LIST_FILE;
+}
+const std::string& Str::ECF_PASSWD() {
+    static std::string ECF_PASSWD = "ecf.passwd";
+    return ECF_PASSWD;
+}
+const std::string& Str::ECF_CUSTOM_PASSWD() {
+    static std::string ECF_CUSTOM_PASSWD = "ecf.custom_passwd";
+    return ECF_CUSTOM_PASSWD;
+}
+
+const std::string& Str::ALPHANUMERIC_UNDERSCORE() {
+    static string ALPHANUMERIC_UNDERSCORE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_";
+    return ALPHANUMERIC_UNDERSCORE;
+}
+
+const std::string& Str::NUMERIC() {
+    static string NUMERIC = "0123456789";
+    return NUMERIC;
+}
+
+void Str::removeQuotes(std::string& s) {
+    if (!s.empty()) {
+        if (s[0] == '"' && s[s.size() - 1] == '"') {
+            s.erase(s.begin());
+            s.erase(s.begin() + s.size() - 1);
+        }
+    }
+}
+// 047 is octal for '
+void Str::removeSingleQuotes(std::string& s) {
+    if (!s.empty()) {
+        if (s[0] == 047 && s[s.size() - 1] == 047) {
+            s.erase(s.begin());
+            s.erase(s.begin() + s.size() - 1);
+        }
+    }
+}
+
+bool Str::replace(std::string& jobLine, const std::string& stringToFind, const std::string& stringToReplace) {
+    size_t pos = jobLine.find(stringToFind);
+    if (pos != string::npos) {
+        jobLine.replace(pos, stringToFind.length(), stringToReplace);
+        return true;
+    }
+    return false;
+}
+
+bool Str::replace_all(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace) {
+    bool replaced = false;
+    size_t pos    = 0;
+    while ((pos = subject.find(stringToFind, pos)) != std::string::npos) {
+        subject.replace(pos, stringToFind.length(), stringToReplace);
+        pos += stringToReplace.length();
+        replaced = true;
+    }
+    return replaced;
+}
+
+bool Str::extract_data_member_value(const std::string& str,
+                                    const std::string& data_member_name,
+                                    std::string& data_member_value) {
+    //        012345678901234567,
+    //    str=cmd 1 user:mao
+    //    data_member_name=user:
+    //    data_member_value=ma0
+    std::string::size_type start = str.find(data_member_name);
+    if (start != std::string::npos) {
+        start += data_member_name.size();
+        data_member_value.clear();
+        for (size_t i = start; i < str.size(); i++) {
+            if (str[i] == ' ')
+                break;
+            data_member_value += str[i];
+        }
+        return true;
+    }
+    return false;
+}
+
+void Str::replaceall(std::string& subject, const std::string& search, const std::string& replace) {
+    boost::replace_all(subject, search, replace);
+}
+
+#define USE_STRINGSPLITTER 1
+void Str::split(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters) {
+#ifdef USE_STRINGSPLITTER
+    Str::split_using_string_view(line, tokens, delimiters);
+#else
+    Str::split_orig(line, tokens, delimiters);
+#endif
+    //   This test will split a line 1000000 times: 'This is a long string that is going to be used to test the
+    //   performance of splitting with different Implementations the fastest times wins ' Time for istreamstream 1000000
+    //   times = 2.131s wall, (2.140s user + 0.000s system = 2.140s) CPU (100.4%) Time for std::getline 1000000 times
+    //   = 1.490s wall, (1.490s user + 0.000s system = 1.490s) CPU (100.0%) Time for boost::split 1000000 times = 0.930s
+    //   wall, (0.920s user + 0.000s system = 0.920s) CPU (99.0%) Time for Str::split_orig 1000000               times
+    //   = 1.065s wall, (1.070s user + 0.000s system = 1.070s) CPU (100.5%) Time for Str::split_orig1 1000000 times =
+    //   0.561s wall, (0.560s user + 0.000s system = 0.560s) CPU (99.9%) Time for Str::split_using_string_view2 1000000
+    //   times = 0.686s wall, (0.690s user + 0.000s system = 0.690s) CPU (100.6%) Time for Str::split_using_string_view
+    //   1000000  times = 0.482s wall, (0.480s user + 0.000s system = 0.480s) CPU (99.6%) Time for
+    //   make_split_iterator::split 1000000    times = 3.611s wall, (3.610s user + 0.000s system = 3.610s) CPU (100.0%)
+    //   Time for std::string_view 1000000            times = 0.769s wall, (0.770s user + 0.000s system = 0.770s) CPU
+    //   (100.1%) Time for std::string_view(2) 1000000         times = 0.688s wall, (0.690s user + 0.000s system =
+    //   0.690s) CPU (100.3%)
+    //  ACore:: ...test_str_split_perf_with_file
+    //   This test will split each line in file ${ECF_TEST_DEFS_DIR}vsms2.31415.def
+    //   Time for istreamstream 2001774                 times = 1.567s wall, (1.570s user + 0.000s system = 1.570s) CPU
+    //   (100.2%) Time for std::getline 2001774                  times = 2.456s wall, (2.460s user + 0.000s system
+    //   = 2.460s) CPU (100.2%) Time for boost::split 2001774                  times = 1.698s wall, (1.690s user +
+    //   0.000s system = 1.690s) CPU (99.5%) Time for Str::split_orig 2001774               times = 0.822s wall, (0.830s
+    //   user + 0.000s system = 0.830s) CPU (101.0%) Time for Str::split_orig1 2001774              times = 0.502s wall,
+    //   (0.500s user + 0.000s system = 0.500s) CPU (99.7%) Time for Str::split_using_string_view 2001774  times =
+    //   0.489s wall, (0.490s user + 0.000s system = 0.490s) CPU (100.3%) Time for Str::split_using_string_view2 2001774
+    //   times = 0.639s wall, (0.630s user + 0.000s system = 0.630s) CPU (98.6%) Time for boost::make_split_iterator
+    //   2001774    times = 3.338s wall, (3.340s user + 0.000s system = 3.340s) CPU (100.1%) Time for std::string_view
+    //   2001774            times = 0.599s wall, (0.600s user + 0.000s system = 0.600s) CPU (100.1%) Time for
+    //   std::string_view(2) 2001774         times = 0.696s wall, (0.700s user + 0.000s system = 0.700s) CPU (100.6%)
+}
+
+void Str::split_orig(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters) {
+    // Skip delimiters at beginning.
+    string::size_type lastPos = line.find_first_not_of(delimiters, 0);
+
+    // Find first "non-delimiter".
+    string::size_type pos = line.find_first_of(delimiters, lastPos);
+
+    while (string::npos != pos || string::npos != lastPos) {
+        tokens.push_back(line.substr(lastPos, pos - lastPos)); // Found a token, add it to the vector.
+        lastPos = line.find_first_not_of(delimiters, pos);     // Skip delimiters.  Note the "not_of"
+        pos     = line.find_first_of(delimiters, lastPos);     // Find next "non-delimiter"
+    }
+}
+
+void Str::split_orig1(const std::string& line, std::vector<std::string>& tokens, const std::string& delims) {
+    auto first = std::cbegin(line);
+    auto end   = std::cend(line);
+
+    while (first != end) {
+        const auto second = std::find_first_of(first, end, std::cbegin(delims), std::cend(delims));
+
+        if (first != second)
+            tokens.emplace_back(first, second);
+
+        if (second == end)
+            break;
+
+        first = std::next(second);
+    }
+}
+
+void Str::split_using_string_view(std::string_view strv, std::vector<std::string>& output, std::string_view delims) {
+    // Uses pointers
+    for (auto first = strv.data(), second = strv.data(), last = first + strv.size(); second != last && first != last;
+         first = second + 1) {
+        second = std::find_first_of(first, last, std::cbegin(delims), std::cend(delims));
+
+        if (first != second)
+            output.emplace_back(first, second - first);
+    }
+}
+
+void Str::split_using_string_view2(std::string_view strv, std::vector<std::string>& output, std::string_view delims) {
+    size_t first = 0;
+
+    size_t strv_size = strv.size();
+    while (first < strv_size) {
+        const auto second = strv.find_first_of(delims, first);
+
+        if (first != second) {
+            std::string_view ref = strv.substr(first, second - first);
+            output.emplace_back(ref.begin(), ref.end());
+        }
+
+        if (second == std::string_view::npos)
+            break;
+
+        first = second + 1;
+    }
+}
+
+std::vector<std::string_view> Str::tokenize_quotation(const std::string& s, std::string_view quotes) {
+
+    std::vector<std::string_view> tokens;
+
+    std::string levels;
+
+    const char* current = &s[0];
+    const char* start   = current;
+    while (*current != 0) {
+        if (*current == ' ' && levels.empty()) {
+            if (start != current) {
+                tokens.emplace_back(start, static_cast<size_t>(current - start));
+            }
+            start = current + 1;
+        }
+        else {
+            if (std::any_of(
+                    std::begin(quotes), std::end(quotes), [&current](char quote) { return *current == quote; })) {
+                if (!levels.empty() && (levels.back() == *current)) {
+                    levels.pop_back();
+                }
+                else {
+                    if (levels.empty()) {
+                        start = current;
+                    }
+                    levels.push_back(*current);
+                }
+            }
+        }
+        ++current;
+    }
+
+    if (start != current) {
+        tokens.emplace_back(start, static_cast<size_t>(current - start));
+    }
+
+    return tokens;
+}
+
+bool Str::get_token(std::string_view str, size_t pos, std::string& token, std::string_view delims) {
+    //   Time for StringSplitter::get_token 250000 times = 1.457s wall, (1.460s user + 0.000s system = 1.460s) CPU
+    //   (100.2%) Time for Str::get_token            250000 times = 0.566s wall, (0.560s user + 0.000s system = 0.560s)
+    //   CPU (99.0%) Time for Str::get_token2           250000 times = 0.668s wall, (0.670s user + 0.000s system =
+    //   0.670s) CPU (100.3%) Time for Str::get_token3           250000 times = 0.620s wall, (0.620s user + 0.000s
+    //   system = 0.620s) CPU (100.0%)
+
+    size_t current_pos = 0;
+    auto first         = std::cbegin(str);
+    auto end           = std::cend(str);
+
+    while (first != end) {
+        const auto second = std::find_first_of(first, end, std::cbegin(delims), std::cend(delims));
+
+        if (first != second) {
+            if (current_pos == pos) {
+                token = std::string(first, second);
+                return true;
+            }
+            current_pos++;
+        }
+
+        if (second == end)
+            break;
+
+        first = std::next(second);
+    }
+    return false;
+}
+
+bool Str::get_token2(std::string_view strv, size_t pos, std::string& token, std::string_view delims) {
+    size_t current_pos = 0;
+    size_t first       = 0;
+    while (first < strv.size()) {
+        const auto second = strv.find_first_of(delims, first);
+
+        if (first != second) {
+            if (current_pos == pos) {
+                std::string_view ref = strv.substr(first, second - first);
+                token                = std::string(ref.begin(), ref.end());
+                return true;
+            }
+            current_pos++;
+        }
+
+        if (second == std::string_view::npos)
+            break;
+
+        first = second + 1;
+    }
+    return false;
+}
+
+bool Str::get_token3(std::string_view str, size_t pos, std::string& token, std::string_view delims) {
+    size_t current_pos = 0;
+    for (auto first = str.data(), second = str.data(), last = first + str.size(); second != last && first != last;
+         first = second + 1) {
+
+        second = std::find_first_of(first, last, std::cbegin(delims), std::cend(delims));
+        if (first != second) {
+            if (current_pos == pos) {
+                token = std::string(first, second - first);
+                return true;
+            }
+            current_pos++;
+        }
+    }
+    return false;
+}
+
+boost::split_iterator<std::string::const_iterator> Str::make_split_iterator(const std::string& line,
+                                                                            const std::string& delimiters) {
+    return boost::make_split_iterator(
+        line, boost::algorithm::token_finder(boost::is_any_of(delimiters), boost::algorithm::token_compress_on));
+}
+
+static bool caseInsCharCompare(char a, char b) {
+    return (toupper(a) == toupper(b));
+}
+
+bool Str::caseInsCompare(const std::string& s1, const std::string& s2) {
+    return ((s1.size() == s2.size()) && equal(s1.begin(), s1.end(), s2.begin(), caseInsCharCompare));
+}
+
+bool Str::caseInsLess(const std::string& a, const std::string& b) {
+    return std::lexicographical_compare(a.begin(), a.end(), b.begin(), b.end(), [](char x, char y) -> bool {
+        if (toupper(x) == toupper(y)) {
+            return x > y;
+        }
+        return toupper(static_cast<unsigned char>(x)) < toupper(static_cast<unsigned char>(y));
+    });
+}
+
+bool Str::caseInsGreater(const std::string& a, const std::string& b) {
+    return std::lexicographical_compare(a.begin(), a.end(), b.begin(), b.end(), [](char x, char y) -> bool {
+        if (toupper(x) == toupper(y)) {
+            return x < y;
+        }
+        return toupper(static_cast<unsigned char>(x)) > toupper(static_cast<unsigned char>(y));
+    });
+}
+
+bool Str::valid_name(const std::string& name, std::string& msg) {
+    // valid names are alphabetic (alphanumeric | underscore | .)
+    // however we can't have a leading '.' as that can interfere with trigger expressions
+
+    // verify that the string is not empty
+    if (name.empty()) {
+        msg = "Invalid name. Empty string.";
+        return false;
+    }
+
+    // verify that the first character is alphanumeric or is an underscore
+    bool result = Str::ALPHANUMERIC_UNDERSCORE().find(name[0], 0) != string::npos;
+    if (!result) {
+        msg = "Valid names can only consist of alphanumeric characters, "
+              "underscores and dots (The first character cannot be a dot). "
+              "The first character is not valid (only alphanumeric or an underscore is allowed): ";
+        msg += name;
+        return false;
+    }
+
+    // verify that any other characters are alphanumeric or underscore
+    if (name.size() > 1) {
+        result = name.find_first_not_of(VALID_NODE_CHARS, 1) == string::npos;
+        if (!result) {
+            msg = "Valid names can only consist of alphanumeric characters, "
+                  "underscores and dots (The first character cannot be a dot). ";
+            if (name.find('\r') != string::npos)
+                msg += "Windows line ending ? ";
+            msg += "'";
+            msg += name;
+            msg += "'"; // use '<name>' to show if PC format. i.e carriage return
+        }
+    }
+
+    return result;
+}
+
+bool Str::valid_name(const std::string& name) {
+    // valid names are alphabetic (alphanumeric | underscore | .)
+    // however we can't have a leading '.' as that can interfere with trigger expressions
+
+    // verify that the string is not empty
+    if (name.empty()) {
+        return false;
+    }
+
+    // verify that the first character is alphabetic or has underscore
+    bool result = Str::ALPHANUMERIC_UNDERSCORE().find(name[0], 0) != string::npos;
+    if (!result) {
+        return false;
+    }
+
+    // verify that any other characters are alphanumeric or underscore
+    if (name.size() > 1) {
+        result = name.find_first_not_of(VALID_NODE_CHARS, 1) == string::npos;
+    }
+
+    return result;
+}
+
+int Str::to_int(const std::string& the_str, int error_return) {
+    if (the_str.find_first_of(Str::NUMERIC(), 0) != std::string::npos) {
+        try {
+            return ecf::convert_to<int>(the_str);
+        }
+        catch (const ecf::bad_conversion&) {
+        }
+    }
+    return error_return;
+}
+
+bool Str::truncate_at_start(std::string& fileContents, size_t max_lines) {
+    if (fileContents.empty())
+        return false;
+
+    /// Truncate from the front
+    size_t no_of_new_lines = 0;
+    for (size_t i = fileContents.size() - 1; i > 0; --i) {
+        if (fileContents[i] == '\n')
+            no_of_new_lines++;
+        if (no_of_new_lines >= max_lines) {
+            fileContents.erase(fileContents.begin(), fileContents.begin() + i + 1); // skip new line at start of file
+            return true;
+        }
+    }
+    return false;
+}
+
+bool Str::truncate_at_end(std::string& fileContents, size_t max_lines) {
+    if (fileContents.empty())
+        return false;
+
+    /// Truncate from the back
+    size_t no_of_new_lines = 0;
+    size_t the_size        = fileContents.size();
+    for (size_t i = 0; i < the_size; ++i) {
+        if (fileContents[i] == '\n')
+            no_of_new_lines++;
+        if (no_of_new_lines >= max_lines) {
+            fileContents.erase(fileContents.begin() + i + 1, fileContents.end()); // skip new line at end of file
+            return true;
+        }
+    }
+    return false;
+}
+
+std::string Str::dump_string_vec(const std::vector<std::string>& vec) {
+    std::string str;
+    for (const auto& s : vec) {
+        str += s;
+        str += "\n";
+    }
+    return str;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Str.hpp 5.13.0-1/libs/core/src/ecflow/core/Str.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Str.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Str.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,243 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Str_HPP
+#define ecflow_core_Str_HPP
+
+#include <cstring>
+#include <limits>
+#include <string>
+#include <string_view>
+#include <vector>
+
+#include <boost/algorithm/string.hpp>
+
+namespace ecf {
+
+namespace algorithm {
+
+template <typename Sequence1, typename Sequence2 = std::string>
+inline static auto join(const Sequence1& strings, const Sequence2& separator = std::string(", ")) {
+    return ::boost::algorithm::join(strings, separator);
+}
+
+template <typename Sequence, typename SearchSequence, typename ReplaceSequence>
+inline static auto replace_first(Sequence& input, const SearchSequence& search, const ReplaceSequence& replace) {
+    return ::boost::algorithm::replace_first(input, search, replace);
+}
+
+template <typename ResultSequence, typename Sequence1, typename Sequence2>
+inline static ResultSequence& split(ResultSequence& result, const Sequence1& input, const Sequence2& separators) {
+    return ::boost::algorithm::split(result, input, ::boost::is_any_of(separators));
+}
+
+template <typename Sequence1, typename Sequence2>
+inline static bool starts_with(const Sequence1& input, const Sequence2& pattern) {
+    return ::boost::algorithm::starts_with(input, pattern);
+}
+
+template <typename Sequence>
+inline static void trim(Sequence& input) {
+    ::boost::algorithm::trim(input);
+}
+
+template <typename T>
+static std::vector<std::string> transform_to_name_vector(const std::vector<T>& i) {
+    std::vector<std::string> o;
+    o.reserve(i.size());
+    std::transform(std::begin(i), std::end(i), std::back_inserter(o), [](const auto& v) { return v->name(); });
+    return o;
+}
+
+inline std::string tolower(std::string s) {
+    std::transform(std::begin(s), std::end(s), std::begin(s), [](unsigned char c) { return std::tolower(c); });
+    return s;
+}
+
+} // namespace algorithm
+
+class Str {
+public:
+    // Disable default construction
+    Str() = delete;
+    // Disable copy (and move) semantics
+    Str(const Str&)                  = delete;
+    const Str& operator=(const Str&) = delete;
+
+    static int reserve_4() { return 4; }
+    static int reserve_8() { return 8; }
+    static int reserve_16() { return 17; }
+    static int reserve_32() { return 32; }
+    static int reserve_64() { return 64; }
+
+    // remove any quotes on the string, else does nothing
+    // "fred" -> fred
+    //  fred  -> fred
+    static void removeQuotes(std::string&);
+
+    // remove any single quotes on the string, else does nothing
+    // 'fred' -> fred
+    //  fred  -> fred
+    static void removeSingleQuotes(std::string&);
+
+    /// Find 'stringToFind' in 'jobLine' and replace with string 'stringToReplace'
+    /// return true if replace ok else returns false;
+    static bool replace(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace);
+    static bool replace_all(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace);
+    static void replaceall(std::string& subject, const std::string& stringToFind, const std::string& stringToReplace);
+
+    // extract data member value, ie given a string of the form:
+    //   str=cmd a b fred:value
+    //   data_member_name=fred:
+    //   extract value
+    static bool extract_data_member_value(const std::string& str,
+                                          const std::string& data_member_name,
+                                          std::string& data_member_value);
+
+    /// split string using default delimiters of space and tab as a separator;
+    /// The split is based on *ANY* of the characters in the delimiters.
+    /// **** Hence a delimiter of "==" will still split "a = complete"
+    /// **** sequential delimiter character are ignored ****
+    /// This function is used to choose the fastest implementation
+    static void split(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters = " \t");
+
+    static std::vector<std::string_view> tokenize_quotation(const std::string& s, std::string_view quotes);
+
+    static void
+    split_orig(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters = " \t");
+
+    static void
+    split_orig1(const std::string& line, std::vector<std::string>& tokens, const std::string& delimiters = " \t");
+
+    static void split_using_string_view(std::string_view line,
+                                        std::vector<std::string>& tokens,
+                                        std::string_view delimiters = " \t");
+
+    static void split_using_string_view2(std::string_view line,
+                                         std::vector<std::string>& tokens,
+                                         std::string_view delimiters = " \t");
+
+    // Get token at a given pos. Two different implementations
+    static bool get_token(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
+    static bool get_token2(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
+    static bool get_token3(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
+
+    // Uses boost::make_split_iterator will remove
+    // consecutive delimiters in the middle of the string
+    // ** However preserves leading and trailing empty tokens *IF* delimiters at start/end
+    //
+    // Usage:
+    //    boost::split_iterator<std::string::const_iterator> tokens = Str::make_split_iterator(str);
+    //    for(; !tokens.eof(); ++tokens ) {
+    //       boost::iterator_range<string::const_iterator> range = *tokens;
+    //       std::string the_string(range.begin(), range.end()) ;
+    //    }
+    //
+    //    std::vector<std::string> vec;
+    //    typedef boost::split_iterator<std::string::const_iterator> split_iter_t;
+    //    for(split_iter_t i = Str::split(s,delim); i != split_iter_t(); i++) {
+    //       vec.push_back(boost::copy_range<std::string>(*i));
+    //    }
+    static boost::split_iterator<std::string::const_iterator>
+    make_split_iterator(const std::string& str, const std::string& delimiters = " \t");
+
+    /// case in sensitive string comparison
+    static bool caseInsCompare(const std::string&, const std::string&);
+
+    /// case insensitive less
+    static bool caseInsLess(const std::string&, const std::string&);
+
+    /// case insensitive Greater
+    static bool caseInsGreater(const std::string&, const std::string&);
+
+    /// Used for checking node names
+    static bool valid_name(const std::string& name, std::string& msg);
+    static bool valid_name(const std::string& name);
+
+    /// This function checks if the given string actually has any digits before attempting the conversion;
+    /// this approach is faster than using ecf::convert_to<int> directly (and thus always attempt to
+    /// perform the conversion).
+    /// Use this function when it is not possible to ensure the string is convertible to an integer (e.g. user input).
+    ///
+    /// This function return the given `error_return` (by default, numeric_limits<int>::max()),
+    /// in cases where the conversion is invalid.
+    static int to_int(const std::string&, int error_return = std::numeric_limits<int>::max());
+
+    /// Truncate the input string at the start/end if exceeds max_lines_ newlines
+    /// returns true if truncated false otherwise
+    static bool truncate_at_start(std::string& fileContents, size_t max_lines);
+    static bool truncate_at_end(std::string& fileContents, size_t max_lines);
+
+    static std::string dump_string_vec(const std::vector<std::string>& vec);
+
+    /// Only use strcmp if the first characters are the same
+    static int local_strcmp(const char* s, const char* t) { return (*s != *t ? *s - *t : strcmp(s, t)); }
+
+    // returns a static string of alphanumerics and underscore
+    static const std::string& ALPHANUMERIC_UNDERSCORE();
+
+    // returns a static string of numerics chars
+    static const std::string& NUMERIC();
+
+    static const char* CHILD_CMD();
+    static const char* USER_CMD();
+    static const char* SVR_CMD(); // Only for automatic check_pt
+
+    // Allows string to be returned by reference
+    static const std::string& EMPTY();
+    static const std::string& ROOT_PATH();      // "/"
+    static const std::string& PATH_SEPERATOR(); // "/"
+    static const std::string& COLON();          // ":"
+
+    static const std::string& STATE_CHANGE();
+
+    static const std::string& TASK();
+    static const std::string& FAMILY();
+    static const std::string& SUITE();
+    static const std::string& ALIAS();
+
+    static const std::string& DEFAULT_PORT_NUMBER(); // "3141"
+    static const std::string& LOCALHOST();
+
+    static const std::string& ECF_PORT();
+    static const std::string& ECF_RID();
+    static const std::string& ECF_TRYNO();
+    static const std::string& ECF_TRIES();
+    static const std::string& ECF_NAME();
+    static const std::string& ECF_HOST();
+    static const std::string& ECF_PASS();
+    static const std::string& ECF_JOB();
+    static const std::string& ECF_JOBOUT();
+    static const std::string& ECF_SCRIPT();
+    static const std::string& ECF_DUMMY_TASK();
+    static const std::string& ECF_NO_SCRIPT();
+    static const std::string& ECF_MICRO();
+    static const std::string& ECF_FILES();
+    static const std::string& ECF_FETCH();
+    static const std::string& ECF_KILL_CMD();
+    static const std::string& ECF_STATUS_CMD();
+
+    static const std::string& ECF_HOME();
+    static const std::string& ECF_INCLUDE();
+    static const std::string& ECF_JOB_CMD();
+    static const std::string& ECF_OUT();
+    static const std::string& ECF_EXTN();
+    static const std::string& ECF_LOG();
+
+    static const std::string& WHITE_LIST_FILE();
+    static const std::string& ECF_PASSWD();
+    static const std::string& ECF_CUSTOM_PASSWD();
+
+    static const char* cpu_timer_format() { return "%ws wall, (%us user + %ss system = %ts) CPU (%p%)"; }
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_Str_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/StringSplitter.cpp 5.13.0-1/libs/core/src/ecflow/core/StringSplitter.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/StringSplitter.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/StringSplitter.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/StringSplitter.hpp"
+
+namespace ecf {
+
+bool StringSplitter::finished() const {
+    // Skip delimiters at beginning. so for an empty string or string of just separators, we do not call next()
+    // This mirrors the old split functionality
+    if (finished_)
+        return true;
+    first_not_of_ = rem_.find_first_not_of(sep_);
+    if (first_not_of_ == std::string_view::npos)
+        finished_ = true;
+    return finished_;
+}
+
+std::string_view StringSplitter::next() const {
+    if (first_not_of_ != 0)
+        rem_ = rem_.substr(first_not_of_);
+
+    std::string_view::size_type pos = rem_.find_first_of(sep_); // Find first "non-delimiter".
+    if (pos != std::string_view::npos) {
+        std::string_view ret = rem_.substr(0, pos);
+        rem_                 = rem_.substr(pos + 1); // skip over separator
+
+        // if separator is at the end, lose the last empty tokens
+        if (rem_.find_first_not_of(sep_) == std::string_view::npos) {
+            finished_ = true;
+        }
+        return ret;
+    }
+
+    finished_ = true;
+    return rem_;
+}
+
+void StringSplitter::reset() {
+    rem_      = src_;
+    finished_ = false;
+}
+
+void StringSplitter::split(const std::string& str,
+                           std::vector<std::string_view>& lineTokens,
+                           std::string_view delimiters) {
+    StringSplitter string_splitter(str, delimiters);
+    while (!string_splitter.finished()) {
+        lineTokens.push_back(string_splitter.next());
+    }
+}
+
+void StringSplitter::split2(std::string_view str, std::vector<std::string_view>& ret, const char* delimiters) {
+    std::string_view::size_type start = 0;
+
+    auto pos = str.find_first_of(delimiters, start);
+    while (pos != std::string_view::npos) {
+        if (pos != start) {
+            ret.emplace_back(str.substr(start, pos - start));
+        }
+        start = pos + 1;
+        pos   = str.find_first_of(delimiters, start);
+    }
+    if (start < str.length())
+        ret.emplace_back(str.substr(start, str.length() - start));
+}
+
+void StringSplitter::split(const std::string& str, std::vector<std::string>& lineTokens, std::string_view delimiters) {
+    StringSplitter string_splitter(str, delimiters);
+    while (!string_splitter.finished()) {
+        std::string_view ref = string_splitter.next();
+        lineTokens.emplace_back(ref.begin(), ref.end());
+    }
+}
+
+bool StringSplitter::get_token(std::string_view line, size_t pos, std::string& token, std::string_view sep) {
+    size_t count = 0;
+    StringSplitter string_splitter(line, sep);
+    while (!string_splitter.finished()) {
+        std::string_view the_token = string_splitter.next();
+        if (count == pos) {
+            token = std::string(the_token.begin(), the_token.end());
+            return true;
+        }
+        else if (count > pos)
+            return false;
+        count++;
+    }
+    return false;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/StringSplitter.hpp 5.13.0-1/libs/core/src/ecflow/core/StringSplitter.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/StringSplitter.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/StringSplitter.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_StringSplitter_HPP
+#define ecflow_core_StringSplitter_HPP
+
+#include <string>
+#include <string_view>
+#include <vector>
+
+namespace ecf {
+
+// ****************************************************************************
+// IMPORTANT: std::string_view is a *READ ONLY* REFERENCE to an existing string
+// HENCE:     the reference string *MUST* not change, and its lifetime must EXCEED string_view
+//
+// Will split a string. Will return an empty std::string_view if there's a separator at the end.
+// This shows the fastest split for a string. **** Based on boost 1.64 ****
+//    Method:              time
+//    boost::split:        4.06
+//    Str::split:          2.33
+//    make_split_iterator  4.07
+//    std::string_view    1.42
+
+class StringSplitter {
+    std::string_view src_;
+    mutable std::string_view rem_;
+    std::string_view sep_;
+    mutable std::string_view::size_type first_not_of_;
+    mutable bool finished_;
+
+public:
+    explicit StringSplitter(std::string_view src, std::string_view sep = " \t")
+        : src_(src),
+          rem_(src),
+          sep_(sep),
+          first_not_of_(0),
+          finished_(false) {}
+
+    // this rules out temp strings, it also rules out char * because of two available overloads
+    StringSplitter(const std::string&& src, std::string_view sep) = delete;
+
+    // this re-enables support for string literals (which are never temp)
+    // it even handles correctly char arrays that contain a null terminated string
+    // because string_view does not have a char array constructor!
+    template <std::size_t N>
+    explicit StringSplitter(const char (&sz)[N], std::string_view sep = " \t")
+        : src_(sz),
+          rem_(sz),
+          sep_(sep),
+          first_not_of_(0),
+          finished_(false) {}
+
+    std::string_view next() const;
+    bool finished() const;
+    bool last() const { return finished_; }
+    void reset();
+
+    /// The preferred splitter as it does not create strings
+    static void
+    split(const std::string& str, std::vector<std::string_view>& lineTokens, std::string_view delimiters = " \t");
+
+    // This the fastest splitter at the moment
+    static void split2(std::string_view str, std::vector<std::string_view>& lineTokens, const char* delimiters = " \t");
+
+    /// This was added to maintain compatibility, slightly faster than original Str::split
+    static void
+    split(const std::string& str, std::vector<std::string>& lineTokens, std::string_view delimiters = " \t");
+
+    /// return the token at pos, otherwise returns false.
+    static bool get_token(std::string_view line, size_t pos, std::string& token, std::string_view sep = " \t");
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_StringSplitter_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/TimeSeries.cpp 5.13.0-1/libs/core/src/ecflow/core/TimeSeries.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/TimeSeries.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/TimeSeries.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,963 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/TimeSeries.hpp"
+
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/cereal_boost_time.hpp"
+#ifdef DEBUG
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+// #define DEBUG_TIME_SERIES 1
+// #define DEBUG_TIME_SERIES_IS_FREE 1
+#ifdef DEBUG_TIME_SERIES_IS_FREE
+    #include "ecflow/core/Indentor.hpp"
+#endif
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+static void testTimeSlot(const ecf::TimeSlot& ts) {
+    if (ts.hour() < 0 || ts.hour() > 23) {
+        std::stringstream ss;
+        ss << "TimeSeries:  time hour(" << ts.hour() << ") must be in range 0-23";
+        throw std::out_of_range(ss.str());
+    }
+    if (ts.minute() < 0 || ts.minute() > 59) {
+        std::stringstream ss;
+        ss << "TimeSeries:  time minute(" << ts.minute() << ") must be in range 0-59";
+        throw std::out_of_range(ss.str());
+    }
+}
+
+namespace ecf {
+
+TimeSeries::TimeSeries() = default;
+
+TimeSeries::TimeSeries(int hour, int minute, bool relative)
+    : start_(hour, minute),
+      nextTimeSlot_(hour, minute),
+      lastTimeSlot_(start_.duration()),
+      relativeToSuiteStart_(relative) {
+    testTimeSlot(start_);
+}
+
+TimeSeries::TimeSeries(const TimeSlot& t, bool relative)
+    : start_(t),
+      nextTimeSlot_(t),
+      lastTimeSlot_(t.duration()),
+      relativeToSuiteStart_(relative) {
+    testTimeSlot(start_);
+}
+
+TimeSeries::TimeSeries(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative)
+    : start_(start),
+      finish_(finish),
+      incr_(incr),
+      nextTimeSlot_(start),
+      relativeToSuiteStart_(relative) {
+    testTimeSlot(start);
+    testTimeSlot(finish);
+    testTimeSlot(incr);
+
+    if (!finish_.isNULL()) {
+        if (incr_.isNULL()) {
+            std::stringstream ss;
+            ss << "TimeSeries::TimeSeries: Invalid time series: Finish specified without an increment";
+            throw std::out_of_range(ss.str());
+        }
+    }
+
+    if (start.duration() > finish.duration()) {
+        std::stringstream ss;
+        ss << "TimeSeries::TimeSeries: Invalid time series: Start time(" << start.toString()
+           << ") is greater than end time(" << finish.toString() << ")";
+        throw std::out_of_range(ss.str());
+    }
+    if (incr.hour() == 0 && incr.minute() == 0) {
+        throw std::out_of_range(
+            "TimeSeries::TimeSeries Invalid time series:  Increment must be greater than 0 minutes.");
+    }
+    boost::posix_time::time_duration diff = finish.duration() - start.duration();
+    if (incr.duration() > diff) {
+        std::stringstream ss;
+        ss << "TimeSeries::TimeSeries: Invalid time series: Increment(" << incr.toString()
+           << ") is greater than duration " << to_simple_string(diff) << " between start(" << start.toString()
+           << ") and finish(" << finish.toString() << ")";
+        throw std::out_of_range(ss.str());
+    }
+
+    compute_last_time_slot();
+
+    // #ifdef DEBUG_TIME_SERIES
+    //	cout << "TimeSeries::TimeSeries "  << dump() << "\n";
+    // #endif
+}
+
+bool TimeSeries::operator<(const TimeSeries& rhs) const {
+    return start_ < rhs.start_;
+}
+
+void TimeSeries::compute_last_time_slot() {
+    if (!finish_.isNULL()) {
+        lastTimeSlot_ = start_.duration();
+        while (lastTimeSlot_ <= finish_.duration())
+            lastTimeSlot_ += incr_.duration();
+        lastTimeSlot_ -= incr_.duration();
+    }
+}
+
+bool TimeSeries::calendarChanged(const ecf::Calendar& c) {
+    if (relativeToSuiteStart_) {
+        relativeDuration_ += c.calendarIncrement();
+        return true;
+    }
+    else if (c.dayChanged()) {
+
+        // Clear expired flag and next slot. Needed since requeuing will expire flag when pastime slot
+        // Hence we need something to reset. Otherwise, for next day isFree will always return false;
+        isValid_      = true;
+        nextTimeSlot_ = start_;
+        return true;
+    }
+    return false;
+}
+
+bool TimeSeries::resetRelativeDuration() {
+    if (relativeToSuiteStart_) {
+        relativeDuration_ = time_duration(0, 0, 0, 0);
+
+#ifdef DEBUG_TIME_SERIES
+        log(Log::DBG, "TimeSeries::resetRelativeDuration " + dump());
+#endif
+
+        return true;
+    }
+#ifdef DEBUG_TIME_SERIES
+    log(Log::DBG, "TimeSeries::resetRelativeDuration " + dump());
+#endif
+    return false;
+}
+
+void TimeSeries::reset_only() {
+    isValid_      = true;
+    nextTimeSlot_ = start_;
+    (void)resetRelativeDuration();
+}
+
+void TimeSeries::reset(const ecf::Calendar& c) {
+    reset_only();
+
+    // Note: **difference between reset and re-queue,
+    //  Hence if at begin(), time slot same as current time, allow job to run.
+    //  reset  : while( current_time >  nextTimeSlot_.duration()) {  // need for why command
+    //              if (current_time >  start_.duration() ) {
+    //  requeue: while( current_time >= nextTimeSlot_.duration()) {
+    //              if (current_time >= start_.duration() ) {
+
+    // Update nextTimeSlot_ so that why command works out of the box, when nodes have been begun.
+    // *if* the current time is *AT* the start do *not* increment nextTimeSlot_, otherwise we will miss first time slot
+    time_duration current_time = duration(c);
+    if (hasIncrement()) {
+
+        // only used when we have a series, and *NOT* relative. A relative time series does not care about midnight.
+        if (!relativeToSuiteStart_) {
+            suiteTimeAtReque_ = TimeSlot(c.suiteTime().time_of_day());
+        }
+
+        while (current_time > nextTimeSlot_.duration()) {
+            time_duration value = nextTimeSlot_.duration();
+            value += incr_.duration();
+            nextTimeSlot_ = TimeSlot(value.hours(), value.minutes());
+        }
+        if (nextTimeSlot_ > finish_) {
+            isValid_ = false; // time has expired
+        }
+    }
+    else {
+        if (current_time > start_.duration()) {
+            isValid_ = false; // time has expired
+        }
+    }
+
+#ifdef DEBUG_TIME_SERIES
+    //	LogToCout toCoutAsWell;
+    log(Log::DBG, "TimeSeries::reset   " + dump());
+#endif
+}
+
+void TimeSeries::requeue(const ecf::Calendar& c, bool reset_next_time_slot) {
+    // cout << "TimeSeries::requeue " << c.toString()  << "\n";
+
+    // *RESET* to handle case where time slot has been advanced, but at requeue it must be reset
+    // This is important otherwise user can never reset and time slot that had been advanced
+    // by using miss_next_time_slot()
+    if (reset_next_time_slot) {
+        isValid_      = true;
+        nextTimeSlot_ = start_;
+    }
+
+    //   time 13:00 // nextTimeSlot_ is initialised to 13:00, on TimeSeries::requeue() invalidate time series
+    //              // to stop multiple job submissions on same time slot
+    //                       -------------------- nextTimeSlot_
+    //                       |     -------------- isValid = false
+    //                       V     V
+    //   10:00 11:00 12:00 13:00 14:00 15:00 16:00 17:00 18:00 19:00 20:00
+    //     |     |     |     |     |     |     |     |     |     |     |
+    //  ------time----------->
+    //
+    // TimeSeries::requeue(..) is called at the *re-queue* stage. *after*:
+    //   a/ task has completed
+    //   b/ checkForRequeue() has passed.
+    // hence if we get here for a single slot time, where calendar time >= start time
+    // then this time series is no longer valid. This will stop multiple job submission
+    // for the same time slot
+    time_duration current_time = duration(c);
+    if (!hasIncrement()) {
+        if (current_time >= start_.duration()) {
+            isValid_ = false; // time has expired
+#ifdef DEBUG_TIME_SERIES
+            LOG(Log::DBG,
+                "TimeSeries::requeue HOLDING TIME EXPIRED (duration(c) >= start_.duration() ) "
+                    << dump() << " duration=" << to_simple_string(duration(c)));
+#endif
+        }
+        return;
+    }
+
+    // Only used when we have a series, and NOT relative. A relative time series does not care about midnight
+    if (!relativeToSuiteStart_) {
+        suiteTimeAtReque_ = TimeSlot(c.suiteTime().time_of_day());
+    }
+
+    // the nextTimeSlot_ needs to be set to a multiple of incr
+    // However the nextTimeSlot_ cannot just be incremented by incr
+    // since we can't assume that a task completes within the given time slots
+    // *hence increments to NEXT TIME SLOT large than calendar time.
+    // time 10::00 20:00 01:00
+    //                       --------------------------------------------------------nextTimeSlot_ must greater than
+    //                       current time. |                                               --------isValid = false V V
+    //   10:00 11:00 12:00 13:00 14:00 15:00 16:00 17:00 18:00 19:00 20:00 21:00
+    //     |     |     |     |     |     |     |     |     |     |     |     |
+    //  ------time---->
+    //
+    while (current_time >= nextTimeSlot_.duration()) {
+        time_duration value = nextTimeSlot_.duration();
+        value += incr_.duration();
+        nextTimeSlot_ = TimeSlot(value.hours(), value.minutes());
+    }
+
+    if (nextTimeSlot_ > finish_) {
+        isValid_          = false;      // time has expired
+        suiteTimeAtReque_ = TimeSlot(); // expire for new requeue
+#ifdef DEBUG_TIME_SERIES
+        log(Log::DBG, "TimeSeries::requeue  HOLDING TIME EXPIRED (nextTimeSlot_ > finish_) " + dump());
+#endif
+    }
+}
+
+TimeSlot TimeSeries::compute_next_time_slot(const ecf::Calendar& c) const {
+    // This functionality needs to mirror TimeSeries::requeue
+    time_duration current_time = duration(c);
+    if (!hasIncrement()) {
+        if (current_time >= start_.duration()) {
+            return {}; // time has expired
+        }
+        return start_;
+    }
+
+    TimeSlot nextTimeSlot = start_;
+    while (current_time >= nextTimeSlot.duration()) {
+        time_duration value = nextTimeSlot.duration();
+        value += incr_.duration();
+        nextTimeSlot = TimeSlot(value.hours(), value.minutes());
+    }
+
+    if (nextTimeSlot > finish_) {
+        return {}; // time has expired
+    }
+    return nextTimeSlot;
+}
+
+bool TimeSeries::requeueable(const ecf::Calendar& c) const {
+    boost::posix_time::time_duration calendar_time = duration(c);
+    if (calendar_time < start().duration())
+        return true;
+    if (hasIncrement()) {
+        if (calendar_time < finish().duration()) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool TimeSeries::isFree(const ecf::Calendar& calendar) const {
+#ifdef DEBUG_TIME_SERIES_IS_FREE
+    LogToCout toCoutAsWell;
+    Indentor indent;
+#endif
+
+    if (!isValid_) {
+        // time has expired, hence time is not free
+#ifdef DEBUG_TIME_SERIES_IS_FREE
+        log(Log::DBG, "TimeSeries::isFree (!isValid_) HOLDING " + dump());
+#endif
+        return false;
+    }
+
+    // Matched calendar duration with the current value of the time series
+    // or match with one of time slots.
+
+    // Note:: the definition file has time series format of hh:mm this
+    //        means we have a minute resolution. The clock/calendar
+    //        duration has seconds based resolution. hence we must
+    //        compensate for this.
+    //
+    //   time 10:00 20:00 01:00
+    //   start
+    //     |                 ----- next time slot                      --- finish
+    //     |                 |                                         |
+    //     V                 V                                         V
+    //   10:00 11:00 12:00 13:00 14:00 15:00 16:00 17:00 18:00 19:00 20:00
+    //     |     |     |     |     |     |     |     |     |     |     |
+    //  ------time---->
+    //
+    bool ret = match_duration_with_time_series(duration(calendar));
+    //	if (ret) {
+    //	   std::cout << "TimeSeries::isFree " << dump() << " is free at calendar: " << calendar.toString() << "\n";
+    //	}
+    return ret;
+}
+
+bool TimeSeries::match_duration_with_time_series(const boost::posix_time::time_duration& relative_or_real_td) const {
+#ifdef DEBUG_TIME_SERIES_IS_FREE
+    Indentor ident;
+#endif
+
+    if (!hasIncrement()) {
+        // We ignore seconds, hence +00:02  will match 2.58 (two minutes 58 seconds) relative duration
+        time_duration start_td = start_.duration();
+        if (relative_or_real_td.hours() == start_td.hours() && relative_or_real_td.minutes() == start_td.minutes()) {
+#ifdef DEBUG_TIME_SERIES_IS_FREE
+            LOG(Log::DBG,
+                "TimeSeries::match_duration_with_time_series " << dump() << " FREE at "
+                                                               << to_simple_string(relative_or_real_td));
+#endif
+            return true;
+        }
+
+#ifdef DEBUG_TIME_SERIES_IS_FREE
+        LOG(Log::DBG,
+            "TimeSeries::match_duration_with_time_series " << dump() << " HOLDING at "
+                                                           << to_simple_string(relative_or_real_td));
+#endif
+        return false;
+    }
+
+    time_duration endDuration     = finish_.duration();
+    time_duration incrDuration    = incr_.duration();
+    time_duration nextTimeSlot_td = nextTimeSlot_.duration();
+    long hours                    = relative_or_real_td.hours();
+    long minutes                  = relative_or_real_td.minutes();
+    while (nextTimeSlot_td <= endDuration) {
+
+        if (hours == nextTimeSlot_td.hours() && minutes == nextTimeSlot_td.minutes()) {
+#ifdef DEBUG_TIME_SERIES_IS_FREE
+            LOG(Log::DBG,
+                "TimeSeries::match_duration_with_time_series (nextTimeSlot_td == duration)  "
+                    << dump() << " FREE at " << to_simple_string(relative_or_real_td));
+#endif
+            return true;
+        }
+        nextTimeSlot_td += incrDuration;
+    }
+
+#ifdef DEBUG_TIME_SERIES
+    LOG(Log::DBG,
+        "TimeSeries::match_duration_with_time_series HOLDING (nextTimeSlot_td > endDuration)  "
+            << dump() << " HOLDING at " << to_simple_string(relative_or_real_td));
+#endif
+    return false;
+}
+
+void TimeSeries::miss_next_time_slot() {
+    if (!hasIncrement()) {
+        // single slot, does not have a next time slot, hence expire time
+        isValid_ = false;
+    }
+    else {
+        time_duration value = nextTimeSlot_.duration();
+        value += incr_.duration();
+        nextTimeSlot_ = TimeSlot(value.hours(), value.minutes());
+        if (nextTimeSlot_ > finish_) {
+            // time has expired,
+            isValid_ = false;
+        }
+    }
+}
+
+bool TimeSeries::checkForRequeue(const ecf::Calendar& calendar,
+                                 const TimeSlot& the_min,
+                                 const TimeSlot& the_max,
+                                 bool cmd_context) const {
+    // ************************************************************************
+    // THIS IS CALLED IN THE CONTEXT WHERE NODE HAS COMPLETED. Hence ****asynchronous****
+    // RETURNING TRUE FROM HERE WILL FORCE NODE TO QUEUED STATE
+    // HENCE THIS FUNCTION MUST RETURN FALSE, WHEN END OF TIME SLOT HAS BEEN REACHED/expired
+    // The resolution is in minutes
+    // *************************************************************************
+    // cout << "TimeSeries::checkForRequeue " << calendar.suite_time_str() << " min: " << the_min << " max: " << the_max
+    // << " cmd_context(" << cmd_context << ") +++++++++++++++\n";
+#ifdef DEBUG_TIME_SERIES
+    log(Log::DBG, "TimeSeries::checkForRequeue: " + dump());
+#endif
+
+    if (!isValid_) {
+        // time has expired, hence can no longer re-queues, i.e no future time dependency
+#ifdef DEBUG_TIME_SERIES
+        // cout << " TimeSeries::checkForRequeue " << calendar.suite_time_str() << "  HOLDING\n";
+        log(Log::DBG, "TimeSeries::checkForRequeue HOLDING !isValid_  " + dump());
+#endif
+        return false;
+    }
+
+    if (hasIncrement()) {
+        // Note if we are equal to the finish and were called as part of completeCmd
+        // then completeCmd will initiate a job submission immediately
+        //  start  00:01
+        //  finish 00:04   Node will be queued 4 times
+        //  incr   00:01
+
+        // If the current value is greater that finish, then returning true would increment
+        // value past the end, and force node state to be stuck in state queue.
+        if (nextTimeSlot_ > finish_) {
+#ifdef DEBUG_TIME_SERIES
+            // cout << " TimeSeries::checkForRequeue ( nextTimeSlot_ > finish_ )    HOLDING\n";
+            log(Log::DBG, "TimeSeries::checkForRequeue HOLDING  ( nextTimeSlot_ > finish_ )  " + dump());
+#endif
+            return false;
+        }
+
+        // ECFLOW-130 jobs that start before midnight and finish after midnight should not re-queue
+        // This should ONLY apply to non relative time series, since a relative time series does care about midnight
+        if (!relativeToSuiteStart_ && !suiteTimeAtReque_.isNULL()) {
+            TimeSlot suiteTimeNow(calendar.suiteTime().time_of_day());
+            // cout << "TimeSeries::checkForRequeue suiteTimeNow = " << suiteTimeNow << "
+            // =====================================================\n";
+            //  we use >= specifically for unit test, to pass.
+            if (suiteTimeNow >= suiteTimeAtReque_) {
+                // normal flow, i.e same day
+                suiteTimeAtReque_ = TimeSlot(); // make NULL, allow requeuing to reset.
+            }
+            else {
+                // The day changed between (requeue/reset):->queued->submitted->active->complete->(checkForRequeue)
+#ifdef DEBUG_TIME_SERIES
+                // cout << " TimeSeries::checkForRequeue day changed
+                // ===================================================== HOLDING\n";
+                log(Log::DBG, "TimeSeries::checkForRequeue HOLDING suiteTimeNow < suiteTimeAtReque_  " + dump());
+#endif
+                return false;
+            }
+        }
+
+        time_duration calendar_duration = duration(calendar);
+        if (cmd_context) {
+            // In the *COMMAND* context, allow re-queue if we are *BEFORE* the last time slot
+            if (calendar_duration < lastTimeSlot_) {
+                return true;
+            }
+        }
+        else {
+            if (calendar_duration >= start_.duration() && calendar_duration < lastTimeSlot_) {
+                return true;
+            }
+        }
+
+#ifdef DEBUG_TIME_SERIES
+        log(Log::DBG,
+            "TimeSeries::checkForRequeue  HOLDING calendar_duration < start_ || calendar_duration >= lastTimeSlot_)  " +
+                dump());
+#endif
+        return false;
+    }
+
+    // *** When we have a single time slots we cannot make a decision, whether
+    // *** we should re-queue based on this attribute *alone*. (i.e when we have > 1 time/today attributes)
+    // *** Hence we pass min and max time slots, over all the time bases attributes of the same kind.
+    // *** In our case we only do this for Time and Today attributes.
+    // *** The the_min/the_max have been computed for all attribute (i.e single time slots and ranges)
+
+    // We have a single time slot, *OR* multiple with same time slot
+    if (the_min == the_max) {
+        // cout << " TimeSeries::checkForRequeue (the_min == the_max) HOLDING \n";
+#ifdef DEBUG_TIME_SERIES
+        log(Log::DBG, "TimeSeries::checkForRequeue  HOLDING  the_min == the_max  " + dump());
+#endif
+        return false;
+    }
+
+    // The the_min/the_max takes into account *all* start/finish Time and Today attributes
+    time_duration calendar_duration = duration(calendar);
+    if (cmd_context) {
+        // In the *COMMAND* context, allow re-queue if we are *BEFORE* the max time slot
+        if (calendar_duration < the_max.duration()) {
+            // cout << " TimeSeries::checkForRequeue *COMMAND* context calendar_duration < the_max.duration()) --> allow
+            // requeue\n";
+            return true;
+        }
+    }
+    else {
+        if (calendar_duration >= the_min.duration() && calendar_duration < the_max.duration()) {
+            // cout << " TimeSeries::checkForRequeue (calendar_duration > the_min.duration() && calendar_duration <
+            // the_max.duration()) --> allow requeue\n";
+            return true;
+        }
+    }
+
+    // cout << " TimeSeries::checkForRequeue calendar duration " << to_simple_string(calendar_duration) << " not in
+    // range " <<  to_simple_string(the_min.duration())  << "-" <<  to_simple_string(the_max.duration()) << "  HOLDING
+    // \n";
+#ifdef DEBUG_TIME_SERIES
+    log(Log::DBG, "TimeSeries::checkForRequeue HOLDING multiple slots not in range " + dump());
+#endif
+    return false;
+}
+
+void TimeSeries::min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const {
+    if (the_min.isNULL() || start_ < the_min)
+        the_min = start_;
+    if (the_max.isNULL() || start_ > the_max)
+        the_max = start_;
+    if (hasIncrement()) {
+        if (finish_ < the_min)
+            the_min = finish_;
+        if (finish_ > the_max)
+            the_max = finish_;
+    }
+}
+
+void TimeSeries::why(const ecf::Calendar& c, std::string& theReasonWhy) const {
+    std::stringstream ss;
+    ss << " ( next run time is ";
+    if (relativeToSuiteStart_)
+        ss << "+";
+    ss << nextTimeSlot_.toString();
+
+    TimeSlot currentTime = TimeSlot(duration(c));
+    ss << ", current suite time is ";
+    if (relativeToSuiteStart_)
+        ss << "+";
+    ss << currentTime.toString() << " )";
+    theReasonWhy += ss.str();
+}
+
+boost::posix_time::time_duration TimeSeries::duration(const ecf::Calendar& c) const {
+    // return with a minute resolution
+    if (relativeToSuiteStart_) {
+
+        // relative to suite start only
+        return {relativeDuration_.hours(), relativeDuration_.minutes(), 0, 0};
+    }
+
+    LOG_ASSERT(!c.suiteTime().is_special(), "init has not been called on calendar. TimeSeries::duration");
+    time_duration time_of_day = c.suiteTime().time_of_day();
+    return {time_of_day.hours(), time_of_day.minutes(), 0, 0};
+}
+
+void TimeSeries::free_slots(std::vector<boost::posix_time::time_duration>& vec) const {
+    if (hasIncrement()) {
+
+        time_duration i            = start_.duration();
+        time_duration endDuration  = finish_.duration();
+        time_duration incrDuration = incr_.duration();
+        while (i < endDuration) {
+            vec.push_back(i);
+            i += incrDuration;
+        }
+        vec.push_back(finish_.duration());
+        return;
+    }
+
+    vec.push_back(start_.duration());
+}
+
+bool TimeSeries::structureEquals(const TimeSeries& rhs) const {
+    if (relativeToSuiteStart_ != rhs.relativeToSuiteStart_)
+        return false;
+    if (start_ != rhs.start_)
+        return false;
+    if (finish_ != rhs.finish_)
+        return false;
+    if (incr_ != rhs.incr_)
+        return false;
+    return true;
+}
+
+bool TimeSeries::operator==(const TimeSeries& rhs) const {
+    // additional state
+    if (isValid_ != rhs.isValid_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "TimeSeries::operator==  ( isValid_ != rhs.isValid_) " << toString() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (nextTimeSlot_ != rhs.nextTimeSlot_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "TimeSeries::operator==  ( nextTimeSlot_(" << nextTimeSlot_.toString()
+                      << ") != rhs.nextTimeSlot_(" << rhs.nextTimeSlot_.toString() << ")) " << toString() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (relativeDuration_ != rhs.relativeDuration_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "TimeSeries::operator==  ( relativeDuration_ != rhs.relativeDuration_) " << toString() << "\n";
+        }
+#endif
+        return false;
+    }
+    return structureEquals(rhs);
+}
+
+void TimeSeries::print(std::string& os) const {
+    write(os);
+    os += "\n";
+}
+
+std::string TimeSeries::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void TimeSeries::write(std::string& ret) const {
+    if (relativeToSuiteStart_)
+        ret += "+";
+    start_.write(ret);
+    if (!finish_.isNULL()) {
+        ret += " ";
+        finish_.write(ret);
+        ret += " ";
+        incr_.write(ret);
+    }
+}
+
+std::string TimeSeries::dump() const {
+    std::stringstream ss;
+    ss << toString();
+    ss << " isValid_(" << isValid_ << ")";
+    ss << " nextTimeSlot_(" << nextTimeSlot_.toString() << ")";
+    ss << " relativeDuration_(" << to_simple_string(relativeDuration_) << ")";
+    ss << " lastTimeSlot_(" << to_simple_string(lastTimeSlot_) << ")";
+    ss << " suiteTimeAtReque_(" << suiteTimeAtReque_.toString() << ")";
+    return ss.str();
+}
+
+bool TimeSeries::checkInvariants(std::string& errormsg) const {
+    if (!finish_.isNULL()) {
+        if (incr_.isNULL()) {
+            errormsg += "TimeSeries::checkInvariants increment cannot be NULL when we have a time series";
+            cout << errormsg << "  " << toString() << "\n";
+            return false;
+        }
+        if (incr_.hour() == 0 && incr_.minute() == 0) {
+            errormsg += "TimeSeries::checkInvariants increment must greater than zero";
+            cout << errormsg << "  " << toString() << "\n";
+            return false;
+        }
+
+        if (start_.duration() > finish_.duration()) {
+            errormsg += "TimeSeries::checkInvariants Invalid time series start() > finish()";
+            cout << errormsg << "  " << toString() << "\n";
+            return false;
+        }
+
+        if (lastTimeSlot_ <= start_.duration() && lastTimeSlot_ > finish_.duration()) {
+            errormsg += "TimeSeries::checkInvariants Invalid last time slot";
+            cout << errormsg << "  " << toString() << "\n";
+            return false;
+        }
+    }
+    if (relativeDuration_.is_special()) {
+        errormsg += "TimeSeries::checkInvariants relativeDuration_ should not be special";
+        cout << errormsg << "  " << toString() << "\n";
+        return false;
+    }
+
+    if (!relativeToSuiteStart_ && relativeDuration_.total_seconds() > 0) {
+        errormsg += "TimeSeries::checkInvariants Can only have RelativeDuration if relativeToSuiteStart_ flag is set";
+        cout << errormsg << "  " << toString() << "\n";
+        return false;
+    }
+
+    return true;
+}
+
+std::ostream& operator<<(std::ostream& os, const TimeSeries* d) {
+    if (d) {
+        string s;
+        d->print(s);
+        os << s;
+        return os;
+    }
+    return os << "TimeSlot == NULL";
+}
+std::ostream& operator<<(std::ostream& os, const TimeSeries& d) {
+    string s;
+    d.print(s);
+    os << s;
+    return os;
+}
+
+ecf::TimeSeries TimeSeries::create(const std::string& str) {
+    std::vector<std::string> lineTokens;
+    Str::split(str, lineTokens);
+    size_t index = 0;
+    return TimeSeries::create(index, lineTokens);
+}
+
+std::string TimeSeries::state_to_string(bool isFree) const {
+    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e.
+    //                 task a; task b;
+    //             Hence use of '/' character
+    // time 10:30 # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
+    std::string ret;
+    write_state(ret, isFree);
+    return ret;
+}
+
+void TimeSeries::write_state(std::string& ret, bool isFree) const {
+    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e.
+    //                 task a; task b;
+    //             Hence use of '/' character
+    // time 10:30 # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
+    bool next_time_slot_changed    = (nextTimeSlot_ != start_);
+    bool relative_duration_changed = (!relativeDuration_.is_special() && relativeDuration_.total_seconds() != 0);
+    if (isFree || !isValid_ || next_time_slot_changed || relative_duration_changed) {
+        ret += " #";
+        if (isFree)
+            ret += " free";
+        if (!isValid_)
+            ret += " isValid:false";
+        if (next_time_slot_changed) {
+            ret += " nextTimeSlot/";
+            ret += nextTimeSlot_.toString();
+        }
+        if (relative_duration_changed) {
+            ret += " relativeDuration/";
+            ret += to_simple_string(relativeDuration_);
+        }
+    }
+}
+
+void TimeSeries::write_state_for_gui(std::string& ret, bool isFree) const {
+    bool next_time_slot_changed    = (nextTimeSlot_ != start_);
+    bool relative_duration_changed = (!relativeDuration_.is_special() && relativeDuration_.total_seconds() != 0);
+    if (isFree || !isValid_ || next_time_slot_changed || relative_duration_changed) {
+        ret += " #";
+        if (isFree)
+            ret += " free";
+        if (!isValid_)
+            ret += " expired";
+        if (next_time_slot_changed) {
+            ret += " nextTimeSlot=";
+            ret += nextTimeSlot_.toString();
+        }
+        if (relative_duration_changed) {
+            ret += " relDuration=";
+            ret += to_simple_string(relativeDuration_);
+        }
+    }
+}
+
+void TimeSeries::parse_state(size_t index, const std::vector<std::string>& lineTokens, ecf::TimeSeries& ts) {
+    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e.
+    //                 task a; task b;
+    //             Hence use of '/' character
+    //
+    // Here free is attribute state & not time series state hence ignore
+    // time 10:30              # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
+    // cron 10:00 20:00 01:00  # free isValid:false nextTimeSlot/10:30 relativeDuration/00:00:00
+    bool comment_fnd        = false;
+    size_t line_tokens_size = lineTokens.size();
+    for (size_t i = index; i < line_tokens_size; i++) {
+        if (comment_fnd) {
+            if (lineTokens[i] == "isValid:false") {
+                ts.isValid_ = false;
+                continue;
+            }
+            if (lineTokens[i].find("nextTimeSlot") != std::string::npos) {
+                std::string nextTimeSlot;
+                if (Extract::split_get_second(lineTokens[i], nextTimeSlot, '/')) {
+                    // Note: we do *not* check for valid time since nextTimeSlot, relative times can be incremented past
+                    // 24 hours, i.e. cron +00:00 18:00 06:00 # isValid:false nextTimeSlot/523:00
+                    int startHour = -1;
+                    int startMin  = -1;
+                    getTime(nextTimeSlot, startHour, startMin, false /*check_time*/);
+                    ts.nextTimeSlot_ = TimeSlot(startHour, startMin);
+                }
+                else
+                    throw std::runtime_error("TimeSeries::parse_state: could not extract state.");
+            }
+            if (lineTokens[i].find("relativeDuration") != std::string::npos) {
+                std::string relativeDuration;
+                if (Extract::split_get_second(lineTokens[i], relativeDuration, '/')) {
+                    ts.relativeDuration_ = time_duration(duration_from_string(relativeDuration));
+                }
+                else
+                    throw std::runtime_error("TimeSeries::parse_state: could not extract state.");
+            }
+        }
+        if (lineTokens[i] == "#")
+            comment_fnd = true;
+    }
+    ts.compute_last_time_slot();
+}
+
+ecf::TimeSeries TimeSeries::create(size_t& index, const std::vector<std::string>& lineTokens, bool read_state) {
+    size_t line_tokens_size = lineTokens.size();
+    assert(index < line_tokens_size);
+    int startHour = -1;
+    int startMin  = -1;
+
+    // cron 10:00 20:00 01:00
+    // index is on 10:00, ie index should have value of 1 in this case
+    string startStr = lineTokens[index];
+    bool relative   = false;
+    if (startStr[0] == '+') {
+        relative = true;
+        startStr.erase(startStr.begin()); // remove leading +
+                                          // string must be of form 12:00
+    }
+    getTime(startStr, startHour, startMin);
+    TimeSlot start(startHour, startMin);
+
+    index++; // on 20:00
+    if (index < line_tokens_size && lineTokens[index][0] != '#') {
+
+        // if third token is not a comment the time must be of the form
+        // cron 10:00 20:00 01:00
+        if (index + 1 >= line_tokens_size)
+            throw std::runtime_error("TimeSeries::create: Invalid time series :");
+
+        int finishHour = -1;
+        int finishMin  = -1;
+        getTime(lineTokens[index], finishHour, finishMin);
+        TimeSlot finish(finishHour, finishMin);
+
+        index++;
+
+        int incrHour = -1;
+        int incrMin  = -1;
+        getTime(lineTokens[index], incrHour, incrMin);
+        TimeSlot incr(incrHour, incrMin);
+
+        if (read_state) {
+            TimeSeries ts(start, finish, incr, relative);
+            parse_state(index, lineTokens, ts);
+            return ts;
+        }
+        return TimeSeries(start, finish, incr, relative);
+    }
+
+    if (read_state) {
+        TimeSeries ts(start, relative);
+        parse_state(index, lineTokens, ts);
+        return ts;
+    }
+    return TimeSeries(start, relative);
+}
+
+bool TimeSeries::getTime(const std::string& time, int& hour, int& min, bool check_time) {
+    // HH:MM
+    // +HH:MM  for other clients
+    size_t colonPos = time.find_first_of(':');
+    if (colonPos == string::npos)
+        throw std::runtime_error("TimeSeries::getTime: Invalid time :'" + time + "'");
+
+    std::string theHour;
+    bool relative = false;
+    if (time[0] == '+') {
+        relative = true;
+        theHour  = time.substr(1, colonPos - 1);
+    }
+    else
+        theHour = time.substr(0, colonPos);
+
+    std::string theMin = time.substr(colonPos + 1);
+
+    if (check_time && theHour.size() != 2)
+        throw std::runtime_error("TimeSeries::getTime: Invalid hour :" + theHour);
+    if (theMin.size() != 2)
+        throw std::runtime_error("TimeSeries::getTime: Invalid minute :" + theMin);
+
+    hour = Extract::theInt(theHour, "TimeSeries::getTime: hour must be a integer : " + theHour);
+    min  = Extract::theInt(theMin, "TimeSeries::getTime: minute must be integer : " + theMin);
+
+    if (check_time)
+        testTime(hour, min);
+    return relative;
+}
+
+void TimeSeries::testTime(int hour, int minute) {
+    if (hour == -1 || minute == -1) {
+        throw std::runtime_error("TimeSeries::testTime: Failed to extract time");
+    }
+    if (hour < 0 || hour > 23) {
+        std::stringstream ss;
+        ss << "TimeSeries::testTime: time hour(" << hour << ") must be in range 0-23";
+        throw std::runtime_error(ss.str());
+    }
+    if (minute < 0 || minute > 59) {
+        std::stringstream ss;
+        ss << "TimeSeries::testTime: time minute(" << minute << ") must be in range 0-59";
+        throw std::runtime_error(ss.str());
+    }
+}
+
+template <class Archive>
+void TimeSeries::serialize(Archive& ar, std::uint32_t const /*version*/) {
+    ar(CEREAL_NVP(start_));
+    CEREAL_OPTIONAL_NVP(ar, finish_, [this]() { return !finish_.isNULL(); });
+    CEREAL_OPTIONAL_NVP(ar, incr_, [this]() { return !incr_.isNULL(); });
+    CEREAL_OPTIONAL_NVP(ar, nextTimeSlot_, [this]() { return !nextTimeSlot_.isNULL() && nextTimeSlot_ != start_; });
+    CEREAL_OPTIONAL_NVP(
+        ar, relativeDuration_, [this]() { return relativeDuration_ != boost::posix_time::time_duration(0, 0, 0, 0); });
+    CEREAL_OPTIONAL_NVP(ar, relativeToSuiteStart_, [this]() { return relativeToSuiteStart_; });
+    CEREAL_OPTIONAL_NVP(ar, isValid_, [this]() { return !isValid_; });
+
+    if (Archive::is_loading::value) {
+        if (nextTimeSlot_.isNULL())
+            nextTimeSlot_ = start_;
+        if (!finish_.isNULL())
+            compute_last_time_slot();
+    }
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(TimeSeries);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/TimeSeries.hpp 5.13.0-1/libs/core/src/ecflow/core/TimeSeries.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/TimeSeries.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/TimeSeries.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,211 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_TimeSeries_HPP
+#define ecflow_core_TimeSeries_HPP
+
+///
+/// \brief Represents a set of time instants (possibly just one)
+///
+
+#include <cstdint>
+#include <vector>
+
+#include <boost/date_time/posix_time/posix_time.hpp>
+
+#include "ecflow/core/TimeSlot.hpp"
+
+namespace ecf {
+class Calendar;
+} // namespace ecf
+
+namespace ecf {
+/// TimeSeries can have a single time slot or a series of time slots
+///
+///
+/// We need nextTimeSlot_ data member to record the next valid time slot, otherwise when
+/// we have a time series, all times within the time series would be valid for
+/// Job submission. We do not know how long a job will run, hence when incrementing
+/// the nextTimeSlot_, we need the *NEXT* available time slot *after* the current calendar time.
+///
+/// Usage pattern is :
+///           TimeSeries.calendarChanged()   // Called every minute. Calls isFree(). Once free we stay free, until
+///           requeue.
+///                                          // At midnight clear time expiration and reset next time slot
+///           TimeSeries.isFree(..)          // called when node is QUEUED:
+///                                          // during dependency evaluation, checks next time slot, against calendar
+///                                          time
+///                                          // Once free a node stays free, until requeue()
+///           TimeSeries.checkForRequeue();  // called when node is COMPLETE: Checks if next available time slot is
+///           valid
+///                                          // *Must* return false for last time slot
+///                                          // ECFLOW-130 jobs that start before midnight and finish after midnight
+///                                          should not requeue
+///           TimeSeries.requeue();          // called when node is re-queued.
+///                                          // Sets value to next valid time slot after calendar time.
+///                                          // Can *expire* the time, relies on TimeSeries.calendarChanged() to clear
+///                                          time expiration
+///                                          // after midnight
+/// ECFLOW-130 jobs that start before midnight and finish after midnight should not requeue
+
+// Use compiler, destructor, copy constructor and assignment operator
+class TimeSeries {
+public:
+    TimeSeries();
+    TimeSeries(int hour, int minute, bool relative = false);
+    explicit TimeSeries(const TimeSlot&, bool relative = false);
+    TimeSeries(const TimeSlot& start, const TimeSlot& finish, const TimeSlot& incr, bool relative = false);
+
+    bool operator<(const TimeSeries& rhs) const;
+
+    // returns true if a state change is made
+    // Will clear time expiration flag at midnight
+    bool calendarChanged(const ecf::Calendar& c);
+
+    // relative duration stored locally since it can be reset, when used with repeats
+    // returns true if relative duration is reset/ i.e state change has been made
+    bool resetRelativeDuration();
+    void reset_only();
+    void reset(const ecf::Calendar& c);
+
+    // Increment time series. Will find the next time slot after current calendar
+    // record the current suite time, to check of jobs finish after midnight
+    void requeue(const ecf::Calendar& c, bool reset_next_time_slot = true);
+
+    // Since we can miss next time slot , allow its computation for the
+    // use with why command, returns a NULL timeslot if next time is invalid
+    // This functionality will mirror the requeue(..) function
+    TimeSlot compute_next_time_slot(const ecf::Calendar& c) const;
+
+    // Return true calendar is before or within scheduled time
+    bool requeueable(const ecf::Calendar& c) const;
+
+    /// if relativeToSuiteStart returns the relative duration, else returns calendar suite time of day.
+    /// The returned resolution is in minutes
+    boost::posix_time::time_duration duration(const ecf::Calendar& calendar) const;
+
+    /// If time has expired, returns false
+    /// Note: relative means relative to suite start, or relative to the beginning of repeated node.
+    /// Is of the form hh:mm.   This means relative has a range 00:00->99.59
+    /// For a single slot time series, should not be re queued again, and hence
+    /// should fail checkForRequeue. Likewise when the the current value is
+    /// the finish, then node should also not be re queued, otherwise the
+    /// node will be stuck in queued state.
+    bool isFree(const ecf::Calendar& calendar) const;
+
+    /// For single slot time based attributes we need additional context (i.e the_min,the_max parameter)
+    /// in order to determine whether we should re-queue.
+    /// Additionally when we have a time range, what if the last jobs runs over midnight. In this case
+    /// we need to return false. i.e do not re-queue ECFLOW-130
+    bool checkForRequeue(const ecf::Calendar& calendar,
+                         const TimeSlot& the_min,
+                         const TimeSlot& the_max,
+                         bool cmd_context = false) const;
+
+    void min_max_time_slots(TimeSlot& the_min, TimeSlot& the_max) const;
+
+    // Called when explicitly Free holding time dependency. via FreeDepCmd
+    // We want to avoid the next time slot.
+    void miss_next_time_slot();
+
+    void why(const ecf::Calendar&, std::string& theReasonWhy) const;
+
+    bool hasIncrement() const { return !finish_.isNULL(); }
+    const TimeSlot& start() const { return start_; }
+    const TimeSlot& finish() const { return finish_; }
+    const TimeSlot& incr() const { return incr_; }
+    const TimeSlot& value() const { return nextTimeSlot_; }
+    bool relative() const { return relativeToSuiteStart_; }
+    void free_slots(std::vector<boost::posix_time::time_duration>&) const;
+
+    void print(std::string&) const;
+    bool operator==(const TimeSeries& rhs) const;
+    bool operator!=(const TimeSeries& rhs) const { return !operator==(rhs); }
+    bool structureEquals(const TimeSeries& rhs) const;
+
+    /// returns true if no time specified
+    bool isNULL() const { return start_.isNULL(); }
+
+    std::string state_to_string(bool isFree) const;
+    void write_state(std::string&, bool free) const;
+    void write_state_for_gui(std::string&, bool free) const;
+    std::string toString() const;
+    void write(std::string&) const;
+    std::string dump() const;
+    bool checkInvariants(std::string& errormsg) const;
+
+    /// expects HH:MM or +HH:MM will throw std:runtime_error for errors,
+    /// *if* hour not in range(0-24), minutes(0-59), *and* check_time parameter is enabled
+    static bool getTime(const std::string& time, int& hour, int& min, bool check_time = true);
+
+    /// extract string like
+    ///     time +00:00 20:00 00:10 # this is a comment which will be ignored. index = 1
+    ///     time +20:00        // index = 1
+    ///     today 20:00        // index = 1
+    ///     +00:00 20:00 00:10 // index = 0
+    ///     +20:00             // index = 0
+    /// will throw std:runtime_error for errors
+    /// will assert if index >= lineTokens.size()
+    static ecf::TimeSeries create(size_t& index, // where we should start
+                                  const std::vector<std::string>& lineTokens,
+                                  bool read_state = false);
+
+    // like above but string should not contain "time"
+    static ecf::TimeSeries create(const std::string& str);
+
+    // Parse state associated with the time series: Ignores attributes like free.
+    static void parse_state(size_t index, const std::vector<std::string>& lineTokens, ecf::TimeSeries& ts);
+    void set_isValid(bool b) { isValid_ = b; }                          // for test only
+    void set_next_time_slot(const TimeSlot& ts) { nextTimeSlot_ = ts; } // needed for test only
+    const TimeSlot& get_next_time_slot() const { return nextTimeSlot_; }
+
+    // Is the time still valid, return false means time has expired.
+    bool is_valid() const { return isValid_; }
+
+private:
+    static void testTime(int hour, int minute);
+
+    // HANDLE CASE WHERE FINISH MINUTES IS NOT DIVISIBLE BY THE INCREMENT
+    // time 00:00 23:59 00:10  last valid time is 23:50
+    // time 00:30 23:59 04:00  last valid time is 20:30
+    // The last valid time here is 23:50/20:30 must return false, to stop node being
+    // stuck in queued mode In the case where the FINISH is NOT a multiple of the increment
+    // Need a different mechanism to determine the end.
+    void compute_last_time_slot(); // only call for series
+
+    bool match_duration_with_time_series(const boost::posix_time::time_duration& relative_or_real_td) const;
+
+private:
+    TimeSlot start_;
+    TimeSlot finish_;
+    TimeSlot incr_;
+    TimeSlot nextTimeSlot_;             // nextTimeSlot_ >= start && is incremented by incr
+    mutable TimeSlot suiteTimeAtReque_; // NOT persisted, check of day change, between requeue -> checkForRequeue, when
+                                        // we have series
+    boost::posix_time::time_duration relativeDuration_;
+    boost::posix_time::time_duration lastTimeSlot_; // Only used when we have a series, can be generated
+    bool relativeToSuiteStart_{false};
+    bool isValid_{true}; // Needed for single slot to avoid multiple jobs submissions
+
+private:
+    // Note: isValid_      is persisted for use by why() command on the client side.
+    // Note: nextTimeSlot_ is persisted for use by why() command on the client side.
+    // Note: relativeDuration_ is persisted for use by why() command on the client side.
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const /*version*/);
+};
+
+std::ostream& operator<<(std::ostream& os, const TimeSeries*);
+std::ostream& operator<<(std::ostream& os, const TimeSeries&);
+
+} // namespace ecf
+
+#endif /* ecflow_core_TimeSeries_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/TimeSlot.cpp 5.13.0-1/libs/core/src/ecflow/core/TimeSlot.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/TimeSlot.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/TimeSlot.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,104 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/TimeSlot.hpp"
+
+#include <ostream>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace boost::posix_time;
+
+namespace ecf {
+
+///////////////////////////////////////////////////////////////////////////////////////////
+
+bool TimeSlot::operator<(const TimeSlot& rhs) const {
+    if (h_ < rhs.hour())
+        return true;
+    if (h_ == rhs.hour()) {
+        return m_ < rhs.minute();
+    }
+    return false;
+}
+
+bool TimeSlot::operator>(const TimeSlot& rhs) const {
+    if (h_ > rhs.hour())
+        return true;
+    if (h_ == rhs.hour()) {
+        return m_ > rhs.minute();
+    }
+    return false;
+}
+
+bool TimeSlot::operator<=(const TimeSlot& rhs) const {
+    if (operator<(rhs))
+        return true;
+    return operator==(rhs);
+}
+
+bool TimeSlot::operator>=(const TimeSlot& rhs) const {
+    if (operator>(rhs))
+        return true;
+    return operator==(rhs);
+}
+
+std::string TimeSlot::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void TimeSlot::write(std::string& ret) const {
+    if (isNULL()) {
+        ret += "00:00";
+        return;
+    }
+
+    if (h_ < 10)
+        ret += "0";
+    ret += ecf::convert_to<std::string>(h_);
+
+    ret += Str::COLON();
+    if (m_ < 10)
+        ret += "0";
+    ret += ecf::convert_to<std::string>(m_);
+}
+
+boost::posix_time::time_duration TimeSlot::duration() const {
+    assert(!isNULL());
+    return boost::posix_time::time_duration(hours(h_) + minutes(m_));
+}
+
+std::ostream& operator<<(std::ostream& os, const TimeSlot* d) {
+    if (d) {
+        std::string s;
+        d->print(s);
+        os << s;
+        return os;
+    }
+    return os << "TimeSlot == NULL";
+}
+std::ostream& operator<<(std::ostream& os, const TimeSlot& d) {
+    std::string s;
+    d.print(s);
+    os << s;
+    return os;
+}
+
+template <class Archive>
+void TimeSlot::serialize(Archive& ar) {
+    ar(CEREAL_NVP(h_), CEREAL_NVP(m_));
+}
+CEREAL_TEMPLATE_SPECIALIZE(TimeSlot);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/TimeSlot.hpp 5.13.0-1/libs/core/src/ecflow/core/TimeSlot.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/TimeSlot.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/TimeSlot.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,73 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_TimeSlot_HPP
+#define ecflow_core_TimeSlot_HPP
+
+#include <iosfwd>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+namespace cereal {
+class access;
+}
+
+namespace ecf {
+
+// Use compiler , generated destructor, assignment,  copy constructor
+// *relative* times can extend to a maximum of 99 hours and 59 seconds
+//
+// TimeSlot is used in many other attributes, i.e. like AutoCancelAttr,AutoArchiveAttr
+// in this case user can specify days, which we convert to hours, hence it
+// is possible for a TimeSlot hour to have any integer value
+class TimeSlot {
+public:
+    static std::string type() { return "TimeSlot"; }
+    TimeSlot() = default;
+    TimeSlot(int hour, int min) : h_(hour), m_(min) { assert(hour >= 0 && min >= 0); }
+    explicit TimeSlot(const boost::posix_time::time_duration& td) : h_(td.hours()), m_(td.minutes()) {
+        assert(h_ < 60 && m_ < 60);
+    }
+
+    bool operator==(const TimeSlot& rhs) const { return ((h_ == rhs.h_) && (m_ == rhs.m_)); }
+    bool operator!=(const TimeSlot& rhs) const { return !operator==(rhs); }
+
+    bool operator<(const TimeSlot& rhs) const;
+    bool operator>(const TimeSlot& rhs) const;
+    bool operator<=(const TimeSlot& rhs) const;
+    bool operator>=(const TimeSlot& rhs) const;
+
+    int hour() const { return h_; }
+    int minute() const { return m_; }
+    bool isNULL() const { return (h_ == -1 && m_ == -1); }
+    void print(std::string& os) const { write(os); }
+
+    /// returns the corresponding duration.
+    boost::posix_time::time_duration duration() const;
+
+    // returns  struct in the format hh:mm
+    std::string toString() const;
+    void write(std::string&) const;
+
+private:
+    int h_{-1};
+    int m_{-1};
+
+    // *IMPORTANT* no version for a simple class
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+std::ostream& operator<<(std::ostream& os, const TimeSlot*);
+std::ostream& operator<<(std::ostream& os, const TimeSlot&);
+} // namespace ecf
+
+#endif /* ecflow_core_TimeSlot_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/TimeStamp.cpp 5.13.0-1/libs/core/src/ecflow/core/TimeStamp.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/TimeStamp.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/TimeStamp.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/TimeStamp.hpp"
+
+#include <ctime>
+
+namespace ecf {
+namespace TimeStamp {
+
+namespace {
+
+struct regular
+{
+    static constexpr char const* format = "[%H:%M:%S %d.%m.%Y] ";
+    static constexpr size_t size        = 23;
+};
+
+struct brief
+{
+    static constexpr char const* format = "[%H:%M:%S %d.%m] ";
+    static constexpr size_t size        = 18;
+};
+
+template <typename FMT = regular>
+std::string format_now() {
+    std::time_t now = std::time(nullptr);
+    char buffer[FMT::size];
+    std::strftime(buffer, sizeof(buffer), FMT::format, std::localtime(&now));
+    return buffer;
+}
+
+} // namespace
+
+std::string now() {
+    return format_now();
+}
+
+void now(std::string& time_stamp) {
+    time_stamp = format_now();
+}
+
+void now_in_brief(std::string& time_stamp) {
+    time_stamp = format_now<brief>();
+}
+
+} // namespace TimeStamp
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/TimeStamp.hpp 5.13.0-1/libs/core/src/ecflow/core/TimeStamp.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/TimeStamp.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/TimeStamp.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_TimeStamp_HPP
+#define ecflow_core_TimeStamp_HPP
+
+#include <string>
+
+namespace ecf {
+namespace TimeStamp {
+
+/// Generate a 'regular' time stamp.
+///
+/// Format specified as
+///  - "[%02d:%02d:%02d %d.%d.%d] ", considering "[hour:min:sec day.month.year]
+///  "
+///
+/// Results in the following examples
+///  - "[05:26:20 29.10.2014] "
+///  - "[05:26:20 17.1.2023] "
+///
+std::string now();
+void now(std::string&);
+
+/// Generate a 'brief' time stamp.
+///
+/// Format specified as
+///  - "[%02d:%02d:%02d %d.%d] ", considering "[hour:min:sec day.month] "
+///
+/// Results in the following examples
+///  - "[05:26:20 29.10] "
+///  - "[05:26:20 17.1] "
+///
+void now_in_brief(std::string&);
+
+} // namespace TimeStamp
+} // namespace ecf
+
+#endif /* ecflow_core_TimeStamp_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/User.cpp 5.13.0-1/libs/core/src/ecflow/core/User.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/User.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/User.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,94 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/User.hpp"
+
+#include <cassert>
+#include <cerrno>  // for errno()
+#include <cstring> // for strerror()
+#include <pwd.h>   // for getpwuid()
+#include <sstream>
+#include <stdexcept>
+#include <unistd.h> // ofr getuid()
+
+#include "ecflow/core/Enumerate.hpp"
+
+namespace ecf {
+
+namespace detail {
+
+template <>
+struct EnumTraits<User::Action>
+{
+    using underlying_t = std::underlying_type_t<User::Action>;
+
+    static constexpr std::array map = std::array{
+        // clang-format off
+        std::make_pair(User::Action::FOB, "fob"),
+        std::make_pair(User::Action::FAIL, "fail"),
+        std::make_pair(User::Action::ADOPT, "adopt"),
+        std::make_pair(User::Action::REMOVE, "remove"),
+        std::make_pair(User::Action::BLOCK, "block"),
+        std::make_pair(User::Action::KILL, "kill"),
+        // clang-format on
+    };
+    static constexpr size_t size = map.size();
+
+    static_assert(EnumTraits<User::Action>::size == map.back().first + 1);
+};
+
+} // namespace detail
+
+bool User::valid_user_action(const std::string& s) {
+    return Enumerate<User::Action>::is_valid(s);
+}
+
+User::Action User::user_action(const std::string& s) {
+    return Enumerate<User::Action>::to_enum(s).value_or(User::BLOCK);
+}
+
+std::string User::to_string(User::Action uc) {
+    if (auto found = Enumerate<User::Action>::to_string(uc); found) {
+        return std::string{found.value()};
+    }
+    assert(false);
+    return std::string();
+}
+
+std::string User::login_name() {
+    static std::string the_user_name;
+    if (the_user_name.empty()) {
+
+        // Get the uid of the running process and use it to get a record from /etc/passwd */
+        // getuid() cannot fail, but getpwuid can fail.
+        errno                         = 0;
+        uid_t real_user_id_of_process = getuid();
+        struct passwd* thePassWord    = getpwuid(real_user_id_of_process);
+        if (thePassWord == nullptr) {
+            if (errno != 0) {
+                std::string theError = strerror(errno);
+                throw std::runtime_error("UserCmd::get_user: could not determine user name. Because: " + theError);
+            }
+
+            std::stringstream ss;
+            ss << "UserCmd::get_user: could not determine user name for uid " << real_user_id_of_process;
+            throw std::runtime_error(ss.str());
+        }
+
+        the_user_name = thePassWord->pw_name; // equivalent to the login name
+        if (the_user_name.empty()) {
+            throw std::runtime_error(
+                "UserCmd::get_user: could not determine user name. Because: thePassWord->pw_name is empty");
+        }
+    }
+    return the_user_name;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/User.hpp 5.13.0-1/libs/core/src/ecflow/core/User.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/User.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/User.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_User_HPP
+#define ecflow_core_User_HPP
+
+#include <string>
+
+namespace ecf {
+
+class User {
+public:
+    enum Action { FOB, FAIL, ADOPT, REMOVE, BLOCK, KILL };
+
+    // Disable default construction
+    User(const User&) = delete;
+    // Disable copy (and move) semantics
+    const User& operator=(const User&) = delete;
+    User()                             = delete;
+
+    static bool valid_user_action(const std::string&);
+    static Action user_action(const std::string&);
+    static std::string to_string(Action);
+
+    // return login name: will throw if there are any errors
+    static std::string login_name();
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_User_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Version.cpp 5.13.0-1/libs/core/src/ecflow/core/Version.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/Version.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Version.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,127 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Version.hpp"
+
+#include <sstream>
+
+#include <boost/version.hpp>
+#include <cereal/version.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/ecflow_version.h"
+
+namespace ecf {
+
+// ********************************************************************
+// IMPORTANT:
+// The version number is extracted externally.
+//   see ACore/doc/extracting_version_number.ddoc
+//
+//   See ACore/src/ecflow_version.h
+//   This file is generated when cmake is run, i.e.
+//     `sh -x $WK/cmake.sh debug`
+//
+// When changing the version change remember to:
+//    - re-login into remote system to update ECFLOW_INSTALL_DIR & ECFLOW_PYTHON_INSTALL_DIR
+//      required for interactive install
+//
+// To Install a new version on all the different platforms:
+//  . build_scripts/nightly/quick_install_.sh
+// This is because the definition hold's the last version.
+// Hence, we must rerun to update the version.
+//
+// ************************************************************************************
+// Use  <minor_number>rc<number> for release candidates, Once release we revert back:
+//      0rc1    -> 0
+//      10rc3   -> 10
+// ************************************************************************************
+//
+// **Please update file history.ddoc with the changed made for each release ***
+// ********************************************************************
+#ifdef DEBUG
+const std::string Version::TAG = " (debug)"; // Old tag: beta(debug)
+#else
+const std::string Version::TAG = ""; // Old tag: beta
+#endif
+
+// See: http://www.cmake.org/cmake/help/cmake_tutorial.html
+// For defining version numbers. This is done is a separate file
+// that is then included
+std::string Version::description() {
+    std::stringstream ss;
+    ss << "Ecflow" << Version::TAG << " version(" << ECFLOW_RELEASE << "." << ECFLOW_MAJOR << "." << ECFLOW_MINOR;
+
+    ss << ") boost(" << Version::boost() << ")";
+    std::string the_comp = compiler();
+    if (!the_comp.empty())
+        ss << " compiler(" << the_comp << ")";
+
+    ss << " protocol(JSON cereal " << CEREAL_VERSION_MAJOR << "." << CEREAL_VERSION_MINOR << "." << CEREAL_VERSION_PATCH
+       << ")";
+
+#ifdef ECF_OPENSSL
+    ss << " openssl(enabled)";
+#endif
+
+    ss << " Compiled on " << __DATE__ << " " << __TIME__;
+    return ss.str();
+}
+
+std::string Version::version() {
+    std::string ret = "ecflow_";
+    ret += ecf::convert_to<std::string>(ECFLOW_RELEASE);
+    ret += "_";
+    ret += ecf::convert_to<std::string>(ECFLOW_MAJOR);
+    ret += "_";
+    ret += ecf::convert_to<std::string>(ECFLOW_MINOR);
+    return ret;
+}
+
+std::string Version::raw() {
+    std::string ret = ecf::convert_to<std::string>(ECFLOW_RELEASE);
+    ret += ".";
+    ret += ecf::convert_to<std::string>(ECFLOW_MAJOR);
+    ret += ".";
+    ret += ecf::convert_to<std::string>(ECFLOW_MINOR);
+    return ret;
+}
+
+std::string Version::boost() {
+    std::stringstream ss;
+    ss << BOOST_VERSION / 100000 << "."     // major version
+       << BOOST_VERSION / 100 % 1000 << "." // minor version
+       << BOOST_VERSION % 100;              // patch level
+    return ss.str();
+}
+
+std::string Version::compiler() {
+    std::stringstream ss;
+#if defined(_AIX)
+    ss << "aix " << __IBMCPP__;
+#elif defined(HPUX)
+    ss << "aCC " << __HP_aCC; // type aCC +help, this will show compiler manual, search for Predefined Macros
+#else
+    #if defined(__clang__)
+    //  To find the list of defines for clang use:
+    //  echo | /usr/local/apps/clang/current/bin/clang++ -dM -E -
+    ss << "clang " << __clang_major__ << "." << __clang_minor__;
+    #elif defined(__INTEL_COMPILER)
+    ss << "intel " << __INTEL_COMPILER;
+    #elif defined(_CRAYC)
+    ss << "cray " << _CRAYC;
+    #else
+    ss << "gcc " << __GNUC__ << "." << __GNUC_MINOR__ << "." << __GNUC_PATCHLEVEL__;
+    #endif
+#endif
+    return ss.str();
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/Version.hpp 5.13.0-1/libs/core/src/ecflow/core/Version.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/Version.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/Version.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_Version_HPP
+#define ecflow_core_Version_HPP
+
+///
+/// \brief Holds the version of ECFlow. Checked against definition file.
+///         For each major release the major number should be incremented.
+///
+/// If the parsing comes across a construct it does not recognize, then
+/// an exception is thrown. i.e if a construct added in release 2.0 of ECF
+/// is read in by version 1.0 of ECF. The exception should indicate the
+/// current release
+///
+
+#include <string>
+
+namespace ecf {
+
+class Version {
+public:
+    // Disable default construction
+    Version() = delete;
+    // Disable copy (and move) semantics
+    Version(const Version&)                  = delete;
+    const Version& operator=(const Version&) = delete;
+
+    /// Outputs a string of the form:
+    /// ECF <tag> version release_.major_.minor_
+    static std::string description();
+
+    /// Outputs string of form: ecflow_<release>_<major>_<minor>
+    /// This could be used by install
+    static std::string version();
+
+    /// Outputs string of form: <release>.<major>.<minor>
+    static std::string raw();
+
+private:
+    static const std::string TAG; // alpha, beta, release
+
+    /// return version of the boost library
+    static std::string boost();
+
+    // Return the version of the compiler. Can return empty string
+    static std::string compiler();
+};
+
+} // namespace ecf
+
+#endif /* ecflow_core_Version_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/WhiteListFile.cpp 5.13.0-1/libs/core/src/ecflow/core/WhiteListFile.cpp
--- 5.12.4-1/libs/core/src/ecflow/core/WhiteListFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/WhiteListFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,603 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/WhiteListFile.hpp"
+
+#include <iostream>
+#include <vector>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/User.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+WhiteListFile::WhiteListFile() = default;
+
+WhiteListFile::~WhiteListFile() = default;
+
+bool WhiteListFile::verify_read_access(const std::string& user) const {
+    // Please note that the presence of * , even with paths means all users, have access
+    // Command like --news has no paths, hence allow access to all if * specified
+    if (all_users_have_read_access_)
+        return true;
+    if (users_with_read_access_.empty() && users_with_write_access_.empty())
+        return true;
+
+    if (users_with_read_access_.find(user) != users_with_read_access_.end())
+        return true;
+    if (users_with_read_access_.find("*") != users_with_read_access_.end())
+        return true;
+
+    // user with write access also have read access
+    if (users_with_write_access_.find(user) != users_with_write_access_.end())
+        return true;
+    if (users_with_write_access_.find("*") != users_with_write_access_.end())
+        return true;
+    return false;
+}
+
+bool WhiteListFile::verify_write_access(const std::string& user) const {
+    if (all_users_have_write_access_)
+        return true;
+    if (users_with_read_access_.empty() && users_with_write_access_.empty())
+        return true;
+
+    if (verify_path_access(user, Str::EMPTY(), users_with_write_access_))
+        return true;
+    if (verify_path_access("*", Str::EMPTY(), users_with_write_access_))
+        return true;
+    return false;
+}
+
+bool WhiteListFile::verify_read_access(const std::string& user, const std::string& path) const {
+    if (all_users_have_read_access_)
+        return true;
+    if (users_with_read_access_.empty() && users_with_write_access_.empty())
+        return true;
+    if (verify_path_access(user, path, users_with_read_access_))
+        return true;
+    if (verify_path_access("*", path, users_with_read_access_))
+        return true;
+
+    // user with write access also have read access
+    if (verify_path_access(user, path, users_with_write_access_))
+        return true;
+    if (verify_path_access("*", path, users_with_write_access_))
+        return true;
+
+    return false;
+}
+
+bool WhiteListFile::verify_write_access(const std::string& user, const std::string& path) const {
+    if (all_users_have_write_access_)
+        return true;
+    if (users_with_read_access_.empty() && users_with_write_access_.empty())
+        return true;
+
+    if (verify_path_access(user, path, users_with_write_access_))
+        return true;
+    if (verify_path_access("*", path, users_with_write_access_))
+        return true;
+
+    return false;
+}
+
+bool WhiteListFile::verify_read_access(const std::string& user, const std::vector<std::string>& paths) const {
+    //   std::cout << "WhiteListFile::verify_read_access user " << user << " paths( ";
+    //   for(size_t i = 0; i < paths.size(); i++) { std::cout << paths[i] << " "; }
+    //   std::cout << ") \n";
+    //   std::cout << "  all_users_have_read_access_: " << all_users_have_read_access_ << "\n";
+    //   std::cout << "  users_with_read_access_.size(): " << users_with_read_access_.size() << "\n";
+    //   std::cout << "  users_with_write_access_.size(): " << users_with_write_access_.size() << "\n";
+    //   std::cout << dump_valid_users() << "\n\n";
+
+    if (all_users_have_read_access_)
+        return true;
+    if (users_with_read_access_.empty() && users_with_write_access_.empty())
+        return true;
+    if (verify_path_access(user, paths, users_with_read_access_))
+        return true;
+    if (verify_path_access("*", paths, users_with_read_access_))
+        return true;
+
+    // user with write access also have read access
+    if (verify_path_access(user, paths, users_with_write_access_))
+        return true;
+    if (verify_path_access("*", paths, users_with_write_access_))
+        return true;
+
+    return false;
+}
+
+bool WhiteListFile::verify_write_access(const std::string& user, const std::vector<std::string>& paths) const {
+    if (all_users_have_write_access_)
+        return true;
+    if (users_with_read_access_.empty() && users_with_write_access_.empty())
+        return true;
+    if (verify_path_access(user, paths, users_with_write_access_))
+        return true;
+    if (verify_path_access("*", paths, users_with_write_access_))
+        return true;
+    return false;
+}
+
+static bool path_access(const std::vector<std::string>& paths, const std::vector<std::string>& allowed_paths) {
+    if (allowed_paths.empty())
+        return true; // no paths are specified in PASSWORD file allow access
+
+    // Paths specified in PASSWORD file.
+    if (paths.empty())
+        return false; // INPUT user path empty deny access
+
+    // when we have a set of paths, supplied by the GUI. These can be random path selections
+    // Hence to allow access *ALL* paths need to pass access
+    //
+    // need to correctly check for subsets
+    //    allowed_paths              paths               valid
+    //    /ecflow                    /ecflow_1182        FALSE
+    //    /ecflow/fred               /ecflow/freddy      FALSE
+    //    /ecflow/fred               /ecflow/fred/me     TRUE
+
+    size_t allowed_paths_size = allowed_paths.size();
+    size_t paths_size         = paths.size();
+    for (size_t i = 0; i < paths_size; i++) {
+        const std::string& path          = paths[i];
+        bool found_path_in_allowed_paths = false;
+
+        for (size_t ap = 0; ap < allowed_paths_size; ap++) {
+            const std::string& allowed_path = allowed_paths[ap];
+            //         cout << "path " << path << "\n";
+            //         cout << "allowed_path " <<  allowed_path << "\n";
+            //         if (path.size() > allowed_paths[ap].size()) {
+            //            cout << "path[allowed_path.size()] " << path[ allowed_path.size()] << "\n";
+            //         }
+            if (path.find(allowed_path) == 0) {
+                if (path.size() > allowed_path.size() && path[allowed_path.size()] != '/') {
+                    // FALSE case above
+                    continue;
+                }
+
+                found_path_in_allowed_paths = true;
+                continue; // all paths must match, or fail
+            }
+        }
+        if (!found_path_in_allowed_paths)
+            return false;
+    }
+    return true;
+}
+
+static bool path_access(const std::string& path, const std::vector<std::string>& allowed_paths) {
+    if (allowed_paths.empty())
+        return true;
+    if (path.empty())
+        return false;
+
+    size_t allowed_paths_size = allowed_paths.size();
+    for (size_t ap = 0; ap < allowed_paths_size; ap++) {
+        const std::string& allowed_path = allowed_paths[ap];
+
+        if (path.find(allowed_path) == 0) {
+            // found path in allowed paths, check correct SUB_PATH
+            if (path.size() > allowed_path.size() && path[allowed_path.size()] != '/') {
+                // FALSE case above
+                continue;
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
+bool WhiteListFile::verify_path_access(const std::string& user,
+                                       const std::vector<std::string>& paths,
+                                       const mymap& user_path_map) const {
+    auto it = user_path_map.find(user);
+    if (it != user_path_map.end()) {
+        return path_access(paths, it->second);
+    }
+    return false;
+}
+
+bool WhiteListFile::verify_path_access(const std::string& user,
+                                       const std::string& path,
+                                       const mymap& user_path_map) const {
+    auto it = user_path_map.find(user);
+    if (it != user_path_map.end()) {
+        return path_access(path, it->second);
+    }
+    return false;
+}
+
+bool WhiteListFile::load(const std::string& file, bool debug, std::string& errorMsg) {
+    if (debug) {
+        std::cout << "  White list file " << file << " opening...\n";
+    }
+
+    white_list_file_             = file;
+    all_users_have_read_access_  = false;
+    all_users_have_write_access_ = false;
+    users_with_read_access_.clear();
+    users_with_write_access_.clear();
+
+    std::vector<std::string> lines;
+    if (File::splitFileIntoLines(white_list_file_, lines, true /* ignore empty lines */)) {
+
+        bool foundVersionNumber = false; // can read from version 4.4.5 onwards
+        size_t lines_size       = lines.size();
+        for (size_t i = 0; i < lines_size; ++i) {
+
+            if (lines[i].empty())
+                continue;
+
+            // ignore/remove all comments
+            if (lines[i][0] == '#')
+                continue;
+            std::string theLine           = lines[i];
+            string::size_type comment_pos = theLine.find("#");
+            if (comment_pos != std::string::npos) {
+                theLine.erase(comment_pos);
+            }
+
+            ecf::algorithm::trim(theLine); // remove leading and trailing spaces
+            std::vector<std::string> lineTokens;
+            Str::split(theLine, lineTokens);
+            if (lineTokens.empty())
+                continue;
+
+            // version should be at the start
+            if (!foundVersionNumber) {
+
+                if (!validateVersionNumber(lineTokens[0], errorMsg)) {
+                    std::stringstream ss;
+                    ss << " " << i + 1 << ": " << lines[i] << "\n";
+                    ss << "for ECF_LISTS file " << white_list_file_ << "\n";
+                    errorMsg += ss.str();
+                    return false;
+                }
+                foundVersionNumber = true;
+                continue;
+            }
+            else {
+                if (!add_user(lineTokens, errorMsg)) {
+                    return false;
+                }
+            }
+        }
+
+        // remove duplicates
+        mymap::iterator i;
+        for (i = users_with_read_access_.begin(); i != users_with_read_access_.end(); ++i) {
+            std::vector<std::string>& paths = (*i).second;
+            std::sort(paths.begin(), paths.end());
+            paths.erase(std::unique(paths.begin(), paths.end()), paths.end());
+        }
+        for (i = users_with_write_access_.begin(); i != users_with_write_access_.end(); ++i) {
+            std::vector<std::string>& paths = (*i).second;
+            std::sort(paths.begin(), paths.end());
+            paths.erase(std::unique(paths.begin(), paths.end()), paths.end());
+        }
+
+        if (debug)
+            std::cout << dump_valid_users() << "\n";
+
+        return true;
+    }
+
+    errorMsg += "Could not open file specified by ECF_LISTS ";
+    errorMsg += white_list_file_;
+    errorMsg += " (";
+    errorMsg += strerror(errno);
+    errorMsg += ")";
+    if (debug)
+        std::cout << dump_valid_users() << "\n";
+    return false;
+}
+
+std::string WhiteListFile::dump_valid_users() const {
+    std::stringstream ss;
+    ss << "ECF_LISTS = '" << white_list_file_ << "'\n";
+    if (users_with_read_access_.empty() && users_with_write_access_.empty())
+        ss << " No users specified. Everyone has read/write access\n";
+    if (all_users_have_read_access_)
+        ss << " All users have read access\n";
+    if (all_users_have_write_access_)
+        ss << " All users have write access\n";
+
+    mymap::const_iterator i;
+    for (i = users_with_read_access_.begin(); i != users_with_read_access_.end(); ++i) {
+        ss << " User: " << (*i).first << " ";
+        const std::vector<std::string>& paths = (*i).second;
+        for (const auto& path : paths)
+            ss << path << ",";
+        ss << " has read access\n";
+    }
+    for (i = users_with_write_access_.begin(); i != users_with_write_access_.end(); ++i) {
+        ss << " User: " << (*i).first << " ";
+        const std::vector<std::string>& paths = (*i).second;
+        for (const auto& path : paths)
+            ss << path << ",";
+        ss << " has read/write access\n";
+    }
+
+    return ss.str();
+}
+
+bool WhiteListFile::validateVersionNumber(const std::string& line, std::string& errorMsg) const {
+    // Expect 4.4.14, Current syntax in force after 4.4.5
+    // If first character is NUMERIC and we have dots
+    bool firstCharIsNumeric = Str::NUMERIC().find(line[0], 0) != string::npos;
+    if (firstCharIsNumeric && line.find(".") != string::npos) {
+
+        std::vector<std::string> versionNumberTokens;
+        Str::split(line, versionNumberTokens, ".");
+        if (versionNumberTokens.size() != 3) {
+            std::stringstream ss;
+            ss << "Expected version of the form <int>.<int>.<int> i.e 4.4.14. but found invalid version number\n";
+            errorMsg += ss.str();
+            return false;
+        }
+
+        try {
+            auto major = ecf::convert_to<int>(versionNumberTokens[0]);
+            auto minor = ecf::convert_to<int>(versionNumberTokens[1]);
+            auto part  = ecf::convert_to<int>(versionNumberTokens[2]);
+            if (major < 4) {
+                errorMsg += "Only white list files with a version >= 4.4.5 is supported\n";
+                return false;
+            }
+            if (major == 4 && minor < 4) {
+                errorMsg += "Only white list files with a version >= 4.4.5 is supported\n";
+                return false;
+            }
+            if (major == 4 && minor == 4 && part < 5) {
+                errorMsg += "Only white list files with a version >= 4.4.5 is supported\n";
+                return false;
+            }
+        }
+        catch (const ecf::bad_conversion&) {
+            errorMsg += "Invalid version number \n";
+            return false;
+        }
+
+        return true;
+    }
+
+    errorMsg += "The version number not found. The version number must appear before the users.\n";
+    return false;
+}
+
+bool WhiteListFile::add_user(std::vector<std::string>& tokens, std::string& error_msg) {
+    // # please note if the same user appear multiple times, then the access right are additive
+    // # Hence if the user has been given write access, then other change to access rights for
+    // # same user are ignored
+    //
+    // # These user have read and write access to the server
+    // uid1  # a comment
+    // uid2  # a comment
+    // cog   # a comment
+    //
+    // # Read only users
+    //-*     # *all* users have read access to *all* suites
+    //-fred
+    //
+    //*   # *all* user have read/write access, to *all* suites
+    //
+    // # access to suites
+    //-fred /suiteX  # user fred is only allowed read access to suiteX only
+    // bill    /suiteX,/suiteB # user bill is allowed read/write access to suiteX and suiteB only
+    //-*      /open   # all user are allowed access to suite /open
+    // joe    /        # has read/write access to everything, this same as 'joe' by itself
+    //*      /        # all users have read/write access
+    //*      /x,/y    # all user have read/write access to suite /x, /y
+
+    // Use of * by itself means *all* user have read/write access to *all* suites
+    if (all_users_have_write_access_)
+        return true;
+
+    if (tokens.size() == 1) {
+        std::string user = tokens[0];
+        if (user[0] == '-') {
+
+            // Read access
+            user.erase(user.begin());
+
+            // if we see -* all users have read access
+            if (user == "*") {
+                all_users_have_read_access_ = true;
+                users_with_read_access_.clear();
+            }
+            else {
+                if (!all_users_have_read_access_)
+                    users_with_read_access_.insert(std::make_pair(user, std::vector<std::string>()));
+            }
+            return true;
+        }
+
+        // write access , this also IMPLIES read access
+        // if we see * all users have read and write access
+        if (user == "*") {
+            all_users_have_write_access_ = true;
+            all_users_have_read_access_  = true;
+            users_with_write_access_.clear();
+            users_with_read_access_.clear();
+        }
+        else {
+            if (!all_users_have_read_access_)
+                users_with_read_access_.insert(std::make_pair(user, std::vector<std::string>()));
+            if (!all_users_have_write_access_)
+                users_with_write_access_.insert(std::make_pair(user, std::vector<std::string>()));
+        }
+        return true;
+    }
+
+    bool clear_paths = false;
+    bool read_only   = false;
+    std::string user;
+    std::vector<std::string> paths;
+    for (auto tok : tokens) {
+        if (tok.empty())
+            continue;
+        if (tok[0] == '-') {
+            // read only user for a given set of paths
+            read_only = true;
+            tok.erase(tok.begin());
+            if (!tok.empty()) {
+                if (!user.empty()) {
+                    error_msg = "Can only have one user per line, first user:";
+                    error_msg += user;
+                    error_msg += " second user:";
+                    error_msg += tok;
+                    return false;
+                }
+                user = tok; // user =  <name> || *
+            }
+        }
+        else if (tok[0] == '*') {
+            // all user have read/write access for a given set of suites ?
+            if (!user.empty()) {
+                error_msg = "Can only have one user per line, first user:";
+                error_msg += user;
+                error_msg += " second user:";
+                error_msg += tok;
+                return false;
+            }
+            user = "*";
+        }
+        else if (tok[0] == '/') {
+            // path or set of paths
+            std::vector<std::string> local_paths;
+            Str::split(tok, local_paths, ",");
+            std::copy(local_paths.begin(), local_paths.end(), std::back_inserter(paths));
+
+            // root path '/' means apply to all suites, in which case the paths may as well be empty.
+            for (const auto& path : paths) {
+                if (path == "/") {
+                    clear_paths = true;
+                    break;
+                }
+            }
+        }
+        else {
+            // read/write user
+            if (!user.empty()) {
+                error_msg = "Can only have one user per line, first user:";
+                error_msg += user;
+                error_msg += " second user:";
+                error_msg += tok;
+                return false;
+            }
+            user = tok;
+        }
+    }
+
+    if (clear_paths) {
+        paths.clear(); // user has used root path '/'
+
+        // * user means all users
+        if (user == "*") {
+            if (read_only) {
+                // -* /
+                all_users_have_read_access_ = true;
+                users_with_read_access_.clear();
+            }
+            else {
+                // * /
+                all_users_have_write_access_ = true;
+                users_with_write_access_.clear();
+            }
+        }
+    }
+
+    // check all paths start with '/'
+    for (auto& path : paths) {
+        if (!path.empty() && path[0] != '/') {
+            error_msg = "Paths must start with '/'";
+            return false;
+        }
+    }
+
+    if (read_only) {
+        if (!all_users_have_read_access_) {
+            auto it = users_with_read_access_.find(user);
+            if (it == users_with_read_access_.end())
+                users_with_read_access_.insert(std::make_pair(user, paths));
+            else
+                std::copy(paths.begin(), paths.end(), std::back_inserter(it->second));
+        }
+    }
+    else {
+        if (!all_users_have_write_access_) {
+            auto it = users_with_write_access_.find(user);
+            if (it == users_with_write_access_.end())
+                users_with_write_access_.insert(std::make_pair(user, paths));
+            else
+                std::copy(paths.begin(), paths.end(), std::back_inserter(it->second));
+        }
+    }
+    return true;
+}
+
+bool WhiteListFile::createWithReadAccess(const std::string& pathToFile, std::string& errorMsg) {
+    std::vector<std::string> lines;
+    lines.reserve(2);
+
+    lines.emplace_back("4.4.14");
+    lines.push_back("-" + User::login_name());
+
+    return File::create(pathToFile, lines, errorMsg);
+}
+
+bool WhiteListFile::createWithWriteAccess(const std::string& pathToFile, std::string& errorMsg) {
+    std::vector<std::string> lines;
+    lines.reserve(2);
+
+    lines.emplace_back("4.4.14");
+    lines.push_back(User::login_name()); // equivalent to the login name
+
+    return File::create(pathToFile, lines, errorMsg);
+}
+
+bool WhiteListFile::createWithNoAccess(const std::string& pathToFile, std::string& errorMsg) {
+    std::vector<std::string> lines;
+    lines.reserve(5);
+
+    lines.emplace_back("4.4.14");
+    lines.emplace_back("userXX");
+    lines.emplace_back("userYY");
+    lines.emplace_back("-userZZ");
+    lines.emplace_back("-userZY");
+
+    return File::create(pathToFile, lines, errorMsg);
+}
+
+bool WhiteListFile::createEmpty(const std::string& pathToFile, std::string& errorMsg) {
+    std::vector<std::string> lines;
+    lines.reserve(1);
+    lines.emplace_back("4.4.14");
+
+    return File::create(pathToFile, lines, errorMsg);
+}
+
+void WhiteListFile::allow_write_access_for_server_user() {
+    std::string user = User::login_name();
+    if (verify_write_access(user))
+        return;
+
+    // add write access
+    auto it = users_with_write_access_.find(user);
+    if (it == users_with_write_access_.end()) {
+        users_with_write_access_.insert(std::make_pair(user, std::vector<std::string>()));
+    }
+}
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/WhiteListFile.hpp 5.13.0-1/libs/core/src/ecflow/core/WhiteListFile.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/WhiteListFile.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/WhiteListFile.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,96 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_WhiteListFile_HPP
+#define ecflow_core_WhiteListFile_HPP
+
+///
+/// \brief Parser for whitelist file
+///
+
+#include <string>
+#include <unordered_map>
+#include <vector>
+
+// ----------------------------------------------------------------
+// The whiteList file, is used to indicate users who are allowed
+// read/write access to the server when calling *user* commands
+
+class WhiteListFile {
+public:
+    WhiteListFile();
+    // Disable copy (and move) semantics
+    WhiteListFile(const WhiteListFile&)                  = delete;
+    const WhiteListFile& operator=(const WhiteListFile&) = delete;
+
+    ~WhiteListFile();
+
+    // If any user in read/write lists, then it has read access.
+    // However, when paths are specified the returns may not be the same. i.e,
+    //    verify_read_access("userX") != verify_read_access("userX","/f")
+    // This is is because different commands, call different functions:
+    // Hence if we have:
+    //              verify_read_access(userX) verify_read_access(userX,'/f') verify_read_access(userX,'/s1')
+    //  userX  /s1               TRUE                  FALSE                        TRUE
+    //  -userX /s2               TRUE                  FALSE                        FALSE
+    //
+    // If we also add * in the mix: All users have read/write access to suite `/a`, and read access to `/b`
+    //  *  /a
+    //  -* /b
+    //  userX  /s1
+    //  -userX /s2
+    // HENCE:
+    //    verify_read_access(userX)   -> TRUE
+    //    verify_read_access(yy)      -> TRUE  // yy qualifies as all users
+    //   verify_read_access(userX,/a) -> TRUE
+    //   verify_read_access(yy,/a)    -> TRUE
+    bool verify_read_access(const std::string& user) const;
+    bool verify_read_access(const std::string& user, const std::string& path) const;
+    bool verify_read_access(const std::string& user, const std::vector<std::string>& paths) const;
+
+    bool verify_write_access(const std::string& user) const;
+    bool verify_write_access(const std::string& user, const std::string& path) const;
+    bool verify_write_access(const std::string& user, const std::vector<std::string>& paths) const;
+
+    std::string dump_valid_users() const;
+
+    // Parse the file if any errors found return false and errorMsg
+    // The parser expects version number  4.4.5
+    bool load(const std::string& file, bool debug, std::string& errorMsg);
+
+    // Function used in test:
+    // Will overwrite the existing file
+    static bool createWithReadAccess(const std::string& pathToFile, std::string& errorMsg);
+    static bool createWithWriteAccess(const std::string& pathToFile, std::string& errorMsg);
+    static bool createWithNoAccess(const std::string& pathToFile, std::string& errorMsg);
+    static bool createEmpty(const std::string& pathToFile, std::string& errorMsg);
+
+    size_t read_access_size() const { return users_with_read_access_.size(); }
+    size_t write_access_size() const { return users_with_write_access_.size(); }
+
+    // return true if current user has write access
+    void allow_write_access_for_server_user();
+
+private:
+    bool validateVersionNumber(const std::string& line, std::string& errorMsg) const;
+    bool add_user(std::vector<std::string>& tokens, std::string& error_msg);
+
+    typedef std::unordered_map<std::string, std::vector<std::string>> mymap;
+    bool verify_path_access(const std::string& user, const std::vector<std::string>& paths, const mymap&) const;
+    bool verify_path_access(const std::string& user, const std::string& path, const mymap&) const;
+
+    bool all_users_have_read_access_{false};
+    bool all_users_have_write_access_{false};
+    std::string white_list_file_;
+    mymap users_with_read_access_;  // user,paths
+    mymap users_with_write_access_; // user,paths
+};
+
+#endif /* ecflow_core_WhiteListFile_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/cereal_boost_time.hpp 5.13.0-1/libs/core/src/ecflow/core/cereal_boost_time.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/cereal_boost_time.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/cereal_boost_time.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_cereal_boost_time_HPP
+#define ecflow_core_cereal_boost_time_HPP
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/date_time/posix_time/time_serialize.hpp>
+#include <cereal/archives/json.hpp>
+#include <cereal/details/traits.hpp>
+
+namespace cereal {
+
+// ===================================================================================
+// Handle boost::posix_time::time_duration
+template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
+inline void save(Archive& ar, boost::posix_time::time_duration const& d) {
+    ar(cereal::make_nvp("duration", to_simple_string(d)));
+}
+
+//! Loading for std::map<std::string, std::string> for text based archives
+template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
+inline void load(Archive& ar, boost::posix_time::time_duration& d) {
+    std::string value;
+    ar(value);
+    d = boost::posix_time::duration_from_string(value);
+}
+
+// ===================================================================================
+// Handle boost::posix_time::ptime
+template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
+inline void save(Archive& ar, boost::posix_time::ptime const& d) {
+    ar(cereal::make_nvp("ptime", to_simple_string(d)));
+}
+
+//! Loading for std::map<std::string, std::string> for text based archives
+template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
+inline void load(Archive& ar, boost::posix_time::ptime& d) {
+    std::string value;
+    ar(value);
+    d = boost::posix_time::time_from_string(value);
+}
+
+// ===================================================================================
+// Handle boost::gregorian::date
+template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
+inline void save(Archive& ar, boost::gregorian::date const& d) {
+    ar(cereal::make_nvp("date", to_simple_string(d)));
+}
+
+//! Loading for std::map<std::string, std::string> for text based archives
+template <class Archive, traits::EnableIf<traits::is_text_archive<Archive>::value> = traits::sfinae>
+inline void load(Archive& ar, boost::gregorian::date& d) {
+    std::string value;
+    ar(value);
+    d = boost::gregorian::from_simple_string(value);
+}
+
+} // namespace cereal
+
+#endif /* ecflow_core_cereal_boost_time_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/cereal_optional_nvp.hpp 5.13.0-1/libs/core/src/ecflow/core/cereal_optional_nvp.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/cereal_optional_nvp.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/cereal_optional_nvp.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,102 @@
+/*
+ * The MIT License (MIT)
+ * Copyright (c) 2017 Yehonatan Ballas
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in all
+ * copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
+ */
+
+#ifndef ecflow_core_cereal_optional_nvp_HPP
+#define ecflow_core_cereal_optional_nvp_HPP
+
+///
+/// Example
+///
+/// struct B
+/// {
+/// int x, y, z;
+///
+/// template <class Archive>
+/// void serialize(Archive & ar)
+/// {
+///       cereal::make_optional_nvp(ar, "x", x);
+///       CEREAL_OPTIONAL_NVP(ar, y);
+///       CEREAL_OPTIONAL_NVP(ar, z, [this]() {return z != 1; }); // conditionally save
+/// }
+/// };
+///
+
+#include <type_traits> // for std::enable_if_t
+
+#include <cereal/cereal.hpp>
+#include <cereal/details/traits.hpp>
+
+namespace cereal {
+class JSONInputArchive;
+class XMLInputArchive;
+
+// Optionally load an NVP if its name equals to the current node's name
+// Loading members should be done in the same order they were saved
+// return true if NVP found
+template <class Archive, class T>
+typename std::enable_if_t<traits::is_same_archive<Archive, JSONInputArchive>::value ||
+                              traits::is_same_archive<Archive, XMLInputArchive>::value,
+                          bool>
+make_optional_nvp(Archive& ar, const char* name, T&& value) {
+    const auto node_name = ar.getNodeName();
+
+    // if names are equal
+    if (node_name != nullptr && strcmp(name, node_name) == 0) {
+        ar(make_nvp(name, std::forward<T>(value))); // load the NVP. Advances to the next node
+        return true;
+    }
+
+    return false;
+}
+
+template <class Archive, class T>
+void make_optional_nvp(OutputArchive<Archive>& ar, const char* name, T&& value) {
+    ar(make_nvp(name, std::forward<T>(value)));
+}
+
+// Saves NVP if predicate is true. Useful for avoiding splitting into save & load if also saving optionally.
+template <class Archive, class T, class Predicate>
+void make_optional_nvp(OutputArchive<Archive>& ar, const char* name, T&& value, Predicate predicate) {
+    if (predicate())
+        ar(make_nvp(name, std::forward<T>(value)));
+}
+
+template <class Archive, class T, class Predicate>
+typename std::enable_if_t<traits::is_same_archive<Archive, JSONInputArchive>::value ||
+                              traits::is_same_archive<Archive, XMLInputArchive>::value,
+                          bool>
+make_optional_nvp(Archive& ar, const char* name, T&& value, Predicate predicate) {
+    return make_optional_nvp(ar, name, std::forward<T>(value));
+}
+} // namespace cereal
+
+// Macros for using the variable name as the NVP name
+#define EXPAND(x) x
+#define GET_CEREAL_OPTIONAL_NVP_MACRO(_1, _2, _3, NAME, ...) NAME
+#define CEREAL_OPTIONAL_NVP(...) \
+    EXPAND(GET_CEREAL_OPTIONAL_NVP_MACRO(__VA_ARGS__, CEREAL_OPTIONAL_NVP_3, CEREAL_OPTIONAL_NVP_2)(__VA_ARGS__))
+
+#define CEREAL_OPTIONAL_NVP_2(ar, T) ::cereal::make_optional_nvp(ar, #T, T)
+#define CEREAL_OPTIONAL_NVP_3(ar, T, P) ::cereal::make_optional_nvp(ar, #T, T, P)
+
+#endif /* ecflow_core_cereal_optional_nvp_HPP */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/ecflow_source_build_dir.h.in 5.13.0-1/libs/core/src/ecflow/core/ecflow_source_build_dir.h.in
--- 5.12.4-1/libs/core/src/ecflow/core/ecflow_source_build_dir.h.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/ecflow_source_build_dir.h.in	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_ecflow_source_build_dir_H
+#define ecflow_core_ecflow_source_build_dir_H
+ 
+#define CMAKE_ECFLOW_SOURCE_DIR "@PROJECT_SOURCE_DIR@"
+#define CMAKE_ECFLOW_BUILD_DIR  "@PROJECT_BINARY_DIR@"
+
+#endif /* ecflow_core_ecflow_source_build_dir_H */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/ecflow_version.h.in 5.13.0-1/libs/core/src/ecflow/core/ecflow_version.h.in
--- 5.12.4-1/libs/core/src/ecflow/core/ecflow_version.h.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/ecflow_version.h.in	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,26 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_ecflow_version_config_H
+#define ecflow_core_ecflow_version_config_H
+
+// clang-format off
+#define ECFLOW_VERSION   "@ecflow_VERSION@"
+#define ECFLOW_RELEASE   "@ecflow_VERSION_MAJOR@"
+#define ECFLOW_MAJOR     "@ecflow_VERSION_MINOR@"
+#define ECFLOW_MINOR     "@ecflow_VERSION_PATCH@"
+
+// available but not used
+// PROJECT_VERSION=@PROJECT_VERSION@
+// PROJECT_VERSION_MAJOR=@PROJECT_VERSION_MAJOR@
+// PROJECT_VERSION_MINOR=@PROJECT_VERSION_MINOR@
+// PROJECT_VERSION_PATCH=@PROJECT_VERSION_PATCH@
+
+#endif /* ecflow_core_ecflow_version_config_H */
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/exceptions/Exceptions.hpp 5.13.0-1/libs/core/src/ecflow/core/exceptions/Exceptions.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/exceptions/Exceptions.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/exceptions/Exceptions.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_exceptions_Exceptions_HPP
+#define ecflow_core_exceptions_Exceptions_HPP
+
+#include <stdexcept>
+
+namespace ecf {
+
+struct Exception : public std::runtime_error
+{
+    explicit Exception(const char* what) : std::runtime_error(what) {}
+    explicit Exception(const std::string& what) : std::runtime_error(what) {}
+};
+
+struct InvalidArgument : public Exception
+{
+    explicit InvalidArgument(const char* what) : Exception(what) {}
+    explicit InvalidArgument(const std::string& what) : Exception(what) {}
+};
+
+} // namespace ecf
+
+#endif // ecflow_core_exceptions_Exceptions_HPP
diff -pruN 5.12.4-1/libs/core/src/ecflow/core/perf_timer.hpp 5.13.0-1/libs/core/src/ecflow/core/perf_timer.hpp
--- 5.12.4-1/libs/core/src/ecflow/core/perf_timer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/src/ecflow/core/perf_timer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_perf_timer_HPP
+#define ecflow_core_perf_timer_HPP
+
+#include <cassert>
+#include <chrono>
+#include <functional> // std::ref
+#include <iostream>
+#include <string>
+#include <vector>
+
+// TODO: remove when we use c++17
+template <typename F, typename... Args>
+auto invoke(F f, Args&&... args) -> decltype(std::ref(f)(std::forward<Args>(args)...)) {
+    return std::ref(f)(std::forward<Args>(args)...);
+}
+
+template <typename Time = std::chrono::microseconds, typename Clock = std::chrono::high_resolution_clock>
+struct perf_timer
+{
+    template <typename F, typename... Args>
+    static Time duration(F&& f, Args... args) {
+        auto start = Clock::now();
+
+        // std::invoke(std::forward<F>(f), std::forward<Args>(args)...); // c++17
+        invoke(std::forward<F>(f), std::forward<Args>(args)...);
+
+        auto end = Clock::now();
+        return std::chrono::duration_cast<Time>(end - start);
+    }
+};
+
+template <class Resolution = std::chrono::milliseconds>
+class Timer {
+public:
+    using Clock = std::conditional_t<std::chrono::high_resolution_clock::is_steady,
+                                     std::chrono::high_resolution_clock,
+                                     std::chrono::steady_clock>;
+
+private:
+    const Clock::time_point start_ = Clock::now();
+
+public:
+    Timer()  = default;
+    ~Timer() = default;
+    void elapsed(const char* msg) const {
+        const auto end = Clock::now();
+        std::cout << msg << " " << std::chrono::duration_cast<Resolution>(end - start_).count() << std::endl;
+    }
+
+    Resolution elapsed() const { return std::chrono::duration_cast<Resolution>(Clock::now() - start_); }
+};
+
+#endif /* ecflow_core_perf_timer_HPP */
diff -pruN 5.12.4-1/libs/core/test/TestCalendar.cpp 5.13.0-1/libs/core/test/TestCalendar.cpp
--- 5.12.4-1/libs/core/test/TestCalendar.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestCalendar.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,520 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/date_time/posix_time/time_formatters.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Cal.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Calendar)
+
+BOOST_AUTO_TEST_CASE(test_calendar_default_ptime) {
+    cout << "ACore:: ...test_calendar_default_ptime \n";
+
+    ptime time;
+    BOOST_CHECK_MESSAGE(time.is_special(), "Default ptime is special");
+    BOOST_CHECK_MESSAGE(time.is_not_a_date_time(), "Default ptime is_not_a_date_time");
+    BOOST_CHECK_MESSAGE(!time.is_infinity(), "Expected Default ptime not is_infinity");
+    BOOST_CHECK_MESSAGE(!time.is_pos_infinity(), "Expected default ptime not is_pos_infinity");
+    BOOST_CHECK_MESSAGE(!time.is_neg_infinity(), "Expected default ptime not is_neg_infinity");
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_state_parsing) {
+    cout << "ACore:: ...test_calendar_state_parsing\n";
+
+    Calendar calendar;
+    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Default calendar type should be real");
+
+    // init the calendar to 2009, Feb, 10th, then write out the state
+    boost::gregorian::date theDate(2009, 2, 10);
+    ptime time(theDate, hours(23) + minutes(59));
+    calendar.init(time, Calendar::REAL);
+    std::string calendar_state;
+    calendar.write_state(calendar_state);
+
+    // read the state, into a different calendar & compare
+    std::vector<std::string> lineTokens;
+    Str::split(calendar_state, lineTokens);
+    Calendar calendar2;
+    calendar2.read_state(calendar_state, lineTokens);
+    BOOST_CHECK_MESSAGE(calendar == calendar2,
+                        "Calendar should be the same\n"
+                            << calendar.toString() << "\n"
+                            << calendar2.toString());
+
+    // Update calendar.
+    calendar.update(minutes(2));
+    BOOST_CHECK_MESSAGE(!(calendar == calendar2), "Calendar should be different");
+
+    // re-compare after reloading state
+    lineTokens.clear();
+    calendar_state.clear();
+    calendar.write_state(calendar_state);
+
+    Str::split(calendar_state, lineTokens);
+    calendar2.read_state(calendar_state, lineTokens);
+
+    BOOST_CHECK_MESSAGE(calendar == calendar2, "Calendar should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_1) {
+    cout << "ACore:: ...test_calendar_1\n";
+
+    Calendar calendar;
+    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Default calendar type should be real");
+
+    // init the calendar to 2009, Feb, 10th,  15 minutes past midnight
+    boost::gregorian::date theDate(2009, 2, 10);
+    ptime time(theDate, hours(23) + minutes(59));
+    calendar.init(time, Calendar::HYBRID);
+    BOOST_CHECK_MESSAGE(calendar.hybrid(), "init failed to reset calendar type");
+
+    calendar.update(minutes(2));
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar) {
+    cout << "ACore:: ...test_calendar_basic\n";
+
+    Calendar calendar;
+    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Default calendar type should be real");
+
+    // init the calendar to 2009, Feb, 10th,  15 minutes past midnight
+    boost::gregorian::date theDate(2009, 2, 10);
+    ptime time(theDate, minutes(15));
+    calendar.init(time, Calendar::REAL);
+    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "Calendar should now be REAL");
+
+    std::string expectedTime = "2009-Feb-10 00:15:00";
+    std::string actualTime   = to_simple_string(calendar.suiteTime());
+    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
+
+    time_duration td = hours(1) + minutes(10);
+    calendar.update(td);
+    expectedTime = "2009-Feb-10 01:25:00";
+    actualTime   = to_simple_string(calendar.suiteTime());
+    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
+
+    // Increment by 24 hours
+    calendar.update(hours(24));
+    expectedTime = "2009-Feb-11 01:25:00";
+    actualTime   = to_simple_string(calendar.suiteTime());
+    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_time_series_relative) {
+    cout << "ACore:: ...test_calendar_time_series_relative\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
+
+    std::string expectedTime = "2010-Feb-10 00:00:00";
+    std::string actualTime   = to_simple_string(calendar.suiteTime());
+    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
+
+    // Create a test when we can match a time series. Need to sync hour with suite time
+    // at hour 1, suite time should also be 01:00, for test to work
+    //
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr    1:00
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), true /*relative*/);
+
+    for (int hour = 1; hour < 24; hour++) {
+        // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
+        calendar.update(time_duration(hours(1)));
+        timeSeries.calendarChanged(calendar);
+
+        //		cerr << "hour = " << hour << " suiteTime " << to_simple_string(calendar.suiteTime()) << "\n";
+        if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar),
+                                "Calendar should match relative time series at hour " << hour);
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                                "Calendar should NOT match relative time series at hour " << hour);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_time_series_relative_complex) {
+    cout << "ACore:: ...test_calendar_time_series_relative_complex\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
+
+    // Create a test when we can match a time series
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr   00:15
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15), true /*relative*/);
+
+    for (int hour = 0; hour < 24; hour++) {
+        for (int minute = 0; minute < 60; minute++) {
+
+            // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
+            calendar.update(minutes(1));
+            timeSeries.calendarChanged(calendar);
+
+            tm suiteTm = to_tm(calendar.suiteTime());
+
+            bool matches = timeSeries.isFree(calendar);
+
+            bool intersects =
+                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
+                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
+            // Ovoid overshooting past end of series
+            bool boundaryOk = true;
+            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
+                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
+            }
+
+            if (intersects && boundaryOk) {
+                BOOST_CHECK_MESSAGE(matches,
+                                    "Calendar should match relative time series at "
+                                        << suiteTm.tm_hour << Str::COLON() << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+                if (!matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!matches,
+                                    "Calendar should NOT match relative time series at "
+                                        << suiteTm.tm_hour << Str::COLON() << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+
+                if (matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_time_series_real) {
+    cout << "ACore:: ...test_calendar_time_series_real\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    std::string expectedTime = "2010-Feb-10 00:00:00";
+    std::string actualTime   = to_simple_string(calendar.suiteTime());
+    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
+
+    // Create a test when we can match a time series
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr    1:00
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0));
+
+    for (int hour = 1; hour < 24; hour++) {
+        // Update calendar every hour, then see we can match time series, in REAL
+        // Update will set the local time from the computers system clock, however
+        // for testing this will need to be overriden below.
+        calendar.update(time_duration(hours(1)));
+
+        // cerr << "hour = " << hour << " suiteTime " << to_simple_string(calendar.suiteTime())  << "\n";
+        if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar), "Calendar should match time series at hour " << hour);
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Calendar should NOT match time series at hour " << hour);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_time_series_real_complex) {
+    cout << "ACore:: ...test_calendar_time_series_real_complex\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr   00:15
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15));
+
+    for (int hour = 0; hour < 24; hour++) {
+        for (int minute = 0; minute < 60; minute++) {
+
+            // Update calendar every minute, then see we can match time series, *RELATIVE* to suite start
+            calendar.update(minutes(1));
+
+            tm suiteTm = to_tm(calendar.suiteTime());
+
+            bool matches = timeSeries.isFree(calendar);
+
+            bool intersects =
+                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
+                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
+            // Ovoid overshooting past end of series
+            bool boundaryOk = true;
+            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
+                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
+            }
+
+            if (intersects && boundaryOk) {
+                BOOST_CHECK_MESSAGE(matches,
+                                    "Calendar should match relative time series at "
+                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+                if (!matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!matches,
+                                    "Calendar should NOT match relative time series at "
+                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+
+                if (matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_hybrid) {
+    cout << "ACore:: ...test_calendar_hybrid\n";
+
+    // The hybrid calendar should not change the suite date.
+    // Test by updateing calendar by more than 24 hours
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
+    BOOST_CHECK_MESSAGE(calendar.hybrid(), "calendar type should be hybrid");
+
+    std::string expectedTime = "2010-Feb-10 00:00:00";
+    std::string actualTime   = to_simple_string(calendar.suiteTime());
+    BOOST_CHECK_MESSAGE(actualTime == expectedTime, "Expected '" << expectedTime << "' but found " << actualTime);
+
+    std::string expectedDate = "2010-Feb-10";
+
+    // Check cache is correct
+    int expected_day_of_week  = calendar.day_of_week();
+    int expected_day_of_year  = calendar.day_of_year();
+    int expected_day_of_month = calendar.day_of_month();
+    int expected_month        = calendar.month();
+    int expected_year         = calendar.year();
+
+    for (int hour = 1; hour < 73; hour++) {
+        // Update calendar every hour, for 73 hours
+        // the date should be the same, i.e 2009, Feb, 10th
+
+        ptime timeBeforeUpdate = calendar.suiteTime();
+
+        calendar.update(time_duration(hours(1)));
+
+        ptime timeAfterUpdate = calendar.suiteTime();
+
+        //		cerr << "hour = " << hour << " timeBeforeUpdate " << to_simple_string(timeBeforeUpdate)
+        //		    << "   timeAfterUpdate = " << to_simple_string(timeAfterUpdate) <<  "\n";
+
+        if (hour != 24 && hour != 48 && hour != 72) {
+            time_period diff(timeBeforeUpdate, timeAfterUpdate);
+            time_duration gap = diff.length();
+            BOOST_CHECK_MESSAGE(gap.hours() == 1,
+                                "Expected one hour difference but found " << gap.hours() << " at hour " << hour);
+        }
+
+        std::string actualDate = to_simple_string(calendar.suiteTime().date());
+        BOOST_CHECK_MESSAGE(actualDate == expectedDate,
+                            "Expected '" << expectedDate << "' but found " << actualDate << " at hour " << hour);
+
+        // check cache ECFLOW-458
+        int actual_day_of_week  = calendar.day_of_week();
+        int actual_day_of_year  = calendar.day_of_year();
+        int actual_day_of_month = calendar.day_of_month();
+        int actual_month        = calendar.month();
+        int actual_year         = calendar.year();
+        BOOST_CHECK_MESSAGE(actual_day_of_week == expected_day_of_week,
+                            "Expected day of week '" << expected_day_of_week << "' but found " << actual_day_of_week
+                                                     << " at hour " << hour);
+        BOOST_CHECK_MESSAGE(actual_day_of_year == expected_day_of_year,
+                            "Expected day of year '" << expected_day_of_year << "' but found " << actual_day_of_year
+                                                     << " at hour " << hour);
+        BOOST_CHECK_MESSAGE(actual_day_of_month == expected_day_of_month,
+                            "Expected day of month '" << expected_day_of_month << "' but found " << actual_day_of_month
+                                                      << " at hour " << hour);
+        BOOST_CHECK_MESSAGE(actual_month == expected_month,
+                            "Expected month '" << expected_month << "' but found " << actual_month << " at hour "
+                                               << hour);
+        BOOST_CHECK_MESSAGE(actual_year == expected_year,
+                            "Expected year '" << expected_year << "' but found " << actual_year << " at hour " << hour);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_day_changed_for_real) {
+    cout << "ACore:: ...test_day_changed_for_real\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "calendar type should be real");
+
+    // Check cache is correct
+    int expected_day_of_week  = calendar.day_of_week();
+    int expected_day_of_year  = calendar.day_of_year();
+    int expected_day_of_month = calendar.day_of_month();
+
+    for (int hour = 1; hour < 73; hour++) {
+        // Update calendar every hour, for 72 hours
+        calendar.update(time_duration(hours(1)));
+
+        if (hour == 24 || hour == 48 || hour == 72) {
+            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
+                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
+            expected_day_of_week++;
+            expected_day_of_year++;
+            expected_day_of_month++;
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
+                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
+        }
+
+        // check cache ECFLOW-458
+        int actual_day_of_week  = calendar.day_of_week();
+        int actual_day_of_year  = calendar.day_of_year();
+        int actual_day_of_month = calendar.day_of_month();
+        BOOST_CHECK_MESSAGE(actual_day_of_week == expected_day_of_week,
+                            "Expected day of week '" << expected_day_of_week << "' but found " << actual_day_of_week
+                                                     << " at hour " << hour);
+        BOOST_CHECK_MESSAGE(actual_day_of_year == expected_day_of_year,
+                            "Expected day of year '" << expected_day_of_year << "' but found " << actual_day_of_year
+                                                     << " at hour " << hour);
+        BOOST_CHECK_MESSAGE(actual_day_of_month == expected_day_of_month,
+                            "Expected day of month '" << expected_day_of_month << "' but found " << actual_day_of_month
+                                                      << " at hour " << hour);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_day_changed_for_hybrid) {
+    cout << "ACore:: ...test_day_changed_for_hybrid\n";
+
+    // init the calendar
+    Calendar calendar; // default clock is real
+    calendar.init(ptime(date(2015, 10, 31), minutes(0)), Calendar::HYBRID);
+    BOOST_CHECK_MESSAGE(calendar.hybrid(), "calendar type should be hybrid");
+
+    // HYBRID calendars allow for day change but not date.
+    std::string expected_date = to_simple_string(calendar.date());
+
+    // Check cache is correct
+    int expected_day_of_week  = calendar.day_of_week();
+    int expected_day_of_year  = calendar.day_of_year();
+    int expected_day_of_month = calendar.day_of_month();
+
+    for (int hour = 1; hour < 73; hour++) {
+        // Update calendar every hour, for 72 hours
+        calendar.update(time_duration(hours(1)));
+
+        BOOST_CHECK_MESSAGE(expected_date == to_simple_string(calendar.date()),
+                            "Unexpected date change for hybrid calendar at hour " << hour);
+
+        // Day should change even for hybrid calendar,
+        if (hour == 24 || hour == 48 || hour == 72) {
+            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
+                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
+                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
+        }
+
+        // check cache ECFLOW-458
+        int actual_day_of_week  = calendar.day_of_week();
+        int actual_day_of_year  = calendar.day_of_year();
+        int actual_day_of_month = calendar.day_of_month();
+        BOOST_CHECK_MESSAGE(actual_day_of_week == expected_day_of_week,
+                            "Expected day of week '" << expected_day_of_week << "' but found " << actual_day_of_week
+                                                     << " at hour " << hour);
+        BOOST_CHECK_MESSAGE(actual_day_of_year == expected_day_of_year,
+                            "Expected day of year '" << expected_day_of_year << "' but found " << actual_day_of_year
+                                                     << " at hour " << hour);
+        BOOST_CHECK_MESSAGE(actual_day_of_month == expected_day_of_month,
+                            "Expected day of month '" << expected_day_of_month << "' but found " << actual_day_of_month
+                                                      << " at hour " << hour);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_calendar_julian) {
+    cout << "ACore:: ...test_calendar_julian\n";
+
+    Calendar calendar;
+    calendar.init(ptime(date(2017, 1, 1), minutes(0)), Calendar::REAL);
+    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "calendar type should be real");
+
+    int days = 0;
+    while (calendar.year() != 2018) {
+
+        boost::gregorian::date cal_date = calendar.date();
+        long boost_julian               = cal_date.julian_day();
+
+        std::string iso_string = to_iso_string(cal_date);
+        auto date_as_long      = ecf::convert_to<long>(iso_string);
+        long ecmwf_julian      = Cal::date_to_julian(date_as_long);
+
+        BOOST_CHECK_MESSAGE(boost_julian == ecmwf_julian,
+                            "boost julian " << boost_julian << " != ecmwf julian " << ecmwf_julian << " for "
+                                            << iso_string);
+
+        // Update calendar every day for a year
+        calendar.update(time_duration(hours(24)));
+        days++;
+    }
+    BOOST_CHECK_MESSAGE(days == 365, "expected 365 days but found " << days);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestCereal.cpp 5.13.0-1/libs/core/test/TestCereal.cpp
--- 5.12.4-1/libs/core/test/TestCereal.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestCereal.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,116 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestSerialisation.hpp"
+#include "ecflow/core/Filesystem.hpp"
+
+using namespace ecf;
+using namespace boost;
+using namespace std;
+
+class MyClass {
+public:
+    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5, SUSPENDED = 6 };
+    MyClass() = default;
+    bool operator==(const MyClass& rhs) const { return x == rhs.x && y == rhs.y && state_ == rhs.state_; }
+    void print(std::ostream& os) const { os << "MyClass: x(" << x << ") y(" << y << ") state(" << state_ << ")"; }
+
+private:
+    // This method lets cereal know which data members to serialize
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& archive, std::uint32_t const version) {
+        archive(CEREAL_NVP(x), CEREAL_NVP(y), CEREAL_NVP(state_));
+    }
+    int x{2}, y{2};
+    State state_{State::SUSPENDED};
+};
+CEREAL_CLASS_VERSION(MyClass, 1)
+
+class MyTop : public MyClass {
+public:
+    MyTop() = default;
+    void set(int x, int y, int z) {
+        x_ = x;
+        y_ = y;
+        z_ = z;
+    }
+    bool operator==(const MyTop& rhs) const {
+        return (MyClass::operator==(rhs)) && x_ == rhs.x_ && y_ == rhs.y_ && z_ == rhs.z_;
+    }
+    void print(std::ostream& os) const {
+        os << "MyTop:";
+        MyClass::print(os);
+        os << ": x(" << x_ << ") y(" << y_ << ") z(" << z_ << ")";
+    }
+
+private:
+    // This method lets cereal know which data members to serialize
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& archive, std::uint32_t const version) {
+        archive(cereal::base_class<MyClass>(this), CEREAL_NVP(x_), CEREAL_NVP(y_), CEREAL_NVP(z_));
+    }
+    int x_{1}, y_{1}, z_{1};
+};
+CEREAL_CLASS_VERSION(MyTop, 1)
+
+std::ostream& operator<<(std::ostream& os, MyTop const& m) {
+    m.print(os);
+    return os;
+}
+
+// =================================================================================
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Cereal)
+
+BOOST_AUTO_TEST_CASE(test_cereal_json) {
+    cout << "ACore:: ...test_cereal_json \n";
+    std::string path = "test_cereal_json";
+    {
+        std::ofstream os(path);
+        cereal::JSONOutputArchive oarchive(os); // Create an output archive
+
+        MyTop m1, m2, m3;
+        oarchive(cereal::make_nvp("MyTop", m1), m2, m3); // Write the data to the archive
+    }                                                    // archive goes out of scope, ensuring all contents are flushed
+
+    {
+        BOOST_CHECK_MESSAGE(fs::exists(path), " Expected file to exist");
+
+        std::ifstream is(path);
+        cereal::JSONInputArchive iarchive(is); // Create an input archive
+
+        MyTop m1, m2, m3;
+        iarchive(m1, m2, m3); // Read the data from the archive
+
+        fs::remove(path); // Remove the file. Comment out for debugging
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_cereal_json2) {
+    cout << "ACore:: ...test_cereal_json2\n";
+    MyTop m1;
+    m1.set(10, 10, 10);
+    std::string path = "test_cereal_json2";
+    { ecf::doSave(path, m1); }
+    { ecf::doRestore(path, m1); }
+    { ecf::doSaveAndRestore<MyTop>(path); }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestCerealOptionalNVP.cpp 5.13.0-1/libs/core/test/TestCerealOptionalNVP.cpp
--- 5.12.4-1/libs/core/test/TestCerealOptionalNVP.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestCerealOptionalNVP.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+using namespace ecf;
+using namespace boost;
+using namespace std;
+
+class Base {
+public:
+    enum State { UNKNOWN = 0, COMPLETE = 1, QUEUED = 2, ABORTED = 3, SUBMITTED = 4, ACTIVE = 5, SUSPENDED = 6 };
+    Base() = default;
+    explicit Base(bool test) : test_(test) {}
+    bool operator==(const Base& rhs) const {
+        return x == rhs.x && y == rhs.y && state_ == rhs.state_ && test_ == rhs.test_;
+    }
+    void print(std::ostream& os) const {
+        os << "Base: x(" << x << ") y(" << y << ") state(" << state_ << ") test(" << test_ << ")";
+    }
+
+private:
+    // This method lets cereal know which data members to serialize
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(CEREAL_NVP(x), CEREAL_NVP(y), CEREAL_NVP(state_));
+        CEREAL_OPTIONAL_NVP(ar, test_, [this]() { return test_; }); // conditionally save
+    }
+    int x{2}, y{2};
+    State state_{State::SUSPENDED};
+    bool test_{false};
+};
+
+std::ostream& operator<<(std::ostream& os, Base const& m) {
+    m.print(os);
+    return os;
+}
+
+// =================================================================================
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_CerealOptionalNVP)
+
+BOOST_AUTO_TEST_CASE(test_cereal_optional) {
+    cout << "ACore:: ...test_cereal_optional\n";
+    Base original;
+    Base original1(true);
+    std::string path = "test_cereal_optional";
+    {
+        std::ofstream os(path);
+        cereal::JSONOutputArchive oarchive(os); // Create an output archive
+        oarchive(cereal::make_nvp("Base", original),
+                 cereal::make_nvp("Base", original1)); // Write the data to the archive
+    }                                                  // archive goes out of scope, ensuring all contents are flushed
+
+    {
+        BOOST_CHECK_MESSAGE(fs::exists(path), " Expected file to exist");
+
+        std::ifstream is(path);
+        cereal::JSONInputArchive iarchive(is); // Create an input archive
+
+        Base restored;
+        Base restored1;
+        iarchive(restored, restored1); // Read the data from the archive
+        BOOST_CHECK_MESSAGE(restored == original, "restored(" << restored << ") != original(" << original << ")");
+        BOOST_CHECK_MESSAGE(restored1 == original1, "restored1(" << restored1 << ") != original1(" << original1 << ")");
+        fs::remove(path); // Remove the file. Comment out for debugging
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestCerealWithHierarchy.cpp 5.13.0-1/libs/core/test/TestCerealWithHierarchy.cpp
--- 5.12.4-1/libs/core/test/TestCerealWithHierarchy.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestCerealWithHierarchy.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,152 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+using namespace ecf;
+using namespace boost;
+using namespace std;
+
+// ======================================================================================
+
+class BaseCmd {
+public:
+    BaseCmd()          = default;
+    virtual ~BaseCmd() = default;
+
+    bool operator==(const BaseCmd& rhs) const { return true; }
+    void print(std::ostream& os) const {}
+    virtual bool equals(BaseCmd* rhs) const = 0;
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& archive, std::uint32_t const version) {}
+};
+
+class Derived1 : public BaseCmd {
+public:
+    Derived1() = default;
+    explicit Derived1(int x) : BaseCmd(), x_(x) {}
+    ~Derived1() override = default;
+
+    int get_x() const { return x_; }
+
+    bool equals(BaseCmd* rhs) const override {
+        auto* the_rhs = dynamic_cast<Derived1*>(rhs);
+        if (!the_rhs)
+            return false;
+        if (x_ != the_rhs->get_x())
+            return false;
+        return true;
+    }
+
+    void print(std::ostream& os) const {
+        os << "Derived1:";
+        BaseCmd::print(os);
+        os << ": x(" << x_ << ")";
+    }
+
+private:
+    int x_{0};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<BaseCmd>(this), x_);
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, Derived1 const& m) {
+    m.print(os);
+    return os;
+}
+
+class CmdContainer {
+public:
+    CmdContainer() = default;
+    explicit CmdContainer(std::shared_ptr<BaseCmd> cmd) : cmd_(cmd) {}
+
+    bool operator==(const CmdContainer& rhs) const {
+        if (!cmd_.get() && !rhs.cmd_.get())
+            return true;
+        if (cmd_.get() && !rhs.cmd_.get())
+            return false;
+        if (!cmd_.get() && rhs.cmd_.get())
+            return false;
+        return (cmd_->equals(rhs.cmd_.get()));
+    }
+
+    void print(std::ostream& os) const {
+        if (cmd_.get())
+            cmd_->print(os);
+        os << "NULL request";
+    }
+
+private:
+    std::shared_ptr<BaseCmd> cmd_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& archive) {
+        archive(CEREAL_NVP(cmd_));
+    }
+};
+
+std::ostream& operator<<(std::ostream& os, CmdContainer const& m) {
+    m.print(os);
+    return os;
+}
+
+CEREAL_REGISTER_TYPE(Derived1)
+
+// =================================================================================
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_CerealWithHierarchy)
+
+BOOST_AUTO_TEST_CASE(test_cereal_save_as_string_and_save_as_filename) {
+    cout << "ACore:: ...test_cereal_save_as_string_and_save_as_filename\n";
+
+    std::shared_ptr<BaseCmd> cmd = std::make_shared<Derived1>(10);
+    CmdContainer originalCmd(cmd);
+    std::string saved_cmd_as_string;
+
+    // SAVE as string and file
+    {
+        BOOST_REQUIRE_NO_THROW(ecf::save("ACore.txt", originalCmd)); // save as filename
+        ecf::save_as_string(saved_cmd_as_string, originalCmd); // save as string, this is buggy forgets trailing '}'
+    }
+
+    // RESTORE from filename and string
+    {
+        CmdContainer restoredCmd;
+        BOOST_REQUIRE_NO_THROW(ecf::restore("ACore.txt", restoredCmd)); // restore from filename
+        BOOST_REQUIRE_MESSAGE(restoredCmd == originalCmd,
+                              "restoredCmd " << restoredCmd << "  originalCmd " << originalCmd);
+    }
+    {
+        // cout <<  saved_cmd_as_string << "\n";
+        CmdContainer restoredCmd;
+        ecf::restore_from_string(saved_cmd_as_string, restoredCmd); // restore form string fails, due to missing '}'
+        BOOST_REQUIRE_MESSAGE(restoredCmd == originalCmd,
+                              "restoredCmd " << restoredCmd << "  originalCmd " << originalCmd);
+    }
+
+    fs::remove("ACore.txt");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestChrono.cpp 5.13.0-1/libs/core/test/TestChrono.cpp
--- 5.12.4-1/libs/core/test/TestChrono.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestChrono.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,126 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Chrono.hpp"
+
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Chrono)
+
+BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_create_reference_instant) {
+    Instant instant;
+    BOOST_CHECK_EQUAL(Instant::format(instant), "19700101T000000");
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono__is_able_to_create_instant_based_on_std_chrono_time_point) {
+    Instant original{std::chrono::system_clock::now()};
+
+    auto timestamp        = Instant::format(original);
+    Instant reconstructed = Instant::parse(timestamp);
+    auto timestamp2       = Instant::format(reconstructed);
+
+    BOOST_CHECK_EQUAL(original, reconstructed);
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_parse_and_format_instant) {
+    {
+        std::string value = "19700101T000000";
+        Instant instant   = Instant::parse(value);
+        BOOST_CHECK_EQUAL(Instant::format(instant), value);
+    }
+    {
+        std::string value = "20000101T235959";
+        Instant instant   = Instant::parse(value);
+        BOOST_CHECK_EQUAL(Instant::format(instant), value);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_compare_instants_for_equality) {
+    Instant instant0 = Instant::parse("20000101T235959");
+
+    Instant instant1 = instant0;
+    Instant instant2 = Instant::parse("20000102T000000");
+    Instant instant3 = Instant::parse("20000102T000001");
+
+    BOOST_CHECK(instant0 == instant1);
+
+    BOOST_CHECK(instant1 == instant1);
+    BOOST_CHECK(instant1 != instant2);
+    BOOST_CHECK(instant1 != instant3);
+
+    BOOST_CHECK(instant2 != instant1);
+    BOOST_CHECK(instant2 == instant2);
+    BOOST_CHECK(instant2 != instant3);
+
+    BOOST_CHECK(instant3 != instant1);
+    BOOST_CHECK(instant3 != instant2);
+    BOOST_CHECK(instant3 == instant3);
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_compare_instants_for_inequality) {
+    Instant instant1 = Instant::parse("20000101T235959");
+    Instant instant2 = Instant::parse("20000102T000000");
+    Instant instant3 = Instant::parse("20000102T000001");
+
+    BOOST_CHECK(instant1 < instant2);
+    BOOST_CHECK(instant1 < instant3);
+
+    BOOST_CHECK(instant2 > instant1);
+    BOOST_CHECK(instant2 < instant3);
+
+    BOOST_CHECK(instant3 > instant1);
+    BOOST_CHECK(instant3 > instant2);
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_add_duration_to_instant) {
+    {
+        Instant instant = Instant::parse("20000101T235959");
+        Instant next    = instant + Duration{std::chrono::seconds{1}};
+        BOOST_CHECK_EQUAL(Instant::format(next), "20000102T000000");
+    }
+    {
+        Instant instant = Instant::parse("20000101T235959");
+        Instant next    = instant + Duration{-std::chrono::seconds{1}};
+        BOOST_CHECK_EQUAL(Instant::format(next), "20000101T235958");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono_is_able_to_subtract_duration_from_instant) {
+    {
+        Instant instant = Instant::parse("20000101T235959");
+        Instant next    = instant - Duration{std::chrono::seconds{1}};
+        BOOST_CHECK_EQUAL(Instant::format(next), "20000101T235958");
+    }
+    {
+        Instant instant = Instant::parse("20000101T235959");
+        Instant next    = instant - Duration{-std::chrono::seconds{1}};
+        BOOST_CHECK_EQUAL(Instant::format(next), "20000102T000000");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono_parsing_invalid_value_throws) {
+    using expected = std::runtime_error;
+    BOOST_CHECK_THROW(Instant::parse("20000101T235961"), expected);
+    BOOST_CHECK_THROW(Instant::parse("20000101T236059"), expected);
+    BOOST_CHECK_THROW(Instant::parse("20000101T240000"), expected);
+    BOOST_CHECK_THROW(Instant::parse("20000101T555555"), expected);
+    BOOST_CHECK_THROW(Instant::parse("20000132T000000"), expected);
+    BOOST_CHECK_THROW(Instant::parse("20000230T000000"), expected);
+    BOOST_CHECK_THROW(Instant::parse("20000431T000000"), expected);
+    BOOST_CHECK_THROW(Instant::parse("20000631T000000"), expected);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestClassDataMemberInit.cpp 5.13.0-1/libs/core/test/TestClassDataMemberInit.cpp
--- 5.12.4-1/libs/core/test/TestClassDataMemberInit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestClassDataMemberInit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,113 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+#include <vector>
+
+#include <boost/test/unit_test.hpp>
+
+using namespace boost;
+using namespace std;
+
+// #define DEBUG_ME 1
+
+class MyType {
+public:
+    explicit MyType(std::string str) : mName(std::move(str)) {
+#ifdef DEBUG_ME
+        std::cout << "MyType::MyType " << mName << " my_int:" << my_int_ << '\n';
+#endif
+    }
+
+    ~MyType() {
+#ifdef DEBUG_ME
+        std::cout << "MyType::~MyType " << mName << " my_int:" << my_int_ << '\n';
+#endif
+    }
+
+    MyType(const MyType& other) : mName(other.mName) {
+#ifdef DEBUG_ME
+        std::cout << "MyType::MyType(const MyType&) " << mName << " my_int:" << my_int_ << '\n';
+#endif
+    }
+
+    MyType(MyType&& other) noexcept
+        : mName(std::move(other.mName)) { // vector needs noexcept to call move copy constructor during resize.
+#ifdef DEBUG_ME
+        std::cout << "MyType::MyType(MyType&&) " << mName << " my_int:" << my_int_ << '\n';
+#endif
+    }
+
+    MyType& operator=(const MyType& other) {
+        if (this != &other)
+            mName = other.mName;
+#ifdef DEBUG_ME
+        std::cout << "MyType::operator=(const MyType&) " << mName << " my_int:" << my_int_ << '\n';
+#endif
+        return *this;
+    }
+
+    MyType& operator=(MyType&& other) noexcept {
+        if (this != &other)
+            mName = std::move(other.mName);
+#ifdef DEBUG_ME
+        std::cout << "MyType::operator=(MyType&&) " << mName << " my_int:" << my_int_ << '\n';
+#endif
+        return *this;
+    }
+
+    int my_int() const { return my_int_; }
+    int* my_ptr() const { return my_ptr_; }
+
+private:
+    std::string mName;
+    int my_int_{3};        //  show be applied for all constructor types
+    int* my_ptr_{nullptr}; //  show be applied for all constructor types
+};
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_ClassDataMemberInit)
+
+BOOST_AUTO_TEST_CASE(test_class_data_member_init) {
+    cout << "ACore:: ...test_class_data_member_init \n";
+
+    {
+        MyType type("ABC");
+        auto tmoved = std::move(type);
+        BOOST_CHECK_MESSAGE(tmoved.my_int() == 3, "Error found");
+        BOOST_CHECK_MESSAGE(tmoved.my_ptr() == nullptr, "Error found");
+    }
+    {
+        MyType type("ABC");
+        auto tcopied = MyType(type);
+        BOOST_CHECK_MESSAGE(tcopied.my_int() == 3, "Error found");
+        BOOST_CHECK_MESSAGE(tcopied.my_ptr() == nullptr, "Error found");
+    }
+    {
+        MyType tassigned("XYZ");
+        MyType type("ABC");
+        tassigned = type;
+        BOOST_CHECK_MESSAGE(tassigned.my_int() == 3, "Error found");
+        BOOST_CHECK_MESSAGE(tassigned.my_ptr() == nullptr, "Error found");
+    }
+    {
+        MyType tassigned("XYZ");
+        MyType temp("ABC");
+        tassigned = std::move(temp);
+        BOOST_CHECK_MESSAGE(tassigned.my_int() == 3, "Error found");
+        BOOST_CHECK_MESSAGE(tassigned.my_ptr() == nullptr, "Error found");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestCommandLine.cpp 5.13.0-1/libs/core/test/TestCommandLine.cpp
--- 5.12.4-1/libs/core/test/TestCommandLine.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestCommandLine.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,128 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/CommandLine.hpp"
+#include "ecflow/core/Converter.hpp"
+
+using namespace boost;
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_CommandLine)
+
+static void doCheck(const std::vector<std::string>& theArgs) {
+    CommandLine cl(theArgs);
+
+    BOOST_CHECK_MESSAGE(cl.size() == theArgs.size(), " argc incorrect");
+
+    for (size_t i = 0; i < cl.size(); i++) {
+        const auto& arg = cl.tokens()[i];
+        BOOST_CHECK_MESSAGE(string(arg) == theArgs[i],
+                            "Mismatch in args expected " << theArgs[i] << " but found " << arg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_with_0_args) {
+    std::vector<std::string> theArgs;
+    doCheck(theArgs);
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_with_1_arg) {
+    std::vector theArgs = {"arg1"s};
+    doCheck(theArgs);
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_with_2_args) {
+    std::vector theArgs = {"arg1"s, "arg2"s};
+    doCheck(theArgs);
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_with_10_args) {
+    std::vector<std::string> theArgs(10);
+    for (int i = 0; i < 10; i++) {
+        theArgs.push_back("arg"s + ecf::convert_to<std::string>(i));
+    }
+    doCheck(theArgs);
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_even_quotes) {
+    CommandLine cl{R"(ecflow_client --alter=change variable VARIABLE "some long value string" /path/to/task)"};
+
+    BOOST_REQUIRE_EQUAL(cl.size(), 6ul);
+    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "ecflow_client");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "some long value string");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "/path/to/task");
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_incorrect_quotes) {
+    BOOST_REQUIRE_THROW(
+        CommandLine{R"(ecflow_client --alter=change variable name "some incorrectly ' quoted value" "/some/path)"},
+        std::runtime_error);
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_unmatched_quotes) {
+    BOOST_REQUIRE_THROW(CommandLine{R"(ecflow_client --alter=change variable name "some unclosed value /some/path)"},
+                        std::runtime_error);
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_command_line_with_matched_quotes) {
+    CommandLine cl{R"(ecflow_client --alter=change variable name "some correctly 'inner' quotes value" '/some/path')"};
+
+    BOOST_REQUIRE_EQUAL(cl.size(), 6ul);
+    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "ecflow_client");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "some correctly 'inner' quotes value");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "/some/path");
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_single_option) {
+    CommandLine cl{R"(executable --option)"};
+
+    BOOST_CHECK_EQUAL(cl.tokens().size(), 2ul);
+    BOOST_CHECK_EQUAL(cl.tokens()[0], "executable");
+    BOOST_CHECK_EQUAL(cl.tokens()[1], "--option");
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_empty_value_parameters) {
+    CommandLine cl{R"(   executable --option parameter  type name    ""   "   "   " value " "\"" /some/path  )"};
+
+    BOOST_REQUIRE_EQUAL(cl.tokens().size(), 10ul);
+    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "executable");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[1], "--option");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[2], "parameter");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[3], "type");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "name");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[6], "   ");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[7], " value ");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[8], "\"");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[9], "/some/path");
+}
+
+BOOST_AUTO_TEST_CASE(test_command_line_is_able_to_handle_single_quotes_in_double_quotes) {
+    CommandLine cl{R"(ecflow_client --alter change variable name "'value'" /some/path  )"};
+
+    BOOST_REQUIRE_EQUAL(cl.tokens().size(), 7ul);
+    BOOST_REQUIRE_EQUAL(cl.tokens()[0], "ecflow_client");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[1], "--alter");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[2], "change");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[3], "variable");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[4], "name");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[5], "'value'");
+    BOOST_REQUIRE_EQUAL(cl.tokens()[6], "/some/path");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestConverter.cpp 5.13.0-1/libs/core/test/TestConverter.cpp
--- 5.12.4-1/libs/core/test/TestConverter.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestConverter.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/gregorian/gregorian.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Converter.hpp"
+
+/*
+ * The following dummy classes are defined to support test `can_use_custom_conversion_traits` and confirms that
+ * customization point ::ecf::converter_traits<From, To>::convert(...) can be provided.
+ */
+struct Widget
+{
+};
+struct Gizmo
+{
+};
+
+template <>
+struct ecf::converter_traits<Widget, Gizmo>
+{
+    inline static Gizmo convert(const Widget&) { return Gizmo{}; }
+};
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Converter)
+
+BOOST_AUTO_TEST_CASE(can_convert_from_numeric_to_string) {
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(0), "0");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(123), "123");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(123L), "123");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>('c'), "c");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>("s"), "s");
+
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(0.0), "0");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(0.00), "0");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(1.0), "1");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(-3.5), "-3.5");
+}
+
+BOOST_AUTO_TEST_CASE(can_convert_from_string_to_numeric) {
+    BOOST_CHECK_EQUAL(ecf::convert_to<int>("-0"), 0);
+    BOOST_CHECK_EQUAL(ecf::convert_to<int>("-123"), -123);
+    BOOST_CHECK_EXCEPTION(ecf::convert_to<int>("s"), ecf::bad_conversion, [](const auto& e) { return true; });
+    BOOST_CHECK_EXCEPTION(ecf::convert_to<int>('c'), ecf::bad_conversion, [](const auto& e) { return true; });
+
+    BOOST_CHECK_EQUAL(ecf::convert_to<unsigned int>("-0"), 0U);
+    BOOST_CHECK_EQUAL(ecf::convert_to<unsigned int>("-123"), static_cast<unsigned int>(-123));
+    BOOST_CHECK_EXCEPTION(ecf::convert_to<unsigned int>("s"), ecf::bad_conversion, [](const auto& e) { return true; });
+    BOOST_CHECK_EXCEPTION(ecf::convert_to<unsigned int>('c'), ecf::bad_conversion, [](const auto& e) { return true; });
+
+    BOOST_CHECK_EQUAL(ecf::convert_to<long>("-0"), 0);
+    BOOST_CHECK_EQUAL(ecf::convert_to<long>(-123), -123);
+    BOOST_CHECK_EXCEPTION(ecf::convert_to<long>("s"), ecf::bad_conversion, [](const auto& e) { return true; });
+    BOOST_CHECK_EXCEPTION(ecf::convert_to<long>('c'), ecf::bad_conversion, [](const auto& e) { return true; });
+
+    BOOST_CHECK_EQUAL(ecf::convert_to<double>("0.0"), 0);
+    BOOST_CHECK_EQUAL(ecf::convert_to<double>("0.00"), 0);
+    BOOST_CHECK_EQUAL(ecf::convert_to<double>("1.0"), 1);
+    BOOST_CHECK_EQUAL(ecf::convert_to<double>("-3.5"), -3.5);
+}
+
+BOOST_AUTO_TEST_CASE(can_convert_from_boost_object_to_string) {
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(boost::gregorian::greg_day{23}), "23");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(boost::gregorian::greg_month{2}), "Feb");
+    BOOST_CHECK_EQUAL(ecf::convert_to<std::string>(boost::gregorian::greg_year{2000}), "2000");
+}
+
+BOOST_AUTO_TEST_CASE(can_use_custom_conversion_traits) {
+    // By compiling, the following expression confirms that a Widget can be converted to a Gizmo.
+    ecf::convert_to<Gizmo>(Widget{});
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestCore_main.cpp 5.13.0-1/libs/core/test/TestCore_main.cpp
--- 5.12.4-1/libs/core/test/TestCore_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestCore_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Core
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/core/test/TestExtract.cpp 5.13.0-1/libs/core/test/TestExtract.cpp
--- 5.12.4-1/libs/core/test/TestExtract.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestExtract.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,106 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Extract.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Extract)
+
+BOOST_AUTO_TEST_CASE(can_extract_path_and_name) {
+    using namespace std::string_literals;
+    {
+        auto token = "/suite/family:obj"s;
+        std::string path;
+        std::string name;
+        BOOST_CHECK(Extract::pathAndName(token, path, name));
+        BOOST_CHECK_EQUAL(path, "/suite/family"s);
+        BOOST_CHECK_EQUAL(name, "obj"s);
+    }
+    {
+        auto token = "/suite/family"s;
+        std::string path;
+        std::string name;
+        BOOST_CHECK(Extract::pathAndName(token, path, name));
+        BOOST_CHECK_EQUAL(path, "/suite/family"s);
+        BOOST_CHECK_EQUAL(name, ""s);
+    }
+    {
+        auto token = "obj"s;
+        std::string path;
+        std::string name;
+        BOOST_CHECK(Extract::pathAndName(token, path, name));
+        BOOST_CHECK_EQUAL(path, ""s);
+        BOOST_CHECK_EQUAL(name, "obj"s);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_extract_second_token) {
+    using namespace std::string_literals;
+    {
+        auto token = "First:Second"s;
+        std::string second;
+        BOOST_CHECK(Extract::split_get_second(token, second));
+        BOOST_CHECK_EQUAL(second, "Second"s);
+    }
+    {
+        auto token = "/suite/family:obj"s;
+        std::string second;
+        BOOST_CHECK(Extract::split_get_second(token, second));
+        BOOST_CHECK_EQUAL(second, "obj"s);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_extract_integer) {
+    using namespace std::string_literals;
+    { BOOST_CHECK_THROW(Extract::theInt("", "error message"s), std::runtime_error); }
+    { BOOST_CHECK_THROW(Extract::theInt("a", "error message"s), std::runtime_error); }
+    { BOOST_CHECK_THROW(Extract::theInt("abc", "error message"s), std::runtime_error); }
+    { BOOST_CHECK_THROW(Extract::theInt("#", "error message"s), std::runtime_error); }
+    { BOOST_CHECK_THROW(Extract::theInt(":", "error message"s), std::runtime_error); }
+    { BOOST_CHECK_EQUAL(Extract::theInt("42", "error message"s), 42); }
+    { BOOST_CHECK_EQUAL(Extract::theInt("-42", "error message"s), -42); }
+    { BOOST_CHECK_THROW(Extract::theInt("42 ", "error message"s), std::runtime_error); }
+    { BOOST_CHECK_THROW(Extract::theInt("42 42", "error message"s), std::runtime_error); }
+    { BOOST_CHECK_THROW(Extract::theInt("42.42", "error message"s), std::runtime_error); }
+}
+
+BOOST_AUTO_TEST_CASE(can_extract_optional_integer) {
+    using namespace std::string_literals;
+    {
+        auto tokens = std::vector{"repeat"s, "integer"s, "variable"s, "1"s, "2"s, "#a"s, "comment"s};
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 0, 42, "error message"s), std::runtime_error); }
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 1, 42, "error message"s), std::runtime_error); }
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 2, 42, "error message"s), std::runtime_error); }
+        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 3, 42, "error message"), 1); }
+        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 4, 42, "error message"), 2); }
+        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 5, 42, "error message"), 42); }
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 6, 42, "error message"s), std::runtime_error); }
+    }
+    {
+        auto tokens = std::vector{"repeat"s, "integer"s, "variable"s, "1"s, "2"s, "#"s, "a"s, "comment"s};
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 0, 42, "error message"s), std::runtime_error); }
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 1, 42, "error message"s), std::runtime_error); }
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 2, 42, "error message"s), std::runtime_error); }
+        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 3, 42, "error message"s), 1); }
+        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 4, 42, "error message"s), 2); }
+        { BOOST_CHECK_EQUAL(Extract::optionalInt(tokens, 5, 42, "error message"s), 42); }
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 6, 42, "error message"s), std::runtime_error); }
+        { BOOST_CHECK_THROW(Extract::optionalInt(tokens, 7, 42, "error message"s), std::runtime_error); }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestFile.cpp 5.13.0-1/libs/core/test/TestFile.cpp
--- 5.12.4-1/libs/core/test/TestFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,556 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib> // for getenv()
+#include <fstream> // for std::ofstream
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Converter.hpp"
+
+// #define FILE_PERF_CHECK_IMPLEMENTATIONS 1;
+#ifdef FILE_PERF_CHECK_IMPLEMENTATIONS
+    #include <boost/timer/timer.hpp>
+
+    #include "ecflow/core/Str.hpp"
+#endif
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/NodePath.hpp"
+#include "ecflow/core/User.hpp"
+
+using namespace boost;
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_File)
+
+BOOST_AUTO_TEST_CASE(test_splitFileIntoLines) {
+    // This is sanity test for splitFileIntoLines used extensively
+    cout << "ACore:: ...test_splitFileIntoLines\n";
+
+    std::string path = File::test_data("libs/core/test/data/test_splitFileIntoLines.txt", "libs/core");
+
+    std::string theText = "This is a test string";
+    {
+        {
+            std::ofstream file_with_one_line(path.c_str());
+            file_with_one_line << theText;
+        }
+
+        std::vector<std::string> lines;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
+                            " Failed to open file " << path << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(lines.size() == 1, " Expected 1 line but found " << lines.size());
+
+        fs::remove(path); // Remove the file. Comment out for debugging
+    }
+
+    {
+        {
+            std::ofstream file_with_one_line(path.c_str());
+            file_with_one_line << theText << "\n"; // addition of '/n' , should still be one line
+        }
+
+        std::vector<std::string> lines;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
+                            " Failed to open file " << path << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(lines.size() == 1, " Expected 1 line but found " << lines.size());
+
+        fs::remove(path); // Remove the file. Comment out for debugging
+    }
+
+    {
+        {
+            std::ofstream file_with_two_line(path.c_str());
+            file_with_two_line << theText << "\n";
+            file_with_two_line << theText;
+        }
+
+        std::vector<std::string> lines;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
+                            " Failed to open file " << path << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(lines.size() == 2, " Expected 2 line but found " << lines.size());
+
+        fs::remove(path); // Remove the file. Comment out for debugging
+    }
+
+    {
+        {
+            std::ofstream file_with_three_line(path.c_str());
+            file_with_three_line << theText << "\n";
+            file_with_three_line << theText << "\n";
+            file_with_three_line << theText;
+        }
+
+        std::vector<std::string> lines;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
+                            " Failed to open file " << path << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(lines.size() == 3, " Expected 3 line but found " << lines.size());
+
+        fs::remove(path); // Remove the file. Comment out for debugging
+    }
+
+    {
+        {
+            std::ofstream file_with_three_line(path.c_str());
+            file_with_three_line << theText << "\n";
+            file_with_three_line << theText << "\n";
+            file_with_three_line << theText << "\n";
+        }
+
+        std::vector<std::string> lines;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
+                            " Failed to open file " << path << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(lines.size() == 3, " Expected 3 line but found " << lines.size());
+
+        fs::remove(path); // Remove the file. Comment out for debugging
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_file_tokenizer) {
+    cout << "ACore:: ...test_file_tokenizer\n";
+
+    std::string path = File::test_data("libs/core/test/data/test_file_tokenizer.txt", "libs/core");
+
+    size_t linesWithText = 100;
+    std::string theText  = "This is a test string";
+    {
+        std::ofstream file(path.c_str());
+        for (size_t i = 0; i < linesWithText; i++) {
+            if (i % 2 == 0)
+                file << "\n";        // 51 empty lines
+            file << theText << "\n"; // 100  text lines
+        }
+    }
+    {
+        std::vector<std::string> lines;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines, true /*ignore empty lines*/),
+                            " Failed to open file " << path << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(lines.size() == linesWithText,
+                            "Expected " << linesWithText << " but found " << lines.size());
+        BOOST_CHECK_MESSAGE(lines[0] == theText, "Expected '" << theText << "' but found " << lines[0]);
+        BOOST_CHECK_MESSAGE(lines[linesWithText - 1] == theText,
+                            "Expected '" << theText << "' but found " << lines[linesWithText - 1]);
+
+        lines.clear();
+        size_t totalLines = 151;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
+                            " Failed to open file " << path << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(lines.size() == totalLines - 1,
+                            "Expected " << totalLines - 1 << " but found " << lines.size());
+        BOOST_CHECK_MESSAGE(lines[0] == "", "Expected empty string  but found " << lines[0]);
+        BOOST_CHECK_MESSAGE(lines[1] == theText, "Expected '" << theText << "' but found " << lines[1]);
+        BOOST_CHECK_MESSAGE(lines[2] == theText, "Expected '" << theText << "' but found " << lines[2]);
+        BOOST_CHECK_MESSAGE(lines[3] == "", "Expected empty string  but found " << lines[3]);
+    }
+
+#ifdef FILE_PERF_CHECK_IMPLEMENTATIONS
+    {
+        size_t openFileNTimes = 100000;
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < openFileNTimes; i++) {
+            std::vector<std::string> lines;
+            BOOST_CHECK_MESSAGE(File::splitFileIntoLines(path, lines),
+                                " Failed to open file " << path << " (" << strerror(errno) << ")");
+        }
+        cout << "Time for opening file " << openFileNTimes << " times = " << timer.format(3, Str::cpu_timer_format())
+             << "\n";
+    }
+#endif
+
+    // Remove the file. Comment out for debugging
+    fs::remove(path);
+}
+
+BOOST_AUTO_TEST_CASE(test_file_backwardSearch) {
+    cout << "ACore:: ...test_file_backwardSearch\n";
+
+    std::string nodePath = "dir0/dir1/dir2/dir3/dir4/dir5";
+    std::string rootPath = File::test_data("libs/core/test/data", "libs/core");
+    std::string expected = File::test_data("libs/core/test/data/", "libs/core") + nodePath;
+
+    std::string path = rootPath;
+    std::string dir  = "dir";
+    for (int i = 0; i < 6; i++) {
+        path += "/" + dir + ecf::convert_to<std::string>(i);
+    }
+    // Should have test/data/dir0/dir1/dir3/dir3/dir4/dir5
+    //         or  ACore/test/data/dir0/dir1/dir3/dir3/dir4/dir5
+    BOOST_REQUIRE_MESSAGE(path == expected, " Error expected " << expected << " but found " << path);
+
+    // Create the missing directories
+    BOOST_REQUIRE_MESSAGE(File::createDirectories(path), "Failed to create dirs");
+
+    // Create a file in each of the directories. See Page 21 SMS User Guide.
+    std::vector<std::string> fileContents;
+    fileContents.emplace_back("something");
+    vector<std::string> nodePathTokens;
+    NodePath::split(nodePath, nodePathTokens);
+    while (nodePathTokens.size() > 0) {
+
+        // Reconstitute the path
+        std::string path         = NodePath::createPath(nodePathTokens);
+        std::string combinedPath = rootPath + path;
+
+        BOOST_REQUIRE_MESSAGE(File::createDirectories(combinedPath), "Failed to create dirs " << combinedPath);
+
+        combinedPath += File::ECF_EXTN(); // .ecf, .man , etc
+
+        // std::cout << "Creating file " << combinedPath << "\n";
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(File::create(combinedPath, fileContents, errorMsg),
+                              "Failed to create " << combinedPath << " because " << errorMsg);
+
+        nodePathTokens.erase(nodePathTokens.begin()); // consume first path token
+    }
+
+    // Now do a backward search for them
+    int filesFound = 0;
+    for (int i = 0; i < 6; i++) {
+        std::string theFile = File::backwardSearch(rootPath, nodePath, File::ECF_EXTN());
+        BOOST_CHECK_MESSAGE(!theFile.empty(),
+                            i << ": Failed to find dir5.ecf with rootPath " << rootPath << " and node path "
+                              << nodePath);
+        if (!theFile.empty()) {
+            filesFound++;
+            //			std::cout << "About to remove file " << theFile << "\n";
+            fs::remove(theFile); // remove it so we don't find it again.
+        }
+    }
+    // Expect the following files to be found:
+    //	test/data/dir0/dir1/dir2/dir3/dir4/dir5.ecf
+    //	test/data/dir1/dir2/dir3/dir4/dir5.ecf
+    //	test/data/dir2/dir3/dir4/dir5.ecf
+    //	test/data/dir3/dir4/dir5.ecf
+    //	test/data/dir4/dir5.ecf
+    //	test/data/dir5.ecf
+    BOOST_CHECK_MESSAGE(filesFound == 6, " expect to find 6 files but found " << filesFound);
+
+    // Remove the test dir. Comment out for debugging
+    for (int i = 0; i < 6; i++) {
+        path = rootPath + "/" + dir + ecf::convert_to<std::string>(i);
+        BOOST_CHECK_MESSAGE(File::removeDir(path), "Failed to remove dir " << path);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_file_forwardSearch) {
+    cout << "ACore:: ...test_file_forwardSearch user:" << ecf::User::login_name() << "\n";
+
+    std::string dir_path = "/dir0/dir1/dir2/dir3/dir4";
+    std::string nodePath = dir_path + "/task";
+    std::string rootPath = File::test_data("libs/core/test/data", "libs/core");
+    std::string expected = File::test_data("libs/core/test/data", "libs/core") + nodePath;
+
+    std::string path = rootPath;
+    std::string dir  = "dir";
+    for (int i = 0; i < 6; i++) {
+        if (i == 5)
+            path += "/task";
+        else
+            path += "/" + dir + ecf::convert_to<std::string>(i);
+    }
+    // Should have test/data/dir0/dir1/dir3/dir3/dir4/task
+    //         or  ACore/test/data/dir0/dir1/dir3/dir3/dir4/task
+    BOOST_REQUIRE_MESSAGE(path == expected, " Error expected " << expected << " but found " << path);
+
+    string combined_dir_path = rootPath + dir_path;
+    // cout << " creating directories  : " << combined_dir_path  << "\n";
+    BOOST_REQUIRE_MESSAGE(File::createDirectories(combined_dir_path), "Failed to create dirs" << combined_dir_path);
+
+    // cout << " Create a file(task.ecf) in each of the directories  nodePath: " << nodePath << "\n";
+    std::vector<std::string> fileContents;
+    fileContents.emplace_back("something");
+    vector<std::string> nodePathTokens;
+    NodePath::split(nodePath, nodePathTokens);
+    while (nodePathTokens.size() > 0) {
+
+        std::string path = NodePath::createPath(nodePathTokens);
+        // cout << "   Reconstituted path  : " << path << " from nodePathTokens.size() " << nodePathTokens.size() <<
+        // "\n";
+
+        std::string combinedPath = rootPath + path + File::ECF_EXTN(); // .ecf, .man , etc
+        // cout << "   Creating file       : " << combinedPath << "\n";
+
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(File::create(combinedPath, fileContents, errorMsg),
+                              "Failed to create " << combinedPath << " because " << errorMsg);
+
+        // Preserve the last token, i.e task
+        if (nodePathTokens.size() >= 2)
+            nodePathTokens.erase(nodePathTokens.begin() + nodePathTokens.size() -
+                                 2); // consume one from last path token
+        else
+            nodePathTokens.erase(nodePathTokens.begin());
+    }
+    BOOST_REQUIRE_MESSAGE(nodePathTokens.empty(), "Expected nodePathTokens vec to be empty");
+
+    // Now do a forward search for them:
+    // Expect the following files to be found:
+    // test/data/dir0/dir1/dir2/dir3/dir4/task.ecf
+    // test/data/dir0/dir1/dir2/dir3/task.ecf
+    // test/data/dir0/dir1/dir2/task.ecf
+    // test/data/dir0/dir1/task.ecf
+    // test/data/dir0/task.ecf
+    // test/data/task.ecf
+    // cout << "rootPath: " << rootPath << "\n";
+    // cout << "ECF_EXTN: " << File::ECF_EXTN()  << "\n";
+    int filesFound = 0;
+    for (int i = 0; i < 6; i++) {
+        BOOST_REQUIRE_MESSAGE(i >= 0, "Dummy to debug on macos");
+        std::string theFile = File::forwardSearch(rootPath, nodePath, File::ECF_EXTN());
+        BOOST_CHECK_MESSAGE(!theFile.empty(),
+                            i << ": Failed to find task.ecf with rootPath " << rootPath << " and node path "
+                              << nodePath);
+        if (!theFile.empty()) {
+            filesFound++;
+            // std::cout << "Found file at: " << theFile << "\n";
+            fs::remove(theFile); // *remove* so we don't find it again
+        }
+    }
+    BOOST_CHECK_MESSAGE(filesFound == 6, " expect to find 6 files but found " << filesFound);
+
+    // Remove the test dir0. Comment out for debugging
+    BOOST_CHECK_MESSAGE(File::removeDir(rootPath + "/dir0"), "Failed to remove dir " << rootPath + "/dir0");
+}
+
+BOOST_AUTO_TEST_CASE(test_create_missing_directories) {
+    cout << "ACore:: ...test_create_missing_directories";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    std::string nodePath = "dir0/dir1/dir2/dir3/dir4/dir5";
+    std::string rootPath = File::test_data("libs/core/test/data", "libs/core");
+    std::string expected = File::test_data("libs/core/test/data/", "libs/core") + nodePath;
+
+    std::string dir_remove = rootPath + "/dir0";
+    {
+        // Test basics first, expect "ACore/test/data/dir0/dir1/dir2/dir3/dir4/dir5" to be created
+        BOOST_CHECK_MESSAGE(File::createMissingDirectories(expected),
+                            expected << " expected directories to be created");
+        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
+
+        // remove the directory
+        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
+
+        //      fs::path fs_path(expected);
+        //      std::cout << "parent path " << fs_path.parent_path() << "\n";
+        //      std::cout << "root path " << fs_path.root_path()  << "\n";
+        //      std::cout << "root name " << fs_path.root_name()  << "\n";
+        //      std::cout << "root directory " << fs_path.root_directory()  << "\n";
+        //      std::cout << "relative_path " << fs_path.relative_path()  << "\n";
+        //      std::cout << "filename " << fs_path.filename()  << "\n";
+        //      std::cout << "stem " << fs_path.stem()  << "\n";
+        //      std::cout << "extension " << fs_path.extension()  << "\n";
+    }
+    {
+        // Test "ACore/test/data/dir0/dir1/dir2/dir3/dir4/dir5/fred.ecf" to be created
+        std::string dir_with_file = expected + "/fred.ecf";
+        BOOST_CHECK_MESSAGE(File::createMissingDirectories(dir_with_file),
+                            "Expected '" << dir_with_file << "' to be created");
+        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
+
+        // remove the directory
+        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
+
+        //      fs::path fs_path(dir_with_file);
+        //      std::cout << "parent path " << fs_path.parent_path() << "\n";
+        //      std::cout << "root path " << fs_path.root_path()  << "\n";
+        //      std::cout << "root name " << fs_path.root_name()  << "\n";
+        //      std::cout << "root directory " << fs_path.root_directory()  << "\n";
+        //      std::cout << "relative_path " << fs_path.relative_path()  << "\n";
+        //      std::cout << "filename " << fs_path.filename()  << "\n";
+        //      std::cout << "stem " << fs_path.stem()  << "\n";
+        //      std::cout << "extension " << fs_path.extension()  << "\n";
+    }
+
+    {
+        // Create directories twice. Need to minimise call to fstat
+        BOOST_CHECK_MESSAGE(File::createMissingDirectories(expected), "expected file to be created");
+        BOOST_CHECK_MESSAGE(File::createMissingDirectories(expected), "expected file to be created");
+        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
+
+        // remove the directory
+        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
+    }
+
+    {
+        // Create directories twice. Need to minimise call to fstat
+        std::string dir_with_file = expected + "/fred.ecf";
+        BOOST_CHECK_MESSAGE(File::createMissingDirectories(dir_with_file), "expected file to be created");
+        BOOST_CHECK_MESSAGE(File::createMissingDirectories(dir_with_file), "expected file to be created");
+        BOOST_CHECK_MESSAGE(fs::exists(expected), expected << " directory not created");
+
+        // remove the directory
+        BOOST_CHECK_MESSAGE(File::removeDir(dir_remove), "Failed to remove dir " << dir_remove);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_get_last_lines_of_a_file) {
+    cout << "ACore:: ...test_get_last_lines_of_a_file\n";
+
+    std::string path = File::test_data("libs/core/test/data/test_get_last_lines_of_a_file.txt", "libs/core");
+    std::string last_100_lines;
+    size_t no_of_lines = 100;
+    { // create file with 100 lines 0-99
+        std::stringstream ss;
+        std::ofstream file(path.c_str());
+        for (size_t i = 0; i < no_of_lines; i++) {
+            file << i << ": the line\n";
+            ss << i << ": the line\n";
+        }
+        last_100_lines = ss.str();
+    }
+    { // get negative lines
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, -1, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
+    }
+    { // get no lines
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, 0, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
+    }
+    { // get the last line only
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, 1, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "99: the line\n", "Expected '99: the line\n' but found " << last_lines);
+    }
+    { // get the last 2 line only
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, 2, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "98: the line\n99: the line\n",
+                              "Expected last 2 lines but got " << last_lines);
+    }
+    { // get the last 100 line only
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, no_of_lines, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == last_100_lines,
+                              "Expected last " << no_of_lines << " lines but got " << last_lines);
+    }
+    { // get the last 1000 line only
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, 1000, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == last_100_lines,
+                              "Expected last " << no_of_lines << " lines but got " << last_lines);
+    }
+
+    fs::remove(path); // Remove the file. Comment out for debugging
+
+    // ===================================================================================
+    // Now check empty file
+    // ===================================================================================
+    {
+        std::ofstream file(path.c_str()); // create empty file
+        BOOST_REQUIRE_MESSAGE(file.good(), "failed");
+    }
+
+    { // get no lines ?
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, 0, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
+    }
+    { // get the last line only
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, 1, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
+    }
+    { // get the last 2 line only
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, 2, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
+    }
+    { // get the last 100 line only
+        std::string error_msg;
+        std::string last_lines = File::get_last_n_lines(path, no_of_lines, error_msg);
+        BOOST_REQUIRE_MESSAGE(error_msg.empty(), "Expected no failure but got " << error_msg);
+        BOOST_REQUIRE_MESSAGE(last_lines == "", "Expected '' but found " << last_lines);
+    }
+
+    fs::remove(path); // Remove the file. Comment out for debugging
+}
+
+BOOST_AUTO_TEST_CASE(test_directory_traversal) {
+    cout << "ACore:: ...test_directory_traversal\n";
+
+    int regular_file = 0;
+    //    int directory    = 0;
+    //    int symlink      = 0;
+    //    int other        = 0;
+
+    for (auto& entry : fs::directory_iterator(fs::current_path())) {
+        if (is_regular_file(entry))
+            regular_file++;
+        //        if (is_directory(entry))
+        //            directory++;
+        //        if (is_symlink(entry))
+        //            symlink++;
+        //        if (is_other(entry))
+        //            other++;
+        //      cout << "name.path()            " << entry.path() << "\n";
+        //      cout << "name.path().string()   " << entry.path().string() << "\n";
+        //      cout << "name.path().filename() " << entry.path().filename() << "\n";
+        if (is_regular_file(entry)) {
+            boost::uintmax_t entry_size = fs::file_size(entry);
+            boost::uintmax_t path_size  = fs::file_size(entry.path());
+            BOOST_REQUIRE_MESSAGE(entry_size == path_size,
+                                  "Directory entry file size " << entry_size << " not the same as entry.path() "
+                                                               << path_size);
+            BOOST_REQUIRE_MESSAGE(fs::last_write_time(entry) == fs::last_write_time(entry.path()),
+                                  "Directory entry last write time, not the same as entry.path()");
+            //         cout << "file_size " << fs::file_size(entry) << "\n";
+        }
+    }
+    //   cout << "regular_file " << regular_file << "\n";
+    //   cout << "directory  " <<  directory << "\n";
+    //   cout << "symlink  " << symlink  << "\n";
+    //   cout << "other  " << other  << "\n";
+    BOOST_REQUIRE_MESSAGE(regular_file > 0, "Expected some files in directory");
+}
+
+BOOST_AUTO_TEST_CASE(test_get_all_files_by_extension) {
+    cout << "ACore:: ...test_get_all_files_by_extension\n";
+    {
+        std::string rootPath = File::test_data("libs/core/test/data/badPasswdFiles", "libs/core");
+        std::vector<fs::path> vec;
+        File::find_files_with_extn(rootPath, ".passwd", vec);
+        // for(auto& file: vec)  std::cout << file << "\n";
+        BOOST_REQUIRE_MESSAGE(vec.size() == 6, "Expected 6 files in directory " << rootPath);
+    }
+    {
+        std::string rootPath = File::test_data("libs/core/test/data/badWhiteListFiles", "libs/core");
+        std::vector<fs::path> vec;
+        File::find_files_with_extn(rootPath, ".lists", vec);
+        // for(auto& file: vec)  std::cout << file << "\n";
+        BOOST_REQUIRE_MESSAGE(vec.size() == 7, "Expected 7 files in directory " << rootPath);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestGetUserDetails.cpp 5.13.0-1/libs/core/test/TestGetUserDetails.cpp
--- 5.12.4-1/libs/core/test/TestGetUserDetails.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestGetUserDetails.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,43 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdio>
+#include <iostream>
+#include <pwd.h> /* getpwdid */
+#include <string>
+#include <unistd.h>
+
+#include <boost/test/unit_test.hpp>
+#include <sys/types.h>
+
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_GetUserDetails)
+
+BOOST_AUTO_TEST_CASE(test_get_user_details, *boost::unit_test::disabled()) {
+    cout << "ACore:: ...test_get_user_details\n";
+
+    /* Get the uid of the running processand use it to get a record from /etc/passwd */
+    struct passwd* passwd = getpwuid(getuid());
+
+    printf("\n The Real User Name is %s ", passwd->pw_gecos);
+    printf("\n The Login Name is %s ", passwd->pw_name);
+    printf("\n The Home Directory is %s", passwd->pw_dir);
+    printf("\n The Login Shell is %s ", passwd->pw_shell);
+    printf("\n The Passwd is %s ", getpwuid(getuid())->pw_passwd);
+    printf("\n The uid is %lu ", (unsigned long)getpwuid(getuid())->pw_uid);
+    printf("\n The gid is %lu \n\n", (unsigned long)getpwuid(getuid())->pw_gid);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestLog.cpp 5.13.0-1/libs/core/test/TestLog.cpp
--- 5.12.4-1/libs/core/test/TestLog.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestLog.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,383 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Pid.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Log)
+
+static std::string getLogPath() {
+
+    // ECFLOW-712, generate unique name for log file, To allow parallel test
+    std::string log_file = "libs/core/test/logfile";
+    log_file += Pid::getpid(); // can throw
+    log_file += ".txt";
+    return File::test_data(log_file, "libs/core");
+}
+
+BOOST_AUTO_TEST_CASE(test_log) {
+    std::string path = getLogPath();
+    cout << "ACore:: ...test_log " << path << "\n";
+
+    // delete the log file if it exists.
+    fs::remove(path);
+    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path);
+
+    LogFlusher logFlusher;
+    Log::create(path);
+    LOG(Log::MSG, "First Message");
+    LOG(Log::LOG, "LOG");
+    LOG(Log::ERR, "ERROR");
+    LOG(Log::WAR, "WARNING");
+    LOG(Log::DBG, "DEBUG");
+    LOG(Log::OTH, "OTHER");
+    log(Log::OTH, "test: void log(Log::LogType,const std::string& message)");
+
+    LOG(Log::OTH, "test: LOG(level,path << path) " << path << " " << path);
+
+    Log::instance()->log(Log::OTH, "OTHER2");
+
+    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
+}
+
+BOOST_AUTO_TEST_CASE(test_log_append) {
+    cout << "ACore:: ...test_log_append\n";
+
+    std::string path = getLogPath();
+
+    BOOST_REQUIRE_MESSAGE(fs::exists(path), "log file " << path << " not created by previous test\n");
+
+    {
+        LogFlusher logFlusher;
+        LOG(Log::MSG, "Last Message");
+    }
+
+    // Load the log file into a vector, of strings, and test content
+    std::vector<std::string> lines;
+    BOOST_REQUIRE_MESSAGE(File::splitFileIntoLines(path, lines, true /*IGNORE EMPTY LINE AT THE END*/),
+                          "Failed to open log file"
+                              << " (" << strerror(errno) << ")");
+    BOOST_REQUIRE(lines.size() != 0);
+    BOOST_CHECK_MESSAGE(lines.size() == 10, " Expected 10 lines in log, but found " << lines.size() << "\n");
+    BOOST_CHECK_MESSAGE(lines[0].find("First Message") != string::npos,
+                        "Expected first line to contain 'First Message' but found " << lines[0] << "\n");
+    BOOST_CHECK_MESSAGE(lines.back().find("Last Message") != string::npos,
+                        "Expected last line to contain 'Last Message' but found " << lines.back() << "\n");
+
+    // Clear the log file. Comment out for debugging
+    Log::instance()->clear();
+    BOOST_CHECK_MESSAGE(fs::file_size(path) == 0, "Clear of log file failed\n");
+
+    // Remove the log file. Comment out for debugging
+    fs::remove(path);
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_log_path) {
+    cout << "ACore:: ...test_log_path\n";
+
+    Log::create("test_log_path.log");
+
+    // make sure path returned is absolute
+    std::string path = Log::instance()->path();
+    BOOST_REQUIRE_MESSAGE(path[0] == '/', "Expected absolute paths for log file but found " << path);
+
+    // Remove the log file. Comment out for debugging
+    fs::remove(path);
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_log_new_path_errors) {
+    cout << "ACore:: ...test_log_new_path_errors\n";
+
+    // delete the log file if it exists.
+    std::string path = getLogPath();
+    fs::remove(path);
+
+    // create a now log file.
+    Log::create(path);
+    LOG(Log::MSG, "First Message");
+    LOG(Log::LOG, "LOG");
+
+    // Specify bad paths for new log file
+    // First test empty path throws
+    BOOST_REQUIRE_THROW(Log::instance()->new_path(""), std::runtime_error);
+
+    // If a path is specified make sure parent directory exists
+    fs::path current_path = fs::current_path();
+    std::string path2     = current_path.string();
+    path2 += "/a/made/up/path/fred.log";
+    // cout << path2<< "\n";
+    BOOST_REQUIRE_THROW(Log::instance()->new_path(path2), std::runtime_error);
+
+    // Make sure path does not correspond to a directory
+    // cout << "parent directory: " << current_path.parent_path() << "\n";
+    BOOST_REQUIRE_THROW(Log::instance()->new_path(current_path.parent_path().string()), std::runtime_error);
+
+    //   {
+    //      fs::path valid_path = getLogPath();
+    //      std::cout << "valid_path = " << valid_path << "\n";
+    //      std::cout << "valid_path.root_path(): " << valid_path.root_path() << "\n";
+    //      std::cout << "valid_path.root_name() : " << valid_path.root_name()  << "\n";
+    //      std::cout << "valid_path.root_directory()  : " << valid_path.root_directory()   << "\n";
+    //      std::cout << "valid_path.relative_path()  : " << valid_path.relative_path()   << "\n";
+    //      std::cout << "valid_path.parent_path()  : " << valid_path.parent_path()   << "\n";
+    //      std::cout << "valid_path.filename()  : " << valid_path.filename()   << "\n";
+    //      std::cout << "valid_path.stem()  : " << valid_path.stem()   << "\n";
+    //      std::cout << "valid_path.extension()  : " << valid_path.extension()   << "\n";
+    //   }
+
+    // Remove the log file. Comment out for debugging
+    fs::remove(Log::instance()->path());
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_log_new_path) {
+    cout << "ACore:: ...test_log_new_path\n";
+
+    // delete the log file if it exists.
+    std::string path = getLogPath();
+    fs::remove(path);
+
+    // create a new log file.
+    Log::create(path);
+    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()),
+                        "Log file should be created after explicit call to Log::create()\n");
+    LOG(Log::LOG, "LOG");
+    fs::remove(Log::instance()->path());
+
+    // Specify a new log path. Path could be a relative path like "test/logfile.log"
+    std::string relative_path = File::test_data("libs/core/test/logfile.log", "libs/core");
+
+    BOOST_REQUIRE_NO_THROW(Log::instance()->new_path(relative_path));
+    BOOST_CHECK_MESSAGE(!fs::exists(Log::instance()->path()),
+                        "Log file should *NOT* be created until first message is logged\n");
+    LOG(Log::LOG, "LOG");
+    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()),
+                        "Log file should be created after first message is logged\n");
+    fs::remove(Log::instance()->path());
+
+    // Specify a new log path. This time we just specify a file name, without a path.
+    BOOST_REQUIRE_NO_THROW(Log::instance()->new_path("testlog.log"));
+    BOOST_CHECK_MESSAGE(!fs::exists(Log::instance()->path()),
+                        "Log file should not be created until first message is logged\n");
+    // File not created until a message is logged
+    LOG(Log::LOG, "LOG");
+    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()),
+                        "Log file should be created after first message is logged\n");
+
+    fs::remove(Log::instance()->path());
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_get_last_n_lines_from_log) {
+    cout << "ACore:: ...test_get_last_n_lines_from_log\n";
+
+    // delete the log file if it exists.
+    std::string path = getLogPath();
+    fs::remove(path);
+    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path);
+
+    // Create the log file;
+    Log::create(path);
+    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
+
+    // Log file should be empty
+    const int NO_OF_LINES_IN_LOG_FILE = 200;
+    {
+        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
+            std::string line = Log::instance()->contents(i);
+            BOOST_CHECK_MESSAGE(line.empty(), "Expected empty string but found\n" << line);
+        }
+    }
+
+    // Populate the log file
+    std::string msg = "This is message ";
+    for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; ++i)
+        LOG(Log::MSG, msg << i);
+
+    // Now check, getting the lines
+    {
+        std::string line = Log::instance()->contents(0);
+        BOOST_CHECK_MESSAGE(line.empty(), "Expected empty string but found\n" << line);
+    }
+    {
+        // Check we get back the number of line requested
+        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
+            std::string lines = Log::instance()->contents(i);
+            int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
+            BOOST_CHECK_MESSAGE(i == newlineCount, "expected to  " << i << " newlines but found " << newlineCount);
+        }
+    }
+    {
+        // Check we get back *ALL* lines requested
+        std::string lines = Log::instance()->contents(NO_OF_LINES_IN_LOG_FILE);
+        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
+            std::stringstream ss;
+            ss << msg << i;
+            std::string str_to_find = ss.str();
+            BOOST_CHECK_MESSAGE(lines.find(str_to_find) != std::string::npos,
+                                "expected to find " << str_to_find << " in the log file");
+        }
+    }
+
+    {
+        // Request more than is available, should only get back whats there
+        std::string lines = Log::instance()->contents(NO_OF_LINES_IN_LOG_FILE * 2);
+        int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
+        BOOST_CHECK_MESSAGE(NO_OF_LINES_IN_LOG_FILE == newlineCount,
+                            "expected " << NO_OF_LINES_IN_LOG_FILE << " newlines but found " << newlineCount);
+    }
+
+    fs::remove(Log::instance()->path());
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_get_first_n_lines_from_log) {
+    cout << "ACore:: ...test_get_first_n_lines_from_log\n";
+
+    // delete the log file if it exists.
+    std::string path = getLogPath();
+    fs::remove(path);
+    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path << " not created \n");
+
+    // Create the log file;
+    Log::create(path);
+    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
+
+    // Populate the log file
+    const int NO_OF_LINES_IN_LOG_FILE = 200;
+    std::string msg                   = "This is message ";
+    for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; ++i)
+        LOG(Log::MSG, msg << i);
+
+    // Now check, getting the lines
+    {
+        // Get the first line
+        std::string line     = Log::instance()->contents(-1);
+        std::string expected = msg + "0";
+        BOOST_CHECK_MESSAGE(line.find(expected) != std::string::npos,
+                            "Expected '" << expected << "' but found\n"
+                                         << line);
+    }
+    {
+        // Get the first & second line
+        std::string line      = Log::instance()->contents(-2);
+        std::string expected0 = msg + "0";
+        std::string expected1 = msg + "1";
+        BOOST_CHECK_MESSAGE(line.find(expected0) != std::string::npos,
+                            "Expected '" << expected0 << "' but found\n"
+                                         << line);
+        BOOST_CHECK_MESSAGE(line.find(expected1) != std::string::npos,
+                            "Expected '" << expected1 << "' but found\n"
+                                         << line);
+    }
+    {
+        // Check we get back the number of line requested
+        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
+            std::string lines = Log::instance()->contents(-i);
+            int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
+            BOOST_CHECK_MESSAGE(i == newlineCount, "expected to  " << i << " newlines but found " << newlineCount);
+        }
+    }
+    {
+        std::string lines = Log::instance()->contents(-NO_OF_LINES_IN_LOG_FILE);
+        for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; i++) {
+            std::stringstream ss;
+            ss << msg << i;
+            std::string expected = ss.str();
+            BOOST_CHECK_MESSAGE(lines.find(expected) != std::string::npos,
+                                "Expected '" << expected << "' but found for i " << i);
+        }
+    }
+
+    {
+        // Request more than is available, should only get back whats there
+        std::string lines = Log::instance()->contents(-NO_OF_LINES_IN_LOG_FILE * 2);
+        int newlineCount  = std::count(lines.begin(), lines.end(), '\n');
+        BOOST_CHECK_MESSAGE(NO_OF_LINES_IN_LOG_FILE == newlineCount,
+                            "expected " << NO_OF_LINES_IN_LOG_FILE << " newlines but found " << newlineCount);
+    }
+
+    fs::remove(Log::instance()->path());
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_get_log_timing) {
+    cout << "ACore:: ...test_get_log_timing: " << flush;
+
+    // *************************************************************************************
+    // This test was used with *DIFFERENT* implementations for Log::instance()->contents(1)
+    // What is shows, is that for optimal performance we should *NOT* load the entire log file
+    // This can be several giga bytes.
+    // **************************************************************************************
+
+    // delete the log file if it exists.
+    std::string path = getLogPath();
+    fs::remove(getLogPath());
+    BOOST_REQUIRE_MESSAGE(!fs::exists(path), "log file not deleted " << path << " not created \n");
+
+    // Create the log file;
+    Log::create(path);
+    BOOST_CHECK_MESSAGE(fs::exists(path), "log file " << path << " not created \n");
+
+    // Populate the log file
+    const int NO_OF_LINES_IN_LOG_FILE = 20000;
+    std::string msg                   = "This is message ";
+    for (int i = 0; i < NO_OF_LINES_IN_LOG_FILE; ++i)
+        LOG(Log::MSG, msg << i);
+
+    DurationTimer timer;
+
+    {
+        const int LOOP = 100;
+        for (int i = 0; i < LOOP; i++) {
+            std::string lines = Log::instance()->contents(1);
+            BOOST_CHECK_MESSAGE(!lines.empty(), "expected entry");
+        }
+    }
+
+    fs::remove(Log::instance()->path());
+
+    // Explicitly destroy log. To keep valgrind happy
+    Log::destroy();
+
+    cout << timer.duration() << "s\n" << flush;
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestMessage.cpp 5.13.0-1/libs/core/test/TestMessage.cpp
--- 5.12.4-1/libs/core/test/TestMessage.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestMessage.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,54 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Message.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Message)
+
+BOOST_AUTO_TEST_CASE(test_message_can_create_from_various_arguments) {
+    using namespace ecf;
+    using namespace std::string_literals;
+
+    BOOST_CHECK_EQUAL(Message().str(), ""s);
+    BOOST_CHECK_EQUAL(Message("a", ' ', "1").str(), "a 1"s);
+    BOOST_CHECK_EQUAL(Message("a", ' ', "1.01").str(), "a 1.01"s);
+    BOOST_CHECK_EQUAL(Message("a", ' ', 1).str(), "a 1"s);
+    BOOST_CHECK_EQUAL(Message("a", ' ', 1.01).str(), "a 1.01"s);
+    BOOST_CHECK_EQUAL(Message("a", ' ', true).str(), "a 1"s);
+    BOOST_CHECK_EQUAL(Message("a", Message("b", 'c')).str(), "abc"s);
+}
+
+BOOST_AUTO_TEST_CASE(test_message_can_convert_to_string) {
+    using namespace ecf;
+    using namespace std::string_literals;
+
+    std::string s = Message("a", Message("b", 'c'));
+    BOOST_CHECK_EQUAL(s, "abc"s);
+}
+
+BOOST_AUTO_TEST_CASE(test_message_can_stream) {
+    using namespace ecf;
+    using namespace std::string_literals;
+
+    std::ostringstream oss;
+    oss << Message("a", Message("b", 'c'));
+
+    BOOST_CHECK_EQUAL(oss.str(), "abc"s);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestMigration.cpp 5.13.0-1/libs/core/test/TestMigration.cpp
--- 5.12.4-1/libs/core/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestMigration.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestSerialisation.hpp"
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/DState.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Migration)
+
+// If you are updating the tests, *MAKE SURE* to check out test/data/migration/* files
+// #define UPDATE_TESTS 1
+
+BOOST_AUTO_TEST_CASE(test_migration_restore_cereal) {
+    cout << "ACore:: ...test_migration_restore_cereal\n";
+
+    std::string file_name = File::test_data("libs/core/test/data/migration/", "libs/core");
+
+    // Note: default calendar constructor will init with current time: Hence set for comparison
+    Calendar calendar;
+    boost::gregorian::date theDate(2011, 2, 10);
+    ptime time(theDate, hours(23) + minutes(59));
+    calendar.init(time, Calendar::REAL); // Calendar type is derived from the clock attribute & hence is not persisted
+
+    DebugEquality debug_equality; // only as affect in DEBUG build
+
+    string cereal_version = "_1_2_2_";
+
+#ifdef UPDATE_TESTS
+    doSave<TimeSlot>(file_name + "timeslot_default_constructor" + cereal_version);
+    doSave<TimeSeries>(file_name + "timeseries_default_constructor" + cereal_version);
+    doSave<Calendar>(file_name + "calendar" + cereal_version, calendar);
+    doSave(file_name + "timeslot" + cereal_version + "11", TimeSlot(1, 1));
+    doSave(file_name + "timeslot" + cereal_version + "9959", TimeSlot(99, 59));
+    doSave(file_name + "timeseries" + cereal_version + "1010", TimeSeries(TimeSlot(10, 10)));
+    doSave(file_name + "dstate" + cereal_version, DState());
+    doSave(file_name + "nstate" + cereal_version, NState());
+#else
+    do_restore<TimeSlot>(file_name + "timeslot_default_constructor" + cereal_version, TimeSlot());
+    do_restore<TimeSeries>(file_name + "timeseries_default_constructor" + cereal_version, TimeSeries());
+    do_restore<Calendar>(file_name + "calendar" + cereal_version, calendar);
+    do_restore<TimeSlot>(file_name + "timeslot" + cereal_version + "11", TimeSlot(1, 1));
+    do_restore<TimeSlot>(file_name + "timeslot" + cereal_version + "9959", TimeSlot(99, 59));
+    do_restore<TimeSeries>(file_name + "timeseries" + cereal_version + "1010", TimeSeries(TimeSlot(10, 10)));
+    do_restore<DState>(file_name + "dstate" + cereal_version, DState());
+    do_restore<NState>(file_name + "nstate" + cereal_version, NState());
+#endif
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestNodePath.cpp 5.13.0-1/libs/core/test/TestNodePath.cpp
--- 5.12.4-1/libs/core/test/TestNodePath.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestNodePath.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,144 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <iterator> // std::ostream_iterator
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+#include <boost/timer/timer.hpp>
+
+#include "ecflow/core/NodePath.hpp"
+
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_NodePath)
+
+static void checkPath(const std::vector<std::string>& expectedPath, const std::string& path) {
+    std::vector<std::string> thePath;
+    NodePath::split(path, thePath);
+    if (thePath != expectedPath) {
+        BOOST_CHECK_MESSAGE(false, "Failed for " << path);
+        std::cout << "Expected '";
+        std::copy(expectedPath.begin(), expectedPath.end(), std::ostream_iterator<std::string>(std::cout, " "));
+        std::cout << "'\nbut found '";
+        std::copy(thePath.begin(), thePath.end(), std::ostream_iterator<std::string>(std::cout, " "));
+        std::cout << "'\n";
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_path_extractor_constructor) {
+    cout << "ACore:: ...test_path_extractor_constructor\n";
+    BOOST_CHECK(true); // stop boost test from complaining about no checks
+
+    std::vector<std::string> theExpectedPath;
+    checkPath(theExpectedPath, "");
+
+    theExpectedPath.emplace_back("suite");
+    checkPath(theExpectedPath, "/suite");
+    checkPath(theExpectedPath, "suite");
+}
+
+BOOST_AUTO_TEST_CASE(test_path_extractor) {
+    cout << "ACore:: ...test_path_extractor\n";
+    BOOST_CHECK(true); // stop boost test from complaining about no checks
+
+    std::vector<std::string> theExpectedPath;
+    theExpectedPath.emplace_back("suite");
+    theExpectedPath.emplace_back("family");
+    theExpectedPath.emplace_back("task");
+
+    checkPath(theExpectedPath, "/suite/family/task");
+    checkPath(theExpectedPath, "/suite/family/task/");
+}
+
+BOOST_AUTO_TEST_CASE(test_unix_path_extractor) {
+    cout << "ACore:: ...test_unix_path_extractor\n";
+    BOOST_CHECK(true); // stop boost test from complaining about no checks
+
+    // On Unix multiple '/' are treated as one.
+    std::vector<std::string> theExpectedPath;
+    theExpectedPath.emplace_back("suite");
+    theExpectedPath.emplace_back("family");
+    theExpectedPath.emplace_back("task");
+
+    checkPath(theExpectedPath, "/suite///family////task");
+    checkPath(theExpectedPath, "/suite///family////task//");
+    checkPath(theExpectedPath, "//suite///family////task//");
+    checkPath(theExpectedPath, "///suite///family////task//");
+    checkPath(theExpectedPath, "///suite///family////task///");
+}
+
+BOOST_AUTO_TEST_CASE(test_extractHostPort) {
+    cout << "ACore:: ...test_extractHostPort\n";
+
+    std::string path;
+    std::string host;
+    std::string port;
+    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
+
+    path = "Apath";
+    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
+
+    path = " : ";
+    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
+
+    path = "host:";
+    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
+
+    path = ":port";
+    BOOST_CHECK_MESSAGE(!NodePath::extractHostPort(path, host, port), "expected failure");
+
+    path = "host:port";
+    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
+    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
+
+    path = "//host:port";
+    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
+    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
+
+    path = "//host:port/";
+    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
+    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
+
+    path = "//host:port/suite";
+    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
+    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
+
+    path = "//host:port/suite/family/task";
+    BOOST_CHECK_MESSAGE(NodePath::extractHostPort(path, host, port), "expected success " << host << ":" << port);
+    BOOST_CHECK_MESSAGE(host == "host" && port == "port", "expected 'host:port' found " << host << ":" << port);
+}
+
+BOOST_AUTO_TEST_CASE(test_NodePath_perf, *boost::unit_test::disabled()) {
+    cout << "ACore:: ...test_NodePath_perf \n";
+
+    // Timing using:
+    //    StringSplitter : 6.35
+    //    Str::split     : 8.64
+    // See: Str::split -> define USE_STRINGSPLITTER
+
+    // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+    boost::timer::auto_cpu_timer timer;
+    int n = 10000000;
+    std::vector<std::string> thePath;
+    thePath.reserve(20);
+    for (int i = 0; i < n; i++) {
+        thePath.clear();
+        NodePath::split("/this/is/a/test/string/that/will/be/used/to/check/perf/of/node/path/extraction", thePath);
+    }
+    cout << "Timing for " << n << " NodePath is  " << timer.elapsed().wall << endl;
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestPasswdFile.cpp 5.13.0-1/libs/core/test/TestPasswdFile.cpp
--- 5.12.4-1/libs/core/test/TestPasswdFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestPasswdFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,153 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/PasswdFile.hpp"
+#include "ecflow/core/PasswordEncryption.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// #define DEBUG_ME 1
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_PasswdFile)
+
+void test_passwd_files(const std::string& directory, bool pass) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+#if DEBUG_ME
+    std::cout << "...In directory: " << full_path.relative_path() << "\n";
+#endif
+
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (fs::is_directory(dir_itr->status())) {
+                test_passwd_files(relPath.string(), pass);
+                continue;
+            }
+#if DEBUG_ME
+            std::cout << "......Parsing file " << relPath.string() << "\n";
+#endif
+            PasswdFile theFile;
+            std::string errorMsg;
+            bool parsedOk = theFile.load(relPath.string(), false /*debug*/, errorMsg);
+            if (pass) {
+                // Test expected to pass
+                BOOST_CHECK_MESSAGE(parsedOk,
+                                    "Failed to parse file " << relPath << "\n"
+                                                            << errorMsg << "\n"
+                                                            << theFile.dump());
+            }
+            else {
+                // test expected to fail
+                BOOST_CHECK_MESSAGE(!parsedOk,
+                                    "Parse expected to fail for " << relPath << "\n"
+                                                                  << errorMsg << "\n"
+                                                                  << theFile.dump());
+#if DEBUG_ME
+                cout << "\n" << errorMsg << "\n";
+#endif
+            }
+        }
+        catch (const std::exception& ex) {
+            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_for_good_passwd_files) {
+    cout << "ACore:: ...test_parsing_for_good_passwd_files\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodPasswdFiles", "libs/core");
+
+    // All the files in this directory are expected to pass
+    test_passwd_files(path, true);
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_for_bad_passwd_files) {
+    cout << "ACore:: ...test_parsing_for_bad_passwd_files\n";
+
+    std::string path = File::test_data("libs/core/test/data/badPasswdFiles", "libs/core");
+
+    // All the files in this directory are expected to fail
+    test_passwd_files(path, false);
+}
+
+BOOST_AUTO_TEST_CASE(test_passwd_empty_file) {
+    cout << "ACore:: ...test_passwd_empty_file\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodPasswdFiles/empty.passwd", "libs/core");
+
+    PasswdFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    BOOST_REQUIRE_MESSAGE(theFile.passwds().empty(), "expected empty file ");
+    BOOST_REQUIRE_MESSAGE(theFile.get_passwd("fred", "host", "port") == string(), "expected empty string");
+    BOOST_REQUIRE_MESSAGE(theFile.authenticate("fred", ""),
+                          "expected to authenticate. TEST CASE with empty password file");
+    BOOST_REQUIRE_MESSAGE(!theFile.authenticate("fred", "passwd"), "expected not to authenticate");
+    BOOST_REQUIRE_MESSAGE(!theFile.authenticate("", "passwd"), "expected not to authenticate");
+    BOOST_REQUIRE_MESSAGE(!theFile.authenticate("", ""), "expected not to authenticate");
+}
+
+BOOST_AUTO_TEST_CASE(test_passwd) {
+    cout << "ACore:: ...test_passwd\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodPasswdFiles/ecf.passwd", "libs/core");
+
+    PasswdFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    BOOST_CHECK_MESSAGE(theFile.check_at_least_one_user_with_host_and_port("host", "3141"), "expected to pass");
+    BOOST_CHECK_MESSAGE(theFile.check_at_least_one_user_with_host_and_port("host3", "3143"), "expected to pass");
+    BOOST_CHECK_MESSAGE(theFile.check_at_least_one_user_with_host_and_port("host4", "3145"), "expected to pass");
+    BOOST_CHECK_MESSAGE(!theFile.check_at_least_one_user_with_host_and_port("xxxx", "3141"), "expected fail ");
+    BOOST_CHECK_MESSAGE(!theFile.check_at_least_one_user_with_host_and_port("host", "13141"), "expected fail ");
+
+    // make sure we find all the users and the access right are correct
+    //   4.4.0  # comment
+    //
+    //   # comment
+    //   fred host 3141  x12ggg # comment
+    //   fred host3 3143 passwd
+    //   fred host4 3145 x12ggg
+    //   # comment
+    //
+    //   jake host 3141  x12ggg
+    //   tom host3 3143    x12ggg # sdsdsd
+
+    std::vector<Pass_wd> expected_passwds;
+    expected_passwds.emplace_back("fred", "host", "3141", PasswordEncryption::encrypt("x12ggg", "fred"));
+    expected_passwds.emplace_back("fred", "host3", "3143", PasswordEncryption::encrypt("passwd", "fred"));
+    expected_passwds.emplace_back("fred", "host4", "3145", PasswordEncryption::encrypt("x12ggg", "fred"));
+    expected_passwds.emplace_back("jake", "host", "3141", PasswordEncryption::encrypt("x12ggg", "jake"));
+    expected_passwds.emplace_back("tom", "host3", "3143", PasswordEncryption::encrypt("x12ggg", "tom"));
+
+    BOOST_REQUIRE_MESSAGE(expected_passwds == theFile.passwds(), "expected passwords to match");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestPasswordEncryption.cpp 5.13.0-1/libs/core/test/TestPasswordEncryption.cpp
--- 5.12.4-1/libs/core/test/TestPasswordEncryption.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestPasswordEncryption.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+///
+/// \brief Tests the functionality provided by PasswordEncryption
+///
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/PasswordEncryption.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_PasswordEncryption)
+
+BOOST_AUTO_TEST_CASE(test_is_able_to_encrypt_password) {
+    PasswordEncryption::username_t user               = "username";
+    PasswordEncryption::plain_password_t plain        = "password";
+    PasswordEncryption::encrypted_password_t expected = "usjRS48E8ZADM";
+    // Expected was obtained by calling `$ openssl passwd -salt username password`
+
+    auto encrypted = PasswordEncryption::encrypt(plain, user);
+
+    BOOST_REQUIRE(encrypted == expected);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestPerfTimer.cpp 5.13.0-1/libs/core/test/TestPerfTimer.cpp
--- 5.12.4-1/libs/core/test/TestPerfTimer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestPerfTimer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/perf_timer.hpp"
+
+using namespace boost;
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_PerfTimer)
+
+static void func(int const count = 100000) {
+    // std::cout << " func : count " << count << "\n";
+    for (int i = 0; i < count; i++) {
+        std::string s = std::string("fred");
+        s += ecf::convert_to<std::string>(i);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_perf_with_chrono) {
+    cout << "ACore:: ...test_perf_with_chrono\n";
+
+    // using namespace std::chrono_literals;
+
+    auto t = perf_timer<>::duration(func, 100000);
+
+    std::cout << "   " << std::chrono::duration<double, std::micro>(t).count() << " micro" << std::endl;
+    std::cout << "   " << std::chrono::duration<double, std::milli>(t).count() << " milli" << std::endl;
+    std::cout << "   " << std::chrono::duration<double, std::nano>(t).count() << " nano" << std::endl;
+
+    // This does not work, ie calling func with no arguments ?? with our hacked invoke, wait till c++ 17
+    // auto t0= perf_timer<std::chrono::nanoseconds>::duration(func);
+
+    auto t1 = perf_timer<std::chrono::nanoseconds>::duration(func, 10);
+    auto t2 = perf_timer<std::chrono::microseconds>::duration(func, 100);
+    auto t3 = perf_timer<std::chrono::milliseconds>::duration(func, 100000);
+    std::cout << "   " << std::chrono::duration<double, std::milli>(t1 + t2 + t3).count() << " milli" << std::endl;
+    BOOST_CHECK_MESSAGE(true, "dummy to keep unit test happy");
+}
+
+BOOST_AUTO_TEST_CASE(test_chrono_timer) {
+    cout << "ACore:: ... test_chrono_timer\n";
+
+    // using namespace std::chrono_literals;
+    {
+        Timer<std::chrono::milliseconds> timer;
+        func();
+        timer.elapsed("   func with default args , milliseconds");
+        std::cout << "    " << std::chrono::duration<double, std::micro>(timer.elapsed()).count() << " micro"
+                  << std::endl;
+        std::cout << "    " << std::chrono::duration<double, std::milli>(timer.elapsed()).count() << " milli"
+                  << std::endl;
+        std::cout << "    " << std::chrono::duration<double, std::nano>(timer.elapsed()).count() << " nano"
+                  << std::endl;
+    }
+    {
+        Timer<std::chrono::microseconds> timer;
+        func();
+        timer.elapsed("   func with default args , microseconds");
+    }
+    {
+        Timer<std::chrono::nanoseconds> timer;
+        func();
+        timer.elapsed("   func with default args , nanoseconds");
+    }
+    {
+        Timer<std::chrono::seconds> timer;
+        func();
+        timer.elapsed("   func with default args , seconds");
+    }
+    BOOST_CHECK_MESSAGE(true, "dummy to keep unit test happy");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestRealCalendar.cpp 5.13.0-1/libs/core/test/TestRealCalendar.cpp
--- 5.12.4-1/libs/core/test/TestRealCalendar.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestRealCalendar.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,350 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/date_time/posix_time/time_formatters.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_RealCalendar)
+
+BOOST_AUTO_TEST_CASE(test_REAL_calendar) {
+    cout << "ACore:: ...test_REAL_calendar\n";
+
+    // init the calendar to 2009, Feb, 10th,
+    boost::gregorian::date theDate(2009, 2, 10);
+    ptime time(theDate, hours(22) + minutes(10));
+
+    Calendar calendar;
+    calendar.init(time, Calendar::REAL);
+
+    // record the time for the test
+    boost::posix_time::ptime theSuiteTime        = calendar.suiteTime();
+    boost::posix_time::time_duration theDuration = calendar.duration();
+
+    // Take time now and add 2 minutes, use this to update calendar by 2 minutes
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+    time_now += minutes(2);
+    theSuiteTime += minutes(2);
+    theDuration += minutes(2);
+
+    calendar.update(time_now);
+
+    BOOST_CHECK_MESSAGE(calendar.suiteTime() == theSuiteTime,
+                        " Expected " << to_simple_string(theSuiteTime) << " but found "
+                                     << to_simple_string(calendar.suiteTime()));
+    BOOST_CHECK_MESSAGE(calendar.duration() == theDuration,
+                        " Expected " << to_simple_string(theDuration) << " but found "
+                                     << to_simple_string(calendar.duration()));
+
+    time_now += hours(24);
+    theSuiteTime += hours(24);
+    theDuration += hours(24);
+
+    calendar.update(time_now);
+
+    BOOST_CHECK_MESSAGE(calendar.suiteTime() == theSuiteTime,
+                        " Expected " << to_simple_string(theSuiteTime) << " but found "
+                                     << to_simple_string(calendar.suiteTime()));
+    BOOST_CHECK_MESSAGE(calendar.duration() == theDuration,
+                        " Expected " << to_simple_string(theDuration) << " but found "
+                                     << to_simple_string(calendar.duration()));
+}
+
+BOOST_AUTO_TEST_CASE(test_REAL_calendar_time_series_relative_complex) {
+    cout << "ACore:: ...test_REAL_calendar_time_series_relative_complex\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
+
+    // Create a test when we can match a time series
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr   00:15
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15), true /*relative*/);
+
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+
+    for (int hour = 0; hour < 24; hour++) {
+        for (int minute = 0; minute < 60; minute++) {
+
+            // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
+            time_now += minutes(1);
+
+            calendar.update(time_now);
+
+            timeSeries.calendarChanged(calendar);
+
+            tm suiteTm = to_tm(calendar.suiteTime());
+
+            bool matches = timeSeries.isFree(calendar);
+
+            bool intersects =
+                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
+                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
+            // Ovoid overshooting past end of series
+            bool boundaryOk = true;
+            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
+                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
+            }
+
+            if (intersects && boundaryOk) {
+                BOOST_CHECK_MESSAGE(matches,
+                                    "Calendar should match relative time series at "
+                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+                if (!matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!matches,
+                                    "Calendar should NOT match relative time series at "
+                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+
+                if (matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_REAL_calendar_time_series) {
+    cout << "ACore:: ...test_REAL_calendar_time_series\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr    1:00
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0));
+
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+
+    for (int hour = 1; hour < 24; hour++) {
+        // Update calendar every hour, then see we can match time series, in REAL
+        // Update will set the local time from the computers system clock, however
+        // for testing this will need to be overriden below.
+
+        time_now += hours(1);
+
+        calendar.update(time_now);
+
+        // cerr << "hour = " << hour << " suiteTime " << to_simple_string(calendar.suiteTime())  << "\n";
+        if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(calendar), "Calendar should match time series at hour " << hour);
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Calendar should NOT match time series at hour " << hour);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_REAL_calendar_time_series_complex) {
+    cout << "ACore:: ...test_REAL_calendar_time_series_complex\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr   00:15
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(0, 15));
+
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+
+    for (int hour = 0; hour < 24; hour++) {
+        for (int minute = 0; minute < 60; minute++) {
+
+            // Update calendar every minute, then see we can match time series, *RELATIVE* to suite start
+            time_now += minutes(1);
+            calendar.update(time_now);
+
+            tm suiteTm = to_tm(calendar.suiteTime());
+
+            bool matches = timeSeries.isFree(calendar);
+
+            bool intersects =
+                (suiteTm.tm_hour >= timeSeries.start().hour() && suiteTm.tm_hour <= timeSeries.finish().hour() &&
+                 (suiteTm.tm_min == 0 || suiteTm.tm_min % timeSeries.incr().minute() == 0));
+            // Ovoid overshooting past end of series
+            bool boundaryOk = true;
+            if (suiteTm.tm_hour == timeSeries.finish().hour()) {
+                boundaryOk = (suiteTm.tm_min <= timeSeries.finish().minute());
+            }
+
+            if (intersects && boundaryOk) {
+                BOOST_CHECK_MESSAGE(matches,
+                                    "Calendar should match relative time series at "
+                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+                if (!matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!matches,
+                                    "Calendar should NOT match relative time series at "
+                                        << suiteTm.tm_hour << ":" << suiteTm.tm_min
+                                        << " suite time = " << to_simple_string(calendar.suiteTime()));
+
+                if (matches) {
+                    cerr << "suiteTm.tm_hour =" << suiteTm.tm_hour << " suiteTm.tm_min = " << suiteTm.tm_min
+                         << " timeSeries.start().hour() " << timeSeries.start().hour()
+                         << " timeSeries.start().minute() " << timeSeries.start().minute()
+                         << " timeSeries.finish().hour() " << timeSeries.finish().hour()
+                         << " timeSeries.finish().minute() " << timeSeries.finish().minute()
+                         << " suiteTm.tm_min % 15 = " << suiteTm.tm_min % 15 << "\n";
+                }
+            }
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_REAL_calendar_hybrid_date) {
+    cout << "ACore:: ...test_REAL_calendar_hybrid_date\n";
+
+    // The hybrid calendar should not change the suite date.
+    // Test by updateing calendar by more than 24 hours
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
+
+    std::string expectedDate          = "2010-Feb-10";
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+
+    for (int hour = 1; hour < 60; hour++) {
+        // Update calendar every hour, for 60 hours
+        // the date should be the same, i.e 2009, Feb, 10th
+
+        ptime timeBeforeUpdate = calendar.suiteTime();
+
+        time_now += hours(1);
+
+        calendar.update(time_now);
+
+        ptime timeAfterUpdate = calendar.suiteTime();
+
+        //		cerr << "hour = " << hour << " timeBeforeUpdate " << to_simple_string(timeBeforeUpdate)
+        //		    << "   timeAfterUpdate = " << to_simple_string(timeAfterUpdate) <<  "\n";
+
+        if (hour != 24 && hour != 48) {
+            time_period diff(timeBeforeUpdate, timeAfterUpdate);
+            time_duration gap = diff.length();
+            BOOST_CHECK_MESSAGE(gap.hours() == 1,
+                                "Expected one hour difference but found " << gap.hours() << " at hour " << hour);
+        }
+
+        std::string actualDate = to_simple_string(calendar.suiteTime().date());
+        BOOST_CHECK_MESSAGE(actualDate == expectedDate,
+                            "Expected '" << expectedDate << "' but found " << actualDate << " at hour " << hour);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_REAL_day_changed) {
+    cout << "ACore:: ...test_REAL_day_changed \n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+    BOOST_CHECK_MESSAGE(!calendar.hybrid(), "calendar type should be real");
+
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+
+    for (int hour = 1; hour < 73; hour++) {
+        // Update calendar every hour, for 72 hours
+
+        time_now += hours(1);
+
+        calendar.update(time_now);
+
+        if (hour == 24 || hour == 48 || hour == 72) {
+            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
+                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
+                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_REAL_day_changed_for_hybrid) {
+    cout << "ACore:: ...test_REAL_day_changed_for_hybrid\n";
+
+    // init the calendar to 2009, Feb, 10th,  0 minutes past midnight
+    Calendar calendar;
+    calendar.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::HYBRID);
+    BOOST_CHECK_MESSAGE(calendar.hybrid(), "calendar type should be real");
+
+    // HYBRID calendars allow for day change but not date.
+    std::string expected_date = to_simple_string(calendar.date());
+
+    boost::posix_time::ptime time_now = Calendar::second_clock_time();
+
+    for (int hour = 1; hour < 73; hour++) {
+        // Update calendar every hour, for 72 hours
+
+        time_now += hours(1);
+        calendar.update(time_now);
+
+        BOOST_CHECK_MESSAGE(expected_date == to_simple_string(calendar.date()),
+                            "Unexpected date change for hybrid calendar at hour " << hour);
+
+        // Day should change even for hybrid calendar,
+        if (hour == 24 || hour == 48 || hour == 72) {
+            BOOST_CHECK_MESSAGE(calendar.dayChanged(),
+                                "Expected day change at hour " << hour << " calendar " << calendar.toString());
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!calendar.dayChanged(),
+                                "Un-Expected day change at hour " << hour << " calendar " << calendar.toString());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestSanitizerAS.cpp 5.13.0-1/libs/core/test/TestSanitizerAS.cpp
--- 5.12.4-1/libs/core/test/TestSanitizerAS.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestSanitizerAS.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+using namespace boost;
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_SanitizerAS)
+
+bool bool_returning_function() {
+    return true;
+}
+int integer_returning_function() {
+    return 3;
+}
+
+#if defined(__GNUC__) and !defined(__clang__)
+    #pragma GCC diagnostic push
+    #pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
+#endif
+
+// *** This test does not seem work with address sanitiser ****
+BOOST_AUTO_TEST_CASE(test_sanitizer_use_of_out_of_scope_stack_memory) {
+    char* test_me = getenv("ECF_TEST_SANITIZER_AS");
+    if (test_me) {
+        cout << "ACore:: ...test_sanitizer_use_of_out_of_scope_stack_memory\n";
+
+        int* pointer = NULL;
+        if (bool_returning_function()) {
+            int value = integer_returning_function();
+            pointer   = &value;
+        }
+        cout << "dodgy pointer:" << *pointer << "\n"; // Error: invalid access of stack memory out of declaration scope
+        *pointer = 42;
+        cout << "dodgy pointer:" << *pointer << "\n";
+        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
+    }
+}
+
+#if defined(__GNUC__) and !defined(__clang__)
+    #pragma GCC diagnostic pop
+#endif
+
+#if defined(__GNUC__) and !defined(__clang__)
+    #pragma GCC diagnostic push
+    #pragma GCC diagnostic ignored "-Warray-bounds"
+#endif
+
+BOOST_AUTO_TEST_CASE(test_sanitizer_vector_overflow) {
+    char* test_me = getenv("ECF_TEST_SANITIZER_AS");
+    if (test_me) {
+        cout << "ACore:: ...test_sanitizer_vector_overflow\n";
+        // This check detects when a libc++ container is accessed beyond the region [container.begin(), container.end())
+        // — even when the accessed memory is in a heap-allocated buffer used internally by a container.
+
+        // the following example, the vector variable has valid indexes in the range [0, 2], but is accessed at index 3,
+        // causing an overflow.
+        std::vector<int> vector{0, 1, 2};
+        auto* pointer = &vector[0];
+        cout << pointer[3]; // Error: out of bounds access for vector
+        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
+    }
+}
+
+#if defined(__GNUC__) and !defined(__clang__)
+    #pragma GCC diagnostic pop
+#endif
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestSanitizerUB.cpp 5.13.0-1/libs/core/test/TestSanitizerUB.cpp
--- 5.12.4-1/libs/core/test/TestSanitizerUB.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestSanitizerUB.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,120 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+using namespace boost;
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_SanitizerUB)
+
+struct Base
+{
+    int pad1{0};
+};
+struct Derived : Base
+{
+    int pad2{0};
+};
+Derived* getDerived() {
+    return static_cast<Derived*>(new Base); // Error: invalid downcast
+}
+
+#if defined(__GNUC__) and !defined(__clang__)
+    #pragma GCC diagnostic push
+    #pragma GCC diagnostic ignored "-Warray-bounds"
+#endif
+
+BOOST_AUTO_TEST_CASE(test_sanitizer_invalid_object_size) {
+    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
+    if (test_me) {
+        cout << "ACore:: ...test_sanitizer_invalid_object_size\n";
+
+        // This check detects pointer casts in which the size of the source type is less than the size of the
+        // destination type. Using the result of such a cast to access out-of-bounds data has undefined behaviour
+        cout << getDerived()->pad2 << "\n";
+        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
+    }
+}
+
+#if defined(__GNUC__) and !defined(__clang__)
+    #pragma GCC diagnostic pop
+#endif
+
+BOOST_AUTO_TEST_CASE(test_sanitizer_misaligned_structure_pointer_assignment) {
+    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
+    if (test_me) {
+        cout << "ACore:: ...test_sanitizer_misaligned_structure_pointer_assignment\n";
+        // In the following example, the pointer variable is required to have 8-byte alignment, but is only 1-byte
+        // aligned.
+
+        struct A
+        {
+            int32_t i32;
+            int64_t i64;
+        };
+        int8_t* buffer    = (int8_t*)malloc(32);
+        struct A* pointer = (struct A*)(buffer + 1);
+        pointer->i32      = 7; // Error: pointer is misaligned
+
+        BOOST_CHECK_MESSAGE(pointer->i32 == 7, "expected error");
+
+        // solution
+        // One solution is to mark the struct as packed. In the following example, the A structure is packed,
+        // preventing the compiler from adding padding between members.
+        // struct A { ... } __attribute__((packed));
+        BOOST_CHECK_MESSAGE(true, "stop boost test from complaining");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_sanitizer_out_of_bounds_array_access) {
+    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
+    if (test_me) {
+        cout << "ACore:: ...test_sanitizer_out_of_bounds_array_access\n";
+
+        // This check detects out-of-bounds access of arrays with fixed or variable-length sizes.
+        // Out-of-bounds array accesses have undefined behaviour, and can result in crashes or incorrect program output.
+        int array[5] = {0, 0, 0, 0, 0};
+        for (int i = 0; i <= 5; ++i) {
+            array[i] += 1; // Error: out-of-bounds access on the last iteration
+            BOOST_REQUIRE_NO_THROW(array[i] += 1);
+        }
+    }
+}
+
+struct A
+{
+    int x;
+    int getX() {
+        //        if (!this) { // Warning: redundant null check may be removed
+        //            return 0;
+        //        }
+        return x; // Warning: 'this' pointer is null, but is dereferenced here
+    }
+};
+
+BOOST_AUTO_TEST_CASE(test_sanitizer_member_access_through_null_pointer) {
+    char* test_me = getenv("ECF_TEST_SANITIZER_UB");
+    if (test_me) {
+        cout << "ACore:: ...test_sanitizer_member_access_through_null_pointer \n";
+
+        A* a  = nullptr;
+        int x = a->getX(); // Error: member access through null pointer
+        BOOST_CHECK_MESSAGE(x, "stop boost test from complaining");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestSerialisation.cpp 5.13.0-1/libs/core/test/TestSerialisation.cpp
--- 5.12.4-1/libs/core/test/TestSerialisation.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestSerialisation.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "TestSerialisation.hpp"
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+static std::string fileName = "test.txt";
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Serialisation)
+
+BOOST_AUTO_TEST_CASE(test_calendar_serialisation) {
+    cout << "ACore:: ...test_calendar_serialisation \n";
+
+    Calendar cal;
+    doSaveAndRestore(fileName, cal);
+}
+
+BOOST_AUTO_TEST_CASE(test_TimeSlot_serialisation) {
+    cout << "ACore:: ...test_TimeSlot_serialisation \n";
+
+    { doSaveAndRestore<TimeSlot>(fileName); }
+
+    {
+        TimeSlot saved(1, 1);
+        doSaveAndRestore(fileName, saved);
+    }
+
+    {
+        TimeSlot saved(99, 59);
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_TimeSeries_serialisation) {
+    cout << "ACore:: ...test_TimeSeries_serialisation \n";
+
+    { doSaveAndRestore<TimeSeries>(fileName); }
+    {
+        TimeSeries saved = TimeSeries(TimeSlot(10, 10));
+        doSaveAndRestore(fileName, saved);
+    }
+    {
+        TimeSeries saved = TimeSeries(TimeSlot(0, 0), TimeSlot(10, 10), TimeSlot(0, 10));
+        doSaveAndRestore(fileName, saved);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestSerialisation.hpp 5.13.0-1/libs/core/test/TestSerialisation.hpp
--- 5.12.4-1/libs/core/test/TestSerialisation.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestSerialisation.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_TestSerialisation_HPP
+#define ecflow_core_TestSerialisation_HPP
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Serialization.hpp"
+
+namespace ecf {
+
+template <typename T>
+void do_restore(const std::string& fileName, const T& saved) {
+    T restored;
+    try {
+        ecf::restore(fileName, restored);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Restore failed because: " << e.what());
+    }
+    BOOST_CHECK_MESSAGE(saved == restored, "save and restored don't match for " << fileName << "\n");
+}
+
+template <typename T>
+void doRestore(const std::string& fileName, const T& saved) {
+    do_restore(fileName, saved);
+    std::remove(fileName.c_str());
+}
+
+template <typename T>
+void doSave(const std::string& fileName, const T& saved) {
+    try {
+        ecf::save(fileName, saved);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Save  failed because: " << e.what());
+    }
+}
+
+template <typename T>
+void doSave(const std::string& fileName) {
+    T saved;
+    doSave(fileName, saved);
+}
+
+template <typename T>
+void doSaveAndRestore(const std::string& fileName, const T& saved) {
+    doSave(fileName, saved);
+    doRestore(fileName, saved);
+}
+
+template <typename T>
+void doSaveAndRestore(const std::string& fileName) {
+    T saved;
+    doSaveAndRestore(fileName, saved);
+}
+
+} // namespace ecf
+
+#endif /* ecflow_core_TestSerialisation_HPP */
diff -pruN 5.12.4-1/libs/core/test/TestStr.cpp 5.13.0-1/libs/core/test/TestStr.cpp
--- 5.12.4-1/libs/core/test/TestStr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestStr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,939 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <algorithm>
+#include <functional>
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+#include <boost/timer/timer.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/StringSplitter.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Str)
+
+BOOST_AUTO_TEST_CASE(test_str) {
+    cout << "ACore:: ...test_str\n";
+
+    {
+        std::string str;
+        std::string expected;
+        Str::removeQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+
+        str      = "\"\"";
+        expected = "";
+        Str::removeQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+
+        str      = "fred";
+        expected = "fred";
+        Str::removeQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+
+        str      = "\"fred\"";
+        expected = "fred";
+        Str::removeQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+    }
+    {
+        std::string str;
+        std::string expected;
+        Str::removeSingleQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+
+        str      = "''";
+        expected = "";
+        Str::removeSingleQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+
+        str      = "fred";
+        expected = "fred";
+        Str::removeSingleQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+
+        str      = "'fred'";
+        expected = "fred";
+        Str::removeSingleQuotes(str);
+        BOOST_CHECK_MESSAGE(str == expected, " Expected " << expected << " but found " << str);
+    }
+    {
+        string test;
+        BOOST_CHECK_MESSAGE(!Str::truncate_at_start(test, 7), "Empty sring should return false");
+
+        test            = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
+        string expected = "line";
+        BOOST_CHECK_MESSAGE(Str::truncate_at_start(test, 1) && test == expected,
+                            "Expected:\n"
+                                << expected << "\nbut found:\n"
+                                << test);
+
+        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
+        expected = "a\nstring\nwith\nlots\nof\nnew\nline";
+        BOOST_CHECK_MESSAGE(Str::truncate_at_start(test, 7) && test == expected,
+                            "Expected:\n"
+                                << expected << "\nbut found:\n"
+                                << test);
+
+        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
+        expected = test;
+        BOOST_CHECK_MESSAGE(!Str::truncate_at_start(test, 9) && test == expected,
+                            "Expected:\n"
+                                << expected << "\nbut found:\n"
+                                << test);
+    }
+    {
+        string test;
+        BOOST_CHECK_MESSAGE(!Str::truncate_at_end(test, 7), "Empty string should return false");
+
+        test            = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
+        string expected = "this\n";
+        BOOST_CHECK_MESSAGE(Str::truncate_at_end(test, 1) && test == expected,
+                            "Expected:\n"
+                                << expected << "\nbut found:\n"
+                                << test);
+
+        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
+        expected = "this\nis\n";
+        BOOST_CHECK_MESSAGE(Str::truncate_at_end(test, 2) && test == expected,
+                            "Expected:\n"
+                                << expected << "\nbut found:\n"
+                                << test);
+
+        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
+        expected = "this\nis\na\nstring\nwith\nlots\nof\n";
+        BOOST_CHECK_MESSAGE(Str::truncate_at_end(test, 7) && test == expected,
+                            "Expected:\n"
+                                << expected << "\nbut found:\n"
+                                << test);
+
+        test     = "this\nis\na\nstring\nwith\nlots\nof\nnew\nline";
+        expected = test;
+        BOOST_CHECK_MESSAGE(!Str::truncate_at_end(test, 9) && test == expected,
+                            "Expected:\n"
+                                << expected << "\nbut found:\n"
+                                << test);
+    }
+}
+
+static void
+check(const std::string& line, const std::vector<std::string>& result, const std::vector<std::string>& expected) {
+    BOOST_CHECK_MESSAGE(result.size() == expected.size(),
+                        "expected size " << expected.size() << " but found " << result.size() << " for '" << line
+                                         << "'");
+    BOOST_CHECK_MESSAGE(result == expected, "failed for '" << line << "'");
+    if (result != expected) {
+        cout << "Line    :'" << line << "'\n";
+        cout << "Actual  :";
+        for (const string& t : result) {
+            cout << "'" << t << "'";
+        }
+        cout << "\n";
+        cout << "Expected:";
+        for (const string& t : expected) {
+            cout << "'" << t << "'";
+        }
+        cout << "\n";
+    }
+}
+
+static void
+check(const std::string& line, const std::vector<std::string_view>& result2, const std::vector<std::string>& expected) {
+    std::vector<std::string> result;
+    for (auto ref : result2) {
+        result.emplace_back(ref.begin(), ref.end());
+    }
+    check(line, result, expected);
+}
+
+static void check(const std::string& line,
+                  boost::split_iterator<std::string::const_iterator> res,
+                  const std::vector<std::string>& expected) {
+    std::vector<std::string> result;
+    typedef boost::split_iterator<std::string::const_iterator> split_iter_t;
+    for (; res != split_iter_t(); res++)
+        result.push_back(boost::copy_range<std::string>(*res));
+    check(line, result, expected);
+}
+
+static void check_splitters(const std::string& line, const std::vector<std::string>& expected) {
+    std::vector<std::string> result, result1, result2, result3;
+    std::vector<std::string_view> result4;
+
+    Str::split_orig(line, result);
+    check(line, result, expected);
+    Str::split_orig1(line, result1);
+    check(line, result1, expected);
+    Str::split_using_string_view(line, result2);
+    check(line, result2, expected);
+    Str::split_using_string_view2(line, result3);
+    check(line, result3, expected);
+    StringSplitter::split(line, result4);
+    check(line, result4, expected);
+
+    // While were at it also check get_token
+    for (size_t i = 0; i < result1.size(); i++) {
+        std::string token;
+        BOOST_CHECK_MESSAGE(Str::get_token(line, i, token) && token == result1[i],
+                            "Str::get_token failed for pos " << i << " line:'" << line << "' expected '" << result1[i]
+                                                             << "' but found '" << token << "'");
+
+        token.clear();
+        BOOST_CHECK_MESSAGE(Str::get_token2(line, i, token) && token == result1[i],
+                            "Str::get_token2 failed for pos " << i << " line:'" << line << "' expected '" << result1[i]
+                                                              << "' but found '" << token << "'");
+
+        token.clear();
+        BOOST_CHECK_MESSAGE(Str::get_token3(line, i, token) && token == result1[i],
+                            "Str::get_token3 failed for pos " << i << " line:'" << line << "' expected '" << result1[i]
+                                                              << "' but found '" << token << "'");
+
+        token.clear();
+        BOOST_CHECK_MESSAGE(StringSplitter::get_token(line, i, token) && token == result1[i],
+                            "StringSplitter::get_token failed for pos " << i << " line:'" << line << "' expected '"
+                                                                        << result1[i] << "' but found '" << token
+                                                                        << "'");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_str_split) {
+    cout << "ACore:: ...test_str_split\n";
+
+    std::vector<std::string> expected;
+
+    std::string line = "This is a string";
+    expected.emplace_back("This");
+    expected.emplace_back("is");
+    expected.emplace_back("a");
+    expected.emplace_back("string");
+    check_splitters(line, expected);
+
+    expected.clear();
+    line = "  ";
+    check_splitters(line, expected);
+
+    line = "a";
+    expected.clear();
+    expected.emplace_back("a");
+    check_splitters(line, expected);
+
+    // Some implementation fail this test
+    line = "\n";
+    expected.clear();
+    expected.emplace_back("\n");
+    check_splitters(line, expected);
+
+    line = "a ";
+    expected.clear();
+    expected.emplace_back("a");
+    check_splitters(line, expected);
+
+    line = " a";
+    expected.clear();
+    expected.emplace_back("a");
+    check_splitters(line, expected);
+
+    line = "	a"; // check tabs
+    expected.clear();
+    expected.emplace_back("a");
+    check_splitters(line, expected);
+
+    line = "		a		"; // check sequential tabs
+    expected.clear();
+    expected.emplace_back("a");
+    check_splitters(line, expected);
+
+    line = " a ";
+    expected.clear();
+    expected.emplace_back("a");
+    check_splitters(line, expected);
+
+    line = "        a     b     c       d        ";
+    expected.clear();
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    expected.emplace_back("d");
+    check_splitters(line, expected);
+
+    line = " - !   $ % ^ & * ( ) - + ?";
+    expected.clear();
+    expected.emplace_back("-");
+    expected.emplace_back("!");
+    expected.emplace_back("$");
+    expected.emplace_back("%");
+    expected.emplace_back("^");
+    expected.emplace_back("&");
+    expected.emplace_back("*");
+    expected.emplace_back("(");
+    expected.emplace_back(")");
+    expected.emplace_back("-");
+    expected.emplace_back("+");
+    expected.emplace_back("?");
+    check_splitters(line, expected);
+
+    // Check tabs
+    line = "		 verify complete:8		                # 4 sundays in october hence expect 8 task "
+           "completions";
+    expected.clear();
+    expected.emplace_back("verify");
+    expected.emplace_back("complete:8");
+    expected.emplace_back("#");
+    expected.emplace_back("4");
+    expected.emplace_back("sundays");
+    expected.emplace_back("in");
+    expected.emplace_back("october");
+    expected.emplace_back("hence");
+    expected.emplace_back("expect");
+    expected.emplace_back("8");
+    expected.emplace_back("task");
+    expected.emplace_back("completions");
+    check_splitters(line, expected);
+}
+
+BOOST_AUTO_TEST_CASE(test_str_split_make_split_iterator) {
+    cout << "ACore:: ...test_str_split_make_split_iterator\n";
+
+    std::string line = "This is a string";
+    std::vector<std::string> expected;
+    expected.emplace_back("This");
+    expected.emplace_back("is");
+    expected.emplace_back("a");
+    expected.emplace_back("string");
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    expected.emplace_back("");
+    line = "";
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    expected.emplace_back("");
+    expected.emplace_back("");
+    line = "  "; // If start/end is delimeter, then preserved as empty token
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = "a";
+    expected.emplace_back("a");
+    check(line, Str::make_split_iterator(line), expected);
+
+    // Some implementation fail this test
+    expected.clear();
+    line = "\n";
+    expected.emplace_back("\n");
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = "a ";
+    expected.emplace_back("a");
+    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = " a";
+    expected.emplace_back("");
+    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = " a"; // check tabs
+    expected.emplace_back("");
+    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = "    a     "; // check sequential tabs
+    expected.emplace_back("");
+    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
+    expected.emplace_back("");
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = " a ";
+    expected.emplace_back("");
+    expected.emplace_back("a"); // delimeter at start/end preserved, as empty token
+    expected.emplace_back("");
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = "        a     b     c       d        ";
+    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    expected.emplace_back("d");
+    expected.emplace_back("");
+    check(line, Str::make_split_iterator(line), expected);
+
+    expected.clear();
+    line = " - !   $ % ^  & * ( ) - + ?";
+    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
+    expected.emplace_back("-");
+    expected.emplace_back("!");
+    expected.emplace_back("$");
+    expected.emplace_back("%");
+    expected.emplace_back("^");
+    expected.emplace_back("&");
+    expected.emplace_back("*");
+    expected.emplace_back("(");
+    expected.emplace_back(")");
+    expected.emplace_back("-");
+    expected.emplace_back("+");
+    expected.emplace_back("?");
+    check(line, Str::make_split_iterator(line), expected);
+
+    // Check tabs
+    expected.clear();
+    line = "     verify complete:8                      # 4 sundays in october hence expect 8 task completions";
+    expected.emplace_back(""); // delimeter at start/end preserved, as empty token
+    expected.emplace_back("verify");
+    expected.emplace_back("complete:8");
+    expected.emplace_back("#");
+    expected.emplace_back("4");
+    expected.emplace_back("sundays");
+    expected.emplace_back("in");
+    expected.emplace_back("october");
+    expected.emplace_back("hence");
+    expected.emplace_back("expect");
+    expected.emplace_back("8");
+    expected.emplace_back("task");
+    expected.emplace_back("completions");
+    check(line, Str::make_split_iterator(line), expected);
+}
+
+static void
+test_replace(std::string& testStr, const std::string& find, const std::string& replace, const std::string& expected) {
+    BOOST_CHECK_MESSAGE(Str::replace(testStr, find, replace),
+                        "Replace failed for " << testStr << " find(" << find << ") replace(" << replace << ")");
+    BOOST_CHECK_MESSAGE(testStr == expected, "Expected '" << expected << "' but found '" << testStr << "'");
+}
+
+static void test_replace_all(std::string& testStr,
+                             const std::string& find,
+                             const std::string& replace,
+                             const std::string& expected) {
+    std::string testStrCopy = testStr;
+
+    BOOST_CHECK_MESSAGE(Str::replace_all(testStr, find, replace),
+                        "Replace failed for " << testStr << " find(" << find << ") replace(" << replace << ")");
+    BOOST_CHECK_MESSAGE(testStr == expected, "Expected '" << expected << "' but found '" << testStr << "'");
+
+    Str::replaceall(testStrCopy, find, replace);
+    BOOST_CHECK_MESSAGE(testStr == testStrCopy, "Expected '" << testStrCopy << "' but found '" << testStr << "'");
+}
+
+BOOST_AUTO_TEST_CASE(test_str_replace) {
+    cout << "ACore:: ...test_str_replace\n";
+
+    std::string testStr = "This is a string";
+    test_replace(testStr, "This", "That", "That is a string");
+
+    testStr = "This is a string";
+    test_replace(testStr, "This is a string", "", "");
+
+    testStr = "This is a string";
+    test_replace(testStr, "is a", "was a", "This was a string");
+
+    testStr = "This\n is a string";
+    test_replace(testStr, "\n", "\\n", "This\\n is a string");
+
+    testStr = "This\n is\n a\n string\n";
+    test_replace_all(testStr, "\n", "\\n", R"(This\n is\n a\n string\n)");
+
+    // Test case insenstive string comparison
+    BOOST_CHECK_MESSAGE(Str::caseInsCompare("", ""), " bug1");
+    BOOST_CHECK_MESSAGE(!Str::caseInsCompare("Str", "Str1"), " bug1");
+    BOOST_CHECK_MESSAGE(!Str::caseInsCompare("", "Str1"), " bug1");
+    BOOST_CHECK_MESSAGE(Str::caseInsCompare("Str", "STR"), " bug1");
+    BOOST_CHECK_MESSAGE(Str::caseInsCompare("Case", "CaSE"), " bug1");
+}
+
+BOOST_AUTO_TEST_CASE(test_str_replace_all) {
+    cout << "ACore:: ...test_str_replace_all\n";
+
+    std::string testStr = "This is a string";
+    test_replace_all(testStr, "This", "That", "That is a string");
+
+    testStr = "This is a string";
+    test_replace_all(testStr, "This is a string", "", "");
+
+    testStr = "This is a string";
+    test_replace_all(testStr, "is a", "was a", "This was a string");
+
+    testStr = "This\n is a string";
+    test_replace_all(testStr, "\n", "\\n", "This\\n is a string");
+
+    testStr = "This\n is\n a\n string\n";
+    test_replace_all(testStr, "\n", "\\n", R"(This\n is\n a\n string\n)");
+
+    testStr = "This\n is\n a\n string\n";
+    test_replace_all(testStr, "\n", "", "This is a string");
+}
+
+BOOST_AUTO_TEST_CASE(test_str_to_int) {
+    cout << "ACore:: ...test_str(to_int)\n";
+    BOOST_CHECK_MESSAGE(Str::to_int("0") == 0, "Expected 0");
+    BOOST_CHECK_MESSAGE(Str::to_int("1") == 1, "Expected 1");
+    BOOST_CHECK_MESSAGE(Str::to_int("-0") == 0, "Expected 0");
+    BOOST_CHECK_MESSAGE(Str::to_int("-1") == -1, "Expected -1");
+    BOOST_CHECK_MESSAGE(Str::to_int("") == std::numeric_limits<int>::max(), "Expected max int");
+    BOOST_CHECK_MESSAGE(Str::to_int("-") == std::numeric_limits<int>::max(), "Expected max int");
+    BOOST_CHECK_MESSAGE(Str::to_int(" ") == std::numeric_limits<int>::max(), "Expected max int");
+    BOOST_CHECK_MESSAGE(Str::to_int("q") == std::numeric_limits<int>::max(), "Expected max int");
+    BOOST_CHECK_MESSAGE(Str::to_int("q22") == std::numeric_limits<int>::max(), "Expected max int");
+    BOOST_CHECK_MESSAGE(Str::to_int("q22", -1) == -1, "Expected -1 on failure");
+    BOOST_CHECK_MESSAGE(Str::to_int("99 99") == std::numeric_limits<int>::max(), "Expected max int");
+    BOOST_CHECK_MESSAGE(Str::to_int("99 99", 0) == 0, "Expected 0 for failure");
+}
+
+BOOST_AUTO_TEST_CASE(test_extract_data_member_value) {
+    cout << "ACore:: ...test_extract_data_member_value\n";
+    std::string expected = "value";
+    std::string actual;
+    std::string str = "aa bb c fred:value";
+    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "fred:", actual), " failed");
+    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
+
+    str      = "fred:x  bill:zzz jake:12345 1234:99  6677";
+    expected = "x";
+    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "fred:", actual), " failed");
+    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
+
+    expected = "zzz";
+    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "bill:", actual), " failed");
+    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
+
+    expected = "12345";
+    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "jake:", actual), " failed");
+    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
+
+    expected = "99";
+    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "1234:", actual), " failed");
+    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
+
+    expected = "77";
+    BOOST_CHECK_MESSAGE(Str::extract_data_member_value(str, "66", actual), " failed");
+    BOOST_CHECK_MESSAGE(expected == actual, "expected '" << expected << "' but found '" << actual << "'");
+}
+
+std::string toString(const std::vector<std::string>& c) {
+    std::stringstream ss;
+    std::copy(c.begin(), c.end(), std::ostream_iterator<std::string>(ss, ", "));
+    return ss.str();
+}
+
+BOOST_AUTO_TEST_CASE(test_str_less_greater) {
+    cout << "ACore:: ...test_str_less_greater\n";
+
+    std::vector<std::string> expected;
+    expected.emplace_back("a1");
+    expected.emplace_back("A2");
+    expected.emplace_back("b1");
+    expected.emplace_back("B2");
+    expected.emplace_back("c");
+
+    std::vector<std::string> expectedGreater;
+    expectedGreater.emplace_back("c");
+    expectedGreater.emplace_back("B2");
+    expectedGreater.emplace_back("b1");
+    expectedGreater.emplace_back("A2");
+    expectedGreater.emplace_back("a1");
+
+    std::vector<std::string> vec;
+    vec.emplace_back("c");
+    vec.emplace_back("A2");
+    vec.emplace_back("a1");
+    vec.emplace_back("b1");
+    vec.emplace_back("B2");
+
+    std::sort(vec.begin(), vec.end(), Str::caseInsLess);
+    BOOST_REQUIRE_MESSAGE(vec == expected, "expected " << toString(expected) << " but found " << toString(vec));
+
+    std::sort(vec.begin(), vec.end(), Str::caseInsGreater);
+    BOOST_REQUIRE_MESSAGE(vec == expectedGreater,
+                          "expected " << toString(expectedGreater) << " but found " << toString(vec));
+
+    // --------------------------------------------------------------------
+
+    expected.clear();
+    expected.emplace_back("a");
+    expected.emplace_back("A");
+    expected.emplace_back("b");
+    expected.emplace_back("B");
+    expected.emplace_back("c");
+
+    expectedGreater.clear();
+    expectedGreater.emplace_back("c");
+    expectedGreater.emplace_back("B");
+    expectedGreater.emplace_back("b");
+    expectedGreater.emplace_back("A");
+    expectedGreater.emplace_back("a");
+
+    vec.clear();
+    vec.emplace_back("c");
+    vec.emplace_back("B");
+    vec.emplace_back("A");
+    vec.emplace_back("b");
+    vec.emplace_back("a");
+
+    std::sort(vec.begin(), vec.end(), Str::caseInsLess);
+    BOOST_REQUIRE_MESSAGE(vec == expected, "expected " << toString(expected) << " but found " << toString(vec));
+
+    std::sort(vec.begin(), vec.end(), Str::caseInsGreater);
+    BOOST_REQUIRE_MESSAGE(vec == expectedGreater,
+                          "expected " << toString(expectedGreater) << " but found " << toString(vec));
+
+    // --------------------------------------------------------------------
+
+    expected.clear();
+    expected.emplace_back("1234");
+    expected.emplace_back("baSE");
+    expected.emplace_back("Base");
+    expected.emplace_back("case");
+    expected.emplace_back("CaSe");
+    expected.emplace_back("suite");
+    expected.emplace_back("SUITE");
+
+    expectedGreater.clear();
+    expectedGreater.emplace_back("SUITE");
+    expectedGreater.emplace_back("suite");
+    expectedGreater.emplace_back("CaSe");
+    expectedGreater.emplace_back("case");
+    expectedGreater.emplace_back("Base");
+    expectedGreater.emplace_back("baSE");
+    expectedGreater.emplace_back("1234");
+
+    vec.clear();
+    vec.emplace_back("suite");
+    vec.emplace_back("SUITE");
+    vec.emplace_back("baSE");
+    vec.emplace_back("Base");
+    vec.emplace_back("case");
+    vec.emplace_back("CaSe");
+    vec.emplace_back("1234");
+
+    std::sort(vec.begin(), vec.end(), Str::caseInsLess);
+    BOOST_REQUIRE_MESSAGE(vec == expected, "expected " << toString(expected) << " but found " << toString(vec));
+
+    std::sort(vec.begin(), vec.end(), Str::caseInsGreater);
+    BOOST_REQUIRE_MESSAGE(vec == expectedGreater,
+                          "expected " << toString(expectedGreater) << " but found " << toString(vec));
+}
+
+//// ==============================================================
+//// Timing to find the fastest looping
+//// ==============================================================
+class Fred {
+public:
+    explicit Fred(int i = 0) : i_(i) { /*std::cout << "Fred constructor\n"*/
+        // Do nothing...
+    }
+    Fred(const Fred& rhs) : i_(rhs.i_) { /*std::cout << "Fred copy constructor\n";*/
+        // Do nothing...
+    }
+    Fred& operator=(const Fred& rhs) { /*std::cout << "assignment operator\n";*/
+        i_ = rhs.i_;
+        return *this;
+    }
+    ~Fred() { /*std::cout << "Fred destructor\n";*/
+        // Do nothing...
+    }
+
+    void inc() { i_++; }
+
+private:
+    int i_;
+};
+
+BOOST_AUTO_TEST_CASE(test_loop, *boost::unit_test::disabled()) {
+    const size_t size = 200000000;
+    std::vector<Fred> vec;
+    vec.reserve(size);
+    for (size_t i = 0; i < size; i++) {
+        vec.push_back(Fred(i));
+    }
+
+    {
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (auto& fred : vec) {
+            fred.inc();
+        }
+        cout << "Time: for(auto &fred : vec) { fred.inc(); }                                                "
+             << timer.format(3, Str::cpu_timer_format()) << "\n";
+    }
+
+    {
+        boost::timer::cpu_timer timer;
+        std::for_each(vec.begin(), vec.end(), [](Fred& fred) { fred.inc(); });
+        cout << "Time: std::for_each(vec.begin(),vec.end(),[](Fred& fred) { fred.inc();} );                 "
+             << timer.format(3, Str::cpu_timer_format()) << "\n";
+    }
+
+    {
+        boost::timer::cpu_timer timer;
+        std::vector<Fred>::iterator theEnd = vec.end();
+        for (std::vector<Fred>::iterator i = vec.begin(); i < theEnd; i++) {
+            (*i).inc();
+        }
+        cout << "Time: for (std::vector<Fred>::iterator  i = vec.begin(); i < theEnd ; i++) { (*i).inc(); } "
+             << timer.format(3, Str::cpu_timer_format()) << "\n";
+    }
+
+    {
+        boost::timer::cpu_timer timer;
+        size_t theSize = vec.size();
+        for (size_t i = 0; i < theSize; i++) {
+            vec[i].inc();
+        }
+        cout << "Time: for (size_t i = 0; i < theSize ; i++) { vec[i].inc(); }                              "
+             << timer.format(3, Str::cpu_timer_format()) << "\n";
+    }
+}
+
+/// ==============================================================
+/// Timing to find the fastest conversion from string to int
+/// ==============================================================
+static void methodX(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
+    // 0.81
+    // for bad conversion istringstream seems to return 0, hence add guard
+    if (str.find_first_of(Str::NUMERIC(), 0) == 0) {
+        int number = 0;
+        std::istringstream(str) >> number;
+        numberRes.push_back(number);
+    }
+    else {
+        stringRes.push_back(str);
+    }
+}
+
+static void method1(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
+    // 12.2
+    try {
+        int number = ecf::convert_to<int>(str);
+        numberRes.push_back(number);
+    }
+    catch (const ecf::bad_conversion&) {
+        stringRes.push_back(str);
+    }
+}
+
+static void method2(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
+    // 0.6
+    if (str.find_first_of(Str::NUMERIC(), 0) == 0) {
+        try {
+            int number = ecf::convert_to<int>(str);
+            numberRes.push_back(number);
+        }
+        catch (const ecf::bad_conversion&) {
+            stringRes.push_back(str);
+        }
+    }
+    else {
+        stringRes.push_back(str);
+    }
+}
+
+static void method3(const std::string& str, std::vector<std::string>& stringRes, std::vector<int>& numberRes) {
+    // 0.14
+    // atoi return 0 for errors,
+    int number = atoi(str.c_str()); // does not handle errors
+    if (number == 0 && str.size() != 1) {
+        stringRes.push_back(str);
+    }
+    else {
+        numberRes.push_back(number);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_lexical_cast_perf, *boost::unit_test::disabled()) {
+    cout << "ACore:: ...test_string_to_int_conversion\n";
+
+    size_t the_size = 1000000;
+    std::vector<std::string> stringTokens;
+    std::vector<std::string> numberTokens;
+    std::vector<int> expectedNumberRes;
+    for (size_t i = 0; i < the_size; i++) {
+        stringTokens.push_back("astring");
+    }
+    for (size_t i = 0; i < the_size; i++) {
+        numberTokens.push_back(ecf::convert_to<std::string>(i));
+        expectedNumberRes.push_back(i);
+    }
+
+    std::vector<std::string> stringRes;
+    stringTokens.reserve(stringTokens.size());
+    std::vector<int> numberRes;
+    numberRes.reserve(expectedNumberRes.size());
+
+    {
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (size_t i = 0; i < stringTokens.size(); i++) {
+            method1(stringTokens[i], stringRes, numberRes);
+        }
+        for (size_t i = 0; i < numberTokens.size(); i++) {
+            method1(numberTokens[i], stringRes, numberRes);
+        }
+        cout << "Time for method1  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes, " method 1 wrong");
+        BOOST_CHECK_MESSAGE(stringTokens == stringRes, "method 1 wrong");
+        numberRes.clear();
+        stringRes.clear();
+    }
+
+    {
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (size_t i = 0; i < stringTokens.size(); i++) {
+            methodX(stringTokens[i], stringRes, numberRes);
+        }
+        for (size_t i = 0; i < numberTokens.size(); i++) {
+            methodX(numberTokens[i], stringRes, numberRes);
+        }
+        cout << "Time for methodX  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes, " method X wrong");
+        BOOST_CHECK_MESSAGE(stringTokens == stringRes, "method X wrong");
+        numberRes.clear();
+        stringRes.clear();
+    }
+
+    {
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (size_t i = 0; i < stringTokens.size(); i++) {
+            method2(stringTokens[i], stringRes, numberRes);
+        }
+        for (size_t i = 0; i < numberTokens.size(); i++) {
+            method2(numberTokens[i], stringRes, numberRes);
+        }
+        cout << "Time for method2  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes, "method 2 wrong");
+        BOOST_CHECK_MESSAGE(stringTokens == stringRes, "method 2 wrong");
+        numberRes.clear();
+        stringRes.clear();
+    }
+
+    {
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (size_t i = 0; i < stringTokens.size(); i++) {
+            method3(stringTokens[i], stringRes, numberRes);
+        }
+        for (size_t i = 0; i < numberTokens.size(); i++) {
+            method3(numberTokens[i], stringRes, numberRes);
+        }
+        cout << "Time for method3  elapsed time = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(numberRes == expectedNumberRes,
+                            " method3 wrong numberRes.size()=" << numberRes.size()
+                                                               << " expected size = " << expectedNumberRes.size());
+        BOOST_CHECK_MESSAGE(stringTokens == stringRes,
+                            " method3 wrong stringRes.size()=" << stringRes.size()
+                                                               << " expected size = " << stringTokens.size());
+        numberRes.clear();
+        stringRes.clear();
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_int_to_str_perf, *boost::unit_test::disabled()) {
+    cout << "ACore:: ...test_int_to_str_perf\n";
+
+    // Lexical_cast is approx twice as fast as using streams
+    // time for ostream = 0.97
+    // time for lexical_cast = 0.45
+
+    const int the_size = 1000000;
+    {
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < the_size; i++) {
+            std::ostringstream st;
+            st << i;
+            std::string s = st.str();
+        }
+        cout << "Time for int to string using ostringstream  elapsed time = "
+             << timer.format(3, Str::cpu_timer_format()) << "\n";
+    }
+
+    {
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < the_size; i++) {
+            std::string s = ecf::convert_to<std::string>(i);
+        }
+        cout << "Time for int to string using ecf::convert_to elapsed time = "
+             << timer.format(3, Str::cpu_timer_format()) << "\n";
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_str_valid_name) {
+    cout << "ACore:: ...test_str_valid_name\n";
+
+    std::vector<std::string> valid;
+    valid.emplace_back("a");
+    valid.emplace_back("a122345");
+    valid.emplace_back("_a122345");
+    valid.emplace_back("_");
+    valid.emplace_back("0");
+    valid.emplace_back("1");
+    valid.emplace_back("2");
+    valid.emplace_back("3");
+    valid.emplace_back("4");
+    valid.emplace_back("5");
+    valid.emplace_back("6");
+    valid.emplace_back("7");
+    valid.emplace_back("8");
+    valid.emplace_back("9");
+    valid.emplace_back("11");
+    valid.emplace_back("111");
+    for (const auto& i : valid) {
+        std::string msg;
+        BOOST_CHECK_MESSAGE(Str::valid_name(i, msg), "Expected " << i << " to be valid");
+        BOOST_CHECK_MESSAGE(Str::valid_name(i), "Expected " << i << " to be valid");
+    }
+
+    BOOST_CHECK_MESSAGE(!Str::valid_name(""), "Expected empty string to be in-valid");
+    BOOST_CHECK_MESSAGE(!Str::valid_name("."), "Expected '.' string to be in-valid");
+    std::vector<std::string> invalid;
+    invalid.emplace_back("?");
+    invalid.emplace_back("!");
+    invalid.emplace_back("\"");
+    invalid.emplace_back("$");
+    invalid.emplace_back("%");
+    invalid.emplace_back("^");
+    invalid.emplace_back("*");
+    invalid.emplace_back("(");
+    invalid.emplace_back(")");
+    invalid.emplace_back("-");
+    invalid.emplace_back("+");
+    invalid.emplace_back(":");
+    invalid.emplace_back(";");
+    invalid.emplace_back("@");
+    invalid.emplace_back("~");
+    invalid.emplace_back("<");
+    invalid.emplace_back(">");
+    invalid.emplace_back("!");
+    for (const auto& i : invalid) {
+        std::string msg;
+        BOOST_CHECK_MESSAGE(!Str::valid_name(i, msg), "Expected " << i << " to be in-valid");
+        BOOST_CHECK_MESSAGE(!Str::valid_name(i), "Expected " << i << " to be in-valid");
+
+        std::string s = "a" + i;
+        BOOST_CHECK_MESSAGE(!Str::valid_name(s, msg), "Expected " << s << " to be in-valid");
+        BOOST_CHECK_MESSAGE(!Str::valid_name(s), "Expected " << s << " to be in-valid");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestStringSplitPerf.cpp 5.13.0-1/libs/core/test/TestStringSplitPerf.cpp
--- 5.12.4-1/libs/core/test/TestStringSplitPerf.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestStringSplitPerf.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,481 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+// **************************************************************************************************************
+// IMPORTANT: Str:split uses StringSplitter:
+//            to run these tests, please switch off Str.cpp::USE_STRINGSPLITTER
+// **************************************************************************************************************
+// #define STRING_SPLIT_IMPLEMENTATIONS_PERF_CHECK_ 1;
+
+#ifdef STRING_SPLIT_IMPLEMENTATIONS_PERF_CHECK_
+    #include <fstream>
+    #include <iostream>
+
+    #include <boost/timer/timer.hpp>
+
+    #include "ecflow/core/File.hpp"
+    #include "ecflow/core/Str.hpp"
+    #include "ecflow/core/StringSplitter.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+#endif
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_StringSplitPerf)
+
+#ifdef STRING_SPLIT_IMPLEMENTATIONS_PERF_CHECK_
+
+std::vector<std::string> split_using_getline(const std::string& s, char delimiter) {
+    std::vector<std::string> tokens;
+    std::string token;
+    std::istringstream tokenStream(s);
+    while (std::getline(tokenStream, token, delimiter)) {
+        tokens.push_back(token);
+    }
+    return tokens;
+}
+
+BOOST_AUTO_TEST_CASE(test_str_split_perf) {
+    cout << "ACore:: ...test_str_split_perf\n";
+    //   Time for istreamstream 1000000 times = 2.59404
+    //   Time for std::getline 1000000 times = 1.83148
+    //   Time for boost::split 1000000 times = 1.18149
+    //   Time for Str::split_orig 1000000 times = 1.3015
+    //   Time for make_split_iterator::split 1000000 times = 4.1821
+    //   Time for std::string_view 1000000 times =  0.975816
+    //   Time for std::string_view(2) 1000000 times = 0.780003
+
+    std::string line = "This is a long string that is going to be used to test the performance of splitting with "
+                       "different Implementations the fastest times wins ";
+    size_t times     = 1000000;
+    cout << " This test will split a line " << times << " times: '" << line << "'\n";
+
+    string reconstructed;
+    reconstructed.reserve(line.size());
+
+    { // istreamstream    https://www.fluentcpp.com/2017/04/21/how-to-split-a-string-in-c/
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (size_t i = 0; i < times; i++) {
+            std::istringstream iss(line);
+            std::vector<std::string> result((std::istream_iterator<std::string>(iss)),
+                                            std::istream_iterator<std::string>());
+            reconstructed.clear();
+            for (const std::string& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for istreamstream " << times
+             << "                 times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
+    }
+
+    { // split using std::get_line    https://www.fluentcpp.com/2017/04/21/how-to-split-a-string-in-c/
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (size_t i = 0; i < times; i++) {
+            std::vector<std::string> result = split_using_getline(line, ' ');
+            reconstructed.clear();
+            for (const std::string& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for std::getline " << times
+             << "                  times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
+    }
+
+    { // BOOST SPLIT
+        std::vector<std::string> result;
+        boost::timer::cpu_timer timer; // measures CPU, replace with cpu_timer with boost > 1.51, measures cpu & elapsed
+        for (size_t i = 0; i < times; i++) {
+            result.clear();
+            // boost::algorithm::split(result, line, boost::is_any_of(" \t"),boost::algorithm::token_compress_on);
+            boost::split(result, line, [](char c) { return c == ' '; });
+
+            reconstructed.clear();
+            for (const std::string& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for boost::split " << times
+             << "                  times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        // BOOST_CHECK_MESSAGE(line==reconstructed,"\n'" << line << "'\n'" << reconstructed << "'"); // add extra space
+    }
+
+    { // Str::split_orig
+        std::vector<std::string> result;
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            result.clear();
+            Str::split_orig(line, result);
+
+            reconstructed.clear();
+            for (const std::string& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for Str::split_orig " << times
+             << "               times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
+    }
+    { // Str::split_orig1
+        std::vector<std::string> result;
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            result.clear();
+            Str::split_orig1(line, result);
+
+            reconstructed.clear();
+            for (const std::string& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for Str::split_orig1 " << times
+             << "              times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
+    }
+    { // Str::split_using_string_view2
+        std::vector<std::string> result;
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            result.clear();
+            Str::split_using_string_view2(line, result);
+
+            reconstructed.clear();
+            for (const std::string& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for Str::split_using_string_view2 " << times
+             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
+    }
+    { // Str::split_using_string_view
+        std::vector<std::string> result;
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            result.clear();
+            Str::split_using_string_view(line, result);
+
+            reconstructed.clear();
+            for (const std::string& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for Str::split_using_string_view " << times
+             << "  times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, " error");
+    }
+
+    typedef boost::split_iterator<string::const_iterator> split_iter_t;
+    { // boost::make_split_iterator
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+
+            split_iter_t tokens = Str::make_split_iterator(line);
+
+            std::stringstream ss;
+            for (; !tokens.eof(); ++tokens) {
+                boost::iterator_range<string::const_iterator> range = *tokens;
+                ss << range << " ";
+            }
+            reconstructed = ss.str();
+        }
+        cout << " Time for make_split_iterator::split " << times
+             << "    times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        // BOOST_CHECK_MESSAGE(line==reconstructed,"\n'" << line << "'\n'" << reconstructed << "'");
+    }
+
+    { // std::string_view
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            StringSplitter string_splitter(line);
+
+            reconstructed.clear();
+            while (!string_splitter.finished()) {
+                std::string_view sv = string_splitter.next();
+                reconstructed += std::string(sv.begin(), sv.end());
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for std::string_view " << times
+             << "            times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
+    }
+
+    { // std::string_view
+        boost::timer::cpu_timer timer;
+        std::vector<std::string_view> result;
+        for (size_t i = 0; i < times; i++) {
+
+            result.clear();
+            StringSplitter::split2(line, result);
+
+            reconstructed.clear();
+            for (const auto& s : result) {
+                reconstructed += std::string(s.begin(), s.end());
+                reconstructed += " ";
+            }
+        }
+        cout << " Time for std::string_view(2) " << times
+             << "         times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(line == reconstructed, "\n'" << line << "'\n'" << reconstructed << "'");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_str_split_perf_with_file) {
+    cout << "ACore:: ...test_str_split_perf_with_file\n";
+    //   Time for istreamstream 2001774 times = 1.81123
+    //   Time for std::getline 2001774 times = 2.89138
+    //   Time for boost::split 2001774 times = 1.98556
+    //   Time for Str::split_orig 2001774 times = 0.947959
+    //   Time for boost::make_split_iterator 2001774 times = 3.921
+    //   Time for std::string_view 2001774 times = 0.765805
+    //   Time for std::string_view(2) 2001774 times = 0.752472
+
+    // Now test performance of splitting with a big DEFS file
+    char* ecf_test_defs_dir = getenv("ECF_TEST_DEFS_DIR");
+    if (!ecf_test_defs_dir) {
+        std::cout << "Ingoring test, since directory defined by environment variable(ECF_TEST_DEFS_DIR) is missing";
+        return;
+    }
+    std::string path = std::string(ecf_test_defs_dir) + "/vsms2.31415.def";
+    if (!fs::exists(path)) {
+        std::cout << "Ingoring test, since file defined by environment variable(ECF_TEST_DEFS_DIR) " << path
+                  << " is missing";
+        return;
+    }
+
+    std::vector<std::string> file_contents;
+    if (File::splitFileIntoLines(path, file_contents, true /* ignore empty lines*/)) {
+
+        cout << " This test will split each line in file " << path << "\n";
+
+        std::vector<std::string> result;
+        result.reserve(300);
+
+        auto reconstruct_line = [](const std::vector<std::string>& result) {
+            string reconstructed;
+            for (const auto& s : result) {
+                reconstructed += s;
+                reconstructed += " ";
+            }
+        };
+
+        { // istreamstream
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+                std::istringstream iss(file_contents[i]);
+                std::vector<std::string> result1((std::istream_iterator<std::string>(iss)),
+                                                 std::istream_iterator<std::string>());
+                reconstruct_line(result1);
+            }
+            cout << " Time for istreamstream " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+        { // std::getline
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+                reconstruct_line(split_using_getline(file_contents[i], ' '));
+            }
+            cout << " Time for std::getline " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+        {
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+                result.clear();
+                // boost::algorithm::split(result,file_contents[i], boost::is_any_of("
+                // \t"),boost::algorithm::token_compress_on);
+                boost::split(result, file_contents[i], [](char c) { return c == ' '; });
+
+                reconstruct_line(result);
+            }
+            cout << " Time for boost::split " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+        {
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+                result.clear();
+                Str::split_orig(file_contents[i], result);
+
+                reconstruct_line(result);
+            }
+            cout << " Time for Str::split_orig " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+        {
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+                result.clear();
+                Str::split_orig1(file_contents[i], result);
+
+                reconstruct_line(result);
+            }
+            cout << " Time for Str::split_orig1 " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+        {
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+                result.clear();
+                Str::split_using_string_view(file_contents[i], result);
+
+                reconstruct_line(result);
+            }
+            cout << " Time for Str::split_using_string_view " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+        {
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+                result.clear();
+                Str::split_using_string_view2(file_contents[i], result);
+
+                reconstruct_line(result);
+            }
+            cout << " Time for Str::split_using_string_view2 " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+        {
+            typedef boost::split_iterator<string::const_iterator> split_iter_t;
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+
+                std::stringstream ss;
+                split_iter_t tokens = Str::make_split_iterator(file_contents[i]);
+
+                for (; !tokens.eof(); ++tokens) {
+                    boost::iterator_range<string::const_iterator> range = *tokens;
+                    ss << range << " ";
+                }
+                string reconstructed = ss.str();
+            }
+            cout << " Time for boost::make_split_iterator " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+
+        {
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+
+                StringSplitter string_splitter(file_contents[i]);
+
+                string reconstructed;
+                while (!string_splitter.finished()) {
+                    std::string_view sv = string_splitter.next();
+                    reconstructed += std::string(sv.begin(), sv.end());
+                    reconstructed += " ";
+                }
+            }
+            cout << " Time for std::string_view " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+
+        {
+            std::vector<std::string_view> result1;
+            boost::timer::cpu_timer timer;
+            for (size_t i = 0; i < file_contents.size(); i++) {
+
+                StringSplitter::split2(file_contents[i], result1);
+
+                string reconstructed;
+                for (const auto& s : result1) {
+                    reconstructed += std::string(s.begin(), s.end());
+                    reconstructed += " ";
+                }
+                result1.clear();
+            }
+            cout << " Time std::string_view(2) " << file_contents.size()
+                 << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_str_get_token_perf) {
+    cout << "ACore:: ...test_str_get_token_perf\n";
+
+    std::vector<std::string> result;
+    std::string line = "This is a long string that is going to be used to test the performance of splitting with "
+                       "different Implementations the fastest times wins ";
+    size_t times     = 250000;
+    cout << " This test will split a line " << times << " times: '" << line << "'\n";
+
+    Str::split_using_string_view(line, result);
+    size_t result_size = result.size();
+    std::string token;
+
+    {
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            for (size_t r = 0; r < result_size; r++) {
+                token.clear();
+                (void)StringSplitter::get_token(line, r, token);
+            }
+        }
+        cout << " Time for StringSplitter::get_token " << times
+             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
+    }
+    {
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            for (size_t r = 0; r < result_size; r++) {
+                token.clear();
+                (void)Str::get_token(line, r, token);
+            }
+        }
+        cout << " Time for Str::get_token            " << times
+             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
+    }
+    {
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            for (size_t r = 0; r < result_size; r++) {
+                token.clear();
+                (void)Str::get_token2(line, r, token);
+            }
+        }
+        cout << " Time for Str::get_token2           " << times
+             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
+    }
+    {
+        boost::timer::cpu_timer timer;
+        for (size_t i = 0; i < times; i++) {
+            for (size_t r = 0; r < result_size; r++) {
+                token.clear();
+                (void)Str::get_token3(line, r, token);
+            }
+        }
+        cout << " Time for Str::get_token3           " << times
+             << " times = " << timer.format(3, Str::cpu_timer_format()) << "\n";
+        BOOST_CHECK_MESSAGE(true, "Keep compiler happy");
+    }
+}
+
+#endif
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestStringSplitter.cpp 5.13.0-1/libs/core/test/TestStringSplitter.cpp
--- 5.12.4-1/libs/core/test/TestStringSplitter.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestStringSplitter.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,319 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/StringSplitter.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_StringSplitter)
+
+static void
+check(const std::string& line, const StringSplitter& string_splitter, const std::vector<std::string>& expected) {
+    std::vector<std::string> result;
+    while (!string_splitter.finished()) {
+        std::string_view ref = string_splitter.next();
+        // std::cout << "ref:'" << ref << "'\n";
+        result.emplace_back(ref.begin(), ref.end());
+    }
+    BOOST_CHECK_MESSAGE(result.size() == expected.size(),
+                        "expected size " << expected.size() << " but found " << result.size() << " for '" << line
+                                         << "'");
+    BOOST_CHECK_MESSAGE(result == expected, "failed for '" << line << "'");
+    if (result != expected) {
+        cout << "Line    :'" << line << "'\n";
+        cout << "Actual  :";
+        for (const string& t : result) {
+            cout << "'" << t << "'";
+        }
+        cout << "\n";
+        cout << "Expected:";
+        for (const string& t : expected) {
+            cout << "'" << t << "'";
+        }
+        cout << "\n";
+    }
+}
+
+static void check(const std::string& line, const std::vector<std::string>& expected, const char* delims = " \t") {
+    std::vector<std::string> result;
+    std::vector<std::string_view> result2;
+    StringSplitter::split2(line, result2, delims);
+    std::transform(result2.begin(), result2.end(), std::back_inserter(result), [](const std::string_view& sv) {
+        return std::string(sv.begin(), sv.end());
+    });
+
+    BOOST_CHECK_MESSAGE(result.size() == expected.size(),
+                        "expected size " << expected.size() << " but found " << result.size() << " for '" << line
+                                         << "'");
+    BOOST_CHECK_MESSAGE(result == expected, "failed for '" << line << "'");
+    if (result != expected) {
+        cout << "Line    :'" << line << "'\n";
+        cout << "Actual  :";
+        for (const string& t : result) {
+            cout << "'" << t << "'";
+        }
+        cout << "\n";
+        cout << "Expected:";
+        for (const string& t : expected) {
+            cout << "'" << t << "'";
+        }
+        cout << "\n";
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_StringSplitter) {
+    cout << "ACore:: ...test_StringSplitter\n";
+
+    std::string line = "This is a string please split me";
+    std::vector<std::string> expected;
+
+    expected.emplace_back("This");
+    expected.emplace_back("is");
+    expected.emplace_back("a");
+    expected.emplace_back("string");
+    expected.emplace_back("please");
+    expected.emplace_back("split");
+    expected.emplace_back("me");
+    StringSplitter string_splitter(line);
+    check(line, string_splitter, expected);
+    check(line, expected);
+
+    // reset
+    string_splitter.reset();
+    check(line, string_splitter, expected);
+}
+
+BOOST_AUTO_TEST_CASE(test_str_split_StringSplitter) {
+    cout << "ACore:: ...test_str_split_StringSplitter\n";
+
+    // If end is delimeter, then preserved as empty token
+
+    std::string line = "This is a string";
+    std::vector<std::string> expected;
+
+    expected.emplace_back("This");
+    expected.emplace_back("is");
+    expected.emplace_back("a");
+    expected.emplace_back("string");
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter("This is a string"), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = "";
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter(""), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = "  ";
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter("  "), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = "a";
+    expected.emplace_back("a");
+    check(line, StringSplitter(line), expected);
+    check(line, expected);
+
+    // Some implementation fail this test
+    expected.clear();
+    line = "\n";
+    expected.emplace_back("\n");
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter("\n"), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = "a ";
+    expected.emplace_back("a");
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter("a "), expected);
+    check(line, expected);
+
+    expected.clear();
+    expected.emplace_back("a");
+    line = " a";
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter(" a"), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = "  a  "; // check sequential tabs
+    expected.emplace_back("a");
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter("  a  "), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = " a ";
+    expected.emplace_back("a");
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter(" a "), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = "        a     b     c       d        ";
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    expected.emplace_back("d");
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter("        a     b     c       d        "), expected);
+    check(line, expected);
+
+    expected.clear();
+    line = " - !   $ % ^  & * ( ) - + ? ";
+    expected.emplace_back("-");
+    expected.emplace_back("!");
+    expected.emplace_back("$");
+    expected.emplace_back("%");
+    expected.emplace_back("^");
+    expected.emplace_back("&");
+    expected.emplace_back("*");
+    expected.emplace_back("(");
+    expected.emplace_back(")");
+    expected.emplace_back("-");
+    expected.emplace_back("+");
+    expected.emplace_back("?");
+    check(line, StringSplitter(line), expected);
+    check(line, StringSplitter(" - !   $ % ^  & * ( ) - + ? "), expected);
+    check(line, expected);
+
+    // Check tabs
+    expected.clear();
+    line = "     verify complete:8                      # 4 sundays in october hence expect 8 task completions";
+    expected.emplace_back("verify");
+    expected.emplace_back("complete:8");
+    expected.emplace_back("#");
+    expected.emplace_back("4");
+    expected.emplace_back("sundays");
+    expected.emplace_back("in");
+    expected.emplace_back("october");
+    expected.emplace_back("hence");
+    expected.emplace_back("expect");
+    expected.emplace_back("8");
+    expected.emplace_back("task");
+    expected.emplace_back("completions");
+    check(line, StringSplitter(line), expected);
+    check(line,
+          StringSplitter(
+              "     verify complete:8                      # 4 sundays in october hence expect 8 task completions"),
+          expected);
+    check(line, expected);
+
+    // Check paths
+    expected.clear();
+    expected.emplace_back("a");
+    line = "/a";
+    check(line, StringSplitter(line, "/"), expected);
+    check(line, StringSplitter("/a", "/"), expected);
+    check(line, expected, "/");
+
+    expected.clear();
+    line = "";
+    check(line, StringSplitter(line, "/"), expected);
+    check(line, StringSplitter("", "/"), expected);
+    check(line, expected, "/");
+
+    expected.clear();
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    expected.emplace_back("c");
+    expected.emplace_back("e");
+    line = "/a/b/c/c//e";
+    check(line, StringSplitter(line, "/"), expected);
+    check(line, expected, "/");
+
+    expected.clear();
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    expected.emplace_back("c");
+    expected.emplace_back("e");
+    line = "///a/b/c/c//e";
+    check(line, StringSplitter(line, "/"), expected);
+    check(line, StringSplitter("///a/b/c/c//e", "/"), expected);
+    check(line, expected, "/");
+
+    expected.clear();
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    expected.emplace_back("c");
+    expected.emplace_back("e");
+    line = "//a/b/c/c//e/";
+    check(line, StringSplitter(line, "/"), expected);
+    check(line, StringSplitter("//a/b/c/c//e/", "/"), expected);
+    check(line, expected, "/");
+
+    expected.clear();
+    expected.emplace_back("a ");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    expected.emplace_back("c e");
+    line = "/a /b/c/c e";
+    check(line, StringSplitter(line, "/"), expected);
+    check(line, StringSplitter("/a /b/c/c e", "/"), expected);
+    check(line, expected, "/");
+}
+
+static void test_get_token(const std::string& line, const char* delims = " \t") {
+    std::vector<std::string> tokens;
+    Str::split_orig(line, tokens, delims);
+    for (size_t i = 0; i < tokens.size(); i++) {
+        std::string token;
+        BOOST_CHECK_MESSAGE(StringSplitter::get_token(line, i, token, delims) && token == tokens[i],
+                            "Expected to find " << tokens[i] << " but found " << token);
+    }
+    std::string token;
+    BOOST_CHECK_MESSAGE(!StringSplitter::get_token(line, tokens.size(), token), "Expected to fail");
+}
+
+BOOST_AUTO_TEST_CASE(test_StringSplitter_get_token) {
+    cout << "ACore:: ...test_StringSplitter_get_token \n";
+
+    std::vector<std::string> test_data = {"This is a string",
+                                          "a",
+                                          " a",
+                                          "a ",
+                                          " a ",
+                                          "        a     b     c       d        ",
+                                          " - !   $ % ^  & * ( ) - + ? ",
+                                          "\n"};
+
+    std::vector<std::string> test_data1 = {
+        "/a",
+        "///a/b/c/c//e",
+        "//a/b/c/c//e/",
+    };
+
+    for (const auto& s : test_data) {
+        test_get_token(s);
+    }
+    for (const auto& s : test_data1) {
+        test_get_token(s, "/");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestTimeSeries.cpp 5.13.0-1/libs/core/test/TestTimeSeries.cpp
--- 5.12.4-1/libs/core/test/TestTimeSeries.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestTimeSeries.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,782 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/date_time/posix_time/time_formatters.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+using namespace boost;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_TimeSeries)
+
+BOOST_AUTO_TEST_CASE(test_default_boost_time_duration) {
+    cout << "ACore:: ...test_default_boost_time_duration\n";
+
+    boost::posix_time::time_duration td;
+    BOOST_CHECK_MESSAGE(td.is_special() == false,
+                        "Default constructed boost::posix_time::time_duration, should not be special");
+    BOOST_CHECK_MESSAGE(td.hours() == 0, "Expected 0 for hours");
+    BOOST_CHECK_MESSAGE(td.minutes() == 0, "Expected 0 for minutes");
+    BOOST_CHECK_MESSAGE(td.seconds() == 0, "Expected 0 for seconds ");
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_min_max_time_slots) {
+    cout << "ACore:: ...test_time_series_min_max_time_slots\n";
+
+    TimeSlot the_min;
+    TimeSlot the_max;
+
+    TimeSeries a(9, 0, true);
+    a.min_max_time_slots(the_min, the_max);
+    BOOST_CHECK_MESSAGE(the_min == TimeSlot(9, 0), "Max min time slot failed");
+    BOOST_CHECK_MESSAGE(the_max == TimeSlot(9, 0), "Max min time slot failed");
+
+    TimeSeries b(TimeSlot(10, 12), false);
+    b.min_max_time_slots(the_min, the_max);
+    BOOST_CHECK_MESSAGE(the_min == TimeSlot(9, 0), "Max min time slot failed");
+    BOOST_CHECK_MESSAGE(the_max == TimeSlot(10, 12), "Max min time slot failed");
+
+    TimeSeries c(TimeSlot(0, 10), TimeSlot(10, 13), TimeSlot(0, 1));
+    c.min_max_time_slots(the_min, the_max);
+    BOOST_CHECK_MESSAGE(the_min == TimeSlot(0, 10), "Max min time slot failed");
+    BOOST_CHECK_MESSAGE(the_max == TimeSlot(10, 13), "Max min time slot failed");
+
+    TimeSeries x;
+    x.min_max_time_slots(the_min, the_max);
+    BOOST_CHECK_MESSAGE(the_min == TimeSlot(), "Max min time slot failed");
+    BOOST_CHECK_MESSAGE(the_max == TimeSlot(10, 13), "Max min time slot failed");
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_constrcution) {
+    cout << "ACore:: ...test_time_series_constrcution\n";
+
+    {
+        TimeSeries x;
+        TimeSeries y;
+        BOOST_CHECK_MESSAGE(x == y, "Equality operator expected to succeed");
+
+        TimeSeries a(10, 12, true);
+        TimeSeries b(10, 12, true);
+        BOOST_CHECK_MESSAGE(a == b, "Equality operator expected to succeed");
+
+        TimeSeries c(10, 12, false);
+        TimeSeries d(10, 12, false);
+        BOOST_CHECK_MESSAGE(c == d, "Equality operator expected to succeed");
+
+        TimeSeries e(TimeSlot(14, 59), false);
+        TimeSeries f(TimeSlot(14, 59), false);
+        BOOST_CHECK_MESSAGE(e == f, "Equality operator expected to succeed");
+
+        TimeSeries g(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1));
+        TimeSeries h(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1));
+        BOOST_CHECK_MESSAGE(g == h, "Equality operator expected to succeed");
+    }
+    {
+        TimeSeries a(10, 12, false);
+        TimeSeries b(10, 12, true);
+        BOOST_CHECK_MESSAGE(a != b, "Equality operator expected to fail");
+
+        TimeSeries c(10, 13, false);
+        TimeSeries d(10, 12, false);
+        BOOST_CHECK_MESSAGE(c != d, "Equality operator expected to fail");
+
+        TimeSeries e(TimeSlot(14, 59), false);
+        TimeSeries f(TimeSlot(14, 10), false);
+        BOOST_CHECK_MESSAGE(e != f, "Equality operator expected to fail");
+
+        TimeSeries g(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1), true);
+        TimeSeries h(TimeSlot(0, 10), TimeSlot(10, 4), TimeSlot(0, 1), false);
+        BOOST_CHECK_MESSAGE(g != h, "Equality operator expected to fail");
+    }
+
+    /// Basic test for time series of getters and setters
+    TimeSeries timeSeries(TimeSlot(0, 1), TimeSlot(0, 4), TimeSlot(0, 1));
+    BOOST_CHECK_MESSAGE(timeSeries.hasIncrement(), "expected increment");
+    std::string errMsg;
+    BOOST_CHECK_MESSAGE(timeSeries.checkInvariants(errMsg), errMsg);
+
+    TimeSeries another = timeSeries;
+    BOOST_CHECK_MESSAGE(another == timeSeries, "copy constructor failed for TimeSeries ");
+    BOOST_CHECK_MESSAGE(another.checkInvariants(errMsg), errMsg);
+    BOOST_CHECK_MESSAGE(timeSeries.checkInvariants(errMsg), errMsg);
+
+    TimeSeries timeSeries2(TimeSlot(0, 1), TimeSlot(0, 4), TimeSlot(0, 1));
+    BOOST_CHECK_MESSAGE(timeSeries2.checkInvariants(errMsg), errMsg);
+    another = timeSeries2;
+    BOOST_CHECK_MESSAGE(another == timeSeries2, "assignment operator failed for TimeSeries ");
+    BOOST_CHECK_MESSAGE(another.checkInvariants(errMsg), errMsg);
+
+    TimeSeries timeSeries3(TimeSlot(0, 1));
+    BOOST_CHECK_MESSAGE(timeSeries3.checkInvariants(errMsg), errMsg);
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series) {
+    cout << "ACore:: ...test_time_series\n";
+
+    /// Basic test for time series of getters and setters
+    TimeSeries timeSeries(TimeSlot(0, 1), TimeSlot(0, 4), TimeSlot(0, 1));
+    BOOST_CHECK_MESSAGE(timeSeries.hasIncrement(), "expected increment");
+
+    std::string expected = "00:01:00";
+    std::string actual   = to_simple_string(timeSeries.start().duration());
+    BOOST_CHECK_MESSAGE(expected == actual, " expected " << expected << " but found " << actual);
+
+    expected = "00:04:00";
+    actual   = to_simple_string(timeSeries.finish().duration());
+    BOOST_CHECK_MESSAGE(expected == actual, " expected " << expected << " but found " << actual);
+
+    expected = "00:01:00";
+    actual   = to_simple_string(timeSeries.incr().duration());
+    BOOST_CHECK_MESSAGE(expected == actual, " expected " << expected << " but found " << actual);
+
+    TimeSeries timeSeries2(TimeSlot(0, 1));
+    BOOST_CHECK_MESSAGE(!timeSeries2.hasIncrement(), "Not expecting time series");
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_increment_real) {
+    cout << "ACore:: ...test_time_series_increment_real\n";
+
+    // Test time series with  a calendar, we update calendar then
+    // test time series isFree(), and checkForRequeue
+    Calendar c;
+    c.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series. Need to sync hour with suite time
+    // at hour 1, suite time should also be 01:00, for test to work
+    //
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr    1:00
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), true /* relative */);
+    TimeSeries timeSeries2(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), true /* relative */);
+    TimeSeries timeSeries3(TimeSlot(15, 0), true /* relative */);
+
+    TimeSlot t1_min, t1_max, t2_min, t2_max, t3_min, t3_max;
+    timeSeries.min_max_time_slots(t1_min, t1_max);
+    timeSeries2.min_max_time_slots(t2_min, t2_max);
+    timeSeries3.min_max_time_slots(t3_min, t3_max);
+    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(20, 0), "Not as expected");
+    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(11, 0) && t2_max == TimeSlot(15, 0), "Not as expected");
+    BOOST_CHECK_MESSAGE(t3_min == TimeSlot(15, 0) && t3_max == TimeSlot(15, 0), "Not as expected");
+
+    // Follow normal process
+    timeSeries.reset(c);
+    timeSeries2.reset(c);
+    timeSeries3.reset(c);
+
+    bool cmd_context = true;
+    for (int hour = 1; hour < 24; hour++) {
+        // Update calendar every hour, then see we can match time series, *RELATIVE* to suite start
+        c.update(time_duration(hours(1)));
+        timeSeries.calendarChanged(c);
+        timeSeries2.calendarChanged(c);
+        timeSeries3.calendarChanged(c);
+
+        //		cerr << "hour = " << hour << " calendar_duration " << to_simple_string(timeSeries.duration(c))
+        //		    << " timeSeries=" << timeSeries.toString() << " timeSeries2=" << timeSeries2.toString() << "
+        // timeSeries3=" << timeSeries3.toString() << "\n";
+        if (hour < timeSeries.start().hour()) {
+            BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(c, t1_min, t1_max, cmd_context),
+                                " Time series " << timeSeries.toString() << " checkForRequeue should pass at "
+                                                << c.suite_time_str());
+            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(c, t1_min, t1_max),
+                                " Time series " << timeSeries.toString() << " checkForRequeue should fail at "
+                                                << c.suite_time_str());
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(c),
+                                "Time series " << timeSeries.toString() << " should NOT be free at hour " << hour);
+        }
+        else if (hour >= timeSeries.start().hour() && hour <= timeSeries.finish().hour()) {
+            BOOST_CHECK_MESSAGE(timeSeries.isFree(c),
+                                "Time series " << timeSeries.toString() << " should be free at hour " << hour);
+
+            /// At the last hour checkForRequeue should return false; This ensures that value will
+            /// not get incremented and so, should leave node in the complete state.
+            if (hour < timeSeries.finish().hour()) {
+                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(c, t1_min, t1_max),
+                                    "Time series " << timeSeries.toString()
+                                                   << " checkForRequeue should be free at hour " << hour);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(c, t1_min, t1_max),
+                                    "Time series " << timeSeries.toString()
+                                                   << "checkForRequeue should Not free at hour " << hour);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries.isFree(c),
+                                "Time series " << timeSeries.toString() << " should NOT be free at hour " << hour);
+            BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(c, t1_min, t1_max),
+                                " Time series " << timeSeries.toString() << " should fail at " << hour);
+        }
+
+        if (hour < timeSeries2.start().hour()) {
+            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(c, t1_min, t1_max),
+                                " Time series " << timeSeries2.toString() << "checkForRequeue should pass at " << hour);
+            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(c),
+                                "Time series " << timeSeries2.toString() << " should NOT be free at hour " << hour);
+        }
+        else if (hour >= timeSeries2.start().hour() && hour <= timeSeries2.finish().hour()) {
+            BOOST_CHECK_MESSAGE(timeSeries2.isFree(c),
+                                "Time series " << timeSeries2.toString() << " should be free at hour " << hour);
+
+            /// At the last hour checkForRequeue should return false;
+            if (hour < timeSeries2.finish().hour()) {
+                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(c, t2_min, t2_max),
+                                    "Time series " << timeSeries2.toString()
+                                                   << " checkForRequeue should be free at hour " << hour);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(c, t2_min, t2_max),
+                                    "Time series " << timeSeries2.toString()
+                                                   << "checkForRequeue should Not free at hour " << hour);
+            }
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!timeSeries2.isFree(c),
+                                "Time series " << timeSeries2.toString() << " not be free at hour " << hour);
+            BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(c, t2_min, t2_max),
+                                " Time series " << timeSeries2.toString() << " should fail at " << hour);
+        }
+
+        if (hour == timeSeries3.start().hour()) {
+            BOOST_CHECK_MESSAGE(timeSeries3.isFree(c),
+                                "Time series " << timeSeries3.toString() << " should be free at hour " << hour);
+        }
+        else if (hour < timeSeries3.start().hour()) {
+            BOOST_CHECK_MESSAGE(!timeSeries3.isFree(c),
+                                "Time series " << timeSeries3.toString() << " isFree should fail at hour " << hour);
+        }
+        else if (hour > timeSeries3.start().hour()) {
+            BOOST_CHECK_MESSAGE(!timeSeries3.isFree(c),
+                                "Time series " << timeSeries3.toString() << " is Free should fail at hour " << hour);
+        }
+        BOOST_CHECK_MESSAGE(!timeSeries3.checkForRequeue(c, t3_min, t3_max),
+                            " Time series " << timeSeries3.toString() << " checkForRequeue should fail at " << hour);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_requeueable_and_compute_next_time_slot) {
+    cout << "ACore:: ...test_time_series_requeueable_and_compute_next_time_slot\n";
+
+    // Test time series with  a calendar, we update calendar then
+    // test time series requeueable(), and compute_next_time_slot
+    // This are used with the WHY command
+    Calendar c;
+    c.init(ptime(date(2010, 2, 10), minutes(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series. Need to sync hour with suite time
+    // at hour 1, suite time should also be 01:00, for test to work
+    //
+    // Create the time series: start  10:00
+    //                         finish 20:00
+    //                         incr    1:00
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(20, 0), TimeSlot(1, 0), true /* relative */);
+    TimeSeries timeSeries2(TimeSlot(11, 0), TimeSlot(15, 0), TimeSlot(1, 0), true /* relative */);
+    TimeSeries timeSeries3(TimeSlot(15, 0), true /* relative */);
+
+    for (int hour = 1; hour < 24; hour++) {
+        // Update calendar every hour, then see we can match time series,
+        c.update(time_duration(hours(1)));
+        timeSeries.calendarChanged(c);
+        timeSeries2.calendarChanged(c);
+        timeSeries3.calendarChanged(c);
+
+        //    cerr << "hour = " << hour << " calendar_duration " << to_simple_string(timeSeries.duration(c))
+        //        << " timeSeries=" << timeSeries.toString() << " timeSeries2=" << timeSeries2.toString() << "
+        //        timeSeries3=" << timeSeries3.toString() << "\n";
+        if (hour < timeSeries.start().hour()) {
+            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
+            TimeSlot expected(10, 0);
+            BOOST_CHECK_MESSAGE(next_time_slot == expected,
+                                " Time series " << timeSeries.toString() << " at " << hour
+                                                << " expected next time slot at " << expected.toString()
+                                                << " but found " << next_time_slot.toString());
+            BOOST_CHECK_MESSAGE(timeSeries.requeueable(c),
+                                "Time series " << timeSeries.toString() << " should be requeueable at hour " << hour);
+        }
+        else if (hour == timeSeries.start().hour()) {
+            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
+            TimeSlot expected(11, 0);
+            BOOST_CHECK_MESSAGE(next_time_slot == expected,
+                                " Time series " << timeSeries.toString() << " at " << hour
+                                                << " expected next time slot at " << expected.toString()
+                                                << " but found " << next_time_slot.toString());
+            BOOST_CHECK_MESSAGE(timeSeries.requeueable(c),
+                                "Time series " << timeSeries.toString() << " should be requeueable at hour " << hour);
+        }
+        else if (hour > timeSeries.start().hour() && hour < timeSeries.finish().hour()) {
+            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
+            TimeSlot expected(hour + 1, 0);
+            BOOST_CHECK_MESSAGE(next_time_slot == expected,
+                                " Time series " << timeSeries.toString() << " at " << hour
+                                                << " expected next time slot at " << expected.toString()
+                                                << " but found " << next_time_slot.toString());
+            BOOST_CHECK_MESSAGE(timeSeries.requeueable(c),
+                                "Time series " << timeSeries.toString() << " should be requeueable at hour " << hour);
+        }
+        else if (hour == timeSeries.finish().hour()) {
+            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
+            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
+                                " Time series " << timeSeries.toString() << " at " << hour
+                                                << " expected next time slot  to be NULL");
+            BOOST_CHECK_MESSAGE(!timeSeries.requeueable(c),
+                                "Time series " << timeSeries.toString() << " should NOT be requeueable at hour "
+                                               << hour);
+        }
+        else if (hour > timeSeries.finish().hour()) {
+            TimeSlot next_time_slot = timeSeries.compute_next_time_slot(c);
+            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
+                                " Time series " << timeSeries.toString() << " at " << hour
+                                                << " expected next time slot to be NULL");
+            BOOST_CHECK_MESSAGE(!timeSeries.requeueable(c),
+                                "Time series " << timeSeries.toString() << " should NOT be requeueable at hour "
+                                               << hour);
+        }
+
+        if (hour < timeSeries2.start().hour()) {
+            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
+            TimeSlot expected(11, 0);
+            BOOST_CHECK_MESSAGE(next_time_slot == expected,
+                                " Time series " << timeSeries2.toString() << " at " << hour
+                                                << " expected next time slot at " << expected.toString()
+                                                << " but found " << next_time_slot.toString());
+            BOOST_CHECK_MESSAGE(timeSeries2.requeueable(c),
+                                "Time series " << timeSeries2.toString() << " should be requeueable at hour " << hour);
+        }
+        else if (hour == timeSeries2.start().hour()) {
+            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
+            TimeSlot expected(12, 0);
+            BOOST_CHECK_MESSAGE(next_time_slot == expected,
+                                " Time series " << timeSeries2.toString() << " at " << hour
+                                                << " expected next time slot at " << expected.toString()
+                                                << " but found " << next_time_slot.toString());
+            BOOST_CHECK_MESSAGE(timeSeries2.requeueable(c),
+                                "Time series " << timeSeries2.toString() << " should NOT be requeueable at hour "
+                                               << hour);
+        }
+        else if (hour > timeSeries2.start().hour() && hour < timeSeries2.finish().hour()) {
+            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
+            TimeSlot expected(hour + 1, 0);
+            BOOST_CHECK_MESSAGE(next_time_slot == expected,
+                                " Time series " << timeSeries2.toString() << " at " << hour
+                                                << " expected next time slot at " << expected.toString()
+                                                << " but found " << next_time_slot.toString());
+            BOOST_CHECK_MESSAGE(timeSeries2.requeueable(c),
+                                "Time series " << timeSeries2.toString() << " should be requeueable at hour " << hour);
+        }
+        else if (hour == timeSeries2.finish().hour()) {
+            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
+            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
+                                " Time series " << timeSeries2.toString() << " at " << hour
+                                                << " expected next time slot  to be NULL");
+            BOOST_CHECK_MESSAGE(!timeSeries2.requeueable(c),
+                                "Time series " << timeSeries2.toString() << " should NOT be requeueable at hour "
+                                               << hour);
+        }
+        else if (hour > timeSeries2.finish().hour()) {
+            TimeSlot next_time_slot = timeSeries2.compute_next_time_slot(c);
+            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
+                                " Time series " << timeSeries2.toString() << " at " << hour
+                                                << " expected next time slot to be NULL");
+            BOOST_CHECK_MESSAGE(!timeSeries2.requeueable(c),
+                                "Time series " << timeSeries2.toString() << " should NOT be requeueable at hour "
+                                               << hour);
+        }
+
+        if (hour < timeSeries3.start().hour()) {
+            TimeSlot next_time_slot = timeSeries3.compute_next_time_slot(c);
+            TimeSlot expected(15, 0);
+            BOOST_CHECK_MESSAGE(next_time_slot == expected,
+                                " Time series " << timeSeries3.toString() << " at " << hour
+                                                << " expected next time slot at " << expected.toString()
+                                                << " but found " << next_time_slot.toString());
+            BOOST_CHECK_MESSAGE(timeSeries3.requeueable(c),
+                                "Time series " << timeSeries3.toString() << " should be requeueable at hour " << hour);
+        }
+        else if (hour == timeSeries3.start().hour()) {
+            TimeSlot next_time_slot = timeSeries3.compute_next_time_slot(c);
+            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
+                                " Time series " << timeSeries3.toString() << " at " << hour
+                                                << " expected next time slot to be NULL");
+            BOOST_CHECK_MESSAGE(!timeSeries3.requeueable(c),
+                                "Time series " << timeSeries3.toString() << " should NOT be requeueable at hour "
+                                               << hour);
+        }
+        else if (hour > timeSeries3.start().hour()) {
+            TimeSlot next_time_slot = timeSeries3.compute_next_time_slot(c);
+            BOOST_CHECK_MESSAGE(next_time_slot.isNULL(),
+                                " Time series " << timeSeries3.toString() << " at " << hour
+                                                << " expected next time slot to be NULL");
+            BOOST_CHECK_MESSAGE(!timeSeries3.requeueable(c),
+                                "Time series " << timeSeries3.toString() << " should NOT be requeueable at hour "
+                                               << hour);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_finish_not_divisble_by_increment) {
+    cout << "ACore:: ...test_time_series_finish_not_divisble_by_increment\n";
+
+    // HANDLE CASE WHERE FINISH MINUTES IS NOT DIVISIBLE BY THE INCREMENT
+
+    // Test time series with  a calendar, we update calendar then
+    // test time series isFree(), and checkForRequeue
+    Calendar calendar;
+    calendar.init(ptime(date(2008, 10, 8), hours(0)), Calendar::REAL);
+
+    // Create a test when we can match a time series.
+    // NOTE: Finish minute is not a multiple of INCREMENT hence last valid time slot is 23:50
+    //
+    // Create the time series: start  00:00
+    //                         finish 23:59
+    //                         incr   00:10
+    TimeSeries timeSeries(TimeSlot(0, 0), TimeSlot(23, 59), TimeSlot(0, 10), false /* relative */);
+    TimeSeries timeSeries2(TimeSlot(0, 30), TimeSlot(23, 59), TimeSlot(4, 0), false /* relative */);
+
+    TimeSlot t1_min, t1_max, t2_min, t2_max;
+    timeSeries.min_max_time_slots(t1_min, t1_max);
+    timeSeries2.min_max_time_slots(t2_min, t2_max);
+    BOOST_CHECK_MESSAGE(t1_min == TimeSlot(0, 0) && t1_max == TimeSlot(23, 59), "Not as expected");
+    BOOST_CHECK_MESSAGE(t2_min == TimeSlot(0, 30) && t2_max == TimeSlot(23, 59), "Not as expected");
+
+    time_duration last  = hours(23) + minutes(50); // last valid time is 23:50
+    time_duration last2 = hours(20) + minutes(30); // last valid time is 20:30
+
+    // follow normal process
+    timeSeries.reset(calendar);
+    timeSeries2.reset(calendar);
+
+    for (int hour = 0; hour < 24; hour++) {
+        for (int minute = 0; minute < 60; minute++) {
+
+            calendar.update(minutes(1));
+            timeSeries.calendarChanged(calendar);
+            timeSeries2.calendarChanged(calendar);
+
+            // cout << to_simple_string(calendar.suiteTime()) << "\n";
+
+            if (calendar.dayChanged()) {
+                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    " expected " << timeSeries.toString() << " checkForRequeue to pass at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+            else if (calendar.suiteTime().time_of_day() < timeSeries.start().duration()) {
+                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    " expected " << timeSeries.toString() << " checkForRequeue to pass at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+            else if (calendar.suiteTime().time_of_day() >= timeSeries.start().duration() &&
+                     calendar.suiteTime().time_of_day() < last) {
+                BOOST_CHECK_MESSAGE(timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    " expected " << timeSeries.toString() << " checkForRequeue to pass at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                                    " expected " << timeSeries.toString() << " checkForRequeue to fail at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+
+            if (calendar.dayChanged()) {
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+            else if (calendar.suiteTime().time_of_day() < timeSeries2.start().duration()) {
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+            else if (calendar.suiteTime().time_of_day() >= timeSeries2.start().duration() &&
+                     calendar.suiteTime().time_of_day() < last2) {
+                BOOST_CHECK_MESSAGE(timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    " expected " << timeSeries2.toString() << " checkForRequeue to pass at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+            else {
+                BOOST_CHECK_MESSAGE(!timeSeries2.checkForRequeue(calendar, t2_min, t2_max),
+                                    " expected " << timeSeries2.toString() << " checkForRequeue to fail at "
+                                                 << to_simple_string(calendar.suiteTime()));
+            }
+
+            //         if (calendar.dayChanged()) {
+            //            timeSeries.reset(calendar);
+            //            timeSeries2.reset(calendar);
+            //         }
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_miss_time_slot) {
+    cout << "ACore:: ...test_time_series_miss_time_slot\n";
+
+    Calendar calendar;
+    calendar.init(ptime(date(2008, 10, 8), hours(10)), Calendar::REAL);
+
+    // Create a test when we can match a time series.
+    // NOTE: Finish minute is not a multiple of INCREMENT hence last valid time slot is 23:50
+    //
+    // Create the time series: start  10:00
+    //                         finish 23:59
+    //                         incr   00:10
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(23, 59), TimeSlot(0, 10), false /* relative */);
+    timeSeries.miss_next_time_slot(); // will increment next_time_slot
+    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 10), "miss time slot not working ");
+
+    timeSeries.miss_next_time_slot(); // will increment next_time_slot
+    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 20), "miss time slot not working ");
+
+    // requeue time series,
+    timeSeries.requeue(calendar); // calendar time is at midnight 10:00
+    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 10), "Expected requeue to reset time series");
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_miss_time_slot_1) {
+    cout << "ACore:: ...test_time_series_miss_time_slot_1\n";
+
+    // Create calendar before time series
+    {
+        Calendar calendar;
+        calendar.init(ptime(date(2008, 10, 8), hours(9)), Calendar::REAL); // 09:00
+
+        TimeSeries timeSeries(10, 0, false /* relative */); // 10:00
+
+        TimeSlot t1_min, t1_max;
+        timeSeries.min_max_time_slots(t1_min, t1_max);
+        BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(10, 0), "Not as expected");
+
+        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time holding at 10:00 since calendar is 09:00");
+        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                            "Expected checkForRequeue to return false always");
+
+        timeSeries.miss_next_time_slot();
+        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time to hold");
+        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                            "Expected checkForRequeue to return false");
+
+        timeSeries.requeue(calendar);
+        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time holding at 10:00 since calendar is 09:00");
+        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                            "Expected checkForRequeue to return false after Requeue");
+    }
+    {
+        // Create a time after the time series
+        Calendar calendar;
+        calendar.init(ptime(date(2008, 10, 8), hours(11)), Calendar::REAL); // 11:00
+
+        TimeSeries timeSeries(10, 0, false /* relative */); // 10:00
+
+        TimeSlot t1_min, t1_max;
+        timeSeries.min_max_time_slots(t1_min, t1_max);
+        BOOST_CHECK_MESSAGE(t1_min == TimeSlot(10, 0) && t1_max == TimeSlot(10, 0), "Not as expected");
+
+        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                            "Expected time NOT to be free, since calendar time is after time slot");
+        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                            "Expected checkForRequeue to return false, since calendar time > slot time");
+
+        timeSeries.miss_next_time_slot();
+        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar), "Expected time to hold");
+        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                            "Expected checkForRequeue to return false");
+
+        timeSeries.requeue(calendar);
+        BOOST_CHECK_MESSAGE(!timeSeries.isFree(calendar),
+                            "Expected time to hold, since calendar time is after time slot");
+        BOOST_CHECK_MESSAGE(!timeSeries.checkForRequeue(calendar, t1_min, t1_max),
+                            "Expected checkForRequeue to return false,since calendar time is after time slot");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_reset) {
+    cout << "ACore:: ...test_time_series_reset\n";
+
+    // Create a test when we can match a time series.
+    // NOTE: Finish minute is not a multiple of INCREMENT hence last valid time slot is 23:50
+    //
+    // Create the time series: start  10:00
+    //                         finish 23:59
+    //                         incr   00:10
+    TimeSeries timeSeries(TimeSlot(10, 0), TimeSlot(23, 59), TimeSlot(0, 10), false /* relative */);
+    BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0), "defaults not correct");
+
+    { // set calendar before time series start & then reset
+
+        Calendar calendar;
+        calendar.init(ptime(date(2008, 10, 8), hours(9)), Calendar::REAL);
+        timeSeries.reset(calendar);
+        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0),
+                            "Reset should set value(next_valid_time_slot) to start." << timeSeries.dump());
+
+        timeSeries.miss_next_time_slot();
+
+        timeSeries.requeue(calendar);
+        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0),
+                            "requeue should set value(next_valid_time_slot) to start." << timeSeries.dump());
+    }
+    { // set calendar at time series start & then reset
+
+        Calendar calendar;
+        calendar.init(ptime(date(2008, 10, 8), hours(10)), Calendar::REAL);
+        timeSeries.reset(calendar);
+        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 0),
+                            "Reset should set value(next_valid_time_slot) to start." << timeSeries.dump());
+
+        timeSeries.miss_next_time_slot();
+
+        timeSeries.requeue(calendar);
+        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(10, 10),
+                            "requeue should set value(next_valid_time_slot) to start." << timeSeries.dump());
+    }
+    { // set calendar after time series start & before time series end, then reset
+
+        Calendar calendar;
+        calendar.init(ptime(date(2008, 10, 8), hours(11)), Calendar::REAL);
+        timeSeries.reset(calendar);
+        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(11, 0),
+                            "Reset should update free slot." << timeSeries.dump());
+
+        timeSeries.miss_next_time_slot();
+
+        timeSeries.requeue(calendar);
+        BOOST_CHECK_MESSAGE(timeSeries.value() == TimeSlot(11, 10),
+                            "requeue should update to first time slot." << timeSeries.dump());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_parsing) {
+    cout << "ACore:: ...test_time_series_parsing\n";
+
+    BOOST_CHECK_MESSAGE(TimeSeries::create("00:30") == ecf::TimeSeries(0, 30), "Error ");
+    BOOST_CHECK_MESSAGE(TimeSeries::create("+00:30") == ecf::TimeSeries(0, 30, true), "Error ");
+
+    ecf::TimeSlot start(0, 30);
+    ecf::TimeSlot finish(21, 03);
+    ecf::TimeSlot incr(1, 30);
+    BOOST_CHECK_MESSAGE(TimeSeries::create("00:30 21:03 01:30") == ecf::TimeSeries(start, finish, incr), "Error");
+    BOOST_CHECK_MESSAGE(TimeSeries::create("+00:30 21:03 01:30") == ecf::TimeSeries(start, finish, incr, true),
+                        "Error");
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series_state_parsing) {
+    cout << "ACore:: ...test_time_series_state_parsing\n";
+
+    /// extract string like
+    ///     time +00:00 20:00 00:10 # this is a comment which will be ignored. index = 1
+    ///     time +20:00        // index = 1
+    ///     today 20:00        // index = 1
+    ///     +00:00 20:00 00:10 // index = 0
+    ///     +20:00             // index = 0
+    /// will throw std:runtime_error for errors
+    /// will assert if index >= lineTokens.size()
+    {
+        size_t index         = 0;
+        std::string the_time = "+00:00 20:00 00:10";
+        std::vector<std::string> lineTokens;
+        Str::split(the_time, lineTokens);
+        BOOST_CHECK_MESSAGE(TimeSeries::create(index, lineTokens) ==
+                                ecf::TimeSeries(TimeSlot(0, 0), TimeSlot(20, 0), TimeSlot(0, 10), true),
+                            "Error");
+    }
+    {
+        size_t index         = 0;
+        std::string the_time = "+10:10";
+        std::vector<std::string> lineTokens;
+        Str::split(the_time, lineTokens);
+        BOOST_CHECK_MESSAGE(TimeSeries::create(index, lineTokens) == ecf::TimeSeries(TimeSlot(10, 10), true), "Error");
+    }
+    {
+        size_t index         = 0;
+        std::string the_time = "+10:10 # free isValid:false";
+        ecf::TimeSeries expected(TimeSlot(10, 10), true);
+        expected.set_isValid(false);
+
+        std::vector<std::string> lineTokens;
+        Str::split(the_time, lineTokens);
+        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
+        BOOST_CHECK_MESSAGE(parsed_ts == expected,
+                            "Expected \n'" << expected.toString() << expected.state_to_string(false) << "'"
+                                           << " But found \n'" << parsed_ts.toString()
+                                           << parsed_ts.state_to_string(false) << "'");
+    }
+    {
+        size_t index         = 0;
+        std::string the_time = "+10:10 # free isValid:false nextTimeSlot/10:10 relativeDuration/00:00:00";
+        ecf::TimeSeries expected(TimeSlot(10, 10), true);
+        expected.set_isValid(false);
+
+        std::vector<std::string> lineTokens;
+        Str::split(the_time, lineTokens);
+        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
+        BOOST_CHECK_MESSAGE(parsed_ts == expected,
+                            "Expected \n'" << expected.toString() << expected.state_to_string(false) << "'"
+                                           << " But found\n'" << parsed_ts.toString()
+                                           << parsed_ts.state_to_string(false) << "'");
+    }
+    {
+        // Update relative duration
+        size_t index         = 0;
+        std::string the_time = "+10:10 # free isValid:false nextTimeSlot/10:10 relativeDuration/01:00:00";
+        ecf::TimeSeries expected(TimeSlot(10, 10), true);
+        expected.set_isValid(false);
+
+        Calendar calendar;
+        calendar.init(ptime(date(2008, 10, 8), hours(0)), Calendar::REAL);
+        calendar.update(time_duration(hours(1)));
+        expected.calendarChanged(calendar);
+
+        std::vector<std::string> lineTokens;
+        Str::split(the_time, lineTokens);
+        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
+        BOOST_CHECK_MESSAGE(parsed_ts == expected,
+                            "Expected \n'" << expected.toString() << expected.state_to_string(false) << "'"
+                                           << " But found\n'" << parsed_ts.toString()
+                                           << parsed_ts.state_to_string(false) << "'");
+    }
+
+    {
+        // Update nextTimeSlot, create calendar at 09:00 and increment time series.
+        std::string the_time = "09:00 12:00 01:00 # isValid:false nextTimeSlot/10:00 relativeDuration/00:00:00";
+        ecf::TimeSeries expected(TimeSlot(9, 0), TimeSlot(12, 0), TimeSlot(1, 0), false);
+        expected.set_isValid(false);
+
+        Calendar calendar;
+        calendar.init(ptime(date(2008, 10, 8), hours(9)), Calendar::REAL);
+        expected.requeue(calendar); // this will reset isValid to true
+        expected.set_isValid(false);
+
+        std::vector<std::string> lineTokens;
+        Str::split(the_time, lineTokens);
+        size_t index              = 0;
+        ecf::TimeSeries parsed_ts = TimeSeries::create(index, lineTokens, true);
+
+        BOOST_CHECK_MESSAGE(parsed_ts == expected,
+                            "Expected \n'" << expected.dump() << expected.state_to_string(false) << "'"
+                                           << " But found\n'" << parsed_ts.dump() << parsed_ts.state_to_string(false)
+                                           << "'");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestTimeSlot.cpp 5.13.0-1/libs/core/test/TestTimeSlot.cpp
--- 5.12.4-1/libs/core/test/TestTimeSlot.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestTimeSlot.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,101 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/TimeSlot.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_TimeSlot)
+
+BOOST_AUTO_TEST_CASE(test_time_slot) {
+    cout << "ACore:: ...test_time_slot\n";
+
+    // test timeslot operator
+    {
+        TimeSlot x;
+        TimeSlot y;
+        BOOST_CHECK_MESSAGE(x.isNULL(), "Expected NULL");
+        BOOST_CHECK_MESSAGE(y.isNULL(), "Expected NULL");
+        BOOST_CHECK_MESSAGE(x == y, "Equality operator expected to succeed");
+        BOOST_CHECK_MESSAGE(!(x < y), "Less than operator expected to fail");
+        BOOST_CHECK_MESSAGE(!(x > y), "Greater than operator expected to fail");
+        BOOST_CHECK_MESSAGE(x <= y, "<= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(x >= y, ">= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(y <= x, "<= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(y >= x, ">= operator expected to succeed");
+
+        TimeSlot a(10, 12);
+        TimeSlot b(10, 12);
+        BOOST_CHECK_MESSAGE(!a.isNULL(), "Expected NOT NULL");
+        BOOST_CHECK_MESSAGE(!b.isNULL(), "Expected NOT NULL");
+        BOOST_CHECK_MESSAGE(a == b, "Equality operator expected to succeed");
+        BOOST_CHECK_MESSAGE(!(a < b), "Less than operator expected to fail");
+        BOOST_CHECK_MESSAGE(!(a > b), "Greater than operator expected to fail");
+        BOOST_CHECK_MESSAGE(a <= b, "<= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(a >= b, ">= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(b <= a, "<= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(b >= a, ">= operator expected to succeed");
+
+        TimeSlot c(0, 0);
+        TimeSlot d(0, 0);
+        BOOST_CHECK_MESSAGE(!c.isNULL(), "Expected NOT NULL");
+        BOOST_CHECK_MESSAGE(!d.isNULL(), "Expected NOT NULL");
+        BOOST_CHECK_MESSAGE(c == d, "Equality operator expected to succeed");
+        BOOST_CHECK_MESSAGE(!(c < d), "Less than operator expected to fail");
+        BOOST_CHECK_MESSAGE(!(c > d), "Greater than operator expected to fail");
+        BOOST_CHECK_MESSAGE(c <= d, "<= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(c >= d, ">= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(d <= c, "<= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(d >= c, ">= operator expected to succeed");
+
+        TimeSlot a1(10, 1);
+        TimeSlot b1(10, 12);
+        BOOST_CHECK_MESSAGE(!a1.isNULL(), "Expected NOT NULL");
+        BOOST_CHECK_MESSAGE(!b1.isNULL(), "Expected NOT NULL");
+        BOOST_CHECK_MESSAGE(a1 != b1, "Equality operator expected to fail");
+        BOOST_CHECK_MESSAGE(a1 < b1, "Less than operator expected to succeed");
+        BOOST_CHECK_MESSAGE(!(a1 > b1), "Greater than operator expected to fail");
+        BOOST_CHECK_MESSAGE(!(a1 >= b1), ">= than operator expected to fail");
+        BOOST_CHECK_MESSAGE(b1 > a1, "Greater than operator expected to succeed");
+        BOOST_CHECK_MESSAGE(b1 >= a1, ">= expected to succeed");
+
+        TimeSlot xx(10, 1);
+        TimeSlot yy(23, 12);
+        BOOST_CHECK_MESSAGE(xx != yy, "Equality operator expected to fail");
+        BOOST_CHECK_MESSAGE(xx < yy, "Less than operator expected to succeed");
+        BOOST_CHECK_MESSAGE(xx <= yy, "<= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(yy > xx, "Greater than operator expected to succeed");
+        BOOST_CHECK_MESSAGE(yy >= xx, ">= operator expected to succeed");
+        BOOST_CHECK_MESSAGE(!(xx > yy), "Greater than operator expected to fail");
+        BOOST_CHECK_MESSAGE(!(xx >= yy), ">= operator expected to fail");
+
+        TimeSlot x1(11, 0);
+        TimeSlot y1(10, 0);
+        BOOST_CHECK_MESSAGE(x1 != y1, "Equality operator expected to fail");
+        BOOST_CHECK_MESSAGE(!(x1 < y1), "Less than operator expected to fail");
+        BOOST_CHECK_MESSAGE(!(x1 <= y1), "<= operator expected to fail");
+        BOOST_CHECK_MESSAGE(x1 > y1, "Greater than operator expected to succced");
+        BOOST_CHECK_MESSAGE(x1 >= y1, ">= operator expected to succced");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestVersion.cpp 5.13.0-1/libs/core/test/TestVersion.cpp
--- 5.12.4-1/libs/core/test/TestVersion.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestVersion.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Version)
+
+BOOST_AUTO_TEST_CASE(test_version) {
+    std::string desc = Version::description();
+    BOOST_CHECK_MESSAGE(!desc.empty(), "Expected version");
+    cout << "ACore:: ...test_version:" << desc << endl;
+}
+
+BOOST_AUTO_TEST_CASE(test_version_against_cmake) {
+    cout << "ACore:: ...test_version_against_cmake" << endl;
+
+    // Open the file CMakeList.txt
+    std::string version_cmake_file = File::root_source_dir() + "/CMakeLists.txt";
+    std::vector<std::string> lines;
+    BOOST_REQUIRE_MESSAGE(File::splitFileIntoLines(version_cmake_file, lines, true /* impore empty lines */),
+                          "Failed to open file " << version_cmake_file << " (" << strerror(errno) << ")");
+    BOOST_REQUIRE_MESSAGE(!lines.empty(), "File " << version_cmake_file << " does not contain version info ??");
+
+    // Expecting lines like:
+    //   project( ecflow LANGUAGES CXX VERSION 5.3.1 )
+    // Compare against VERSION
+    std::string cmake_version;
+    for (auto& line : lines) {
+        std::vector<std::string> tokens;
+        Str::split(line, tokens);
+
+        if (line.find("project") != std::string::npos && line.find("ecflow") != std::string::npos &&
+            line.find("LANGUAGES") != std::string::npos && line.find("CXX") != std::string::npos &&
+            line.find("VERSION") != std::string::npos) {
+            for (size_t i = 0; i < tokens.size(); i++) {
+                if (tokens[i] == "VERSION") {
+                    if (i + 1 < tokens.size()) {
+                        cmake_version = tokens[i + 1];
+                        break;
+                    }
+                }
+            }
+        }
+    }
+
+    // The if they don't match, we have failed to regenrate and check in ecflow_version.h
+    BOOST_REQUIRE_MESSAGE(!cmake_version.empty(),
+                          "Expected to find 'project( ecflow LANGUAGES CXX VERSION N.N.N )' in file "
+                              << version_cmake_file);
+    BOOST_REQUIRE_MESSAGE(
+        Version::raw() == cmake_version,
+        "\n  Expected " << cmake_version << " but found " << Version::raw()
+                        << ", Please regenerate file $WK/ACore/src/ecflow_version.h by calling 'sh -x $WK/cmake.sh'");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestVersioning.cpp 5.13.0-1/libs/core/test/TestVersioning.cpp
--- 5.12.4-1/libs/core/test/TestVersioning.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestVersioning.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,66 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "TestVersioning.hpp"
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Serialization.hpp"
+
+using namespace std;
+using namespace boost;
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_Versioning)
+
+// This class will create a Class X. This is serialised.
+// This class is then reloaded, with different kinds of version changes, to base version 0;
+// Note: we simulate different release of class X, by using name spaces
+//       This is possible since the name space is not written.
+BOOST_AUTO_TEST_CASE(test_versioning) {
+    cout << "ACore:: ...test_versioning\n";
+    {
+        // write out version 0; This will be reloaded with different version of X
+        const version0::X t = version0::X(10);
+        ecf::save("version0", t);
+    }
+
+    {
+        // Version 1 adds a new data member: i.e min_
+        version_new_data_member::X t;
+        ecf::restore("version0", t);
+        BOOST_CHECK_MESSAGE(t == version_new_data_member::X(10, 0), "Should be the same");
+    }
+
+    {
+        // Version 1 change data member name: from hour_ -> hours_:
+        // This required no change at all. Since serialisation relies on order.
+        version_change_dm_name::X t;
+        ecf::restore("version0", t);
+        BOOST_CHECK_MESSAGE(t == version_change_dm_name::X(10), "Should be the same");
+    }
+
+    {
+        // Version 1 change data member type: from int -> string :
+        version_change_dm_type::X t;
+        ecf::restore("version0", t);
+        BOOST_CHECK_MESSAGE(t == version_change_dm_type::X("10"),
+                            "Reading integer as string expected '10', but found string " << t.str());
+    }
+
+    // remove the generate file
+    fs::remove("version0");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/TestVersioning.hpp 5.13.0-1/libs/core/test/TestVersioning.hpp
--- 5.12.4-1/libs/core/test/TestVersioning.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestVersioning.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,110 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_test_TestVersioning_HPP
+#define ecflow_core_test_TestVersioning_HPP
+
+#include "TestSerialisation.hpp"
+#include "ecflow/core/Converter.hpp"
+
+/// To simulate changing of data model over time, we will
+/// namespace's. The actual serialisation does not appears to
+/// persist the name space
+
+namespace version0 {
+class X {
+public:
+    static std::string type() { return "X"; }
+    explicit X(int h = 0) : hour_(h) {}
+    bool operator==(const X& rhs) const { return hour_ == rhs.hour_; }
+
+private:
+    int hour_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar & hour_;
+    }
+};
+} // namespace version0
+
+namespace version_new_data_member {
+class X {
+public:
+    static std::string type() { return "X"; }
+    explicit X(int h = 0, int m = 0) : hour_(h), min_(m) {}
+    bool operator==(const X& rhs) const { return hour_ == rhs.hour_ && min_ == rhs.min_; }
+
+private:
+    int hour_;
+    int min_;
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        // When *loading* the version pertains to loaded version in the data
+        // When *saving* the version always pertains to the latest version
+        ar & hour_;
+        if (version > 0)
+            ar & min_;
+    }
+};
+} // namespace version_new_data_member
+CEREAL_CLASS_VERSION(version_new_data_member::X, 1)
+
+namespace version_change_dm_name {
+class X {
+public:
+    static std::string type() { return "X"; }
+    explicit X(int h = 0) : hours_(h) {}
+    bool operator==(const X& rhs) const { return hours_ == rhs.hours_; }
+
+private:
+    int hours_;
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar & hours_;
+    }
+};
+} // namespace version_change_dm_name
+CEREAL_CLASS_VERSION(version_change_dm_name::X, 1)
+
+namespace version_change_dm_type {
+class X {
+public:
+    explicit X(const std::string& h = "") : hour_(h) {}
+    bool operator==(const X& rhs) const { return hour_ == rhs.hour_; }
+    std::string str() const { return hour_; }
+
+private:
+    std::string hour_;
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        // When *loading* the version pertains to loaded version in the data
+        // When *saving* the version always pertains to the latest version
+        if (version == 0) {
+            // Change data member type: int(version0)--->string(version1)
+            int the_old_hour = 0;
+            ar & the_old_hour;
+            hour_ = ecf::convert_to<std::string>(the_old_hour);
+        }
+        else {
+            ar & hour_;
+        }
+    }
+};
+
+} // namespace version_change_dm_type
+
+CEREAL_CLASS_VERSION(version_change_dm_type::X, 1)
+
+#endif /* ecflow_core_test_TestVersioning_HPP */
diff -pruN 5.12.4-1/libs/core/test/TestWhiteListFile.cpp 5.13.0-1/libs/core/test/TestWhiteListFile.cpp
--- 5.12.4-1/libs/core/test/TestWhiteListFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/TestWhiteListFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,691 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/WhiteListFile.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// #define DEBUG_ME 1
+
+BOOST_AUTO_TEST_SUITE(U_Core)
+
+BOOST_AUTO_TEST_SUITE(T_WhiteListFile)
+
+void test_white_list_files(const std::string& directory, bool pass) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (fs::is_directory(dir_itr->status())) {
+                test_white_list_files(relPath.string(), pass);
+                continue;
+            }
+
+#if DEBUG_ME
+            std::cout << "......Parsing file " << relPath.string() << "\n";
+#endif
+
+            WhiteListFile theFile;
+            std::string errorMsg;
+            bool parsedOk = theFile.load(relPath.string(), false /*debug*/, errorMsg);
+            if (pass) {
+                // Test expected to pass
+                BOOST_CHECK_MESSAGE(parsedOk,
+                                    "Failed to parse file " << relPath << "\n"
+                                                            << errorMsg << "\n"
+                                                            << theFile.dump_valid_users());
+            }
+            else {
+                // test expected to fail
+                BOOST_CHECK_MESSAGE(!parsedOk,
+                                    "Parse expected to fail for " << relPath << "\n"
+                                                                  << errorMsg << "\n"
+                                                                  << theFile.dump_valid_users());
+#if DEBUG_ME
+                cout << "\n" << errorMsg << "\n";
+#endif
+            }
+        }
+        catch (const std::exception& ex) {
+            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_for_good_white_list_files) {
+    cout << "ACore:: ...test_parsing_for_good_white_list_files\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodWhiteListFiles", "libs/core");
+
+    // All the files in this directory are expected to pass
+    test_white_list_files(path, true);
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_for_bad_white_list_files) {
+    cout << "ACore:: ...test_parsing_for_bad_white_list_files\n";
+
+    std::string path = File::test_data("libs/core/test/data/badWhiteListFiles", "libs/core");
+
+    // All the files in this directory are expected to fail
+    test_white_list_files(path, false);
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list_default) {
+    cout << "ACore:: ...test_white_list_default\n";
+
+    WhiteListFile theFile;
+
+    BOOST_REQUIRE_MESSAGE(0 == theFile.read_access_size(),
+                          "expected 0 users with read access but found " << theFile.read_access_size());
+    BOOST_REQUIRE_MESSAGE(0 == theFile.write_access_size(),
+                          "expected 0 users with write access but found " << theFile.write_access_size());
+
+    // test random user
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", "/x"), "Expected user xxtt to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", paths), "Expected user xxtt to have read access ");
+
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("yyyy"), "Expected user yyyy to have write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", "/y"), "Expected user zzzz to have write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", paths), "Expected user zzzz to have write access ");
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list_empty_file) {
+    cout << "ACore:: ...test_white_list_empty_file\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodWhiteListFiles/empty.lists", "libs/core");
+
+    WhiteListFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    BOOST_REQUIRE_MESSAGE(0 == theFile.read_access_size(),
+                          "expected 0 users with read access but found " << theFile.read_access_size());
+    BOOST_REQUIRE_MESSAGE(0 == theFile.write_access_size(),
+                          "expected 0 users with write access but found " << theFile.write_access_size());
+
+    // test random user
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", "/x"), "Expected user xxtt to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxtt", paths), "Expected user xxtt to have read access ");
+
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("yyyy"), "Expected user yyyy to have write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", "/y"), "Expected user zzzz to have write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzz", paths), "Expected user zzzz to have write access ");
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list) {
+    cout << "ACore:: ...test_white_list\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodWhiteListFiles/good1.lists", "libs/core");
+
+    WhiteListFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    // make sure we find all the users and the access right are correct
+    // 	uid1    # a comment
+    // 	uid2  # a comment
+    // 	cog   # a comment
+    //
+    // 	#
+    // 	# Read only uisers
+    // 	#
+    // 	-fred  # a comment
+    // 	-bill # a comment
+    // 	-jake # a comment
+
+    // 	avi   /suite/write
+    // 	-avi  /suite/read
+    std::vector<std::string> expected_users_with_read_access;
+    expected_users_with_read_access.emplace_back("fred");
+    expected_users_with_read_access.emplace_back("bill");
+    expected_users_with_read_access.emplace_back("jake");
+
+    expected_users_with_read_access.emplace_back("uid1"); // users with write access also have read access
+    expected_users_with_read_access.emplace_back("uid2"); // users with write access also have read access
+    expected_users_with_read_access.emplace_back("cog");  // users with write access also have read access
+
+    std::vector<std::string> expected_users_with_read_write_access;
+    expected_users_with_read_write_access.emplace_back("uid1");
+    expected_users_with_read_write_access.emplace_back("uid2");
+    expected_users_with_read_write_access.emplace_back("cog");
+
+    std::vector<std::string> expected_users_with_read_access_to_paths_only;
+    expected_users_with_read_access_to_paths_only.emplace_back("avi");
+
+    std::vector<std::string> expected_users_with_write_access_to_paths_only;
+    expected_users_with_write_access_to_paths_only.emplace_back("avi");
+
+    BOOST_REQUIRE_MESSAGE(
+        expected_users_with_read_access.size() + expected_users_with_read_access_to_paths_only.size() ==
+            theFile.read_access_size(),
+        " expected " << expected_users_with_read_access.size() + expected_users_with_write_access_to_paths_only.size()
+                     << " users with read access but found " << theFile.read_access_size());
+    BOOST_REQUIRE_MESSAGE(expected_users_with_read_write_access.size() +
+                                  expected_users_with_write_access_to_paths_only.size() ==
+                              theFile.write_access_size(),
+                          " expected " << expected_users_with_read_write_access.size() +
+                                              expected_users_with_write_access_to_paths_only.size()
+                                       << " users with write access but found " << theFile.write_access_size());
+
+    // Users who have read access, to all including paths
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    std::vector<std::string>::const_iterator i;
+    for (i = expected_users_with_read_access.begin(); i != expected_users_with_read_access.end(); ++i) {
+        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i), "Expected user " << *i << " to have read access ");
+        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i, "/x"), "Expected user " << *i << " to have read access ");
+        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i, paths), "Expected user " << *i << " to have read access ");
+    }
+    for (i = expected_users_with_read_write_access.begin(); i != expected_users_with_read_write_access.end(); ++i) {
+        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i), "Expected user " << *i << " to have write access ");
+        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i, "/x"), "Expected user " << *i << " to have write access ");
+        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i, paths), "Expected user " << *i << " to have write access ");
+    }
+
+    // Users who have restricted read/write access to certain paths only.
+    vector<string> read_paths;
+    read_paths.emplace_back("/suite/read");
+    read_paths.emplace_back("/suite/read/f1");
+    read_paths.emplace_back("/suite/read/f1/t1");
+    for (i = expected_users_with_read_access_to_paths_only.begin();
+         i != expected_users_with_read_access_to_paths_only.end();
+         ++i) {
+        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i), "Expected user " << *i << " to have read access ");
+        BOOST_CHECK_MESSAGE(theFile.verify_read_access(*i, read_paths),
+                            "Expected user " << *i << " to have read access to paths");
+        BOOST_CHECK_MESSAGE(!theFile.verify_read_access(*i, paths),
+                            "Expected user " << *i << " to NOT have read access to paths /a, /b , /c");
+        BOOST_CHECK_MESSAGE(!theFile.verify_read_access(*i, "/suite"),
+                            "Expected user " << *i << " to NOT have read access to paths /suite only /suite/read");
+        BOOST_CHECK_MESSAGE(!theFile.verify_read_access(*i, "/suite/read_me"),
+                            "Expected user "
+                                << *i << " with path '/suite/read_me' to NOT have read access to path /suite/read");
+    }
+
+    vector<string> write_paths;
+    write_paths.emplace_back("/suite/write");
+    write_paths.emplace_back("/suite/write/f1");
+    write_paths.emplace_back("/suite/write/f1/t1");
+    for (i = expected_users_with_write_access_to_paths_only.begin();
+         i != expected_users_with_write_access_to_paths_only.end();
+         ++i) {
+        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i),
+                            "Expected user " << *i << " to NOT have generic write access ");
+        BOOST_CHECK_MESSAGE(theFile.verify_write_access(*i, write_paths),
+                            "Expected user " << *i << " to have write access to paths");
+        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i, paths),
+                            "Expected user " << *i << " to have NOT has write access to paths /a, /b , /c");
+        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i, "/suite"),
+                            "Expected user " << *i << " to NOT have write access to paths /suite only /suite/write");
+        BOOST_CHECK_MESSAGE(!theFile.verify_write_access(*i, "/suite/write_me"),
+                            "Expected user "
+                                << *i << " with path '/suite/write_me' to NOT have write access to paths /suite/write");
+    }
+
+    // test random user
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("xxxx"), "Expected user xxxx to NOT have read access ");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("xxxx", "/x"), "Expected user xxxx to NOT have read access ");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("xxxx", paths), "Expected user xxxx to NOT have read access ");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("*"), "Expected user *  to NOT have read access ");
+
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("yyyy"), "Expected user yyyy  to NOT have write access ");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("zzzz", "/x"), "Expected user zzzz  to NOT have write access ");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("zzzz", paths), "Expected user zzzz  to NOT have write access ");
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list_all_users_have_read_access) {
+    cout << "ACore:: ...test_white_list_all_users_have_read_access\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodWhiteListFiles/all_read_access.lists", "libs/core");
+
+    WhiteListFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    // make sure we find all the users and the access right are correct
+    // # These user have read and write access to the server
+    // uid1  # a comment
+    // uid2  # a comment
+    // cog   # a comment
+    //
+    //
+    // # Read only users
+    //-*
+    //-fred  # a comment
+    //-bill # a comment
+    //-jake # a comment
+
+    std::vector<std::string> expected_users_with_read_write_access;
+    expected_users_with_read_write_access.emplace_back("uid1");
+    expected_users_with_read_write_access.emplace_back("uid2");
+    expected_users_with_read_write_access.emplace_back("cog");
+
+    // When all users have read access, the read access size should be empty
+    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
+
+    BOOST_REQUIRE_MESSAGE(expected_users_with_read_write_access.size() == theFile.write_access_size(),
+                          " expected " << expected_users_with_read_write_access.size()
+                                       << " users with write access but found " << theFile.write_access_size());
+
+    // Any user should have read access
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", "/x"), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("bill"), "Expected user bill  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("uid1"), "Expected user xxxx  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("uid2"), "Expected user xxxx  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("cog"), "Expected user xxxx  to have read access ");
+
+    std::vector<std::string>::const_iterator i;
+    for (i = expected_users_with_read_write_access.begin(); i != expected_users_with_read_write_access.end(); ++i) {
+        BOOST_REQUIRE_MESSAGE(theFile.verify_write_access(*i), "Expected user " << *i << " to have write access ");
+        BOOST_REQUIRE_MESSAGE(theFile.verify_write_access(*i, "/x"),
+                              "Expected user " << *i << " to have write access ");
+        BOOST_REQUIRE_MESSAGE(theFile.verify_write_access(*i, paths),
+                              "Expected user " << *i << " to have write access ");
+    }
+
+    // test random user for write access
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("yyyy"), "Expected user yyyy  to NOT have write access ");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("zzzz"), "Expected user zzzz  to NOT have write access ");
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list_all_users_have_write_access) {
+    cout << "ACore:: ...test_white_list_all_users_have_write_access\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodWhiteListFiles/all_write_access.lists", "libs/core");
+
+    WhiteListFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    // make sure we find all the users and the access right are correct
+    //   uid1  # a comment
+    //   uid2  # a comment
+    //   cog   # a comment
+    //   *
+    //
+    //   # Read only users
+    //   -*
+    //   -fred  # a comment
+    //   -bill # a comment
+    //   -jake # a comment
+
+    // When all users have read access, the read access size should be empty
+    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
+    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
+
+    // Any user should have read access
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", "/x"), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("bill"), "Expected user bill  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"), "Expected user xxxx  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", "/x"), "Expected user xxxx  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", paths), "Expected user xxxx  to have read access ");
+
+    // Any user should have read write access
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred"), "Expected user fred  to have read/write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzzzz"), "Expected user zzzzzz  to have read/write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzzzz", "/x"),
+                          "Expected user zzzzzz  to have read/write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("zzzzzz", paths),
+                          "Expected user zzzzzz  to have read/write access ");
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list_all_path_users_have_write_access) {
+    cout << "ACore:: ...test_white_list_all_path_users_have_write_access\n";
+
+    std::string path =
+        File::test_data("libs/core/test/data/goodWhiteListFiles/all_path_write_access.lists", "libs/core");
+
+    WhiteListFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    //   4.4.14
+    //   * /  # same as '*'
+
+    // When all users have read/write access, the read/write access size should be empty
+    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
+    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 0, " expected 0  but found " << theFile.write_access_size());
+
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    vector<string> paths1;
+    paths1.emplace_back("/a");
+    paths1.emplace_back("/b");
+    // Any user should have read/write access
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", "/x"), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths1), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred"), "Expected user fred  to have read/write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", "/x"), "Expected user fred  to have read/write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths), "Expected user fred  to have read/write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths1),
+                          "Expected user fred  to have read/write access ");
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list_all_path_users_have_read_access) {
+    cout << "ACore:: ...test_white_list_all_path_users_have_read_access\n";
+
+    std::string path =
+        File::test_data("libs/core/test/data/goodWhiteListFiles/all_path_read_access.lists", "libs/core");
+
+    WhiteListFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    //   4.4.14
+    //   -* /  # same as '*'
+
+    // When all users have read/write access, the size should be empty
+    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 0, " expected 0  but found " << theFile.read_access_size());
+    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 0, " expected 0  but found " << theFile.write_access_size());
+
+    // When no write access specified all user have write access
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    vector<string> paths1;
+    paths1.emplace_back("/a");
+    paths1.emplace_back("/b");
+    // Any user should have read/write access
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred"), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred"), "Expected user fred  to have read access ");
+
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("fred", paths1), "Expected user fred  to have read access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths), "Expected user fred  to have read/write access ");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("fred", paths1),
+                          "Expected user fred  to have read/write access ");
+}
+
+BOOST_AUTO_TEST_CASE(test_white_list_path_access_list) {
+    cout << "ACore:: ...test_white_list_path_access_list\n";
+
+    std::string path = File::test_data("libs/core/test/data/goodWhiteListFiles/path_access.lists", "libs/core");
+
+    WhiteListFile theFile;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(theFile.load(path, false, errorMsg), "Failed to parse file " << path << "\n" << errorMsg);
+
+    //   4.4.14
+    //
+    //   user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
+    //   user2 /a
+    //   user2 /b
+    //   user2 /c       # user2 has read write access to suite /a /b /c
+    //   user3 /a /b /c # user3 has read write access to suite /a /b /c
+    //
+    //   /a /b /c userx # userx has read write access to suite /a /b /c
+    //   /a,/b,/c usery # userx has read write access to suite /a /b /c
+    //
+    //   /a userz
+    //   /b userz
+    //   /c userz
+    //
+    //   -user4 /a,/b,/c  # user4 has read access to suite /a /b /c
+    //   -user5 /a
+    //   -user5 /b
+    //   -user5 /c    # user5 has read access to suite /a /b /c
+    //   -user6 /a /b /c   # user6 has read access to suite /a /b /c
+    //
+    //   /a /b /c -userxx # userxx has read  access to suite /a /b /c
+    //   /a,/b,/c -useryy # userxy has read  access to suite /a /b /c
+    //
+    //   /a -userzz
+    //   /b -userzz
+    //   /c -userzz
+    //
+    // ##################################
+    //*  /x /y   # all user have read/write access  suites /x /y
+    //-* /w /z   # all user have read access to suite /w /z
+
+    // When all users have read access, the read access size should be empty
+    BOOST_REQUIRE_MESSAGE(theFile.read_access_size() == 7,
+                          " expected 7  but found " << theFile.read_access_size() << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.write_access_size() == 7,
+                          " expected 7  but found " << theFile.write_access_size() << theFile.dump_valid_users());
+
+    // When no write access specified all user have write access
+    vector<string> paths;
+    paths.emplace_back("/a");
+    paths.emplace_back("/b");
+    paths.emplace_back("/c");
+    vector<string> partial_paths;
+    partial_paths.emplace_back("/a");
+    partial_paths.emplace_back("/b");
+
+    // read/write
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1", partial_paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user1", paths),
+                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user1", partial_paths),
+                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user2", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user2", paths),
+                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user3", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user3", paths),
+                          "Expected user to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userx", paths),
+                          "Expected userx to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("userx", paths),
+                          "Expected userx to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("usery", paths),
+                          "Expected userx to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("usery", paths),
+                          "Expected userx to have read/write access to /a,/b,/c" << theFile.dump_valid_users());
+
+    // read only
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user4", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user5", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user6", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userxx", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("useryy", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userzz", paths),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+
+    // single path, read/write
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user1", "/a"),
+                          "Expected user to have read/write access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user2", "/a"),
+                          "Expected user to have read access to /a,/b,/c" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user2", "/a"),
+                          "Expected user to have read/write access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user3", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("user3", "/a"),
+                          "Expected user to have read/write access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userx", "/a"),
+                          "Expected userx to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("userx", "/a"),
+                          "Expected userx to have read/write access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("usery", "/a"),
+                          "Expected userx to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("usery", "/a"),
+                          "Expected userx to have read/write access to /a" << theFile.dump_valid_users());
+
+    // single path, read
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user4", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user5", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user6", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userxx", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("useryy", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("userzz", "/a"),
+                          "Expected user to have read access to /a" << theFile.dump_valid_users());
+
+    // ============================================================================================
+    // test * user, * means all users
+    //*  /x /y   # all user have read/write access  suites /x /y
+    //-* /w /z   # all user have read access to suite /w /z
+    vector<string> single_pathx;
+    single_pathx.emplace_back("/x");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx"),
+                          "Expected *ALL* user to have read access" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", single_pathx),
+                          "Expected *ALL* user to have read access to /x" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("xxxx", single_pathx),
+                          "Expected *ALL* user to have read/write access to /x" << theFile.dump_valid_users());
+
+    vector<string> single_pathw;
+    single_pathw.emplace_back("/w");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", single_pathw),
+                          "Expected *ALL* user to have read access to /w" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("xxxx", single_pathw),
+                          "Expected failure for write access to /w" << theFile.dump_valid_users());
+
+    vector<string> multiple_pathsxy;
+    multiple_pathsxy.emplace_back("/x");
+    multiple_pathsxy.emplace_back("/y");
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("xxxx", multiple_pathsxy),
+                          "Expected *ALL* user to have read access to /x,/y" << theFile.dump_valid_users());
+
+    // ============================================================================================
+    // Failure
+    // ============================================================================================
+
+    // single path failure
+    //   user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
+    vector<string> single_path_failure;
+    single_path_failure.emplace_back("/fail");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", "/fail"),
+                          "Expected user to not have read access to /fail" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", single_path_failure),
+                          "Expected user to not have read access to /fail" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", "/fail"),
+                          "Expected user to not have read/write access to /fail" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", single_path_failure),
+                          "Expected user to not have read/write access to /fail" << theFile.dump_valid_users());
+
+    // multi path failure
+    //   user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
+    vector<string> multiple_paths_failure;
+    multiple_paths_failure.emplace_back("/a");
+    multiple_paths_failure.emplace_back("/b");
+    multiple_paths_failure.emplace_back("/fail");
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", multiple_paths_failure),
+                          "Expected user to not have read access to /fail\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", multiple_paths_failure),
+                          "Expected user to not have read/write access to /fail\n"
+                              << theFile.dump_valid_users());
+
+    // Presence of *, should allow read access to all including unknown users
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown"),
+                          "Expected unknown user to pass due to presence of *\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/x"),
+                          "Expected pass \n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/y"), "Expected pass\n" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/w"), "Expected pass\n" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("unknown", "/z"), "Expected pass\n" << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("unknown", "/x"),
+                          "Expected pass\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(theFile.verify_write_access("unknown", "/y"),
+                          "Expected pass\n"
+                              << theFile.dump_valid_users());
+
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("unknown", "/a"),
+                          "Expected failure for unknown user for path /a\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("unknown", "/a"),
+                          "Expected failure for unknown user for path /a\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("unknown", paths),
+                          "Expected failure for unknown user\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("unknown", paths),
+                          "Expected failure for unknown user\n"
+                              << theFile.dump_valid_users());
+
+    // user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
+    BOOST_REQUIRE_MESSAGE(theFile.verify_read_access("user1"),
+                          "Expected user1 to not have read access, EVEN if no paths specified, --news has no paths\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", vector<string>()),
+                          "Expected user to not have read access if no paths specified\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_read_access("user1", ""),
+                          "Expected user to not have read access if no paths specified\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1"),
+                          "Expected user to not have read/write if no paths specified\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", ""),
+                          "Expected user to not have read/write if no paths specified\n"
+                              << theFile.dump_valid_users());
+    BOOST_REQUIRE_MESSAGE(!theFile.verify_write_access("user1", vector<string>()),
+                          "Expected user to not have read/write if no paths specified\n"
+                              << theFile.dump_valid_users());
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf.passwd 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf.passwd
--- 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+4.
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf1.passwd 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf1.passwd
--- 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf1.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf1.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+3.1.0
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf2.passwd 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf2.passwd
--- 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf2.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf2.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+4.5.0
+fred host port passwd #  port should be an integer
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf3.passwd 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf3.passwd
--- 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf3.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf3.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+4.5.0
+fred host port #  port sould be an integer
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf4.passwd 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf4.passwd
--- 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf4.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf4.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+4.5.0
+#  missing passwd
+fred host port  
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf5.passwd 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf5.passwd
--- 5.12.4-1/libs/core/test/data/badPasswdFiles/ecf5.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badPasswdFiles/ecf5.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+4.5.0
+fred host 3141 xxxx
+fred host 3141 yyyy  # cant connect to same host:port with two different passwords with same user
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad2.lists 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad2.lists
--- 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad2.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad2.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+#
+4.   #   version number is wrong
+
+#
+# These user have read and write access to the server
+#
+uid1    # a comment
+uid2  # a comment
+  
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad3.lists 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad3.lists
--- 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad3.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad3.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+#
+2.10.14   #  valid version number should be greater than 4.4.5
+   
+#
+# These user have read and write access to the server
+#
+uid1    # a comment
+uid2  # a comment
+  
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad5.lists 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad5.lists
--- 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad5.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad5.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+# missing version number
+ 
+#
+# These user have read and write access to the server
+#
+uid1    # a comment
+uid2  # a comment
+cog   # a comment
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad_paths.lists 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad_paths.lists
--- 5.12.4-1/libs/core/test/data/badWhiteListFiles/bad_paths.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badWhiteListFiles/bad_paths.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+4.4.14 
+fred /x,/y,fred
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badWhiteListFiles/badsms.lists 5.13.0-1/libs/core/test/data/badWhiteListFiles/badsms.lists
--- 5.12.4-1/libs/core/test/data/badWhiteListFiles/badsms.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badWhiteListFiles/badsms.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+
+uid1
+uid2
+cog
+
+
+4.4.14   #  error version number should be at the start
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badWhiteListFiles/multipleWriteUsers.lists 5.13.0-1/libs/core/test/data/badWhiteListFiles/multipleWriteUsers.lists
--- 5.12.4-1/libs/core/test/data/badWhiteListFiles/multipleWriteUsers.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badWhiteListFiles/multipleWriteUsers.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+4.4.14 
+uid1 uid3 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/badWhiteListFiles/mutipleReadUser.lists 5.13.0-1/libs/core/test/data/badWhiteListFiles/mutipleReadUser.lists
--- 5.12.4-1/libs/core/test/data/badWhiteListFiles/mutipleReadUser.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/badWhiteListFiles/mutipleReadUser.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+4.4.14 
+-fred -joe
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/goodPasswdFiles/ecf.passwd 5.13.0-1/libs/core/test/data/goodPasswdFiles/ecf.passwd
--- 5.12.4-1/libs/core/test/data/goodPasswdFiles/ecf.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodPasswdFiles/ecf.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+4.5.0  # comment
+
+# comment
+fred host 3141  x12ggg # comment
+fred host3 3143 passwd
+fred host4 3145 x12ggg
+# comment
+
+jake host 3141  x12ggg
+tom host3 3143    x12ggg # sdsdsd
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/goodPasswdFiles/empty.passwd 5.13.0-1/libs/core/test/data/goodPasswdFiles/empty.passwd
--- 5.12.4-1/libs/core/test/data/goodPasswdFiles/empty.passwd	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodPasswdFiles/empty.passwd	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+4.5.0
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_path_read_access.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_path_read_access.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_path_read_access.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_path_read_access.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+4.4.14
+-* /  # same as '-*'
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_path_write_access.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_path_write_access.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_path_write_access.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_path_write_access.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+4.4.14 
+* /  # same as '*'
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_read_access.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_read_access.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_read_access.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_read_access.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+#
+4.4.14   #   comment
+
+# These user have read and write access to the server
+uid1  # a comment
+uid2  # a comment
+cog   # a comment
+
+
+# Read only users
+-*
+-fred  # a comment
+-bill # a comment
+-jake # a comment
+
+# a comment
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_write_access.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_write_access.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/all_write_access.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/all_write_access.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+
+4.4.14   # comment
+
+# These user have read and write access to the server
+uid1  
+uid2   
+cog    
+*     # all users have read and write access 
+
+# Read only users
+-*
+-fred # a comment
+-bill # a comment
+-jake # a comment
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/empty.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/empty.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/empty.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/empty.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+4.4.14   # comment
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/good1.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/good1.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/good1.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/good1.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+#
+4.4.14   #   comment
+
+# These user have read and write access to the server
+uid1  # a comment
+uid2  # a comment
+cog   # a comment
+
+
+# Read only users
+-fred  # a comment
+-bill # a comment
+-jake # a comment
+
+avi   /suite/write
+-avi  /suite/read
+# a comment
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/goodsms.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/goodsms.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/goodsms.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/goodsms.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+
+4.4.14   # comment
+
+uid1
+uid2
+cog
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/long_path_access.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/long_path_access.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/long_path_access.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/long_path_access.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+4.4.14 
+
+user1 /a/b/c/d,/b,/c  # user1 has read write access to suite /a /b /c
+/a/b/c/d /b /c userx # userx has read write access to suite /a /b /c
+ 
+/a/b/c/d/e userz
+/b userz
+/c userz
+/c userz # duplicates should be ignored
+
+-user4 /a,/b,/c/e/f/g/h  # user4 has read access to suite /a /b /c
+-user4 /a,/b,/c/e/f/g/h
+
+##################################
+* /x/y/a /y   # all user have read/write access  suites /x /y
+-* /w /z  # all user have read access to suite /w /z
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/goodWhiteListFiles/path_access.lists 5.13.0-1/libs/core/test/data/goodWhiteListFiles/path_access.lists
--- 5.12.4-1/libs/core/test/data/goodWhiteListFiles/path_access.lists	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/goodWhiteListFiles/path_access.lists	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,35 @@
+4.4.14 
+
+user1 /a,/b,/c  # user1 has read write access to suite /a /b /c
+user1 /a,/b,/c  # duplicate should be ignored
+user2 /a
+user2 /b
+user2 /c       # user2 has read write access to suite /a /b /c
+user3 /a /b /c # user3 has read write access to suite /a /b /c
+
+/a /b /c userx # userx has read write access to suite /a /b /c
+/a,/b,/c usery # userx has read write access to suite /a /b /c
+
+/a userz
+/a userz  # duplicate should be ignored
+/b userz
+/c userz
+
+-user4 /a,/b,/c  # user4 has read access to suite /a /b /c
+-user4 /a,/b,/c  # duplicate should be ignored
+-user5 /a
+-user5 /b
+-user5 /c         # user5 has read access to suite /a /b /c
+-user6 /a /b /c   # user6 has read access to suite /a /b /c
+
+/a /b /c -userxx # userxx has read  access to suite /a /b /c
+/a,/b,/c -useryy # userxy has read  access to suite /a /b /c
+
+/a -userzz
+/b -userzz
+/c -userzz
+/c -userzz       # duplicate should be ignored
+
+##################################
+* /x /y   # all user have read/write access  suites /x /y
+-* /w /z  # all user have read access to suite /w /z
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/calendar_1_2_2_ 5.13.0-1/libs/core/test/data/migration/calendar_1_2_2_
--- 5.12.4-1/libs/core/test/data/migration/calendar_1_2_2_	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/calendar_1_2_2_	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8CalendarE":{"cereal_class_version":0,"initTime_":{"ptime":"2011-Feb-10 23:59:00"},"initLocalTime_":{"ptime":"2018-Aug-20 10:10:33"},"lastTime_":{"ptime":"2018-Aug-20 10:10:33"}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/dstate_1_2_2_ 5.13.0-1/libs/core/test/data/migration/dstate_1_2_2_
--- 5.12.4-1/libs/core/test/data/migration/dstate_1_2_2_	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/dstate_1_2_2_	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"6DState":{"st_":2}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/nstate_1_2_2_ 5.13.0-1/libs/core/test/data/migration/nstate_1_2_2_
--- 5.12.4-1/libs/core/test/data/migration/nstate_1_2_2_	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/nstate_1_2_2_	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"6NState":{"st_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/timeseries_1_2_2_1010 5.13.0-1/libs/core/test/data/migration/timeseries_1_2_2_1010
--- 5.12.4-1/libs/core/test/data/migration/timeseries_1_2_2_1010	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/timeseries_1_2_2_1010	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf10TimeSeriesE":{"cereal_class_version":0,"start_":{"h_":10,"m_":10}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/timeseries_default_constructor_1_2_2_ 5.13.0-1/libs/core/test/data/migration/timeseries_default_constructor_1_2_2_
--- 5.12.4-1/libs/core/test/data/migration/timeseries_default_constructor_1_2_2_	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/timeseries_default_constructor_1_2_2_	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf10TimeSeriesE":{"cereal_class_version":0,"start_":{"h_":-1,"m_":-1}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/timeslot_1_2_2_11 5.13.0-1/libs/core/test/data/migration/timeslot_1_2_2_11
--- 5.12.4-1/libs/core/test/data/migration/timeslot_1_2_2_11	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/timeslot_1_2_2_11	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8TimeSlotE":{"h_":1,"m_":1}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/timeslot_1_2_2_9959 5.13.0-1/libs/core/test/data/migration/timeslot_1_2_2_9959
--- 5.12.4-1/libs/core/test/data/migration/timeslot_1_2_2_9959	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/timeslot_1_2_2_9959	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8TimeSlotE":{"h_":99,"m_":59}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/core/test/data/migration/timeslot_default_constructor_1_2_2_ 5.13.0-1/libs/core/test/data/migration/timeslot_default_constructor_1_2_2_
--- 5.12.4-1/libs/core/test/data/migration/timeslot_default_constructor_1_2_2_	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/core/test/data/migration/timeslot_default_constructor_1_2_2_	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"N3ecf8TimeSlotE":{"h_":-1,"m_":-1}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/CMakeLists.txt 5.13.0-1/libs/node/CMakeLists.txt
--- 5.12.4-1/libs/node/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,224 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+set(test_srcs
+  # Headers
+  test/MyDefsFixture.hpp
+  # Sources
+  test/TestAdd.cpp
+  test/TestAlias.cpp
+  test/TestAssignmentOperator.cpp
+  test/TestChangeMgrSingleton.cpp
+  test/TestClientSuiteMgr.cpp
+  test/TestCopyConstructor.cpp
+  test/TestDefStatus.cpp
+  test/TestDefs.cpp
+  test/TestEcfFile.cpp
+  test/TestEcfFileLocator.cpp
+  test/TestEnviromentSubstitution.cpp
+  test/TestExprParser.cpp
+  test/TestExprRepeatDateArithmetic.cpp
+  test/TestExprRepeatDateListArithmetic.cpp
+  test/TestFindAbsNodePath.cpp
+  test/TestFlag.cpp
+  test/TestHistoryParser.cpp
+  test/TestInLimit.cpp
+  test/TestJobCreator.cpp
+  test/TestJobProfiler.cpp
+  test/TestLimit.cpp
+  test/TestMigration.cpp
+  test/TestMissNextTimeSlot.cpp
+  test/TestMovePeer.cpp
+  test/TestNodeBeginRequeue.cpp
+  test/TestNodeState.cpp
+  test/TestNode_main.cpp # test entry point
+  test/TestOrder.cpp
+  test/TestPersistence.cpp
+  test/TestPreProcessing.cpp
+  test/TestRepeatWithTimeDependencies.cpp
+  test/TestReplace.cpp
+  test/TestSetState.cpp
+  test/TestSpecificIssues.cpp
+  test/TestSystem.cpp
+  test/TestTaskScriptGenerator.cpp
+  test/TestTimeDependencies.cpp
+  test/TestVariableGeneration.cpp
+  test/TestVariableInheritance.cpp
+  test/TestVariableSubstitution.cpp
+  test/TestVariableSubstitutionDefs.cpp
+  test/TestZombies.cpp
+)
+
+ecbuild_add_test(
+  TARGET
+    u_node
+  LABELS
+    unit
+    nightly
+  SOURCES
+    ${test_srcs}
+  LIBS
+    test_support
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+  TEST_DEPENDS
+    u_attributes
+)
+target_clangformat(u_node
+  CONDITION ENABLE_TESTS)
+
+
+set(test_srcs
+  # Headers
+  test/parser/PersistHelper.hpp
+  test/parser/TemporaryFile.hpp
+  # Sources
+  test/parser/PersistHelper.cpp
+  test/parser/TemporaryFile.cpp
+  test/parser/TestAutoAddExterns.cpp
+  test/parser/TestAvisoAttr.cpp
+  test/parser/TestDefsStructurePersistAndReload.cpp
+  test/parser/TestMementoPersistAndReload.cpp
+  test/parser/TestMigration.cpp
+  test/parser/TestMirrorAttr.cpp
+  test/parser/TestParser.cpp
+  test/parser/TestParser_main.cpp # test entry point
+  test/parser/TestVariableParsing.cpp
+)
+ecbuild_add_test(
+  TARGET
+    u_parser
+  LABELS
+    unit
+    nightly
+  SOURCES
+    ${test_srcs}
+  INCLUDES
+    test
+    test/parser
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+  TEST_DEPENDS
+    u_node
+)
+target_clangformat(u_parser
+  CONDITION ENABLE_TESTS
+)
+
+if (ENABLE_ALL_TESTS)
+  set(test_srcs
+    test/TestSingleExprParse.cpp
+    test/TestSingleExprParse_main.cpp # test entry point
+  )
+
+  ecbuild_add_test(
+    TARGET
+      u_node_single
+    LABELS
+      unit
+      nightly
+    SOURCES
+      ${test_srcs}
+    LIBS
+      ecflow_all
+      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+    TEST_DEPENDS
+      u_anattr
+  )
+  target_clangformat(u_node_single
+    CONDITION ENABLE_TESTS
+  )
+
+
+  set(test_srcs
+    # Headers
+    test/parser/PersistHelper.hpp
+    test/parser/TemporaryFile.hpp
+    # Sources
+    test/parser/PersistHelper.cpp
+    test/parser/TemporaryFile.cpp
+    test/parser/TestParserPerformance_main.cpp # test entry point
+    test/parser/TestSingleDefsFile.cpp
+  )
+
+  ecbuild_add_test(
+    TARGET
+      p_parser
+    LABELS
+      performance
+      nightly
+    SOURCES
+      ${test_srcs}
+    LIBS
+      ecflow_all
+      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+      Boost::timer
+  )
+  target_clangformat(p_parser
+    CONDITION ENABLE_TESTS
+  )
+
+
+  set(test_srcs
+    # Headers
+    test/parser/PersistHelper.hpp
+    test/parser/TemporaryFile.hpp
+    # Sources
+    test/parser/ParseTimer.cpp
+    test/parser/PersistHelper.cpp
+    test/parser/TemporaryFile.cpp
+  )
+
+  # The following is not technically a test (as it makes no checks),
+  # but a tool to measure the time it takes to parse 'mega.def' file
+  ecbuild_add_test(
+    TARGET
+      p_parser_timer
+    LABELS
+      performance
+      nightly
+    ARGS
+      ${CMAKE_CURRENT_SOURCE_DIR}/test/parser/data/single_defs/mega.def
+    SOURCES
+      ${test_srcs}
+    LIBS
+      ecflow_all
+      Boost::boost # Boost header-only libraries must be available
+      Boost::timer
+  )
+  target_clangformat(p_parser_timer
+    CONDITION ENABLE_TESTS
+  )
+
+  # The following is not technically a test (as it makes no checks),
+  # but a tool to parse 'mega.def' file
+  set(test_srcs
+    test/parser/ParseOnly.cpp
+  )
+  ecbuild_add_test(
+    TARGET
+      p_parser_only
+    LABELS
+      performance
+      nightly
+    ARGS
+      ${CMAKE_CURRENT_SOURCE_DIR}/test/parser/data/single_defs/mega.def
+    SOURCES
+      ${test_srcs}
+    LIBS
+      ecflow_all
+      Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+  )
+  target_clangformat(p_parser_only
+    CONDITION ENABLE_TESTS
+  )
+
+endif()
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/AbstractObserver.hpp 5.13.0-1/libs/node/src/ecflow/node/AbstractObserver.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/AbstractObserver.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/AbstractObserver.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_core_AbstractObserver_HPP
+#define ecflow_core_AbstractObserver_HPP
+
+#include <vector>
+
+#include "ecflow/node/Aspect.hpp"
+
+class Node;
+class Defs;
+
+class AbstractObserver {
+public:
+    virtual ~AbstractObserver() = default;
+
+    virtual void update_start(const Node*, const std::vector<ecf::Aspect::Type>&) = 0;
+    virtual void update_start(const Defs*, const std::vector<ecf::Aspect::Type>&) = 0;
+
+    virtual void update(const Node*, const std::vector<ecf::Aspect::Type>&) = 0;
+    virtual void update(const Defs*, const std::vector<ecf::Aspect::Type>&) = 0;
+
+    /// After this call, the node will be deleted, hence observers must *NOT* use the pointers
+    virtual void update_delete(const Node*) {}
+    virtual void update_delete(const Defs*) {}
+};
+
+#endif /* ecflow_core_AbstractObserver_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Alias.cpp 5.13.0-1/libs/node/src/ecflow/node/Alias.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Alias.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Alias.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,165 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Alias.hpp"
+
+#include <limits>
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+//==================================================================================
+Alias::Alias(const std::string& name, bool check) : Submittable(name, check) {
+    set_state_only(NState::QUEUED);
+}
+
+Alias::Alias(const Alias& rhs) = default;
+
+Alias::Alias() {
+    set_state_only(NState::QUEUED);
+}
+
+node_ptr Alias::clone() const {
+    return std::make_shared<Alias>(*this);
+}
+
+Alias::~Alias() {
+    if (!Ecf::server()) {
+        notify_delete();
+    }
+}
+
+Alias& Alias::operator=(const Alias& rhs) {
+    if (this != &rhs) {
+        Submittable::operator=(rhs);
+    }
+    return *this;
+}
+
+alias_ptr Alias::create(const std::string& name, bool check) {
+    return std::make_shared<Alias>(name, check);
+}
+
+bool Alias::operator==(const Alias& rhs) const {
+    return Submittable::operator==(rhs);
+}
+
+void Alias::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    os += "alias ";
+    os += name();
+    if (!PrintStyle::defsStyle()) {
+        bool added_comment_char = false;
+        write_state(os, added_comment_char);
+    }
+    os += "\n";
+
+    Node::print(os);
+
+    // Generated variable are not persisted since they are created on demand
+    // There *NO* point in printing them they will always be empty
+}
+std::ostream& operator<<(std::ostream& os, const Alias& d) {
+    std::string s;
+    d.print(s);
+    os << s;
+    return os;
+}
+
+void Alias::begin() {
+    Submittable::begin();
+}
+
+void Alias::requeue(Requeue_args& args) {
+    Submittable::requeue(args);
+}
+
+const std::string& Alias::debugType() const {
+    return ecf::Str::ALIAS();
+}
+
+node_ptr Alias::removeChild(Node*) {
+    LOG_ASSERT(false, "");
+    return node_ptr();
+}
+
+bool Alias::addChild(const node_ptr&, size_t) {
+    LOG_ASSERT(false, "");
+    return false;
+}
+
+size_t Alias::child_position(const Node*) const {
+    return std::numeric_limits<std::size_t>::max();
+}
+
+bool Alias::isAddChildOk(Node* alias, std::string& errorMsg) const {
+    errorMsg += "Cannot add children to a Alias";
+    return false;
+}
+
+void Alias::handleStateChange() {
+    Node::handleStateChange();
+
+    /// Increment/decrement limits based on the current state
+    update_limits();
+
+    // Aliases are stand alone, they do no requeue or bubble up/down state changes
+    // i.e no requeue since they have no time dependencies, or repeat
+}
+
+const std::string& Alias::script_extension() const {
+    return File::USR_EXTN();
+}
+
+void Alias::collateChanges(DefsDelta& changes) const {
+    /// All changes to Alias should be on ONE compound_memento_ptr
+    compound_memento_ptr comp;
+    Submittable::incremental_changes(changes, comp);
+}
+
+void Alias::get_all_nodes(std::vector<node_ptr>& nodes) const {
+    nodes.push_back(non_const_this());
+}
+
+// Functions unique to aliases
+void Alias::add_alias_variable(const std::string& name, const std::string& value) {
+    if (name.empty()) {
+        throw std::runtime_error("Alias::add_alias_variable: Variable with empty name");
+    }
+
+    // The bool argument to variable, allows addition of Variable without name checking
+    addVariable(Variable(name, value, false));
+}
+
+node_ptr Alias::find_node_up_the_tree(const std::string& name) const {
+    Node* the_parent = parent();
+    if (the_parent)
+        return the_parent->find_node_up_the_tree(name);
+    return node_ptr();
+}
+
+template <class Archive>
+void Alias::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Submittable>(this));
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(Alias);
+CEREAL_REGISTER_TYPE(Alias)
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Alias.hpp 5.13.0-1/libs/node/src/ecflow/node/Alias.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Alias.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Alias.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,97 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Alias_HPP
+#define ecflow_node_Alias_HPP
+
+#include "ecflow/node/Submittable.hpp"
+
+class Alias final : public Submittable {
+public:
+    explicit Alias(const std::string& name, bool check = true);
+    Alias();
+    Alias(const Alias&);
+    Alias& operator=(const Alias&);
+    node_ptr clone() const override;
+
+    ~Alias() override;
+
+    static alias_ptr create(const std::string& name, bool check = true);
+
+    void print(std::string&) const override;
+    bool operator==(const Alias& rhs) const;
+
+    /// Overridden to reset the try number
+    /// The tasks job can be invoked multiple times. For each invocation we want to preserve
+    /// the output. The try number is used in SMSJOB/SMSJOBOUT to preserve the output when
+    /// there are multiple runs.  re-queue/begin() resets the try Number
+    void begin() override;
+    void requeue(Requeue_args&) override;
+
+    Suite* suite() const override { return parent()->suite(); }
+    Defs* defs() const override {
+        return (parent()) ? parent()->defs() : nullptr;
+    } // exposed to python hence check for NULL first
+    Alias* isAlias() const override { return const_cast<Alias*>(this); }
+    Submittable* isSubmittable() const override { return const_cast<Alias*>(this); }
+
+    const std::string& debugType() const override;
+
+    node_ptr removeChild(Node* child) override;
+    bool addChild(const node_ptr& child, size_t position = std::numeric_limits<std::size_t>::max()) override;
+    bool isAddChildOk(Node* child, std::string& errorMsg) const override;
+
+    const std::string& script_extension() const override;
+
+    void collateChanges(DefsDelta&) const override;
+    void set_memento(const SubmittableMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
+        Submittable::set_memento(m, aspects, f);
+    }
+
+    node_ptr find_node_up_the_tree(const std::string& name) const override;
+
+    // Pure node Functions that are not implemented for aliases
+    node_ptr find_relative_node(const std::vector<std::string>&) override { return node_ptr(); }
+
+    void get_all_nodes(std::vector<node_ptr>& nodes) const override;
+
+    // Functions unique to aliases
+    // Alias variable names by pass checking of valid names, allowing anything
+    void add_alias_variable(const std::string& name, const std::string& value);
+
+private:
+    size_t child_position(const Node*) const override;
+
+    /// Job creation checking is typically called from python API
+    /// This has been disabled for Aliases
+    void check_job_creation(job_creation_ctrl_ptr) override {}
+
+    // Overridden from Node to increment/decrement limits only
+    // i.e we do not update parent computed states for aliases
+    void handleStateChange() override;
+
+    // Pure node Functions that are not implemented for aliases
+    void accept(ecf::NodeTreeVisitor&) override {}
+    void acceptVisitTraversor(ecf::NodeTreeVisitor&) override {}
+    void get_all_tasks(std::vector<task_ptr>&) const override {}
+    void get_all_aliases(std::vector<alias_ptr>&) const override {}
+    void getAllNodes(std::vector<Node*>&) const override {}
+    void getAllTasks(std::vector<Task*>&) const override {}
+    void getAllSubmittables(std::vector<Submittable*>&) const override {}
+    void get_all_active_submittables(std::vector<Submittable*>&) const override {}
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+std::ostream& operator<<(std::ostream& os, const Alias&);
+
+#endif /* ecflow_node_Alias_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Aspect.hpp 5.13.0-1/libs/node/src/ecflow/node/Aspect.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Aspect.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Aspect.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,70 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Aspect_HPP
+#define ecflow_node_Aspect_HPP
+
+///
+/// \brief This class is used to provide observers with more info regarding
+/// whats changed. used as a part of the observer pattern
+/// s
+
+namespace ecf {
+
+class Aspect {
+public:
+    enum Type {
+        NOT_DEFINED,
+        ORDER,
+        ADD_REMOVE_NODE,
+        ADD_REMOVE_ATTR,
+        METER,
+        EVENT,
+        LABEL,
+        LIMIT,
+        STATE,
+        DEFSTATUS,
+        SUSPENDED,
+        SERVER_STATE,
+        SERVER_VARIABLE,
+        EXPR_TRIGGER,
+        EXPR_COMPLETE,
+        REPEAT,
+        REPEAT_INDEX,
+        NODE_VARIABLE,
+        LATE,
+        TODAY,
+        TIME,
+        DAY,
+        CRON,
+        DATE,
+        FLAG,
+        SUBMITTABLE,
+        SUITE_CLOCK,
+        SUITE_BEGIN,
+        SUITE_CALENDAR,
+        ALIAS_NUMBER,
+        QUEUE,
+        QUEUE_INDEX,
+        GENERIC,
+        AVISO,
+        MIRROR
+    };
+
+    // Disable default construction
+    Aspect() = delete;
+    // Disable copy (and move) semantics
+    Aspect(const Aspect&)                  = delete;
+    const Aspect& operator=(const Aspect&) = delete;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_Aspect_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Attr.cpp 5.13.0-1/libs/node/src/ecflow/node/Attr.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Attr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Attr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Attr.hpp"
+
+#include <cassert>
+
+namespace ecf {
+
+const char* Attr::to_string(Attr::Type s) {
+    switch (s) {
+        case Attr::EVENT:
+            return "event";
+        case Attr::METER:
+            return "meter";
+        case Attr::LABEL:
+            return "label";
+        case Attr::LIMIT:
+            return "limit";
+        case Attr::VARIABLE:
+            return "variable";
+        case Attr::ALL:
+            return "all";
+        case Attr::UNKNOWN:
+            return "unknown";
+        default:
+            assert(false);
+            break;
+    }
+    assert(false);
+    return nullptr;
+}
+
+Attr::Type Attr::to_attr(const std::string& str) {
+    if (str == "event")
+        return Attr::EVENT;
+    if (str == "meter")
+        return Attr::METER;
+    if (str == "label")
+        return Attr::LABEL;
+    if (str == "limit")
+        return Attr::LIMIT;
+    if (str == "variable")
+        return Attr::VARIABLE;
+    if (str == "all")
+        return Attr::ALL;
+    return Attr::UNKNOWN;
+}
+
+bool Attr::is_valid(const std::string& str) {
+    return (to_attr(str) == Attr::UNKNOWN) ? false : true;
+}
+
+std::vector<std::string> Attr::all_attrs() {
+    std::vector<std::string> vec;
+    vec.reserve(6);
+    vec.emplace_back("event");
+    vec.emplace_back("meter");
+    vec.emplace_back("label");
+    vec.emplace_back("limit");
+    vec.emplace_back("variable");
+    vec.emplace_back("all");
+    return vec;
+}
+
+std::vector<Attr::Type> Attr::attrs() {
+    std::vector<Attr::Type> vec;
+    vec.reserve(6);
+    vec.push_back(Attr::UNKNOWN);
+    vec.push_back(Attr::EVENT);
+    vec.push_back(Attr::METER);
+    vec.push_back(Attr::LABEL);
+    vec.push_back(Attr::LIMIT);
+    vec.push_back(Attr::VARIABLE);
+    vec.push_back(Attr::ALL);
+    return vec;
+}
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Attr.hpp 5.13.0-1/libs/node/src/ecflow/node/Attr.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Attr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Attr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,37 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Attr_HPP
+#define ecflow_node_Attr_HPP
+
+#include <string>
+#include <vector>
+
+namespace ecf {
+class Attr {
+public:
+    enum Type { UNKNOWN = 0, EVENT = 1, METER = 2, LABEL = 3, LIMIT = 4, VARIABLE = 5, ALL = 6 };
+
+    // Disable default construction
+    Attr() = delete;
+    // Disable copy (and move) semantics
+    Attr(const Attr&)                  = delete;
+    const Attr& operator=(const Attr&) = delete;
+
+    static const char* to_string(Attr::Type s);
+    static Attr::Type to_attr(const std::string& attr);
+    static bool is_valid(const std::string& state);
+    static std::vector<std::string> all_attrs();
+    static std::vector<Attr::Type> attrs();
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_Attr_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/AutoRestoreAttr.cpp 5.13.0-1/libs/node/src/ecflow/node/AutoRestoreAttr.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/AutoRestoreAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/AutoRestoreAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,149 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/AutoRestoreAttr.hpp"
+
+#include <sstream>
+
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/NodeContainer.hpp"
+
+#ifdef DEBUG
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+using namespace std;
+
+namespace ecf {
+
+void AutoRestoreAttr::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    os += "\n";
+}
+
+std::string AutoRestoreAttr::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void AutoRestoreAttr::write(std::string& ret) const {
+    ret += "autorestore";
+    for (const auto& i : nodes_to_restore_) {
+        ret += " ";
+        ret += i;
+    }
+}
+
+bool AutoRestoreAttr::operator==(const AutoRestoreAttr& rhs) const {
+    if (nodes_to_restore_ == rhs.nodes_to_restore_)
+        return true;
+
+#ifdef DEBUG
+    if (Ecf::debug_equality()) {
+        std::cout << "AutoRestoreAttr::operator== nodes_to_restore_ == rhs.nodes_to_restore_\n";
+    }
+#endif
+
+    return false;
+}
+
+void AutoRestoreAttr::do_autorestore() {
+    string warning_message;
+    for (const auto& i : nodes_to_restore_) {
+
+        warning_message.clear();
+        node_ptr referenceNode = node_->findReferencedNode(i, warning_message);
+        if (!referenceNode.get()) {
+            /// Could not find the references node
+            std::stringstream ss;
+            ss << "AutoRestoreAttr::do_auto_restore: " << node_->debugType() << " references a path '" << i
+               << "' which cannot be found\n";
+            log(Log::ERR, ss.str());
+            continue;
+        }
+
+        NodeContainer* nc = referenceNode->isNodeContainer();
+        if (nc) {
+            try {
+                nc->restore();
+            }
+            catch (std::exception& e) {
+                std::stringstream ss;
+                ss << "AutoRestoreAttr::do_auto_restore: could not autorestore : because : " << e.what();
+                log(Log::ERR, ss.str());
+            }
+        }
+        else {
+            std::stringstream ss;
+            ss << "AutoRestoreAttr::do_auto_restore: " << node_->debugType() << " references a node '" << i
+               << "' which cannot be restored. Only family and suite nodes can be restored";
+            log(Log::ERR, ss.str());
+        }
+    }
+}
+
+void AutoRestoreAttr::check(std::string& errorMsg) const {
+    std::vector<NodeContainer*> vec;
+    string warning_message;
+    for (const auto& i : nodes_to_restore_) {
+
+        warning_message.clear();
+        node_ptr referenceNode = node_->findReferencedNode(i, warning_message);
+        if (!referenceNode.get()) {
+            /// Could not find the references node
+
+            // OK a little bit of duplication, since findReferencedNode, will also look for externs
+            // See if the Path:name is defined as an extern, in which case *DONT* error:
+            // This is client side specific, since server does not have externs.
+            if (node_->defs()->find_extern(i, Str::EMPTY())) {
+                continue;
+            }
+
+            std::stringstream ss;
+            ss << "Error: autorestore on node " << node_->debugType() << " references a path '" << i
+               << "' which cannot be found\n";
+            errorMsg += ss.str();
+            continue;
+        }
+
+        // reference node found, make sure it not a task
+        NodeContainer* nc = referenceNode->isNodeContainer();
+        if (!nc) {
+            std::stringstream ss;
+            ss << "Error: autorestore on node " << node_->debugType() << " references a node '" << i
+               << "' which is a task. restore only works with suites or family nodes";
+            errorMsg += ss.str();
+        }
+
+        // Check for duplicate references
+        if (find(vec.begin(), vec.end(), nc) == vec.end())
+            vec.push_back(nc);
+        else {
+            std::stringstream ss;
+            ss << "Error: autorestore on node " << node_->debugType() << ", duplicate references to node '" << i << "'";
+            errorMsg += ss.str();
+        }
+    }
+}
+
+template <class Archive>
+void AutoRestoreAttr::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(nodes_to_restore_));
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(AutoRestoreAttr);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/AutoRestoreAttr.hpp 5.13.0-1/libs/node/src/ecflow/node/AutoRestoreAttr.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/AutoRestoreAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/AutoRestoreAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,60 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_AutoRestoreAttr_HPP
+#define ecflow_node_AutoRestoreAttr_HPP
+
+#include <cstdint>
+#include <string>
+#include <vector>
+
+namespace cereal {
+class access;
+}
+
+class Node;
+
+namespace ecf {
+
+// Use compiler, destructor
+class AutoRestoreAttr {
+public:
+    AutoRestoreAttr(const AutoRestoreAttr& rhs) : node_(nullptr), nodes_to_restore_(rhs.nodes_to_restore_) {}
+    explicit AutoRestoreAttr(const std::vector<std::string>& nodes_to_restore)
+        : node_(nullptr),
+          nodes_to_restore_(nodes_to_restore) {}
+    AutoRestoreAttr() = default;
+
+    // needed by node copy constructor and persistence
+    void set_node(Node* n) { node_ = n; }
+
+    void print(std::string&) const;
+    bool operator==(const AutoRestoreAttr& rhs) const;
+    std::string toString() const;
+
+    void do_autorestore();
+    const std::vector<std::string>& nodes_to_restore() const { return nodes_to_restore_; }
+    void check(std::string& errorMsg) const; // check auto restore can reference the nodes
+
+private:
+    void write(std::string&) const;
+
+private:
+    Node* node_{nullptr};                       // Not persisted, constructor will always set this up.
+    std::vector<std::string> nodes_to_restore_; // must be suite or family
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_AutoRestoreAttr_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/AvisoAttr.cpp 5.13.0-1/libs/node/src/ecflow/node/AvisoAttr.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/AvisoAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/AvisoAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,249 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/AvisoAttr.hpp"
+
+#include <sstream>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Message.hpp"
+#include "ecflow/core/Overload.hpp"
+#include "ecflow/core/exceptions/Exceptions.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/Operations.hpp"
+
+namespace ecf {
+
+bool AvisoAttr::is_valid_name(const std::string& name) {
+    return ecf::Str::valid_name(name);
+}
+
+AvisoAttr::AvisoAttr(Node* parent,
+                     name_t name,
+                     listener_t listener,
+                     url_t url,
+                     schema_t schema,
+                     polling_t polling,
+                     revision_t revision,
+                     auth_t auth,
+                     reason_t reason)
+    : parent_{parent},
+      parent_path_{parent ? parent->absNodePath() : ""},
+      name_{std::move(name)},
+      listener_{std::move(listener)},
+      url_{std::move(url)},
+      schema_{std::move(schema)},
+      polling_{std::move(polling)},
+      auth_{std::move(auth)},
+      reason_{std::move(reason)},
+      revision_{revision},
+      controller_{nullptr} {
+    if (!ecf::Str::valid_name(name_)) {
+        throw ecf::InvalidArgument(ecf::Message("Invalid AvisoAttr name :", name_));
+    }
+}
+
+AvisoAttr AvisoAttr::make_detached() const {
+    AvisoAttr detached   = *this;
+    detached.parent_     = nullptr;
+    detached.controller_ = nullptr;
+    return detached;
+}
+
+void AvisoAttr::set_listener(std::string_view listener) {
+    state_change_no_ = Ecf::incr_state_change_no();
+
+    listener_ = listener;
+}
+
+void AvisoAttr::set_revision(revision_t revision) {
+    state_change_no_ = Ecf::incr_state_change_no();
+
+    revision_ = revision;
+}
+
+std::string AvisoAttr::path() const {
+    std::string path = parent_path_;
+    path += ':';
+    path += name_;
+    return path;
+}
+
+bool AvisoAttr::why(std::string& theReasonWhy) const {
+    if (isFree()) {
+        return false;
+    }
+
+    theReasonWhy += ecf::Message(" is Aviso dependent (", listener_, "), but no notification received");
+    return true;
+}
+
+void AvisoAttr::reset() {
+    state_change_no_ = Ecf::incr_state_change_no();
+
+    if (parent_->state() == NState::QUEUED) {
+        start();
+    }
+}
+
+bool AvisoAttr::isFree() const {
+    SLOG(D, "AvisoAttr: check Aviso attribute (name: " << name_ << ", listener: " << listener_ << ") is free");
+
+    if (controller_ == nullptr) {
+        return false;
+    }
+
+    // Task associated with Attribute is free when any notification is found
+    auto notifications = controller_->get_notifications(this->path());
+
+    if (notifications.empty()) {
+        // No notifications, nothing to do -- task continues to wait
+        return false;
+    }
+
+    // Notifications found -- task can continue
+
+    // (a) get the latest revision
+    auto& back = notifications.back();
+
+    state_change_no_ = Ecf::incr_state_change_no();
+
+    // (b) update the revision, in the listener configuration
+    auto is_free = std::visit(
+        ecf::overload{
+            [this](const ecf::service::aviso::NotificationPackage<service::aviso::ConfiguredListener,
+                                                                  service::aviso::AvisoNotification>& response) {
+                SLOG(D, "AvisoAttr::isFree: " << this->path() << " updated revision to " << this->revision_);
+                this->revision_ = response.configuration.revision();
+                parent_->flag().clear(Flag::REMOTE_ERROR);
+                parent_->flag().set_state_change_no(state_change_no_);
+                reason_ = "";
+                return true;
+            },
+            [this](const ecf::service::aviso::AvisoNoMatch& response) {
+                parent_->flag().clear(Flag::REMOTE_ERROR);
+                parent_->flag().set_state_change_no(state_change_no_);
+                reason_ = "";
+                return false;
+            },
+            [this](const ecf::service::aviso::AvisoError& response) {
+                parent_->flag().set(Flag::REMOTE_ERROR);
+                parent_->flag().set_state_change_no(state_change_no_);
+                reason_ = response.reason();
+                return false;
+            }},
+        back);
+
+    ecf::visit_parents(*parent_, [n = this->state_change_no_](Node& node) { node.set_state_change_no(n); });
+
+    return is_free;
+}
+
+void AvisoAttr::start() const {
+    LOG(Log::DBG, Message("AvisoAttr: subscribe Aviso attribute (name: ", name_, ", listener: ", listener_, ")"));
+
+    // Path -- the unique identifier of the Aviso listener
+    std::string aviso_path = path();
+
+    // Listener -- the configuration for the Aviso listener
+    auto aviso_listener = listener_;
+    aviso_listener      = aviso_listener.substr(1, aviso_listener.size() - 2);
+
+    // URL -- the URL for the Aviso server
+    std::string aviso_url = url_;
+    parent_->variableSubstitution(aviso_url);
+    if (aviso_url.empty()) {
+        throw std::runtime_error("AvisoAttr: invalid Aviso URL detected for " + aviso_path);
+    }
+
+    // Schema -- the path to the Schema used to interpret the Aviso notifications
+    std::string aviso_schema = schema_;
+    parent_->variableSubstitution(aviso_schema);
+
+    std::string aviso_polling = polling_;
+    parent_->variableSubstitution(aviso_polling);
+    if (aviso_polling.empty()) {
+        throw std::runtime_error("AvisoAttr: invalid Aviso polling interval detected for " + aviso_path);
+    }
+    auto polling = boost::lexical_cast<std::uint32_t>(aviso_polling);
+
+    std::string aviso_auth = auth_;
+    parent_->variableSubstitution(aviso_auth);
+
+    start_controller(aviso_path, aviso_listener, aviso_url, aviso_schema, polling, aviso_auth);
+}
+
+void AvisoAttr::start_controller(const std::string& aviso_path,
+                                 const std::string& aviso_listener,
+                                 const std::string& aviso_url,
+                                 const std::string& aviso_schema,
+                                 std::uint32_t polling,
+                                 const std::string& aviso_auth) const {
+
+    if (!controller_) {
+        // Controller -- start up the Aviso controller, and subscribe the Aviso listener
+        controller_ = std::make_shared<controller_t>();
+        controller_->subscribe(ecf::service::aviso::AvisoSubscribe{
+            aviso_path, aviso_listener, aviso_url, aviso_schema, polling, revision_, aviso_auth});
+        // Controller -- effectively start the Aviso listener
+        // n.b. this must be done after subscribing in the controller, so that the polling interval is set
+        controller_->start();
+    }
+}
+
+void AvisoAttr::stop_controller(const std::string& aviso_path) const {
+    if (controller_ != nullptr) {
+        SLOG(D, "AvisoAttr: finishing polling for Aviso attribute (" << parent_path_ << ":" << name_ << ")");
+
+        controller_->subscribe(ecf::service::aviso::AvisoUnsubscribe{aviso_path});
+
+        // Controller -- shutdown up the Aviso controller
+        controller_->stop();
+        controller_ = nullptr;
+    }
+}
+
+void AvisoAttr::finish() const {
+    using namespace ecf;
+
+    std::string aviso_path = path();
+    stop_controller(aviso_path);
+}
+
+bool operator==(const AvisoAttr& lhs, const AvisoAttr& rhs) {
+    return lhs.name() == rhs.name() && lhs.listener() == rhs.listener() && lhs.url() == rhs.url() &&
+           lhs.schema() == rhs.schema() && lhs.polling() == rhs.polling() && lhs.revision() == rhs.revision() &&
+           lhs.auth() == rhs.auth() && lhs.reason() == rhs.reason();
+}
+
+std::string to_python_string(const AvisoAttr& aviso) {
+    std::string s;
+    s += "AvisoAttr(";
+    s += "name=";
+    s += aviso.name();
+    s += ", listener=";
+    s += aviso.listener();
+    s += ", url=";
+    s += aviso.url();
+    s += ", schema=";
+    s += aviso.schema();
+    s += ", polling=";
+    s += aviso.polling();
+    s += ", revision=";
+    s += aviso.revision();
+    s += ", auth=";
+    s += aviso.auth();
+    s += ", reason=";
+    s += aviso.reason();
+    s += ")";
+    return s;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/AvisoAttr.hpp 5.13.0-1/libs/node/src/ecflow/node/AvisoAttr.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/AvisoAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/AvisoAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,159 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_AvisoAttr_HPP
+#define ecflow_node_AvisoAttr_HPP
+
+#include <cstdint>
+#include <iostream>
+#include <string>
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/service/aviso/AvisoService.hpp"
+
+namespace cereal {
+class access;
+}
+
+class Node;
+
+namespace ecf {
+
+///
+/// \brief AvisoAttr represents an attribute, attached to a \ref Node.
+///
+/// The Aviso attribute effectively acts as a trigger for the Node, granting
+/// the Node to be (re)queued as soon as a related notification is received.
+///
+/// \see https://github.com/ecmwf/aviso
+///
+
+class AvisoAttr {
+public:
+    using path_t     = std::string;
+    using name_t     = std::string;
+    using listener_t = std::string;
+    using url_t      = std::string;
+    using schema_t   = std::string;
+    using polling_t  = std::string;
+    using revision_t = std::uint64_t;
+    using auth_t     = std::string;
+    using reason_t   = std::string;
+
+    using controller_t     = ecf::service::aviso::AvisoController;
+    using controller_ptr_t = std::shared_ptr<controller_t>;
+
+    static constexpr const char* default_url     = "%ECF_AVISO_URL%";
+    static constexpr const char* default_schema  = "%ECF_AVISO_SCHEMA%";
+    static constexpr const char* default_polling = "%ECF_AVISO_POLLING%";
+    static constexpr const char* default_auth    = "%ECF_AVISO_AUTH%";
+
+    static bool is_valid_name(const std::string& name);
+
+    /**
+     * Creates a(n invalid) Aviso
+     *
+     * Note: this is required by Cereal serialization
+     *       Cereal invokes the default ctor to create the object and only then proceeds to member-wise serialization.
+     */
+    AvisoAttr() = default;
+    AvisoAttr(Node* parent,
+              name_t name,
+              listener_t handle,
+              url_t url,
+              schema_t schema,
+              polling_t polling,
+              revision_t revision,
+              auth_t auth,
+              reason_t reason);
+    AvisoAttr(const AvisoAttr& rhs) = default;
+
+    AvisoAttr& operator=(const AvisoAttr& rhs) = default;
+
+    [[nodiscard]] AvisoAttr make_detached() const;
+
+    [[nodiscard]] inline Node* parent() const { return parent_; }
+    [[nodiscard]] inline const std::string& name() const { return name_; }
+    [[nodiscard]] inline const std::string& listener() const { return listener_; }
+    [[nodiscard]] inline const std::string& url() const { return url_; }
+    [[nodiscard]] inline const std::string& schema() const { return schema_; }
+    [[nodiscard]] inline polling_t polling() const { return polling_; }
+    [[nodiscard]] inline revision_t revision() const { return revision_; }
+    [[nodiscard]] inline const std::string& auth() const { return auth_; }
+    [[nodiscard]] inline const std::string& reason() const { return reason_; }
+    [[nodiscard]] path_t path() const;
+
+    void set_listener(std::string_view listener);
+    void set_revision(revision_t revision);
+
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    bool why(std::string& theReasonWhy) const;
+
+    void reset();
+
+    [[nodiscard]] bool isFree() const;
+
+    void start() const;
+    void finish() const;
+
+    template <class Archive>
+    friend void serialize(Archive& ar, AvisoAttr& aviso, std::uint32_t version);
+
+private:
+    void start_controller(const std::string& aviso_path,
+                          const std::string& aviso_listener,
+                          const std::string& aviso_url,
+                          const std::string& aviso_schema,
+                          std::uint32_t polling,
+                          const std::string& aviso_auth) const;
+    void stop_controller(const std::string& aviso_path) const;
+
+    Node* parent_{nullptr}; // only ever used on the server side, to access parent Node variables
+    path_t parent_path_;
+    name_t name_;
+    listener_t listener_;
+    url_t url_;
+    schema_t schema_;
+    polling_t polling_;
+
+    auth_t auth_;
+    mutable reason_t reason_{};
+
+    // The following are mutable as they are modified by the const method isFree()
+    mutable revision_t revision_;
+    mutable unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+    // The controller is only instanciated between start() and finish() calls
+    // This allows the AvisoAttr have a copy-ctor and assignment operator
+    mutable controller_ptr_t controller_;
+};
+
+bool operator==(const AvisoAttr& lhs, const AvisoAttr& rhs);
+
+std::string to_python_string(const AvisoAttr& aviso);
+
+template <class Archive>
+void serialize(Archive& ar, AvisoAttr& aviso, [[maybe_unused]] std::uint32_t version) {
+    ar & aviso.parent_path_;
+    ar & aviso.name_;
+    ar & aviso.listener_;
+    ar & aviso.url_;
+    ar & aviso.schema_;
+    ar & aviso.polling_;
+    ar & aviso.auth_;
+    ar & aviso.reason_;
+    ar & aviso.revision_;
+}
+
+} // namespace ecf
+
+#endif /* ecflow_node_AvisoAttr_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ClientSuiteMgr.cpp 5.13.0-1/libs/node/src/ecflow/node/ClientSuiteMgr.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ClientSuiteMgr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ClientSuiteMgr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,275 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/ClientSuiteMgr.hpp"
+
+#include <algorithm> // for sort, remove_if
+#include <sstream>   // for std::stringstream
+#include <stdexcept>
+
+#include "ecflow/core/Ecf.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// #define DEBUG_HANDLE 1
+
+ClientSuiteMgr::ClientSuiteMgr(Defs* defs) : defs_(defs) {
+}
+
+unsigned int ClientSuiteMgr::create_client_suite(bool auto_add_new_suites,
+                                                 const std::vector<std::string>& suites,
+                                                 const std::string& the_user) {
+    // The handle must be unique. If there are holes, re-use them, i.e
+    //     1,2,3,4,5     user deletes handle 3 ===>  1,2,4,5
+    // Hence re-use handle 3
+    bool found_hole         = false;
+    unsigned int new_handle = 1;
+    for (auto& clientSuite : clientSuites_) {
+        if (clientSuite.handle() == new_handle) {
+            new_handle++;
+        }
+        else {
+            found_hole = true;
+            break;
+        }
+    }
+    if (!found_hole)
+        new_handle = clientSuites_.size() + 1;
+
+    clientSuites_.emplace_back(defs_, new_handle, auto_add_new_suites, suites, the_user);
+
+    // aesthetics only
+    std::sort(clientSuites_.begin(), clientSuites_.end(), [](const ecf::ClientSuites& a, const ecf::ClientSuites& b) {
+        return a.handle() < b.handle();
+    });
+
+    // make sure all suites in ClientSuites are in same order as  Defs suites
+    update_suite_order();
+
+#ifdef DEBUG_HANDLE
+    std::cout << "ClientSuiteMgr::create_client_suite: " << dump() << "\n";
+#endif
+    return new_handle;
+}
+
+void ClientSuiteMgr::remove_client_suite(unsigned int client_handle) {
+    size_t before = clientSuites_.size();
+    clientSuites_.erase(
+        std::remove_if(clientSuites_.begin(),
+                       clientSuites_.end(),
+                       [client_handle](const ecf::ClientSuites& cs) { return cs.handle() == client_handle; }),
+        clientSuites_.end());
+
+    if (before == clientSuites_.size()) {
+        std::stringstream ss;
+        ss << "ClientSuiteMgr::remove_client_suite: handle(" << client_handle
+           << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
+        throw std::runtime_error(ss.str());
+    }
+#ifdef DEBUG_HANDLE
+    std::cout << "ClientSuiteMgr::remove_client_suite: handle(" << client_handle << ") " << dump() << "\n";
+#endif
+}
+
+void ClientSuiteMgr::remove_client_suites(const std::string& user_to_drop) {
+    size_t before = clientSuites_.size();
+    clientSuites_.erase(
+        std::remove_if(clientSuites_.begin(),
+                       clientSuites_.end(),
+                       [&user_to_drop](const ecf::ClientSuites& cs) { return cs.user() == user_to_drop; }),
+        clientSuites_.end());
+
+    if (before == clientSuites_.size()) {
+        std::stringstream ss;
+        ss << "ClientSuiteMgr::remove_client_suites: user(" << user_to_drop
+           << ") has no registered handles. User dropped? Please refresh GUI/re-register suites";
+        throw std::runtime_error(ss.str());
+    }
+
+#ifdef DEBUG_HANDLE
+    std::cout << "ClientSuiteMgr::remove_client_suites: user_to_drop(" << user_to_drop << ") " << dump() << "\n";
+#endif
+}
+
+void ClientSuiteMgr::add_suites(unsigned int client_handle, const std::vector<std::string>& suites) {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            for (const auto& suite : suites) {
+                clientSuites_[i].add_suite(suite);
+            }
+#ifdef DEBUG_HANDLE
+            std::cout << "ClientSuiteMgr::add_suites: client_handle(" << client_handle << ") " << dump() << "\n";
+#endif
+            update_suite_order();
+            return;
+        }
+    }
+    std::stringstream ss;
+    ss << "ClientSuiteMgr::add_suites: handle(" << client_handle
+       << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
+    throw std::runtime_error(ss.str());
+}
+
+void ClientSuiteMgr::remove_suites(unsigned int client_handle, const std::vector<std::string>& suites) {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            for (const auto& suite : suites) {
+                clientSuites_[i].remove_suite(suite);
+            }
+#ifdef DEBUG_HANDLE
+            std::cout << "ClientSuiteMgr::remove_suites: client_handle(" << client_handle << ") " << dump() << "\n";
+#endif
+            return;
+        }
+    }
+    std::stringstream ss;
+    ss << "ClientSuiteMgr::remove_suites: handle(" << client_handle
+       << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
+    throw std::runtime_error(ss.str());
+}
+
+void ClientSuiteMgr::auto_add_new_suites(unsigned int client_handle, bool auto_add_new_suites) {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            clientSuites_[i].add_new_suite(auto_add_new_suites);
+
+#ifdef DEBUG_HANDLE
+            std::cout << "ClientSuiteMgr::auto_add_new_suites: client_handle(" << client_handle
+                      << ") auto_add_new_suites(" << auto_add_new_suites << ") " << dump() << "\n";
+#endif
+            return;
+        }
+    }
+    std::stringstream ss;
+    ss << "ClientSuiteMgr::auto_add_new_suites: handle(" << client_handle
+       << ") does not exist. Handle dropped? Please refresh GUI/re-register suites";
+    throw std::runtime_error(ss.str());
+}
+
+bool ClientSuiteMgr::valid_handle(unsigned int client_handle) const {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            return true;
+        }
+    }
+    return false;
+}
+
+/// returns true if the handle was created, or suites added or removed from it
+bool ClientSuiteMgr::handle_changed(unsigned int client_handle) {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            return clientSuites_[i].handle_changed();
+        }
+    }
+    return false;
+}
+
+void ClientSuiteMgr::collateChanges(unsigned int client_handle, DefsDelta& changes) const {
+    // collate changes over the suites that match the client handle
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            clientSuites_[i].collateChanges(changes);
+            return;
+        }
+    }
+}
+
+void ClientSuiteMgr::suites(unsigned int client_handle, std::vector<std::string>& names) const {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            clientSuites_[i].suites(names);
+            return;
+        }
+    }
+}
+
+defs_ptr ClientSuiteMgr::create_defs(unsigned int client_handle, defs_ptr server_defs) const {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            return clientSuites_[i].create_defs(server_defs);
+        }
+    }
+    return defs_ptr();
+}
+
+void ClientSuiteMgr::max_change_no(unsigned int client_handle,
+                                   unsigned int& max_state_change_no,
+                                   unsigned int& max_modify_change_no) {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        if (clientSuites_[i].handle() == client_handle) {
+            clientSuites_[i].max_change_no(max_state_change_no, max_modify_change_no);
+            return;
+        }
+    }
+    std::stringstream ss;
+    ss << "ClientSuiteMgr::max_change_no: handle(" << client_handle
+       << ") does not exist in server. Handle dropped or Server may have died? Please refresh GUI/re-register suites";
+    throw std::runtime_error(ss.str());
+}
+
+void ClientSuiteMgr::suite_added_in_defs(suite_ptr suite) {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        clientSuites_[i].suite_added_in_defs(suite);
+        clientSuites_[i].update_suite_order();
+    }
+}
+
+void ClientSuiteMgr::suite_deleted_in_defs(suite_ptr suite) {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        clientSuites_[i].suite_deleted_in_defs(suite);
+    }
+}
+
+void ClientSuiteMgr::update_suite_order() {
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        clientSuites_[i].update_suite_order();
+    }
+}
+
+std::string ClientSuiteMgr::dump_max_change_no() const {
+    std::stringstream ss;
+    ss << "ClientSuiteMgr::dump_max_change_no: ECF:(" << Ecf::state_change_no() << "," << Ecf::modify_change_no()
+       << ")\n";
+    size_t client_suites_size = clientSuites_.size();
+    for (size_t i = 0; i < client_suites_size; i++) {
+        unsigned int max_state_change_no  = 0;
+        unsigned int max_modify_change_no = 0;
+        clientSuites_[i].max_change_no(max_state_change_no, max_modify_change_no);
+        ss << "handle: " << clientSuites_[i].handle() << " max(" << max_state_change_no << "," << max_modify_change_no
+           << ")\n";
+    }
+    return ss.str();
+}
+
+/// For debug dumps
+std::string ClientSuiteMgr::dump() const {
+    size_t client_suites_size = clientSuites_.size();
+    std::stringstream ss;
+    ss << "ECF:(" << Ecf::state_change_no() << "," << Ecf::modify_change_no() << ") clientSuites_.size("
+       << client_suites_size << ")\n";
+    for (size_t i = 0; i < client_suites_size; i++) {
+        ss << clientSuites_[i].dump() << "\n";
+    }
+    return ss.str();
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ClientSuiteMgr.hpp 5.13.0-1/libs/node/src/ecflow/node/ClientSuiteMgr.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ClientSuiteMgr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ClientSuiteMgr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,118 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ClientSuiteMgr_HPP
+#define ecflow_node_ClientSuiteMgr_HPP
+
+///
+/// \brief The client may only want to view a small subset of the suites available
+/// in a defs file. This class manages the client handles
+///
+/// Users are allowed to register interest in suite that have not yet been added
+/// This will only work provided we have a definition
+///
+/// Only handle with value > 0 are valid. This is because sync() and news() command
+/// take a client_handle. By reserving a client handle of zero, we can sync with the
+/// full defs.
+///
+///
+/// \note Change of suite order is handled by OrderMemento
+///       and *NOT* by the ClientSuiteMgr, however whenever suites are
+///       registered and added/deleted:
+///       then:
+///           defs_ptr create_defs(unsigned int client_handle) const;
+///
+///       Will return the suites in the same order as the defs
+///
+
+#include "ecflow/node/ClientSuites.hpp"
+class DefsDelta;
+class Defs;
+
+class ClientSuiteMgr {
+public:
+    explicit ClientSuiteMgr(Defs*);
+    // Disable copy (and move) semantics
+    ClientSuiteMgr(const ClientSuiteMgr&)                  = delete;
+    const ClientSuiteMgr& operator=(const ClientSuiteMgr&) = delete;
+
+    /// Create a client suite, and return the handle associated with the created object
+    unsigned int
+    create_client_suite(bool auto_add_new_suites, const std::vector<std::string>& suites, const std::string& user);
+
+    /// These function can throw std::runtime_error if the handle cannot be found
+    void remove_client_suite(unsigned int client_handle);
+    void remove_client_suites(const std::string& user_to_drop);
+    void add_suites(unsigned int client_handle, const std::vector<std::string>& suites);
+    void remove_suites(unsigned int client_handle, const std::vector<std::string>& suites);
+    void auto_add_new_suites(unsigned int client_handle, bool auto_add_new_suites);
+
+    /// Return true if the input handle is valid
+    bool valid_handle(unsigned int client_handle) const;
+
+    /// returns true if the handle was created, or suites added or removed from it
+    /// The handle change flag is reset when create_defs is called
+    bool handle_changed(unsigned int client_handle);
+
+    /// Collect all the state changes, so that only small subset is returned to client
+    /// When nodes are added/deleted we use the modify_change_no_, in this case
+    /// the whole defs is returned. Both integers are returned back to the client
+    /// so that, the client then sends the integers back to server, so we can determine
+    /// what's changed.
+    void collateChanges(unsigned int client_handle, DefsDelta&) const;
+
+    // Only return the defs state and suites that the client has registered in the client handle
+    // *HOWEVER* if the client has registered all the suites, just return the server defs
+    //           *with* the updated change numbers
+    // *OTHERWISE*
+    /// This will also compute the **maximum** state and modify change numbers over
+    /// the suites managed by the client handle.
+    /// and then set it on the newly created defs.
+    /// It also takes special precaution *NOT* to change Ecf::state_change_no() and Ecf::modify_change_no()
+    /// This will clear the handle_changed flag
+    defs_ptr create_defs(unsigned int client_handle, defs_ptr server_defs) const;
+
+    /// Used to determine the change, will throw if handle not found
+    void
+    max_change_no(unsigned int client_handle, unsigned int& max_state_change_no, unsigned int& max_modify_change_no);
+
+    /// Accessor
+    const std::vector<ecf::ClientSuites>& clientSuites() const { return clientSuites_; }
+
+    /// returns the list of suites associated with a handle, Used by ecFlowview
+    void suites(unsigned int client_handle, std::vector<std::string>& names) const;
+
+    /// A suite is being added in the definition.
+    /// If the suite was previously registered *UPDATE* its suite_ptr
+    /// Otherwise if any ClientSuites registered for automatic inclusion of new suite, add them in
+    void suite_added_in_defs(suite_ptr);
+
+    /// The suite is being deleted in the definition, reset the suite_ptr
+    /// Deleted suites STAY registered, until explicitly dropped.
+    void suite_deleted_in_defs(suite_ptr);
+
+    /// Update suites to be in same order as Defs.
+    void update_suite_order();
+
+    /// remove all client Suites
+    void clear() { clientSuites_.clear(); }
+
+    /// Returns a string which has the max state change and modify numbers for each handle
+    std::string dump_max_change_no() const;
+
+    /// For debug dumps
+    std::string dump() const;
+
+private:
+    std::vector<ecf::ClientSuites> clientSuites_;
+    Defs* defs_;
+};
+
+#endif /* ecflow_node_ClientSuiteMgr_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ClientSuites.cpp 5.13.0-1/libs/node/src/ecflow/node/ClientSuites.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ClientSuites.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ClientSuites.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,296 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/ClientSuites.hpp"
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/DefsDelta.hpp"
+#include "ecflow/node/Suite.hpp"
+
+// #define DEBUG_ME 1
+
+namespace ecf {
+
+ClientSuites::ClientSuites(Defs* defs,
+                           unsigned int handle,
+                           bool auto_add_new_suites,
+                           const std::vector<std::string>& suites,
+                           const std::string& user)
+    : defs_(defs),
+      user_(user),
+      handle_(handle),
+      auto_add_new_suites_(auto_add_new_suites) {
+    for (const std::string& s : suites) {
+        add_suite(s);
+    }
+}
+
+void ClientSuites::add_suite(const std::string& s) {
+    suite_ptr suite = defs_->findSuite(s);
+    if (suite.get()) {
+        add_suite(suite);
+    }
+    else {
+        auto i = find_suite(s);
+        if (i != suites_.end()) {
+            (*i).weak_suite_ptr_ = weak_suite_ptr();
+        }
+        else {
+            suites_.emplace_back(s);
+        }
+    }
+}
+
+void ClientSuites::add_suite(suite_ptr suite) {
+    if (suite.get()) {
+
+        // *IMPORTANT* update weak_suite_ptr_
+        auto i = find_suite(suite->name());
+        if (i != suites_.end()) {
+            (*i).weak_suite_ptr_ = weak_suite_ptr(suite);
+        }
+        else {
+            suites_.emplace_back(suite->name(), weak_suite_ptr(suite));
+        }
+        handle_changed_ = true;
+
+#ifdef DEBUG_ME
+        i = suites_.find_suite(suite->name());
+        assert(i != suites_.end());
+        assert((*i).weak_suite_ptr_.lock().get());
+#endif
+    }
+}
+
+void ClientSuites::remove_suite(const std::string& s) {
+    auto i = find_suite(s);
+    if (i != suites_.end()) {
+        if ((*i).weak_suite_ptr_.lock().get()) {
+            handle_changed_ = true;
+        }
+        suites_.erase(i);
+    }
+}
+
+bool ClientSuites::remove_suite(suite_ptr suite) {
+    if (suite.get()) {
+        auto i = find_suite(suite->name());
+        if (i != suites_.end()) {
+            handle_changed_ = true;
+            suites_.erase(i);
+            return true;
+        }
+    }
+    return false;
+}
+
+void ClientSuites::suite_added_in_defs(suite_ptr suite) {
+    if (auto_add_new_suites_)
+        add_suite(suite);
+    else {
+        // *IF* and *ONLY IF* the suite was previously registered added, *UPDATE* its suite_ptr
+        auto i = find_suite(suite->name());
+        if (i != suites_.end()) {
+            // previously registered suite, update
+            add_suite(suite);
+        }
+    }
+}
+
+void ClientSuites::suite_deleted_in_defs(suite_ptr suite) {
+    // Deleted suites are *NOT* automatically removed
+    // They have to be moved explicitly by the user. Reset to weak ptr
+    if (suite.get()) {
+        auto i = find_suite(suite->name());
+        if (i != suites_.end()) {
+            handle_changed_      = true;
+            modify_change_no_    = Ecf::modify_change_no(); // need to pass back to client
+            (*i).weak_suite_ptr_ = weak_suite_ptr();        // reset suite ptr, not strictly necessary
+        }
+    }
+}
+
+void ClientSuites::collateChanges(DefsDelta& changes) const {
+    for (const HSuite& s : suites_) {
+        suite_ptr suite = s.weak_suite_ptr_.lock();
+        if (suite.get()) {
+            suite->collateChanges(changes);
+        }
+    }
+}
+
+defs_ptr ClientSuites::create_defs(defs_ptr server_defs) const {
+    /// Clear handle changed, so we can detect suites added or removed for this handle
+    handle_changed_ = false;
+
+    // If the user has registered *ALL* the suites just return the server defs
+    auto suites_end = suites_.end();
+    if (suites_.size() == server_defs->suiteVec().size()) {
+        size_t real_suite_count = 0;
+        for (auto i = suites_.begin(); i != suites_end; ++i) {
+            suite_ptr suite = (*i).weak_suite_ptr_.lock();
+            if (suite.get())
+                real_suite_count++;
+        }
+        if (real_suite_count == server_defs->suiteVec().size()) {
+
+            server_defs->set_state_change_no(Ecf::state_change_no());
+            server_defs->set_modify_change_no(Ecf::modify_change_no());
+
+            // Update local modify_change_no_ *AND* state_change_no_
+            // ***** Note: Otherwise NewsCmd which computes change numbers over
+            // ***** registered suites will not be correct. causing unnecessary sync's
+            modify_change_no_ = Ecf::modify_change_no();
+            state_change_no_  = Ecf::state_change_no();
+            return server_defs;
+        }
+    }
+
+    // CREATE NEW DEFS, using the registered suites
+    //
+    // *** We do not use local state_change_no_. That is used ONLY when all suites ***
+    // *** are registered.                                                         ***
+    //
+    // add_suite() below will incremented the modify_change_no.
+    // We don't want to do this, as change for suites *not in* the our handle will get skewed
+    // This class ensure that any changes made are reset to their original values
+    EcfPreserveChangeNo preserveChangeNo;
+
+    // Create defs to be sent to the client, with the registered suites.
+    defs_ptr newly_created_defs = Defs::create();
+    newly_created_defs->copy_defs_state_only(server_defs);
+
+    // Store the state/modify change number to the newly created defs *over* the objects that have changed
+    unsigned int the_max_state_change_no  = server_defs->defs_only_max_state_change_no();
+    unsigned int the_max_modify_change_no = 0;
+
+    // Handle suites that get deleted. Need a full sync
+    the_max_modify_change_no = std::max(the_max_modify_change_no, modify_change_no_);
+
+    // Suites should already be in order
+    for (auto i = suites_.begin(); i != suites_end; ++i) {
+        suite_ptr suite = (*i).weak_suite_ptr_.lock();
+        if (suite.get()) {
+
+            // Preserve the change/modify numbers, as these will updated on the suite, by addSuite() below
+            unsigned int suite_state_change_no  = suite->state_change_no();
+            unsigned int suite_modify_change_no = suite->modify_change_no();
+
+            the_max_state_change_no  = std::max(the_max_state_change_no, suite_state_change_no);
+            the_max_modify_change_no = std::max(the_max_modify_change_no, suite_modify_change_no);
+
+            // To avoid copying the suites, we will just add the suites, to the newly created defs
+            // However this presents a problem with the suites defs pointer. To avoid corrupting
+            // the server, we must reset the defs pointer.
+            // The newly_created_defs/Defs serialisation will re-adjust the suites defs pointer
+            Defs* old_defs = suite->defs();
+
+            // This will end up setting the suite's defs pointer to 'newly_created_defs'.
+            // This is wrong, since we only have a single suite
+            suite->set_defs(nullptr);            // otherwise addSuite, will complain
+            newly_created_defs->addSuite(suite); // will update modify_change_no, see comment at top
+
+            suite->set_defs(old_defs);                           // reset the defs, since addSuite() changed defs ptr
+            suite->set_state_change_no(suite_state_change_no);   // reset in case addSuite() changed this
+            suite->set_modify_change_no(suite_modify_change_no); // reset in case addSuite() changed this
+        }
+    }
+
+    // Store the max in the defs, for transmission to client. The client uses this for syncing
+    newly_created_defs->set_state_change_no(the_max_state_change_no);
+    newly_created_defs->set_modify_change_no(the_max_modify_change_no);
+    return newly_created_defs;
+}
+
+void ClientSuites::max_change_no(unsigned int& the_max_state_change_no, unsigned int& the_max_modify_change_no) const {
+    /// get the max state change_no due to:
+    ///   o Defs state changed
+    ///   o Suite order changed
+    ///   o Defs flag changed
+    ///   o Defs server state changed.
+    ///   o Defs server variables changed
+    the_max_state_change_no = defs_->defs_only_max_state_change_no();
+
+    // Take into account case where all suites are registered
+    the_max_state_change_no = std::max(the_max_state_change_no, state_change_no_);
+
+    // Take into account registered suites that get deleted, and where all suites registered
+    the_max_modify_change_no = 0;
+    the_max_modify_change_no = std::max(the_max_modify_change_no, modify_change_no_);
+
+    for (const HSuite& p : suites_) {
+        suite_ptr suite = p.weak_suite_ptr_.lock();
+        if (suite.get()) {
+            the_max_modify_change_no = std::max(the_max_modify_change_no, suite->modify_change_no());
+            the_max_state_change_no  = std::max(the_max_state_change_no, suite->state_change_no());
+        }
+    }
+}
+
+void ClientSuites::suites(std::vector<std::string>& names) const {
+    names.reserve(suites_.size());
+    auto suites_end = suites_.end();
+    for (auto i = suites_.begin(); i != suites_end; ++i) {
+        names.push_back((*i).name_);
+    }
+}
+
+std::string ClientSuites::dump() const {
+    unsigned int maxstatechangeno  = 0;
+    unsigned int maxmodifychangeno = 0;
+    max_change_no(maxstatechangeno, maxmodifychangeno);
+
+    std::stringstream ss;
+    ss << "  handle(" << handle() << ") user(" << user_ << ") auto_add_new_suites(" << auto_add_new_suites_
+       << ") suites_.size(" << suites_.size() << ") suites(";
+
+    auto suites_end = suites_.end();
+    for (auto i = suites_.begin(); i != suites_end; ++i) {
+        suite_ptr suite = (*i).weak_suite_ptr_.lock();
+        if (suite.get()) {
+            ss << " " << suite->name();
+        }
+        else {
+            ss << " " << (*i).name_ << ":NULL";
+        }
+    }
+    ss << ") max(" << maxstatechangeno << "," << maxmodifychangeno << ")";
+    return ss.str();
+}
+
+void ClientSuites::update_suite_order() {
+    const std::vector<suite_ptr>& server_suite_vec = defs_->suiteVec();
+    size_t server_suite_vec_size                   = server_suite_vec.size();
+
+    auto suites_end = suites_.end();
+    for (auto i = suites_.begin(); i != suites_end; ++i) {
+        for (size_t s = 0; s < server_suite_vec_size; s++) {
+            if ((*i).name_ == server_suite_vec[s]->name()) {
+                (*i).index_ = static_cast<int>(s);
+                break;
+            }
+        }
+    }
+
+    std::sort(suites_.begin(), suites_.end(), [](const HSuite& a, const HSuite& b) { return a.index_ < b.index_; });
+}
+
+std::vector<HSuite>::iterator ClientSuites::find_suite(const std::string& name) {
+    auto suites_end = suites_.end();
+    for (auto i = suites_.begin(); i != suites_end; ++i) {
+        if ((*i).name_ == name) {
+            return i;
+        }
+    }
+    return suites_end;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ClientSuites.hpp 5.13.0-1/libs/node/src/ecflow/node/ClientSuites.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ClientSuites.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ClientSuites.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,152 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ClientSuites_HPP
+#define ecflow_node_ClientSuites_HPP
+
+///
+/// \brief The definition file could hold hundreds of suites, however the client
+/// may only be interested in a small subset. By allowing the client to register
+/// the suites they are interested in, we can reduce the network traffic
+/// when they ask for updates.(ie via sync or news)
+/// When the Client registers an interest in suites it is returned a handle,
+/// this handle must is passed back to the server as a reference, with the sync'ing commands
+///
+/// Users are allowed to register interest in suite that have not yet been added
+/// This will only work provided we have a definition
+///
+///
+/// \note Change of suite order is handled by OrderMemento
+///       and *NOT* by the ClientSuites, however whenever suites are:
+///       registered and added/deleted:
+///       then:
+///           defs_ptr create_defs(Defs* server_defs) const;
+///
+///       Will return the suites in the same order as the defs
+///
+
+#include <limits>
+#include <string>
+#include <vector>
+
+#include "ecflow/node/NodeFwd.hpp"
+
+namespace ecf {
+
+struct HSuite
+{
+    HSuite(const std::string& name, weak_suite_ptr p, int index = std::numeric_limits<int>::max())
+        : name_(name),
+          weak_suite_ptr_(p),
+          index_(index) {}
+
+    explicit HSuite(const std::string& name) : name_(name), index_(std::numeric_limits<int>::max()) {}
+
+    std::string name_;              // suite name
+    weak_suite_ptr weak_suite_ptr_; // does suite exist in defs, need to lock, to find out
+    int index_;                     // suites in handles must be in same order as defs
+};
+
+class ClientSuites {
+public:
+    /// Will automatically create a unique handle
+    ClientSuites(Defs*,
+                 unsigned int handle,
+                 bool auto_add_new_suites,
+                 const std::vector<std::string>& suites,
+                 const std::string& user);
+
+    /// Return the handle, returned to the client, and required for all correspondence
+    /// between client server. This value is always > 0
+    unsigned int handle() const { return handle_; }
+
+    /// return the user who requested this handle
+    const std::string& user() const { return user_; }
+
+    /// The handle changed flag is set to true whenever a ClinetSuites is created
+    /// or when suites are added/removed from it. The alternative way would have
+    /// been to update the modify change number, but this would have affected all handles
+    bool handle_changed() const { return handle_changed_; }
+
+    /// Add an interest to this suite
+    void add_suite(const std::string&);
+    void add_suite(suite_ptr);
+
+    /// no longer interested in this suite. Explicit remove
+    void remove_suite(const std::string&);
+    bool remove_suite(suite_ptr);
+
+    /// A new suite is being added in the definition.
+    /// If it was already registered update the suite ptr
+    /// If auto add new suite enabled,register it
+    void suite_added_in_defs(suite_ptr);
+
+    /// The suite is being deleted, update modify_change_no. So we do a full sync
+    /// RESETs suite ptr. Deleted suites are *NOT* automatically removed
+    void suite_deleted_in_defs(suite_ptr);
+
+    /// Collate the incremental changes, made to my suites
+    void collateChanges(DefsDelta& changes) const;
+
+    // Only return the defs state and suites that the client has registered in this suite
+    // *HOWEVER* if the client has registered all the suites, just return the server defs
+    //           *with* the updated change numbers
+    // *OTHERWISE*
+    /// Creates a new defs, by adding the suites to the defs
+    /// The defs is to be transferred to the client
+    /// Suites are returned in the same order as the defs
+    /// We avoid copying, but need to adjust suites defs pointer
+    /// This will clear the handle_changed_  flag
+    defs_ptr create_defs(defs_ptr server_defs) const;
+
+    // iterates overs its suites and return max state and modify change numbers
+    void max_change_no(unsigned int& state_change_no, unsigned int& modify_change_no) const;
+
+    /// Enable/disable interest in new suites.
+    /// if the flag is true, when ever new suites are added to the defs
+    /// The internal list is updated.
+    void add_new_suite(bool flag) { auto_add_new_suites_ = flag; }
+    bool auto_add_new_suites() const { return auto_add_new_suites_; }
+
+    /// returns the list of suites
+    void suites(std::vector<std::string>& names) const;
+
+    /// Update suites to be in same order as Defs.
+    /// This should be done externally to avoid update after individual add
+    void update_suite_order();
+
+    /// For debug dumps
+    std::string dump() const;
+
+private:
+    std::vector<HSuite>::iterator find_suite(const std::string& name);
+
+private:
+    Defs* defs_;
+
+    std::string user_; // user who create this handle
+    std::vector<HSuite> suites_;
+
+    unsigned int handle_; // This must be unique
+
+    // The modify_change_no_ is required specifically when a registered suite is deleted
+    // Both modify_change_no_ & state_change_no_ are required when user has registered
+    // with *ALL* the suites. In this case we need to ensure that after a SYNC/create_defs
+    // the NewsCmd call to max_change_no() is in sync with global change numbers.
+    mutable unsigned int state_change_no_{0};
+    mutable unsigned int modify_change_no_{0};
+
+    bool auto_add_new_suites_;
+    mutable bool handle_changed_{false}; // set when handle created, or when suites added/removed
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_ClientSuites_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/CmdContext.cpp 5.13.0-1/libs/node/src/ecflow/node/CmdContext.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/CmdContext.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/CmdContext.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/CmdContext.hpp"
+
+namespace ecf {
+bool CmdContext::in_command_ = false;
+
+CmdContext::CmdContext() {
+    in_command_ = true;
+}
+
+CmdContext::~CmdContext() {
+    in_command_ = false;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/CmdContext.hpp 5.13.0-1/libs/node/src/ecflow/node/CmdContext.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/CmdContext.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/CmdContext.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_CmdContext_HPP
+#define ecflow_node_CmdContext_HPP
+
+///
+/// \brief This class allow client to determine whether they are in a middle of a command.
+///
+
+namespace ecf {
+
+class CmdContext {
+public:
+    CmdContext();
+    // Disable copy (and move) semantics
+    CmdContext(const CmdContext&)                  = delete;
+    const CmdContext& operator=(const CmdContext&) = delete;
+
+    ~CmdContext();
+
+    static bool in_command() { return in_command_; }
+
+private:
+    static bool in_command_;
+};
+} // namespace ecf
+
+#endif /* ecflow_node_CmdContext_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Defs.cpp 5.13.0-1/libs/node/src/ecflow/node/Defs.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Defs.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Defs.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2156 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Defs.hpp"
+
+#include <cassert>
+#include <limits>
+#include <stdexcept>
+
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/NodePath.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/StringSplitter.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/node/AbstractObserver.hpp"
+#include "ecflow/node/DefsDelta.hpp"
+#include "ecflow/node/ExprDuplicate.hpp"
+#include "ecflow/node/JobCreationCtrl.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/NodeState.hpp"
+#include "ecflow/node/NodeStats.hpp"
+#include "ecflow/node/NodeTreeVisitor.hpp"
+#include "ecflow/node/ResolveExternsVisitor.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/move_peer.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp" /// The reason why Parser code moved into Defs, avoid cyclic dependency
+
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+using namespace ecf;
+using namespace std;
+
+// #define DEBUG_JOB_SUBMISSION 1
+// #define DEBUG_MEMENTO 1
+
+Defs::Defs() = default;
+
+Defs::Defs(const std::string& port) : server_(port) {
+}
+
+Defs::Defs(const Defs& rhs) : state_(rhs.state_), server_(rhs.server_), flag_(rhs.flag_), client_suite_mgr_(this) {
+    size_t theSize = rhs.suiteVec_.size();
+    for (size_t s = 0; s < theSize; s++) {
+        suite_ptr suite_copy = std::make_shared<Suite>(*rhs.suiteVec_[s]);
+        suite_copy->set_defs(this);
+        suiteVec_.push_back(suite_copy);
+    }
+
+    // edit history is not copied
+    // externs not copied
+    // observers not copied
+}
+
+void Defs::copy_defs_state_only(const defs_ptr& server_defs) {
+    if (!server_defs)
+        return;
+
+    // Initialise the defs state. We need to reflect the real state.
+    set_state(server_defs->state());
+
+    // initialise flag
+    flag_ = server_defs->get_flag();
+
+    // Initialise the server state
+    set_server().set_state(server_defs->server().get_state());
+    set_server().set_user_variables(server_defs->server().user_variables());
+    set_server().set_server_variables(server_defs->server().server_variables());
+}
+
+Defs& Defs::operator=(const Defs& rhs) {
+    if (this != &rhs) {
+        Defs tmp(rhs); // does *NOT* use Suite::operator=(const Suite& rhs), we use copy/swap
+
+        std::swap(state_, tmp.state_);
+        std::swap(server_, tmp.server_);
+        std::swap(suiteVec_, tmp.suiteVec_);
+        std::swap(flag_, tmp.flag_);
+
+        // edit history is not copied
+        // externs not copied
+        // observers not copied
+
+        size_t vec_size = suiteVec_.size();
+        for (size_t i = 0; i < vec_size; i++) {
+            suiteVec_[i]->set_defs(this);
+        }
+
+        modify_change_no_ = Ecf::incr_modify_change_no();
+    }
+    return *this;
+}
+
+defs_ptr Defs::create() {
+    return std::make_shared<Defs>();
+}
+defs_ptr Defs::create(const std::string& port) {
+    return std::make_shared<Defs>(port);
+} // Defs::create(port)
+
+Defs::~Defs() {
+    //    cout << "   Deleting defs "\n";
+    if (!Ecf::server()) {
+        notify_delete();
+    }
+
+    // Duplicate AST are held in a static map. Delete them, to avoid valgrind complaining
+    ExprDuplicate reclaim_cloned_ast_memory;
+}
+
+void Defs::handle_migration() {
+    // Fix up any migration issues. Remove when in Bolgna, and ecflow4 no longer used
+    for (const auto& s : suiteVec_) {
+        s->handle_migration(s->calendar());
+    }
+
+    // remove any edit history that is no longer referenced. Ignore root, which will not be found
+    auto it = edit_history_.begin();
+    while (it != edit_history_.end()) {
+
+        if ((*it).first == Str::ROOT_PATH()) {
+            it++;
+            continue; // root path is defs, which is not a node, hence ignore
+        }
+
+        node_ptr node = findAbsNode((*it).first);
+        if (!node.get()) {
+            it = edit_history_.erase(it);
+        }
+        else
+            it++;
+    }
+}
+
+///// State relation functions: ==================================================
+NState::State Defs::state() const {
+    return state_.state();
+}
+
+void Defs::set_state_only(NState::State the_new_state) {
+    state_.setState(the_new_state); // this will update state_change_no
+}
+
+void Defs::set_state(NState::State the_new_state) {
+    set_state_only(the_new_state); // this will update state_change_no
+
+    // Log the state change
+    //           " " +  submitted(max) + ": /"
+    // reserve : 1   +  9              + 3      = 13
+    std::string log_state_change;
+    log_state_change.reserve(13);
+    log_state_change += " ";
+    log_state_change += NState::toString(the_new_state);
+    log_state_change += ": /";
+    ecf::log(Log::LOG, log_state_change);
+}
+
+void Defs::set_most_significant_state() {
+    NState::State computedStateOfImmediateChildren =
+        ecf::theComputedNodeState(suiteVec_, true /* immediate children only */);
+    if (computedStateOfImmediateChildren != state_.state())
+        set_state(computedStateOfImmediateChildren);
+}
+
+/// Others ======================================================================
+void Defs::check_job_creation(job_creation_ctrl_ptr jobCtrl) {
+    /// Job generation checking. is done via the python API
+    /// As such it done directly on the Defs.
+    /// However Job generation checking will end up changing the states of the DEFS
+    /// If this defs is loaded into the server the state of each node may be surprising. (i.e submitted)
+    /// Hence we need to reset the state.
+    if (!jobCtrl.get())
+        throw std::runtime_error("Defs::check_job_creation: NULL JobCreationCtrl passed");
+
+    if (jobCtrl->verbose())
+        cout << "Defs::check_job_creation(verbose):\n";
+
+    // This function should NOT really change the data model
+    // The changed state is reset, hence we need to preserve change and modify numbers
+    EcfPreserveChangeNo preserveChangeNo;
+
+    if (jobCtrl->node_path().empty()) {
+
+        size_t theSize = suiteVec_.size();
+        for (size_t s = 0; s < theSize; s++) {
+            /// begin will cause creation of generated variables. The generated variables
+            /// are use in client scripts and used to locate the ecf files
+            suiteVec_[s]->begin();
+            suiteVec_[s]->check_job_creation(jobCtrl);
+
+            /// reset the state
+            suiteVec_[s]->reset(); // will reset begin
+            suiteVec_[s]->setStateOnlyHierarchically(NState::UNKNOWN);
+            set_most_significant_state();
+        }
+    }
+    else {
+
+        node_ptr node = findAbsNode(jobCtrl->node_path());
+        if (node.get()) {
+            /// begin will cause creation of generated variables. The generated variables
+            /// are use in client scripts and used to locate the ecf files
+            node->suite()->begin();
+            node->check_job_creation(jobCtrl);
+
+            /// reset the state
+            node->reset();
+            node->suite()->reset_begin();
+            node->setStateOnlyHierarchically(NState::UNKNOWN);
+        }
+        else {
+            std::stringstream ss;
+            ss << "Defs::check_job_creation: failed as node path '" << jobCtrl->node_path() << "' does not exist.\n";
+            jobCtrl->error_msg() = ss.str();
+        }
+    }
+}
+
+void Defs::do_generate_scripts(const std::map<std::string, std::string>& override) const {
+    size_t theSize = suiteVec_.size();
+    for (size_t s = 0; s < theSize; s++) {
+        suiteVec_[s]->generate_scripts(override);
+    }
+}
+void Defs::generate_scripts() const {
+    std::map<std::string, std::string> override;
+    do_generate_scripts(override);
+}
+
+static void remove_autocancelled(const std::vector<node_ptr>& auto_cancelled_nodes) {
+    // Permanently remove any auto-cancelled nodes.
+    if (!auto_cancelled_nodes.empty()) {
+        auto theNodeEnd = auto_cancelled_nodes.end();
+        string msg;
+        for (auto n = auto_cancelled_nodes.begin(); n != theNodeEnd; ++n) {
+            // If we have two autocancel in the hierarchy, with same attributes. Then
+            // (*n)->remove() on the second will fail( with a crash, SuiteChanged0 destructor,  no suite pointer)
+            // since it would already be detached. See ECFLOW-556
+            // By checking we can still reach the Defs we know we are not detached
+            if ((*n)->defs()) {
+                msg.clear();
+                msg = "autocancel ";
+                msg += (*n)->debugNodePath();
+                ecf::log(Log::MSG, msg);
+                (*n)->remove();
+            }
+        }
+    }
+}
+
+static void auto_archive(const std::vector<node_ptr>& auto_archive_nodes) {
+    if (!auto_archive_nodes.empty()) {
+        auto theNodeEnd = auto_archive_nodes.end();
+        for (auto n = auto_archive_nodes.begin(); n != theNodeEnd; ++n) {
+            // If we have two auto archive in the hierarchy, with same attributes. Then
+            // By checking we can still reach the Defs we know we are not detached
+            NodeContainer* nc = (*n)->isNodeContainer();
+            if (nc && nc->defs()) {
+                nc->archive();
+            }
+        }
+    }
+}
+
+void Defs::updateCalendar(const ecf::CalendarUpdateParams& calUpdateParams) {
+    // Collate any auto cancelled nodes as a result of calendar update
+    // Collate any auto archive nodes as a result of calendar update
+    Node::Calendar_args cal_args;
+
+    // updateCalendarCount_ is only used in *test*
+    updateCalendarCount_++;
+
+    size_t theSize = suiteVec_.size();
+    for (size_t s = 0; s < theSize; s++) {
+        suiteVec_[s]->updateCalendar(calUpdateParams, cal_args);
+    }
+
+    // Permanently remove any auto-cancelled nodes.
+    remove_autocancelled(cal_args.auto_cancelled_nodes_);
+
+    // Archive any nodes with auto archive attribute, Must be suite/family
+    auto_archive(cal_args.auto_archive_nodes_);
+}
+
+void Defs::update_calendar(Suite* suite, const ecf::CalendarUpdateParams& cal_update_params) {
+    // Collate any auto cancelled nodes as a result of calendar update
+    // Collate any auto archive nodes as a result of calendar update
+    Node::Calendar_args cal_args;
+
+    suite->updateCalendar(cal_update_params, cal_args);
+
+    // Permanently remove any auto-cancelled nodes.
+    remove_autocancelled(cal_args.auto_cancelled_nodes_);
+
+    // Archive any nodes with auto archive attribute, Must be suite/family
+    auto_archive(cal_args.auto_archive_nodes_);
+}
+
+bool Defs::catch_up_to_real_time() {
+    auto time_now = Calendar::second_clock_time();
+
+    //   cout << "Time Now: " << to_simple_string(time_now) << "\n";
+    //   for(const auto& suite : suiteVec_)  cout << suite->calendar().toString() << "\n";
+    //   cout << "===================================================================\n";
+    bool updated = false;
+    time_duration schedule_increment(0, 0, server_.jobSubmissionInterval(), 0);
+    for (const auto& suite : suiteVec_) {
+        // Check if suite has time,today,date,day,cron,late,autocancel,autoarchive attributes
+        if (suite->has_time_based_attributes()) {
+            auto suite_time = suite->calendar().suiteTime();
+            if (time_now - suite_time <= hours(1)) {
+                suite_time += schedule_increment;
+                while (suite_time <= time_now) {
+
+                    update_calendar(suite.get(), ecf::CalendarUpdateParams(suite_time, schedule_increment, true));
+
+                    // cout << suite->name() << " : " << suite->calendar().toString() << "\n";
+                    suite_time += schedule_increment;
+                    updated = true;
+                }
+            }
+        }
+    }
+    //   cout << "===================================================================\n";
+    //   for(const auto& suite : suiteVec_)  cout << suite->calendar().toString() << "\n";
+    return updated;
+}
+
+void Defs::absorb(Defs* input_defs, bool force) {
+    // Dont absorb myself.
+    if (input_defs == this) {
+        return;
+    }
+
+    // updateCalendarCount_ is *only* used in test, reset whenever a new defs is loaded
+    updateCalendarCount_ = 0;
+
+    // We must make a copy, otherwise we are iterating over a vector that is being deleted
+    std::vector<suite_ptr> suiteVecCopy = input_defs->suiteVec();
+    size_t theSize                      = suiteVecCopy.size();
+    for (size_t s = 0; s < theSize; s++) {
+
+        /// regardless remove the suite from the input defs
+        suite_ptr the_input_suite = input_defs->removeSuite(suiteVecCopy[s]);
+
+        if (force) {
+            /// The suite of the same name exists. remove it from *existing* defs
+            suite_ptr existing_suite = findSuite(the_input_suite->name());
+            if (existing_suite.get()) {
+                removeSuite(existing_suite);
+            }
+        }
+
+        /// Add the suite. Will throw if suite of same name already exists.
+        /// This stops accidental overwrite
+        addSuite(the_input_suite);
+    }
+    LOG_ASSERT(input_defs->suiteVec().empty(), "Defs::absorb");
+
+    // Copy over server user variables
+    set_server().add_or_update_user_variables(input_defs->server().user_variables());
+
+    // This only works on the client side. since server does not store externs
+    const set<string>& ex = input_defs->externs();
+    for (const auto& i : ex) {
+        add_extern(i);
+    }
+}
+
+void Defs::accept(ecf::NodeTreeVisitor& v) {
+    v.visitDefs(this);
+    size_t theSuiteVecSize = suiteVec_.size();
+    for (size_t i = 0; i < theSuiteVecSize; i++) {
+        suiteVec_[i]->accept(v);
+    }
+}
+
+void Defs::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
+    LOG_ASSERT(v.traverseObjectStructureViaVisitors(), "");
+    v.visitDefs(this);
+}
+
+bool Defs::verification(std::string& errorMsg) const {
+    size_t theSuiteVecSize = suiteVec_.size();
+    for (size_t i = 0; i < theSuiteVecSize; i++) {
+        suiteVec_[i]->verification(errorMsg);
+    }
+    return errorMsg.empty();
+}
+
+suite_ptr Defs::add_suite(const std::string& name) {
+    if (findSuite(name).get()) {
+        std::stringstream ss;
+        ss << "Add Suite failed: A Suite of name '" << name << "' already exists";
+        throw std::runtime_error(ss.str());
+    }
+    suite_ptr the_suite = Suite::create(name);
+    add_suite_only(the_suite, std::numeric_limits<std::size_t>::max());
+    return the_suite;
+}
+
+void Defs::addSuite(const suite_ptr& s, size_t position) {
+    if (findSuite(s->name()).get()) {
+        std::stringstream ss;
+        ss << "Add Suite failed: A Suite of name '" << s->name() << "' already exists";
+        throw std::runtime_error(ss.str());
+    }
+    add_suite_only(s, position);
+}
+
+void Defs::add_suite_only(const suite_ptr& s, size_t position) {
+    if (s->defs()) {
+        std::stringstream ss;
+        ss << "Add Suite failed: The suite of name '" << s->name() << "' already owned by another Defs ";
+        throw std::runtime_error(ss.str());
+    }
+
+    s->set_defs(this);
+    if (position >= suiteVec_.size()) {
+        suiteVec_.push_back(s);
+    }
+    else {
+        suiteVec_.insert(suiteVec_.begin() + position, s);
+    }
+    Ecf::incr_modify_change_no();
+    client_suite_mgr_.suite_added_in_defs(s);
+}
+
+suite_ptr Defs::removeSuite(suite_ptr s) {
+    auto i = std::find(suiteVec_.begin(), suiteVec_.end(), s);
+    if (i != suiteVec_.end()) {
+        s->set_defs(nullptr); // allows suite to added to different defs
+        suiteVec_.erase(i);   // iterator invalidated
+        Ecf::incr_modify_change_no();
+        client_suite_mgr_.suite_deleted_in_defs(s); // must be after Ecf::incr_modify_change_no();
+        return s;                                   // transfer ownership of suite
+    }
+
+    // Something serious has gone wrong. Cannot find the suite
+    cout << "Defs::removeSuite: assert failure:  suite '" << s->name() << "' suiteVec_.size() = " << suiteVec_.size()
+         << "\n";
+    for (unsigned si = 0; si < suiteVec_.size(); ++si) {
+        cout << si << " " << suiteVec_[si]->name() << "\n";
+    }
+    LOG_ASSERT(false, "Defs::removeSuite the suite not found");
+    return suite_ptr();
+}
+
+size_t Defs::child_position(const Node* child) const {
+    size_t vecSize = suiteVec_.size();
+    for (size_t t = 0; t < vecSize; t++) {
+        if (suiteVec_[t].get() == child) {
+            return t;
+        }
+    }
+    return std::numeric_limits<std::size_t>::max();
+}
+
+node_ptr Defs::removeChild(Node* child) {
+    size_t vecSize = suiteVec_.size();
+    for (size_t t = 0; t < vecSize; t++) {
+        if (suiteVec_[t].get() == child) {
+            Ecf::incr_modify_change_no();
+            suiteVec_[t]->set_defs(nullptr); // Must be set to NULL, allows suite to be added to different defs
+            client_suite_mgr_.suite_deleted_in_defs(suiteVec_[t]); // must be after Ecf::incr_modify_change_no();
+            node_ptr node = std::dynamic_pointer_cast<Node>(suiteVec_[t]);
+            suiteVec_.erase(suiteVec_.begin() + t);
+            return node;
+        }
+    }
+
+    // Something has gone wrong.
+    cout << "Defs::removeChild: assert failed:  suite '" << child->name() << "' suiteVec_.size() = " << suiteVec_.size()
+         << "\n";
+    for (unsigned i = 0; i < suiteVec_.size(); ++i) {
+        cout << i << " " << suiteVec_[i]->name() << "\n";
+    }
+    LOG_ASSERT(false, "Defs::removeChild,the suite not found");
+    return node_ptr();
+}
+
+bool Defs::addChild(const node_ptr& child, size_t position) {
+    LOG_ASSERT(child.get(), "");
+    LOG_ASSERT(child->isSuite(), "");
+
+    // *** CANT construct shared_ptr from a raw pointer, must use dynamic_pointer_cast,
+    // *** otherwise the reference counts will get messed up.
+    // If the suite of the same exists, it is deleted first
+    addSuite(std::dynamic_pointer_cast<Suite>(child), position);
+    return true;
+}
+
+void Defs::add_extern(const std::string& ex) {
+    if (ex.empty()) {
+        throw std::runtime_error("Defs::add_extern: Cannot add empty extern");
+    }
+    externs_.insert(ex);
+    // auto result = externs_.insert(ex);
+    // cout << "Defs::add_extern " << ex << " result " << result.second << "\n";
+}
+
+void Defs::auto_add_externs(bool remove_existing_externs_first) {
+    // cout << "\nDefs::auto_add_externs START EXTERNS size: " << externs_.size() << "
+    // ==================================================== \n";
+    if (remove_existing_externs_first) {
+        externs_.clear();
+    }
+    /// Automatically add externs
+    ResolveExternsVisitor visitor(this);
+    acceptVisitTraversor(visitor);
+    // cout << "Defs::auto_add_externs END EXTERNS size : " << externs_.size() << "
+    // ==================================================== \n";
+}
+
+void Defs::beginSuite(const suite_ptr& suite) {
+    if (!suite.get())
+        throw std::runtime_error("Defs::beginSuite: Begin failed as suite is not loaded");
+
+    if (!suite->begun()) {
+        // Hierarchical set the state. Handle case where we have children that are all defstatus complete
+        // and hence needs parent set to complete. See Simulator/good_defs/operations/naw.def
+        //	  family naw
+        //	    family general
+        //	      time 06:00
+        //	      task metgrams
+        //	        defstatus complete
+        //	      task equipot
+        //	        defstatus complete
+        //	    endfamily
+        suite->begin();
+
+        set_most_significant_state();
+    }
+    else {
+        LOG(Log::WAR, "Suite " << suite->name() << " has already begun");
+    }
+}
+
+void Defs::beginAll() {
+    bool at_least_one_suite_begun = false;
+    size_t theSuiteVecSize        = suiteVec_.size();
+    for (size_t s = 0; s < theSuiteVecSize; s++) {
+        if (!suiteVec_[s]->begun()) {
+            suiteVec_[s]->begin();
+            at_least_one_suite_begun = true;
+        }
+    }
+
+    if (at_least_one_suite_begun) {
+        set_most_significant_state();
+    }
+}
+
+void Defs::reset_begin() {
+    std::for_each(suiteVec_.begin(), suiteVec_.end(), [](suite_ptr s) { s->reset_begin(); });
+}
+
+void Defs::requeue() {
+    bool edit_history_set = flag().is_set(ecf::Flag::MESSAGE);
+    flag_.reset();
+    if (edit_history_set)
+        flag().set(ecf::Flag::MESSAGE);
+
+    Node::Requeue_args args;
+    size_t theSuiteVecSize = suiteVec_.size();
+    for (size_t s = 0; s < theSuiteVecSize; s++) {
+        suiteVec_[s]->requeue(args);
+    }
+
+    set_most_significant_state();
+}
+
+void Defs::sort_attributes(ecf::Attr::Type attr, bool recursive, const std::vector<std::string>& no_sort) {
+    if (attr == ecf::Attr::VARIABLE || attr == ecf::Attr::ALL)
+        server_.sort_variables();
+
+    if (recursive) {
+        size_t theSuiteVecSize = suiteVec_.size();
+        for (size_t s = 0; s < theSuiteVecSize; s++) {
+            SuiteChanged changed(suiteVec_[s]);
+            suiteVec_[s]->sort_attributes(attr, recursive, no_sort);
+        }
+    }
+}
+
+void Defs::check_suite_can_begin(const suite_ptr& suite) const {
+    NState::State suiteState = suite->state();
+    if (!suite->begun() && suiteState != NState::UNKNOWN && suiteState != NState::COMPLETE) {
+        int count = 0;
+        std::vector<Task*> tasks;
+        getAllTasks(tasks);
+        std::stringstream ts;
+        for (auto& task : tasks) {
+            if (task->state() == NState::ACTIVE || task->state() == NState::SUBMITTED) {
+                ts << "   " << task->absNodePath() << "\n";
+                count++;
+            }
+        }
+        /// allow suite to begin even its aborted provide no tasks in active or submitted states
+        if (count > 0) {
+            std::stringstream ss;
+            ss << "Begin failed as suite " << suite->name() << "(computed state=" << NState::toString(suiteState)
+               << ") can only begin if its in UNKNOWN or COMPLETE state\n";
+            ss << "Found " << count << " tasks with state 'active' or 'submitted'\n";
+            ss << ts.str();
+            ss << "Use the force argument to bypass this check, at the risk of creating zombies\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+}
+
+bool Defs::hasTimeDependencies() const {
+    size_t theSuiteVecSize = suiteVec_.size();
+    for (size_t s = 0; s < theSuiteVecSize; s++) {
+        if (suiteVec_[s]->hasTimeDependencies())
+            return true;
+    }
+    return false;
+}
+
+std::string Defs::print(PrintStyle::Type_t t) const {
+    PrintStyle style(t);
+    std::string s;
+    print(s);
+    return s;
+}
+
+void Defs::print(std::string& os) const {
+    // cout << "Defs::print(start) print_cache_ " << print_cache_ << "\n";
+    os.clear();
+    if (print_cache_ != 0)
+        os.reserve(print_cache_);
+    else
+        os.reserve(4096);
+    os += "#";
+    os += ecf::Version::raw();
+    os += "\n";
+
+    if (!PrintStyle::defsStyle())
+        write_state(os);
+
+    if (PrintStyle::getStyle() == PrintStyle::STATE) {
+        os += "# server state: ";
+        os += SState::to_string(server().get_state());
+        os += "\n";
+    }
+
+    // In PrintStyle::MIGRATE we do NOT persist the externs. (+matches boost serialisation)
+    if (!PrintStyle::persist_style()) {
+        auto extern_end = externs_.end();
+        for (auto i = externs_.begin(); i != extern_end; ++i) {
+            os += "extern ";
+            os += *i;
+            os += "\n";
+        }
+    }
+
+    for (const auto& s : suiteVec_) {
+        s->print(os);
+    }
+
+    os += "# enddef\n"; // ECFLOW-1227 so user knows there was no truncation
+    print_cache_ = os.size();
+    // cout << "Defs::print print_cache_ " << print_cache_ << "\n";
+}
+
+void Defs::write_state(std::string& os) const {
+    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e.
+    //                 task a; task b;
+    // *IMPORTANT* make sure name are unique, i.e can't have state: and server_state:
+    // Otherwise read_state() will mess up
+    os += "defs_state ";
+    os += PrintStyle::to_string();
+
+    if (state_ != NState::UNKNOWN) {
+        os += " state>:";
+        os += NState::toString(state_);
+    } // make <state> is unique
+    if (flag_.flag() != 0) {
+        os += " flag:";
+        flag_.write(os);
+    }
+    if (state_change_no_ != 0) {
+        os += " state_change:";
+        os += ecf::convert_to<std::string>(state_change_no_);
+    }
+    if (modify_change_no_ != 0) {
+        os += " modify_change:";
+        os += ecf::convert_to<std::string>(modify_change_no_);
+    }
+    if (server().get_state() != ServerState::default_state()) {
+        os += " server_state:";
+        os += SState::to_string(server().get_state());
+    }
+
+    // This only works when the full defs is requested, otherwise zero as defs is fabricated for handles
+    os += " cal_count:";
+    os += ecf::convert_to<std::string>(updateCalendarCount_);
+    os += "\n";
+
+    // This read by the DefsParser
+    const std::vector<Variable>& server_user_variables = server().user_variables();
+    size_t the_size                                    = server_user_variables.size();
+    for (size_t i = 0; i < the_size; ++i)
+        server_user_variables[i].print(os);
+
+    const std::vector<Variable>& server_variables = server().server_variables();
+    the_size                                      = server_variables.size();
+    for (size_t i = 0; i < the_size; ++i)
+        server_variables[i].print_server_variable(os); // edit var value # server
+
+    // READ by Defs::read_history()
+    // We need to define a separator for the message, will to allow it to be re-read
+    // This separator cannot be :
+    // ' ' space, used in the messages
+    // %  Used in job submission
+    // :  Used in time, and name (:ma0)
+    // [] Used in time
+    // integers used in the time.
+    // -  Used in commands
+    if (save_edit_history_) {
+        Indentor in;
+        for (const auto& i : edit_history_) {
+            Indentor::indent(os);
+            os += "history ";
+            os += i.first;
+            os += " ";                                      // node path
+            const std::vector<std::string>& vec = i.second; // list of requests
+            for (const auto& c : vec) {
+
+                // We expect to output a single newline, hence if there are additional new lines
+                // It can mess  up, re-parse. i.e during alter change label/value, user could have added newlines
+                if (c.find("\n") == std::string::npos) {
+                    os += "\b";
+                    os += c;
+                }
+                else {
+                    std::string h = c;
+                    Str::replaceall(h, "\n", "\\n");
+                    os += "\b";
+                    os += h;
+                }
+            }
+            os += "\n";
+        }
+        save_edit_history_ = false;
+    }
+}
+
+std::string Defs::dump_edit_history() const {
+    std::stringstream os;
+    for (const auto& i : edit_history_) {
+        os << "history ";
+        os << i.first;
+        os << "  ";                                     // node path
+        const std::vector<std::string>& vec = i.second; // list of requests
+        for (const auto& c : vec) {
+
+            // We expect to output a single newline, hence if there are additional new lines
+            // It can mess  up, re-parse. i.e during alter change label/value, user could have added newlines
+            if (c.find("\n") == std::string::npos) {
+                os << " ";
+                os << c;
+            }
+            else {
+                std::string h = c;
+                Str::replaceall(h, "\n", "\\n");
+                os << " ";
+                os << h;
+            }
+        }
+        os << "\n";
+    }
+    return os.str();
+}
+
+void Defs::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
+    //   cout << "line = " << line << "\n";
+    std::string token;
+    size_t line_tokens_size = lineTokens.size();
+    for (size_t i = 2; i < line_tokens_size; i++) {
+        token.clear();
+        const std::string& line_token_i = lineTokens[i];
+        if (line_token_i.find("state>:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Defs::read_state: state extraction failed : " + line_token_i);
+            std::pair<NState::State, bool> state_pair = NState::to_state(token);
+            if (!state_pair.second)
+                throw std::runtime_error("Defs::read_state: Invalid state specified : " + token);
+            set_state_only(state_pair.first);
+        }
+        else if (line_token_i.find("flag:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Defs::read_state: Invalid flag specified : " + line);
+            flag().set_flag(token); // this can throw
+        }
+        else if (line_token_i.find("state_change:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Defs::read_state: Invalid state_change specified : " + line);
+            int sc = Extract::theInt(token, "Defs::read_state: invalid state_change specified : " + line);
+            set_state_change_no(sc);
+        }
+        else if (line_token_i.find("modify_change:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Defs::read_state: Invalid modify_change specified : " + line);
+            int mc = Extract::theInt(token, "Defs::read_state: invalid state_change specified : " + line);
+            set_modify_change_no(mc);
+        }
+        else if (line_token_i.find("server_state:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Defs::read_state: Invalid server_state specified : " + line);
+            if (!SState::isValid(token))
+                throw std::runtime_error("Defs::read_state: Invalid server_state specified : " + line);
+            set_server().set_state(SState::toState(token));
+        }
+        else if (line_token_i.find("cal_count:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Defs::read_state: Invalid cal_count specified : " + line);
+            updateCalendarCount_ = Extract::theInt(token, "Defs::read_state: invalid cal_count specified : " + line);
+        }
+    }
+}
+
+void Defs::read_history(const std::string& line, const std::vector<std::string>& lineTokens) {
+    // expect:
+    // history <node_path> \bmsg1\bmsg2
+    // The message can contain spaces,
+    // Multiple spaces will be lost !!
+    // Edit history older than ecf_prune_node_log_ days, will be pruned.
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("Defs::read_history: Invalid history " + line);
+
+    DefsHistoryParser parser;
+    parser.parse(line);
+
+    const std::vector<std::string>& parsed_messages = parser.parsed_messages();
+    if (ecf_prune_node_log_ == 0) {
+        for (const auto& parsed_message : parsed_messages) {
+            add_edit_history(lineTokens[1], parsed_message);
+        }
+    }
+    else {
+        std::vector<std::string> vec;
+        date todays_date_in_utc = day_clock::universal_day();
+
+        for (const auto& parsed_message : parsed_messages) {
+            // extract the date, expecting MSG:[HH:MM:SS D.M.YYYY]
+            if (parsed_message.find("MSG:[") == 0) {
+
+                size_t space_pos = parsed_message.find(" ");
+                size_t close_p   = parsed_message.find("]");
+                std::string date = parsed_message.substr(space_pos + 1, close_p - space_pos - 1);
+                vec.clear();
+                Str::split(date, vec, ".");
+                if (vec.size() == 3) {
+                    try {
+                        int day   = ecf::convert_to<int>(vec[0]);
+                        int month = ecf::convert_to<int>(vec[1]);
+                        int year  = ecf::convert_to<int>(vec[2]);
+
+                        boost::gregorian::date node_log_date(year, month, day);
+                        boost::gregorian::date_duration duration = todays_date_in_utc - node_log_date;
+                        if (duration.days() > ecf_prune_node_log_) {
+                            continue;
+                        }
+                    }
+                    catch (...) {
+                    }
+                }
+            }
+            add_edit_history(lineTokens[1], parsed_message);
+        }
+    }
+}
+
+bool Defs::compare_edit_history(const Defs& rhs) const {
+    if (edit_history_ != rhs.edit_history_)
+        return false;
+    return true;
+}
+
+bool Defs::compare_change_no(const Defs& rhs) const {
+    if (state_change_no_ != rhs.state_change_no_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Defs::compare_change_no: state_change_no_(" << state_change_no_
+                      << ") != rhs.state_change_no_(" << rhs.state_change_no_ << ")\n";
+        }
+#endif
+        return false;
+    }
+    if (modify_change_no_ != rhs.modify_change_no_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Defs::compare_change_no: modify_change_no_(" << modify_change_no_
+                      << ") != rhs.modify_change_no_(" << rhs.modify_change_no_ << ")\n";
+        }
+#endif
+        return false;
+    }
+    return true;
+}
+
+bool Defs::operator==(const Defs& rhs) const {
+    if (state() != rhs.state()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Defs::operator==  state(" << NState::toString(state()) << ") != rhs.state("
+                      << NState::toString(rhs.state()) << ")) \n";
+        }
+#endif
+        return false;
+    }
+
+    if (server_ != rhs.server()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Defs::operator== server_ != rhs.server())\n";
+        }
+#endif
+        return false;
+    }
+
+    if (flag_ != rhs.flag_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Defs::operator== ( flag_ != rhs.flag_) : '" << flag_.to_string() << "' != '"
+                      << rhs.flag_.to_string() << "'\n";
+        }
+#endif
+        return false;
+    }
+
+    /// Note:: WE specifically exclude testing of externs.
+    /// Externs are not persisted, hence cannot take part in comparison
+    /// Externs only live on the client side.
+
+    if (suiteVec_.size() != rhs.suiteVec_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Defs::operator==    suiteVec_.size(" << suiteVec_.size() << ") != rhs.suiteVec_.size( "
+                      << rhs.suiteVec_.size() << ") \n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < suiteVec_.size(); ++i) {
+        if (!(*(suiteVec_[i]) == *(rhs.suiteVec_[i]))) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Defs::operator==    !( *(suiteVec_[i]) == *(rhs.suiteVec_[i]) )\n";
+            }
+#endif
+            return false;
+        }
+    }
+    return true;
+}
+
+node_ptr Defs::findAbsNode(const std::string& pathToNode) const {
+    //	std::cout << "Defs::findAbsNode " << pathToNode << "\n";
+    // The pathToNode is of the form:
+    //     /suite
+    //     /suite/family
+    //     /suite/family/task
+    //     /suite/family/family/family/task
+    // This is 14% quicker than the previous algorithm, that split 'pathToNode' into a vector of strings first.
+    node_ptr ret;
+    bool first = false;
+    StringSplitter string_splitter(pathToNode, Str::PATH_SEPERATOR());
+    while (!string_splitter.finished()) {
+        std::string_view path_token = string_splitter.next();
+        // std::cout << "path_token:'" << path_token << "'  last = " << string_splitter.last() << "\n";
+        if (!first) {
+            for (const auto& suite : suiteVec_) {
+                if (path_token == suite->name()) {
+                    ret = suite;
+                    if (string_splitter.last()) {
+                        // cout << "finished returning " << ret->absNodePath() << " *last* suite found\n";
+                        return ret;
+                    }
+                    break;
+                }
+            }
+            if (!ret) {
+                // cout << "finished returning suite not found\n";
+                return node_ptr();
+            }
+            first = true;
+        }
+        else {
+            // cout << "seraching from " << ret->absNodePath() << " for " << ref << "\n";
+            ret = ret->find_immediate_child(path_token);
+            if (ret) {
+                if (string_splitter.last()) {
+                    // cout << "finished returning " << ret->absNodePath() << " *last* \n";
+                    return ret;
+                }
+                continue;
+            }
+            // cout << "finished returning node not found\n";
+            return node_ptr();
+        }
+    }
+    // cout << "finished returning node not found, end of loop\n";
+    return node_ptr();
+
+    // OLD code, slower. Since we are creating a vector of strings
+    //	std::vector<std::string> theNodeNames; theNodeNames.reserve(4);
+    //	NodePath::split(pathToNode,theNodeNames);
+    //	if ( theNodeNames.empty() ) {
+    //		return node_ptr();
+    //	}
+    //	size_t child_pos = 0 ; // unused
+    //	size_t pathSize = theNodeNames.size();
+    //	size_t theSuiteVecSize = suiteVec_.size();
+    //	for(size_t s = 0; s < theSuiteVecSize; s++)  {
+    //		size_t index = 0;
+    //		if (theNodeNames[index] == suiteVec_[s]->name()) {
+    //			node_ptr the_node = suiteVec_[s];
+    //			if (pathSize == 1) return the_node;
+    //			index++; // skip over suite,
+    //			while (index < pathSize) {
+    //				the_node = the_node->findImmediateChild(theNodeNames[index],child_pos);
+    //				if (the_node) {
+    //					if (index == pathSize - 1) return the_node;
+    //					index++;
+    //				}
+    //				else {
+    //					return node_ptr();
+    //				}
+    //			}
+    //			return node_ptr();
+    //		}
+    //	}
+    //	return node_ptr();
+}
+
+node_ptr Defs::find_closest_matching_node(const std::string& pathToNode) const {
+    std::vector<std::string> theNodeNames;
+    NodePath::split(pathToNode, theNodeNames);
+    if (theNodeNames.empty())
+        return node_ptr();
+
+    node_ptr closest_matching_node;
+    int index              = 0;
+    size_t theSuiteVecSize = suiteVec_.size();
+    for (size_t s = 0; s < theSuiteVecSize; s++) {
+        suiteVec_[s]->find_closest_matching_node(theNodeNames, index, closest_matching_node);
+        if (closest_matching_node.get())
+            return closest_matching_node;
+    }
+    return node_ptr();
+}
+
+bool Defs::find_extern(const std::string& pathToNode, const std::string& node_attr_name) const {
+    if (externs_.empty()) {
+        return false;
+    }
+
+    if (node_attr_name.empty()) {
+        if (externs_.find(pathToNode) != externs_.end()) {
+            return true;
+        }
+        return false;
+    }
+
+    std::string extern_path = pathToNode;
+    extern_path += Str::COLON();
+    extern_path += node_attr_name;
+
+    if (externs_.find(extern_path) != externs_.end()) {
+        return true;
+    }
+    return false;
+}
+
+suite_ptr Defs::findSuite(const std::string& name) const {
+    for (const auto& s : suiteVec_) {
+        if (s->name() == name) {
+            return s;
+        }
+    }
+    return suite_ptr();
+}
+
+std::string Defs::find_node_path(const std::string& type, const std::string& name) const {
+    for (const auto& s : suiteVec_) {
+        std::string res = s->find_node_path(type, name);
+        if (!res.empty())
+            return res;
+    }
+    return string();
+}
+
+node_ptr Defs::find_node(const std::string& type, const std::string& pathToNode) const {
+    // std::cout << "Defs::find_node  type:" << type << " path: " << pathToNode << "\n";
+    node_ptr node_p = findAbsNode(pathToNode);
+    if (!node_p) {
+        // std::cout << " node not found\n";
+        return node_p;
+    }
+
+    if (Str::caseInsCompare(type, "task")) {
+        if (node_p->isTask())
+            return node_p;
+        return node_ptr();
+    }
+    if (Str::caseInsCompare(type, "family")) {
+        if (node_p->isFamily())
+            return node_p;
+        return node_ptr();
+    }
+    if (Str::caseInsCompare(type, "suite")) {
+        if (node_p->suite())
+            return node_p;
+        return node_ptr();
+    }
+
+    throw std::runtime_error("Defs::find_node: Node of type can't be found " + type);
+    return node_ptr();
+}
+
+bool Defs::check(std::string& errorMsg, std::string& warningMsg) const {
+    for (const auto& s : suiteVec_) {
+        s->check(errorMsg, warningMsg);
+    }
+    return errorMsg.empty();
+}
+
+void Defs::getAllTasks(std::vector<Task*>& tasks) const {
+    for (const auto& s : suiteVec_) {
+        s->getAllTasks(tasks);
+    }
+}
+
+void Defs::getAllSubmittables(std::vector<Submittable*>& tasks) const {
+    for (const auto& s : suiteVec_) {
+        s->getAllSubmittables(tasks);
+    }
+}
+
+void Defs::get_all_active_submittables(std::vector<Submittable*>& tasks) const {
+    for (const auto& s : suiteVec_) {
+        s->get_all_active_submittables(tasks);
+    }
+}
+
+void Defs::get_all_tasks(std::vector<task_ptr>& tasks) const {
+    for (const auto& s : suiteVec_) {
+        s->get_all_tasks(tasks);
+    }
+}
+
+void Defs::get_all_nodes(std::vector<node_ptr>& nodes) const {
+    for (const auto& s : suiteVec_) {
+        s->get_all_nodes(nodes);
+    }
+}
+
+void Defs::get_all_aliases(std::vector<alias_ptr>& aliases) const {
+    for (const auto& s : suiteVec_) {
+        s->get_all_aliases(aliases);
+    }
+}
+
+void Defs::getAllFamilies(std::vector<Family*>& vec) const {
+    for (const auto& s : suiteVec_) {
+        s->getAllFamilies(vec);
+    }
+}
+
+void Defs::getAllNodes(std::vector<Node*>& vec) const {
+    vec.reserve(vec.size() + suiteVec_.size());
+    for (const auto& s : suiteVec_) {
+        vec.push_back(s.get());
+        s->getAllNodes(vec);
+    }
+}
+
+void Defs::getAllAstNodes(std::set<Node*>& theSet) const {
+    for (const auto& s : suiteVec_) {
+        s->getAllAstNodes(theSet);
+    }
+}
+
+bool Defs::deleteChild(Node* nodeToBeDeleted) {
+    // Find node and children of the node to be deleted and remove them from node history
+    remove_edit_history(nodeToBeDeleted);
+
+    Node* parent = nodeToBeDeleted->parent();
+    if (parent)
+        return parent->doDeleteChild(nodeToBeDeleted);
+    return doDeleteChild(nodeToBeDeleted);
+}
+
+bool Defs::doDeleteChild(Node* nodeToBeDeleted) {
+    //	std::cout << "Defs::doDeleteChild nodeToBeDeleted   = " << nodeToBeDeleted->debugNodePath() << "\n";
+
+    auto theSuiteEnd = suiteVec_.end();
+    for (auto s = suiteVec_.begin(); s != theSuiteEnd; ++s) {
+        if ((*s).get() == nodeToBeDeleted) {
+            Ecf::incr_modify_change_no();
+
+            // Remove any child archived file
+            (*s)->remove_archived_files();
+
+            client_suite_mgr_.suite_deleted_in_defs(*s); // must be after Ecf::incr_modify_change_no();
+            (*s)->set_defs(nullptr);                     // Must be set to NULL, allows re-added to a different defs
+            suiteVec_.erase(s);
+            set_most_significant_state(); // must be after suiteVec_.erase(s);
+            return true;
+        }
+    }
+
+    // recurse down only if we did not remove the suite
+    for (auto s = suiteVec_.begin(); s != theSuiteEnd; ++s) {
+        // SuiteChanged is called within doDeleteChild
+        if ((*s)->doDeleteChild(nodeToBeDeleted)) {
+            return true;
+        }
+    }
+    return false;
+}
+
+void Defs::invalidate_trigger_references() const {
+    for (const auto& s : suiteVec_) {
+        s->invalidate_trigger_references();
+    }
+}
+
+node_ptr Defs::replaceChild(const std::string& path,
+                            const defs_ptr& clientDefs,
+                            bool createNodesAsNeeded,
+                            bool force,
+                            std::string& errorMsg) {
+    node_ptr clientNode = clientDefs->findAbsNode(path);
+    if (!clientNode.get()) {
+        errorMsg = "Cannot replace node since path ";
+        errorMsg += path;
+        errorMsg += " does not exist on the client definition";
+        return node_ptr();
+    }
+
+    node_ptr serverNode = findAbsNode(path);
+    if (!force && serverNode.get()) {
+        // Check if serverNode has child tasks in submitted or active states
+        vector<Task*> taskVec;
+        serverNode->getAllTasks(taskVec); // taskVec will be empty if serverNode is a task
+        int count = 0;
+        for (Task* t : taskVec) {
+            if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED)
+                count++;
+        }
+        if (count != 0) {
+            std::stringstream ss;
+            ss << "Cannot replace node " << serverNode->debugNodePath() << " because it has " << count
+               << " tasks which are active or submitted\n";
+            ss << "Please use the 'force' option to bypass this check, at the expense of creating zombies\n";
+            errorMsg = ss.str();
+            return node_ptr();
+        }
+    }
+
+    /// REPLACE ===========================================================
+    if (!createNodesAsNeeded || serverNode.get()) {
+        // Then the child must exist in the server defs (i.e. this)
+        if (!serverNode.get()) {
+            errorMsg = "Cannot replace child since path ";
+            errorMsg += path;
+            errorMsg += " does not exist on the server definition. Please use <parent> option";
+            return node_ptr();
+        }
+
+        invalidate_trigger_references();
+
+        // HAVE a FULL match in the server
+
+        // Take a note of begun status, in case the suite is being replaced.
+        bool begin_node = serverNode->suite()->begun();
+
+        // Preserver suspended states, otherwise preserve state of client node
+        if (serverNode->isSuspended())
+            clientNode->suspend();
+
+        std::vector<node_ptr> all_server_node_children;
+        serverNode->allChildren(all_server_node_children);
+        for (auto& i : all_server_node_children) {
+            if (i->isSuspended()) {
+                node_ptr client_node = clientDefs->findAbsNode(i->absNodePath());
+                if (client_node)
+                    client_node->suspend();
+            }
+        }
+
+        // Find the position of the server node relative to its peers
+        // We use this to re-add client node at the same position
+        size_t child_pos = serverNode->position();
+
+        // Delete node on the server, Must recurse down
+        Node* parentNodeOnServer = serverNode->parent();
+        deleteChild(serverNode.get());
+
+        // Remove reference in the client defs to clientNode and detach from its parent
+        // transfer ownership to the server
+        bool addOk                  = false;
+        node_ptr client_node_to_add = clientNode->remove();
+        if (parentNodeOnServer)
+            addOk = parentNodeOnServer->addChild(client_node_to_add, child_pos);
+        else
+            addOk = addChild(client_node_to_add, child_pos);
+        LOG_ASSERT(addOk, "");
+
+        // preserve begun status. Note: we should't call begin() on the client side. As the suites will not have been
+        // begun. This can cause assert, because begin time attributes assumes that calendar has been initialised. This
+        // is not the case for client ASSERT failure: !c.suiteTime().is_special() at ../ACore/src/TimeSeries.cpp:526
+        // init has not been called on calendar. TimeSeries::duration ECFLOW-1612
+        if (begin_node)
+            client_node_to_add->begin();
+
+        client_node_to_add->set_most_significant_state_up_node_tree();
+        return client_node_to_add;
+    }
+
+    invalidate_trigger_references();
+
+    // ADD ======================================================================
+    // Create/Add nodes as needed for a *PARTIAL* match
+    // If the path is /a/b/c/d/e/f it may be that path /a/b already exists
+    // hence we need only create the missing nodes   c, d, e, f
+    LOG_ASSERT(serverNode == nullptr, "");
+    node_ptr server_parent;
+    Node* last_client_child = clientNode.get(); // remember the last child
+    Node* client_parent     = clientNode->parent();
+    while (client_parent) {
+        server_parent = findAbsNode(client_parent->absNodePath());
+        if (server_parent) {
+            break;
+        }
+        last_client_child = client_parent;
+        client_parent     = client_parent->parent();
+    }
+    if (server_parent.get() == nullptr) {
+        // NOT EVEN A PARTIAL path match, hence move over WHOLE suite, detach from client and add to server
+        node_ptr client_suite_to_add = clientNode->suite()->remove();
+        bool addOk                   = addChild(client_suite_to_add);
+        LOG_ASSERT(addOk, "");
+
+        client_suite_to_add->set_most_significant_state_up_node_tree();
+        return client_suite_to_add;
+    }
+    if (server_parent->isTask()) {
+        errorMsg = "Cannot replace child '";
+        errorMsg += path;
+        errorMsg += "' since path (";
+        errorMsg += server_parent->absNodePath();
+        errorMsg += ") in the server is a task.";
+        return node_ptr();
+    }
+
+    // PARTIAL PATH MATCH,
+    LOG_ASSERT(last_client_child, "");
+    LOG_ASSERT(client_parent, "");
+    LOG_ASSERT(last_client_child->parent() == client_parent, "");
+    LOG_ASSERT(client_parent->absNodePath() == server_parent->absNodePath(), "");
+
+    /// If the child of same name exist we *replace* at the same position otherwise we *add* it to the end
+    size_t client_child_pos = last_client_child->position();
+
+    size_t server_child_pos; // will be set to  std::numeric_limits<std::size_t>::max(), if child not found
+    node_ptr server_child = server_parent->findImmediateChild(last_client_child->name(), server_child_pos);
+    if (server_child.get()) {
+
+        // Copy over suspended state
+        if (server_child->isSuspended()) {
+            last_client_child->suspend();
+        }
+
+        // Child of same name exist on the server, hence remove it
+        deleteChild(server_child.get());
+    }
+
+    // Take a note of begun status, in case the suite is being replaced.
+    bool begin_node = server_parent->suite()->begun();
+
+    node_ptr client_node_to_add = last_client_child->remove();
+    bool addOk                  = server_parent->addChild(client_node_to_add, client_child_pos);
+    LOG_ASSERT(addOk, "");
+
+    // preserve begun status. Note: we should't call begin() on the client side. As the suites will not have been begun.
+    // This can cause assert, because begin time attributes assumes that calendar has been initialised. This is not the
+    // case for client ASSERT failure: !c.suiteTime().is_special() at ../ACore/src/TimeSeries.cpp:526 init has not been
+    // called on calendar. TimeSeries::duration ECFLOW-1612
+    if (begin_node)
+        client_node_to_add->begin();
+
+    client_node_to_add->set_most_significant_state_up_node_tree();
+
+    return client_node_to_add;
+}
+
+void Defs::cereal_save_as_checkpt(const std::string& the_fileName) const {
+    // only_save_edit_history_when_check_pointing or if explicitly requested
+    save_edit_history_ = true; // this is reset after edit_history is saved
+
+    /// Can throw archive exception
+    ecf::save(the_fileName, *this);
+}
+
+void Defs::cereal_restore_from_checkpt(const std::string& the_fileName) {
+    //	cout << "Defs::cereal_restore_from_checkpt " << the_fileName << "\n";
+
+    if (the_fileName.empty())
+        return;
+
+    // deleting existing content first. *** Note: Server environment left as is ****
+    clear();
+
+    ecf::restore(the_fileName, (*this));
+
+    //	cout << "Restored: " << suiteVec_.size() << " suites\n";
+}
+
+void Defs::save_as_checkpt(const std::string& the_fileName) const {
+    // Save as defs will always save children, hence no need for CheckPtContext
+
+    // only_save_edit_history_when_check_pointing or if explicitly requested
+    save_edit_history_ = true; // this is reset after edit_history is saved
+
+    // Speed up check-pointing by avoiding indentation. i.e run_time and disk space
+    // to view indented code use 'ecflow_client --load=checkpt_file check_only print'
+    ecf::DisableIndentor disable_indentation;
+    save_as_filename(the_fileName, PrintStyle::MIGRATE);
+}
+
+void Defs::save_as_filename(const std::string& the_fileName, PrintStyle::Type_t p_style) const {
+    PrintStyle printStyle(p_style);
+
+    std::ofstream ofs(the_fileName.c_str());
+    std::string s;
+    print(s);
+    ofs << s;
+
+    if (!ofs.good()) {
+        std::string err = "Defs::save_as_filename: path(";
+        err += the_fileName;
+        err += ") failed: ";
+        err += File::stream_error_condition(ofs);
+        throw std::runtime_error(err);
+    }
+}
+
+void Defs::save_as_string(std::string& the_string, PrintStyle::Type_t p_style) const {
+    PrintStyle printStyle(p_style);
+
+    // Speed up check-pointing by avoiding indentation. i.e run_time and disk space
+    // to view indented code use 'ecflow_client --load=checkpt_file check_only print'
+    ecf::DisableIndentor disable_indentation;
+    print(the_string);
+}
+
+void Defs::restore(const std::string& the_fileName) {
+    if (the_fileName.empty())
+        return;
+
+    /// *************************************************************************
+    /// The reason why Parser code moved to ANode directory. Avoid cyclic loop
+    /// *************************************************************************
+    std::string errorMsg, warningMsg;
+    if (!restore(the_fileName, errorMsg, warningMsg)) {
+        std::stringstream e;
+        e << "Defs::defs_restore_from_checkpt: " << errorMsg;
+        throw std::runtime_error(e.str());
+    }
+}
+
+bool Defs::restore(const std::string& the_fileName, std::string& errorMsg, std::string& warningMsg) {
+    if (the_fileName.empty()) {
+        errorMsg = "Defs::restore: the filename string is empty";
+        return false;
+    }
+
+    // deleting existing content first. *** Note: Server environment left as is ****
+    clear();
+
+    DefsStructureParser parser(this, the_fileName);
+    bool ret = parser.doParse(errorMsg, warningMsg);
+    return ret;
+}
+
+void Defs::restore_from_string(const std::string& str) {
+    /// *************************************************************************
+    /// The reason why Parser code moved to ANode directory. Avoid cyclic loop
+    /// *************************************************************************
+    std::string errorMsg, warningMsg;
+    if (!restore_from_string(str, errorMsg, warningMsg)) {
+        std::stringstream e;
+        e << "Defs::restore_from_string: " << errorMsg;
+        throw std::runtime_error(e.str());
+    }
+}
+
+bool Defs::restore_from_string(const std::string& str, std::string& errorMsg, std::string& warningMsg) {
+    if (str.empty()) {
+        errorMsg = "Defs::restore_from_string: the string is empty";
+        return false;
+    }
+
+    // deleting existing content first. *** Note: Server environment left as is ****
+    clear();
+
+    // Do *NOT* Reset the state and modify numbers
+    // As we we need this numbers for Syncing between client<->Server
+    DefsStructureParser parser(this, str, false /* not used*/);
+    bool ret = parser.doParse(errorMsg, warningMsg);
+    return ret;
+}
+
+void Defs::clear() {
+    // Duplicate AST are held in a static map.
+    ExprDuplicate reclaim_cloned_ast_memory;
+
+    // *** Note: Server environment left as is ****
+    suiteVec_.clear();
+    externs_.clear();
+    client_suite_mgr_.clear();
+    state_.setState(NState::UNKNOWN);
+    edit_history_.clear();
+    save_edit_history_ = false;
+    Ecf::incr_modify_change_no();
+}
+
+bool Defs::checkInvariants(std::string& errorMsg) const {
+    for (const auto& s : suiteVec_) {
+        if (s->defs() != this) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants suite->defs() function not correct. Child suite parent ptr not correct\n";
+            ss << "For suite " << s->name();
+            errorMsg += ss.str();
+            return false;
+        }
+        if (!s->isSuite()) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants suite isSuite() return NULL ? for suite " << s->name();
+            errorMsg += ss.str();
+            return false;
+        }
+        if (s->isSuite() != s->suite()) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants  s->isSuite(" << s->isSuite() << ") != s->suite(" << s->suite() << ") ";
+            ss << "for suite " << s->name();
+            errorMsg += ss.str();
+            return false;
+        }
+        if (!s->checkInvariants(errorMsg)) {
+            return false;
+        }
+    }
+
+    if (Ecf::server()) {
+        /// The change no should NOT be greater than Ecf::state_change_no()
+
+        if (state_change_no_ > Ecf::state_change_no()) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants: state_change_no(" << state_.state_change_no() << ") > Ecf::state_change_no("
+               << Ecf::state_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+        if (modify_change_no_ > Ecf::modify_change_no()) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants: modify_change_no_(" << modify_change_no_ << ") > Ecf::modify_change_no("
+               << Ecf::modify_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+
+        if (flag_.state_change_no() > Ecf::state_change_no()) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants: flag.state_change_no()(" << flag_.state_change_no()
+               << ") > Ecf::state_change_no(" << Ecf::state_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+
+        if (state_.state_change_no() > Ecf::state_change_no()) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants: state_.state_change_no()(" << state_.state_change_no()
+               << ") > Ecf::state_change_no(" << Ecf::state_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+
+        if (server_.state_change_no() > Ecf::state_change_no()) {
+            std::stringstream ss;
+            ss << "Defs::checkInvariants: server_.state_change_no()(" << server_.state_change_no()
+               << ") > Ecf::state_change_no(" << Ecf::state_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+    }
+    return true;
+}
+
+void Defs::order(Node* immediateChild, NOrder::Order ord) {
+    switch (ord) {
+        case NOrder::TOP: {
+            for (auto i = suiteVec_.begin(); i != suiteVec_.end(); ++i) {
+                suite_ptr s = (*i);
+                if (s.get() == immediateChild) {
+                    suiteVec_.erase(i);
+                    suiteVec_.insert(suiteVec_.begin(), s);
+                    client_suite_mgr_.update_suite_order();
+                    order_state_change_no_ = Ecf::incr_state_change_no();
+                    return;
+                }
+            }
+            throw std::runtime_error("Defs::order: TOP, immediate child suite not found");
+        }
+        case NOrder::BOTTOM: {
+            for (auto i = suiteVec_.begin(); i != suiteVec_.end(); ++i) {
+                suite_ptr s = (*i);
+                if (s.get() == immediateChild) {
+                    suiteVec_.erase(i);
+                    suiteVec_.push_back(s);
+                    order_state_change_no_ = Ecf::incr_state_change_no();
+                    client_suite_mgr_.update_suite_order();
+                    return;
+                }
+            }
+            throw std::runtime_error("Defs::order: BOTTOM, immediate child suite not found");
+        }
+        case NOrder::ALPHA: {
+            std::sort(suiteVec_.begin(), suiteVec_.end(), [](const suite_ptr& a, const suite_ptr& b) {
+                try {
+                    int a_as_int = ecf::convert_to<int>(a->name());
+                    int b_as_int = ecf::convert_to<int>(b->name());
+                    return a_as_int < b_as_int;
+                }
+                catch (const ecf::bad_conversion&) {
+                }
+
+                return Str::caseInsLess(a->name(), b->name());
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            client_suite_mgr_.update_suite_order();
+            break;
+        }
+        case NOrder::ORDER: {
+            std::sort(suiteVec_.begin(), suiteVec_.end(), [](const suite_ptr& a, const suite_ptr& b) {
+                return Str::caseInsGreater(a->name(), b->name());
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            client_suite_mgr_.update_suite_order();
+            break;
+        }
+        case NOrder::UP: {
+            for (size_t t = 0; t < suiteVec_.size(); t++) {
+                if (suiteVec_[t].get() == immediateChild) {
+                    if (t != 0) {
+                        suite_ptr s = suiteVec_[t];
+                        suiteVec_.erase(suiteVec_.begin() + t);
+                        t--;
+                        suiteVec_.insert(suiteVec_.begin() + t, s);
+                        order_state_change_no_ = Ecf::incr_state_change_no();
+                    }
+                    client_suite_mgr_.update_suite_order();
+                    return;
+                }
+            }
+            throw std::runtime_error("Defs::order: UP, immediate child suite not found");
+        }
+        case NOrder::DOWN: {
+            for (size_t t = 0; t < suiteVec_.size(); t++) {
+                if (suiteVec_[t].get() == immediateChild) {
+                    if (t != suiteVec_.size() - 1) {
+                        suite_ptr s = suiteVec_[t];
+                        suiteVec_.erase(suiteVec_.begin() + t);
+                        t++;
+                        suiteVec_.insert(suiteVec_.begin() + t, s);
+                        order_state_change_no_ = Ecf::incr_state_change_no();
+                    }
+                    client_suite_mgr_.update_suite_order();
+                    return;
+                }
+            }
+            throw std::runtime_error("Defs::order: DOWN, immediate child suite not found");
+        }
+        case NOrder::RUNTIME: {
+            for (suite_ptr suite : suiteVec_) {
+                if (suite->state() != NState::COMPLETE) {
+                    throw std::runtime_error("Defs::order: To order by RUNTIME All suites must be complete");
+                }
+            }
+            for (suite_ptr suite : suiteVec_)
+                (void)suite->sum_runtime();
+            std::sort(suiteVec_.begin(), suiteVec_.end(), [](const suite_ptr& a, const suite_ptr& b) {
+                return a->state_change_runtime() > b->state_change_runtime();
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            client_suite_mgr_.update_suite_order();
+            break;
+        }
+    }
+}
+
+void Defs::move_peer(Node* source, Node* dest) {
+    move_peer_node(suiteVec_, source, dest, "Defs");
+    order_state_change_no_ = Ecf::incr_state_change_no();
+    client_suite_mgr_.update_suite_order();
+}
+
+void Defs::top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
+    bool why_found = why(theReasonWhy, html_tags);
+    if (!why_found) {
+        for (const auto& s : suiteVec_) {
+            (void)s->top_down_why(theReasonWhy, html_tags);
+        }
+    }
+}
+
+bool Defs::why(std::vector<std::string>& theReasonWhy, bool html) const {
+    if (isSuspended()) {
+        std::string the_reason = "The server is *not* RUNNING.";
+        theReasonWhy.push_back(the_reason);
+        return true;
+    }
+    else if (state() != NState::QUEUED && state() != NState::ABORTED) {
+        std::stringstream ss;
+        if (html)
+            ss << "The definition state(" << NState::to_html(state()) << ") is not queued or aborted.";
+        else
+            ss << "The definition state(" << NState::toString(state()) << ") is not queued or aborted.";
+        theReasonWhy.push_back(ss.str());
+    }
+    return server_.why(theReasonWhy);
+}
+
+std::string Defs::toString() const {
+    // Let the Client control the print style
+    std::stringstream ss;
+    ss << this;
+    return ss.str();
+}
+
+// Memento functions
+void Defs::collateChanges(unsigned int client_handle, DefsDelta& incremental_changes) const {
+    // Collate any small scale changes to the defs
+    collate_defs_changes_only(incremental_changes);
+
+    if (0 == client_handle) {
+        // small scale changes. Collate changes over all suites.
+        // Suite stores the maximum state change, over *all* its children, this is used by client handle mechanism
+        // and here to avoid traversing down the hierarchy.
+        // ******** We must trap all child changes under the suite. See class SuiteChanged
+        // ******** otherwise some attribute sync's will be missed
+        for (const auto& s : suiteVec_) {
+            //   *IF* node/attribute change no > client_state_change_no
+            //   *THEN*
+            //       Create a memento, and store in incremental_changes_
+            s->collateChanges(incremental_changes);
+        }
+    }
+    else {
+
+        // small scale changes over the suites in our handle, determine what's changed,
+        // relative to each node and attributes client_state_change_no.
+        //   *IF* node/attribute change no > client_state_change_no
+        //   *THEN*
+        //       Create a memento, and store in incremental_changes_
+        client_suite_mgr_.collateChanges(client_handle, incremental_changes);
+    }
+}
+
+void Defs::collate_defs_changes_only(DefsDelta& incremental_changes) const {
+    // ************************************************************************************************
+    // determine if defs state changed. make sure this is in sync with defs_only_max_state_change_no()
+    // ************************************************************************************************
+    compound_memento_ptr comp;
+    if (state_.state_change_no() > incremental_changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
+        comp->add(std::make_shared<StateMemento>(state_.state()));
+    }
+    if (order_state_change_no_ > incremental_changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
+        std::vector<std::string> order;
+        order.reserve(suiteVec_.size());
+        for (const auto& i : suiteVec_)
+            order.push_back(i->name());
+        comp->add(std::make_shared<OrderMemento>(order));
+    }
+
+    // Determine if the flag changed
+    if (flag_.state_change_no() > incremental_changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
+        comp->add(std::make_shared<FlagMemento>(flag_));
+    }
+
+    // determine if defs server state, currently only watch server state. i.e HALTED, SHUTDOWN, RUNNING
+    if (server_.state_change_no() > incremental_changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
+        comp->add(std::make_shared<ServerStateMemento>(server_.get_state()));
+    }
+    if (server_.variable_state_change_no() > incremental_changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(Str::ROOT_PATH());
+        comp->add(std::make_shared<ServerVariableMemento>(server_.user_variables()));
+    }
+
+    if (comp.get()) {
+        incremental_changes.add(comp);
+    }
+}
+
+unsigned int Defs::defs_only_max_state_change_no() const {
+    // ************************************************************************************************
+    // make sure this is in sync with collate_defs_changes_only()
+    // ************************************************************************************************
+    unsigned int max_change_no = 0;
+    max_change_no              = std::max(max_change_no, state_.state_change_no());
+    max_change_no              = std::max(max_change_no, order_state_change_no_);
+    max_change_no              = std::max(max_change_no, flag_.state_change_no());
+    max_change_no              = std::max(max_change_no, server_.state_change_no());
+    max_change_no              = std::max(max_change_no, server_.variable_state_change_no());
+    return max_change_no;
+}
+
+void Defs::set_memento(const StateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Defs::set_memento(const StateMemento* memento)\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::STATE);
+    else
+        set_state(memento->state_);
+}
+
+void Defs::set_memento(const ServerStateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Defs::set_memento(const ServerStateMemento* memento)\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::SERVER_STATE);
+    else
+        server_.set_state(memento->state_);
+}
+
+void Defs::set_memento(const ServerVariableMemento* memento,
+                       std::vector<ecf::Aspect::Type>& aspects,
+                       bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Defs::set_memento(const ServerVariableMemento* memento)\n";
+#endif
+
+    if (aspect_only) {
+        if (server_.user_variables().size() != memento->serverEnv_.size()) {
+            aspects.push_back(ecf::Aspect::ADD_REMOVE_ATTR);
+        }
+        aspects.push_back(ecf::Aspect::SERVER_VARIABLE);
+        return;
+    }
+
+    server_.set_user_variables(memento->serverEnv_);
+}
+
+void Defs::set_memento(const OrderMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Defs::set_memento(const OrderMemento* memento)\n";
+#endif
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::ORDER);
+        return;
+    }
+
+    // Order the suites
+
+    // Order nodes according to memento ordering
+    const std::vector<std::string>& order = memento->order_;
+
+    // NOTE: When we have handles only a small subset of the suites, are returned
+    //       Whereas order will always contain all the suites.
+    //       Hence we need to handle the case where: order.size() != suiteVec_.size()
+
+    std::vector<suite_ptr> vec;
+    vec.reserve(suiteVec_.size());
+    size_t node_vec_size = suiteVec_.size();
+    for (const auto& i : order) {
+        for (size_t t = 0; t < node_vec_size; t++) {
+            if (i == suiteVec_[t]->name()) {
+                vec.push_back(suiteVec_[t]);
+                break;
+            }
+        }
+    }
+    if (vec.size() != suiteVec_.size()) {
+        std::cout << "Defs::set_memento could not find all the names\n";
+        return;
+    }
+    suiteVec_ = vec;
+}
+
+void Defs::set_memento(const FlagMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Defs::set_memento(const FlagMemento* memento)\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::FLAG);
+    else
+        flag_.set_flag(memento->flag_.flag());
+}
+
+// =====================================================================
+
+void Defs::add_edit_history(const std::string& path, const std::string& request) {
+    auto i = edit_history_.find(path);
+    if (i == edit_history_.end()) {
+        edit_history_.insert(std::make_pair(path, std::vector<std::string>(1, request)));
+    }
+    else {
+        (*i).second.push_back(request);
+        if ((*i).second.size() > Defs::max_edit_history_size_per_node()) {
+            (*i).second.erase((*i).second.begin());
+        }
+    }
+}
+
+void Defs::remove_edit_history(Node* node) {
+    if (!node)
+        return;
+
+    // When removing a node *it* and all its children also need to be removed.
+    std::vector<node_ptr> node_children;
+    node->get_all_nodes(node_children);
+    for (const auto& c : node_children) {
+
+        auto it = edit_history_.find(c->absNodePath());
+        if (it != edit_history_.end()) {
+            edit_history_.erase(it);
+        }
+    }
+}
+
+void Defs::clear_edit_history() {
+    edit_history_.clear();
+}
+
+const std::vector<std::string>& Defs::get_edit_history(const std::string& path) const {
+    auto i = edit_history_.find(path);
+    if (i != edit_history_.end()) {
+        return (*i).second;
+    }
+    return empty_edit_history();
+}
+
+const std::vector<std::string>& Defs::empty_edit_history() {
+    static std::vector<std::string> static_edit_history;
+    return static_edit_history;
+}
+
+// =====================================================================================
+
+void Defs::notify_delete() {
+    // make a copy, to avoid iterating over observer list that is being changed
+    std::vector<AbstractObserver*> copy_of_observers = observers_;
+    for (auto& copy_of_observer : copy_of_observers) {
+        copy_of_observer->update_delete(this);
+    }
+
+    /// Check to make sure that the Observer called detach
+    /// We cannot call detach ourselves, since the the client needs to
+    /// call detach in the case where the graphical tree is destroyed by user
+    /// In this case the Subject/Node is being deleted.
+    assert(observers_.empty());
+}
+
+void Defs::notify_start(const std::vector<ecf::Aspect::Type>& aspects) {
+    for (auto& observer : observers_) {
+        observer->update_start(this, aspects);
+    }
+}
+
+void Defs::notify(const std::vector<ecf::Aspect::Type>& aspects) {
+    for (auto& observer : observers_) {
+        observer->update(this, aspects);
+    }
+}
+
+void Defs::attach(AbstractObserver* obs) {
+    observers_.push_back(obs);
+}
+
+void Defs::detach(AbstractObserver* obs) {
+    for (size_t i = 0; i < observers_.size(); i++) {
+        if (observers_[i] == obs) {
+            observers_.erase(observers_.begin() + i);
+            return;
+        }
+    }
+}
+
+bool Defs::is_observed(AbstractObserver* obs) const {
+    for (auto observer : observers_) {
+        if (observer == obs) {
+            return true;
+        }
+    }
+    return false;
+}
+// =====================================================================================
+
+std::ostream& operator<<(std::ostream& os, const Defs* d) {
+    if (d) {
+        std::string s;
+        d->print(s);
+        os << s;
+        return os;
+    }
+    return os << "DEFS == NULL\n";
+}
+std::ostream& operator<<(std::ostream& os, const Defs& d) {
+    std::string s;
+    d.print(s);
+    os << s;
+    return os;
+}
+
+// =========================================================================
+
+DefsHistoryParser::DefsHistoryParser() = default;
+
+void DefsHistoryParser::parse(const std::string& line) {
+    size_t pos = line.find("\b");
+    if (pos != std::string::npos) {
+        // keep compatibility with current way of writing history
+        std::string requests = line.substr(pos);
+        Str::split(requests, parsed_messages_, "\b");
+        return;
+    }
+
+    // fallback, split line based on looking for logType like 'MSG:[' | 'LOG:['
+    string::size_type first = find_log(line, 0);
+    if (first == std::string::npos)
+        return;
+
+    string::size_type next = find_log(line, first + 4);
+    if (next == std::string::npos) {
+        parsed_messages_.push_back(line.substr(first));
+        return;
+    }
+
+    while (next != std::string::npos) {
+        parsed_messages_.push_back(line.substr(first, next - first));
+        first = next;
+        next  = find_log(line, first + 4);
+
+        if (next == std::string::npos) {
+            parsed_messages_.push_back(line.substr(first));
+            return;
+        }
+    }
+}
+
+string::size_type DefsHistoryParser::find_log(const std::string& line, string::size_type pos) const {
+    std::vector<std::string> log_types;
+    Log::get_log_types(log_types);
+
+    for (auto log_type : log_types) {
+        log_type += ":[";
+        string::size_type log_type_pos = line.find(log_type, pos);
+        if (log_type_pos != std::string::npos) {
+            return log_type_pos;
+        }
+    }
+    return std::string::npos;
+}
+
+std::string Defs::stats() const {
+    std::vector<node_ptr> node_vec;
+    get_all_nodes(node_vec);
+
+    std::vector<Family*> family_vec;
+    getAllFamilies(family_vec);
+
+    std::vector<task_ptr> task_vec;
+    get_all_tasks(task_vec);
+
+    size_t alias = 0;
+    for (auto task : task_vec)
+        alias += task->aliases().size();
+
+    NodeStats stats;
+    stats.suites_ = suiteVec_.size();
+    stats.family_ = family_vec.size();
+    stats.task_   = task_vec.size();
+    stats.alias_  = alias;
+    stats.nodes_  = node_vec.size();
+
+    stats.edit_history_nodes_ = edit_history_.size();
+    for (const auto& i : edit_history_) {
+        const std::vector<std::string>& vec = i.second; // list of requests
+        stats.edit_history_paths_ += vec.size();
+    }
+
+    for (auto node : node_vec)
+        node->stats(stats);
+    return stats.print();
+}
+
+template <class Archive>
+void Defs::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(state_change_no_),
+       CEREAL_NVP(modify_change_no_),
+       CEREAL_NVP(updateCalendarCount_),
+       CEREAL_NVP(state_),
+       CEREAL_NVP(server_),
+       CEREAL_NVP(suiteVec_));
+
+    CEREAL_OPTIONAL_NVP(ar, flag_, [this]() { return flag_.flag() != 0; }); // conditionally save
+
+    // only save the edit history when check pointing.
+    CEREAL_OPTIONAL_NVP(
+        ar, edit_history_, [this]() { return save_edit_history_ && !edit_history_.empty(); }); // conditionally save
+
+    if (Archive::is_loading::value) {
+        size_t vec_size = suiteVec_.size();
+        for (size_t i = 0; i < vec_size; i++) {
+            suiteVec_[i]->set_defs(this);
+        }
+    }
+}
+
+CEREAL_TEMPLATE_SPECIALIZE_V(Defs);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Defs.hpp 5.13.0-1/libs/node/src/ecflow/node/Defs.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Defs.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Defs.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,455 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Defs_HPP
+#define ecflow_node_Defs_HPP
+
+///
+/// \brief class defs: The root of the node tree. Holds all the suites:
+/// Externs are not persisted, why ?:
+///   o Externs are un-resolved references to node paths in trigger expressions and inlimits
+///     These references can be dynamically generated.
+///   o Saves on network bandwidth and checkpoint file size
+///
+/// Hence externs are *ONLY* used on the client side.
+///
+
+#include <cstdint>
+#include <iosfwd>
+#include <set>
+#include <unordered_map>
+#include <vector>
+
+#include "ecflow/core/NOrder.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Aspect.hpp"
+#include "ecflow/node/Attr.hpp"
+#include "ecflow/node/ClientSuiteMgr.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+#include "ecflow/node/ServerState.hpp"
+#include "ecflow/node/Suite.hpp"
+
+namespace cereal {
+class access;
+}
+namespace ecf {
+class NodeTreeVisitor;
+class CalendarUpdateParams;
+} // namespace ecf
+
+class Defs {
+public:
+    static defs_ptr create();
+    static defs_ptr create(const std::string& port);
+    Defs();
+    explicit Defs(const std::string& port); // used in test, to initialise server variables
+    Defs(const Defs&);
+    Defs& operator=(const Defs&);
+
+    ~Defs();
+
+    void copy_defs_state_only(const defs_ptr& defs); // needed when creating defs for client handles
+    bool operator==(const Defs& rhs) const;
+    void print(std::string&) const;
+    std::string print(PrintStyle::Type_t t = PrintStyle::MIGRATE) const;
+
+    /// Handle migration of checkpoint 4->5, and 5.0-5.4.0 -> 5.5
+    /// This essentially update date data member of the Day attribute
+    /// Can be removed when ecflow 5 is used everywhere.
+    void handle_migration();
+
+    /// State related functions:
+    /// Defs acts like the root node.
+    void set_state(NState::State);
+    void set_state_only(NState::State);
+    NState::State state() const;
+    void set_most_significant_state();
+
+    // The defs does not need suspend()/resume() as this is controlled by the server states
+    // The defs cannot schedule jobs when HALTED or SHUTDOWN, i.e. not RUNNING, this is same as suspended
+    bool isSuspended() const { return (server().get_state() != SState::RUNNING); }
+
+    /// Python based checking
+    /// Will create a temporary variable ECF_JOB so the job generation is done to a temporary directory
+    /// For TEST ONLY. Will generated jobs from the given node path
+    /// if the no path defined will generate jobs for all tasks
+    /// Job generation here is INDEPENDENT of the dependencies
+    /// Will call begin(). this updated generated variables which are used
+    /// **during variable substitution in job generation.
+    /// Note: All Tasks that fail to create jobs are returned in jobCtrl
+    /// This is because some Tasks are dummy, they have no associated ecf.
+    /// since they will never be run. This can be determined if they have
+    /// trigger expression like "1 == 0"
+    void check_job_creation(job_creation_ctrl_ptr jobCtrl);
+
+    /// Automatically generated '.ecf' scripts for this definition
+    /// It uses the contents of the definition to parameterise what gets
+    /// generated, and the location of the files. Will throw std::runtime_error for errors
+    /// Assumes: ECF_HOME specified and accessible for all Tasks, otherwise std::runtime_error is raised
+    /// If ECF_FILES is specified, then scripts are generated under this directory
+    /// otherwise ECF_HOME is used. The missing directories are automatically added.
+    /// IF ECF_INCLUDE must be specified.The head.h and tail.h includes will
+    /// use angle brackets, i.e %include <head.h>.
+    /// If ECF_CLIENT_EXE_PATH variable is added, child command will use this, otherwise
+    /// will use ecflow_client, and assume this accessible on the path.
+    /// Will not generated scripts for tasks with ECF_DUMMY_TASK specified.
+    void generate_scripts() const;
+
+    /// Update calendar and time dependent variables. This must be called by the polling mechanism,
+    /// This will *ONLY* have an effect after begin() command has been called
+    ///
+    /// Some suites can elect to ignore calendar updates when the server is not running
+    /// This allows normal and relative time dependencies to be honoured, even if the
+    /// server is started/stopped many times.
+    /// Updating the calendar can lead to state changes in the server. i.e when time related
+    /// dependencies are free'd
+    void updateCalendar(const ecf::CalendarUpdateParams&);
+
+    /// Used by simulator & catch_up_to_real_time
+    void update_calendar(Suite* suite, const ecf::CalendarUpdateParams& cal_update_params); // used by simulator
+
+    /// returns the number of times the calendar has been updated. For DEBUG
+    unsigned int updateCalendarCount() const { return updateCalendarCount_; }
+
+    /// When the server is terminated and then restarted, Allow time attributes to catch up.
+    /// This may expire time attributes allowing the task to run
+    /// We only update suite that have time attributes and where the calendars that are 1 hour out of sync with real
+    /// time. It can be quite expensive to update time attributes 1 minute at a time, hence we chose 1 hour. Return true
+    /// if any suite where updated
+    bool catch_up_to_real_time();
+
+    // Implements visitor pattern
+    void accept(ecf::NodeTreeVisitor&);                 // Node Tree structure does the traversal
+    void acceptVisitTraversor(ecf::NodeTreeVisitor& v); // visitor does traversal
+
+    /// Moves all the data from input defs into this definition. By default
+    /// suite of the same name, are left alone, unless the force option is used.
+    /// i.e with force any suites of the same name will overwrite the suite of
+    /// the same name in this definition.
+    /// externs and server user variables are appended to.
+    /// The input defs will be left with NO suites
+    void absorb(Defs*, bool force);
+
+    std::string name() const { return "/"; } /* ABO */
+
+    /// Add a suite to the definition, will throw std::runtime_error if duplicate
+    suite_ptr add_suite(const std::string& name);
+    void addSuite(const suite_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
+    size_t child_position(const Node*) const;
+
+    /// Externs refer to Nodes or, variable, events, meter, repeat, or generated variable
+    /// not currently defined. If the object(variable, event,meter, repeat, or generate variable name)
+    /// is empty the path can refer to a Task, Family of Suite
+    /// extern can have absolute and relative paths
+    /// Typically used in a trigger or complete expression
+    /// Path can be off the form:
+    ///  extern /suite/family
+    ///  extern /suite/family:repeat_name
+    ///  extern ../family:repeat_name
+    void add_extern(const std::string& nodePath);
+    void clear_externs() { externs_.clear(); }
+
+    /// Scan the trigger and complete expressions, and automatically add extern's
+    /// i.e where the node paths, and references, to event, meters, edit and repeat variables,
+    /// don't exist, in this defs.
+    void auto_add_externs(bool remove_existing_externs_first = true);
+
+    /// Flag the chosen suite, so that it can resolve dependencies. This also
+    /// changes the state of all children to QUEUED/defstatus and initialise the node attributes
+    /// Once a suite is begun, it stays in that state
+    void beginSuite(const suite_ptr&);
+
+    /// Enables all suites to resolve dependencies
+    /// Once a suite is begun, it stays in that state
+    void beginAll();
+
+    /// Reset the begin state. **** ONLY to be used for test ********
+    void reset_begin();
+
+    /// throws runtime_error if suite cant begin
+    void check_suite_can_begin(const suite_ptr&) const;
+
+    /// Will requeue all suites. Current used in test only
+    void requeue();
+
+    /// returns true if defs has cron,time,day,date or today time dependencies
+    bool hasTimeDependencies() const;
+
+    /// recursively sort the attributes
+    // expect one attr to be [ event | meter | label | limits | variable ]
+    // if recursive is true, ignore nodes on no_sort list
+    void sort_attributes(ecf::Attr::Type attr,
+                         bool recursive                          = true,
+                         const std::vector<std::string>& no_sort = std::vector<std::string>());
+
+    /// This function is called when ALL definition has been parsed successfully
+    /// Client Side:: The client side has externs, hence any references to node paths
+    ///               in the triggers expression, that are un-resolved and not in
+    ///               the extern;s are reported as errors/warnings
+    ///               Likewise for inlimit references to Limits
+    /// Server Side:: There are no externs hence, check will report all unresolved
+    ///               references as errors.
+    /// Note the AST will be demand loaded in the server. Since they are not persisted.
+    /// we will also resolve inLimit references to Limits. Note inlimit may also
+    /// reference paths, which are externs::
+    // ****** Spirit based AST construction is very expensive  ********
+    // ****** Need to replace at some point in future          ********
+    bool check(std::string& errorMsg, std::string& warningMsg) const;
+
+    /// Assumes input argument is of the form /suite/family/task, /suite/family/family/task
+    node_ptr findAbsNode(const std::string& pathToNode) const;
+    bool find_extern(const std::string& pathToNode, const std::string& node_attr_name) const;
+    suite_ptr findSuite(const std::string& name) const;
+    std::string find_node_path(const std::string& type, const std::string& name) const;
+    node_ptr find_node(const std::string& type, const std::string& pathToNode) const;
+
+    const std::vector<suite_ptr>& suiteVec() const { return suiteVec_; }
+
+    /// Given a path, /suite/family/task, find node which is the closest
+    node_ptr find_closest_matching_node(const std::string& pathToNode) const;
+
+    void getAllFamilies(std::vector<Family*>&) const;
+    void getAllNodes(std::vector<Node*>&) const;
+    void getAllTasks(std::vector<Task*>&) const;
+    void getAllSubmittables(std::vector<Submittable*>&) const;
+    void get_all_active_submittables(std::vector<Submittable*>&) const;
+    void get_all_nodes(std::vector<node_ptr>&) const;
+    void get_all_tasks(std::vector<task_ptr>&) const;
+    void get_all_aliases(std::vector<alias_ptr>&) const;
+    void getAllAstNodes(std::set<Node*>&) const;
+    const std::set<std::string>& externs() const { return externs_; }
+
+    /// Get/set for server state.
+    const ServerState& server() const { return server_; }
+    ServerState& set_server() { return server_; }
+
+    /// find all %VAR% and replaces with variable values, returns false on the
+    /// first variable that can't be found, cmd will be left half processed.
+    /// Will search for ECF_MICRO, if not found assumes % as the micro char
+    bool variableSubsitution(std::string& cmd) const { return server_.variableSubsitution(cmd); }
+
+    /// returns true if definition file passes its verification
+    /// If the definition file contains verify attribute, this function will check
+    /// expected number of state changes corresponds to the actual number of state changes
+    bool verification(std::string& errorMsg) const;
+
+    /// generic way of deleting a Node.
+    /// This should always succeed else something is seriously wrong
+    bool deleteChild(Node*);
+
+    /// This called during replace. If the trigger expression(AST) has been created,  then
+    /// the references to the nodes, will be invalidated.
+    /// These get generated on the fly, when referenced.
+    void invalidate_trigger_references() const;
+
+    /// Adopt the child specified by 'path' from the clientDef.
+    /// If node at path already exists in this instance, it is replaced.
+    /// if  createNodesAsNeeded = false,  then the path must exist on this defs
+    /// otherwise an error message is issued.
+    /// if  createNodesAsNeeded = true, and the path does not exist on this defs
+    /// then the missing path nodes are created.
+    /// In both the client and this defs the trigger references and cleared first.
+    /// Returns the changed node, or NULL and error message set.
+    node_ptr replaceChild(const std::string& path,
+                          const defs_ptr& clientDef,
+                          bool createNodesAsNeeded,
+                          bool force,
+                          std::string& errormsg);
+
+    // Order the suite
+    void order(Node* immediateChild, NOrder::Order);
+    void move_peer(Node* src, Node* dest);
+
+    /// determines why the node is not running.
+    void top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
+    bool why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const; // return true if why found
+
+    /// Function to save/restore the defs as a checkpoint file. Can throw exception
+    /// If the Defs file has content, this is deleted first, i.e. suites, externs, Can throw an exception
+    void cereal_save_as_checkpt(const std::string& fileName) const;
+    void cereal_restore_from_checkpt(const std::string& fileName);
+
+    // defs format
+    void save_as_checkpt(const std::string& fileName) const;
+    void save_as_filename(const std::string& fileName,
+                          PrintStyle::Type_t = PrintStyle::MIGRATE) const; // used in test only
+    void save_as_string(std::string& str, PrintStyle::Type_t = PrintStyle::MIGRATE) const;
+    void restore(const std::string& fileName); // will throw
+    bool restore(const std::string& fileName, std::string& errorMsg, std::string& warningMsg);
+    void restore_from_string(const std::string& str); // will throw
+    bool restore_from_string(const std::string& str, std::string& errorMsg, std::string& warningMsg);
+
+    /// Delete suites, externs, client handles, reset suspended, and locate state
+    /// etc but Server environment left as is:
+    void clear();
+
+    ecf::Flag& flag() { return flag_; }
+    const ecf::Flag& get_flag() const { return flag_; }
+
+    void add_edit_history(const std::string& path, const std::string& request);
+    void remove_edit_history(Node*);
+    void clear_edit_history();
+    std::string dump_edit_history() const;
+    const std::vector<std::string>& get_edit_history(const std::string& path) const;
+    const std::unordered_map<std::string, std::vector<std::string>>& get_edit_history() const { return edit_history_; }
+    void save_edit_history(bool f) const { save_edit_history_ = f; }
+    static const std::vector<std::string>& empty_edit_history();
+    constexpr static size_t max_edit_history_size_per_node() { return 10; }
+
+    /// Memento functions:
+    void collateChanges(unsigned int client_handle, DefsDelta&) const;
+    void set_memento(const StateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const ServerStateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const ServerVariableMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const OrderMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const FlagMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+
+    /// Find the max state change number for defs only. This includes:
+    ///   o the Defs state.
+    ///   o the Defs suspend state
+    ///   o the Defs server state.
+    unsigned int defs_only_max_state_change_no() const;
+
+    /// Change functions, used for *transferring* change number, from server to client
+    void set_state_change_no(unsigned int x) { state_change_no_ = x; }
+    unsigned int state_change_no() const { return state_change_no_; }
+    void set_modify_change_no(unsigned int x) { modify_change_no_ = x; }
+    unsigned int modify_change_no() const { return modify_change_no_; }
+
+    ClientSuiteMgr& client_suite_mgr() { return client_suite_mgr_; }
+
+    // Provided for python interface
+    std::string toString() const;
+
+    // Will recurse down.
+    bool doDeleteChild(Node* nodeToBeDeleted);
+
+    bool checkInvariants(std::string& errorMsg) const;
+
+    void read_state(const std::string& line, const std::vector<std::string>& lineTokens);
+    void read_history(const std::string& line, const std::vector<std::string>& lineTokens);
+    bool compare_edit_history(const Defs&) const;
+    bool compare_change_no(const Defs&) const;
+
+    std::string stats() const; // dump out definition stats
+
+    void ecf_prune_node_log(int v) { ecf_prune_node_log_ = v; }
+
+private:
+    void do_generate_scripts(const std::map<std::string, std::string>& override) const;
+    void write_state(std::string&) const;
+    void collate_defs_changes_only(DefsDelta&) const;
+    void setupDefaultEnv();
+    void add_suite_only(const suite_ptr&, size_t position);
+
+    /// Removes the suite, from defs returned as suite_ptr, asserts if suite does not exist
+    suite_ptr removeSuite(suite_ptr);
+    node_ptr removeChild(Node*);
+    bool addChild(const node_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
+    friend class Node;
+
+    /// For use by python interface,
+    std::vector<suite_ptr>::const_iterator suite_begin() const { return suiteVec_.begin(); }
+    std::vector<suite_ptr>::const_iterator suite_end() const { return suiteVec_.end(); }
+    std::set<std::string>::const_iterator extern_begin() const { return externs_.begin(); }
+    std::set<std::string>::const_iterator extern_end() const { return externs_.end(); }
+    std::vector<Variable>::const_iterator user_variables_begin() const { return server_.user_variables().begin(); }
+    std::vector<Variable>::const_iterator user_variables_end() const { return server_.user_variables().end(); }
+    std::vector<Variable>::const_iterator server_variables_begin() const { return server_.server_variables().begin(); }
+    std::vector<Variable>::const_iterator server_variables_end() const { return server_.server_variables().end(); }
+
+    friend void export_Defs();
+
+private:
+    /// Note: restoring from a check point file will reset, defs state and modify numbers
+    mutable size_t print_cache_{0}; // NOT persisted
+    unsigned int state_change_no_{
+        0}; // persisted since passed to client, however side effect, is it will be in checkpoint file
+    unsigned int modify_change_no_{
+        0}; // persisted since passed to client, however side effect, is it will be in checkpoint file
+    unsigned int updateCalendarCount_{0};
+    unsigned int order_state_change_no_{0}; // *NOT* persisted
+    unsigned int ecf_prune_node_log_{0};    // *NOT* persisted, only used on the server side
+    NState state_;                          // state & change_no, i,e attribute changed
+    ServerState server_;
+    std::vector<suite_ptr> suiteVec_;
+    std::unordered_map<std::string, std::vector<std::string>> edit_history_; // path,request
+    ecf::Flag flag_;
+
+    ClientSuiteMgr client_suite_mgr_{this}; // NOT persisted
+
+    /// Externs are *NEVER* loaded in the server, since they can be computed and
+    /// save on network band with, and check point file size.
+    std::set<std::string> externs_; // NOT persisted
+
+    friend class SaveEditHistoryWhenCheckPointing;
+
+private:
+    /// Observer notifications Start. Allow client to query if they are in syncing with server
+    void notify_start() { in_notification_ = true; }
+    void notify_end() { in_notification_ = false; }
+    std::vector<AbstractObserver*> observers_;
+    mutable bool save_edit_history_{false}; // NOT persisted
+    bool in_notification_{false};
+
+    friend class ChangeStartNotification;
+    void notify_delete();
+
+public:
+    void notify_start(const std::vector<ecf::Aspect::Type>& aspects);
+    void notify(const std::vector<ecf::Aspect::Type>& aspects);
+    void attach(AbstractObserver*);
+    void detach(AbstractObserver*);
+    bool is_observed(AbstractObserver*) const; // return true if we have this observer in our list
+    bool in_notification() const { return in_notification_; }
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+std::ostream& operator<<(std::ostream& os, const Defs*);
+std::ostream& operator<<(std::ostream& os, const Defs&);
+
+// =====================================================================
+// This class is used to read the History
+class DefsHistoryParser {
+public:
+    DefsHistoryParser();
+    // Disable copy (and move) semantics
+    DefsHistoryParser(const DefsHistoryParser&)                  = delete;
+    const DefsHistoryParser& operator=(const DefsHistoryParser&) = delete;
+
+    void parse(const std::string& line);
+    const std::vector<std::string>& parsed_messages() const { return parsed_messages_; }
+
+private:
+    std::string::size_type find_log(const std::string& line, std::string::size_type pos) const;
+    std::vector<std::string> parsed_messages_;
+};
+
+// Start notification. End notification automatically signalled, Even if exception raised.
+class ChangeStartNotification {
+public:
+    explicit ChangeStartNotification(defs_ptr defs) : defs_ptr_(defs) { defs_ptr_->notify_start(); }
+    // Disable copy (and move) semantics
+    ChangeStartNotification(const ChangeStartNotification&)                  = delete;
+    const ChangeStartNotification& operator=(const ChangeStartNotification&) = delete;
+
+    ~ChangeStartNotification() { defs_ptr_->notify_end(); }
+
+private:
+    defs_ptr defs_ptr_;
+};
+
+#endif /* ecflow_node_Defs_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/DefsDelta.cpp 5.13.0-1/libs/node/src/ecflow/node/DefsDelta.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/DefsDelta.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/DefsDelta.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,86 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/DefsDelta.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/node/Memento.hpp"
+
+using namespace std;
+
+// #define DEBUG_MEMENTO 1
+
+//===============================================================
+// DefsDelta
+
+/// Defs delta can be re-used. reset all data members
+void DefsDelta::init(unsigned int client_state_change_no, bool sync_suite_clock) {
+    sync_suite_clock_       = sync_suite_clock;
+    client_state_change_no_ = client_state_change_no;
+
+    server_state_change_no_  = 0;
+    server_modify_change_no_ = 0;
+    compound_mementos_.clear();
+}
+
+bool DefsDelta::incremental_sync(defs_ptr client_def,
+                                 std::vector<std::string>& changed_nodes,
+                                 int client_handle) const {
+    // ****************************************************
+    // On the client side
+    // ****************************************************
+    if (!client_def.get())
+        return false;
+
+    // Clear the changed nodes since we want it to match number of changed memento's
+    // This should have been clear anyway in ServerReply::clear_for_invoke
+    changed_nodes.clear();
+
+    // Update the client defs with latest server *handle* based state change/modify number
+    // to keep pace with the state changes. Passed back later on, to get further changes
+    client_def->set_state_change_no(server_state_change_no_);
+    client_def->set_modify_change_no(server_modify_change_no_);
+
+    try {
+#ifdef DEBUG_MEMENTO
+        std::cout << "DefsDelta::incremental_sync compound_mementos_.size() = " << compound_mementos_.size() << "\n";
+#endif
+
+        // For each compound memento, we should have a changed node,
+        for (compound_memento_ptr m : compound_mementos_) {
+            changed_nodes.push_back(m->abs_node_path()); // Record changed nodes for the Python interface
+            m->incremental_sync(client_def);
+        }
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "Could not apply incremental server changes to client defs( with client handle: " << client_handle
+           << "), because: " << e.what();
+        throw std::runtime_error(ss.str());
+    }
+
+    // For each compound memento, we should have a changed node.(for use with python interface)
+    assert(compound_mementos_.size() == changed_nodes.size());
+
+    // return true if there were any changes made
+    return !compound_mementos_.empty();
+}
+
+void DefsDelta::add(compound_memento_ptr memento) {
+    compound_mementos_.push_back(memento);
+}
+
+template <class Archive>
+void DefsDelta::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(server_state_change_no_), CEREAL_NVP(server_modify_change_no_), CEREAL_NVP(compound_mementos_));
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(DefsDelta);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/DefsDelta.hpp 5.13.0-1/libs/node/src/ecflow/node/DefsDelta.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/DefsDelta.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/DefsDelta.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,90 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_DefsDelta_HPP
+#define ecflow_node_DefsDelta_HPP
+
+///
+///
+/// \brief class DefsDelta: holds a list of incremental changes made in the server.
+///                  This class is created in the server, and transferred to the client
+///                  The client use it to syncronize with the server, without the need
+///                  for asking for the full defs.
+///
+/// When the client request the incremental changes, it also passes its client_state_change_no.
+/// The client_state_change number is used in the server side to determine what's changed.
+/// These changes are collated with add()  and transferred to the client.
+/// The client then calls  incremental_sync() which will apply the changes to the client defs
+/// so bringing it in sync with the server defs.
+///
+/// Note:: updating state_change_no() on the *client side*  a no-op() it has no effect
+///
+
+#include <cstdint>
+
+#include "ecflow/node/NodeFwd.hpp"
+namespace cereal {
+class access;
+}
+
+class DefsDelta {
+public:
+    ///=========================================================================
+    /// *Server side*
+    explicit DefsDelta(unsigned int client_state_change_no) : client_state_change_no_(client_state_change_no) {}
+    // Disable copy (and move) semantics
+    DefsDelta(const DefsDelta&)                  = delete;
+    const DefsDelta& operator=(const DefsDelta&) = delete;
+
+    /// This class can be re-used hence init() should reset all data members
+    void init(unsigned int client_state_change_no, bool sync_suite_clock);
+
+    /// reclaim memory
+    void cleanup() { std::vector<compound_memento_ptr>().swap(compound_mementos_); }
+
+    // ECFLOW-631, allow the suite calendar to be sync'ed, even if there are no other changes
+    bool sync_suite_clock() const { return sync_suite_clock_; }
+
+    /// Add the compound memento, ie. store all memento's for a *given* node.
+    void add(compound_memento_ptr);
+
+    void set_server_state_change_no(unsigned int s) { server_state_change_no_ = s; }
+    void set_server_modify_change_no(unsigned int s) { server_modify_change_no_ = s; }
+    unsigned int get_server_state_change_no() const { return server_state_change_no_; }
+    unsigned int get_server_modify_change_no() const { return server_modify_change_no_; }
+
+    ///=========================================================================
+    /// *Client side*
+    /// Applies the mementos to the client defs and record all changed nodes.
+    /// Can raise std::runtime_error.
+    /// Note:: updating state_change_no() on the *client side*  has *no effect*
+    bool incremental_sync(defs_ptr client_def, std::vector<std::string>& changed_nodes, int client_handle) const;
+
+    /// =========================================================================
+    // The client state change number. Used to determine what's changed
+    unsigned int client_state_change_no() const { return client_state_change_no_; }
+
+    /// return the number of compound mementos
+    size_t size() const { return compound_mementos_.size(); }
+
+private:
+    bool sync_suite_clock_{false};        // *no* need to persist since only used on server side
+    unsigned int client_state_change_no_; // *no* need to persist since only used on server side
+
+    unsigned int server_state_change_no_{0};
+    unsigned int server_modify_change_no_{0};
+    std::vector<compound_memento_ptr> compound_mementos_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_node_DefsDelta_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/DefsTreeVisitor.hpp 5.13.0-1/libs/node/src/ecflow/node/DefsTreeVisitor.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/DefsTreeVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/DefsTreeVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,132 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_DefsTreeVisitor_HPP
+#define ecflow_node_DefsTreeVisitor_HPP
+
+#include <string>
+#include <vector>
+
+#include <ecflow/node/Alias.hpp>
+#include <ecflow/node/Defs.hpp>
+#include <ecflow/node/Family.hpp>
+#include <ecflow/node/Node.hpp>
+#include <ecflow/node/Suite.hpp>
+#include <ecflow/node/Task.hpp>
+
+namespace ecf {
+
+struct NodeNotFound : public std::runtime_error
+{
+    using std::runtime_error::runtime_error;
+};
+
+template <typename V>
+struct DefsTreeVisitor
+{
+    using path_t  = std::string;
+    using nodes_t = std::vector<const Node*>;
+
+    DefsTreeVisitor(const defs_ptr& defs, V& v) : defs_{*defs}, v_{v} {}
+
+    DefsTreeVisitor(const Defs& defs, V& v) : defs_{defs}, v_{v} {}
+
+    void visit_at(const path_t& path) {
+        nodes_t nodes = nodes_at(path);
+        for (auto node : nodes) {
+            visit(*node);
+        }
+    }
+
+private:
+    const Defs& defs_;
+    V& v_;
+
+private:
+    nodes_t nodes_at(const path_t& path) const {
+        nodes_t nodes;
+        if (path == "/") {
+            std::vector<suite_ptr> suites = defs_.suiteVec();
+            std::transform(std::begin(suites), std::end(suites), std::back_inserter(nodes), [](const suite_ptr& ptr) {
+                return static_cast<Node*>(ptr.get());
+            });
+        }
+        else {
+            nodes = nodes_t{get_node(path).get()};
+        }
+        return nodes;
+    }
+
+    node_ptr get_node(const std::string& path) const {
+        if (node_ptr node = defs_.findAbsNode(path); node) {
+            return node;
+        }
+
+        throw NodeNotFound(std::string{"Unable to find node: "} + path);
+    }
+
+    void visit(const Node& node) {
+
+        if (auto found = dynamic_cast<const Suite*>(&node); found) {
+            // Visit suite itself
+            v_.begin_visit(*found);
+            // Visit suite children
+            for (auto&& entry : found->nodeVec()) {
+                visit(*entry.get());
+            }
+            v_.end_visit(*found);
+            return;
+        }
+
+        if (auto found = dynamic_cast<const Family*>(&node); found) {
+            // Visit family itself
+            v_.begin_visit(*found);
+            // Visit family children
+            for (auto&& entry : found->nodeVec()) {
+                visit(*entry.get());
+            }
+            v_.end_visit(*found);
+            return;
+        }
+
+        if (auto found = dynamic_cast<const Task*>(&node); found) {
+            // Visit task itself
+            v_.begin_visit(*found);
+            // Visit task children (i.e. aliases)
+            std::vector<alias_ptr> aliases;
+            found->get_all_aliases(aliases);
+            for (const auto& entry : aliases) {
+                visit(*entry.get());
+            }
+            v_.end_visit(*found);
+            return;
+        }
+
+        if (auto found = dynamic_cast<const Alias*>(&node); found) {
+            // Visit alias itself
+            v_.begin_visit(*found);
+            v_.end_visit(*found);
+            return;
+        }
+
+        // Important!
+        // If this point is reached, then some kind of Node isn't being properly handled.
+        panic();
+    }
+
+    static void panic() {
+        assert(false);
+        std::terminate();
+    }
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_DefsTreeVisitor_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/EcfFile.cpp 5.13.0-1/libs/node/src/ecflow/node/EcfFile.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/EcfFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/EcfFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1875 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/EcfFile.hpp"
+
+#include <cerrno>
+#include <memory>
+#include <sstream>
+#include <stdexcept>
+
+#include <sys/stat.h>
+#include <sys/wait.h> // for waitpid
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Submittable.hpp"
+
+// #define DEBUG_ECF_ 1
+// #define DEBUG_PRE_PROCESS 1
+// #define DEBUG_PRE_PROCESS_INCLUDES 1    // be careful with this as it will skew  the diffs in test code
+// #define DEBUG_MIGRATE 1                 // for TEST ONLY
+
+// #define DEBUG_PRE_PROCESS_OUTPUT 1
+// #define DEBUG_VAR_SUB_OUTPUT 1
+// #define DEBUG_MAN_FILE 1
+
+#ifdef DEBUG_ECF_
+    #include <iostream>
+#endif
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+
+static const char* T_NOPP        = "nopp";
+static const char* T_COMMENT     = "comment";
+static const char* T_MANUAL      = "manual";
+static const char* T_END         = "end";
+static const char* T_ECFMICRO    = "ecfmicro";
+static const char* T_INCLUDE     = "include ";
+static const char* T_INCLUDENOPP = "includenopp ";
+static const char* T_INCLUDEONCE = "includeonce ";
+
+static void vector_to_string(const std::vector<std::string>& vec, std::string& str) {
+    // Determine size of string, to avoid reallocation
+    size_t the_string_size = 0;
+    size_t theSize         = vec.size();
+    for (size_t i = 0; i < theSize; i++) {
+        the_string_size += vec[i].size() + 1;
+    } // +1 is for "\n";
+    str.reserve(str.size() + the_string_size);
+
+    // populate string using the vector
+    for (size_t i = 0; i < theSize; i++) {
+        str += vec[i];
+        str += "\n";
+    }
+}
+
+EcfFile::EcfFile() = default;
+
+EcfFile& EcfFile::operator=(const EcfFile& rhs) {
+    /// This preserves the caches, used to avoid opening/stat of include file more than once.
+    // assign in order or declaration
+    node_               = rhs.node_;
+    ecfMicroCache_      = rhs.ecfMicroCache_;
+    script_path_or_cmd_ = rhs.script_path_or_cmd_;
+    jobLines_.resize(0); // the most expensive
+    job_size_.clear();
+    script_origin_             = rhs.script_origin_;
+    ecf_file_search_algorithm_ = rhs.ecf_file_search_algorithm_;
+    return *this;
+}
+
+// ==================================================================================
+// Avoid making any data model/defs state changes. Changes like:
+//       node_->flag().set(ecf::Flag::NO_SCRIPT);
+// Which will cause a state change.
+// If the script fails then it is up to the calling Task to set this flag
+// This class is also used to extract the scripts/manual, etc form
+// a read only command. hence this class cannot make state changes
+// ===================================================================================
+EcfFile::EcfFile(Node* t,
+                 const std::string& pathToEcfFileOrCommand,
+                 EcfFile::Origin script_origin,
+                 EcfFile::EcfFileSearchAlgorithm search_algo)
+    : node_(t),
+      script_path_or_cmd_(pathToEcfFileOrCommand),
+      script_origin_(script_origin),
+      ecf_file_search_algorithm_(search_algo) {
+    node_->findParentUserVariableValue(Str::ECF_MICRO(), ecfMicroCache_);
+    if (ecfMicroCache_.empty() || ecfMicroCache_.size() != 1) {
+        std::stringstream ss;
+        ss << "EcfFile::EcfFile: Node " << t->absNodePath() << " is referencing a invalid ECF_MICRO variable(' "
+           << ecfMicroCache_ << "). ECF_MICRO when overridden, must be a single character.";
+        throw std::runtime_error(ss.str());
+    }
+
+#ifdef DEBUG_ECF_
+    cout << "   EcfFile::EcfFile pathToEcfFileOrCommand = " << script_path_or_cmd_ << " script_type = " << script_type
+         << "\n";
+#endif
+}
+
+void EcfFile::manual(std::string& theManual) {
+    /// Pre-process the file accessible from the server
+    std::vector<std::string> lines;
+    std::string error_msg;
+    EcfFile::Type file_type = (node_->isSubmittable()) ? EcfFile::SCRIPT : EcfFile::MANUAL;
+    if (!open_script_file(script_path_or_cmd_, file_type, lines, error_msg)) {
+        std::stringstream ss;
+        ss << "EcfFile::manual: For node " << node_->debugNodePath() << ", failed to open file " << script_path_or_cmd_
+           << " : " << error_msg;
+        throw std::runtime_error(ss.str());
+    }
+
+    // expand all %includes this will expand %includenopp by enclosing in %nopp %end, will populate jobLines_
+    PreProcessor data(this, "EcfFile::manual:");
+    data.preProcess(lines);
+
+    // perform variable sub's but don't error if failure
+    try {
+        JobsParam dummy; // create jobs = false, spawn jobs =  false
+        variableSubstitution(dummy);
+    }
+    catch (...) {
+    }
+
+    vector<string> theManualLines;
+    if (!extractManual(jobLines_, theManualLines, error_msg)) {
+        std::stringstream ss;
+        ss << "EcfFile::manual: extraction failed for task " << node_->absNodePath() << " " << error_msg;
+        throw std::runtime_error(ss.str());
+    }
+
+    if (theManualLines.empty()) {
+        // There is no %manual -> %end in the file. However this may be .man file for Suites/Family
+        // For this case just include the pre-processed contents as is, ie since the whole file
+        // is the manual
+        if (node_->isNodeContainer()) {
+            vector_to_string(jobLines_, theManual);
+            return;
+        }
+    }
+
+    vector_to_string(theManualLines, theManual);
+}
+
+std::string EcfFile::origin_str(EcfFile::Origin origin) {
+    string ret;
+    switch (origin) {
+        case ECF_FILES:
+            ret = "ECF_FILES";
+            break;
+        case ECF_HOME:
+            ret = "ECF_HOME";
+            break;
+        case ECF_SCRIPT:
+            ret = "ECF_SCRIPT";
+            break;
+        case ECF_FETCH_CMD:
+            ret = "ECF_FETCH";
+            break;
+        case ECF_SCRIPT_CMD:
+            ret = "ECF_SCRIPT_CMD";
+            break;
+    }
+    return ret;
+}
+
+std::string EcfFile::search_algorithm_str(EcfFile::EcfFileSearchAlgorithm sa) {
+    string ret;
+    switch (sa) {
+        case PRUNE_ROOT:
+            ret = "PRUNE_ROOT";
+            break;
+        case PRUNE_LEAF:
+            ret = "PRUNE_LEAF";
+            break;
+    }
+    return ret;
+}
+
+std::string EcfFile::ecf_file_origin_dump() const {
+    string origin = "# ecf_script_origin :";
+    switch (script_origin_) {
+        case ECF_FILES: {
+            origin += " ECF_FILES(";
+            if (ecf_file_search_algorithm_ == EcfFile::PRUNE_ROOT)
+                origin += "PRUNE_ROOT) : ";
+            else
+                origin += "PRUNE_LEAF) : ";
+            break;
+        }
+        case ECF_HOME: {
+            origin += " ECF_HOME(";
+            if (ecf_file_search_algorithm_ == EcfFile::PRUNE_ROOT)
+                origin += "PRUNE_ROOT) : ";
+            else
+                origin += "PRUNE_LEAF) : ";
+            break;
+        }
+        case ECF_SCRIPT:
+            origin += " ECF_SCRIPT : ";
+            break;
+        case ECF_FETCH_CMD:
+            origin += " ECF_FETCH : ";
+            break;
+        case ECF_SCRIPT_CMD:
+            origin += " ECF_SCRIPT_CMD : ";
+            break;
+    }
+    origin += script_path_or_cmd_;
+    return origin;
+}
+
+void EcfFile::script(std::string& theScript) const {
+    if (script_origin_ == EcfFile::ECF_SCRIPT) {
+        if (!File::open(script_path_or_cmd_, theScript)) {
+            std::stringstream ss;
+            ss << "EcfFile::script: Could not open script for task/alias " << node_->absNodePath() << " at path "
+               << script_path_or_cmd_ << " (" << strerror(errno) << ")";
+            throw std::runtime_error(ss.str());
+        }
+        return;
+    }
+
+    // record script origin, as a comment on the first line
+    std::vector<std::string> lines;
+    lines.push_back(ecf_file_origin_dump());
+    std::string error_msg;
+    if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, error_msg)) {
+        std::stringstream ss;
+        ss << "EcfFile::script: Could not open script for task/alias " << node_->absNodePath() << " using command "
+           << script_path_or_cmd_;
+        throw std::runtime_error(ss.str());
+    }
+    vector_to_string(lines, theScript);
+}
+
+void EcfFile::pre_process_user_file(std::vector<std::string>& user_edit_file, std::string& pre_processed_file) {
+    // expand all %includes this will expand %includenopp by enclosing in %nopp %end, will populate jobLines_
+    PreProcessor data(this, "EcfFile::pre_process_user_file");
+    data.preProcess(user_edit_file);
+
+    remove_comment_manual_and_nopp_tokens();
+
+    JobsParam dummy;
+    variableSubstitution(dummy);
+
+    vector_to_string(jobLines_, pre_processed_file);
+}
+
+void EcfFile::pre_process(std::string& pre_processed_file) {
+    /// Pre-process the ECF file accessible from the server
+    std::vector<std::string> lines;
+    std::string error_msg;
+    if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, error_msg)) {
+        std::stringstream ss;
+        ss << "EcfFile::pre_process: Failed to open file " << script_path_or_cmd_ << " : " << error_msg;
+        throw std::runtime_error(ss.str());
+    }
+
+    // expand all %includes this will expand %includenopp by enclosing in %nopp %end, will populate jobLines_
+    PreProcessor data(this, "EcfFile::pre_process");
+    data.preProcess(lines);
+
+    /// Find Used variables, *after* all %includes expanded, can throw std::runtime_error
+    get_used_variables(pre_processed_file);
+
+    /// Add pre-processed content
+    vector_to_string(jobLines_, pre_processed_file);
+}
+
+void EcfFile::edit_used_variables(std::string& return_script_with_used_variables) {
+    std::string errorMsg;
+    std::vector<std::string> lines;
+    if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, errorMsg)) {
+        throw std::runtime_error("EcfFile::edit_used_variables: Open script failed : " + errorMsg);
+    }
+
+    // Copy the script file, *BEFORE* expanding the includes
+    std::string script;
+    vector_to_string(lines, script);
+
+    // expand all %includes
+    PreProcessor data(this, "EcfFile::edit_used_variables");
+    data.preProcess(lines);
+
+    /// Find Used variables, *after* all %includes expanded, Can throw std::runtime_error
+    get_used_variables(return_script_with_used_variables);
+
+    /// Return Used variables and SCRIPT before pre-processing
+    return_script_with_used_variables += script;
+}
+
+const std::string& EcfFile::create_job(JobsParam& jobsParam) {
+#ifdef DEBUG_ECF_
+    cout << "EcfFile::createJob task " << node_->absNodePath() << " script_path_or_cmd_ = " << script_path_or_cmd_
+         << "\n";
+#endif
+
+    // NOTE: When editing pure python jobs, we may have *NO* variable specified, but only user_edit_file
+    //       hence whenever we have user_edit_file, we should follow the else part below
+    std::string error_msg;
+    { // add scope to limit lifetime of lines variable
+        std::vector<std::string> lines;
+        if (jobsParam.user_edit_variables().empty() && jobsParam.user_edit_file().empty()) {
+            /// The typical *NORMAL* path
+            if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, error_msg)) {
+                throw std::runtime_error("EcfFile::create_job: failed " + error_msg);
+            }
+        }
+        else {
+            // *USER* edit, two kinds
+            if (jobsParam.user_edit_file().empty()) {
+                // *USE* user variables, but ECF file accessible from the server
+                if (!open_script_file(script_path_or_cmd_, EcfFile::SCRIPT, lines, jobsParam.errorMsg())) {
+                    throw std::runtime_error("EcfFile::create_job: User variables, Could not open script: " +
+                                             error_msg);
+                }
+            }
+            else {
+                // *USE* the user supplied ECF file *AND* user variables
+                lines = jobsParam.user_edit_file();
+            }
+        }
+
+        // expand all %includes this will expand %includenopp by enclosing in %nopp %end
+
+        PreProcessor data(this, "EcfFile::create_job");
+        data.preProcess(lines);
+    }
+
+#ifdef DEBUG_PRE_PROCESS_OUTPUT
+    std::string err;
+    File::create("preProcess" + get_extn(), jobLines_, err);
+#endif
+
+    // _IF_ ECF_CLIENT is specified provide Special support for migration.
+    // The variable ECF_CLIENT is used to specify the path to client exe.
+    // This is then used to replace smsinit,smscomplete, smsevent,smsmeter.smslabel,smsabort
+    std::string clientPath;
+    if (node_->findParentUserVariableValue("ECF_CLIENT", clientPath)) {
+        if (!replaceSmsChildCmdsWithEcf(clientPath, error_msg)) {
+            throw std::runtime_error("EcfFile::create_job: ECF_CLIENT replacement failed " + error_msg);
+        }
+#ifdef DEBUG_MIGRATE
+        std::string err;
+        File::create("migrate" + get_extn(), jobLines_, err);
+#endif
+    }
+
+    /// Will use *USER* supplied edit variables in preference to node tree variable *IF* supplied
+    /// expand %VAR% or %VAR:sub% & replace %% with %
+    // Allow variable substitution in comment and manual blocks. But if it fails, don't report as an error
+    variableSubstitution(jobsParam);
+
+#ifdef DEBUG_VAR_SUB_OUTPUT
+    std::string err1;
+    File::create("variableSub" + get_extn(), jobLines_, err1);
+#endif
+
+#ifdef DEBUG_MAN_FILE
+    if (!doCreateManFile(error_msg)) {
+        throw std::runtime_error("EcfFile::create_job: manual file creation failed " + error_msg);
+    }
+#endif
+
+    /// Create the user file for tasks, when submitting without aliases,  before removing comments
+    if (node_->isTask() && !jobsParam.user_edit_variables().empty()) {
+        doCreateUsrFile();
+    }
+
+    remove_comment_manual_and_nopp_tokens();
+
+    return doCreateJobFile(jobsParam /* this is only past in for profiling */); // create job on disk
+}
+
+void EcfFile::extract_used_variables(NameValueMap& used_variables_as_map,
+                                     const std::vector<std::string>& script_lines) {
+    // we only process the contents of the FIRST %comment  %end
+    bool comment   = false;
+    size_t theSize = script_lines.size();
+    for (size_t i = 0; i < theSize; ++i) {
+
+        // std::cout << "EcfFile::extract_used_variables found:'" << script_lines[i] << "\n";
+        if (script_lines[i].empty())
+            continue;
+
+        // take into account micro char during variable substitution
+        string::size_type ecfmicro_pos = script_lines[i].find(Ecf::MICRO());
+        if (ecfmicro_pos == 0) {
+
+            // We cannot do variable substitution between %nopp/%end
+            if (script_lines[i].find(T_COMMENT) == 1) {
+                comment = true;
+                continue;
+            }
+            if (script_lines[i].find(T_NOPP) == 1) {
+                return;
+            }
+            if (script_lines[i].find(T_MANUAL) == 1) {
+                return;
+            }
+            if (script_lines[i].find(T_END) == 1) {
+                return;
+            }
+        }
+
+        if (comment) {
+
+            // expect  name =  value
+            string::size_type equal_pos = script_lines[i].find("=");
+            if (equal_pos == string::npos)
+                continue;
+            string name  = script_lines[i].substr(0, equal_pos);
+            string value = script_lines[i].substr(equal_pos + 1);
+            ecf::algorithm::trim(name);
+            ecf::algorithm::trim(value);
+
+            // std::cout << "   extracted as '" << name << "' = '" << value << "'\n";
+            used_variables_as_map.insert(std::make_pair(name, value));
+        }
+    }
+}
+
+/**
+ * Retrieve the set of paths defined by ECF_INCLUDE.
+ *
+ * ECF_INCLUDE is either a single path, or a list of paths (separated by ':').
+ * The content of ECF_INCLUDE can reference ecFlow variables, which are replaced in the result.
+ *
+ * @param ecf
+ *   The ECF file to consider (the Node directly related with the file determines which ECF_INCLUDE value is used)
+ *
+ * @return
+ *   An empty set if ECF_INCLUDE is not defined; otherwise, the set of paths defined by ECF_INCLUDE, after resolving
+ *   all ecFlow variables.
+ */
+std::vector<std::string> EcfFile::get_ecf_include_paths(const EcfFile& ecf) {
+    assert(ecf.node_);
+    const Node& node = *ecf.node_;
+
+    std::string ecf_include;
+    node.findParentUserVariableValue(Str::ECF_INCLUDE(), ecf_include);
+
+    std::vector<std::string> paths;
+    if (!ecf_include.empty()) {
+
+        // if ECF_INCLUDE is a set a paths, search in order. i.e., like $PATH
+        if (ecf_include.find(':') != std::string::npos) {
+            Str::split(ecf_include, paths, ":");
+        }
+        else {
+            paths = {ecf_include};
+        }
+
+        // Don't rely on hard coded paths. Added for testing, but could be generally useful
+        // since in test scenario ECF_INCLUDE is defined relative to $ECF_HOME
+        for (std::string& path : paths) {
+            node.variable_dollar_substitution(path);
+            node.variableSubstitution(path);
+        }
+    }
+
+    return paths;
+}
+
+bool EcfFile::open_script_file(const std::string& file_or_cmd,
+                               EcfFile::Type type,
+                               std::vector<std::string>& lines,
+                               std::string& errormsg) const {
+#ifdef DEBUG_ECF_
+    std::cout << "EcfFile::open_script_file file(" << file_or_cmd << ") type(" << fileType(type) << ")\n";
+#endif
+    if (file_or_cmd.empty()) {
+        std::stringstream ss;
+        ss << "EcfFile::open_script_file: Could not open ecf " << fileType(type)
+           << " file. Input File/cmd string is empty.";
+        errormsg += ss.str();
+        return false;
+    }
+
+    switch (script_origin_) {
+        case ECF_FILES:
+        case ECF_HOME:
+        case ECF_SCRIPT: {
+            if (type == EcfFile::INCLUDE) {
+                return open_include_file(file_or_cmd, lines, errormsg);
+            }
+            if (!File::splitFileIntoLines(file_or_cmd, lines)) {
+                std::stringstream ss;
+                ss << "Could not open " << fileType(type) << " file:" << file_or_cmd << " (" << strerror(errno) << ")";
+                errormsg += ss.str();
+                return false;
+            }
+            break;
+        }
+
+        case ECF_FETCH_CMD: {
+            // Not tested.
+            string theFile;
+            string theCommand = file_or_cmd; // variables have already been substituted
+            switch (type) {
+                case EcfFile::SCRIPT: {
+                    theCommand += " -s ";
+                    theFile = node_->name() + get_extn();
+                    break;
+                }
+                case EcfFile::INCLUDE:
+                    theCommand += " -i ";
+                    break;
+                case EcfFile::MANUAL: {
+                    theCommand += " -m ";
+                    theFile = node_->name() + get_extn();
+                    break;
+                }
+                case EcfFile::COMMENT: {
+                    theCommand += " -c ";
+                    theFile = node_->name() + get_extn();
+                    break;
+                }
+            }
+            theCommand += theFile;
+            if (!do_popen(theCommand, type, lines, errormsg))
+                return false;
+            break;
+        }
+
+        case ECF_SCRIPT_CMD: {
+            switch (type) {
+                case EcfFile::SCRIPT: {
+                    if (!do_popen(file_or_cmd, type, lines, errormsg))
+                        return false;
+                    break;
+                }
+                case EcfFile::INCLUDE:
+                    return open_include_file(file_or_cmd, lines, errormsg);
+                    break;
+                case EcfFile::MANUAL:
+                case EcfFile::COMMENT:
+                    if (!File::splitFileIntoLines(file_or_cmd, lines)) {
+                        std::stringstream ss;
+                        ss << "Could not open " << fileType(type) << " file:" << file_or_cmd << " (" << strerror(errno)
+                           << ")";
+                        errormsg += ss.str();
+                        return false;
+                    }
+                    break;
+            }
+            break;
+        }
+    }
+    return true;
+}
+
+#define USE_INCLUDE_CACHE 1
+//  ulimit -Hn            # hard limit, of number of open files allowed
+//  ulimit -Sn            # soft limit
+//  ulimit -n <new-limit> # takes affect on current shell only
+//
+//  Check limit of running process:
+//     ps aux | grep process-name
+//     cat /proc/XXX/limits
+//  max open files allowed is:
+//     VM:       cat /proc/sys/fs/file-max:  188086
+//     Desk top: cat /proc/sys/fs/file-max: 3270058
+//  Desktop:
+//     Without cache: real:10.15  user: 5.58  sys: 1.62                                     # opensuse131
+//     With cache:    real: 4.46  user: 3.72  sys: 0.74  Only open/close include file once. # opensuse131
+//     With cache:    real: 3.82  user: 3.22  sys: 0.59  Only open/close include file once. # leap42
+//
+bool EcfFile::open_include_file(const std::string& file, std::vector<std::string>& lines, std::string& errormsg) const {
+#ifdef USE_INCLUDE_CACHE
+    // SEARCH THE CACHE
+    size_t include_file_cache_size = include_file_cache_.size();
+    for (size_t i = 0; i < include_file_cache_size; i++) {
+        if (include_file_cache_[i]->path() == file) {
+            // cout << "found " << file << " in cache, cache size = " << include_file_cache_.size() << "\n";
+            if (!include_file_cache_[i]->lines(lines)) {
+                std::stringstream ss;
+                ss << "Could not open include file: " << file << " (" << strerror(errno)
+                   << ") : include file cache size:" << include_file_cache_.size();
+                errormsg += ss.str();
+                return false;
+            }
+            return true;
+        }
+    }
+
+    // cout << "NOT found " << file << " in cache, cache size = " << include_file_cache_.size() << "\n";
+
+    if (include_file_cache_size > 1000) {
+        // avoid hitting limit for open file descriptors ~1024, valgrind(takes 10 fd). clear cache
+        include_file_cache_.clear();
+    }
+
+    // ADD to cache
+    std::shared_ptr<IncludeFileCache> ptr = std::make_shared<IncludeFileCache>(file);
+    include_file_cache_.push_back(ptr);
+
+    if (!ptr->lines(lines)) {
+        if (errno == EMFILE /*Too many open files*/) {
+
+            log(Log::WAR,
+                "EcfFile::open_include_file: Too many files open(errno=EMFILE), Clearing cache, and trying again. "
+                "Check limits with ulimit -Sn");
+            include_file_cache_.clear();
+
+            std::shared_ptr<IncludeFileCache> a_ptr = std::make_shared<IncludeFileCache>(file);
+            include_file_cache_.push_back(a_ptr);
+            if (!a_ptr->lines(lines)) {
+                std::stringstream ss;
+                ss << "Could not open include file: " << file << " (" << strerror(errno)
+                   << ") include file cache size:" << include_file_cache_.size();
+                errormsg += ss.str();
+                return false;
+            }
+        }
+        else {
+            std::stringstream ss;
+            ss << "Could not open include file: " << file << " (" << strerror(errno)
+               << ") include file cache size:" << include_file_cache_.size();
+            errormsg += ss.str();
+            return false;
+        }
+    }
+#else
+    if (!File::splitFileIntoLines(file, lines)) {
+        std::stringstream ss;
+        ss << "Could not open include file:" << file << " (" << strerror(errno) << ")";
+        errormsg += ss.str();
+        return false;
+    }
+#endif
+    return true;
+}
+
+bool EcfFile::do_popen(const std::string& the_cmd,
+                       EcfFile::Type type,
+                       std::vector<std::string>& lines,
+                       std::string& errormsg) const {
+    FILE* fp = popen(the_cmd.c_str(), "r");
+    if (!fp) {
+        std::stringstream ss;
+        ss << "EcfFile::do_popen:: Could not open " << fileType(type) << " via cmd " << the_cmd << " for task "
+           << node_->absNodePath() << " (" << strerror(errno) << ") ";
+        errormsg += ss.str();
+        return false;
+    }
+    char line[LINE_MAX];
+    while (fgets(line, LINE_MAX, fp)) {
+        lines.emplace_back(line);
+        // remove any trailing new lines
+        std::string& the_line = lines.back();
+        if (!the_line.empty() && the_line[the_line.size() - 1] == '\n') {
+            the_line.erase(the_line.begin() + the_line.size() - 1);
+        }
+    }
+    int status = pclose(fp);
+    if (status == -1) {
+        std::stringstream ss;
+        ss << "EcfFile::do_popen: error on pclose for " << fileType(type) << " via cmd " << the_cmd << " for task "
+           << node_->absNodePath() << " (" << strerror(errno) << ") ";
+        errormsg += ss.str();
+        return false;
+    }
+
+    if (WIFEXITED(status)) {
+        // *Normal* termination via exit
+        if (WEXITSTATUS(status)) {
+            std::stringstream ss;
+            ss << "EcfFile::do_popen: non-zero exit : " << fileType(type) << " via cmd " << the_cmd << " for task "
+               << node_->absNodePath() << " (" << strerror(errno) << ") ";
+            errormsg += ss.str();
+            return false;
+        }
+        else {
+            // exit(0) child terminated normally
+            return true;
+        }
+    }
+    if (WIFSIGNALED(status)) {
+        std::stringstream ss;
+        ss << "EcfFile::do_popen: child process terminated by a signal  : " << fileType(type) << " via cmd " << the_cmd
+           << " for task " << node_->absNodePath() << " (" << strerror(errno) << ") ";
+        errormsg += ss.str();
+        return false;
+    }
+
+    return true;
+}
+
+std::string EcfFile::fileType(EcfFile::Type t) {
+    switch (t) {
+        case EcfFile::SCRIPT:
+            return "script";
+            break;
+        case EcfFile::INCLUDE:
+            return "include";
+            break;
+        case EcfFile::MANUAL:
+            return "manual";
+            break;
+        case EcfFile::COMMENT:
+            return "comment";
+            break;
+    }
+    assert(false);
+    return string();
+}
+
+static void replace(string::size_type commentPos,
+                    std::string& jobLine,
+                    const std::string& smsChildCmd,
+                    const std::string& ecfEquiv,
+                    const std::string& clientPath) {
+    string::size_type childPos = jobLine.find(smsChildCmd);
+    if (childPos != std::string::npos) {
+        if (commentPos == std::string::npos) {
+            std::string replace1 = clientPath;
+            replace1 += ecfEquiv;
+            Str::replace(jobLine, smsChildCmd, replace1);
+        }
+        else if (childPos < commentPos) {
+            std::string replace2 = clientPath;
+            replace2 += ecfEquiv;
+            Str::replace(jobLine, smsChildCmd, replace2);
+        }
+    }
+}
+
+bool EcfFile::replaceSmsChildCmdsWithEcf(const std::string& clientPath, std::string& errormsg) {
+    //   smsinit $$          	   ---> ECF_CLIENT(value) --init=$$
+    //   smscomplete         	   ---> ECF_CLIENT(value)
+    //   smsevent eventname       ---> ECF_CLIENT(value) --event=eventname
+    //   smsmeter metername value ---> ECF_CLIENT(value) --meter=metername value
+    //   smslabel value           ---> ECF_CLIENT(value) --label=value
+    //   smswait expr             ---> ECF_CLIENT(value) --wait=expr
+    //   smsabort                 ---> ECF_CLIENT(value) --abort
+    size_t jobLines_size = jobLines_.size();
+    for (size_t i = 0; i < jobLines_size; ++i) {
+
+        // ONLY do the replacement if there is no leading comment
+        string::size_type commentPos = jobLines_[i].find("#");
+        replace(commentPos, jobLines_[i], "smsinit", " --init ", clientPath);
+        replace(commentPos, jobLines_[i], "smscomplete", " --complete ", clientPath);
+        replace(commentPos, jobLines_[i], "smsabort", " --abort ", clientPath);
+        replace(commentPos, jobLines_[i], "smsevent", " --event ", clientPath);
+        replace(commentPos, jobLines_[i], "smsmeter", " --meter ", clientPath);
+        replace(commentPos, jobLines_[i], "smslabel", " --label ", clientPath);
+        replace(commentPos, jobLines_[i], "smswait", " --wait ", clientPath);
+    }
+    return true;
+}
+
+bool EcfFile::extract_ecfmicro(const std::string& line, std::string& ecfmicro, std::string& error_msg) const {
+    if (!Str::get_token(line, 1, ecfmicro)) {
+        std::stringstream ss;
+        ss << "ecfmicro does not have a replacement character, in " << script_path_or_cmd_;
+        error_msg += ss.str();
+        return false;
+    }
+    // This is typically a single character, however $/£ will be multi-character i.e. size 2
+    if (ecfmicro.size() > 2) {
+        std::stringstream ss;
+        ss << "Expected ecfmicro replacement to be a single character, but found '" << ecfmicro << "' "
+           << ecfmicro.size() << " in file : " << script_path_or_cmd_;
+        error_msg += ss.str();
+        return false;
+    }
+    return true;
+}
+
+void EcfFile::variableSubstitution(const JobsParam& jobsParam) {
+    // Allow variable substitution in comment and manual blocks.
+    // But if it fails, don't report as an error
+
+    // get the cached ECF_MICRO variable, typically its one char.
+    string ecfMicro = ecfMicroCache_;
+    char microChar  = ecfMicro[0];
+
+    // We need a stack to properly implement nopp. This is required since we need to pair
+    // the %end, with nopp. i.e. need to handle
+    // %nopp
+    // %comment
+    // %end      // this is paired with comment
+    // %end      // This is paired with nopp
+    const int NOPP    = 0;
+    const int COMMENT = 1;
+    const int MANUAL  = 2;
+    std::vector<int> pp_stack;
+
+    bool nopp            = false;
+    size_t jobLines_size = jobLines_.size();
+    for (size_t i = 0; i < jobLines_size; ++i) {
+
+        // take into account micro char during variable substitution
+        string::size_type ecfmicro_pos = jobLines_[i].find(ecfMicro);
+        if (ecfmicro_pos == 0) {
+
+            // We cannot do variable substitution between %nopp/%end
+            if (jobLines_[i].find(T_MANUAL) == 1) {
+                pp_stack.push_back(MANUAL);
+                continue;
+            }
+            if (jobLines_[i].find(T_COMMENT) == 1) {
+                pp_stack.push_back(COMMENT);
+                continue;
+            }
+            if (jobLines_[i].find(T_NOPP) == 1) {
+                pp_stack.push_back(NOPP);
+                nopp = true;
+                continue;
+            }
+            if (jobLines_[i].find(T_END) == 1) {
+                if (pp_stack.empty())
+                    throw std::runtime_error("EcfFile::variableSubstitution: failed unpaired %end");
+                int last_directive = pp_stack.back();
+                pp_stack.pop_back();
+                if (last_directive == NOPP)
+                    nopp = false;
+                continue;
+            }
+
+            if (jobLines_[i].find(T_ECFMICRO) == 1) { // %ecfmicro #
+                // override ecfMicro char
+                std::string error_msg;
+                if (!extract_ecfmicro(jobLines_[i], ecfMicro, error_msg)) {
+                    throw std::runtime_error("EcfFile::variableSubstitution: failed : " + error_msg);
+                }
+                microChar = ecfMicro[0];
+                continue; // no point in doing variable subs on %ecfmicro ^
+            }
+        }
+        if (nopp)
+            continue;
+
+        /// For variable substitution % can occur anywhere on the line
+        if (ecfmicro_pos != string::npos) {
+
+            /// In the *NORMAL* flow jobsParam.user_edit_variables() will be EMPTY
+            if (!node_->variable_substitution(jobLines_[i], jobsParam.user_edit_variables(), microChar)) {
+
+                // Allow variable substitution in comment and manual blocks.
+                // But if it fails, don't report as an error
+                int last_directive = -1;
+                if (!pp_stack.empty())
+                    last_directive = pp_stack.back();
+                if (last_directive == COMMENT || last_directive == MANUAL)
+                    continue;
+
+                std::stringstream ss;
+                ss << "EcfFile::variableSubstitution: failed : '" << jobLines_[i] << "'";
+                dump_expanded_script_file(jobLines_);
+                throw std::runtime_error(ss.str());
+            }
+        }
+    }
+}
+
+void EcfFile::get_used_variables(std::string& used_variables) const {
+    /// Find Used variables, *after* all %includes expanded
+    NameValueMap used_variables_map;
+    std::string errorMsg;
+    if (!get_used_variables(used_variables_map, errorMsg)) {
+        throw std::runtime_error("EcfFile::get_used_variables: Extract used variables failed : " + errorMsg);
+    }
+
+    if (!used_variables_map.empty()) {
+
+        // add %comment - edit user variable, %end - ecf user variable
+        used_variables = ecfMicroCache_;
+        used_variables += "comment - ecf user variables\n";
+
+        // ***************************************************************************************
+        // Custom handling of dynamic variables, i.e. ECF_TRYNO, ECF_PASS and
+        // any variable that embeds a try number, i.e. ECF_JOB, ECF_JOBOUT
+        // This is required since the try number is *always* incremented *before* job submission,
+        // hence the value extracted from the job file will *not* be accurate, hence we exclude it.
+        // This way at job submission we use the latest/correct value, which is in-sync with JOB OUTPUT
+        // Note: Otherwise the job output will not be in sync
+        //
+        // Custom handling of ECF_PORT,ECF_HOST,ECF_NAME do not show these variables, these variables
+        // including ECF_PASS appear in the script. If the user accidentally edits them,
+        // Child communication with the server will be broken. Hence, not shown.
+        //
+        // All the above are examples of generated variables, which should not really be edited
+        // The used variables are typically *user* variable *in* the scripts, that user may need
+        // to modify. Hence, we have also excluded generated variables SUITE, FAMILY, TASK
+        // ****************************************************************************************
+        for (std::pair<std::string, std::string> item : used_variables_map) {
+            if (item.first.find(Str::ECF_TRYNO()) != std::string::npos)
+                continue;
+            if (item.first.find(Str::ECF_JOB()) != std::string::npos)
+                continue;
+            if (item.first.find(Str::ECF_JOBOUT()) != std::string::npos)
+                continue;
+            if (item.first.find(Str::ECF_PASS()) != std::string::npos)
+                continue;
+            if (item.first.find(Str::ECF_PORT()) != std::string::npos)
+                continue;
+            if (item.first.find(Str::ECF_HOST()) != std::string::npos)
+                continue;
+            if (item.first.find(Str::ECF_NAME()) != std::string::npos)
+                continue;
+
+            // We must use exact match, to avoid user variables like ESUITE,EFAMILY,ETASK
+            if (item.first == Str::TASK())
+                continue;
+            if (item.first == Str::FAMILY())
+                continue;
+            if (item.first == "FAMILY1")
+                continue;
+            if (item.first == Str::SUITE())
+                continue;
+            used_variables += item.first;
+            used_variables += " = ";
+            used_variables += item.second;
+            used_variables += "\n";
+        }
+
+        used_variables += ecfMicroCache_;
+        used_variables += "end - ecf user variables\n";
+    }
+}
+
+bool EcfFile::get_used_variables(NameValueMap& used_variables, std::string& errormsg) const {
+    // get the cached ECF_MICRO variable, typically its one char.
+    string ecfMicro = ecfMicroCache_;
+
+    char microChar = ecfMicro[0];
+
+    // We need a stack to properly implement nopp. This is required since we need to pair
+    // the %end, with nopp. i.e. need to handle
+    // %nopp
+    // %comment
+    // %end      // this is paired with comment
+    // %end      // This is paired with nopp
+    const int NOPP    = 0;
+    const int COMMENT = 1;
+    const int MANUAL  = 2;
+    std::vector<int> pp_stack;
+
+    bool nopp = false;
+    std::stringstream ss;
+
+    size_t job_lines_size = jobLines_.size();
+    for (size_t i = 0; i < job_lines_size; ++i) {
+
+        if (jobLines_[i].empty())
+            continue;
+
+        // take into account micro char during variable substitution
+        string::size_type ecfmicro_pos = jobLines_[i].find(ecfMicro);
+        if (ecfmicro_pos == 0) {
+
+            // We cannot do variable substitution between %nopp/%end
+            if (jobLines_[i].find(T_MANUAL) == 1) {
+                pp_stack.push_back(MANUAL);
+                continue;
+            }
+            if (jobLines_[i].find(T_COMMENT) == 1) {
+                pp_stack.push_back(COMMENT);
+                continue;
+            }
+            if (jobLines_[i].find(T_NOPP) == 1) {
+                pp_stack.push_back(NOPP);
+                nopp = true;
+                continue;
+            }
+            if (jobLines_[i].find(T_END) == 1) {
+                if (pp_stack.empty())
+                    throw std::runtime_error("EcfFile::get_used_variables: failed  unpaired %end");
+                int last_directive = pp_stack.back();
+                pp_stack.pop_back();
+                if (last_directive == NOPP)
+                    nopp = false;
+                continue;
+            }
+
+            if (!nopp && jobLines_[i].find(T_ECFMICRO) == 1) { // %ecfmicro #
+                // override ecfMicro char
+                std::string error_msg;
+                if (!extract_ecfmicro(jobLines_[i], ecfMicro, error_msg)) {
+                    throw std::runtime_error("EcfFile::get_used_variables: failed : " + error_msg);
+                }
+                microChar = ecfMicro[0];
+                continue;
+            }
+        }
+        if (nopp)
+            continue;
+
+        if (ecfmicro_pos != string::npos) {
+
+            /// *Note:* currently this modifies jobLines_[i]
+            std::string line_copy = jobLines_[i]; // avoid modifying the jobs Lines, end up doing  variable substitution
+            if (!node_->find_all_used_variables(line_copy, used_variables, microChar)) {
+
+                // Allow variable substitution in comment and manual blocks.
+                // But if it fails, dont report as an error
+                int last_directive = -1;
+                if (!pp_stack.empty())
+                    last_directive = pp_stack.back();
+                if (last_directive == COMMENT || last_directive == MANUAL)
+                    continue;
+
+                ss << "Variable find failed for '" << jobLines_[i] << "'  microChar='" << microChar << "' ";
+                dump_expanded_script_file(jobLines_);
+            }
+        }
+    }
+
+    // Append to error message if any
+    errormsg += ss.str();
+
+    return errormsg.empty();
+}
+
+const std::string& EcfFile::doCreateJobFile(JobsParam& jobsParam) const {
+    if (!jobLines_.empty()) {
+        // Guard against ecf file that exist's but is empty,
+        // no point in creating empty job files for them
+
+        // ECF_JOB is used with ECF_JOB_CMD when submitting a job.
+        // First look for a user variable of name ECF_JOB, otherwise look for
+        // the generated variable, hence this should never fail.
+        // *This* assumes that:
+        //   a/ if the user has overridden ECF_JOB then it has been specified at the task level
+        //      Otherwise findParentVariableValue will find the generated ECF_JOB on the task
+        //   b/ The value of the user variable has a valid directory paths and job file name
+        //   c/ The user will lose the try number.
+        std::string ecf_job;
+        if (!node_->findParentVariableValue(Str::ECF_JOB(), ecf_job)) {
+            LOG_ASSERT(!ecf_job.empty(), "EcfFile::doCreateJobFile: ECF_JOB should have been generated, program error");
+        }
+
+        // *** The location of the ECF_ file may not always be the same as the location
+        // *** of the job file. Job file location is specified by ECF_JOB
+        // cout << "EcfFile::createJob ecf " << script_path_or_cmd_ << " ECF_JOB(" << ecf_job << ")\n";
+
+        if (!File::createMissingDirectories(ecf_job)) {
+            std::stringstream ss;
+            ss << "EcfFile::doCreateJobFile: Could not create missing directories for ECF_JOB " << ecf_job << " ("
+               << strerror(errno) << ")";
+            throw std::runtime_error(ss.str());
+        }
+
+        // Create the jobs file.
+        std::string error_msg;
+        if (!File::create(ecf_job, jobLines_, error_msg)) {
+            std::stringstream ss;
+            if (errno == EMFILE /*Too many open files*/) {
+                // CLEAR cache and try again. Can test with ulimit -n 60, (Base/bin/gcc-5.3.0/release/perf_job_gen
+                // ./metabuilder.def)
+                LogToCout log_to_cout;
+                ss << "EcfFile::doCreateJobFile: Too many files open(errno=EMFILE), include file cache size("
+                   << include_file_cache_.size() << ") Clearing cache. Check limits with ulimit -Sn";
+                log(Log::WAR, ss.str());
+
+                include_file_cache_.clear();
+
+                error_msg.clear();
+                if (!File::create(ecf_job, jobLines_, error_msg)) {
+                    ss << "EcfFile::doCreateJobFile: Could not create job file, even after clearing include cache: "
+                       << error_msg; // error_msg includes strerror(errno)
+                    throw std::runtime_error(ss.str());
+                }
+            }
+            else {
+                ss << "EcfFile::doCreateJobFile: Could not create job file : "
+                   << error_msg; // error_msg includes strerror(errno)
+                throw std::runtime_error(ss.str());
+            }
+        }
+
+        // make the job file executable
+        if (chmod(ecf_job.c_str(), 0755) != 0) {
+            std::stringstream ss;
+            ss << "EcfFile::doCreateJobFile: Could not make job file " << ecf_job << "  executable by using chmod ("
+               << strerror(errno) << ")";
+            throw std::runtime_error(ss.str());
+        }
+
+        // record job size, for placement into log files
+        size_t job_output_size = 0;
+        size_t jobLines_size   = jobLines_.size();
+        // cout << " jobLines_.size() " << jobLines_size << " jobLines_.capacity() " << jobLines_.capacity() << "\n";
+        for (size_t i = 0; i < jobLines_size; ++i)
+            job_output_size += jobLines_[i].size();
+        job_output_size += jobLines_size; // take into account new lines for each line of output
+        job_size_ = "job_size:";
+        job_size_ += ecf::convert_to<std::string>(job_output_size);
+        return job_size_;
+    }
+
+    std::stringstream ss;
+    ss << "EcfFile::doCreateJobFile: The ecf file '" << script_path_or_cmd_ << "' that is associated with task '"
+       << node_->absNodePath() << "' is empty";
+    throw std::runtime_error(ss.str());
+}
+
+fs::path EcfFile::file_creation_path() const {
+    return fs::path(script_or_job_path());
+}
+
+std::string EcfFile::script_or_job_path() const {
+    if (script_origin_ == ECF_SCRIPT)
+        return script_path_or_cmd_;
+
+    // ECF_FETCH or ECF_SCRIPT_CMD
+    std::string ecf_job;
+    (void)node_->findParentVariableValue(Str::ECF_JOB(), ecf_job);
+    return ecf_job;
+}
+
+bool EcfFile::doCreateManFile(std::string& errormsg) {
+    vector<string> manFile;
+    if (!extractManual(jobLines_, manFile, errormsg)) {
+        return false;
+    }
+    if (!manFile.empty()) {
+
+        // find the directory associated with job file and place Man file there.
+        fs::path script_file_path = file_creation_path();
+        fs::path parent_path      = script_file_path.parent_path();
+        if (fs::is_directory(parent_path)) {
+
+            fs::path theManFilePath(parent_path.string() + '/' + node_->name() + File::MAN_EXTN());
+
+            // cout << "EcfFile::doCreateManFile job " << manFile.string() << "\n";
+            if (!File::create(theManFilePath.string(), manFile, errormsg))
+                return false;
+        }
+        else {
+            std::stringstream ss;
+            ss << "man file creation failed. The path '" << script_file_path.parent_path() << "' is not a directory";
+            errormsg += ss.str();
+            return false;
+        }
+    }
+    return true;
+}
+
+void EcfFile::doCreateUsrFile() const {
+    // find the directory associated with ecf file and place .usr file there.
+    fs::path script_file_path = file_creation_path();
+    fs::path parent_path      = script_file_path.parent_path();
+    if (fs::is_directory(parent_path)) {
+
+        fs::path theUsrFilePath(parent_path.string() + '/' + node_->name() + File::USR_EXTN());
+
+        // cout << "EcfFile::doCreateUsrFile job " << theUsrFilePath.string() << "\n";
+        std::string error_msg;
+        if (!File::create(theUsrFilePath.string(), jobLines_, error_msg)) {
+            throw std::runtime_error("EcfFile::doCreateUsrFile: file creation failed : " + error_msg);
+        }
+    }
+    else {
+        std::stringstream ss;
+        ss << "EcfFile::doCreateUsrFile: file creation failed. The path '" << script_file_path.parent_path()
+           << "' is not a directory";
+        throw std::runtime_error(ss.str());
+    }
+}
+
+bool EcfFile::extractManual(const std::vector<std::string>& lines,
+                            std::vector<std::string>& theManualLines,
+                            std::string& errormsg) const {
+    // Note: we have already done pre-processing, ie since the manual is obtained after
+    // all the includes have been pre-procssed, hence most errors should have been caught
+    // get the cached ECF_MICRO variable, typically its one char.
+    string ecfMicro = ecfMicroCache_;
+
+    bool add = false;
+    for (const auto& line : lines) {
+        if (line.find(ecfMicro) == 0) {
+            if (line.find(T_MANUAL) == 1) {
+                add = true;
+                continue;
+            }
+            if (add && line.find(T_END) == 1) {
+                add = false;
+                continue;
+            }
+
+            if (line.find(T_ECFMICRO) == 1) { // %ecfmicro #
+
+                if (!extract_ecfmicro(line, ecfMicro, errormsg)) {
+                    return false;
+                }
+
+                continue;
+            }
+        }
+        if (add) {
+            theManualLines.push_back(line);
+        }
+    }
+    if (add) {
+        std::stringstream ss;
+        ss << "Unterminated manual. Matching 'end' is missing, for " << script_path_or_cmd_;
+        errormsg += ss.str();
+        dump_expanded_script_file(lines);
+        return false;
+    }
+    return true;
+}
+
+void EcfFile::remove_comment_manual_and_nopp_tokens() {
+    // preserve *all* lines between %nopp and %end
+    // remove all line between %comment and %end | %manual and %end, *provided* they are not embedded in %nopp/%end
+    // remove tokens %nopp,%end,%ecfmicro and only remove %comment,%manual if they not embedded in %nopp/%end
+
+    // get the cached ECF_MICRO variable, typically its one char.
+    string ecfMicro = ecfMicroCache_;
+
+    // We need a stack to properly implement nopp. This is required since we need to pair
+    // the %end, with nopp. i.e. need to handle
+    // %nopp       // delete this line
+    // %comment    // preserve
+    // -- comment  // preserve
+    // %end        // preserve , this is paired with comment
+    // blah %blah% // preserve, i.e. don't preprocess
+    // %end        // delete this line, This is paired with nopp
+    //
+    // For the following
+    // %comment    // delete this line
+    // -- comment  // delete this line
+    // %end        // delete this line
+
+    const int NOPP    = 0;
+    const int COMMENT = 1;
+    const int MANUAL  = 2;
+    std::vector<int> pp_stack;
+    bool nopp          = false;
+    bool manual_erase  = false;
+    bool comment_erase = false;
+
+    for (auto i = jobLines_.begin(); i != jobLines_.end(); ++i) {
+
+        string::size_type ecfmicro_pos = (*i).find(ecfMicro);
+        if (ecfmicro_pos == 0) {
+            if ((*i).find(T_MANUAL) == 1) {
+                if (manual_erase) {
+                    std::stringstream ss;
+                    ss << "EcfFile::remove_comment_manual_and_nopp_tokens: Embedded manuals are not allowed in "
+                       << script_path_or_cmd_;
+                    throw std::runtime_error(ss.str());
+                }
+
+                pp_stack.push_back(MANUAL);
+                if (nopp)
+                    continue;         // preserve
+                jobLines_.erase(i--); // remove  %manual
+                manual_erase = true;
+                continue;
+            }
+            if ((*i).find(T_COMMENT) == 1) {
+                if (comment_erase) {
+                    std::stringstream ss;
+                    ss << "EcfFile::remove_comment_manual_and_nopp_tokens: Embedded comments are not allowed in "
+                       << script_path_or_cmd_;
+                    throw std::runtime_error(ss.str());
+                }
+
+                pp_stack.push_back(COMMENT);
+                if (nopp)
+                    continue;         // preserve
+                jobLines_.erase(i--); // remove %comment
+                comment_erase = true;
+                continue;
+            }
+            if ((*i).find(T_NOPP) == 1) {
+                if (nopp) {
+                    std::stringstream ss;
+                    ss << "Embedded nopp are not allowed " << script_path_or_cmd_;
+                    throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
+                }
+
+                pp_stack.push_back(NOPP);
+                nopp = true;
+                jobLines_.erase(i--); // remove %nopp
+                continue;
+            }
+            if ((*i).find(T_END) == 1) {
+                if (pp_stack.empty())
+                    throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed unpaired %end");
+                int last_directive = pp_stack.back();
+                pp_stack.pop_back();
+                if (last_directive == NOPP) {
+                    nopp = false;
+                    jobLines_.erase(i--); // remove %end associated with %nopp
+                    continue;
+                }
+                else if (last_directive == MANUAL) {
+                    manual_erase = false;
+                    if (nopp)
+                        continue;         // preserve
+                    jobLines_.erase(i--); // remove %end associated with %manual
+                    continue;
+                }
+                else if (last_directive == COMMENT) {
+                    comment_erase = false;
+                    if (nopp)
+                        continue;         // preserve
+                    jobLines_.erase(i--); // remove %end associated with %comment
+                    continue;
+                }
+                throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed unpaired %end does "
+                                         "not match nopp,comment or manual");
+            }
+            if (!nopp && (*i).find(T_ECFMICRO) == 1) { // %ecfmicro #
+
+                std::string error_msg;
+                if (!extract_ecfmicro((*i), ecfMicro, error_msg)) {
+                    throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed : " + error_msg);
+                }
+                jobLines_.erase(i--); // remove %ecfmicro &
+                continue;
+            }
+        }
+
+        // *** For No-preprocessor (nopp), we only remove the tokens(%nopp,%end) *NOT* the lines between.
+        // *noop* means skip pre-processing, and keep the lines untouched.
+        if (nopp)
+            continue;
+
+        if (manual_erase || comment_erase) {
+            // remove all line between %comment and %end | %manual and %end
+            jobLines_.erase(i--);
+        }
+    }
+
+    if (nopp) {
+        std::stringstream ss;
+        ss << "Unterminated nopp. Matching 'end' is missing, in " << script_path_or_cmd_;
+        throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
+    }
+    if (manual_erase) {
+        std::stringstream ss;
+        ss << "Unterminated manual. Matching 'end' is missing, in " << script_path_or_cmd_;
+        throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
+    }
+    if (comment_erase) {
+        std::stringstream ss;
+        ss << "Unterminated comment. Matching 'end' is missing, in " << script_path_or_cmd_;
+        throw std::runtime_error("EcfFile::remove_comment_manual_and_nopp_tokens: failed " + ss.str());
+    }
+}
+
+int EcfFile::countEcfMicro(const std::string& line, const std::string& ecfMicro) {
+    // ignore ecfmicro character in comments
+    // However pay special attenstion to:
+    // var="%VAR: # fred%  # %fred
+    if (ecfMicro.empty()) {
+        return 0;
+    }
+
+    int count          = 0;
+    const char theChar = ecfMicro[0];
+    size_t end         = line.size();
+    size_t comment_pos = 0;
+    for (size_t i = 0; i < end; ++i) {
+        if (line[i] == theChar) {
+            count++;
+        }
+        if (line[i] == '#') {
+            if (i == 0)
+                return 0;    // very first character is comment
+            comment_pos = i; // remember *last* comment pos
+        }
+    }
+
+    if (count % 2 != 0 && comment_pos != 0) {
+        // could have:
+        // var="%VAR: # fred%  # %fred
+        // discount trailing #
+        count = 0;
+        for (size_t i = 0; i < comment_pos; ++i) {
+            if (line[i] == theChar) {
+                count++;
+            }
+        }
+    }
+    //	cerr << "line " << line << " count = " << count << "\n";
+    return count;
+}
+
+void EcfFile::dump_expanded_script_file(const std::vector<std::string>& lines) {
+#ifdef DEBUG_PRE_PROCESS
+    std::string err;
+    if (!File::create("tmp" + get_extn(), lines, err))
+        std::cout << "Could not create file tmp.ecf\n";
+#endif
+}
+
+/// returns the extension, i.e. for task->.ecf for alias->.usr
+const std::string& EcfFile::get_extn() const {
+    Submittable* task_or_alias = node_->isSubmittable();
+    if (task_or_alias)
+        return task_or_alias->script_extension();
+    else {
+        std::stringstream ss;
+        ss << "EcfFile::get_extn(): Can only return extension for task/alias but found " << node_->debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    return Str::EMPTY();
+}
+
+// =======================================================================================
+
+PreProcessor::PreProcessor(EcfFile* ecfile, const char* error_context)
+    : ecfile_(ecfile),
+      error_context_(error_context),
+      ecf_micro_(ecfile->ecfMicroCache_),
+      jobLines_(ecfile->jobLines_) {
+    pp_nopp_ = ecf_micro_;
+    pp_nopp_ += T_NOPP;
+    pp_comment_ = ecf_micro_;
+    pp_comment_ += T_COMMENT;
+    pp_manual_ = ecf_micro_;
+    pp_manual_ += T_MANUAL;
+    pp_end_ = ecf_micro_;
+    pp_end_ += T_END;
+
+    /// Clear existing jobLines, pre-processing will populate jobLines_
+    jobLines_.clear();
+    jobLines_.reserve(512); // estimate for includes
+}
+
+PreProcessor::~PreProcessor() = default;
+
+void PreProcessor::preProcess(std::vector<std::string>& script_lines) {
+    bool ignore_end_check = false;
+    if (manual_ || comment_)
+        ignore_end_check = true; // %include inside a %manual || %comment, ignore end check in preProcess
+
+    // preProcess is called recursively, i.e. for processing includes
+    // Uses a Depth first traversal
+    for (auto& line : script_lines) {
+        jobLines_.emplace_back(std::move(line));
+        preProcess_line();
+    }
+
+    if (nopp_)
+        throw std::runtime_error(error_context() + "Unterminated nopp, matching 'end' is missing");
+    if (comment_ && !ignore_end_check)
+        throw std::runtime_error(error_context() + "Unterminated comment, matching 'end' is missing");
+    if (manual_ && !ignore_end_check)
+        throw std::runtime_error(error_context() + "Unterminated manual, matching 'end' is missing");
+}
+
+void PreProcessor::preProcess_line() {
+    const std::string& script_line = jobLines_.back();
+
+    // For variable substitution % can occur anywhere on the line, for pre -processing of
+    // %ecfmicro,%manual,%comment,%end,%include,%includenopp it must be the very *first* character
+    string::size_type ecfmicro_pos = script_line.find(ecf_micro_);
+    if (ecfmicro_pos == string::npos)
+        return;
+
+    // Check for Mismatched micro i.e. %FRED or %FRED%%
+    if (ecfmicro_pos != 0 && !nopp_ && !comment_ && !manual_) {
+        // For variable substitution '%' can occur anywhere on the line.
+        int ecfMicroCount = EcfFile::countEcfMicro(script_line, ecf_micro_);
+        if (ecfMicroCount % 2 != 0) {
+            ecfile_->dump_expanded_script_file(jobLines_);
+            std::stringstream ss;
+            ss << "Mismatched ecfmicro(" << ecf_micro_ << ") count(" << ecfMicroCount << ")  at : " << script_line;
+            throw std::runtime_error(error_context() + ss.str());
+        }
+    }
+
+    // %ecfmicro,%manual,%comment,%end,%include,%includenopp,%includeonce it must be the very *first* character
+    if (ecfmicro_pos != 0)
+        return; // handle 'garbage%include'
+
+#ifdef DEBUG_PRE_PROCESS
+    std::cout << i << ": " << script_line << "\n";
+#endif
+    if (script_line.find(pp_manual_) == 0) {
+        if (comment_ || manual_) {
+            ecfile_->dump_expanded_script_file(jobLines_);
+            std::stringstream ss;
+            ss << "Embedded comments/manuals not supported : '" << script_line << "'";
+            throw std::runtime_error(error_context() + ss.str());
+        }
+        manual_ = true;
+        return;
+    }
+    if (script_line.find(pp_comment_) == 0) {
+        if (comment_ || manual_) {
+            ecfile_->dump_expanded_script_file(jobLines_);
+            std::stringstream ss;
+            ss << "Embedded comments/manuals not supported : '" << script_line << "'";
+            throw std::runtime_error(error_context() + ss.str());
+        }
+        comment_ = true;
+        return;
+    }
+    if (script_line.find(pp_nopp_) == 0) {
+        if (nopp_) {
+            ecfile_->dump_expanded_script_file(jobLines_);
+            std::stringstream ss;
+            ss << "Embedded nopp not supported : '" << script_line << "'";
+            throw std::runtime_error(error_context() + ss.str());
+        }
+        nopp_ = true;
+        return;
+    }
+    if (script_line.find(pp_end_) == 0) {
+        if (comment_) {
+            comment_ = false;
+            return;
+        }
+        if (manual_) {
+            manual_ = false;
+            return;
+        }
+        if (nopp_) {
+            nopp_ = false;
+            return;
+        }
+
+        ecfile_->dump_expanded_script_file(jobLines_);
+        std::stringstream ss;
+        ss << pp_end_ << " found with no matching %comment | %manual | %nopp  : '" << script_line << "'";
+        throw std::runtime_error(error_context() + ss.str());
+    }
+    if (nopp_)
+        return;
+
+    // =================================================================================
+    // Handle ecfmicro replacement
+    // =================================================================================
+    if (script_line.find(T_ECFMICRO) == 1) { // %ecfmicro #
+
+        // keep %ecfmicro in jobs file later processing, i.e. for comments/manuals
+        std::string err;
+        if (!ecfile_->extract_ecfmicro(script_line, ecf_micro_, err)) {
+            throw std::runtime_error(error_context() + err);
+        }
+
+        pp_nopp_ = ecf_micro_;
+        pp_nopp_ += T_NOPP;
+        pp_comment_ = ecf_micro_;
+        pp_comment_ += T_COMMENT;
+        pp_manual_ = ecf_micro_;
+        pp_manual_ += T_MANUAL;
+        pp_end_ = ecf_micro_;
+        pp_end_ += T_END;
+
+        return;
+    }
+    else {
+        if (script_line.find("ecf_micro") == 1) { //  Mistyped ecfmicro
+            throw std::runtime_error(error_context() + "Replace with 'ecf_micro' with 'ecfmicro' at line: '" +
+                                     script_line + "'");
+        }
+    }
+
+    // If there's no second token, when what kind of directive is it ?
+    // allow   : %FRED:val%
+    // disallow: %FRED
+    std::string the_include_token;
+    if (!Str::get_token(script_line, 1, the_include_token)) {
+        int ecfMicroCount = EcfFile::countEcfMicro(script_line, ecf_micro_);
+        if (ecfMicroCount % 2 != 0) {
+            throw std::runtime_error(error_context() + " unrecognised pre-processing directive at: '" + script_line +
+                                     "'");
+        }
+        return;
+    }
+
+    // we only end up here if we have includes
+    preProcess_includes();
+}
+
+void PreProcessor::preProcess_includes() {
+    std::string includedFile;
+    bool fnd_includenopp = false;
+    {
+        // Take note: when we call jobLines_.pop_back() below, script_line will be invalidated
+        const std::string& script_line = jobLines_.back();
+
+        // =================================================================================
+        // order is *IMPORTANT*, hence search for includenopp, includeonce, include
+        // Otherwise string::find() of include will match includenopp and includeonce
+        // =================================================================================
+        bool fnd_includeonce = false;
+        bool fnd_include     = false;
+        fnd_includenopp      = (script_line.find(T_INCLUDENOPP) == 1);
+        if (!fnd_includenopp) {
+            fnd_includeonce = (script_line.find(T_INCLUDEONCE) == 1);
+            if (!fnd_includeonce)
+                fnd_include = (script_line.find(T_INCLUDE) == 1);
+        }
+        if (!fnd_include && !fnd_includenopp && !fnd_includeonce) {
+            if (script_line.find("include") == 1) {
+                throw std::runtime_error(error_context() + ", unrecognised or miss-spelled include at: '" +
+                                         script_line + "'");
+            }
+            return;
+        }
+
+        std::string the_include_token;
+        if (!Str::get_token(script_line, 1, the_include_token)) {
+            throw std::runtime_error(error_context() + "Could not extract include token at : " + script_line);
+        }
+
+#ifdef DEBUG_PRE_PROCESS_INCLUDES
+        // Output the includes for debug purposes. Will appear in preProcess.ecf
+        // Note: Will interfere with diff
+        jobLines_.push_back("========== include of " + the_include_token + " ===========================");
+#endif
+
+        includedFile = getIncludedFilePath(the_include_token, script_line);
+
+        // remove %include from the job lines, since were going to expand or ignore it.
+        // **** input script_line life_time is tied, jobLines_.back(), hence jobLines_.pop_back() will invalidate
+        // script_lines
+        // **** Hence don't use script_line after this point.
+        jobLines_.pop_back();
+
+        // handle %includeonce
+        if (fnd_includeonce) {
+            if (std::find(include_once_set_.begin(), include_once_set_.end(), includedFile) !=
+                include_once_set_.end()) {
+                return; // Already processed once ignore
+            }
+            include_once_set_.push_back(includedFile);
+        }
+    }
+
+#ifdef DEBUG_PRE_PROCESS
+    cout << "EcfFile::preProcess processing " << includedFile << "\n";
+#endif
+
+    // Check for recursive includes. some includes like %include <endt.h>
+    // are included many times, but the include is not recursive.
+    // To get round this will use a simple count.
+    // replace map with vector
+    bool fnd = false;
+    for (auto& p : globalIncludedFileSet_) {
+        if (p.first == includedFile) {
+            fnd = true;
+            if (p.second > 100) {
+                std::stringstream ss;
+                ss << " Recursive include of file " << includedFile << " for " << ecfile_->script_path_or_cmd_;
+                throw std::runtime_error(error_context() + ss.str());
+            }
+            p.second++;
+            break;
+        }
+    }
+    if (!fnd) {
+        globalIncludedFileSet_.emplace_back(includedFile, 0);
+    }
+
+    std::vector<std::string> include_lines;
+    if (fnd_includenopp)
+        include_lines.push_back(ecf_micro_ + T_NOPP);
+    std::string err;
+    if (!ecfile_->open_script_file(includedFile, EcfFile::INCLUDE, include_lines, err)) {
+        throw std::runtime_error(error_context() + err);
+    }
+    if (fnd_includenopp)
+        include_lines.push_back(ecf_micro_ + T_END);
+
+    preProcess(include_lines);
+}
+
+std::string PreProcessor::getIncludedFilePath(const std::string& includedFile1, const std::string& line) {
+    // Include can have following format: [ %include | %includeonce | %includenopp ]
+    //   %include /tmp/file.name   -> /tmp/filename
+    //   %include file.name        -> file.name
+    //   %include "../file.name"   -> script_file_location/../file.name
+    //   %include "./file.name"    -> script_file_location/./file.name
+    //   %include "file.name"      -> %ECF_HOME%/%SUITE%/%FAMILY%/filename
+    //   %include <file.name>      -> %ECF_INCLUDE%/filename || %ECF_HOME%/filename # note: ECF_HOME is always a single
+    //   path
+    //
+    //   %include <%file%.name>        -> %ECF_INCLUDE%/filename || %ECF_HOME%/filename
+    //   %include "%file%.name"        -> %ECF_HOME%/%SUITE%/%FAMILY%/filename
+    //   %include "./%file%.name"      -> script_file_location/./file.name
+    //   %include "/%tmp%/%file%.name" -> /%tmp%/%file%.name
+    //   %include %INCLUDE%            -> any of the above
+    //
+    // When ECF_INCLUDE           -> path1:path2:path3
+    //   %include <filename>      -> path1/filename || path2/filename || path3/filename || ECF_HOME/filename
+
+    // the included file could have variables,(ECFLOW-765), check for miss-matched ecf_micro
+    std::string includedFile = includedFile1;
+    if (includedFile.find(ecf_micro_) != std::string::npos) {
+        int ecfMicroCount = EcfFile::countEcfMicro(includedFile, ecf_micro_);
+        if (ecfMicroCount % 2 != 0) {
+            std::stringstream ss;
+            ss << "Mismatched ecfmicro(" << ecf_micro_ << ") count(" << ecfMicroCount << ") at : " << line;
+            throw std::runtime_error(error_context() + ss.str());
+        }
+        NameValueMap user_edit_variables;
+        ecfile_->node_->variable_substitution(includedFile, user_edit_variables, ecf_micro_[0]);
+    }
+
+    std::string the_include_file = includedFile.substr(1, includedFile.size() - 2);
+    if (includedFile.size() >= 2 && includedFile[1] == '/') {
+        // filename starts with '/' no interpretation return as in
+        // %include </home/ecf/fred.ecf>
+        // %include "/home/ecf/fred.ecf"
+        return the_include_file;
+    }
+
+    Node* node = ecfile_->node_;
+    if (includedFile[0] == '<') {
+
+        auto ecf_include_paths = EcfFile::get_ecf_include_paths(*ecfile_);
+        for (const auto& ecf_include_path : ecf_include_paths) {
+            auto include_path_plus_file = ecf_include_path;
+            include_path_plus_file += '/';
+            include_path_plus_file += the_include_file;
+
+            if (ecfile_->file_exists(include_path_plus_file))
+                return include_path_plus_file;
+        }
+
+        // WE get HERE *if* ECF_INCLUDE not specified, or if specified but file *not found*
+        std::string ecf_include;
+        node->findParentVariableValue(Str::ECF_HOME(), ecf_include);
+        if (ecf_include.empty()) {
+            std::stringstream ss;
+            ss << "ECF_INCLUDE/ECF_HOME not specified, at : " << line;
+            throw std::runtime_error(error_context() + ss.str());
+        }
+
+        ecf_include += '/';
+        ecf_include += the_include_file;
+
+        return ecf_include;
+    }
+    else if (includedFile[0] == '"') {
+
+        // we have two forms: "head.h" & "../head.h"
+
+        //  ECFLOW-274 need to allow:
+        //     - %include "../fred.h"     # this is one directory up
+        //     - %include "./fred.h"      # this is at the same level as script
+        std::string path;
+        if (includedFile.find("./") == 1 || includedFile.find("../") == 1) {
+            // remove the leading and trailing '"'
+            std::string the_included_file = includedFile;
+            Str::removeQuotes(the_included_file);
+
+            // Get the root path, i.e. script_or_job_path() is of the form:
+            //    "/user/home/ma/mao/course/t1.ecf || /user/home/ma/mao/course/t1.job"
+            // we need "/user/home/ma/mao/course/"
+            std::string the_script_or_job_path = ecfile_->script_or_job_path();
+            std::string::size_type last_slash  = the_script_or_job_path.rfind("/");
+            if (last_slash != std::string::npos) {
+                path = the_script_or_job_path.substr(0, last_slash + 1);
+                path += the_included_file;
+                // std::cout << "path == " << path << "\n";
+                return path;
+            }
+        }
+
+        // include contents of %ECF_HOME%/%SUITE%/%FAMILY%/filename
+        node->findParentUserVariableValue(Str::ECF_HOME(), path);
+        if (path.empty()) {
+            std::stringstream ss;
+            ss << "ECF_HOME not specified, at : " << line;
+            throw std::runtime_error(error_context() + ss.str());
+        }
+        path += '/';
+        std::string suite;
+        node->findParentVariableValue("SUITE", suite); // SUITE is a generated variable
+        if (suite.empty()) {
+            std::stringstream ss;
+            ss << "SUITE not specified, at : " << line;
+            throw std::runtime_error(error_context() + ss.str());
+        }
+        path += suite;
+        path += '/';
+        std::string family;
+        node->findParentVariableValue("FAMILY", family); // FAMILY is a generated variable
+        if (family.empty()) {
+            std::stringstream ss;
+            ss << "FAMILY not specified, at : " << line;
+            throw std::runtime_error(error_context() + ss.str());
+        }
+        path += family;
+        path += '/';
+        path += the_include_file; // "filename"
+        return path;
+    }
+
+    // File either has an absolute pathname or is in the current working dir.
+    // include file name as is, from current working directory
+    return includedFile;
+}
+
+std::string PreProcessor::error_context() const {
+    std::string ret(error_context_);
+    ret += ": Failed preprocessing : ";
+    ret += ecfile_->node_->debugNodePath();
+    ret += " : path/cmd(";
+    ret += ecfile_->script_path_or_cmd_;
+    ret += ")\n: ";
+    return ret;
+}
+
+bool EcfFile::file_exists(const std::string& ecf_include) const {
+    //   return fs::exists(ecf_include);
+    size_t file_stat_cache_size = file_stat_cache_.size();
+    for (size_t i = 0; i < file_stat_cache_size; i++) {
+        if (file_stat_cache_[i].first == ecf_include) {
+            // cout << "EcfFile::file_exists " << ecf_include << " found in cache " << file_stat_cache_[i].second <<
+            // "\n";
+            return file_stat_cache_[i].second;
+        }
+    }
+    if (fs::exists(ecf_include)) {
+        // cout << "EcfFile::file_exists " << ecf_include << " exists add to cache\n";
+        file_stat_cache_.emplace_back(ecf_include, true);
+        return true;
+    }
+    // cout << "EcfFile::file_exists " << ecf_include << " does NOT exist add to cache\n";
+    file_stat_cache_.emplace_back(ecf_include, false);
+    return false;
+}
+
+// **********************************************************************************
+
+IncludeFileCache::IncludeFileCache(const std::string& path)
+    : path_(path),
+      fp_(path.c_str(), std::ios_base::in),
+      no_of_lines_(0) {
+}
+
+IncludeFileCache::~IncludeFileCache() {
+    fp_.close();
+}
+
+bool IncludeFileCache::lines(std::vector<std::string>& lns) {
+    if (!fp_)
+        return false;
+
+    if (no_of_lines_ != 0) {
+        lns.reserve(no_of_lines_);
+        fp_.seekg(0); // Using cache, reset pos back to 0
+    }
+
+    // Note if we use: while( getline( theEcfFile, line)), then we will miss the *last* *empty* line
+    string line;
+    while (std::getline(fp_, line)) {
+        lns.push_back(line);
+    }                          // c++11
+    fp_.clear();               // eol fp_ will be in bad state reset. So we can re-use
+    no_of_lines_ = lns.size(); // cache for next time
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/EcfFile.hpp 5.13.0-1/libs/node/src/ecflow/node/EcfFile.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/EcfFile.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/EcfFile.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,234 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_EcfFile_HPP
+#define ecflow_node_EcfFile_HPP
+
+#include <fstream>
+#include <memory>
+
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+// This class is used to minimise file I/0.
+// When job processing the same include file can be opened and closed many time
+// This cache serves to open the include file only once. It halves the job processing time.
+class IncludeFileCache {
+public:
+    explicit IncludeFileCache(const std::string& path);
+    // Disable copy (and move) semantics
+    IncludeFileCache(const IncludeFileCache&)                  = delete;
+    const IncludeFileCache& operator=(const IncludeFileCache&) = delete;
+
+    ~IncludeFileCache();
+
+    const std::string& path() const { return path_; }
+    bool lines(std::vector<std::string>&);
+
+private:
+    std::string path_;
+    std::ifstream fp_; // is not copy constructable
+    size_t no_of_lines_;
+};
+
+/// This class is used in the pre-processing of files( .ecf or .usr or .man typically)
+/// It is used to to create the job file.
+///
+///
+/// Please note the %manual is only created on request from the file cmd.
+/// Even then it is extracted as a string. i.e. no .man file is
+/// created. This is left to the client.
+/// When returning the manual we pre-process the files first
+///
+/// However for testing purpose this capability may be retained.
+
+class EcfFile {
+public:
+    enum Origin {
+        ECF_SCRIPT,    // Look for .ecf file, uses default algorithm to find %includes
+        ECF_HOME,      // default directory for scripts
+        ECF_FILES,     // User specified directory
+        ECF_FETCH_CMD, // pre-process output of ECF_FETCH,     all %includes use same command
+        ECF_SCRIPT_CMD // pre-process output of ECF_SCRIPT_CMD, uses default algorithm to find %includes
+    };
+
+    // Use to record how the ecf_file was located from ECF_FILES and ECF_HOME directories. Default is PRUNE_ROOT
+    enum EcfFileSearchAlgorithm { PRUNE_ROOT, PRUNE_LEAF };
+
+    EcfFile();
+
+    /// This preserves the caches, used to avoid opening/stat of include file more than once.
+    EcfFile& operator=(const EcfFile& rhs);
+
+    /// use default copy constructor, assignment, destructor
+    /// ECF_FETCH  is used obtain the script from running a command  i.e.
+    /// from the version control system.
+    EcfFile(Node*,
+            const std::string& path_to_script_or_fetch_cmd,
+            EcfFile::Origin                 = ECF_SCRIPT,
+            EcfFile::EcfFileSearchAlgorithm = PRUNE_ROOT);
+
+    // The path to the ecf file, empty path means that ecf file could not be located
+    bool valid() const { return !script_path_or_cmd_.empty(); }
+
+    /// This function will return the contents of %manual -> %end for the input file
+    /// It will pre-process the file, then extract the manual form all the pre-processed files
+    /// Will throw std::runtime_error for errors
+    void manual(std::string& theManual);
+
+    /// returns the script, The first line contains the origin of the file/cmd.
+    /// Will throw std::runtime_error for errors
+    void script(std::string& theScript) const;
+
+    const std::string& script_path_or_cmd() const { return script_path_or_cmd_; }
+
+    /// What is the origin of this ecf_file
+    std::string ecf_file_origin_dump() const;
+
+    /// simple accessors
+    Origin ecf_file_origin() const { return script_origin_; }
+    EcfFileSearchAlgorithm ecf_file_search_algorithm() const { return ecf_file_search_algorithm_; }
+    static std::string origin_str(Origin);
+    static std::string search_algorithm_str(EcfFileSearchAlgorithm);
+
+    /// Create the job file from with script of a task or alias.
+    /// Note: the location of the ecf file may not be the same as the job file
+    ///       For creating the job we must use ECF_JOB
+    ///
+    /// _IF_ ECF_CLIENT is specified provide Special support for migration. TEST ONLY
+    /// The variable ECF_CLIENT is used to specify the path to client exe.
+    /// This is then used to replace smsinit,smscomplete, smsevent,smsmeter.smslabel,smsabort
+    /// This function will start the pre processing
+    /// Will throw std::runtime_error for errors
+    const std::string& create_job(JobsParam&);
+
+    /// Process the script file, to add all the used variables, add the start of the file
+    /// between %comment %end, The augmented script is returned in file_with_used_variables
+    /// Will throw std::runtime_error for errors
+    void edit_used_variables(std::string& file_with_used_variables);
+
+    /// Pre-processing involves include expansion and variable substitution
+    /// Will throw std::runtime_error if pre processing fails
+    void pre_process(std::string& pre_processed_file);
+
+    /// Does full pre-processing:
+    ///   - include pre-processing
+    ///   - variable substitution
+    ///   - remove comment and manual sections
+    ///   - ignore %nopp
+    void pre_process_user_file(std::vector<std::string>& user_edit_file, std::string& pre_processed_file);
+
+    /// Searches for the first %comment, then extracts all variables of the form
+    ///   <name>  =  <value>
+    /// and places into map
+    static void extract_used_variables(NameValueMap& used_variables_as_map,
+                                       const std::vector<std::string>& script_lines);
+
+    static std::vector<std::string> get_ecf_include_paths(const EcfFile& ecf);
+
+private:
+    friend class PreProcessor;
+    enum Type { SCRIPT, INCLUDE, MANUAL, COMMENT };
+    static std::string fileType(EcfFile::Type);
+
+    bool open_script_file(const std::string& file,
+                          EcfFile::Type,
+                          std::vector<std::string>& lines,
+                          std::string& errormsg) const;
+    bool open_include_file(const std::string& file, std::vector<std::string>& lines, std::string& errormsg) const;
+
+    bool replaceSmsChildCmdsWithEcf(const std::string& clientPath, std::string& errormsg);
+    void variableSubstitution(const JobsParam&);
+    const std::string& doCreateJobFile(JobsParam&) const;
+    bool doCreateManFile(std::string& errormsg);
+    bool extractManual(const std::vector<std::string>& lines,
+                       std::vector<std::string>& theManualLines,
+                       std::string& errormsg) const;
+
+    void remove_comment_manual_and_nopp_tokens();
+
+    static int countEcfMicro(const std::string& line, const std::string& ecfMicro);
+    static void dump_expanded_script_file(const std::vector<std::string>& lines); // for DEBUG
+
+    /// returns the extension, i.e for task->.ecf for alias->.usr, will throw if node_ is not task or alias
+    const std::string& get_extn() const;
+
+    bool
+    do_popen(const std::string& the_cmd, EcfFile::Type, std::vector<std::string>& lines, std::string& errormsg) const;
+
+    fs::path file_creation_path() const;
+    std::string script_or_job_path() const;
+
+    bool extract_ecfmicro(const std::string& line, std::string& ecfmicro, std::string& error_msg) const;
+
+    /// User edit functions:
+    void get_used_variables(std::string& used_variables) const;
+    bool get_used_variables(NameValueMap& used_variables, std::string& errorMsg) const;
+    void doCreateUsrFile() const;
+    bool file_exists(const std::string& file_path) const;
+
+    Node* node_{nullptr};               // Task or Alias or Container when pre-processing the man files
+    std::string ecfMicroCache_;         // cache value of ECF_MICRO
+    std::string script_path_or_cmd_;    // path to .ecf, .usr file or command
+    std::vector<std::string> jobLines_; // Lines that will form the job file.
+
+    mutable std::vector<std::shared_ptr<IncludeFileCache>> include_file_cache_; // only open include file once
+    mutable std::vector<std::pair<std::string, bool>> file_stat_cache_;         // Minimise calls to stat/kernel calls
+    mutable std::string job_size_;                       // to be placed in log file during job submission
+    EcfFile::Origin script_origin_{EcfFile::ECF_SCRIPT}; // get script from a file, or from running a command
+    EcfFile::EcfFileSearchAlgorithm ecf_file_search_algorithm_{
+        EcfFile::PRUNE_ROOT}; // only used for ECF_FILES and ECF_HOME
+};
+
+// This class is used in expanding(pre-processing) the includes.
+// The pre-processing is done in a depth first fashion (ECFLOW-673)
+class PreProcessor {
+public:
+    explicit PreProcessor(EcfFile*, const char* error_context);
+    // Disable copy (and move) semantics
+    PreProcessor(const PreProcessor&)                  = delete;
+    const PreProcessor& operator=(const PreProcessor&) = delete;
+
+    ~PreProcessor();
+
+    void preProcess(std::vector<std::string>& script_lines);
+
+private:
+    std::string error_context() const;
+
+    // include pre-processing on the included file.
+    // Note: include directives _in_ manual/comment should he handled.
+    //       only include directives in %nopp/%end are ignored
+    void preProcess_line();
+    void preProcess_includes();
+    std::string getIncludedFilePath(const std::string& include, const std::string& line);
+
+private:
+    EcfFile* ecfile_;
+    const char* error_context_;
+
+    std::string pp_nopp_;
+    std::string pp_comment_;
+    std::string pp_manual_;
+    std::string pp_end_;
+    std::string ecf_micro_; // constant until ecfmicro changes, then reset
+
+    std::vector<std::string>& jobLines_;
+
+    std::vector<std::pair<std::string, int>>
+        globalIncludedFileSet_; // test for recursive includes, <no _of times it was included>
+    std::vector<std::string> include_once_set_;
+
+    bool nopp_{false};
+    bool comment_{false};
+    bool manual_{false};
+};
+
+#endif /* ecflow_node_EcfFile_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprAst.cpp 5.13.0-1/libs/node/src/ecflow/node/ExprAst.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprAst.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprAst.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2045 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/ExprAst.hpp"
+
+#include <iostream>
+
+#include "ecflow/core/Cal.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAstVisitor.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+////////////////////////////////////////////////////////////////////////////////////
+
+Ast::~Ast() = default;
+
+// #define DEBUG_WHY 1
+
+bool Ast::why(std::string& theReasonWhy, bool html) const {
+    if (evaluate()) {
+#ifdef DEBUG_WHY
+        std::cout << "   Ast::why evaluates returning\n";
+#endif
+        return false;
+    }
+
+    theReasonWhy = "expression ";
+    theReasonWhy += why_expression(html); // provide additional state
+    theReasonWhy += " is false";
+#ifdef DEBUG_WHY
+    std::cout << "    Ast::why  reason = " << theReasonWhy << "\n";
+#endif
+    return true;
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+AstTop::~AstTop() {
+    delete root_;
+}
+
+void AstTop::accept(ExprAstVisitor& v) {
+    v.visitTop(this);
+    root_->accept(v);
+}
+
+AstTop* AstTop::clone() const {
+    auto* top = new AstTop();
+    top->addChild(root_->clone());
+    return top;
+}
+
+bool AstTop::evaluate() const {
+    if (root_) {
+        return root_->evaluate();
+    }
+
+    LOG_ASSERT(false, "AstTop::evaluate(): assert failed, AST top has no root/children");
+    return false;
+}
+
+bool AstTop::check(std::string& error_msg) const {
+    if (root_) {
+        return root_->check(error_msg);
+    }
+    return true;
+}
+
+std::ostream& AstTop::print(std::ostream& os) const {
+    Indentor in;
+    Indentor::indent(os) << "# Trigger Evaluation Tree\n";
+    if (root_) {
+        Indentor in2;
+        return root_->print(os);
+    }
+    return os;
+}
+
+void AstTop::print_flat(std::ostream& os, bool add_bracket) const {
+    if (root_) {
+        root_->print_flat(os, add_bracket);
+    }
+}
+
+bool AstTop::is_valid_ast(std::string& error_msg) const {
+    if (root_) {
+        return root_->is_valid_ast(error_msg);
+    }
+    error_msg = "AstTop: Abstract syntax tree creation failed";
+    return false;
+}
+
+bool AstTop::why(std::string& theReasonWhy, bool html) const {
+    if (evaluate()) {
+#ifdef DEBUG_WHY
+        std::cout << "   AstTop::why evaluates returning\n";
+#endif
+        return false;
+    }
+    return root_->why(theReasonWhy, html);
+}
+
+std::string AstTop::expression() const {
+    std::string ret = exprType_;
+    if (root_) {
+        ret += " ";
+        ret += root_->expression();
+    }
+    return ret;
+}
+
+std::string AstTop::why_expression(bool html) const {
+    std::string ret = exprType_;
+    if (root_) {
+        ret += " ";
+        ret += root_->why_expression(html);
+    }
+    return ret;
+}
+
+void AstTop::setParentNode(Node* p) {
+    if (root_)
+        root_->setParentNode(p);
+}
+
+void AstTop::invalidate_trigger_references() const {
+    if (root_)
+        root_->invalidate_trigger_references();
+}
+
+//////////////////////////////////////////////////////////////////////////////////////
+
+AstRoot::~AstRoot() {
+    delete left_;
+    delete right_;
+    left_  = nullptr;
+    right_ = nullptr;
+}
+
+void AstRoot::accept(ExprAstVisitor& v) {
+    v.visitRoot(this);
+    left_->accept(v);
+    if (right_)
+        right_->accept(v); // right_ is empty for Not
+}
+
+bool AstRoot::check(std::string& error_msg) const {
+    if (left_ && !left_->check(error_msg))
+        return false;
+    if (right_ && !right_->check(error_msg))
+        return false;
+    return true;
+}
+
+void AstRoot::addChild(Ast* n) {
+    LOG_ASSERT(n, "");
+
+    if (!left_) {
+        left_ = n;
+        return;
+    }
+    if (!right_) {
+        right_ = n;
+        return;
+    }
+
+    LOG_ASSERT(false, "AstRoot::addChild: assert failed: root already has left and right children\n");
+}
+
+std::ostream& AstRoot::print(std::ostream& os) const {
+    // left_ should not be NULL, but keep clang static analyser happy
+    if (left_) {
+        if (left_->isRoot()) {
+            Indentor in;
+            left_->print(os);
+        }
+        else
+            left_->print(os);
+    }
+
+    if (right_) { // right_ is empty for Not
+        if (right_->isRoot()) {
+            Indentor in;
+            right_->print(os);
+        }
+        else
+            right_->print(os);
+        ;
+    }
+    return os;
+}
+
+std::string AstRoot::do_why_expression(const std::string& root, bool html) const {
+    std::string ret;
+    if (left_)
+        ret += left_->why_expression(html);
+    ret += root;
+    if (right_)
+        ret += right_->why_expression(html);
+    return ret;
+}
+
+std::string AstRoot::do_bracket_why_expression(const std::string& root, bool html) const {
+    std::string ret = "(";
+    ret += do_why_expression(root, html);
+    ret += ")";
+    return ret;
+}
+
+std::string AstRoot::do_false_bracket_why_expression(const std::string& root, bool html) const {
+    std::string ret;
+    if (html)
+        ret += "<false>"; // still need guard with html for ecflowview ?
+    ret += do_bracket_why_expression(root, html);
+    if (html)
+        ret += "</false>";
+    return ret;
+}
+
+std::string AstRoot::do_expression(const std::string& root) const {
+    std::string ret;
+    if (left_)
+        ret += left_->expression();
+    ret += root;
+    if (right_)
+        ret += right_->expression();
+    return ret;
+}
+
+std::string AstRoot::do_bracket_expression(const std::string& root) const {
+    std::string ret = "(";
+    ret += do_expression(root);
+    ret += ")";
+    return ret;
+}
+
+void AstRoot::setParentNode(Node* p) {
+    if (left_)
+        left_->setParentNode(p);
+    if (right_)
+        right_->setParentNode(p);
+}
+
+void AstRoot::invalidate_trigger_references() const {
+    if (left_)
+        left_->invalidate_trigger_references();
+    if (right_)
+        right_->invalidate_trigger_references();
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstNot::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitNot(this);
+}
+
+AstNot* AstNot::clone() const {
+    auto* ast = new AstNot();
+    if (left_)
+        ast->addChild(left_->clone());
+    return ast;
+}
+
+std::ostream& AstNot::print(std::ostream& os) const {
+    Indentor::indent(os) << "# NOT (" << evaluate_str() << ")";
+    if (right_)
+        os << " # ERROR has right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstNot::is_valid_ast(std::string& error_msg) const {
+    if (right_) {
+        error_msg = "AstNot: should only have a single root";
+        return false;
+    }
+    if (!left_) {
+        error_msg = "AstNot: Does not have root";
+        return false;
+    }
+    return left_->is_valid_ast(error_msg);
+}
+
+void AstNot::print_flat(std::ostream& os, bool add_bracket) const {
+    os << name_;
+    if (left_) {
+        if (add_bracket)
+            os << "(";
+        left_->print_flat(os, add_bracket);
+        if (add_bracket)
+            os << ")";
+    }
+}
+
+std::string AstNot::expression() const {
+    std::string ret = "NOT ";
+    ret += left_->expression();
+    return ret;
+}
+
+std::string AstNot::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+
+    std::string ret;
+    if (html)
+        ret += "<false>";
+    ret += "not ";
+    ret += left_->why_expression(html);
+    if (html)
+        ret += "</false>";
+    return ret;
+}
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstPlus::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitPlus(this);
+}
+
+AstPlus* AstPlus::clone() const {
+    auto* ast = new AstPlus();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstPlus::print(std::ostream& os) const {
+    Indentor::indent(os) << "# PLUS value(" << value() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstPlus::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstPlus: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstPlus: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstPlus::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " + ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstPlus::expression() const {
+    return do_expression(" + ");
+}
+
+std::string AstPlus::why_expression(bool html) const {
+    return do_why_expression(" + ", html);
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstMinus::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitMinus(this);
+}
+
+AstMinus* AstMinus::clone() const {
+    auto* ast = new AstMinus();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstMinus::print(std::ostream& os) const {
+    Indentor::indent(os) << "# MINUS value(" << value() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstMinus::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstMinus: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstMinus: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstMinus::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " - ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstMinus::expression() const {
+    return do_expression(" - ");
+}
+
+std::string AstMinus::why_expression(bool html) const {
+    return do_why_expression(" - ", html);
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstDivide::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitDivide(this);
+}
+
+AstDivide* AstDivide::clone() const {
+    auto* ast = new AstDivide();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+bool AstDivide::check(std::string& error_msg) const {
+    if (right_ && right_->value() == 0) {
+        error_msg += " Error: Divide by zero in trigger expression";
+        return false;
+    }
+    return true;
+}
+
+int AstDivide::value() const {
+    if (right_->value() == 0) {
+        log(Log::ERR, "Divide by zero in trigger/complete expression");
+        return 0;
+    }
+    return (left_->value() / right_->value());
+}
+
+std::ostream& AstDivide::print(std::ostream& os) const {
+    Indentor::indent(os) << "# DIVIDE value(" << value() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstDivide::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstDivide: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstDivide: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstDivide::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " / ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstDivide::expression() const {
+    return do_expression(" / ");
+}
+
+std::string AstDivide::why_expression(bool html) const {
+    return do_why_expression(" / ", html);
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstMultiply::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitMultiply(this);
+}
+
+AstMultiply* AstMultiply::clone() const {
+    auto* ast = new AstMultiply();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstMultiply::print(std::ostream& os) const {
+    Indentor::indent(os) << "# MULTIPLY value(" << value() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstMultiply::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstMultiply: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstMultiply: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstMultiply::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " * ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstMultiply::expression() const {
+    return do_expression(" * ");
+}
+
+std::string AstMultiply::why_expression(bool html) const {
+    return do_why_expression(" * ", html);
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstModulo::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitModulo(this);
+}
+
+AstModulo* AstModulo::clone() const {
+    auto* ast = new AstModulo();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+bool AstModulo::check(std::string& error_msg) const {
+    if (right_ && right_->value() == 0) {
+        error_msg += " Error: Modulo by zero in trigger expression";
+        return false;
+    }
+    return true;
+}
+
+int AstModulo::value() const {
+    if (right_->value() == 0) {
+        log(Log::ERR, "Modulo by zero in trigger/complete expression");
+        return 0;
+    }
+    return (left_->value() % right_->value());
+}
+
+std::ostream& AstModulo::print(std::ostream& os) const {
+    Indentor::indent(os) << "# Modulo value(" << value() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstModulo::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstModulo: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstModulo: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstModulo::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " % ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstModulo::expression() const {
+    return do_expression(" % ");
+}
+
+std::string AstModulo::why_expression(bool html) const {
+    return do_why_expression(" % ", html);
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstAnd::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitAnd(this);
+}
+
+AstAnd* AstAnd::clone() const {
+    auto* ast = new AstAnd();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstAnd::print(std::ostream& os) const {
+    Indentor::indent(os) << "# AND (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstAnd::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstAnd: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstAnd: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstAnd::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " and ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstAnd::expression() const {
+    return do_bracket_expression(" AND ");
+}
+
+std::string AstAnd::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    return do_false_bracket_why_expression(" and ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstOr::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitOr(this);
+}
+
+AstOr* AstOr::clone() const {
+    auto* ast = new AstOr();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstOr::print(std::ostream& os) const {
+    Indentor::indent(os) << "# OR (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstOr::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstOr: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstOr: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstOr::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " or ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstOr::expression() const {
+    return do_bracket_expression(" OR ");
+}
+
+std::string AstOr::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    return do_false_bracket_why_expression(" or ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstEqual::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitEqual(this);
+}
+
+AstEqual* AstEqual::clone() const {
+    auto* ast = new AstEqual();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstEqual::print(std::ostream& os) const {
+    Indentor::indent(os) << "# EQUAL (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstEqual::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstEqual: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstEqual: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstEqual::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " == ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstEqual::expression() const {
+    return do_bracket_expression(" == ");
+}
+
+std::string AstEqual::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    return do_false_bracket_why_expression(" == ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstNotEqual::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitNotEqual(this);
+}
+AstNotEqual* AstNotEqual::clone() const {
+    auto* ast = new AstNotEqual();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstNotEqual::print(std::ostream& os) const {
+    Indentor::indent(os) << "# NOT_EQUAL (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstNotEqual::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstNotEqual: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstNotEqual: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstNotEqual::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " != ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstNotEqual::expression() const {
+    return do_bracket_expression(" != ");
+}
+
+std::string AstNotEqual::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    return do_false_bracket_why_expression(" != ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstLessEqual::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitLessEqual(this);
+}
+AstLessEqual* AstLessEqual::clone() const {
+    auto* ast = new AstLessEqual();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstLessEqual::print(std::ostream& os) const {
+    Indentor::indent(os) << "# LESS_EQUAL (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstLessEqual::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstLessEqual: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstLessEqual: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstLessEqual::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " <= ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstLessEqual::expression() const {
+    return do_bracket_expression(" <= ");
+}
+
+std::string AstLessEqual::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    return do_false_bracket_why_expression(" <= ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstGreaterEqual::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitGreaterEqual(this);
+}
+AstGreaterEqual* AstGreaterEqual::clone() const {
+    auto* ast = new AstGreaterEqual();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstGreaterEqual::print(std::ostream& os) const {
+    Indentor::indent(os) << "# GREATER_EQUAL (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstGreaterEqual::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstGreaterEqual: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstGreaterEqual: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstGreaterEqual::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " >= ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstGreaterEqual::expression() const {
+    return do_bracket_expression(" >= ");
+}
+
+std::string AstGreaterEqual::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    return do_false_bracket_why_expression(" >= ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstGreaterThan::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitGreaterThan(this);
+}
+AstGreaterThan* AstGreaterThan::clone() const {
+    auto* ast = new AstGreaterThan();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstGreaterThan::print(std::ostream& os) const {
+    Indentor::indent(os) << "# GREATER_THAN (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstGreaterThan::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstGreaterThan: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstGreaterThan: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstGreaterThan::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " > ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstGreaterThan::expression() const {
+    return do_bracket_expression(" > ");
+}
+
+std::string AstGreaterThan::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    return do_false_bracket_why_expression(" > ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstLessThan::accept(ExprAstVisitor& v) {
+    AstRoot::accept(v);
+    v.visitLessThan(this);
+}
+
+AstLessThan* AstLessThan::clone() const {
+    auto* ast = new AstLessThan();
+    if (left_)
+        ast->addChild(left_->clone());
+    if (right_)
+        ast->addChild(right_->clone());
+    return ast;
+}
+
+std::ostream& AstLessThan::print(std::ostream& os) const {
+    Indentor::indent(os) << "# LESS_THAN (" << evaluate_str() << ")";
+    if (!left_)
+        os << " # ERROR has no left_";
+    if (!right_)
+        os << " # ERROR has no right_";
+    os << "\n";
+    return AstRoot::print(os);
+}
+
+bool AstLessThan::is_valid_ast(std::string& error_msg) const {
+    if (!left_) {
+        error_msg = "AstLessThan: has no left part";
+        return false;
+    }
+    if (!right_) {
+        error_msg = "AstLessThan: has no right part";
+        return false;
+    }
+    if (left_->is_valid_ast(error_msg) && right_->is_valid_ast(error_msg)) {
+        return true;
+    }
+    return false;
+}
+
+void AstLessThan::print_flat(std::ostream& os, bool add_bracket) const {
+    if (add_bracket)
+        os << "(";
+    if (left_)
+        left_->print_flat(os, add_bracket);
+    os << " < ";
+    if (right_)
+        right_->print_flat(os, add_bracket);
+    if (add_bracket)
+        os << ")";
+}
+
+std::string AstLessThan::expression() const {
+    return do_bracket_expression(" < ");
+}
+
+std::string AstLessThan::why_expression(bool html) const {
+    if (evaluate())
+        return "true";
+    // Using ' < ' seems to mess up html
+    return do_false_bracket_why_expression(" lt ", html); // false - allows GUI to colour the false expression part
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstLeaf::accept(ExprAstVisitor& v) {
+    v.visitLeaf(this);
+}
+
+///////////////////////////////////////////////////////////////////////////////////
+
+void AstFunction::accept(ecf::ExprAstVisitor& v) {
+    v.visitFunction(this); // Not calling base
+}
+
+AstFunction* AstFunction::clone() const {
+    return new AstFunction(ft_, arg()->clone());
+}
+
+static int digits_in_integer(int number) {
+    int digits = 0;
+    if (number < 0)
+        digits = 1; // remove this line if '-' counts as a digit
+    while (number) {
+        number /= 10;
+        digits++;
+    }
+    return digits;
+}
+
+int AstFunction::value() const {
+    int arg_eval = arg_->value();
+
+    switch (ft_) {
+        case AstFunction::DATE_TO_JULIAN: {
+            // cope with 8 digit, yyyymmdd and 10 digit yyyymmddhh
+            int integer_digits = digits_in_integer(arg_eval);
+            if (integer_digits == 10)
+                arg_eval = arg_eval / 100;
+            else if (integer_digits != 8)
+                return 0;
+            return Cal::date_to_julian(arg_eval);
+        }
+        case AstFunction::JULIAN_TO_DATE:
+            return Cal::julian_to_date(arg_eval);
+        default:
+            assert(false);
+    }
+    return 0;
+}
+
+std::ostream& AstFunction::print(std::ostream& os) const {
+    Indentor in;
+    switch (ft_) {
+        case AstFunction::DATE_TO_JULIAN:
+            return Indentor::indent(os) << "# DATE_TO_JULIAN " << value() << "\n";
+        case AstFunction::JULIAN_TO_DATE:
+            return Indentor::indent(os) << "# JULIAN_TO_DATE " << value() << "\n";
+        default:
+            assert(false);
+    }
+    return os;
+}
+
+void AstFunction::print_flat(std::ostream& os, bool add_brackets) const {
+    switch (ft_) {
+        case AstFunction::DATE_TO_JULIAN:
+            os << "date_to_julian(arg:" << arg_->value() << ") = " << value();
+            break;
+        case AstFunction::JULIAN_TO_DATE:
+            os << "julian_to_date(arg:" << arg_->value() << ") = " << value();
+            break;
+        default:
+            assert(false);
+    }
+}
+
+std::string AstFunction::expression() const {
+    std::stringstream ss;
+    switch (ft_) {
+        case AstFunction::DATE_TO_JULIAN:
+            ss << "date_to_julian( arg:" << arg_->expression() << ") = " << value();
+            break;
+        case AstFunction::JULIAN_TO_DATE:
+            ss << "julian_to_date( arg:" << arg_->expression() << ") = " << value();
+            break;
+        default:
+            assert(false);
+    }
+    return ss.str();
+}
+
+std::string AstFunction::why_expression(bool html) const {
+    std::stringstream ss;
+    switch (ft_) {
+        case AstFunction::DATE_TO_JULIAN:
+            ss << "date_to_julian( arg:" << arg_->why_expression(html) << ") = " << value();
+            break;
+        case AstFunction::JULIAN_TO_DATE:
+            ss << "julian_to_date( arg:" << arg_->why_expression(html) << ") = " << value();
+            break;
+        default:
+            assert(false);
+    }
+    return ss.str();
+}
+
+void AstFunction::setParentNode(Node* n) {
+    if (arg_)
+        arg_->setParentNode(n);
+}
+
+///////////////////////////////////////////////////////////////////////////////////
+void AstInteger::accept(ExprAstVisitor& v) {
+    v.visitInteger(this); // Not calling base
+}
+
+AstInteger* AstInteger::clone() const {
+    auto* ast = new AstInteger(value_);
+    return ast;
+}
+
+std::ostream& AstInteger::print(std::ostream& os) const {
+    Indentor in;
+    return Indentor::indent(os) << "# INTEGER " << value() << "\n";
+}
+
+void AstInteger::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    os << value_;
+}
+
+std::string AstInteger::expression() const {
+    std::stringstream ss;
+    ss << value();
+    return ss.str();
+}
+
+std::string AstInteger::why_expression(bool /*html*/) const {
+    return expression();
+}
+
+///////////////////////////////////////////////////////////////////////////////////
+
+void AstInstant::accept(ExprAstVisitor& v) {
+    v.visitInstant(this); // Not calling base
+}
+
+AstInstant* AstInstant::clone() const {
+    auto* ast = new AstInstant(value_);
+    return ast;
+}
+
+std::ostream& AstInstant::print(std::ostream& os) const {
+    Indentor in;
+    return Indentor::indent(os) << "# Instant " << value_ << "\n";
+}
+
+void AstInstant::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    os << value_;
+}
+
+std::string AstInstant::expression() const {
+    std::stringstream ss;
+    ss << value_;
+    return ss.str();
+}
+
+std::string AstInstant::why_expression(bool /*html*/) const {
+    return expression();
+}
+
+//////////////////////////////////////////////////////////////////////////////////
+
+void AstNodeState::accept(ExprAstVisitor& v) {
+    v.visitNodeState(this); // Not calling base
+}
+
+AstNodeState* AstNodeState::clone() const {
+    return new AstNodeState(state_);
+}
+
+std::ostream& AstNodeState::print(std::ostream& os) const {
+    Indentor in;
+    return Indentor::indent(os) << "# NODE_STATE " << DState::toString(state_) << "(" << value() << ")\n";
+}
+
+void AstNodeState::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    os << DState::toString(state_);
+}
+
+std::string AstNodeState::expression() const {
+    return DState::toString(state_);
+}
+
+std::string AstNodeState::why_expression(bool html) const {
+    if (html)
+        return DState::to_html(state_);
+    return DState::toString(state_);
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstEventState::accept(ExprAstVisitor& v) {
+    v.visitEventState(this); // Not calling base
+}
+
+AstEventState* AstEventState::clone() const {
+    return new AstEventState(state_);
+}
+
+std::ostream& AstEventState::print(std::ostream& os) const {
+    Indentor in;
+    return Indentor::indent(os) << "# EVENT_STATE " << state_ << "\n";
+}
+
+void AstEventState::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    if (state_)
+        os << Event::SET();
+    else
+        os << Event::CLEAR();
+}
+
+std::string AstEventState::expression() const {
+    if (state_)
+        return Event::SET();
+    return Event::CLEAR();
+}
+
+std::string AstEventState::why_expression(bool /*html*/) const {
+    return expression();
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstNode::accept(ExprAstVisitor& v) {
+    v.visitNode(this); // Not calling base
+}
+
+AstNode* AstNode::clone() const {
+    return new AstNode(nodePath_);
+}
+
+DState::State AstNode::state() const {
+    // This function is called hundreds of millions of times
+    Node* refNode = referencedNode(); // call once, could be expensive
+    if (refNode)
+        return refNode->dstate();
+    return DState::UNKNOWN;
+}
+
+Node* AstNode::referencedNode() const {
+    // This function is called hundreds of millions of times
+    // One of the server CPU **bottleneck's** is weak ptr locking
+    // Note: gprof does not report on in-lined functions ?
+    Node* ref = get_ref_node();
+    if (ref) {
+        return ref;
+    }
+    if (parentNode_) {
+        std::string errorMsg;
+        ref_node_ = parentNode_->findReferencedNode(nodePath_, errorMsg);
+        return get_ref_node(); // can be NULL
+    }
+    return nullptr;
+}
+
+Node* AstNode::referencedNode(std::string& errorMsg) const {
+    Node* ref = get_ref_node();
+    if (ref) {
+        return ref;
+    }
+    if (parentNode_) {
+        ref_node_ = parentNode_->findReferencedNode(nodePath_, errorMsg);
+        return get_ref_node(); // can be NULL
+    }
+    return nullptr;
+}
+
+std::ostream& AstNode::print(std::ostream& os) const {
+
+    Node* refNode = referencedNode(); // Only call once
+    Indentor in;
+
+    if (refNode) {
+        Indentor::indent(os) << "# NODE " << nodePath_ << " ";
+        os << DState::toString(refNode->dstate()) << "(" << static_cast<int>(refNode->dstate()) << ")\n";
+    }
+    else {
+        Indentor::indent(os) << "# NODE node(?not-found?) " << nodePath_ << " ";
+        os << DState::toString(DState::UNKNOWN) << "(" << static_cast<int>(DState::UNKNOWN)
+           << ") # check suite filter\n";
+    }
+    return os;
+}
+
+void AstNode::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    os << nodePath_;
+}
+
+std::string AstNode::expression() const {
+    return nodePath_;
+}
+
+std::string AstNode::why_expression(bool html) const {
+    Node* refNode = referencedNode(); // Only call once
+    std::string ret;
+    if (html) {
+        if (refNode)
+            ret = Node::path_href_attribute(refNode->absNodePath(), nodePath_);
+        else
+            ret = Node::path_href_attribute(nodePath_);
+    }
+    else
+        ret = nodePath_;
+
+    if (refNode) {
+        ret += "(";
+        if (html)
+            ret += DState::to_html(refNode->dstate());
+        else
+            ret += DState::toString(refNode->dstate());
+        ret += ")";
+        return ret;
+    }
+    else {
+        ret += "?(";
+        if (html)
+            ret += DState::to_html(DState::UNKNOWN);
+        else
+            ret += DState::toString(DState::UNKNOWN);
+        ret += ")";
+    }
+    return ret;
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+std::string AstFlag::name() const {
+    return ecf::Flag::enum_to_string(flag_);
+}
+
+void AstFlag::accept(ExprAstVisitor& v) {
+    v.visitFlag(this); // Not calling base
+}
+
+AstFlag* AstFlag::clone() const {
+    return new AstFlag(nodePath_, flag_);
+}
+
+int AstFlag::value() const {
+    Node* node = referencedNode();
+    if (node && node->flag().is_set(flag_))
+        return 1;
+    if (parentNode_ && nodePath_ == "/") {
+        Defs* the_defs = parentNode_->defs();
+        if (the_defs && the_defs->flag().is_set(flag_))
+            return 1;
+    }
+    return 0;
+}
+
+Node* AstFlag::referencedNode() const {
+    Node* ref = get_ref_node();
+    if (ref) {
+        return ref;
+    }
+    if (parentNode_) {
+        if (nodePath_ == "/")
+            return nullptr; // reference to defs
+        std::string errorMsg;
+        ref_node_ = parentNode_->findReferencedNode(nodePath_, errorMsg);
+        return get_ref_node(); // can be NULL
+    }
+    return nullptr;
+}
+
+Node* AstFlag::referencedNode(std::string& errorMsg) const {
+    Node* ref = get_ref_node();
+    if (ref) {
+        return ref;
+    }
+    if (parentNode_) {
+        if (nodePath_ == "/")
+            return nullptr; // reference to defs
+        ref_node_ = parentNode_->findReferencedNode(nodePath_, ecf::Flag::enum_to_string(flag_), errorMsg);
+        return get_ref_node(); // can be NULL
+    }
+    return nullptr;
+}
+
+std::ostream& AstFlag::print(std::ostream& os) const {
+
+    Node* refNode = referencedNode(); // Only call once
+    Indentor in;
+
+    if (refNode) {
+        Indentor::indent(os) << "# FLAG_NODE " << nodePath_ << " ";
+        os << ecf::Flag::enum_to_string(flag_) << "(" << static_cast<int>(refNode->flag().is_set(flag_)) << ")\n";
+    }
+    else {
+        Indentor::indent(os) << "# FLAG_NODE node(?not-found?) " << nodePath_ << " ";
+        os << ecf::Flag::enum_to_string(flag_) << "(0) # check suite filter\n";
+    }
+    return os;
+}
+
+void AstFlag::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    os << expression();
+}
+
+std::string AstFlag::expression() const {
+    string ret = nodePath_;
+    ret += "<flag>";
+    ret += ecf::Flag::enum_to_string(flag_);
+    return ret;
+}
+
+std::string AstFlag::why_expression(bool html) const {
+    if (evaluate()) {
+#ifdef DEBUG_WHY
+        cout << " AstFlag::why_expression evaluates returning\n";
+#endif
+        return "true";
+    }
+
+#ifdef DEBUG_WHY
+    cout << " AstFlag::why_expression html " << html << "\n";
+#endif
+
+    Node* ref_node = referencedNode(); // Only call once
+    std::string ret;
+    if (html) {
+        // ecflow_ui expects: [attribute_type]attribute_path:attribute_name(value)
+        // i.e                [limit]/suite/family/task:my_limit(value)
+        // i.e                [flag]/suite/family/task:late(value)
+        std::stringstream display_ss;
+        display_ss << "[flag:" << ecf::Flag::enum_to_string(flag_) << "]" << nodePath_;
+        std::string display_str = display_ss.str();
+
+        std::string ref_str;
+        if (ref_node) {
+            std::stringstream ref_ss;
+            ref_ss << "[flag:" << ecf::Flag::enum_to_string(flag_) << "]" << ref_node->absNodePath();
+            ref_str = ref_ss.str();
+        }
+        else
+            ref_str = display_str;
+
+        ret = Node::path_href_attribute(ref_str, display_str);
+        if (!ref_node)
+            ret += "(?)";
+        else {
+            ret += "(";
+            ret += ecf::convert_to<std::string>(ref_node->flag().is_set(flag_));
+            ret += ")";
+        }
+    }
+    else {
+        ret = nodePath_;
+        if (!ref_node)
+            ret += "(?)";
+        ret += "<flag>";
+        ret += ecf::Flag::enum_to_string(flag_);
+        if (!ref_node)
+            ret += "(?)";
+        else {
+            ret += "(";
+            std::stringstream ss;
+            ss << ref_node->flag().is_set(flag_);
+            ret += ss.str();
+            ret += ")";
+        }
+    }
+    return ret;
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+void AstVariable::accept(ExprAstVisitor& v) {
+    v.visitVariable(this); // Not calling base
+}
+
+AstVariable* AstVariable::clone() const {
+    return new AstVariable(nodePath_, name_);
+}
+
+int AstVariable::value() const {
+    VariableHelper varHelper(this);
+    return varHelper.value();
+}
+
+int AstVariable::minus(Ast* right) const {
+    VariableHelper varHelper(this);
+    return varHelper.minus(right->value());
+}
+
+int AstVariable::plus(Ast* right) const {
+    VariableHelper varHelper(this);
+    return varHelper.plus(right->value());
+}
+
+std::ostream& AstVariable::print(std::ostream& os) const {
+    VariableHelper varHelper(this);
+    return varHelper.print(os);
+}
+
+void AstVariable::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    os << nodePath_ << Str::COLON() << name_;
+}
+
+std::string AstVariable::expression() const {
+    return nodePath_ + Str::COLON() + name_;
+}
+
+std::string AstVariable::why_expression(bool html) const {
+    VariableHelper varHelper(this);
+    std::string ret;
+    std::string varType;
+    int theValue = 0;
+    varHelper.varTypeAndValue(varType, theValue);
+    Node* ref_node = varHelper.theReferenceNode();
+
+    if (html) {
+        // ecflow_ui expects: [attribute_type]attribute_path:attribute_name
+        // i.e                [limit]/suite/family/task:my_limit
+        std::stringstream display_ss;
+        display_ss << "[" << varType << "]" << nodePath_ << ":" << name_;
+        std::string display_str = display_ss.str();
+        std::string ref_str;
+        if (ref_node) {
+            std::stringstream ref_ss;
+            ref_ss << "[" << varType << "]" << ref_node->absNodePath() << ":" << name_;
+            ref_str = ref_ss.str();
+        }
+        else
+            ref_str = display_str;
+
+        ret = Node::path_href_attribute(ref_str, display_str);
+        if (!ref_node)
+            ret += "(?)";
+        ret += "(";
+        ret += ecf::convert_to<std::string>(theValue);
+        ret += ")";
+    }
+    else {
+        ret = nodePath_;
+        if (!ref_node)
+            ret += "(?)";
+        ret += Str::COLON();
+        ret += name_;
+        ret += "(";
+        std::stringstream ss;
+        ss << "type:" << varType << " value:" << theValue;
+        ret += ss.str();
+        ret += ")";
+    }
+    return ret;
+}
+
+Node* AstVariable::referencedNode() const {
+    Node* ref = get_ref_node();
+    if (ref) {
+        return ref;
+    }
+    if (parentNode_) {
+        std::string ignoredErrorMsg;
+        ref_node_ = parentNode_->findReferencedNode(nodePath_, name_, ignoredErrorMsg);
+        return get_ref_node(); // can be NULL
+    }
+    return nullptr;
+}
+
+Node* AstVariable::referencedNode(std::string& errorMsg) const {
+    Node* ref = get_ref_node();
+    if (ref) {
+        return ref;
+    }
+    if (parentNode_) {
+        ref_node_ = parentNode_->findReferencedNode(nodePath_, name_, errorMsg);
+        return get_ref_node(); // can be NULL
+    }
+    return nullptr;
+}
+
+////////////////////////////////////////////////////////////////////////////////////
+
+Node* AstParentVariable::find_node_which_references_variable() const {
+    Node* parent = parentNode_;
+    while (parent) {
+        if (parent->findExprVariable(name_))
+            return parent;
+        parent = parent->parent();
+    }
+    return nullptr;
+}
+
+void AstParentVariable::accept(ExprAstVisitor& v) {
+    v.visitParentVariable(this); // Not calling base
+}
+
+AstParentVariable* AstParentVariable::clone() const {
+    return new AstParentVariable(name_);
+}
+
+int AstParentVariable::value() const {
+    Node* ref_node = find_node_which_references_variable();
+    if (ref_node) {
+        return ref_node->findExprVariableValue(name_);
+    }
+    return 0;
+}
+
+int AstParentVariable::minus(Ast* right) const {
+    Node* ref_node = find_node_which_references_variable();
+    if (ref_node) {
+        return ref_node->findExprVariableValueAndMinus(name_, right->value());
+    }
+    return right->value();
+}
+
+int AstParentVariable::plus(Ast* right) const {
+    Node* ref_node = find_node_which_references_variable();
+    if (ref_node) {
+        return ref_node->findExprVariableValueAndPlus(name_, right->value());
+    }
+    return right->value();
+}
+
+std::ostream& AstParentVariable::print(std::ostream& os) const {
+    Indentor in;
+    Indentor::indent(os) << "# " << Str::COLON() << name_;
+
+    Node* ref_node = find_node_which_references_variable();
+    if (ref_node) {
+        os << " node(" << ref_node->name() << ") ";
+        ref_node->findExprVariableAndPrint(name_, os);
+        os << "\n";
+        return os;
+    }
+    os << " node(?not-found?) value(0)";
+    os << " # check suite filter\n";
+    return os;
+}
+
+void AstParentVariable::print_flat(std::ostream& os, bool /*add_bracket*/) const {
+    os << Str::COLON() << name_;
+}
+
+std::string AstParentVariable::expression() const {
+    return Str::COLON() + name_;
+}
+
+std::string AstParentVariable::why_expression(bool html) const {
+    std::string varType = "variable-not-found";
+    int theValue        = 0;
+    std::string ret;
+    Node* ref_node = find_node_which_references_variable();
+    if (ref_node) {
+        theValue = ref_node->findExprVariableValueAndType(name_, varType);
+    }
+    if (html) {
+        // ecflow_ui expects: [attribute_type]attribute_path:attribute_name
+        // i.e                [limit]/suite/family/task:my_limit
+        std::stringstream display_ss;
+        display_ss << "[" << varType << "]"
+                   << ":" << name_;
+        std::string display_str = display_ss.str();
+        std::string ref_str;
+        if (ref_node) {
+            std::stringstream ref_ss;
+            ref_ss << "[" << varType << "]" << ref_node->absNodePath() << ":" << name_;
+            ref_str = ref_ss.str();
+        }
+        else
+            ref_str = display_str;
+
+        ret = Node::path_href_attribute(ref_str, display_str);
+        if (!ref_node)
+            ret += "(?)";
+        ret += "(";
+        ret += ecf::convert_to<std::string>(theValue);
+        ret += ")";
+    }
+    else {
+        if (!ref_node)
+            ret += "(?)";
+        ret += Str::COLON();
+        ret += name_;
+        ret += "(";
+        std::stringstream ss;
+        ss << "type:" << varType << " value:" << theValue;
+        ret += ss.str();
+        ret += ")";
+    }
+    return ret;
+}
+
+// ===============================================================================
+// class VariableHelper:
+// ===============================================================================
+VariableHelper::VariableHelper(const AstVariable* astVariable) : astVariable_(astVariable), theReferenceNode_(nullptr) {
+    // For *this* constructor we don't care about errors'
+    std::string errorMsg;
+    theReferenceNode_ = astVariable_->referencedNode(errorMsg);
+    if (!theReferenceNode_) {
+        // A node can be NULL  if :
+        // 1/ parentNode is NOT set
+        // 2/ when its a extern path. i.e corresponding suite not loaded yet
+        return;
+    }
+    LOG_ASSERT(errorMsg.empty(), ""); // when a reference node is found, the error msg should be empty
+}
+
+// ***NOTE*** This constructor is called during AST construction***. i.e AstResolveVisitor
+// ********** It is used to report errors and to Flag whether meter or event is used
+// ********** in a trigger expression for the simulator
+VariableHelper::VariableHelper(const AstVariable* astVariable, std::string& errorMsg)
+    : astVariable_(astVariable),
+      theReferenceNode_(nullptr) {
+    // for *this* constructor we want to report errors
+    theReferenceNode_ = astVariable_->referencedNode(errorMsg);
+    if (!theReferenceNode_) {
+        // A node can be NULL  if :
+        // 1/ parentNode is NOT set
+        // 2/ when its a extern path. i.e corresponding suite not loaded yet
+        return;
+    }
+    LOG_ASSERT(errorMsg.empty(), ""); // when a reference node is found, the error msg should be empty
+
+    // Find in order, event, meter, user variable, repeat, generated variable, limit
+    // ALSO: if meter or event mark as used in trigger, for simulator
+    if (theReferenceNode_->findExprVariable(astVariable_->name())) {
+        return;
+    }
+
+    // Check externs if possible
+    Defs* defs = theReferenceNode_->defs();
+    if (defs) {
+        if (defs->find_extern(astVariable_->nodePath(), astVariable_->name())) {
+            return;
+        }
+        if (defs->find_extern(theReferenceNode_->absNodePath(), astVariable_->name())) {
+            return;
+        }
+    }
+
+    std::stringstream ss;
+    ss << "From expression Variable " << astVariable_->nodePath() << Str::COLON() << astVariable_->name();
+    ss << " the referenced node is " << theReferenceNode_->debugNodePath() << "\n";
+    errorMsg += ss.str();
+    errorMsg += "Could not find event, meter, variable, repeat, generated variable, limit or queue of name('";
+    errorMsg += astVariable_->name();
+    errorMsg += "') on node ";
+    errorMsg += theReferenceNode_->debugNodePath();
+    errorMsg += "\n";
+
+    // FAILED to find astVar->name(), for node theReferenceNode on event, meter,
+    // user variable, repeat, generated variable
+    // SET theReferenceNode_ to NULL, since it does nor reference the Expression variable
+    theReferenceNode_ = nullptr;
+}
+
+int VariableHelper::value() const {
+    if (theReferenceNode_) {
+        return theReferenceNode_->findExprVariableValue(astVariable_->name());
+    }
+    return 0;
+}
+
+int VariableHelper::plus(int val) const {
+    if (theReferenceNode_) {
+        return theReferenceNode_->findExprVariableValueAndPlus(astVariable_->name(), val);
+    }
+    return val;
+}
+
+int VariableHelper::minus(int val) const {
+    if (theReferenceNode_) {
+        return theReferenceNode_->findExprVariableValueAndMinus(astVariable_->name(), val);
+    }
+    return -val;
+}
+
+void VariableHelper::varTypeAndValue(std::string& varType, int& theValue) const {
+    if (theReferenceNode_) {
+        theValue = theReferenceNode_->findExprVariableValueAndType(astVariable_->name(), varType);
+        return;
+    }
+    varType  = "variable-not-found";
+    theValue = 0;
+}
+
+std::ostream& VariableHelper::print(std::ostream& os) const {
+    Indentor in;
+    Indentor::indent(os) << "# " << astVariable_->nodePath() << Str::COLON() << astVariable_->name();
+
+    if (theReferenceNode_) {
+        os << " node(" << theReferenceNode_->name() << ") ";
+        theReferenceNode_->findExprVariableAndPrint(astVariable_->name(), os);
+    }
+    else {
+        os << " node(?not-found?) " << astVariable_->nodePath() << " value(0) # check suite filter";
+    }
+    os << "\n";
+    return os;
+}
+
+std::ostream& operator<<(std::ostream& os, const Ast& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstTop& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstRoot& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstNot& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstPlus& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstMinus& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstDivide& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstMultiply& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstModulo& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstAnd& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstOr& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstEqual& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstNotEqual& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstLessEqual& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstGreaterEqual& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstGreaterThan& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstLessThan& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstLeaf& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstInteger& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstInstant& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstNodeState& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstEventState& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstNode& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstVariable& d) {
+    return d.print(os);
+}
+std::ostream& operator<<(std::ostream& os, const AstFlag& d) {
+    return d.print(os);
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprAst.hpp 5.13.0-1/libs/node/src/ecflow/node/ExprAst.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprAst.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprAst.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,726 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ExprAst_HPP
+#define ecflow_node_ExprAst_HPP
+
+// The AST is now demand created, and hence we no longer need to persist it
+
+#include <cassert>
+#include <iosfwd>
+
+#include "ecflow/core/Chrono.hpp"
+#include "ecflow/core/DState.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+namespace ecf {
+class ExprAstVisitor;
+} // namespace ecf
+
+//////////////////////////////////////////////////////////////////////////////////
+class Ast {
+public:
+    Ast() = default;
+    virtual ~Ast();
+
+    std::string evaluate_str() const { return evaluate() ? "true" : "false"; }
+
+    virtual void accept(ecf::ExprAstVisitor&) = 0;
+    virtual Ast* clone() const                = 0;
+    virtual bool is_attribute() const { return false; }
+    virtual bool is_not() const { return false; }
+    virtual bool isleaf() const { return false; }
+    virtual bool isRoot() const { return false; }
+    virtual AstTop* isTop() const { return nullptr; }
+    virtual bool is_evaluateable() const { return false; }
+
+    virtual void addChild(Ast*) {}
+    virtual Ast* left() const { return nullptr; }
+    virtual Ast* right() const { return nullptr; }
+    virtual bool evaluate() const {
+        assert(false);
+        return false;
+    }
+    virtual bool empty() const { return true; }
+    virtual int value() const {
+        assert(false);
+        return 0;
+    }                                                       // only valid for leaf or operators
+    virtual bool check(std::string&) const { return true; } // check divide or modulo by zero
+
+    virtual bool is_valid_ast(std::string& error_msg) const                 = 0;
+    virtual std::ostream& print(std::ostream&) const                        = 0;
+    virtual void print_flat(std::ostream&, bool add_brackets = false) const = 0; // used for test
+    virtual std::string type() const                                        = 0;
+    virtual void exprType(const std::string&) {}
+    virtual std::string name() const { return expression(); } /* ABO */
+    virtual std::string expression() const = 0;               // recreate expression from AST
+    virtual bool why(std::string& /*theReasonWhy*/, bool html = false) const;
+    virtual std::string why_expression(bool html = false) const = 0; // recreate expression from AST for why command
+
+    // Use for data arithmetic for REPEAT Date, Use default implementation for others
+    // Currently *ONLY* works if repeat variable in on LHS
+    virtual int minus(Ast* right) const { return (value() - right->value()); }
+    virtual int plus(Ast* right) const { return (value() + right->value()); }
+
+    virtual void setParentNode(Node*) {} // traverse and set for interested nodes
+    virtual void invalidate_trigger_references() const {}
+};
+
+class AstTop : public Ast {
+public:
+    AstTop() = default;
+    ~AstTop() override;
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstTop* clone() const override;
+
+    Ast* left() const override { return root_; }
+    void addChild(Ast* r) override { root_ = r; }
+    AstTop* isTop() const override { return const_cast<AstTop*>(this); }
+    bool evaluate() const override;
+    bool check(std::string& error_msg) const override;
+
+    bool empty() const override { return (root_) ? false : true; }
+    std::ostream& print(std::ostream&) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+
+    bool why(std::string& theReasonWhy, bool html = false) const override;
+    std::string type() const override { return stype(); }
+    void exprType(const std::string& s) override { exprType_ = s; }
+    static std::string stype() { return "top"; }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    void setParentNode(Node*) override;
+    void invalidate_trigger_references() const override;
+
+private:
+    Ast* root_{nullptr};
+    std::string exprType_; // trigger or complete
+};
+
+// This if one of AND, OR, == != <= >= +, -,*,!,%,/
+class AstRoot : public Ast {
+public:
+    AstRoot() = default;
+    ~AstRoot() override;
+
+    bool isRoot() const override { return true; }
+    bool is_evaluateable() const override { return true; }
+
+    bool check(std::string& error_msg) const override;
+    void accept(ecf::ExprAstVisitor&) override;
+    void addChild(Ast* n) override;
+    Ast* left() const override { return left_; }
+    Ast* right() const override { return right_; }
+    std::ostream& print(std::ostream& os) const override;
+    bool empty() const override { return (left_ && right_) ? false : true; }
+    void setParentNode(Node*) override;
+
+    virtual void set_root_name(const std::string&) {}
+    void invalidate_trigger_references() const override;
+
+protected:
+    std::string do_why_expression(const std::string& root, bool html) const;
+    std::string do_bracket_why_expression(const std::string& root, bool html) const;
+    std::string do_false_bracket_why_expression(const std::string& root, bool html) const;
+
+    std::string do_expression(const std::string& root) const;
+    std::string do_bracket_expression(const std::string& root) const;
+
+protected:
+    Ast* left_{nullptr};
+    Ast* right_{nullptr};
+};
+
+class AstNot : public AstRoot {
+public:
+    AstNot() : name_("! ") {}
+    void accept(ecf::ExprAstVisitor&) override;
+    AstNot* clone() const override;
+    bool is_not() const override { return true; }
+
+    bool evaluate() const override {
+        assert(!right_);
+        return !left_->evaluate();
+    }
+    int value() const override {
+        assert(!right_);
+        return !left_->value();
+    }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "not"; }
+    void set_root_name(const std::string& n) override { name_ = n; }
+
+private:
+    std::string name_;
+};
+
+class AstPlus : public AstRoot {
+public:
+    AstPlus() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstPlus* clone() const override;
+
+    bool evaluate() const override { return true; }
+    int value() const override { return left_->plus(right_); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "plus"; }
+};
+
+class AstMinus : public AstRoot {
+public:
+    AstMinus() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstMinus* clone() const override;
+
+    bool evaluate() const override { return true; }
+    int value() const override { return left_->minus(right_); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "minus"; }
+};
+
+class AstDivide : public AstRoot {
+public:
+    AstDivide() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstDivide* clone() const override;
+    bool evaluate() const override { return true; }
+    bool check(std::string& error_msg) const override;
+    int value() const override; // Log error if right hand side has value of zero
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "divide"; }
+};
+
+class AstMultiply : public AstRoot {
+public:
+    AstMultiply() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstMultiply* clone() const override;
+    bool evaluate() const override { return true; }
+    int value() const override { return (left_->value() * right_->value()); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "multiply"; }
+};
+
+class AstModulo : public AstRoot {
+public:
+    AstModulo() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstModulo* clone() const override;
+    bool check(std::string& error_msg) const override;
+    bool evaluate() const override { return true; }
+    int value() const override; // Log error if right hand side has value of zero
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "modulo"; }
+};
+
+class AstAnd : public AstRoot {
+public:
+    AstAnd() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstAnd* clone() const override;
+    bool evaluate() const override { return (left_->evaluate() && right_->evaluate()); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "and"; }
+};
+
+class AstOr : public AstRoot {
+public:
+    AstOr() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstOr* clone() const override;
+    bool evaluate() const override { return (left_->evaluate() || right_->evaluate()); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "or"; }
+};
+
+class AstEqual : public AstRoot {
+public:
+    AstEqual() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstEqual* clone() const override;
+    bool evaluate() const override { return (left_->value() == right_->value()); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "equal"; }
+};
+
+class AstNotEqual : public AstRoot {
+public:
+    AstNotEqual() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstNotEqual* clone() const override;
+    bool evaluate() const override { return (left_->value() != right_->value()); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "not-equal"; }
+};
+
+class AstLessEqual : public AstRoot {
+public:
+    AstLessEqual() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    AstLessEqual* clone() const override;
+    bool evaluate() const override { return (left_->value() <= right_->value()); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "less-equal"; }
+};
+
+class AstGreaterEqual : public AstRoot {
+public:
+    AstGreaterEqual() = default;
+    bool evaluate() const override { return (left_->value() >= right_->value()); }
+    void accept(ecf::ExprAstVisitor&) override;
+    AstGreaterEqual* clone() const override;
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "greater-equal"; }
+};
+
+class AstGreaterThan : public AstRoot {
+public:
+    AstGreaterThan() = default;
+
+    bool evaluate() const override { return (left_->value() > right_->value()); }
+    void accept(ecf::ExprAstVisitor&) override;
+    AstGreaterThan* clone() const override;
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "greater-than"; }
+};
+
+class AstLessThan : public AstRoot {
+public:
+    AstLessThan() = default;
+
+    bool evaluate() const override { return (left_->value() < right_->value()); }
+    void accept(ecf::ExprAstVisitor&) override;
+    AstLessThan* clone() const override;
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    bool is_valid_ast(std::string& error_msg) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "less-than"; }
+};
+
+//=============================================================================================
+/// class AstLeaf
+/// represents Integer, String, Node State, event State, Node, variable
+/// These always represent the right side of the tree
+class AstLeaf : public Ast {
+public:
+    AstLeaf() = default;
+    void accept(ecf::ExprAstVisitor&) override;
+    bool isleaf() const override { return true; }
+    bool is_valid_ast(std::string&) const override { return true; }
+};
+
+class AstFunction : public AstLeaf {
+public:
+    enum FuncType { DATE_TO_JULIAN, JULIAN_TO_DATE };
+    AstFunction(FuncType ft, Ast* arg) : arg_(arg), ft_(ft) { assert(arg_); }
+    ~AstFunction() override { delete arg_; }
+
+    bool is_evaluateable() const override { return true; }
+    bool evaluate() const override { return value() != 0 ? true : false; }
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstFunction* clone() const override;
+    int value() const override;
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "AstFunction"; }
+    void setParentNode(Node* n) override;
+
+    Ast* arg() const { return arg_; }
+    FuncType ft() const { return ft_; }
+
+private:
+    Ast* arg_;
+    FuncType ft_;
+};
+
+class AstInteger : public AstLeaf {
+public:
+    explicit AstInteger(int value) : value_(value) {}
+
+    bool is_evaluateable() const override { return true; }
+    bool evaluate() const override { return value_; } // -1 -2 1 2 3 evaluates to true, 0 returns false
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstInteger* clone() const override;
+    int value() const override { return value_; }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "integer"; }
+
+private:
+    int value_;
+};
+
+class AstInstant : public AstLeaf {
+public:
+    explicit AstInstant(int value) : value_(ecf::coerce_to_instant(value)) {}
+    explicit AstInstant(ecf::Instant value) : value_(std::move(value)) {}
+
+    bool is_evaluateable() const override { return true; }
+    bool evaluate() const override { return value(); } // -1 -2 1 2 3 evaluates to true, 0 returns false
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstInstant* clone() const override;
+    int value() const override { return ecf::coerce_from_instant(value_); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "integer"; }
+
+private:
+    ecf::Instant value_;
+};
+
+class AstNodeState : public AstLeaf {
+public:
+    explicit AstNodeState(DState::State s) : state_(s) {}
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstNodeState* clone() const override;
+    int value() const override { return static_cast<int>(state_); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "node-state"; }
+
+private:
+    DState::State state_;
+};
+
+class AstEventState : public AstLeaf {
+public:
+    explicit AstEventState(bool b) : state_(b) {}
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstEventState* clone() const override;
+    int value() const override { return state_; }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    static std::string stype() { return "event-state"; }
+
+private:
+    bool state_;
+};
+
+/// This class will need to determine the corresponding node pointer
+/// This is required so that during evaluation we don't need to search for the Node.
+/// represent nodeName(a), dotPath(./a), dot dot path(../a/b)
+///
+/// A Node without a corresponding Node* will return the integer value of
+/// DState::UNKNOWN for the value() function. This will allow for trigger
+/// of the form:  trigger a == complete or a == unknown
+/// to be evaluated.
+
+class AstNode : public AstLeaf {
+public:
+    explicit AstNode(const std::string& n) : parentNode_(nullptr), nodePath_(n) {}
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstNode* clone() const override;
+    int value() const override { return static_cast<int>(state()); }
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    void setParentNode(Node* n) override { parentNode_ = n; }
+    void invalidate_trigger_references() const override { ref_node_.reset(); }
+    static std::string stype() { return "node"; }
+
+    const std::string& nodePath() const { return nodePath_; }
+    Node* referencedNode() const;
+    Node* referencedNode(std::string& errorMsg) const;
+    Node* parentNode() const { return parentNode_; }
+    DState::State state() const;
+
+private:
+    Node* get_ref_node() const { return ref_node_.lock().get(); }
+    Node* parentNode_; // should always be non null, before evaluate.
+    std::string nodePath_;
+    mutable weak_node_ptr ref_node_;
+};
+
+class AstFlag : public AstLeaf {
+public:
+    AstFlag(const std::string& n, ecf::Flag::Type ft) : nodePath_(n), flag_(ft) {}
+
+    std::string name() const override;
+
+    bool is_attribute() const override { return true; }
+    // although AstFlag is leaf, However allow to evaluate to cope with
+    //     ( ../family1/<flag>:late != 0 and ../family1/a:myEvent)
+    // Treat this like an integer
+    bool is_evaluateable() const override { return true; }
+    bool evaluate() const override { return value() != 0 ? true : false; }
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstFlag* clone() const override;
+    int value() const override;
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    void setParentNode(Node* n) override { parentNode_ = n; }
+    void invalidate_trigger_references() const override { ref_node_.reset(); }
+    static std::string stype() { return "flag"; }
+
+    const std::string& nodePath() const { return nodePath_; }
+    Node* referencedNode() const;
+    Node* referencedNode(std::string& errorMsg) const;
+    Node* parentNode() const { return parentNode_; }
+
+private:
+    Node* get_ref_node() const { return ref_node_.lock().get(); }
+
+    std::string nodePath_;
+    Node* parentNode_{nullptr}; // should always be non null, before evaluate.
+    mutable weak_node_ptr ref_node_;
+    ecf::Flag::Type flag_;
+};
+
+/// A variable: This can reference in the CURRENT order:
+///     event,
+///     meter,
+///     user variable,
+///     repeat  variable, for enumerated/string we use the positional value
+///     generated variable
+/// ** IT is treated in a same as an integer, and can appear in that context
+//  ** i.e  "2 == (((/seasplots/lag:YMD / 100 ) % 100) % 3"
+class AstVariable : public AstLeaf {
+public:
+    AstVariable(const std::string& nodePath, const std::string& variablename)
+        : parentNode_(nullptr),
+          nodePath_(nodePath),
+          name_(variablename) {}
+
+    std::string name() const override { return name_; }
+    bool is_attribute() const override { return true; }
+
+    // although AstVariable is leaf, However allow to evaluate to cope with
+    //     ( ../family1/a:myMeter >= 20 and ../family1/a:myEvent)
+    // Treat this like an integer
+    bool is_evaluateable() const override { return true; }
+    bool evaluate() const override { return value() != 0 ? true : false; }
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstVariable* clone() const override;
+    int value() const override;
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    void setParentNode(Node* n) override { parentNode_ = n; }
+    void invalidate_trigger_references() const override { ref_node_.reset(); }
+
+    int minus(Ast* right) const override;
+    int plus(Ast* right) const override;
+
+    Node* parentNode() const { return parentNode_; }
+    Node* referencedNode() const;
+    Node* referencedNode(std::string& errorMsg) const;
+
+    static std::string stype() { return "variable"; }
+    const std::string& nodePath() const { return nodePath_; }
+
+private:
+    Node* get_ref_node() const { return ref_node_.lock().get(); }
+
+    Node* parentNode_;
+    std::string nodePath_;
+    std::string name_;
+    mutable weak_node_ptr ref_node_;
+};
+
+/// A variable: This can reference in the CURRENT order:
+///     event,
+///     meter,
+///     user variable,
+///     repeat  variable, for enumerated/string we use the positional value
+///     generated variable
+/// ** IT is treated in a same as an integer, and can appear in that context
+//  ** i.e  "2 == (((:YMD / 100 ) % 100) % 3"
+class AstParentVariable : public AstLeaf {
+public:
+    explicit AstParentVariable(const std::string& variablename) : parentNode_(nullptr), name_(variablename) {}
+
+    std::string name() const override { return name_; }
+    bool is_attribute() const override { return true; }
+
+    // although  AstParentVariable is leaf, However allow to evaluate to cope with
+    //     ( :myMeter >= 20 and :myEvent)
+    // Treat this like an integer
+    bool is_evaluateable() const override { return true; }
+    bool evaluate() const override { return value() != 0 ? true : false; }
+
+    void accept(ecf::ExprAstVisitor&) override;
+    AstParentVariable* clone() const override;
+    int value() const override;
+    std::ostream& print(std::ostream& os) const override;
+    void print_flat(std::ostream&, bool add_brackets = false) const override;
+    std::string type() const override { return stype(); }
+    std::string expression() const override;
+    std::string why_expression(bool html = false) const override;
+    void setParentNode(Node* n) override { parentNode_ = n; }
+    void invalidate_trigger_references() const override { ref_node_.reset(); }
+
+    int minus(Ast* right) const override;
+    int plus(Ast* right) const override;
+
+    Node* parentNode() const { return parentNode_; }
+    static std::string stype() { return "parent_variable"; }
+
+    Node* find_node_which_references_variable() const;
+    Node* referencedNode() const { return find_node_which_references_variable(); }
+
+private:
+    Node* parentNode_;
+    std::string name_;
+    mutable weak_node_ptr ref_node_;
+};
+
+// Helper class
+class VariableHelper {
+public:
+    explicit VariableHelper(const AstVariable* astVariable);
+    VariableHelper(const AstVariable* astVariable, std::string& errorMsg);
+    // Disable copy (and move) semantics
+    VariableHelper(const VariableHelper&)                  = delete;
+    const VariableHelper& operator=(const VariableHelper&) = delete;
+
+    int value() const;
+    int plus(int) const;
+    int minus(int) const;
+
+    std::ostream& print(std::ostream& os) const;
+    Node* theReferenceNode() const { return theReferenceNode_; }
+
+    void varTypeAndValue(std::string& varType, int& value) const;
+
+private:
+    const AstVariable* astVariable_;
+    Node* theReferenceNode_;
+};
+
+// 17
+std::ostream& operator<<(std::ostream& os, const Ast&);
+std::ostream& operator<<(std::ostream& os, const AstTop&);
+std::ostream& operator<<(std::ostream& os, const AstRoot&);
+std::ostream& operator<<(std::ostream& os, const AstNot&);
+std::ostream& operator<<(std::ostream& os, const AstPlus&);
+std::ostream& operator<<(std::ostream& os, const AstMinus&);
+std::ostream& operator<<(std::ostream& os, const AstMultiply&);
+std::ostream& operator<<(std::ostream& os, const AstDivide&);
+std::ostream& operator<<(std::ostream& os, const AstModulo&);
+std::ostream& operator<<(std::ostream& os, const AstAnd&);
+std::ostream& operator<<(std::ostream& os, const AstOr&);
+std::ostream& operator<<(std::ostream& os, const AstEqual&);
+std::ostream& operator<<(std::ostream& os, const AstNotEqual&);
+std::ostream& operator<<(std::ostream& os, const AstLessEqual&);
+std::ostream& operator<<(std::ostream& os, const AstGreaterEqual&);
+std::ostream& operator<<(std::ostream& os, const AstGreaterThan&);
+std::ostream& operator<<(std::ostream& os, const AstLessThan&);
+std::ostream& operator<<(std::ostream& os, const AstLeaf&);
+std::ostream& operator<<(std::ostream& os, const AstInteger&);
+std::ostream& operator<<(std::ostream& os, const AstInstant&);
+std::ostream& operator<<(std::ostream& os, const AstNodeState&);
+std::ostream& operator<<(std::ostream& os, const AstEventState&);
+std::ostream& operator<<(std::ostream& os, const AstNode&);
+std::ostream& operator<<(std::ostream& os, const AstVariable&);
+std::ostream& operator<<(std::ostream& os, const AstFlag&);
+
+#endif /* ecflow_node_ExprAst_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprAstVisitor.cpp 5.13.0-1/libs/node/src/ecflow/node/ExprAstVisitor.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprAstVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprAstVisitor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,119 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/ExprAstVisitor.hpp"
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Node.hpp"
+
+namespace ecf {
+
+//======================================================================================
+
+ExprAstVisitor::~ExprAstVisitor() = default;
+
+//======================================================================================
+AstResolveVisitor::AstResolveVisitor(const Node* node) : triggerNode_(node) {
+}
+AstResolveVisitor::~AstResolveVisitor() = default;
+
+void AstResolveVisitor::visitNode(AstNode* astNode) {
+    // std::cout << "AstResolveVisitor::visitNode errorMsg = " << errorMsg_ << "\n";
+    if (errorMsg_.empty()) {
+
+        astNode->setParentNode(const_cast<Node*>(triggerNode_));
+        Node* node = astNode->referencedNode(errorMsg_);
+        if (!node) {
+            // A node can be NULL when its a extern path. In this case errorMsg should be empty
+            return;
+        }
+        LOG_ASSERT(errorMsg_.empty(), ""); // found Node, make sure errorMsg is empty
+    }
+}
+
+void AstResolveVisitor::visitVariable(AstVariable* astVar) {
+    if (errorMsg_.empty()) {
+
+        astVar->setParentNode(const_cast<Node*>(triggerNode_));
+
+        /// Use VariableHelper to populate errorMsg_
+        VariableHelper varHelper(astVar, errorMsg_);
+    }
+}
+
+void AstResolveVisitor::visitParentVariable(AstParentVariable* astvar) {
+    if (errorMsg_.empty()) {
+
+        astvar->setParentNode(const_cast<Node*>(triggerNode_));
+
+        if (!astvar->find_node_which_references_variable()) {
+
+            // Check externs if possible
+            Defs* defs = triggerNode_->defs();
+            if (defs) {
+                if (defs->find_extern(triggerNode_->absNodePath(), astvar->name())) {
+                    return;
+                }
+            }
+
+            std::stringstream ss;
+            ss << " Could not find variable " << astvar->name() << " on node " << triggerNode_->debugNodePath()
+               << " OR any of its parent nodes";
+            errorMsg_ += ss.str();
+        }
+    }
+}
+
+void AstResolveVisitor::visitFlag(AstFlag* ast) {
+    if (errorMsg_.empty()) {
+
+        ast->setParentNode(const_cast<Node*>(triggerNode_));
+        Node* node = ast->referencedNode(errorMsg_);
+        if (!node) {
+            // A node can be NULL when its a extern path. In this case errorMsg should be empty
+            return;
+        }
+        LOG_ASSERT(errorMsg_.empty(), ""); // found Node, make sure errorMsg is empty
+    }
+}
+
+//===========================================================================================================
+
+AstCollateNodesVisitor::AstCollateNodesVisitor(std::set<Node*>& s) : theSet_(s) {
+}
+AstCollateNodesVisitor::~AstCollateNodesVisitor() = default;
+
+void AstCollateNodesVisitor::visitNode(AstNode* astNode) {
+    Node* referencedNode = astNode->referencedNode(); // could be expensive, hence don't call twice
+    if (referencedNode)
+        theSet_.insert(referencedNode);
+}
+
+void AstCollateNodesVisitor::visitVariable(AstVariable* astVar) {
+    Node* referencedNode = astVar->referencedNode(); // could be expensive, hence don't call twice
+    if (referencedNode)
+        theSet_.insert(referencedNode);
+}
+
+void AstCollateNodesVisitor::visitParentVariable(AstParentVariable* astvar) {
+    Node* referencedNode = astvar->referencedNode(); // could be expensive, hence don't call twice
+    if (referencedNode)
+        theSet_.insert(referencedNode);
+}
+
+void AstCollateNodesVisitor::visitFlag(AstFlag* ast) {
+    Node* referencedNode = ast->referencedNode(); // could be expensive, hence don't call twice
+    if (referencedNode)
+        theSet_.insert(referencedNode);
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprAstVisitor.hpp 5.13.0-1/libs/node/src/ecflow/node/ExprAstVisitor.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprAstVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprAstVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,156 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ExprAstVisitor_HPP
+#define ecflow_node_ExprAstVisitor_HPP
+
+#include <set>
+#include <string>
+
+class Node;
+class AstTop;
+class AstRoot;
+class AstAnd;
+class AstNot;
+class AstPlus;
+class AstMinus;
+class AstDivide;
+class AstMultiply;
+class AstModulo;
+class AstOr;
+class AstEqual;
+class AstNotEqual;
+class AstLessEqual;
+class AstGreaterEqual;
+class AstLessThan;
+class AstGreaterThan;
+class AstLeaf;
+class AstInteger;
+class AstInstant;
+class AstFunction;
+class AstNodeState;
+class AstEventState;
+class AstNode;
+class AstVariable;
+class AstParentVariable;
+class AstFlag;
+
+namespace ecf {
+
+class ExprAstVisitor {
+public:
+    virtual ~ExprAstVisitor();
+
+    virtual void visitTop(AstTop*)                       = 0;
+    virtual void visitRoot(AstRoot*)                     = 0;
+    virtual void visitAnd(AstAnd*)                       = 0;
+    virtual void visitNot(AstNot*)                       = 0;
+    virtual void visitPlus(AstPlus*)                     = 0;
+    virtual void visitMinus(AstMinus*)                   = 0;
+    virtual void visitDivide(AstDivide*)                 = 0;
+    virtual void visitMultiply(AstMultiply*)             = 0;
+    virtual void visitModulo(AstModulo*)                 = 0;
+    virtual void visitOr(AstOr*)                         = 0;
+    virtual void visitEqual(AstEqual*)                   = 0;
+    virtual void visitNotEqual(AstNotEqual*)             = 0;
+    virtual void visitLessEqual(AstLessEqual*)           = 0;
+    virtual void visitGreaterEqual(AstGreaterEqual*)     = 0;
+    virtual void visitGreaterThan(AstGreaterThan*)       = 0;
+    virtual void visitLessThan(AstLessThan*)             = 0;
+    virtual void visitLeaf(AstLeaf*)                     = 0;
+    virtual void visitInteger(AstInteger*)               = 0;
+    virtual void visitInstant(AstInstant*)               = 0;
+    virtual void visitFunction(AstFunction*)             = 0;
+    virtual void visitNodeState(AstNodeState*)           = 0;
+    virtual void visitEventState(AstEventState*)         = 0;
+    virtual void visitNode(AstNode*)                     = 0;
+    virtual void visitVariable(AstVariable*)             = 0;
+    virtual void visitParentVariable(AstParentVariable*) = 0;
+    virtual void visitFlag(AstFlag*)                     = 0;
+};
+
+class AstResolveVisitor : public ExprAstVisitor {
+public:
+    explicit AstResolveVisitor(const Node*);
+    ~AstResolveVisitor() override;
+
+    const std::string& errorMsg() const { return errorMsg_; }
+
+    void visitTop(AstTop*) override {}
+    void visitRoot(AstRoot*) override {}
+    void visitAnd(AstAnd*) override {}
+    void visitNot(AstNot*) override {}
+    void visitPlus(AstPlus*) override {}
+    void visitMinus(AstMinus*) override {}
+    void visitDivide(AstDivide*) override {}
+    void visitMultiply(AstMultiply*) override {}
+    void visitModulo(AstModulo*) override {}
+    void visitOr(AstOr*) override {}
+    void visitEqual(AstEqual*) override {}
+    void visitNotEqual(AstNotEqual*) override {}
+    void visitLessEqual(AstLessEqual*) override {}
+    void visitGreaterEqual(AstGreaterEqual*) override {}
+    void visitGreaterThan(AstGreaterThan*) override {}
+    void visitLessThan(AstLessThan*) override {}
+    void visitLeaf(AstLeaf*) override {}
+    void visitInteger(AstInteger*) override {}
+    void visitInstant(AstInstant*) override {}
+    void visitFunction(AstFunction*) override {}
+    void visitNodeState(AstNodeState*) override {}
+    void visitEventState(AstEventState*) override {}
+    void visitNode(AstNode*) override;
+    void visitVariable(AstVariable*) override;
+    void visitParentVariable(AstParentVariable*) override;
+    void visitFlag(AstFlag*) override;
+
+private:
+    const Node* triggerNode_;
+    std::string errorMsg_;
+};
+
+class AstCollateNodesVisitor : public ExprAstVisitor {
+public:
+    explicit AstCollateNodesVisitor(std::set<Node*>&);
+    ~AstCollateNodesVisitor() override;
+
+    void visitTop(AstTop*) override {}
+    void visitRoot(AstRoot*) override {}
+    void visitAnd(AstAnd*) override {}
+    void visitNot(AstNot*) override {}
+    void visitPlus(AstPlus*) override {}
+    void visitMinus(AstMinus*) override {}
+    void visitDivide(AstDivide*) override {}
+    void visitMultiply(AstMultiply*) override {}
+    void visitModulo(AstModulo*) override {}
+    void visitOr(AstOr*) override {}
+    void visitEqual(AstEqual*) override {}
+    void visitNotEqual(AstNotEqual*) override {}
+    void visitLessEqual(AstLessEqual*) override {}
+    void visitGreaterEqual(AstGreaterEqual*) override {}
+    void visitGreaterThan(AstGreaterThan*) override {}
+    void visitLessThan(AstLessThan*) override {}
+    void visitLeaf(AstLeaf*) override {}
+    void visitInteger(AstInteger*) override {}
+    void visitInstant(AstInstant*) override {}
+    void visitFunction(AstFunction*) override {}
+    void visitNodeState(AstNodeState*) override {}
+    void visitEventState(AstEventState*) override {}
+    void visitNode(AstNode*) override;
+    void visitVariable(AstVariable*) override;
+    void visitParentVariable(AstParentVariable*) override;
+    void visitFlag(AstFlag*) override;
+
+private:
+    std::set<Node*>& theSet_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_ExprAstVisitor_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprDuplicate.cpp 5.13.0-1/libs/node/src/ecflow/node/ExprDuplicate.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprDuplicate.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprDuplicate.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/ExprDuplicate.hpp"
+
+#include <iostream>
+#include <unordered_map>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/ExprAst.hpp"
+
+using namespace std;
+
+static std::unordered_map<std::string, AstTop*> duplicate_expr;
+typedef std::unordered_map<std::string, AstTop*> my_map;
+
+ExprDuplicate::~ExprDuplicate() {
+    // cout << "ExprDuplicate::~ExprDuplicate: server(" << Ecf::server() << ") " << duplicate_expr.size() << "
+    // *****************************************************************\n";
+    for (my_map::value_type i : duplicate_expr) {
+        // cout << " deleting: " << i.first << " :" << i.second << "\n";
+        delete i.second;
+        i.second = NULL;
+    }
+    duplicate_expr.clear();
+}
+
+void ExprDuplicate::dump(const std::string& msg) {
+    cout << "ExprDuplicate::dump server(" << Ecf::server() << ") " << msg << "\n";
+    for (const my_map::value_type& i : duplicate_expr) {
+        cout << "   " << i.first << " :" << i.second << "\n";
+    }
+}
+
+std::unique_ptr<AstTop> ExprDuplicate::find(const std::string& expr) {
+    my_map::const_iterator it = duplicate_expr.find(expr);
+    if (it != duplicate_expr.end()) {
+        return std::unique_ptr<AstTop>((*it).second->clone());
+    }
+    return std::unique_ptr<AstTop>();
+}
+
+void ExprDuplicate::add(const std::string& expr, AstTop* ast) {
+    assert(!expr.empty() && ast);
+    AstTop* clone = ast->clone();
+    duplicate_expr.insert(std::make_pair(expr, clone));
+
+    // cout << "ExprDuplicate::add: server(" << Ecf::server() << ") " << expr << " :" << clone << "   " <<
+    // duplicate_expr.size() << "\n";
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprDuplicate.hpp 5.13.0-1/libs/node/src/ecflow/node/ExprDuplicate.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprDuplicate.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprDuplicate.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ExprDuplicate_HPP
+#define ecflow_node_ExprDuplicate_HPP
+
+///
+/// \brief For large designs > 90% of triggers are identical.
+/// We take advantage of this by using a map to store a *CLONED* ast
+/// This saves a huge amount on re-parsing using spirit classic.
+///
+/// This cloned  AST is maintained in a static map, hence we need to
+/// manage the lifetime, to avoid valgrind complaining.
+///
+
+#include <memory> // for unique_ptr
+#include <string>
+class AstTop;
+
+// reclaim memory allocated in map, Avoid valgrind errors
+class ExprDuplicate {
+private:
+public:
+    ExprDuplicate() = default;
+    // Disable copy (and move) semantics
+    ExprDuplicate(const ExprDuplicate&)                  = delete;
+    const ExprDuplicate& operator=(const ExprDuplicate&) = delete;
+
+    ~ExprDuplicate();
+
+    // for debug only
+    static void dump(const std::string& msg);
+
+    // Find the expr in the map, if found returns a CLONED ast, else NULL
+    static std::unique_ptr<AstTop> find(const std::string& expr);
+
+    // Add the expr to the map, the ast is cloned.
+    static void add(const std::string& expr, AstTop*);
+};
+
+#endif /* ecflow_node_ExprDuplicate_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprParser.cpp 5.13.0-1/libs/node/src/ecflow/node/ExprParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1188 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+// Un-comment these for selective for debugging. At the moment because we have added
+//            ast generation BOOST_SPIRIT_DEBUG is to verbose, making debugging a pain.
+// Typically, I will comment out ONLY BOOST_SPIRIT_DEBUG and enable all the others
+// #define BOOST_SPIRIT_DEBUG
+// #define BOOST_SPIRIT_DUMP_PARSETREE_AS_XML
+// #define PRINT_TREE
+// #define PRINT_AST_TRAVERSAL
+// #define PRINT_AST
+
+#include "ecflow/node/ExprParser.hpp"
+
+#include <iostream>
+#include <map>
+#include <memory>
+#include <sstream>
+#include <stack>
+#include <string>
+
+#include <boost/spirit/include/classic.hpp>
+#include <boost/spirit/include/classic_actor.hpp>
+#include <boost/spirit/include/classic_ast.hpp>
+#include <boost/spirit/include/classic_attribute.hpp>
+#include <boost/spirit/include/classic_confix.hpp>
+#include <boost/spirit/include/classic_core.hpp>
+#include <boost/spirit/include/classic_tree_to_xml.hpp>
+#include <boost/spirit/include/phoenix1_binders.hpp>
+
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/ExprDuplicate.hpp"
+
+// Reference
+// ‘*’   Zero or more
+// ‘!’   Zero or one
+// ‘+’   One or more
+// ‘>>’  Sequence/concatenation
+// ‘|’   alternate
+// ‘-‘   not
+
+////////////////////////////////////////////////////////////////////////////
+using namespace ecf;
+using namespace std;
+using namespace boost::spirit;
+using namespace phoenix;
+using namespace BOOST_SPIRIT_CLASSIC_NS;
+
+/////////////////////////////////////////////////////////////////////////////
+typedef tree_match<const char*> treematch_t;
+typedef treematch_t::tree_iterator tree_iter_t;
+
+//////////////////////////////////////////////////////////////////////////////
+
+struct ExpressionGrammer : public grammar<ExpressionGrammer>
+{
+    // The parser object is copied a lot, so only use reference/pointer variables as data members
+    ExpressionGrammer()  = default;
+    ~ExpressionGrammer() = default;
+
+    static const int integer_ID            = 1;
+    static const int dot_path_ID           = 2;
+    static const int equal_1_ID            = 3;
+    static const int equal_2_ID            = 4;
+    static const int not_equal_1_ID        = 5;
+    static const int not_equal_2_ID        = 6;
+    static const int node_name_ID          = 7;
+    static const int greater_equals_1_ID   = 8;
+    static const int greater_equals_2_ID   = 9;
+    static const int less_equals_1_ID      = 10;
+    static const int less_equals_2_ID      = 11;
+    static const int less_than_1_ID        = 12;
+    static const int less_than_2_ID        = 13;
+    static const int greater_than_1_ID     = 14;
+    static const int greater_than_2_ID     = 15;
+    static const int node_state_unknown_ID = 16;
+
+    static const int node_state_complete_ID  = 18;
+    static const int node_state_queued_ID    = 19;
+    static const int node_state_submitted_ID = 20;
+    static const int node_state_active_ID    = 21;
+    static const int node_state_aborted_ID   = 22;
+
+    static const int not1_ID                = 23;
+    static const int not2_ID                = 24;
+    static const int not3_ID                = 25;
+    static const int and_ID                 = 26;
+    static const int or_ID                  = 27;
+    static const int dot_dot_path_ID        = 29;
+    static const int base_trigger_ID        = 31;
+    static const int sub_expression_ID      = 32;
+    static const int node_path_state_ID     = 34;
+    static const int absolute_path_ID       = 35;
+    static const int event_state_ID         = 36;
+    static const int variable_ID            = 37;
+    static const int plus_ID                = 42;
+    static const int minus_ID               = 43;
+    static const int multiply_ID            = 44;
+    static const int divide_ID              = 45;
+    static const int modulo_ID              = 46;
+    static const int calc_expression_ID     = 47;
+    static const int calc_factor_ID         = 48;
+    static const int calc_term_ID           = 49;
+    static const int calc_grouping_ID       = 50;
+    static const int calc_subexpression_ID  = 51;
+    static const int basic_variable_path_ID = 52;
+    static const int compare_expression_ID  = 53;
+
+    static const int cal_date_to_julian_ID = 54;
+    static const int cal_julian_to_date_ID = 55;
+    static const int cal_argument_ID       = 56;
+
+    static const int flag_path_ID       = 57;
+    static const int flag_late_ID       = 58;
+    static const int flag_zombie_ID     = 59;
+    static const int flag_archived_ID   = 60;
+    static const int flag_ID            = 61;
+    static const int root_path_ID       = 62;
+    static const int parent_variable_ID = 63;
+
+    static const int datetime_ID = 64;
+
+    template <typename ScannerT>
+    struct definition
+    {
+        rule<ScannerT, parser_tag<cal_date_to_julian_ID>> cal_date_to_julian;
+        rule<ScannerT, parser_tag<cal_julian_to_date_ID>> cal_julian_to_date;
+        rule<ScannerT, parser_tag<cal_argument_ID>> cal_argument;
+
+        rule<ScannerT, parser_tag<integer_ID>> integer;
+        rule<ScannerT, parser_tag<plus_ID>> plus;
+        rule<ScannerT, parser_tag<minus_ID>> minus;
+        rule<ScannerT, parser_tag<multiply_ID>> multiply;
+        rule<ScannerT, parser_tag<divide_ID>> divide;
+        rule<ScannerT, parser_tag<modulo_ID>> modulo;
+
+        rule<ScannerT, parser_tag<equal_1_ID>> equal_1;
+        rule<ScannerT, parser_tag<equal_2_ID>> equal_2;
+        rule<ScannerT, parser_tag<not_equal_1_ID>> not_equal_1;
+        rule<ScannerT, parser_tag<not_equal_2_ID>> not_equal_2;
+        rule<ScannerT, parser_tag<node_name_ID>> nodename;
+
+        rule<ScannerT, parser_tag<greater_equals_1_ID>> greater_equals_1;
+        rule<ScannerT, parser_tag<greater_equals_2_ID>> greater_equals_2;
+        rule<ScannerT, parser_tag<less_equals_1_ID>> less_equals_1;
+        rule<ScannerT, parser_tag<less_equals_2_ID>> less_equals_2;
+
+        rule<ScannerT, parser_tag<less_than_1_ID>> less_than_1;
+        rule<ScannerT, parser_tag<less_than_2_ID>> less_than_2;
+        rule<ScannerT, parser_tag<greater_than_1_ID>> greater_than_1;
+        rule<ScannerT, parser_tag<greater_than_2_ID>> greater_than_2;
+
+        rule<ScannerT, parser_tag<node_state_unknown_ID>> node_state_unknown;
+        rule<ScannerT, parser_tag<node_state_complete_ID>> node_state_complete;
+        rule<ScannerT, parser_tag<node_state_queued_ID>> node_state_queued;
+        rule<ScannerT, parser_tag<node_state_submitted_ID>> node_state_submitted;
+        rule<ScannerT, parser_tag<node_state_active_ID>> node_state_active;
+        rule<ScannerT, parser_tag<node_state_aborted_ID>> node_state_aborted;
+
+        rule<ScannerT, parser_tag<not1_ID>> not1_r;
+        rule<ScannerT, parser_tag<not2_ID>> not2_r;
+        rule<ScannerT, parser_tag<not3_ID>> not3_r;
+        rule<ScannerT, parser_tag<and_ID>> and_r;
+        rule<ScannerT, parser_tag<or_ID>> or_r;
+
+        rule<ScannerT, parser_tag<dot_path_ID>> dotpath;
+        rule<ScannerT, parser_tag<dot_dot_path_ID>> dotdotpath;
+        rule<ScannerT, parser_tag<absolute_path_ID>> absolutepath;
+        rule<ScannerT, parser_tag<root_path_ID>> root_path;
+
+        rule<ScannerT, parser_tag<node_path_state_ID>> nodepathstate;
+
+        rule<ScannerT, parser_tag<event_state_ID>> event_state;
+        rule<ScannerT, parser_tag<variable_ID>> variable;
+
+        rule<ScannerT, parser_tag<calc_expression_ID>> calc_expression;
+        rule<ScannerT, parser_tag<calc_factor_ID>> calc_factor;
+        rule<ScannerT, parser_tag<calc_term_ID>> calc_term;
+        rule<ScannerT, parser_tag<calc_grouping_ID>> calc_grouping;
+        rule<ScannerT, parser_tag<calc_subexpression_ID>> calc_subexpression;
+        rule<ScannerT, parser_tag<basic_variable_path_ID>> basic_variable_path;
+        rule<ScannerT, parser_tag<parent_variable_ID>> parent_variable;
+        rule<ScannerT, parser_tag<compare_expression_ID>> compare_expression;
+
+        rule<ScannerT, parser_tag<flag_path_ID>> flag_path;
+        rule<ScannerT, parser_tag<flag_late_ID>> flag_late;
+        rule<ScannerT, parser_tag<flag_zombie_ID>> flag_zombie;
+        rule<ScannerT, parser_tag<flag_archived_ID>> flag_archived;
+        rule<ScannerT, parser_tag<flag_ID>> flag;
+
+        rule<ScannerT> not_r, less_than_comparable, expression, andExpr, operators;
+        rule<ScannerT> nodestate, equality_comparible, and_or, nodepath;
+
+        rule<ScannerT, parser_tag<datetime_ID>> datetime;
+
+        //        ‘*’   Zero or more
+        //        ‘!’   Zero or one
+        //        ‘+’   One or more
+        //        ‘>>’  Sequence/concatenation
+        //        ‘|’   alternate
+        //        ‘-‘   not
+        explicit definition(ExpressionGrammer const& /*self*/) {
+            nodename = leaf_node_d[lexeme_d[(alnum_p || ch_p('_')) >> *(alnum_p || ch_p('_') || ch_p('.'))]];
+
+            // Can be /suite/family/task ||  family/task ||   family
+
+            absolutepath = leaf_node_d[!(str_p("/")) >> nodename >> *(+str_p("/") >> nodename)];
+            dotdotpath // a kind of relative path
+                = leaf_node_d[str_p("..") >> *(+str_p("/") >> str_p("..")) >> +(+str_p("/") >> nodename)];
+
+            dotpath  = leaf_node_d[str_p(".") >> +(str_p("/") >> nodename)];
+            nodepath = absolutepath | dotdotpath | dotpath;
+
+            // Integer is distinct from task/family names that are integers, since nodes with integer
+            // names that occur in trigger/complete expression must have path ./0 ./1
+            integer   = leaf_node_d[uint_p];
+            plus      = root_node_d[str_p("+")];
+            minus     = root_node_d[str_p("-")];
+            divide    = root_node_d[str_p("/")];
+            multiply  = root_node_d[str_p("*")];
+            modulo    = root_node_d[str_p("%")];
+            operators = plus | minus | divide | multiply | modulo;
+
+            equal_1             = root_node_d[str_p("==")];
+            equal_2             = root_node_d[str_p("eq")];
+            not_equal_1         = root_node_d[str_p("!=")];
+            not_equal_2         = root_node_d[str_p("ne")];
+            equality_comparible = equal_1 | equal_2 | not_equal_2 | not_equal_1;
+
+            greater_equals_1 = root_node_d[str_p(">=")];
+            greater_equals_2 = root_node_d[str_p("ge")];
+            less_equals_1    = root_node_d[str_p("<=")];
+            less_equals_2    = root_node_d[str_p("le")];
+            less_than_1      = root_node_d[str_p("<")];
+            less_than_2      = root_node_d[str_p("lt")];
+            greater_than_1   = root_node_d[str_p(">")];
+            greater_than_2   = root_node_d[str_p("gt")];
+            // Prioritise to most common first, to speed up parsing
+            less_than_comparable = greater_equals_2 | less_equals_2 | greater_than_2 | less_than_2 | greater_equals_1 |
+                                   less_equals_1 | less_than_1 | greater_than_1;
+
+            not1_r = root_node_d[str_p("not ")];
+            not2_r = root_node_d[str_p("~")];
+            not3_r = root_node_d[str_p("!")];
+            not_r  = not1_r | not3_r | not2_r;
+
+            and_r  = root_node_d[str_p("and")] || root_node_d[str_p("&&")] || root_node_d[str_p("AND")];
+            or_r   = root_node_d[str_p("or")] || root_node_d[str_p("||")] || root_node_d[str_p("OR")];
+            and_or = and_r | or_r;
+
+            event_state = leaf_node_d[str_p("set")] || leaf_node_d[str_p("clear")];
+
+            node_state_unknown   = root_node_d[str_p("unknown")];
+            node_state_complete  = root_node_d[str_p("complete")];
+            node_state_queued    = root_node_d[str_p("queued")];
+            node_state_submitted = root_node_d[str_p("submitted")];
+            node_state_active    = root_node_d[str_p("active")];
+            node_state_aborted   = root_node_d[str_p("aborted")];
+            nodestate            = node_state_complete | node_state_aborted | node_state_queued | node_state_active |
+                        node_state_submitted | node_state_unknown;
+
+            flag_late     = root_node_d[str_p("late")];
+            flag_zombie   = root_node_d[str_p("zombie")];
+            flag_archived = root_node_d[str_p("archived")];
+            flag          = flag_late | flag_zombie | flag_archived;
+
+            variable            = leaf_node_d[nodename];
+            basic_variable_path = nodepath >> discard_node_d[ch_p(':')] >> variable;
+            parent_variable =
+                ch_p(':') >> variable; // if we discard_node, then we get just 'variable' and NOT parent_variable
+
+            root_path = leaf_node_d[(str_p("/"))];
+            flag_path = (nodepath | root_path) >> discard_node_d[str_p("<flag>")] >> flag;
+
+            cal_argument = basic_variable_path | integer;
+            cal_date_to_julian =
+                str_p("cal::date_to_julian") >> discard_node_d[ch_p('(')] >> cal_argument >> discard_node_d[ch_p(')')];
+            cal_julian_to_date =
+                str_p("cal::julian_to_date") >> discard_node_d[ch_p('(')] >> cal_argument >> discard_node_d[ch_p(')')];
+            datetime = leaf_node_d[lexeme_d[repeat_p(8)[digit_p] >> 'T' >> repeat_p(6)[digit_p]]];
+
+            calc_factor = datetime | integer | basic_variable_path |
+                          discard_node_d[ch_p('(')] >> calc_expression >> discard_node_d[ch_p(')')] | flag_path |
+                          parent_variable | root_node_d[operators] >> calc_factor | cal_date_to_julian |
+                          cal_julian_to_date;
+            calc_term       = calc_factor >> *(root_node_d[operators] >> calc_factor);
+            calc_expression = calc_term >> *(root_node_d[operators] >> calc_term);
+
+            nodepathstate = nodepath >> equality_comparible >> nodestate;
+
+            compare_expression = nodepathstate | basic_variable_path >> equality_comparible >> event_state |
+                                 root_node_d[calc_expression >> *((equality_comparible | less_than_comparable) >>
+                                                                  (!not_r >> calc_expression))];
+
+            // We need to take special care so that 'and' has a higher priority than 'or'
+            // (( This is done by have a custom rule for the and
+            andExpr = !not_r >> compare_expression >> *(and_r >> !not_r >> compare_expression);
+
+            calc_grouping = !not_r >> discard_node_d[ch_p('(')] >> calc_subexpression >> discard_node_d[ch_p(')')];
+
+            calc_subexpression = (andExpr | calc_grouping) >> *((and_r | or_r) >> calc_subexpression);
+
+            expression = calc_subexpression >> end_p;
+
+            BOOST_SPIRIT_DEBUG_NODE(cal_argument);
+            BOOST_SPIRIT_DEBUG_NODE(cal_date_to_julian);
+            BOOST_SPIRIT_DEBUG_NODE(andExpr);
+            BOOST_SPIRIT_DEBUG_NODE(not_r);
+            BOOST_SPIRIT_DEBUG_NODE(not1_r);
+            BOOST_SPIRIT_DEBUG_NODE(not2_r);
+            BOOST_SPIRIT_DEBUG_NODE(expression);
+            BOOST_SPIRIT_DEBUG_NODE(nodename);
+            BOOST_SPIRIT_DEBUG_NODE(nodepath);
+            BOOST_SPIRIT_DEBUG_NODE(dotdotpath);
+            BOOST_SPIRIT_DEBUG_NODE(dotpath);
+            BOOST_SPIRIT_DEBUG_NODE(absolutepath);
+            BOOST_SPIRIT_DEBUG_NODE(less_than_comparable);
+            BOOST_SPIRIT_DEBUG_NODE(nodestate);
+            BOOST_SPIRIT_DEBUG_NODE(equality_comparible);
+            BOOST_SPIRIT_DEBUG_NODE(equal_1);
+            BOOST_SPIRIT_DEBUG_NODE(equal_2);
+            BOOST_SPIRIT_DEBUG_NODE(not_equal_1);
+            BOOST_SPIRIT_DEBUG_NODE(not_equal_2);
+            BOOST_SPIRIT_DEBUG_NODE(and_or);
+            BOOST_SPIRIT_DEBUG_NODE(plus);
+            BOOST_SPIRIT_DEBUG_NODE(minus);
+            BOOST_SPIRIT_DEBUG_NODE(divide);
+            BOOST_SPIRIT_DEBUG_NODE(multiply);
+            BOOST_SPIRIT_DEBUG_NODE(modulo);
+            BOOST_SPIRIT_DEBUG_NODE(nodepathstate);
+            BOOST_SPIRIT_DEBUG_NODE(integer);
+            BOOST_SPIRIT_DEBUG_NODE(event_state);
+            BOOST_SPIRIT_DEBUG_NODE(variable);
+            BOOST_SPIRIT_DEBUG_NODE(basic_variable_path);
+            BOOST_SPIRIT_DEBUG_NODE(parent_variable);
+            BOOST_SPIRIT_DEBUG_NODE(flag_path);
+            BOOST_SPIRIT_DEBUG_NODE(calc_factor);
+            BOOST_SPIRIT_DEBUG_NODE(calc_expression);
+            BOOST_SPIRIT_DEBUG_NODE(calc_term);
+            BOOST_SPIRIT_DEBUG_NODE(compare_expression);
+            BOOST_SPIRIT_DEBUG_NODE(datetime);
+        };
+
+        rule<ScannerT> const& start() const { return expression; }
+    };
+};
+
+/////////////////////////////////////////////////////////////////////////////////////////////
+
+void print(tree_parse_info<> info, const std::string& expr, const std::map<parser_id, std::string>& rule_names);
+
+AstTop* createTopAst(tree_parse_info<> info,
+                     const std::string& expr,
+                     const std::map<parser_id, std::string>& rule_names,
+                     std::string& error_msg);
+
+/////////////////////////////////////////////////////////////////////////////////////////////
+
+ExprParser::ExprParser(const std::string& expression) : expr_(expression) {
+}
+
+static std::map<parser_id, std::string> rule_names;
+static void populate_rule_names() {
+    if (rule_names.empty()) {
+        rule_names[ExpressionGrammer::cal_date_to_julian_ID]   = "cal_date_to_julian";
+        rule_names[ExpressionGrammer::cal_julian_to_date_ID]   = "cal_julian_to_date";
+        rule_names[ExpressionGrammer::cal_argument_ID]         = "cal_argument";
+        rule_names[ExpressionGrammer::modulo_ID]               = "MODULO";
+        rule_names[ExpressionGrammer::equal_1_ID]              = "EQUALS";
+        rule_names[ExpressionGrammer::equal_2_ID]              = "EQUALS";
+        rule_names[ExpressionGrammer::not_equal_1_ID]          = "NOT_EQUAL";
+        rule_names[ExpressionGrammer::not_equal_2_ID]          = "NOT_EQUAL";
+        rule_names[ExpressionGrammer::greater_equals_1_ID]     = "GREATER_THAN_OR_EQUALS";
+        rule_names[ExpressionGrammer::greater_equals_2_ID]     = "GREATER_THAN_OR_EQUALS";
+        rule_names[ExpressionGrammer::less_equals_1_ID]        = "LESS_THAN_OR_EQUALS";
+        rule_names[ExpressionGrammer::less_equals_2_ID]        = "LESS_THAN_OR_EQUALS";
+        rule_names[ExpressionGrammer::less_than_1_ID]          = "LESS_THAN";
+        rule_names[ExpressionGrammer::less_than_2_ID]          = "LESS_THAN";
+        rule_names[ExpressionGrammer::greater_than_1_ID]       = "GREATER_THAN";
+        rule_names[ExpressionGrammer::greater_than_2_ID]       = "GREATER_THAN";
+        rule_names[ExpressionGrammer::not1_ID]                 = "NOT";
+        rule_names[ExpressionGrammer::not2_ID]                 = "NOT";
+        rule_names[ExpressionGrammer::not3_ID]                 = "NOT";
+        rule_names[ExpressionGrammer::and_ID]                  = "AND";
+        rule_names[ExpressionGrammer::or_ID]                   = "OR";
+        rule_names[ExpressionGrammer::node_name_ID]            = "NODE_NAME";
+        rule_names[ExpressionGrammer::node_state_unknown_ID]   = "UNKNOWN";
+        rule_names[ExpressionGrammer::node_state_complete_ID]  = "COMPLETE";
+        rule_names[ExpressionGrammer::node_state_queued_ID]    = "QUEUED";
+        rule_names[ExpressionGrammer::node_state_submitted_ID] = "SUBMITTED";
+        rule_names[ExpressionGrammer::node_state_active_ID]    = "ACTIVE";
+        rule_names[ExpressionGrammer::node_state_aborted_ID]   = "ABORTED";
+        rule_names[ExpressionGrammer::integer_ID]              = "INTEGER";
+        rule_names[ExpressionGrammer::dot_path_ID]             = "DOT_PATH";
+        rule_names[ExpressionGrammer::dot_dot_path_ID]         = "DOT_DOT_PATH";
+        rule_names[ExpressionGrammer::absolute_path_ID]        = "ABSOLUTE_PATH";
+
+        rule_names[ExpressionGrammer::base_trigger_ID]    = "BASE_TRIGGER";
+        rule_names[ExpressionGrammer::sub_expression_ID]  = "SUB_EXPRESSION";
+        rule_names[ExpressionGrammer::node_path_state_ID] = "NODE_PATH_STATE";
+        rule_names[ExpressionGrammer::flag_path_ID]       = "FLAG_PATH";
+
+        rule_names[ExpressionGrammer::event_state_ID] = "STRING";
+        rule_names[ExpressionGrammer::variable_ID]    = "VARIABLE";
+
+        rule_names[ExpressionGrammer::calc_expression_ID]     = "calc_expression_ID";
+        rule_names[ExpressionGrammer::calc_factor_ID]         = "calc_factor_ID";
+        rule_names[ExpressionGrammer::calc_term_ID]           = "calc_term_ID";
+        rule_names[ExpressionGrammer::calc_grouping_ID]       = "calc_grouping_ID";
+        rule_names[ExpressionGrammer::calc_subexpression_ID]  = "calc_subexpression_ID";
+        rule_names[ExpressionGrammer::basic_variable_path_ID] = "basic_variable_path_ID";
+        rule_names[ExpressionGrammer::parent_variable_ID]     = "parent_variable_ID";
+        rule_names[ExpressionGrammer::compare_expression_ID]  = "compare_expression_ID";
+
+        rule_names[ExpressionGrammer::datetime_ID] = "datetime";
+    }
+}
+
+bool ExprParser::doParse(std::string& errorMsg) {
+    if (expr_.empty()) {
+        errorMsg = "Expression is empty";
+        return false;
+    }
+
+    // =========================================================================
+    // For large designs > 90% of triggers are identical.
+    // We take advantage of this by only parsing the expression once
+    // and storing then Abstract Syntax tree( via cloning ) using a map
+    // This saves a huge amount of CPU time in re-parsing using spirit classic.
+    // =========================================================================
+    ast_ = ExprDuplicate::find(expr_);
+    if (ast_.get()) {
+        return true;
+    }
+
+    SimpleExprParser simpleParser(expr_);
+    if (simpleParser.doParse()) {
+        ast_ = simpleParser.ast();
+        ExprDuplicate::add(expr_, ast_.get()); // bypass spirit if same expression used
+        return true;
+    }
+
+    // SPIRIT CLASSIC parsing: very slooooow....
+    ExpressionGrammer grammer;
+    BOOST_SPIRIT_DEBUG_NODE(grammer);
+
+    // Use parser to generates a Boost.Spirit Abstract Syntax Tree (AST)
+    tree_parse_info<> info = ast_parse(expr_.c_str(), grammer, space_p);
+    if (info.full) {
+
+        populate_rule_names();
+
+#if defined(BOOST_SPIRIT_DUMP_PARSETREE_AS_XML)
+        tree_to_xml(cout, info.trees, expr_.c_str(), rule_names);
+#endif
+#if defined(PRINT_TREE)
+        print(info, expr_, rule_names);
+#endif
+        // Boost.Spirit has created an AST for us.
+        // However, it is not usable as is, so we will traverse the AST and create our OWN `Ast*` classes.
+        ast_.reset(createTopAst(info, expr_, rule_names, errorMsg));
+        if (ast_.get() && errorMsg.empty()) {
+            ExprDuplicate::add(expr_, ast_.get());
+        }
+        return errorMsg.empty();
+    }
+    else {
+        std::stringstream ss;
+        ss << "Parsing failed\n";
+        ss << "length = " << std::dec << info.length << "\n";
+        ss << "stopped at: \": " << info.stop << "\"\n";
+        errorMsg = ss.str();
+    }
+    return false;
+}
+
+// The evaluation function for the AST
+void do_print(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names) {
+    Indentor in;
+    auto iter = rule_names.find(i->value.id());
+    if (iter != rule_names.end()) {
+        Indentor::indent(cout) << "Rule " << (*iter).second << "(size:" << i->children.size() << ")"
+                               << "  " << string(i->value.begin(), i->value.end()) << endl;
+    }
+    else {
+        Indentor::indent(cout) << "Unknown rule(id:" << i->value.id().to_long() << ")"
+                               << "(size:" << i->children.size() << ")"
+                               << "  " << string(i->value.begin(), i->value.end()) << endl;
+    }
+
+    Indentor in2;
+    for (auto t = i->children.begin(); t != i->children.end(); ++t) {
+        do_print(t, rule_names);
+    }
+}
+
+void print(tree_parse_info<> info, const std::string& expr, const std::map<parser_id, std::string>& rule_names) {
+    std::cout << "\nPRINT_TREE  " << expr << "\n";
+    do_print(info.trees.begin(), rule_names);
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////
+
+AstRoot* createRootNode(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names) {
+#if defined(PRINT_AST_TRAVERSAL)
+    Indentor in;
+    std::map<parser_id, std::string>::const_iterator iter = rule_names.find(i->value.id());
+    if (iter != rule_names.end()) {
+        Indentor::indent(cout) << "Root Rule " << (*iter).second << "(" << i->children.size() << ")"
+                               << "  " << string(i->value.begin(), i->value.end()) << endl;
+    }
+    else {
+        Indentor::indent(cout) << "Unknown root rule "
+                               << "(" << i->children.size() << ")"
+                               << "  " << string(i->value.begin(), i->value.end()) << endl;
+    }
+#endif
+
+    if (i->value.id() == ExpressionGrammer::equal_1_ID)
+        return new AstEqual();
+    if (i->value.id() == ExpressionGrammer::equal_2_ID)
+        return new AstEqual();
+    if (i->value.id() == ExpressionGrammer::and_ID)
+        return new AstAnd();
+    if (i->value.id() == ExpressionGrammer::or_ID)
+        return new AstOr();
+    // Needed so that testing , when recreating expression uses same name for not.
+    if (i->value.id() == ExpressionGrammer::not1_ID) {
+        auto* astnot = new AstNot();
+        astnot->set_root_name("not ");
+        return astnot;
+    }
+    if (i->value.id() == ExpressionGrammer::not2_ID) {
+        auto* astnot = new AstNot();
+        astnot->set_root_name("~ ");
+        return astnot;
+    }
+    if (i->value.id() == ExpressionGrammer::not3_ID) {
+        auto* astnot = new AstNot();
+        astnot->set_root_name("! ");
+        return astnot;
+    }
+    if (i->value.id() == ExpressionGrammer::plus_ID)
+        return new AstPlus();
+
+    if (i->value.id() == ExpressionGrammer::not_equal_1_ID)
+        return new AstNotEqual();
+    if (i->value.id() == ExpressionGrammer::not_equal_2_ID)
+        return new AstNotEqual();
+    if (i->value.id() == ExpressionGrammer::greater_equals_1_ID)
+        return new AstGreaterEqual();
+    if (i->value.id() == ExpressionGrammer::greater_equals_2_ID)
+        return new AstGreaterEqual();
+    if (i->value.id() == ExpressionGrammer::less_equals_1_ID)
+        return new AstLessEqual();
+    if (i->value.id() == ExpressionGrammer::less_equals_2_ID)
+        return new AstLessEqual();
+    if (i->value.id() == ExpressionGrammer::less_than_1_ID)
+        return new AstLessThan();
+    if (i->value.id() == ExpressionGrammer::less_than_2_ID)
+        return new AstLessThan();
+    if (i->value.id() == ExpressionGrammer::greater_than_1_ID)
+        return new AstGreaterThan();
+    if (i->value.id() == ExpressionGrammer::greater_than_2_ID)
+        return new AstGreaterThan();
+
+    if (i->value.id() == ExpressionGrammer::minus_ID)
+        return new AstMinus();
+    if (i->value.id() == ExpressionGrammer::multiply_ID)
+        return new AstMultiply();
+    if (i->value.id() == ExpressionGrammer::divide_ID)
+        return new AstDivide();
+    if (i->value.id() == ExpressionGrammer::modulo_ID)
+        return new AstModulo();
+    LOG_ASSERT(false, "");
+    return nullptr;
+}
+
+// static bool is_node_state(const tree_iter_t& i) {
+//    if ( i->value.id() == ExpressionGrammer::node_state_unknown_ID  ) return true;
+//    if ( i->value.id() == ExpressionGrammer::node_state_complete_ID  ) return true;
+//    if ( i->value.id() == ExpressionGrammer::node_state_queued_ID  ) return true;
+//    if ( i->value.id() == ExpressionGrammer::node_state_submitted_ID  ) return true;
+//    if ( i->value.id() == ExpressionGrammer::node_state_active_ID  ) return true;
+//    if ( i->value.id() == ExpressionGrammer::node_state_aborted_ID  ) return true;
+//    return false;
+// }
+// static bool has_child_node_state(const tree_iter_t& i) {
+//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
+//       if (is_node_state(t)) return true;
+//    }
+//    return false;
+// }
+// static bool has_child_event_state(const tree_iter_t& i) {
+//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
+//       if ( t->value.id() == ExpressionGrammer::event_state_ID) return true;
+//    }
+//    return false;
+// }
+// static bool child_has_path(const tree_iter_t& i) {
+//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
+//       if ( t->value.id() == ExpressionGrammer::dot_path_ID ) return true;
+//       if ( t->value.id() == ExpressionGrammer::dot_dot_path_ID ) return true;
+//       if ( t->value.id() == ExpressionGrammer::absolute_path_ID ) return true;
+//    }
+//    return false;
+// }
+// static bool is_comparable(const tree_iter_t& i) {
+//    if ( i->value.id() == ExpressionGrammer::equal_1_ID ) return true;
+//    if ( i->value.id() == ExpressionGrammer::equal_2_ID ) return true;
+//    if ( i->value.id() == ExpressionGrammer::not_equal_1_ID ) return true;
+//    if ( i->value.id() == ExpressionGrammer::not_equal_2_ID ) return true;
+//    return false;
+// }
+// static bool has_child_not(const tree_iter_t& i) {
+//    for (tree_iter_t t = i->children.begin(); t != i->children.end(); ++t)  {
+//       if (is_not(t)) return true;
+//    }
+//    return false;
+// }
+
+static bool is_not(const tree_iter_t& i) {
+    if (i->value.id() == ExpressionGrammer::not1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::not2_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::not3_ID)
+        return true;
+    return false;
+}
+static bool child_has(const tree_iter_t& i, int id) {
+    for (auto& t : i->children) {
+        if (t.value.id() == id)
+            return true;
+    }
+    return false;
+}
+static bool is_root_node(const tree_iter_t& i) {
+    if (i->value.id() == ExpressionGrammer::equal_1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::equal_2_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::and_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::or_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::not1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::not2_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::not3_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::plus_ID)
+        return true;
+
+    if (i->value.id() == ExpressionGrammer::not_equal_1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::not_equal_2_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::greater_equals_1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::greater_equals_2_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::less_equals_1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::less_equals_2_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::less_than_1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::less_than_2_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::greater_than_1_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::greater_than_2_ID)
+        return true;
+
+    if (i->value.id() == ExpressionGrammer::minus_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::multiply_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::divide_ID)
+        return true;
+    if (i->value.id() == ExpressionGrammer::modulo_ID)
+        return true;
+    return false;
+}
+
+Ast* createAst(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names) {
+#if defined(PRINT_AST_TRAVERSAL)
+    Indentor in;
+    std::map<parser_id, std::string>::const_iterator iter = rule_names.find(i->value.id());
+    if (iter != rule_names.end()) {
+        Indentor::indent(cout) << "Create AST Rule " << (*iter).second << "(" << i->children.size() << ")"
+                               << "  '" << string(i->value.begin(), i->value.end()) << "'\n";
+    }
+    else {
+        Indentor::indent(cout) << "Create AST Unknown rule "
+                               << "(" << i->children.size() << ")"
+                               << "  '" << string(i->value.begin(), i->value.end()) << "'\n";
+    }
+#endif
+
+    if (i->value.id() == ExpressionGrammer::node_name_ID) {
+
+        string thevalue(i->value.begin(), i->value.end());
+        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
+        LOG_ASSERT(!thevalue.empty(), "");
+        return new AstNode(thevalue);
+    }
+    else if (i->value.id() == ExpressionGrammer::node_state_complete_ID) {
+
+        return new AstNodeState(DState::COMPLETE);
+    }
+    else if (i->value.id() == ExpressionGrammer::basic_variable_path_ID) {
+        LOG_ASSERT((i->children.size() == 2), "");
+        auto theNodePathIter = i->children.begin();
+        auto theNameIter     = i->children.begin() + 1;
+
+        string nodePath(theNodePathIter->value.begin(), theNodePathIter->value.end());
+        string name(theNameIter->value.begin(), theNameIter->value.end());
+        ecf::algorithm::trim(nodePath); // don't know why we get leading/trailing spaces
+        ecf::algorithm::trim(name);     // don't know why we get leading/trailing spaces
+        return new AstVariable(nodePath, name);
+    }
+    else if (i->value.id() == ExpressionGrammer::parent_variable_ID) {
+
+        // tree_iter_t the_colon = i->children.begin(); ignore
+        auto the_variable_t = i->children.begin() + 1;
+
+        string the_variable(the_variable_t->value.begin(), the_variable_t->value.end());
+        ecf::algorithm::trim(the_variable); // don't know why we get leading/trailing spaces
+        LOG_ASSERT(!the_variable.empty(), "");
+        return new AstParentVariable(the_variable);
+    }
+    else if (i->value.id() == ExpressionGrammer::dot_dot_path_ID) {
+
+        string thevalue(i->value.begin(), i->value.end());
+        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
+        LOG_ASSERT(!thevalue.empty(), "");
+        return new AstNode(thevalue);
+    }
+    if (i->value.id() == ExpressionGrammer::absolute_path_ID) {
+
+        string thevalue(i->value.begin(), i->value.end());
+        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
+        LOG_ASSERT(!thevalue.empty(), "");
+        return new AstNode(thevalue);
+    }
+    else if (i->value.id() == ExpressionGrammer::dot_path_ID) {
+
+        string thevalue(i->value.begin(), i->value.end());
+        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
+        LOG_ASSERT(!thevalue.empty(), "");
+        return new AstNode(thevalue);
+    }
+    else if (i->value.id() == ExpressionGrammer::event_state_ID) {
+
+        string thevalue(i->value.begin(), i->value.end());
+        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
+        if (thevalue == Event::SET())
+            return new AstEventState(true);
+        assert(thevalue == Event::CLEAR());
+        return new AstEventState(false);
+    }
+    else if (i->value.id() == ExpressionGrammer::datetime_ID) {
+
+        string thevalue(std::begin(i->value), std::end(i->value));
+        ecf::Instant instant = Instant::parse(thevalue);
+        return new AstInstant(instant);
+    }
+    else if (i->value.id() == ExpressionGrammer::integer_ID) {
+
+        string thevalue(i->value.begin(), i->value.end());
+        ecf::algorithm::trim(thevalue); // don't know why we get leading/trailing spaces
+        auto theInt = ecf::convert_to<int>(thevalue);
+        return new AstInteger(theInt);
+    }
+    else if (i->value.id() == ExpressionGrammer::node_state_aborted_ID) {
+
+        return new AstNodeState(DState::ABORTED);
+    }
+    else if (i->value.id() == ExpressionGrammer::node_state_active_ID) {
+
+        return new AstNodeState(DState::ACTIVE);
+    }
+    else if (i->value.id() == ExpressionGrammer::node_state_queued_ID) {
+
+        return new AstNodeState(DState::QUEUED);
+    }
+    else if (i->value.id() == ExpressionGrammer::node_state_submitted_ID) {
+
+        return new AstNodeState(DState::SUBMITTED);
+    }
+    else if (i->value.id() == ExpressionGrammer::node_state_unknown_ID) {
+
+        return new AstNodeState(DState::UNKNOWN);
+    }
+    else if (i->value.id() == ExpressionGrammer::cal_date_to_julian_ID) {
+
+        LOG_ASSERT((i->children.size() == 2), ""); // 1st is function, 2nd is arg(integer | basic variable path)
+
+        return new AstFunction(AstFunction::DATE_TO_JULIAN, createAst(i->children.begin() + 1, rule_names));
+    }
+    else if (i->value.id() == ExpressionGrammer::cal_julian_to_date_ID) {
+
+        LOG_ASSERT((i->children.size() == 2), ""); // 1st is function, 2nd is arg(integer | basic variable path)
+
+        return new AstFunction(AstFunction::JULIAN_TO_DATE, createAst(i->children.begin() + 1, rule_names));
+    }
+    else if (i->value.id() == ExpressionGrammer::flag_path_ID) {
+
+        LOG_ASSERT((i->children.size() == 2), "");
+        auto theNodePathIter = i->children.begin();
+        auto theFlagIter     = i->children.begin() + 1;
+
+        string nodePath(theNodePathIter->value.begin(), theNodePathIter->value.end());
+        string flag(theFlagIter->value.begin(), theFlagIter->value.end());
+        ecf::algorithm::trim(nodePath); // don't know why we get leading/trailing spaces
+        ecf::algorithm::trim(flag);     // don't know why we get leading/trailing spaces
+
+        return new AstFlag(nodePath, ecf::Flag::string_to_flag_type(flag));
+    }
+    return nullptr;
+}
+
+// The evaluation function for the AST
+Ast* doCreateAst(const tree_iter_t& i, const std::map<parser_id, std::string>& rule_names, Ast* top) {
+#if defined(PRINT_AST_TRAVERSAL)
+    Indentor in;
+    std::map<parser_id, std::string>::const_iterator iter = rule_names.find(i->value.id());
+    if (iter != rule_names.end()) {
+        Indentor::indent(cout) << "Rule " << (*iter).second << " (" << i->children.size() << ")"
+                               << "  " << string(i->value.begin(), i->value.end()) << endl;
+    }
+    else {
+        Indentor::indent(cout) << "Unknown rule "
+                               << "(" << i->children.size() << ")"
+                               << "  " << string(i->value.begin(), i->value.end()) << endl;
+    }
+#endif
+
+    Indentor in2;
+    if (i->children.size() == 3) {
+        // child 1: left                0
+        // child 2: root(i.e ==,!=)    +1
+        // child 3: right              +2
+
+        // cout << "i->children.size() == 3 ======================== \n";
+        AstRoot* someRoot = createRootNode(i->children.begin() + 1, rule_names);
+        if (someRoot) {
+            Ast* left = doCreateAst(i->children.begin(), rule_names, someRoot);
+            if (left)
+                someRoot->addChild(left);
+            Ast* right = doCreateAst(i->children.begin() + 2, rule_names, someRoot);
+            if (right)
+                someRoot->addChild(right);
+
+            if (top)
+                top->addChild(someRoot);
+            else
+                return someRoot;
+        }
+    }
+    else if (is_root_node(i) && i->children.size() == 2) {
+
+        // cout << "is_root_node(i) && i->children.size() == 2\n";
+        AstRoot* someRoot = createRootNode(i, rule_names);
+
+        Ast* left = doCreateAst(i->children.begin(), rule_names, someRoot);
+        if (left)
+            someRoot->addChild(left);
+        Ast* right = doCreateAst(i->children.begin() + 1, rule_names, someRoot);
+        if (right)
+            someRoot->addChild(right);
+
+        if (top)
+            top->addChild(someRoot);
+        else
+            return someRoot;
+    }
+    else if (i->children.size() == 4 && is_not(i->children.begin())) {
+        // child 0: notRoot                 0
+        // child 1: notChild               +1
+        // child 2: someRoot(i.e ==,!=)    +2
+        // child 3: right                  +3
+        // Create as:         someRoot
+        //              notRoot          right
+        //      notChild
+        // cout << "(i->children.size() == 4 && is_not(i->children.begin()))\n";
+
+        LOG_ASSERT(is_not(i->children.begin()), "");
+        AstRoot* notRoot = createRootNode(i->children.begin(), rule_names);
+
+        Ast* notChild = doCreateAst(i->children.begin() + 1, rule_names, notRoot /*top*/);
+        if (notChild)
+            notRoot->addChild(notChild);
+
+        AstRoot* someRoot = createRootNode(i->children.begin() + 2, rule_names);
+        someRoot->addChild(notRoot); // left
+
+        Ast* right = doCreateAst(i->children.begin() + 3, rule_names, someRoot /* top*/);
+        if (right)
+            someRoot->addChild(right);
+        if (top)
+            top->addChild(someRoot);
+        else
+            return someRoot;
+    }
+    else if (i->children.size() == 4 && is_root_node(i->children.begin() + 1) && is_not(i->children.begin() + 2)) {
+        // child 0: child                   0
+        // child 1: someRoot(i.e ==,!=)    +1
+        // child 2: NOT                    +2
+        // child 3: integer | variable     +3
+        //
+        // Create as:         someRoot
+        //              child          notRoot
+        //                                    notChild
+        // cout << "(i->children.size() == 4 && is_root_node(i->children.begin()+1) && is_not(i->children.begin()+2)
+        // )\n";
+        AstRoot* someRoot = createRootNode(i->children.begin() + 1, rule_names);
+        Ast* varPath      = doCreateAst(i->children.begin(), rule_names, someRoot /*top*/);
+        if (varPath)
+            someRoot->addChild(varPath); // left
+
+        AstRoot* notRoot = createRootNode(i->children.begin() + 2, rule_names);
+        someRoot->addChild(notRoot); // right
+
+        Ast* notChild = doCreateAst(i->children.begin() + 3, rule_names, notRoot /*top*/);
+        if (notChild)
+            notRoot->addChild(notChild);
+
+        if (top)
+            top->addChild(someRoot);
+        else
+            return someRoot;
+    }
+    else if (i->children.size() == 2 && is_not(i->children.begin())) {
+        // child 1: not     0
+        // child 2: left   +1
+        // cout << "(i->children.size() == 2 && is_not(i->children.begin()) )\n";
+
+        AstRoot* notRoot = createRootNode(i->children.begin(), rule_names);
+
+        if (child_has(i, ExpressionGrammer::basic_variable_path_ID)) {
+            // special case where we treat as a event i.e ! ../../../prod2diss/operation_is_late:yes
+            notRoot->addChild(createAst(i->children.begin() + 1, rule_names));
+        }
+        else {
+            Ast* left = doCreateAst(i->children.begin() + 1, rule_names, notRoot);
+            if (left)
+                notRoot->addChild(left);
+        }
+
+        if (top)
+            top->addChild(notRoot);
+        else
+            return notRoot;
+    }
+    else if (i->children.size() >= 5) {
+        // Must be multiple and's could have nots  Could have:
+        //     !a and b
+        //      a and !b
+        // We always treat the not as *child*
+        // cout << "(i->children.size() >=5 ) \n";
+        stack<Ast*> childs;
+        stack<Ast*> parents;
+        Ast* not_ast = nullptr;
+        for (auto t = i->children.begin(); t != i->children.end(); ++t) {
+            if (is_root_node(t) && !is_not(t)) {
+                Ast* and_ast = createRootNode(t, rule_names);
+                assert(and_ast);
+                assert(parents.empty());
+                parents.push(and_ast);
+            }
+            else {
+                if (is_not(t)) {
+                    assert(!not_ast);
+                    not_ast = createRootNode(t, rule_names);
+                    assert(not_ast);
+                    childs.push(not_ast);
+                }
+                else {
+                    Ast* child_ast = doCreateAst(t, rule_names, /*Top*/ nullptr);
+                    assert(child_ast);
+                    if (not_ast) {
+                        not_ast->addChild(child_ast);
+                        not_ast = nullptr;
+                    }
+                    else {
+                        childs.push(child_ast);
+                    }
+                }
+            }
+
+            if (parents.size() == 1 && childs.size() == 2) {
+                Ast* parent = parents.top();
+                parents.pop();
+                Ast* child1 = childs.top();
+                childs.pop();
+                Ast* child2 = childs.top();
+                childs.pop();
+                parent->addChild(child2);
+                parent->addChild(child1);
+                assert(parents.empty() && childs.empty());
+                childs.push(parent);
+            }
+        }
+        assert(top);
+        assert(childs.size() == 1);
+        if (top)
+            top->addChild(childs.top());
+    }
+    else {
+        // cout <<
+        // "JJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJJ\n";
+        Ast* child = createAst(i, rule_names);
+        if (top && child)
+            top->addChild(child);
+        else
+            return child;
+    }
+    return nullptr;
+}
+
+AstTop* createTopAst(tree_parse_info<> info,
+                     const std::string& expr,
+                     const std::map<parser_id, std::string>& rule_names,
+                     std::string& error_msg) {
+#if defined(PRINT_AST_TRAVERSAL)
+    std::cout << "\nPRINT_AST_TRAVERSAL  " << expr << "\n";
+#endif
+
+    std::unique_ptr<AstTop> ast = std::make_unique<AstTop>();
+    try {
+        (void)doCreateAst(info.trees.begin(), rule_names, ast.get());
+    }
+    catch (std::runtime_error& error) {
+        error_msg = error.what();
+        return nullptr;
+    }
+
+    if (!ast->is_valid_ast(error_msg)) {
+        return nullptr;
+    }
+
+#if defined(PRINT_AST)
+    if (ast.get()) {
+        std::stringstream s2;
+        ast->print_flat(s2, true /*add_brackets*/);
+        std::cout << "\nPRINT_AST  " << s2.str() << "\n";
+        std::cout << "PRINT_AST  " << expr << "\n";
+        std::cout << *ast.get();
+    }
+#endif
+    return ast.release();
+}
+
+///////////////////////////////////////////////////////////////////////////
+// SimpleExprParser
+//////////////////////////////////////////////////////////////////////////
+
+bool has_complex_expressions(const std::string& expr) {
+    // we allow . and /
+    if (expr.find('(') != string::npos)
+        return true;
+    if (expr.find(':') != string::npos)
+        return true;
+    if (expr.find('.') != string::npos)
+        return true;
+    if (expr.find('/') != string::npos)
+        return true;
+    if (expr.find(" not ") != string::npos)
+        return true;
+    if (expr.find(" and ") != string::npos)
+        return true;
+    if (expr.find(" or ") != string::npos)
+        return true;
+    if (expr.find('!') != string::npos)
+        return true;
+    if (expr.find("&&") != string::npos)
+        return true;
+    if (expr.find("||") != string::npos)
+        return true;
+    if (expr.find('<') != string::npos)
+        return true;
+    if (expr.find('>') != string::npos)
+        return true;
+    if (expr.find('+') != string::npos)
+        return true;
+    if (expr.find('-') != string::npos)
+        return true;
+    if (expr.find('*') != string::npos)
+        return true;
+    if (expr.find('~') != string::npos)
+        return true;
+    if (expr.find(" ne ") != string::npos)
+        return true;
+    if (expr.find(" ge ") != string::npos)
+        return true;
+    if (expr.find("<=") != string::npos)
+        return true;
+    if (expr.find(">=") != string::npos)
+        return true;
+    if (expr.find(" le ") != string::npos)
+        return true;
+    if (expr.find(" gt ") != string::npos)
+        return true;
+    if (expr.find(" lt ") != string::npos)
+        return true;
+    return false;
+}
+
+bool SimpleExprParser::doParse() {
+    // 3199.def 57Mg
+    // a == b, || a eq b i.e simple  76940
+    // complex                       39240
+    if (has_complex_expressions(expr_)) {
+        return false;
+    }
+
+    // look for path == <state> || path eq state
+    // This gets round issue with Str::split:
+    //   "a = complete" will be split
+    // since will split on *ANY* of character, and hence this would not be reported as an error
+    std::vector<std::string> tokens;
+    if (expr_.find("==") != string::npos) {
+        Str::split(expr_, tokens, "==");
+    }
+    else if (expr_.find(" eq ") != string::npos) {
+        Str::split(expr_, tokens, " eq ");
+    }
+    else {
+        return false;
+    }
+
+    if (tokens.size() == 2) {
+
+        ecf::algorithm::trim(tokens[0]);
+        ecf::algorithm::trim(tokens[1]);
+
+        if (tokens[0].find(' ') != string::npos) {
+            //         cout << "Found space " << expr_ << "\n";
+            return false;
+        }
+
+        if (DState::isValid(tokens[1])) {
+
+            ast_          = std::make_unique<AstTop>();
+            Ast* someRoot = new AstEqual();
+            someRoot->addChild(new AstNode(tokens[0]));
+            someRoot->addChild(new AstNodeState(DState::toState(tokens[1])));
+            ast_->addChild(someRoot);
+            //       cout << "simple expr : " << expr_ << " `" << tokens[0] << "' = '" << tokens[1] << "'\n";
+            return true;
+        }
+        else {
+            try {
+                auto left     = ecf::convert_to<int>(tokens[0]);
+                auto right    = ecf::convert_to<int>(tokens[1]);
+                ast_          = std::make_unique<AstTop>();
+                Ast* someRoot = new AstEqual();
+                someRoot->addChild(new AstInteger(left));
+                someRoot->addChild(new AstInteger(right));
+                ast_->addChild(someRoot);
+                //               cout << "simple INT expr : " << expr_ << " `" << tokens[0] << "' = '" << tokens[1] <<
+                //               "'\n";
+                return true;
+            }
+            catch (const ecf::bad_conversion&) {
+                //            cout << "simple INT FAILED expr : " << expr_ << " `" << tokens[0] << "' = '"
+                //                     << tokens[1] << "'\n";
+            }
+        }
+    }
+    return false;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ExprParser.hpp 5.13.0-1/libs/node/src/ecflow/node/ExprParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ExprParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ExprParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ExprParser_HPP
+#define ecflow_node_ExprParser_HPP
+
+#include <memory> // for unique_ptr
+#include <string>
+
+#include "ecflow/node/ExprAst.hpp"
+
+/// This class will parse a expression and create the abstract syntax tree
+/// It will own the AST unless specifically released calling ast();
+class ExprParser {
+public:
+    explicit ExprParser(const std::string& expression);
+    // Disable copy (and move) semantics
+    ExprParser(const ExprParser&)                  = delete;
+    const ExprParser& operator=(const ExprParser&) = delete;
+
+    /// Parse the expression, return true if parse OK false otherwise
+    /// if false is returned, and error message is returned
+    bool doParse(std::string& errorMsg);
+
+    /// return the Abstract syntax tree, and release memory
+    std::unique_ptr<AstTop> ast() { return std::move(ast_); }
+
+    /// return the Abstract syntax tree, without release memory
+    AstTop* getAst() const { return ast_.get(); }
+
+private:
+    std::unique_ptr<AstTop> ast_;
+    std::string expr_;
+};
+
+// This class was added to mitigate the slowness of the boost classic spirit parser
+// we will recognise very simple expression, and bypass spirit. Very limited
+// But the simple expression do form a very large subset
+class SimpleExprParser {
+public:
+    explicit SimpleExprParser(const std::string& expression) : expr_(expression) {}
+    // Disable copy (and move) semantics
+    SimpleExprParser(const SimpleExprParser&)                  = delete;
+    const SimpleExprParser& operator=(const SimpleExprParser&) = delete;
+
+    /// Parse the expression, return true if parse OK false otherwise
+    bool doParse();
+
+    /// return the Abstract syntax tree, and release memory
+    std::unique_ptr<AstTop> ast() { return std::move(ast_); }
+
+private:
+    const std::string& expr_;
+    std::unique_ptr<AstTop> ast_;
+};
+
+#endif /* ecflow_node_ExprParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Expression.cpp 5.13.0-1/libs/node/src/ecflow/node/Expression.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Expression.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Expression.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,293 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Expression.hpp"
+
+#include <cassert>
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/node/ExprParser.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace std;
+using namespace ecf;
+
+///////////////////////////////////////////////////////////////////////////////////////////
+
+std::string PartExpression::toString(const std::string& exprType) const {
+    std::stringstream ss;
+    ss << exprType; // trigger or complete
+    switch (type_) {
+        case PartExpression::FIRST:
+            ss << " ";
+            break;
+        case PartExpression::AND:
+            ss << " -a ";
+            break;
+        case PartExpression::OR:
+            ss << " -o ";
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    ss << exp_ << "\n";
+    return ss.str();
+}
+
+void PartExpression::print(std::string& os, const std::string& exprType, bool isFree) const {
+    Indentor in;
+    Indentor::indent(os);
+    os += exprType;
+    switch (type_) {
+        case PartExpression::FIRST:
+            os += " ";
+            break;
+        case PartExpression::AND:
+            os += " -a ";
+            break;
+        case PartExpression::OR:
+            os += " -o ";
+            break;
+        default:
+            assert(false);
+            break;
+    }
+    os += exp_;
+
+    if (!PrintStyle::defsStyle()) {
+        if (type_ == PartExpression::FIRST) {
+            if (isFree)
+                os += " # free";
+        }
+    }
+    os += "\n";
+}
+
+std::unique_ptr<AstTop> PartExpression::parseExpressions(std::string& errorMsg) const {
+    // #ifdef DEBUG
+    //	cout << "PartExpression::parseExpressions '" << exp_ << "'\n";
+    // #endif
+    if (!exp_.empty()) {
+        ExprParser expressionParser(exp_);
+        if (expressionParser.doParse(errorMsg)) {
+
+            // returns new allocated memory, if no errors
+            std::unique_ptr<AstTop> ast = expressionParser.ast();
+
+            if (errorMsg.empty())
+                LOG_ASSERT(ast.get(), "");
+            else
+                LOG_ASSERT(!ast.get(), "");
+
+            return ast;
+        }
+    }
+    return std::unique_ptr<AstTop>();
+}
+
+//===========================================================================
+
+Expression::Expression(const std::string& expression) {
+    add(PartExpression(expression));
+}
+
+Expression::Expression(const PartExpression& exp) {
+    add(exp);
+}
+
+Expression::Expression() = default;
+
+Expression::Expression(const Expression& rhs) : vec_(rhs.vec_), free_(rhs.free_) {
+}
+
+std::unique_ptr<AstTop> Expression::parse(const std::string& expression_to_parse,
+                                          const std::string& error_msg_context) {
+    PartExpression exp(expression_to_parse);
+    string parseErrorMsg;
+    std::unique_ptr<AstTop> ast = exp.parseExpressions(parseErrorMsg);
+    if (!ast.get()) {
+        std::stringstream ss;
+        ss << error_msg_context << " Failed to parse expression '" << expression_to_parse << "'.  " << parseErrorMsg;
+        throw std::runtime_error(ss.str());
+    }
+    return ast;
+}
+
+std::unique_ptr<AstTop> Expression::parse_no_throw(const std::string& expression_to_parse,
+                                                   std::string& error_msg_context) {
+    PartExpression exp(expression_to_parse);
+    string parseErrorMsg;
+    std::unique_ptr<AstTop> ast = exp.parseExpressions(parseErrorMsg);
+    if (!ast.get()) {
+        std::stringstream ss;
+        ss << error_msg_context << " Failed to parse expression '" << expression_to_parse << "'.  " << parseErrorMsg;
+        error_msg_context = ss.str();
+    }
+    return ast;
+}
+
+void Expression::print(std::string& os, const std::string& exprType) const {
+    for (const PartExpression& expr : vec_) {
+        expr.print(os, exprType, free_);
+    }
+}
+
+std::string Expression::compose_expression(const std::vector<PartExpression>& vec) {
+    string ret;
+    auto theEnd = vec.end();
+    for (auto expr = vec.begin(); expr != theEnd; ++expr) {
+        if ((*expr).andExpr())
+            ret += " AND ";
+        else if ((*expr).orExpr())
+            ret += " OR ";
+        ret += (*expr).expression();
+    }
+    return ret;
+}
+
+void Expression::add(const PartExpression& t) {
+    if (vec_.empty()) {
+        // The first expression should not have AND or OR
+        if (t.andExpr() || t.orExpr()) {
+            std::stringstream ss;
+            ss << "Expression::add: expression " << t.expression()
+               << " failed: The first expression should not have AND or OR set";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else {
+        // Subsequent expression must be AND or OR expressions
+        if (!t.andExpr() && !t.orExpr()) {
+            std::stringstream ss;
+            ss << "Expression::add: expression " << t.expression()
+               << " failed: Subsequent expression must have AND or OR set";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    vec_.push_back(t);
+    //	cout << "Expression::add " << expression() << "\n";
+}
+
+void Expression::add_expr(const std::vector<PartExpression>& vec) {
+    for (auto part : vec) {
+        if (!empty() && part.expr_type() == PartExpression::FIRST)
+            part.set_expr_type(PartExpression::AND);
+        add(part);
+    }
+}
+
+// ============================================================================
+// CREATE AST tree for each expression, and COMBINE AST for each expression into a single AST.
+// ============================================================================
+void Expression::createAST(Node* node, const std::string& exprType, std::string& errorMsg) const {
+    size_t theSize = vec_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        std::string localErrorMsg;
+        std::unique_ptr<AstTop> ast = vec_[i].parseExpressions(localErrorMsg);
+        if (ast.get()) {
+
+            // We can have multiple trigger/complete expression, combine to a single AST tree
+            if (theCombinedAst_.get()) {
+                // Must be trigger with -a(and) or -o(or) option's
+                LOG_ASSERT(theCombinedAst_->isTop(), "");
+                LOG_ASSERT(ast->isTop(), "");
+                /* Combine AST tree
+                                          top     top2 (this top needs to be deleted)       top            top2
+                                           |        |                                ===>    |              |
+                                          root1    root2                                   newRoot         NULL;
+                                                                                            / \
+                                                                                        root1  root2
+                 */
+                Ast* newRoot = nullptr;
+                if (vec_[i].andExpr())
+                    newRoot = new AstAnd();
+                else if (vec_[i].orExpr())
+                    newRoot = new AstOr();
+                else
+                    LOG_ASSERT(false, ""); // what else can it be.
+
+                if (newRoot) {
+                    newRoot->addChild(theCombinedAst_->left());
+                    newRoot->addChild(ast->left());
+                    theCombinedAst_->addChild(newRoot); // will overwrite
+
+                    // Since we have transferred over root2 it must be set to NULL for top2,
+                    // to avoid its child destruction
+                    ast->addChild(nullptr); // since its an unique_ptr, no need for explicit delete
+                }
+            }
+            else {
+                // The very first expression should _NOT_ be AND/OR trigger. (i.e no -o | -a)
+                LOG_ASSERT((!vec_[i].andExpr()) && (!vec_[i].orExpr()), "");
+                theCombinedAst_ = std::move(ast); // transfer ownership
+                theCombinedAst_->exprType(exprType);
+            }
+            //			cout << "****************************************************************\n";
+            //			cout << theCombinedAst->expression() << "\n";
+            //			cout << *theCombinedAst << "\n";
+        }
+        else {
+            std::stringstream ss;
+            ss << "Failed to parse " << vec_[i].toString(exprType) << " at " << node->debugNodePath() << " because "
+               << localErrorMsg << "\n\n";
+            errorMsg += ss.str();
+            break;
+        }
+    }
+
+    if (theCombinedAst_.get()) {
+        theCombinedAst_->setParentNode(node);
+    }
+}
+
+void Expression::setFree() {
+    // Only update for a real change
+    if (!free_) {
+        state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Expression::setFree()\n";
+#endif
+    }
+    free_ = true;
+}
+
+void Expression::clearFree() {
+    // Only update for a real change
+    if (free_) {
+        state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Expression::clearFree()\n";
+#endif
+    }
+    free_ = false;
+}
+
+template <class Archive>
+void PartExpression::serialize(Archive& ar) {
+    ar(CEREAL_NVP(exp_));
+    CEREAL_OPTIONAL_NVP(ar, type_, [this]() { return type_ != default_expr_type(); }); // conditionally save
+}
+
+template <class Archive>
+void Expression::serialize(Archive& ar) {
+    ar(CEREAL_NVP(vec_));
+    CEREAL_OPTIONAL_NVP(ar, free_, [this]() { return free_; }); // conditionally save
+}
+
+CEREAL_TEMPLATE_SPECIALIZE(PartExpression);
+CEREAL_TEMPLATE_SPECIALIZE(Expression);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Expression.hpp 5.13.0-1/libs/node/src/ecflow/node/Expression.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Expression.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Expression.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,152 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Expression_HPP
+#define ecflow_node_Expression_HPP
+
+#include <memory> // for unique_ptr
+
+#include "ecflow/node/ExprAst.hpp"
+
+class Node;
+
+namespace cereal {
+class access;
+}
+
+/// class PartExpression:
+///  Hold a single expression, optional can specify whether it is to be And' or
+///  'Ored' when used as a part of a larger expression.
+///  Uses compiler , generated destructor, assignment,  copy constructor
+class PartExpression {
+public:
+    enum ExprType { FIRST, AND, OR };
+
+    PartExpression() : type_(default_expr_type()) {}
+    explicit PartExpression(const std::string& expression) : exp_(expression), type_(default_expr_type()) {}
+    explicit PartExpression(std::string&& expression) : exp_(std::move(expression)), type_(default_expr_type()) {}
+    PartExpression(const std::string& expression, bool and_type) : exp_(expression), type_((and_type) ? AND : OR) {}
+    PartExpression(std::string&& expression, bool and_type)
+        : exp_(std::move(expression)),
+          type_((and_type) ? AND : OR) {}
+
+    static ExprType default_expr_type() { return FIRST; } // NEVER change
+
+    const std::string& expression() const { return exp_; }
+    bool andExpr() const { return (type_ == AND) ? true : false; }
+    bool orExpr() const { return (type_ == OR) ? true : false; }
+
+    std::string toString(const std::string& exprType) const;
+    void print(std::string&, const std::string& exprType, bool isFree) const;
+
+    bool operator==(const PartExpression& rhs) const { return type_ == rhs.type_ && exp_ == rhs.exp_; }
+    bool operator!=(const PartExpression& rhs) const { return !operator==(rhs); }
+
+    /// Parse the expression and create the abstract syntax tree
+    std::unique_ptr<AstTop> parseExpressions(std::string& errorMsg) const;
+
+    void set_expr_type(ExprType t) { type_ = t; }
+    ExprType expr_type() const { return type_; }
+
+private:
+    std::string exp_;
+    ExprType type_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+////////////////////////////////////////////////////////////////////////////////////////
+// Class Expression:
+//       A Expression occur in a Trigger or Complete statement
+//       This class hold a number of part expression.
+//       It can also create a  single AST from the part expressions
+// NOTE: Distinguish between parser errors, and node path resolution
+//       Here we are only concerned with parser errors.
+// Use compiler , generated destructor, assignment,  copy constructor
+class Expression {
+public:
+    Expression();
+    explicit Expression(const std::string& expression);
+    explicit Expression(const PartExpression&);
+
+    Expression(const Expression& rhs);
+    // prevent assignment since we have an unique_ptr
+    Expression& operator=(Expression const& f) = delete;
+
+    bool operator==(const Expression& rhs) const {
+        if (free_ != rhs.free_)
+            return false;
+        return vec_ == rhs.vec_;
+    }
+    bool operator!=(const Expression& rhs) const { return !operator==(rhs); }
+
+    /// Helper function, will parse the expression and return the abstract syntax tree
+
+    static std::unique_ptr<AstTop> parse(const std::string& expression_to_parse,
+                                         const std::string& error_msg_context); // Will throw for parse errors
+    static std::unique_ptr<AstTop> parse_no_throw(const std::string& expression_to_parse,
+                                                  std::string& error_msg_context);
+
+    /// User should add "trigger" or "complete" at the start.
+    /// The part expression's are combined and returned as a single string
+    std::string expression() const { return compose_expression(vec_); }
+    static std::string compose_expression(const std::vector<PartExpression>& vec);
+
+    /// Need to pass in trigger tag, since expression may be split over multiple lines
+    /// trigger    "a == complete"
+    /// trigger -a "b == complete"
+    void print(std::string&, const std::string& exprType) const;
+
+    /// Use when we want to add compose a large expression form a set of smaller ones
+    void add(const PartExpression& t);
+    void add_expr(const std::vector<PartExpression>& vec);
+
+    // ==============================================================================================
+    // CREATE AST tree for each expression and COMBINE AST for each expression into a single AST.
+    // ==============================================================================================
+    void createAST(Node* parent_node, const std::string& exprType, std::string& errorMsg) const;
+    AstTop* get_ast() const { return theCombinedAst_.get(); } // can return NULL
+
+    /// Placed here rather than the expression tree. Since the expression
+    /// tree is created on demand, and is not persisted
+    void setFree();   // hence must be used before evaluate
+    void clearFree(); // resets the free flag
+    bool isFree() const { return free_; }
+    bool empty() const { return vec_.empty(); }
+    const std::vector<PartExpression>& expr() const { return vec_; }
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+private: /// For use by python interface,
+    friend void export_NodeAttr();
+    friend class Trigger;
+    friend class Complete;
+    std::vector<PartExpression>::const_iterator part_begin() const { return vec_.begin(); }
+    std::vector<PartExpression>::const_iterator part_end() const { return vec_.end(); }
+
+private:
+    // They are created on demand. reasons:
+    // 1/ Help with AIX serialisation
+    // 2/ Help to reduce network traffic
+    mutable std::unique_ptr<AstTop> theCombinedAst_; // *not* persisted, demand created
+    std::vector<PartExpression> vec_;
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    bool free_{false};
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_node_Expression_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Family.cpp 5.13.0-1/libs/node/src/ecflow/node/Family.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Family.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Family.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,228 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Family.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/NodeTreeVisitor.hpp"
+
+using namespace ecf;
+using namespace std;
+
+/////////////////////////////////////////////////////////////////////////////////////////
+// The false below is used as a dummy argument to call the Variable constructor that does not
+// Check the variable names. i.e we know they are valid
+
+Family& Family::operator=(const Family& rhs) {
+    if (this != &rhs) {
+        NodeContainer::operator=(rhs);
+        delete fam_gen_variables_;
+        fam_gen_variables_ = nullptr;
+    }
+    return *this;
+}
+
+node_ptr Family::clone() const {
+    return std::make_shared<Family>(*this);
+}
+
+Family::~Family() {
+    if (!Ecf::server()) {
+        notify_delete();
+    }
+
+    delete fam_gen_variables_;
+}
+
+family_ptr Family::create(const std::string& name, bool check) {
+    return std::make_shared<Family>(name, check);
+}
+
+family_ptr Family::create_me(const std::string& name) {
+    return std::make_shared<Family>(name, true);
+}
+
+bool Family::check_defaults() const {
+    if (fam_gen_variables_ != nullptr)
+        throw std::runtime_error("Family ::check_defaults():  fam_gen_variables_ != nullptr");
+    return NodeContainer::check_defaults();
+}
+
+void Family::accept(ecf::NodeTreeVisitor& v) {
+    v.visitFamily(this);
+    NodeContainer::accept(v);
+}
+
+void Family::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
+    v.visitFamily(this);
+}
+
+void Family::begin() {
+    NodeContainer::begin();
+    update_generated_variables();
+}
+
+bool Family::resolveDependencies(JobsParam& jobsParam) {
+    if (jobsParam.check_for_job_generation_timeout())
+        return false;
+
+    return NodeContainer::resolveDependencies(jobsParam);
+}
+
+void Family::requeue(Requeue_args& args) {
+    NodeContainer::requeue(args);
+    update_generated_variables();
+}
+
+bool Family::operator==(const Family& rhs) const {
+    return NodeContainer::operator==(rhs);
+}
+
+void Family::print(std::string& os) const {
+    // Generated variable are not persisted since they are created on demand
+    // There *NO* point in printing them they will always be empty
+
+    Indentor in;
+    Indentor::indent(os);
+    os += "family ";
+    os += name();
+    if (!PrintStyle::defsStyle()) {
+        bool added_comment_char = false;
+        write_state(os, added_comment_char);
+    }
+    os += "\n";
+
+    Node::print(os);
+    NodeContainer::print(os);
+    Indentor::indent(os);
+    os += "endfamily\n";
+}
+
+void Family::write_state(std::string& ret, bool& added_comment_char) const {
+    NodeContainer::write_state(ret, added_comment_char);
+}
+void Family::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
+    NodeContainer::read_state(line, lineTokens);
+}
+
+const std::string& Family::debugType() const {
+    return ecf::Str::FAMILY();
+}
+
+std::ostream& operator<<(std::ostream& os, const Family& d) {
+    std::string s;
+    d.print(s);
+    os << s;
+    return os;
+}
+
+void Family::collateChanges(DefsDelta& changes) const {
+    /// All changes to family should be on ONE compound_memento_ptr
+    compound_memento_ptr compound;
+    NodeContainer::incremental_changes(changes, compound);
+
+    // Traversal
+    NodeContainer::collateChanges(changes);
+}
+
+// generated variables --------------------------------------------------------------------------
+
+void Family::update_generated_variables() const {
+    if (!fam_gen_variables_)
+        fam_gen_variables_ = new FamGenVariables(this);
+    fam_gen_variables_->update_generated_variables();
+    update_repeat_genvar();
+}
+
+const Variable& Family::findGenVariable(const std::string& name) const {
+    // Generally it should be never the case that the values are empty
+    // Since the user is assumed to have called begin(), which force
+    // the generation of generated variables
+
+    // AST can reference generated variables. Currently integer based values
+    // The family names can be integers
+
+    if (!fam_gen_variables_)
+        update_generated_variables();
+    const Variable& gen_var = fam_gen_variables_->findGenVariable(name);
+    if (!gen_var.empty())
+        return gen_var;
+
+    return NodeContainer::findGenVariable(name);
+}
+
+void Family::gen_variables(std::vector<Variable>& vec) const {
+    if (!fam_gen_variables_)
+        update_generated_variables();
+
+    vec.reserve(vec.size() + 3);
+    fam_gen_variables_->gen_variables(vec);
+    NodeContainer::gen_variables(vec);
+}
+
+std::string Family::find_node_path(const std::string& type, const std::string& node_name) const {
+    if (Str::caseInsCompare(type, "family")) {
+        if (node_name == name()) {
+            return absNodePath();
+        }
+    }
+    return NodeContainer::find_node_path(type, node_name);
+}
+
+// ================================================================
+
+FamGenVariables::FamGenVariables(const Family* f)
+    : family_(f),
+      genvar_family_("FAMILY", "", false),
+      genvar_family1_("FAMILY1", "", false) {
+}
+
+void FamGenVariables::update_generated_variables() const {
+    // This function is called during:
+    //   o begin()
+    //   o requeue()
+    // Since family generated not persisted, allow for demand creation by client
+    genvar_family1_.set_value(family_->name());
+
+    // FAMILY is the full path excluding the suite, there is *NO* leading slash
+    std::string path              = family_->absNodePath();
+    string::size_type secondSlash = path.find('/', 1);
+    path.erase(0, secondSlash + 1);
+    genvar_family_.set_value(path);
+}
+
+const Variable& FamGenVariables::findGenVariable(const std::string& name) const {
+    if (genvar_family_.name() == name)
+        return genvar_family_;
+    if (genvar_family1_.name() == name)
+        return genvar_family1_;
+    return Variable::EMPTY();
+}
+
+void FamGenVariables::gen_variables(std::vector<Variable>& vec) const {
+    vec.push_back(genvar_family_);
+    vec.push_back(genvar_family1_);
+}
+
+template <class Archive>
+void Family::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<NodeContainer>(this));
+}
+
+CEREAL_TEMPLATE_SPECIALIZE_V(Family);
+CEREAL_REGISTER_TYPE(Family)
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Family.hpp 5.13.0-1/libs/node/src/ecflow/node/Family.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Family.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Family.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,98 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Family_HPP
+#define ecflow_node_Family_HPP
+
+#include "ecflow/node/NodeContainer.hpp"
+
+class FamGenVariables;
+
+class Family final : public NodeContainer {
+public:
+    explicit Family(const std::string& name, bool check = true) : NodeContainer(name, check) {}
+    Family() = default;
+    Family(const Family& rhs) : NodeContainer(rhs) {}
+    Family& operator=(const Family&);
+    node_ptr clone() const override;
+
+    ~Family() override;
+
+    static family_ptr create(const std::string& name, bool check = true);
+    static family_ptr create_me(const std::string& name); // python api, to pick correct init function
+
+    bool check_defaults() const override;
+
+    Suite* suite() const override { return parent()->suite(); }
+    Defs* defs() const override {
+        return (parent()) ? parent()->defs() : nullptr;
+    } // exposed to python hence check for NULL first
+    Family* isFamily() const override { return const_cast<Family*>(this); }
+    NodeContainer* isNodeContainer() const override { return const_cast<Family*>(this); }
+
+    void begin() override;
+    bool resolveDependencies(JobsParam&) override; // overriden to speicy family for job profiler
+    void requeue(Requeue_args&) override;
+    void accept(ecf::NodeTreeVisitor&) override;
+    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
+    void update_generated_variables() const override;
+    const Variable& findGenVariable(const std::string& name) const override;
+    void gen_variables(std::vector<Variable>&) const override;
+    std::string find_node_path(const std::string& type, const std::string& name) const override;
+
+    const std::string& debugType() const override;
+
+    void print(std::string&) const override;
+    bool operator==(const Family& rhs) const;
+
+    void collateChanges(DefsDelta&) const override;
+    void set_memento(const OrderMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
+        NodeContainer::set_memento(m, aspects, f);
+    }
+    void set_memento(const ChildrenMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
+        NodeContainer::set_memento(m, aspects, f);
+    }
+
+    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
+
+private:
+    void write_state(std::string&, bool&) const override;
+
+    mutable FamGenVariables* fam_gen_variables_{nullptr};
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+std::ostream& operator<<(std::ostream& os, const Family&);
+
+// We can have several thousands Families. This class helps in avoiding
+// the creation of generated variables until required.
+// This improves client->server download times by avoiding thousands of string constructions
+class FamGenVariables {
+public:
+    explicit FamGenVariables(const Family*);
+    // Disable copy (and move) semantics
+    FamGenVariables(const FamGenVariables&)                  = delete;
+    const FamGenVariables& operator=(const FamGenVariables&) = delete;
+
+    void update_generated_variables() const;
+    const Variable& findGenVariable(const std::string& name) const;
+    void gen_variables(std::vector<Variable>& vec) const;
+
+private:
+    const Family* family_;
+    mutable Variable genvar_family_;
+    mutable Variable genvar_family1_;
+};
+
+#endif /* ecflow_node_Family_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Flag.cpp 5.13.0-1/libs/node/src/ecflow/node/Flag.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Flag.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Flag.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,381 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Flag.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+
+namespace ecf {
+
+void Flag::set(Flag::Type flag) {
+    if (!is_set(flag)) { // minimize changes to state_change_no_
+        flag_ |= (1 << flag);
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+}
+
+void Flag::clear(Flag::Type flag) {
+    if (is_set(flag)) { // minimize changes to state_change_no_
+        flag_ &= ~(1 << flag);
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+}
+
+void Flag::reset() {
+    flag_            = 0;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+std::vector<Flag::Type> Flag::list() {
+    std::vector<Flag::Type> ret;
+    ret.reserve(25);
+    ret.push_back(Flag::FORCE_ABORT);
+    ret.push_back(Flag::USER_EDIT);
+    ret.push_back(Flag::TASK_ABORTED);
+    ret.push_back(Flag::EDIT_FAILED);
+    ret.push_back(Flag::JOBCMD_FAILED);
+    ret.push_back(Flag::KILLCMD_FAILED);
+    ret.push_back(Flag::STATUSCMD_FAILED);
+    ret.push_back(Flag::NO_SCRIPT);
+    ret.push_back(Flag::KILLED);
+    ret.push_back(Flag::STATUS);
+    ret.push_back(Flag::LATE);
+    ret.push_back(Flag::MESSAGE);
+    ret.push_back(Flag::BYRULE);
+    ret.push_back(Flag::QUEUELIMIT);
+    ret.push_back(Flag::WAIT);
+    ret.push_back(Flag::LOCKED);
+    ret.push_back(Flag::ZOMBIE);
+    ret.push_back(Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
+    ret.push_back(Flag::ARCHIVED);
+    ret.push_back(Flag::RESTORED);
+    ret.push_back(Flag::THRESHOLD);
+    ret.push_back(Flag::ECF_SIGTERM);
+    ret.push_back(Flag::LOG_ERROR);
+    ret.push_back(Flag::CHECKPT_ERROR);
+    ret.push_back(Flag::REMOTE_ERROR);
+    return ret;
+}
+
+constexpr std::array<Flag::Type, 25> Flag::array() {
+    return std::array{Flag::FORCE_ABORT,      Flag::USER_EDIT,     Flag::TASK_ABORTED,
+                      Flag::EDIT_FAILED,      Flag::JOBCMD_FAILED, Flag::KILLCMD_FAILED,
+                      Flag::STATUSCMD_FAILED, Flag::NO_SCRIPT,     Flag::KILLED,
+                      Flag::STATUS,           Flag::LATE,          Flag::MESSAGE,
+                      Flag::BYRULE,           Flag::QUEUELIMIT,    Flag::WAIT,
+                      Flag::LOCKED,           Flag::ZOMBIE,        Flag::NO_REQUE_IF_SINGLE_TIME_DEP,
+                      Flag::ARCHIVED,         Flag::RESTORED,      Flag::THRESHOLD,
+                      Flag::ECF_SIGTERM,      Flag::LOG_ERROR,     Flag::CHECKPT_ERROR,
+                      Flag::REMOTE_ERROR};
+}
+
+std::string Flag::enum_to_string(Flag::Type flag) {
+
+    switch (flag) {
+        case Flag::FORCE_ABORT:
+            return "force_aborted";
+            break;
+        case Flag::USER_EDIT:
+            return "user_edit";
+            break;
+        case Flag::TASK_ABORTED:
+            return "task_aborted";
+            break;
+        case Flag::EDIT_FAILED:
+            return "edit_failed";
+            break;
+        case Flag::JOBCMD_FAILED:
+            return "ecfcmd_failed";
+            break;
+        case Flag::NO_SCRIPT:
+            return "no_script";
+            break;
+        case Flag::KILLED:
+            return "killed";
+            break;
+        case Flag::LATE:
+            return "late";
+            break;
+        case Flag::MESSAGE:
+            return "message";
+            break;
+        case Flag::BYRULE:
+            return "by_rule";
+            break;
+        case Flag::QUEUELIMIT:
+            return "queue_limit";
+            break;
+        case Flag::WAIT:
+            return "task_waiting";
+            break;
+        case Flag::LOCKED:
+            return "locked";
+            break;
+        case Flag::ZOMBIE:
+            return "zombie";
+            break;
+        case Flag::NO_REQUE_IF_SINGLE_TIME_DEP:
+            return "no_reque";
+            break;
+        case Flag::ARCHIVED:
+            return "archived";
+            break;
+        case Flag::RESTORED:
+            return "restored";
+            break;
+        case Flag::THRESHOLD:
+            return "threshold";
+            break;
+        case Flag::ECF_SIGTERM:
+            return "sigterm";
+            break;
+        case Flag::LOG_ERROR:
+            return "log_error";
+            break;
+        case Flag::CHECKPT_ERROR:
+            return "checkpt_error";
+            break;
+        case Flag::KILLCMD_FAILED:
+            return "killcmd_failed";
+            break;
+        case Flag::STATUSCMD_FAILED:
+            return "statuscmd_failed";
+            break;
+        case Flag::STATUS:
+            return "status";
+            break;
+        case Flag::REMOTE_ERROR:
+            return "remote_error";
+            break;
+        case Flag::NOT_SET:
+            return "not_set";
+            break;
+        default:
+            break;
+    };
+    return std::string();
+}
+
+const char* Flag::enum_to_char_star(Flag::Type flag) {
+    switch (flag) {
+        case Flag::FORCE_ABORT:
+            return "force_aborted";
+            break;
+        case Flag::USER_EDIT:
+            return "user_edit";
+            break;
+        case Flag::TASK_ABORTED:
+            return "task_aborted";
+            break;
+        case Flag::EDIT_FAILED:
+            return "edit_failed";
+            break;
+        case Flag::JOBCMD_FAILED:
+            return "ecfcmd_failed";
+            break;
+        case Flag::KILLCMD_FAILED:
+            return "killcmd_failed";
+            break;
+        case Flag::STATUSCMD_FAILED:
+            return "statuscmd_failed";
+            break;
+        case Flag::STATUS:
+            return "status";
+            break;
+        case Flag::NO_SCRIPT:
+            return "no_script";
+            break;
+        case Flag::KILLED:
+            return "killed";
+            break;
+        case Flag::LATE:
+            return "late";
+            break;
+        case Flag::MESSAGE:
+            return "message";
+            break;
+        case Flag::BYRULE:
+            return "by_rule";
+            break;
+        case Flag::QUEUELIMIT:
+            return "queue_limit";
+            break;
+        case Flag::WAIT:
+            return "task_waiting";
+            break;
+        case Flag::LOCKED:
+            return "locked";
+            break;
+        case Flag::ZOMBIE:
+            return "zombie";
+            break;
+        case Flag::NO_REQUE_IF_SINGLE_TIME_DEP:
+            return "no_reque";
+            break;
+        case Flag::ARCHIVED:
+            return "archived";
+            break;
+        case Flag::RESTORED:
+            return "restored";
+            break;
+        case Flag::THRESHOLD:
+            return "threshold";
+            break;
+        case Flag::ECF_SIGTERM:
+            return "sigterm";
+            break;
+        case Flag::LOG_ERROR:
+            return "log_error";
+            break;
+        case Flag::CHECKPT_ERROR:
+            return "checkpt_error";
+            break;
+        case Flag::REMOTE_ERROR:
+            return "remote_error";
+            break;
+        case Flag::NOT_SET:
+            return "not_set";
+            break;
+        default:
+            break;
+    };
+    assert(false);
+    return nullptr;
+}
+
+Flag::Type Flag::string_to_flag_type(const std::string& s) {
+    if (s == "force_aborted")
+        return Flag::FORCE_ABORT;
+    if (s == "user_edit")
+        return Flag::USER_EDIT;
+    if (s == "task_aborted")
+        return Flag::TASK_ABORTED;
+    if (s == "edit_failed")
+        return Flag::EDIT_FAILED;
+    if (s == "ecfcmd_failed")
+        return Flag::JOBCMD_FAILED;
+    if (s == "killcmd_failed")
+        return Flag::KILLCMD_FAILED;
+    if (s == "statuscmd_failed")
+        return Flag::STATUSCMD_FAILED;
+    if (s == "status")
+        return Flag::STATUS;
+    if (s == "no_script")
+        return Flag::NO_SCRIPT;
+    if (s == "killed")
+        return Flag::KILLED;
+    if (s == "late")
+        return Flag::LATE;
+    if (s == "message")
+        return Flag::MESSAGE;
+    if (s == "by_rule")
+        return Flag::BYRULE;
+    if (s == "queue_limit")
+        return Flag::QUEUELIMIT;
+    if (s == "task_waiting")
+        return Flag::WAIT;
+    if (s == "locked")
+        return Flag::LOCKED;
+    if (s == "zombie")
+        return Flag::ZOMBIE;
+    if (s == "no_reque")
+        return Flag::NO_REQUE_IF_SINGLE_TIME_DEP;
+    if (s == "archived")
+        return Flag::ARCHIVED;
+    if (s == "restored")
+        return Flag::RESTORED;
+    if (s == "threshold")
+        return Flag::THRESHOLD;
+    if (s == "sigterm")
+        return Flag::ECF_SIGTERM;
+    if (s == "log_error")
+        return Flag::LOG_ERROR;
+    if (s == "checkpt_error")
+        return Flag::CHECKPT_ERROR;
+    if (s == "remote_error")
+        return Flag::REMOTE_ERROR;
+    return Flag::NOT_SET;
+}
+
+void Flag::valid_flag_type(std::vector<std::string>& vec) {
+    vec.reserve(25);
+    vec.emplace_back("force_aborted");
+    vec.emplace_back("user_edit");
+    vec.emplace_back("task_aborted");
+    vec.emplace_back("edit_failed");
+    vec.emplace_back("ecfcmd_failed");
+    vec.emplace_back("statuscmd_failed");
+    vec.emplace_back("killcmd_failed");
+    vec.emplace_back("no_script");
+    vec.emplace_back("killed");
+    vec.emplace_back("status");
+    vec.emplace_back("late");
+    vec.emplace_back("message");
+    vec.emplace_back("by_rule");
+    vec.emplace_back("queue_limit");
+    vec.emplace_back("task_waiting");
+    vec.emplace_back("locked");
+    vec.emplace_back("zombie");
+    vec.emplace_back("no_reque");
+    vec.emplace_back("archived");
+    vec.emplace_back("restored");
+    vec.emplace_back("threshold");
+    vec.emplace_back("sigterm");
+    vec.emplace_back("log_error");
+    vec.emplace_back("checkpt_error");
+    vec.emplace_back("remote_error");
+}
+
+std::string Flag::to_string() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void Flag::write(std::string& ret) const {
+    bool added     = false;
+    auto flag_list = Flag::array();
+    for (auto& i : flag_list) {
+        if (is_set(i)) {
+            if (added)
+                ret += ',';
+            ret += enum_to_char_star(i);
+            added = true;
+        }
+    }
+}
+
+void Flag::set_flag(const std::string& flags) {
+    std::vector<std::string> the_flags_vec;
+    Str::split(flags, the_flags_vec, ",");
+
+    for (const auto& i : the_flags_vec) {
+        if (i == "migrated")
+            continue; // 4.4.x release had migrated ignore. REMOVE when 5.0.0 is default
+
+        Flag::Type ft = string_to_flag_type(i);
+        if (ft == Flag::NOT_SET) {
+            throw std::runtime_error("Flag::set_flag: Unknown flag types found: " + i);
+        }
+        set(ft);
+    }
+}
+
+template <class Archive>
+void Flag::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(flag_));
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(Flag);
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Flag.hpp 5.13.0-1/libs/node/src/ecflow/node/Flag.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Flag.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Flag.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,179 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Flag_HPP
+#define ecflow_node_Flag_HPP
+
+#include <array>
+#include <cstdint>
+#include <string>
+#include <vector>
+
+namespace cereal {
+class access;
+}
+
+namespace ecf {
+
+/// Flag are used store what has happened to a node. These are shown as icon in ecFlowview
+/// Uses compiler generated copy constructor, assignment operator and destructor
+
+/// During interactive use. A Node can be *forced to complete*, or forced to *run*
+/// Typically the user may want to force a node to complete, if they are trying
+/// to update the repeat variable.
+///
+/// In either case  we need to miss a time slot, this is done by setting the
+/// NO_REQUE_IF_SINGLE_TIME_DEP, then at REQUE time we query the flag, if it was set
+/// we avoid resetting the time slots. effectively missing the next time slot.
+///
+/// This functionality is only required during interactive force or run
+/// However if the job aborted, we need to clear NO_REQUE_IF_SINGLE_TIME_DEP, i.e
+///     time 10:00
+///     time 11:00
+/// If at 9.00am use the run command, we want to miss the 10:00 time slot.
+/// However if the run at 9.00 fails, and we run again, we also miss 11:00 time slot
+/// to avoid this if the job aborts, we clear NO_REQUE_IF_SINGLE_TIME_DEP flag.
+
+class Flag {
+public:
+    using underlying_type_t = int;
+    static_assert(sizeof(underlying_type_t) >= 4, "Flag's underlying type must have at least 4 bytes");
+
+    Flag() = default;
+
+    /// The BYRULE is used to distinguish between tasks that have RUN and completed
+    /// and those that have completed by complete expression.
+    enum Type {
+
+        // Node* do not run when try_no > ECF_TRIES, and task aborted by user
+        FORCE_ABORT = 0,
+
+        // task
+        USER_EDIT = 1,
+
+        // task*
+        TASK_ABORTED = 2,
+
+        // task*
+        EDIT_FAILED = 3,
+
+        // task*
+        JOBCMD_FAILED = 4,
+
+        // task*
+        NO_SCRIPT = 5,
+
+        // task* do not run when try_no > ECF_TRIES, and task killed by user
+        KILLED = 6,
+
+        // Node attribute,
+        LATE = 7,
+
+        // Node
+        MESSAGE = 8,
+
+        // Node*, set if node is set to complete by complete trigger expression
+        BYRULE = 9,
+
+        // Node                                   ( NOT USED currently)
+        QUEUELIMIT = 10,
+
+        // task*  set when waiting for trigger expression in client command
+        WAIT = 11,
+
+        // Server                                 ( NOT USED currently)
+        LOCKED = 12,
+
+        // task*  Set/cleared but never queried by GUI
+        ZOMBIE = 13,
+
+        //
+        NO_REQUE_IF_SINGLE_TIME_DEP = 14,
+
+        // Container
+        ARCHIVED = 15,
+
+        // Container, Avoid re-archiving node that is restored, until re-queued again
+        RESTORED = 16,
+
+        // Job threshold exceeded, slow disk, large includes/huge scripts,overloaded machine,server)
+        THRESHOLD = 17,
+
+        // Record on defs that server received SIGTERM signal, main used in test
+        ECF_SIGTERM = 18,
+
+        //
+        NOT_SET = 19,
+
+        // Error in opening or writing to the log file
+        LOG_ERROR = 20,
+
+        // Error in saving checkpoint file
+        CHECKPT_ERROR = 21,
+
+        // task*
+        KILLCMD_FAILED = 22,
+
+        // task*
+        STATUSCMD_FAILED = 23,
+
+        // task*
+        STATUS = 24,
+
+        // Error connecting to remote source
+        REMOTE_ERROR = 25
+    };
+
+    bool operator==(const Flag& rhs) const { return flag_ == rhs.flag_; }
+    bool operator!=(const Flag& rhs) const { return !operator==(rhs); }
+
+    // Flag functions:
+    void set(Type flag);
+    void clear(Type flag);
+    bool is_set(Type flag) const { return (flag_ & (1 << flag)); }
+
+    void reset();
+    int flag() const { return flag_; }
+    void set_flag(underlying_type_t f) { flag_ = f; }
+    void set_flag(const std::string& flags); // these are comma separated
+
+    /// returns a comma separated list of all flags set
+    std::string to_string() const;
+    void write(std::string&) const;
+
+    /// returns the string equivalent
+    static std::string enum_to_string(Flag::Type flag);
+    static const char* enum_to_char_star(Flag::Type flag);
+
+    /// Used to determine change in state relative to client
+    void set_state_change_no(unsigned int n) { state_change_no_ = n; }
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    /// returns the list of all flag types
+    static std::vector<Flag::Type> list();
+    static constexpr std::array<Flag::Type, 25> array();
+
+    /// Converts from string to flag types.
+    static Flag::Type string_to_flag_type(const std::string& s);
+
+    /// valid flag types, than can be used in AlterCmd
+    static void valid_flag_type(std::vector<std::string>& vec);
+
+private:
+    underlying_type_t flag_{0};
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+} // namespace ecf
+
+#endif /* ecflow_node_Flag_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/InLimit.cpp 5.13.0-1/libs/node/src/ecflow/node/InLimit.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/InLimit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/InLimit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,164 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/InLimit.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Limit.hpp"
+#ifdef DEBUG
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+using namespace std;
+using namespace ecf;
+
+/////////////////////////////////////////////////////////////////////////////////////////////
+
+InLimit::InLimit(const std::string& name,
+                 const std::string& pathToNode,
+                 int tokens,
+                 bool limit_this_node_only,
+                 bool limit_submission,
+                 bool check)
+    : n_(name),
+      path_(pathToNode),
+      tokens_(tokens),
+      limit_this_node_only_(limit_this_node_only),
+      limit_submission_(limit_submission) {
+    if (check && !Str::valid_name(name)) {
+        throw std::runtime_error("InLimit::InLimit: Invalid InLimit name: " + name);
+    }
+    if (limit_this_node_only_ && limit_submission_) {
+        throw std::runtime_error(
+            "InLimit::InLimit: can't limit family only(-n) and limit submission(-s) at the same time");
+    }
+}
+
+bool InLimit::operator==(const InLimit& rhs) const {
+    if (path_ != rhs.path_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "InLimit::operator==   path_ != rhs.path_\n";
+#endif
+        return false;
+    }
+    if (n_ != rhs.n_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "InLimit::operator==     n_ != rhs.n_\n";
+#endif
+        return false;
+    }
+    if (tokens_ != rhs.tokens_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "InLimit::operator==    tokens_(" << tokens_ << ") != rhs.tokens_(" << rhs.tokens_ << ")\n";
+#endif
+        return false;
+    }
+
+    if (limit_this_node_only_ != rhs.limit_this_node_only_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "InLimit::operator==    limit_this_node_only_(" << limit_this_node_only_
+                      << ") != rhs.limit_this_node_only_(" << rhs.limit_this_node_only_ << ")\n";
+#endif
+        return false;
+    }
+    if (limit_submission_ != rhs.limit_submission_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "InLimit::operator==     limit_submission_(" << limit_submission_
+                      << ") != rhs.limit_submission_ (" << rhs.limit_submission_ << ")\n";
+#endif
+        return false;
+    }
+    if (incremented_ != rhs.incremented_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality())
+            std::cout << "InLimit::operator==    incremented_(" << incremented_ << ") != rhs.incremented_("
+                      << rhs.incremented_ << ")\n";
+#endif
+        return false;
+    }
+
+    // Note: comparison does not look at Limit pointers
+    return true;
+}
+
+void InLimit::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+
+    if (!PrintStyle::defsStyle()) {
+
+        // write state; See InlimitParser::doParse for read state part
+        if (incremented_)
+            os += " # incremented:1";
+
+        if (PrintStyle::getStyle() == PrintStyle::STATE) {
+            Limit* the_limit = limit();
+            if (the_limit) {
+                os += " # referenced limit(value) ";
+                os += ecf::convert_to<std::string>(the_limit->theLimit());
+                os += "(";
+                os += ecf::convert_to<std::string>(the_limit->value());
+                os += ")";
+            }
+        }
+    }
+
+    os += "\n";
+}
+
+std::string InLimit::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void InLimit::write(std::string& ret) const {
+    ret += "inlimit ";
+    if (limit_this_node_only_)
+        ret += "-n ";
+    if (limit_submission_)
+        ret += "-s ";
+    if (path_.empty())
+        ret += n_;
+    else {
+        ret += path_;
+        ret += Str::COLON();
+        ret += n_;
+    }
+    if (tokens_ != 1) {
+        ret += " ";
+        ret += ecf::convert_to<std::string>(tokens_);
+    }
+}
+
+template <class Archive>
+void InLimit::serialize(Archive& ar) {
+    ar(CEREAL_NVP(n_));
+    CEREAL_OPTIONAL_NVP(ar, path_, [this]() { return !path_.empty(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, tokens_, [this]() { return tokens_ != 1; }); // conditionally save
+    CEREAL_OPTIONAL_NVP(
+        ar, limit_this_node_only_, [this]() { return limit_this_node_only_; }); // conditionally save new to 5.0.0
+    CEREAL_OPTIONAL_NVP(
+        ar, limit_submission_, [this]() { return limit_submission_; });       // conditionally save new to 5.0.0
+    CEREAL_OPTIONAL_NVP(ar, incremented_, [this]() { return incremented_; }); // conditionally save new to 5.0.0
+}
+CEREAL_TEMPLATE_SPECIALIZE(InLimit);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/InLimit.hpp 5.13.0-1/libs/node/src/ecflow/node/InLimit.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/InLimit.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/InLimit.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_InLimit_HPP
+#define ecflow_node_InLimit_HPP
+
+#include <string>
+
+#include "ecflow/node/LimitFwd.hpp"
+
+namespace cereal {
+class access;
+}
+
+// Inlimit. Multiple inlimits on same Node are logically ANDED
+//    inlimit    limitName     // This will consume one token in the limit <limitName>
+//    inlimit    limitName 10  // This will consume 10 tokens in the limit <limitName>
+//    inlimit -s limitName     // Limit submission, consume one token in the limit <limitName>
+//    inlimit -s limitName 10  // Limit submission, consume consume 10 tokens in the limit <limitName>
+//    inlimit -n limitName     // Only applicable to a Suite/family, does not matter how many tasks
+//                             // the family has, will only consume one token in the family
+//                             // Can control number of active families.
+//
+// Inlimit of the same name specified on a task take priority over the family
+class InLimit {
+public:
+    explicit InLimit(const std::string& limit_name, // referenced limit
+                     const std::string& path_to_node_with_referenced_limit =
+                         std::string(),                 // if empty, search for limit up parent hierarchy
+                     int tokens                = 1,     // tokens to consume in the Limit
+                     bool limit_this_node_only = false, // if true limit this node only
+                     bool limit_submission     = false, // limit submission only
+                     bool check                = true   // disable name checking
+    );
+    InLimit() = default;
+
+    void print(std::string&) const;
+    bool operator==(const InLimit& rhs) const;
+    bool operator<(const InLimit& rhs) const { return n_ < rhs.name(); }
+
+    const std::string& name() const { return n_; } // must be defined
+    const std::string& pathToNode() const {
+        return path_;
+    } // can be empty,the node referenced by the In-Limit, this should hold the Limit.
+    int tokens() const { return tokens_; }
+
+    bool limit_submission() const { return limit_submission_; }
+    bool limit_this_node_only() const { return limit_this_node_only_; }
+    bool incremented() const { return incremented_; } // only used with limit_this_node_only
+    void set_incremented(bool f) { incremented_ = f; }
+
+    std::string toString() const;
+
+private:
+    void write(std::string&) const;
+
+    void limit(limit_ptr l) { limit_ = std::weak_ptr<Limit>(l); }
+    Limit* limit() const { return limit_.lock().get(); } // can return NULL
+    friend class InLimitMgr;
+
+private:
+    std::weak_ptr<Limit> limit_; // NOT persisted since computed on the fly
+    std::string n_;
+    std::string path_;
+    int tokens_{1};
+    bool limit_this_node_only_{
+        false}; // default is false,if True, will consume one token(s) only, regardless of number of children
+    bool limit_submission_{false}; // limit submission only
+    bool incremented_{false};      // state
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_node_InLimit_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/InLimitMgr.cpp 5.13.0-1/libs/node/src/ecflow/node/InLimitMgr.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/InLimitMgr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/InLimitMgr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,520 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/InLimitMgr.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/Node.hpp"
+
+#ifdef DEBUG
+    #include <ostream>
+
+    #include "ecflow/core/Ecf.hpp"
+#endif
+
+using namespace ecf;
+using namespace std;
+
+void InLimitMgr::reset() {
+    for (auto& i : vec_) {
+        i.set_incremented(false);
+    }
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+
+InLimitMgr& InLimitMgr::operator=(const InLimitMgr& rhs) {
+    if (this != &rhs) {
+        vec_  = rhs.vec_;
+        node_ = nullptr;
+    }
+    return *this;
+}
+
+void InLimitMgr::print(std::string& os) const {
+    for (const InLimit& i : vec_) {
+        i.print(os);
+    }
+}
+
+bool InLimitMgr::operator==(const InLimitMgr& rhs) const {
+    if (vec_.size() != rhs.vec_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "InLimitMgr::operator==  vec_.size() != rhs.vec_.size() " << node_->debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (size_t i = 0; i < vec_.size(); ++i) {
+        if (!(vec_[i] == rhs.vec_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "InLimitMgr::operator==  (!(vec_[i] == rhs.vec_[i] )) " << node_->debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+    return true;
+}
+
+void InLimitMgr::addInLimit(const InLimit& l, bool check) {
+    if (check && findInLimitByNameAndPath(l)) {
+        throw std::runtime_error("Add InLimit failed: Duplicate InLimit see node " + node_->debugNodePath());
+    }
+    vec_.push_back(l);
+}
+
+bool InLimitMgr::deleteInlimit(const std::string& name) {
+    // cout << "InLimitMgr::deleteInlimit: " << name << "\n";
+    if (name.empty()) {
+        vec_.clear();
+        return true;
+    }
+
+    string path_to_limit; // This can be empty
+    string limit_name;
+    (void)Extract::pathAndName(name, path_to_limit, limit_name); // already checked for empty name
+    // cout << "   path_to_limit:" << path_to_limit << "\n";
+    // cout << "   limit_name:" <<  limit_name << "\n";
+
+    for (size_t i = 0; i < vec_.size(); i++) {
+        // cout << "   " << i << ": " << vec_[i].pathToNode() << "  :  " << vec_[i].name() << "\n";
+        if (path_to_limit.empty()) {
+            if (vec_[i].name() == limit_name) {
+                vec_.erase(vec_.begin() + i);
+                return true;
+            }
+        }
+        else {
+            if (vec_[i].name() == limit_name && vec_[i].pathToNode() == path_to_limit) {
+                vec_.erase(vec_.begin() + i);
+                return true;
+            }
+        }
+    }
+    throw std::runtime_error("InLimitMgr::deleteInlimit: Cannot find inlimit: " + name);
+}
+
+Limit* InLimitMgr::findLimitViaInLimit(const InLimit& theInLimit) const {
+    // Use in *test* only
+    size_t theSize = vec_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (vec_[i].name() == theInLimit.name() && vec_[i].pathToNode() == theInLimit.pathToNode()) {
+            resolveInLimit(vec_[i]);
+            return vec_[i].limit();
+        }
+    }
+    return nullptr;
+}
+
+bool InLimitMgr::findInLimitByNameAndPath(const InLimit& theInLimit) const {
+    size_t theSize = vec_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (vec_[i].name() == theInLimit.name() && vec_[i].pathToNode() == theInLimit.pathToNode()) {
+            return true;
+        }
+    }
+    return false;
+}
+
+void InLimitMgr::get_memento(compound_memento_ptr& comp) const {
+#ifdef DEBUG_MEMENTO
+    std::cout << "InLimitMgr::get_memento " << node_->debugNodePath() << "\n";
+#endif
+
+    for (const InLimit& l : vec_) {
+        comp->add(std::make_shared<NodeInLimitMemento>(l));
+    }
+}
+
+bool InLimitMgr::inLimit() const {
+    // Check in we are in limit.
+    // ** WE need to do a lookahead. hence we pass down inlimit tokens **
+    // In the case we have multiple inlimits then we are only in limit if _ALL_ are in limit.
+    // This is like a logical AND.
+
+    if (vec_.empty())
+        return true;
+
+    resolveInLimitReferences();
+
+    int inlimitsWithLimits = 0;
+    int inlimitCount       = 0;
+    size_t theSize         = vec_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (vec_[i].limit_this_node_only()) {
+            if (vec_[i].incremented()) {
+                continue; // Effectively, this inlimit no longer constrains any tasks, allowing them to run.
+            }
+        }
+        Limit* limit = vec_[i].limit();
+        if (limit) {
+            inlimitsWithLimits++;
+            if (limit->inLimit(vec_[i].tokens())) {
+                inlimitCount++;
+            }
+        }
+    }
+
+    return (inlimitsWithLimits == inlimitCount);
+}
+
+void InLimitMgr::incrementInLimit(std::set<Limit*>& limitSet, const std::string& task_path) {
+    // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << endl;
+
+    // *NOTE* each limit is incremented if within LIMIT, and that
+    //        has not previously been updated.
+    //  we could have the same in limit at the task and family level.
+    //  in this case the task takes priority.
+    //  suite suite
+    //    family family
+    //       inlimit limitname 12
+    //       task t1
+    //          inlimit limitname 4
+    //    endfamily
+    //  endsuite
+    //
+    // In this case the limit <limitname> is incremented by 4 _only_
+    //
+    // Note: It is illegal for a node to have the same inlimit but with
+    //       different tokens:
+    //
+    //       task t1
+    //          inlimit limitname 4
+    //          inlimit limitname 2    // illegal and trapped by parser
+
+    if (vec_.empty())
+        return;
+
+    resolveInLimitReferences();
+
+    for (InLimit& inlimit : vec_) {
+        Limit* limit = inlimit.limit();
+        if (limit && limitSet.find(limit) == limitSet.end()) {
+            limitSet.insert(limit);
+
+            // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << " LIMIT incremented " << endl;
+            if (inlimit.limit_this_node_only()) {
+                if (!inlimit.incremented()) {
+                    // Can only increment this once, Notice we pass down this node path, i.e since this node is being
+                    // limited
+                    limit->increment(inlimit.tokens(), node_->absNodePath()); // node could suite || family || task
+                    inlimit.set_incremented(true);
+                }
+            }
+            else {
+                limit->increment(inlimit.tokens(), task_path);
+            }
+        }
+    }
+}
+
+void InLimitMgr::decrementInLimit(std::set<Limit*>& limitSet, const std::string& task_path) {
+    // *NOTE* each limit is incremented if within LIMIT, and that has not previously been updated.
+    //  we could have the same in limit at the task and family level.
+    //  in this case the task takes priority.
+    //  suite suite
+    //    family family
+    //       inlimit limitname 12
+    //       task t1
+    //          inlimit limitname 4
+    //    endfamily
+    //  endsuite
+    //
+    // In this case the limit <limitname> is incremented by 4 _only_
+    //
+    // Note: It is illegal for a node to have the same inlimit but with different tokens:
+    //       task t1
+    //          inlimit limitname 4
+    //          inlimit limitname 2    // illegal and trapped by parser
+
+    if (vec_.empty())
+        return;
+
+    resolveInLimitReferences();
+
+    std::vector<task_ptr> task_vec;
+    for (InLimit& inlimit : vec_) {
+        Limit* limit = inlimit.limit();
+        if (limit && limitSet.find(limit) == limitSet.end()) {
+            limitSet.insert(limit);
+            // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << " LIMIT decremented " << endl;
+
+            if (inlimit.limit_this_node_only()) {
+                if (inlimit.incremented()) {
+
+                    // Can only decrement this once, i.e when all child tasks are completed or aborted or queued or
+                    // unknown
+                    bool at_least_one_active = false;
+                    if (task_vec.empty())
+                        node_->get_all_tasks(task_vec); // Get tasks once, inside for loop
+                    for (task_ptr task : task_vec) {
+                        if (task->state() == NState::ACTIVE || task->state() == NState::SUBMITTED) {
+                            at_least_one_active = true;
+                            break;
+                        }
+                    }
+                    if (at_least_one_active)
+                        continue;
+
+                    limit->decrement(inlimit.tokens(), node_->absNodePath());
+                    inlimit.set_incremented(false);
+                }
+            }
+            else {
+                limit->decrement(inlimit.tokens(), task_path);
+            }
+        }
+    }
+}
+
+void InLimitMgr::decrementInLimitForSubmission(std::set<Limit*>& limitSet, const std::string& task_path) {
+    if (vec_.empty())
+        return;
+
+    resolveInLimitReferences();
+
+    for (InLimit& inlimit : vec_) {
+        Limit* limit = inlimit.limit();
+        if (limit && limitSet.find(limit) == limitSet.end()) {
+            limitSet.insert(limit);
+            // cout << "InLimitMgr::incrementInLimit " << node_->absNodePath() << " LIMIT decremented " << endl;
+
+            if (inlimit.limit_submission()) {
+                limit->decrement(inlimit.tokens(), task_path);
+            }
+        }
+    }
+}
+
+// #define DEBUG_WHY 1
+
+static void add_consumed_paths(Limit* limit, std::stringstream& ss) {
+    ss << "(";
+    const std::set<std::string>& consumed_paths = limit->paths();
+    int count                                   = 0;
+    for (const auto& consumed_path : consumed_paths) {
+        if (4 == count) {
+            ss << "...";
+            break;
+        }
+        ss << consumed_path << ",";
+        count++;
+    }
+    ss << ")";
+}
+
+bool InLimitMgr::why(std::vector<std::string>& vec, bool html) const {
+    // Note: if this correspond to a leaf node, like a task. Then it may not be
+    // sufficient to just check in limits at this level  *BUT*
+    // Node::top_down_why() and Node::bottom_up_why() will traverse the hierarchy
+    // so we don't need to replicate it here.
+
+#ifdef DEBUG_WHY
+    std::cout << "InLimitMgr::why " << node_->debugNodePath() << " top_down:" << top_down << "\n";
+#endif
+    bool why_found = false;
+    if (!inLimit()) {
+#ifdef DEBUG_WHY
+        std::cout << "   InLimitMgr::why " << node_->debugNodePath() << " NOT in limit\n";
+#endif
+        for (auto& i : vec_) {
+            Limit* limit = i.limit();
+            if (limit && !limit->inLimit(i.tokens())) {
+                std::stringstream ss;
+                if (i.pathToNode().empty()) {
+                    ss << "limit " << limit->name() << " is full";
+                }
+                else {
+                    if (html) {
+                        std::stringstream s;
+                        s << "[limit]" << i.pathToNode() << Str::COLON() << limit->name();
+                        ss << Node::path_href_attribute(s.str()) << " is full";
+                    }
+                    else
+                        ss << "limit " << i.pathToNode() << Str::COLON() << limit->name() << " is full";
+                }
+
+                // show node paths that have consumed a limit, Only show first 5, Otherwise string may be too long
+                add_consumed_paths(limit, ss);
+
+                vec.push_back(ss.str());
+                why_found = true;
+            }
+        }
+    }
+    return why_found;
+}
+
+void InLimitMgr::check(std::string& errorMsg, std::string& warningMsg, bool reportErrors, bool reportWarnings) const {
+    size_t theSize = vec_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        (void)find_limit(vec_[i], errorMsg, warningMsg, reportErrors, reportWarnings);
+    }
+}
+
+void InLimitMgr::resolveInLimit(InLimit& inLimit,
+                                std::string& errorMsg,
+                                std::string& warningMsg,
+                                bool reportErrors,
+                                bool reportWarnings) const {
+    //		cout << "Inlimit " << inLimit.toString() << "\n";
+
+    /// if limit pointer already setup use them. These are shared ptr backed, Hence if deleted beneath use should return
+    /// 0;
+    if (inLimit.limit()) {
+        //		cout << "InLimitMgr::resolveInLimit " << inLimit.toString() << " Reusing limit ptr \n";
+        return;
+    }
+
+    /// Find the limit referenced by the InLimit. i.e. Link inLimit to its LIMIT
+    /// The return value can be NULL
+    limit_ptr referencedLimit = find_limit(inLimit, errorMsg, warningMsg, reportErrors, reportWarnings);
+    inLimit.limit(referencedLimit);
+}
+
+void InLimitMgr::auto_add_inlimit_externs(Defs* defs) const {
+    std::string errorMsg;
+    std::string warningMsg;
+    size_t theSize = vec_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        limit_ptr referencedLimit = find_limit(vec_[i], errorMsg, warningMsg, false, false);
+        if (!referencedLimit.get()) {
+            if (vec_[i].pathToNode().empty())
+                defs->add_extern(vec_[i].name());
+            else
+                defs->add_extern(vec_[i].pathToNode() + ":" + vec_[i].name());
+        }
+    }
+}
+
+limit_ptr InLimitMgr::find_limit(const InLimit& inLimit,
+                                 std::string& errorMsg,
+                                 std::string& warningMsg,
+                                 bool reportErrors,
+                                 bool reportWarnings) const {
+    if (inLimit.pathToNode().empty()) {
+
+        // cout << "inLimit.pathToNode().empty() search " << debugType() << " " << node_->absNodePath() << "\n";
+        limit_ptr referencedLimit = node_->findLimitUpNodeTree(inLimit.name());
+        if (referencedLimit.get())
+            return referencedLimit;
+
+        if (reportWarnings) {
+
+            // See if the name is defined, as an extern, in which case *DONT* warn:
+            // This is client side specific, since server does not have externs.
+            if (node_->defs()->find_extern(inLimit.name(), Str::EMPTY())) {
+                return referencedLimit; // this is empty/NULL
+            }
+
+            std::stringstream ss;
+            ss << "Warning: ";
+            ss << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString()
+               << ", which cannot be found on the parent nodes\n";
+            warningMsg += ss.str();
+        }
+        return referencedLimit; // this is empty/NULL
+    }
+
+    // *FIND* the node referenced by the In-Limit, this should hold the Limit.
+    // cout << "Inlimit path not empty \n";
+    string warning_message;
+    node_ptr referenceNode = node_->findReferencedNode(inLimit.pathToNode(), inLimit.name(), warning_message);
+    if (!referenceNode.get()) {
+        /// Could not find the node which *HOLDS* the limit
+        if (reportWarnings) {
+
+            // OK a little bit of duplication, since findReferencedNode, will also look for externs
+            // See if the Path:name is defined as an extern, in which case *DONT* warn:
+            // This is client side specific, since server does not have externs.
+            if (node_->defs()->find_extern(inLimit.pathToNode(), inLimit.name())) {
+                return limit_ptr();
+            }
+
+            std::stringstream ss;
+            ss << "Warning: " << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString()
+               << ", which cannot be found\n";
+            warningMsg += ss.str();
+        }
+        return limit_ptr();
+    }
+
+    // *FOUND* the node which should hold the Limit.
+    limit_ptr referencedLimit = referenceNode->find_limit(inLimit.name());
+    if (!referencedLimit.get()) {
+
+        // See if the name is defined, as an extern, in which case *DONT* warn:
+        // This is client side specific, since server does not have externs.
+        if (node_->defs()->find_extern(inLimit.pathToNode(), inLimit.name())) {
+            return limit_ptr();
+        }
+
+        if (reportWarnings) {
+            std::stringstream ss;
+            ss << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString() << " :";
+            ss << "The referenced " << referenceNode->debugType() << " '" << referenceNode->absNodePath()
+               << "' does not define the limit " << inLimit.name() << "\n";
+            warning_message += ss.str();
+            warningMsg += "Warning: ";
+            warningMsg += warning_message;
+            warningMsg += "\n";
+        }
+        return referencedLimit; // this is empty/NULL
+    }
+
+    // *FOUND* the referenced LIMIT. inlimit tokens must be less than limit.
+    // ECFLOW-713 make this a warning and not error, it allows job control over multiple suites, at load/begin time
+    if (inLimit.tokens() > referencedLimit->theLimit()) {
+        if (reportWarnings) {
+            // in limit exceeds the LIMIT value
+            std::stringstream ss;
+            ss << "Warning: ";
+            ss << node_->debugType() << " " << node_->absNodePath() << " has a " << inLimit.toString()
+               << " reference\n";
+            ss << " with value '" << inLimit.tokens() << "' which exceeds '" << referencedLimit->theLimit()
+               << "' defined on the Limit\n";
+            warningMsg += ss.str();
+        }
+    }
+    return referencedLimit;
+}
+
+void InLimitMgr::resolveInLimit(InLimit& inLimit) const {
+    // Used in *test* only
+    std::string errorMsg;
+    std::string warningMsg;
+    resolveInLimit(inLimit, errorMsg, warningMsg, false, false);
+}
+
+void InLimitMgr::resolveInLimitReferences() const {
+    size_t theSize = vec_.size();
+    if (theSize > 0) {
+        std::string warningMsg;
+        std::string errorMsg;
+        for (size_t i = 0; i < theSize; i++) {
+            resolveInLimit(vec_[i], errorMsg, warningMsg, false, false);
+        }
+    }
+}
+
+template <class Archive>
+void InLimitMgr::serialize(Archive& ar) {
+    ar(CEREAL_NVP(vec_));
+}
+CEREAL_TEMPLATE_SPECIALIZE(InLimitMgr);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/InLimitMgr.hpp 5.13.0-1/libs/node/src/ecflow/node/InLimitMgr.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/InLimitMgr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/InLimitMgr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,140 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_InLimitMgr_HPP
+#define ecflow_node_InLimitMgr_HPP
+
+#include <memory>
+#include <set>
+#include <string>
+
+#include "ecflow/node/InLimit.hpp"
+#include "ecflow/node/LimitFwd.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+namespace cereal {
+class access;
+}
+
+// class InLimitMgr:
+// Design notes:
+// Please note: when ever we want access the inlimits, limit ptrs we
+// must resolve(/compute them first). This save on client code which
+// modifies the node tree from having handle it.
+// If this proves to be a bottle next. We could add a caching mechanism
+// base on the Ecf class,so that we need only update the pointers
+// when a structural modification is made.
+//
+class InLimitMgr {
+public:
+    explicit InLimitMgr(Node* n) : node_(n) {}
+    InLimitMgr(const InLimitMgr& rhs) : vec_(rhs.vec_) {}
+    InLimitMgr() = default;
+
+    // needed by node copy constructor
+    void set_node(Node* n) { node_ = n; }
+
+    // Used by begin/re-queue
+    void reset(); // clear incremented flag, for family limited nodes.
+
+    // standard functions: ==============================================
+    InLimitMgr& operator=(const InLimitMgr&);
+    void print(std::string&) const;
+    bool operator==(const InLimitMgr& rhs) const;
+    void clear() { vec_.clear(); }
+
+    // Access functions: ======================================================
+    const std::vector<InLimit>& inlimits() const { return vec_; }
+
+    // Add functions: ===============================================================
+    void addInLimit(const InLimit&, bool check = true); // will throw std::runtime_error if duplicate
+
+    // Delete functions: can throw std::runtime_error ===================================
+    // if name argument is empty, delete all attributes of that type
+    // if delete was successful return true, else return false.
+    // Can throw std::runtime_error if the attribute cannot be found
+    bool deleteInlimit(const std::string& name);
+
+    // mementos functions:
+    void get_memento(compound_memento_ptr& comp) const;
+
+    // Find functions: ============================================================
+    /// *** This will resolve the in limits first ***
+    /// Used in *test* only
+    Limit* findLimitViaInLimit(const InLimit&) const;
+
+    bool findInLimitByNameAndPath(const InLimit&) const; // use name,path,token,
+
+    // Why:
+    bool why(std::vector<std::string>& vec, bool html = false) const; // return true if why found
+
+    // Limit functions:
+
+    /// Are the in limits pointers to the Limits in limit.
+    /// This is a very heavily used function. *******
+    /// *** This will resolve the in limits first ***
+    bool inLimit() const;
+
+    /// After job submission we need to increment the in limit, to indicate that a
+    /// resource is consumed.
+    /// *** This will resolve the in limits first ***
+    void
+    incrementInLimit(std::set<Limit*>& limitSet,  // The set ensure we only update once
+                     const std::string& task_path // The task that was submitted, and hence caused Limit to increment
+    );
+
+    /// After job aborts or completes we need to decrement the in limit, to indicate that
+    /// additional resource is available.
+    /// *** This will resolve the in limits first ***
+    void decrementInLimit(std::set<Limit*>& limitSet,  // The set ensure we only update once
+                          const std::string& task_path // The task that completed or aborted. Gives up the token
+    );
+    void
+    decrementInLimitForSubmission(std::set<Limit*>& limitSet,  // The set ensure we only update once
+                                  const std::string& task_path // The task that completed or aborted. Gives up the token
+    );
+
+    /// Check to see if inlimit's can reference their Limits
+    void check(std::string& errorMsg, std::string& warningMsg, bool reportErrors, bool reportWarnings) const;
+
+    /// Add externs where the inlimit reference to limits cannot be resolved
+    void auto_add_inlimit_externs(Defs*) const;
+
+    /// Needed by python interface
+    std::vector<InLimit>::const_iterator inlimit_begin() const { return vec_.begin(); }
+    std::vector<InLimit>::const_iterator inlimit_end() const { return vec_.end(); }
+
+private:
+    /// Setup in-limits, to point to their limits,
+    void resolveInLimitReferences() const;
+    void resolveInLimit(InLimit&,
+                        std::string& errorMsg,
+                        std::string& warningMsg,
+                        bool reportErrors,
+                        bool reportWarnings) const;
+    void resolveInLimit(InLimit&) const;
+
+    limit_ptr find_limit(const InLimit&,
+                         std::string& errorMsg,
+                         std::string& warningMsg,
+                         bool reportErrors,
+                         bool reportWarnings) const;
+
+private:
+    Node* node_{nullptr}; // Not persisted, constructor will always set this up.
+
+    mutable std::vector<InLimit> vec_;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_node_InLimitMgr_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/JobCreationCtrl.cpp 5.13.0-1/libs/node/src/ecflow/node/JobCreationCtrl.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/JobCreationCtrl.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/JobCreationCtrl.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,26 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/JobCreationCtrl.hpp"
+
+#include <cstdlib> // for getenv()
+#include <iostream>
+#include <stdexcept>
+
+void JobCreationCtrl::generate_temp_dir() {
+    if (!getenv("TMPDIR"))
+        throw std::runtime_error(
+            "JobCreationCtrl::generate_temp_dir(), The environment variable TMPDIR is not defined");
+    tempDirForJobGeneration_ = getenv("TMPDIR");
+    tempDirForJobGeneration_ += "/ecf_check_job_creation";
+    if (fs::exists(tempDirForJobGeneration_))
+        fs::remove_all(tempDirForJobGeneration_);
+    std::cout << "JobCreationCtrl::generate_temp_dir()  " << tempDirForJobGeneration_ << "\n";
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/JobCreationCtrl.hpp 5.13.0-1/libs/node/src/ecflow/node/JobCreationCtrl.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/JobCreationCtrl.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/JobCreationCtrl.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_JobCreationCtrl_HPP
+#define ecflow_node_JobCreationCtrl_HPP
+
+#include <string>
+#include <vector>
+
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+// Used as a utility class for testing Job creation
+// Collates data during the node tree traversal
+// Note: For testing purposes we do not always want to create jobs
+class JobCreationCtrl : public std::enable_shared_from_this<JobCreationCtrl> {
+public:
+    JobCreationCtrl()                       = default;
+    JobCreationCtrl(const JobCreationCtrl&) = delete;
+    ~JobCreationCtrl()                      = default;
+
+    JobCreationCtrl& operator=(const JobCreationCtrl&) = delete;
+
+    void set_node_path(const std::string& absNodePath) { absNodePath_ = absNodePath; }
+    const std::string& node_path() const { return absNodePath_; }
+
+    void generate_temp_dir();
+    void set_dir_for_job_creation(const std::string& tempDirForJobGeneration) {
+        tempDirForJobGeneration_ = tempDirForJobGeneration;
+    }
+    const std::string& dir_for_job_creation() { return tempDirForJobGeneration_; }
+
+    std::string& error_msg() { return errorMsg_; }
+    const std::string& get_error_msg() const { return errorMsg_; }
+
+    void push_back_failing_submittable(submittable_ptr t) { fail_submittables_.push_back(t); }
+    const std::vector<weak_submittable_ptr>& fail_submittables() const { return fail_submittables_; }
+
+    void set_verbose(bool verbose) { verbose_ = verbose; }
+    bool verbose() const { return verbose_; }
+
+    // Used in job creation checking. Holds EcfFile, which has a CACHE of included files.
+    // Use to minimise file opening of included files
+    // Since we hold a only a single JobsParam over ALL job creation testing. See ECFLOW-1210
+    JobsParam& jobsParam() { return jobsParam_; }
+
+private:
+    bool verbose_{false};
+    std::string absNodePath_;
+    std::string tempDirForJobGeneration_;
+    std::string errorMsg_;
+    std::vector<weak_submittable_ptr> fail_submittables_;
+    JobsParam jobsParam_; // create jobs = false, spawn jobs = false used as a cache
+};
+
+#endif /* ecflow_node_JobCreationCtrl_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/JobProfiler.cpp 5.13.0-1/libs/node/src/ecflow/node/JobProfiler.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/JobProfiler.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/JobProfiler.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,73 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/JobProfiler.hpp"
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// Connection and client timeout issues can be replicated  by adding
+//   - sleep(1) in EcfFile , i.e when creating the job output
+//
+
+static size_t task_threshold_ = 4000;
+
+namespace ecf {
+
+int JobProfiler::task_threshold_default() {
+    return 4000;
+}
+
+// =================================================================================
+JobProfiler::JobProfiler(Task* node, JobsParam& jobsParam, size_t threshold)
+    : node_(node),
+      jobsParam_(jobsParam),
+      start_time_(boost::posix_time::microsec_clock::universal_time()),
+      threshold_(threshold) {
+    // If job generation takes longer than the time to *reach* next_poll_time_, then time out.
+    // Hence we start out with 60 seconds, and time for job generation should decrease. Until reset back to 60
+    // Should allow greater child/user command communication.
+    if (!jobsParam_.next_poll_time().is_special() && start_time_ >= jobsParam_.next_poll_time()) {
+        jobsParam_.set_timed_out_of_job_generation(start_time_);
+    }
+}
+
+JobProfiler::~JobProfiler() {
+    if (node_) {
+        boost::posix_time::time_duration duration = boost::posix_time::microsec_clock::universal_time() - start_time_;
+        size_t time_taken                         = duration.total_milliseconds();
+
+        // When testing we set submitJobsInterval to < 0
+        if (jobsParam_.submitJobsInterval() < 0) {
+            time_taken = threshold_ + 1;
+        }
+
+        if (time_taken > threshold_) {
+            std::stringstream ss;
+            ss << "Job generation for task " << node_->absNodePath() << " took " << time_taken
+               << "ms, Exceeds ECF_TASK_THRESHOLD(" << threshold_ << "ms)";
+            log(Log::WAR, ss.str());
+            node_->flag().set(ecf::Flag::THRESHOLD);
+        }
+    }
+}
+
+void JobProfiler::set_task_threshold(size_t threshold) {
+    task_threshold_ = threshold;
+}
+size_t JobProfiler::task_threshold() {
+    return task_threshold_;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/JobProfiler.hpp 5.13.0-1/libs/node/src/ecflow/node/JobProfiler.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/JobProfiler.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/JobProfiler.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_JobProfiler_HPP
+#define ecflow_node_JobProfiler_HPP
+
+///
+/// \brief This class is used to aid profiling of the job generation step.
+///
+/// This will be used to identify those suite/family/tasks that take the most
+/// amount of time, *when* we exceed the jobs generation interval.
+/// In particular if we have output that is many megabytes, it can affect
+/// the performance of the server, especially when the server is running
+/// on virtual machines
+///
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+class JobsParam;
+class Task;
+
+namespace ecf {
+
+class JobProfiler {
+private:
+public:
+    // Note: 1000 milliseconds = 1 second
+    JobProfiler(Task*, JobsParam&, size_t threshold /* expected to be milliseconds */);
+    // Disable copy (and move) semantics
+    JobProfiler(const JobProfiler&)                  = delete;
+    const JobProfiler& operator=(const JobProfiler&) = delete;
+
+    ~JobProfiler();
+
+    static void set_task_threshold(size_t threshold);
+    static size_t task_threshold();
+
+    static int task_threshold_default();
+
+private:
+    Task* node_;
+    JobsParam& jobsParam_;
+    boost::posix_time::ptime start_time_;
+    size_t threshold_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_JobProfiler_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Jobs.cpp 5.13.0-1/libs/node/src/ecflow/node/Jobs.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Jobs.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Jobs.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,120 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Jobs.hpp"
+
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Operations.hpp"
+#include "ecflow/node/Signal.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// #define DEBUG_JOB_SUBMISSION 1
+
+bool Jobs::generate(JobsParam& jobsParam) const {
+#ifdef DEBUG_JOB_SUBMISSION
+    cout << "\n"
+         << "Jobs::generate (" << jobsParam.logDebugMessage() << ") create jobs(" << jobsParam.createJobs() << ")";
+    if (defs_)
+        cout << " server_state(" << SState::to_string(defs_->server().get_state()) << ")\n";
+#endif
+
+    // dependency resolving and job submission must be less than submitJobsInterval seconds
+    // Note: Duration timer makes a system call
+    DurationTimer durationTimer;
+
+#ifdef DEBUG_JOB_SUBMISSION
+    LogToCout toCoutAsWell;
+    LOG(Log::DBG, "-->Job submission start " << jobsParam.logDebugMessage());
+#endif
+    {
+        // Constructor does nothing, destructor will un-block SIGCHLD
+        // This allows the child process termination to be handled by the signal handler in System.
+        // The destructor will then re-block SIGCHLD
+        Signal unblock_on_desctruction_then_reblock;
+
+        // *******************************************************************
+        // **** JOB submission *MUST* be done sequentially, as each task could
+        // **** be affected by a resource/limit, and hence affect subsequent
+        // **** job submission
+        // *******************************************************************
+
+        if (defs_) {
+            if (defs_->server().get_state() == SState::RUNNING) {
+                const std::vector<suite_ptr>& suites = defs_->suiteVec();
+                for (const suite_ptr& suite : suites) {
+                    // SuiteChanged moved into Suite::resolveDependencies.
+                    // This ensures the fast path and when suite are not begun we save a ctor/dtor call
+                    ecf::visit_all(*suite, ActivateAll{});
+                    (void)suite->resolveDependencies(jobsParam);
+                }
+            }
+        }
+        else {
+            if (!node_->isParentSuspended()) {
+                // suite, family, task
+                SuiteChanged1 changed(node_->suite());
+                (void)node_->resolveDependencies(jobsParam);
+            }
+        }
+
+        // *****************************************************************
+        // Should end up calling signal handler here for any pending SIGCHLD
+        // *****************************************************************
+    }
+
+    // Process children that have terminated
+    System::instance()->processTerminatedChildren();
+
+#ifdef DEBUG_JOB_SUBMISSION
+    LOG(Log::DBG,
+        "-->Job submission finish interval = " << jobsParam.submitJobsInterval() << " time taken = "
+                                               << durationTimer.duration() << " Tasks/Aliases submitted "
+                                               << jobsParam.submitted().size() << " " << jobsParam.getErrorMsg());
+#endif
+
+    if (durationTimer.duration() > jobsParam.submitJobsInterval()) {
+        LOG(Log::ERR,
+            "Jobs::generate: job generation time(" << durationTimer.duration()
+                                                   << " seconds) is greater than job submission interval of "
+                                                   << jobsParam.submitJobsInterval() << " seconds!!");
+    }
+    return jobsParam.getErrorMsg().empty();
+}
+
+bool Jobs::generate() const {
+    Defs* defs = nullptr;
+    if (defs_) {
+        defs = defs_;
+        LOG_ASSERT(defs != nullptr, "defs_ == NULL");
+    }
+    else {
+        defs = node_->defs();
+        LOG_ASSERT(defs != nullptr, "node_->defs() == NULL");
+    }
+
+    if (defs && defs->server().get_state() == SState::RUNNING) {
+        LOG_ASSERT(defs->server().jobSubmissionInterval() != 0, "");
+        JobsParam jobsParam(defs->server().jobSubmissionInterval(), defs->server().jobGeneration());
+#ifdef DEBUG_JOB_SUBMISSION
+        jobsParam.logDebugMessage(" from Jobs::generate()/Server");
+#endif
+
+        return generate(jobsParam);
+    }
+    return false;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Jobs.hpp 5.13.0-1/libs/node/src/ecflow/node/Jobs.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Jobs.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Jobs.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,82 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Jobs_HPP
+#define ecflow_node_Jobs_HPP
+
+#include "ecflow/node/NodeFwd.hpp"
+
+///
+/// Job generation implies the following activities:
+///
+/// 1/ Resolve dependencies.
+/// This implies inspecting day, date, time and triggers; and determine if
+/// each node is free or still holding.
+/// For task nodes that are free of its dependencies, a job can be created.
+/// Note: Job generation is not performed for Nodes that are suspended.
+///       In this case, time dependencies are still checked, and marked as
+///       free, accordingly. When the Nodes are later resumed, dependencies
+///       are (re)checked and job scripts are eventually created.
+///
+/// 2/ Create jobs scripts.
+/// Perform pre-processing of .ecf files including variable substitution.
+///
+/// 3/ Change state of task to submitted.
+///
+/// 4/ Increment the inlimit references (for successful job submissions).
+///
+/// 5/ Update limits according to Error/Complete
+///
+/// 6/ Set up signal handlers to monitor child jobs.
+/// This ensures that on failure the Task state is changed to ABORTED and
+/// related limit references are updated accordingly.
+///
+/// Important: Job submissions *MUST* be done sequentially, as each job
+/// submission can potentially consume a resource (e.g. a limit), which can
+/// affect the ability to perform subsequent job submissions.
+///
+/// The process of resolving dependencies (and submitting all the tasks), must
+/// take less than 60 seconds, as this is resolution of the clock.
+/// For testing purposes, this can be changed and we might not always want
+/// to actually create jobs.
+///
+/// @returns true, if job submission succeeds; false, otherwise (with error message in JobsParam)
+///
+/// The job files are shell scripts, which have IPC (child commands) which talk to
+/// to the server. Since the scripts are user created, they can include, errors:
+///   o multiple call to complete
+///     To guard against this, we should *not* clear/reset password in the complete.
+///     Otherwise, we will registered as a zombie.
+///   o Failure to call complete (maybe due to early exit in the job file).
+///     There is not much we can do here, the job will stay active.
+///   o Path do not match, since the node tree, in the server has been deleted
+///     Typically the job will hold on the child commands.
+///
+/// Note: in real life test 99% of job generation is done after child command.
+///
+
+class Jobs {
+public:
+    explicit Jobs(const defs_ptr& d) : defs_(d.get()) {}
+    explicit Jobs(Defs* d) : defs_(d) {}
+    explicit Jobs(Node* d) : node_(d) {}
+    // Disable copy (and move) semantics
+    Jobs(const Jobs&)                  = delete;
+    const Jobs& operator=(const Jobs&) = delete;
+
+    bool generate(JobsParam&) const;
+    bool generate() const;
+
+private:
+    Defs* defs_{nullptr};
+    Node* node_{nullptr};
+};
+
+#endif /* ecflow_node_Jobs_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/JobsParam.cpp 5.13.0-1/libs/node/src/ecflow/node/JobsParam.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/JobsParam.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/JobsParam.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/JobsParam.hpp"
+
+bool JobsParam::check_for_job_generation_timeout() {
+    if (timed_out_of_job_generation_)
+        return true;
+    return check_for_job_generation_timeout(boost::posix_time::microsec_clock::universal_time());
+}
+
+bool JobsParam::check_for_job_generation_timeout(const boost::posix_time::ptime& start_time) {
+    if (timed_out_of_job_generation_) {
+        return true;
+    }
+    if (!next_poll_time_.is_special() && start_time >= next_poll_time_) {
+        set_timed_out_of_job_generation(start_time);
+        return true;
+    }
+    return false;
+}
+
+void JobsParam::clear() {
+    errorMsg_.clear();
+    debugMsg_.clear();
+    submitted_.clear();
+    user_edit_file_.clear();
+    user_edit_variables_.clear();
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/JobsParam.hpp 5.13.0-1/libs/node/src/ecflow/node/JobsParam.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/JobsParam.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/JobsParam.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,102 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_JobsParam_HPP
+#define ecflow_node_JobsParam_HPP
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/node/EcfFile.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+// Used as a utility class for controlling job creation.
+// Collates data during the node tree traversal
+// Note: For testing purposes we do not always want to create jobs or spawn jobs
+class JobsParam {
+public:
+    // This constructor is used in test
+    explicit JobsParam(bool createJobs = false) : createJobs_(createJobs) {}
+
+    JobsParam(int submitJobsInterval, bool createJobs, bool spawn_jobs = true)
+        : createJobs_(createJobs),
+          spawnJobs_(spawn_jobs),
+          submitJobsInterval_(submitJobsInterval) {
+        if (!createJobs_)
+            spawnJobs_ = false;
+    }
+
+    // Disable copy (and move) semantics
+    JobsParam(const JobsParam&)                  = delete;
+    const JobsParam& operator=(const JobsParam&) = delete;
+
+    // Allow JobsParam to be re-used. Preserve cache in EcfFile. ECFLOW-1210
+    void clear();
+
+    std::string& errorMsg() { return errorMsg_; }
+    const std::string& getErrorMsg() const { return errorMsg_; }
+
+    void push_back_submittable(Submittable* t) { submitted_.push_back(t); }
+    const std::vector<Submittable*>& submitted() const { return submitted_; }
+
+    bool createJobs() const { return createJobs_; }
+    bool spawnJobs() const { return spawnJobs_; }
+
+    /// returns the number of seconds at which we should check time dependencies
+    /// this includes evaluating trigger dependencies and submit the corresponding jobs.
+    /// This is set at 60 seconds. But will vary for debug purposes only.
+    int submitJobsInterval() const { return submitJobsInterval_; }
+
+    /// Allow user to set the debug message that appears in log file when job submission starts
+    void logDebugMessage(const std::string& s) { debugMsg_ = s; }
+    const std::string& logDebugMessage() const { return debugMsg_; }
+
+    void set_user_edit_variables(const NameValueMap& v) { user_edit_variables_ = v; }
+    const NameValueMap& user_edit_variables() const { return user_edit_variables_; }
+
+    void set_user_edit_file(const std::vector<std::string>& file) { user_edit_file_ = file; }
+    const std::vector<std::string>& user_edit_file() const { return user_edit_file_; }
+
+    // Functions to aid timing of job generation
+    void set_next_poll_time(const boost::posix_time::ptime& next_poll_time) { next_poll_time_ = next_poll_time; }
+    const boost::posix_time::ptime& next_poll_time() const { return next_poll_time_; }
+    const boost::posix_time::ptime& time_out_time() const { return time_out_time_; }
+
+    // If job generation takes longer than the time to *reach* next_poll_time_, then time out.
+    // Hence we start out with 60 seconds, and time for job generation should decrease. Until reset back to 60
+    // Should allow greater child/user command communication.
+    void set_timed_out_of_job_generation(const boost::posix_time::ptime& t) {
+        time_out_time_               = t;
+        timed_out_of_job_generation_ = true;
+    }
+    bool timed_out_of_job_generation() const { return timed_out_of_job_generation_; }
+
+    // ensure that we avoid job generation close the server poll time.
+    bool check_for_job_generation_timeout();
+    bool check_for_job_generation_timeout(const boost::posix_time::ptime& time_now);
+
+    void set_ecf_file(const EcfFile& ecf_file) { ecf_file_ = ecf_file; }
+    EcfFile& ecf_file() { return ecf_file_; }
+
+private:
+    bool timed_out_of_job_generation_{false};
+    bool createJobs_;
+    bool spawnJobs_{false};
+    int submitJobsInterval_{60};
+    std::string errorMsg_;
+    std::string debugMsg_;
+    std::vector<Submittable*> submitted_;
+    std::vector<std::string> user_edit_file_;
+    NameValueMap user_edit_variables_;        // Used for User edit
+    boost::posix_time::ptime next_poll_time_; // Aid early exit from job generation, if it takes to long
+    boost::posix_time::ptime time_out_time_;  // When we actually timed out must >= next_poll_time_
+    EcfFile ecf_file_;                        // keep for lifetime, to optimise memory and cache include file
+};
+
+#endif /* ecflow_node_JobsParam_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Limit.cpp 5.13.0-1/libs/node/src/ecflow/node/Limit.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Limit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Limit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,221 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Limit.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+/////////////////////////////////////////////////////////////////////////////////////////////
+
+Limit::Limit(const std::string& name, int limit) : n_(name), lim_(limit) {
+    if (!Str::valid_name(name)) {
+        throw std::runtime_error("Limit::Limit: Invalid Limit name: " + name);
+    }
+}
+
+Limit::Limit(const std::string& name, int limit, int value, const std::set<std::string>& paths, bool check)
+    : n_(name),
+      lim_(limit),
+      value_(value),
+      paths_(paths) {
+    if (check && !Str::valid_name(name)) {
+        throw std::runtime_error("Limit::Limit: Invalid Limit name: " + name);
+    }
+}
+
+Limit::Limit(const Limit& rhs) : n_(rhs.n_), lim_(rhs.lim_), value_(rhs.value_), paths_(rhs.paths_) {
+}
+
+bool Limit::operator==(const Limit& rhs) const {
+    if (value_ != rhs.value_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Limit::operator==value_(" << value_ << ") != rhs.value_(" << rhs.value_ << ") " << toString()
+                      << "   rhs(" << rhs.toString() << ")\n";
+        }
+#endif
+        return false;
+    }
+    if (lim_ != rhs.lim_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Limit::operator==( lim_ != rhs.lim_) " << toString() << "   rhs(" << rhs.toString() << ")\n";
+        }
+#endif
+        return false;
+    }
+    if (n_ != rhs.n_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Limit::operator==( n_ != rhs.n_ ) " << toString() << "   rhs(" << rhs.toString() << ")\n";
+        }
+#endif
+        return false;
+    }
+    if (paths_ != rhs.paths_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Limit::operator==( paths_ != rhs.paths_ ) " << toString() << "   rhs(" << rhs.toString()
+                      << ")\n";
+        }
+#endif
+        return false;
+    }
+    return true;
+}
+
+void Limit::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    write(os);
+    if (!PrintStyle::defsStyle()) {
+        if (value_ != 0) {
+            os += " # ";
+            os += ecf::convert_to<std::string>(value_);
+            for (const auto& path : paths_) {
+                os += " ";
+                os += path;
+            }
+        }
+    }
+    os += "\n";
+}
+
+std::string Limit::toString() const {
+    std::string ret;
+    write(ret);
+    return ret;
+}
+
+void Limit::write(std::string& ret) const {
+    ret += "limit ";
+    ret += n_;
+    ret += " ";
+    ret += ecf::convert_to<std::string>(lim_);
+}
+
+void Limit::decrement(int tokens, const std::string& abs_node_path) {
+
+    // cout << "Limit::decrement name = " << n_ << " current value_ = " << value_ << " limit = " <<  lim_ << " consume
+    // tokens = " << tokens << " path = " << abs_node_path << "\n"; Note: we previously had 'if (value_ > 0) {
+    //       However if the user had manually changed the value_, then we could be left with paths_,  that would never
+    //       have been cleared
+    if (delete_path(abs_node_path)) {
+        // delete_path() will increment state_change_no
+        value_ -= tokens;
+        if (value_ < 0) {
+            value_ = 0;
+            paths_.clear();
+        }
+    }
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Limit::decrement\n";
+#endif
+    // cout << "Limit::decrement name = " << n_ << " current value_ = " << value_ << "\n";
+}
+
+void Limit::increment(int tokens, const std::string& abs_node_path) {
+    // cout << "Limit::increment name = " << n_ << " current value_ = " << value_ << " limit = " <<  lim_ << " consume
+    // tokens = " << tokens << " path = " << abs_node_path << "\n";
+
+    // increment should keep increasing limit value, *EVEN* if over the limit. See ECFLOW-324
+    // Note: previously we had:
+    //     if ( value_ < lim_ ) {
+
+    auto result = paths_.insert(abs_node_path);
+    if (result.second) {
+        value_ += tokens;
+        update_change_no();
+    }
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Limit::increment\n";
+#endif
+    // cout << "Limit::increment name = " << n_ << " current value_ = " << value_ << "\n";
+}
+
+void Limit::setValue(int v) {
+    value_ = v;
+    if (value_ == 0)
+        paths_.clear();
+    update_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "   Limit::setValue() value_ = " << value_ << "\n";
+#endif
+}
+
+void Limit::setLimit(int v) {
+    lim_ = v;
+    update_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "   Limit::setLimit() lim_ = " << value_ << "\n";
+#endif
+}
+
+void Limit::set_paths(const std::set<std::string>& paths) {
+    paths_ = paths;
+    update_change_no();
+}
+
+void Limit::set_state(int limit, int value, const std::set<std::string>& paths) {
+    value_ = value;
+    lim_   = limit;
+    paths_ = paths;
+    update_change_no();
+}
+
+bool Limit::delete_path(const std::string& abs_node_path) {
+    auto i = paths_.find(abs_node_path);
+    if (i != paths_.end()) {
+        paths_.erase(i);
+        update_change_no();
+        return true;
+    }
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Limit::delete_path() \n";
+#endif
+    return false;
+}
+
+void Limit::reset() {
+    paths_.clear();
+    setValue(0); // will increment state_change_no_
+}
+
+void Limit::update_change_no() {
+    state_change_no_ = Ecf::incr_state_change_no();
+    if (node_) {
+        Suite* suite = node_->suite();
+        if (suite)
+            suite->set_state_change_no(state_change_no_);
+    }
+}
+
+template <class Archive>
+void Limit::serialize(Archive& ar) {
+    ar(CEREAL_NVP(n_), CEREAL_NVP(lim_));
+    CEREAL_OPTIONAL_NVP(ar, value_, [this]() { return value_ != 0; });     // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, paths_, [this]() { return !paths_.empty(); }); // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE(Limit);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Limit.hpp 5.13.0-1/libs/node/src/ecflow/node/Limit.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Limit.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Limit.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,92 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Limit_HPP
+#define ecflow_node_Limit_HPP
+
+///
+/// \note Limit was placed in the ANode category because inlimit can reference
+/// Limit on *ANOTHER* suite. This presents a problem with incremental sync,
+/// since that requires access to a parent/suite, to mark the suite as changed.
+///
+/// To get round this issue the Node will set the parent pointer on the Limit
+/// this then makes it easy for incremental sync, since we directly access the
+/// parent suite
+///
+
+#include <set>
+#include <string>
+
+namespace cereal {
+class access;
+}
+class Node;
+
+// Class Limit: The limit is zero based, hence if limit is 10, increment must use < 10
+class Limit {
+public:
+    Limit(const std::string& name, int limit);
+    Limit(const std::string& name, int limit, int value, const std::set<std::string>& paths, bool check = true);
+    Limit() = default;
+    Limit(const Limit& rhs);
+
+    void print(std::string&) const;
+    bool operator==(const Limit& rhs) const;
+    bool operator<(const Limit& rhs) const { return n_ < rhs.name(); }
+    const std::string& name() const { return n_; }
+
+    Node* node() const { return node_; }
+    void set_node(Node* n) { node_ = n; }
+
+    void setValue(int v);
+    void setLimit(int v);
+    void set_state(int limit, int value, const std::set<std::string>& p); // for use by memento
+    void set_paths(const std::set<std::string>& p);
+
+    bool delete_path(const std::string& abs_node_path); // for use by AlterCmd
+    const std::set<std::string>& paths() const { return paths_; }
+
+    int value() const { return value_; }
+    bool inLimit(int inlimit_tokens) const { return ((value_ + inlimit_tokens) <= lim_); }
+    int theLimit() const { return lim_; }
+    void increment(int tokens, const std::string& abs_node_path);
+    void decrement(int tokens, const std::string& abs_node_path);
+    void reset();
+
+    // The state_change_no is never reset. Must be incremented if it can affect equality
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    // for python interface
+    std::string toString() const;
+
+    // ECFLOW-518, we can't use:
+    //    std::set<std::string>::const_iterator paths_begin() const { return paths_.begin();}
+    //    std::set<std::string>::const_iterator paths_end() const { return paths_.end();}
+    // because boost python does not support std::set<std::string> out of the box
+    // we will wrap and return list instead. See ExportNodeAttr.cpp
+
+private:
+    void update_change_no();
+    void write(std::string&) const;
+
+private:
+    std::string n_;
+    Node* node_{nullptr};             // The parent NOT persisted
+    unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+    int lim_{0};
+    int value_{0};
+    std::set<std::string> paths_; // Updated via increment()/decrement()/reset(). Typically task paths
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar);
+};
+
+#endif /* ecflow_node_Limit_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/LimitFwd.hpp 5.13.0-1/libs/node/src/ecflow/node/LimitFwd.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/LimitFwd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/LimitFwd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_LimitFwd_HPP
+#define ecflow_node_LimitFwd_HPP
+
+#include <memory>
+
+class Limit;
+typedef std::shared_ptr<Limit> limit_ptr;
+
+#endif /* ecflow_node_LimitFwd_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Memento.cpp 5.13.0-1/libs/node/src/ecflow/node/Memento.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Memento.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Memento.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,415 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Memento.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/cereal_boost_time.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// #define DEBUG_MEMENTO 1
+
+// ===============================================================
+Memento::~Memento() = default;
+
+// ===============================================================
+void CompoundMemento::incremental_sync(defs_ptr client_def) const {
+    /// Clear out aspects, for this Memento.
+    ///   Aspects are added via do_incremental_* / set_mememto functions
+    ///   AND in *this* function when node attributes have been added or deleted.
+    aspects_.clear();
+
+    node_ptr node = client_def->findAbsNode(absNodePath_);
+    if (!node.get()) {
+        if (absNodePath_ != Str::ROOT_PATH()) {
+
+            // add more context, about what's suites are in the client defs.
+            std::string error_msg = "CompoundMemento::incremental_sync: could not find path ";
+            error_msg += absNodePath_;
+            error_msg += "\nClient has the following suites: ";
+            for (const auto& suite : client_def->suiteVec()) {
+                error_msg += suite->name();
+                error_msg += ",";
+            }
+            throw std::runtime_error(error_msg);
+        }
+
+#ifdef DEBUG_MEMENTO
+        cout << "CompoundMemento::incremental_sync: ROOT_PATH\n";
+#endif
+        //
+        // Notify observers what aspect is going to change, before make-ing data model changes
+        //
+        for (memento_ptr m : vec_) {
+            m->do_incremental_defs_sync(
+                client_def.get(), aspects_, true /* collect aspects only, don't make any changes*/);
+        }
+        size_t aspect_size = aspects_.size();
+        client_def->notify_start(aspects_);
+
+        /// make data model change.
+        /// Notify any interested parties incremental changes
+        /// Aspects records the kind of changes.
+        for (memento_ptr m : vec_) {
+#ifdef DEBUG_MEMENTO
+            cout << "   " << typeid(*(m.get())).name() << "\n";
+#endif
+            m->do_incremental_defs_sync(client_def.get(), aspects_, false /*Data model changes only*/);
+        }
+        if (aspect_size != aspects_.size()) {
+            assert(aspect_size == aspects_.size()); // aspect size should not change, when making data model changes
+        }
+        client_def->notify(aspects_);
+    }
+    else {
+
+#ifdef DEBUG_MEMENTO
+        cout << "CompoundMemento::incremental_sync: " << node->debugNodePath() << "\n";
+#endif
+        // Notify observers what aspect, is going to change.
+        Task* task     = node->isTask();
+        Alias* alias   = node->isAlias();
+        Suite* suite   = node->isSuite();
+        Family* family = node->isFamily();
+
+        if (clear_attributes_)
+            aspects_.push_back(ecf::Aspect::ADD_REMOVE_ATTR);
+
+        for (memento_ptr m : vec_) {
+#ifdef DEBUG_MEMENTO
+            cout << "   " << typeid(*(m.get())).name() << "\n";
+#endif
+            if (task)
+                m->do_incremental_task_sync(task, aspects_, true /* collect aspects only, don't make any changes*/);
+            else if (alias)
+                m->do_incremental_alias_sync(alias, aspects_, true /* collect aspects only, don't make any changes*/);
+            else if (suite)
+                m->do_incremental_suite_sync(suite, aspects_, true /* collect aspects only, don't make any changes*/);
+            else if (family)
+                m->do_incremental_family_sync(family, aspects_, true /* collect aspects only, don't make any changes*/);
+            m->do_incremental_node_sync(node.get(), aspects_, true /* collect aspects only, don't make any changes*/);
+        }
+        size_t aspect_size = aspects_.size();
+        node->notify_start(aspects_);
+
+        //
+        // data model changes only, aspects should not change
+        //
+        if (clear_attributes_)
+            node->clear();
+
+        for (memento_ptr m : vec_) {
+            if (task)
+                m->do_incremental_task_sync(task, aspects_, false /*Data model changes only*/);
+            else if (alias)
+                m->do_incremental_alias_sync(alias, aspects_, false /*Data model changes only*/);
+            else if (suite)
+                m->do_incremental_suite_sync(suite, aspects_, false /*Data model changes only*/);
+            else if (family)
+                m->do_incremental_family_sync(family, aspects_, false /*Data model changes only*/);
+            m->do_incremental_node_sync(node.get(), aspects_, false /*Data model changes only*/);
+        }
+        if (aspect_size != aspects_.size()) {
+            assert(aspect_size == aspects_.size()); // aspect size should not change, when making data model changes
+        }
+
+        /// Notify any interested parties that Node has made incremental changes
+        /// Aspects records the kind of changes.
+        node->notify(aspects_);
+    }
+}
+
+// ===================================================================================================
+
+template <class Archive>
+void Memento::serialize(Archive& ar, std::uint32_t const version) {
+}
+
+template <class Archive>
+void CompoundMemento::serialize(Archive& ar, std::uint32_t const version) {
+    CEREAL_OPTIONAL_NVP(ar, clear_attributes_, [this]() { return clear_attributes_; }); // conditionally save
+    ar(CEREAL_NVP(absNodePath_), CEREAL_NVP(vec_));
+}
+
+template <class Archive>
+void StateMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
+}
+
+template <class Archive>
+void NodeStateMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
+}
+
+template <class Archive>
+void OrderMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(order_));
+}
+
+template <class Archive>
+void ChildrenMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(children_));
+}
+
+template <class Archive>
+void AliasChildrenMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(children_));
+}
+
+template <class Archive>
+void AliasNumberMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(alias_no_));
+}
+
+template <class Archive>
+void SuspendedMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(suspended_));
+}
+
+template <class Archive>
+void ServerStateMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
+}
+
+template <class Archive>
+void ServerVariableMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(serverEnv_));
+}
+
+template <class Archive>
+void NodeDefStatusDeltaMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(state_));
+}
+
+template <class Archive>
+void NodeEventMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(event_));
+}
+
+template <class Archive>
+void NodeMeterMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(meter_));
+}
+
+template <class Archive>
+void NodeLabelMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(label_));
+}
+
+template <class Archive>
+void NodeAvisoMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(aviso_));
+}
+
+template <class Archive>
+void NodeMirrorMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(mirror_));
+}
+
+template <class Archive>
+void NodeQueueMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(queue_));
+}
+
+template <class Archive>
+void NodeGenericMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(generic_));
+}
+
+template <class Archive>
+void NodeQueueIndexMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(index_), CEREAL_NVP(name_), CEREAL_NVP(state_vec_));
+}
+
+template <class Archive>
+void NodeTriggerMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(exp_));
+}
+
+template <class Archive>
+void NodeCompleteMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(exp_));
+}
+
+template <class Archive>
+void NodeRepeatMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(repeat_));
+}
+
+template <class Archive>
+void NodeRepeatIndexMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(index_or_value_));
+}
+
+template <class Archive>
+void NodeLimitMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(limit_));
+}
+
+template <class Archive>
+void NodeInLimitMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(inlimit_));
+}
+
+template <class Archive>
+void NodeVariableMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(var_));
+}
+
+template <class Archive>
+void NodeLateMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(late_));
+}
+
+template <class Archive>
+void FlagMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(flag_));
+}
+
+template <class Archive>
+void NodeTodayMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
+}
+
+template <class Archive>
+void NodeTimeMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
+}
+
+template <class Archive>
+void NodeDayMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
+}
+
+template <class Archive>
+void NodeCronMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
+}
+
+template <class Archive>
+void NodeDateMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
+}
+
+template <class Archive>
+void NodeZombieMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(attr_));
+}
+
+template <class Archive>
+void NodeVerifyMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(verifys_));
+}
+
+template <class Archive>
+void SubmittableMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(paswd_), CEREAL_NVP(rid_), CEREAL_NVP(abr_), CEREAL_NVP(tryNo_));
+}
+
+template <class Archive>
+void SuiteClockMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(clockAttr_));
+}
+
+template <class Archive>
+void SuiteBeginDeltaMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(begun_));
+}
+
+template <class Archive>
+void SuiteCalendarMemento::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Memento>(this), CEREAL_NVP(cal_));
+}
+
+CEREAL_TEMPLATE_SPECIALIZE_V(Memento);
+CEREAL_TEMPLATE_SPECIALIZE_V(CompoundMemento);
+
+CEREAL_TEMPLATE_SPECIALIZE_V(StateMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeStateMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeDefStatusDeltaMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(SuspendedMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(ServerStateMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(ServerVariableMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeEventMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeMeterMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeLabelMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeAvisoMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeMirrorMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeQueueMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeGenericMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeQueueIndexMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeTriggerMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeCompleteMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeRepeatMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeRepeatIndexMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeLimitMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeInLimitMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeVariableMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeLateMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeTodayMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeTimeMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeDayMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeCronMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeDateMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeZombieMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeVerifyMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(FlagMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(SubmittableMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(SuiteClockMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(SuiteBeginDeltaMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(SuiteCalendarMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(OrderMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(ChildrenMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(AliasChildrenMemento);
+CEREAL_TEMPLATE_SPECIALIZE_V(AliasNumberMemento);
+
+CEREAL_REGISTER_TYPE(StateMemento)
+CEREAL_REGISTER_TYPE(NodeStateMemento)
+CEREAL_REGISTER_TYPE(NodeDefStatusDeltaMemento)
+CEREAL_REGISTER_TYPE(SuspendedMemento)
+CEREAL_REGISTER_TYPE(ServerStateMemento)
+CEREAL_REGISTER_TYPE(ServerVariableMemento)
+CEREAL_REGISTER_TYPE(NodeEventMemento)
+CEREAL_REGISTER_TYPE(NodeMeterMemento)
+CEREAL_REGISTER_TYPE(NodeLabelMemento)
+CEREAL_REGISTER_TYPE(NodeAvisoMemento)
+CEREAL_REGISTER_TYPE(NodeMirrorMemento)
+CEREAL_REGISTER_TYPE(NodeQueueMemento)
+CEREAL_REGISTER_TYPE(NodeGenericMemento)
+CEREAL_REGISTER_TYPE(NodeQueueIndexMemento)
+CEREAL_REGISTER_TYPE(NodeTriggerMemento)
+CEREAL_REGISTER_TYPE(NodeCompleteMemento)
+CEREAL_REGISTER_TYPE(NodeRepeatMemento)
+CEREAL_REGISTER_TYPE(NodeRepeatIndexMemento)
+CEREAL_REGISTER_TYPE(NodeLimitMemento)
+CEREAL_REGISTER_TYPE(NodeInLimitMemento)
+CEREAL_REGISTER_TYPE(NodeVariableMemento)
+CEREAL_REGISTER_TYPE(NodeLateMemento)
+CEREAL_REGISTER_TYPE(NodeTodayMemento)
+CEREAL_REGISTER_TYPE(NodeTimeMemento)
+CEREAL_REGISTER_TYPE(NodeDayMemento)
+CEREAL_REGISTER_TYPE(NodeCronMemento)
+CEREAL_REGISTER_TYPE(NodeDateMemento)
+CEREAL_REGISTER_TYPE(NodeZombieMemento)
+CEREAL_REGISTER_TYPE(NodeVerifyMemento)
+CEREAL_REGISTER_TYPE(FlagMemento)
+CEREAL_REGISTER_TYPE(SubmittableMemento)
+CEREAL_REGISTER_TYPE(SuiteClockMemento)
+CEREAL_REGISTER_TYPE(SuiteBeginDeltaMemento)
+CEREAL_REGISTER_TYPE(SuiteCalendarMemento)
+CEREAL_REGISTER_TYPE(OrderMemento)
+CEREAL_REGISTER_TYPE(ChildrenMemento)
+CEREAL_REGISTER_TYPE(AliasChildrenMemento)
+CEREAL_REGISTER_TYPE(AliasNumberMemento)
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Memento.hpp 5.13.0-1/libs/node/src/ecflow/node/Memento.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Memento.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Memento.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,832 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Memento_HPP
+#define ecflow_node_Memento_HPP
+
+///
+/// \note Classes derived from Memento are stored on DefsDelta.
+/// DefsDelta is transferred from Server to Client during a sync. See SSyncCmd.hpp
+///
+/// Are created in the server, but used by the client to sync.
+///
+/// Used to capture incremental change of state, to node, and node attributes
+/// Serve as a base class of all memento's
+/// Later on the client side, the changes can be applied. via incremental_sync()
+/// The are several kind of changes that we can capture:
+///   a/ simple state changes,
+///   b/ Change in attribute structure
+///   c/ Deletion of attribute
+///   d/ Addition of an attribute
+///   e/ Add/delete of a Family/task
+///   f/ Add/Delete of suite
+///
+/// The main emphasis here is to capture a,b,c,d,e. This is easily handled by state_change_no.
+/// option f/ is handled via a full update and hence does not use mementos
+///
+/// ISSUES: AIX has issues with TOC(table of contents) overflow. This is heavily
+/// influenced by the number of global symbols. Unfortunately each boost serializable
+/// type, greatly increases the number of globals.
+/// Hence, we need to ensure we use the minimum number of serializable types.
+///
+
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+// #define DEBUG_MEMENTO 1
+
+class Memento {
+public:
+    Memento()               = default;
+    Memento(const Memento&) = delete;
+    virtual ~Memento();
+
+    Memento& operator=(const Memento&) = delete;
+
+private:
+    /// Applies the mementos to the client side defs. Can raise std::runtime_error
+    virtual void do_incremental_node_sync(Node*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
+    virtual void do_incremental_task_sync(Task*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
+    virtual void do_incremental_alias_sync(Alias*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
+    virtual void do_incremental_suite_sync(Suite*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
+    virtual void do_incremental_family_sync(Family*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
+    virtual void do_incremental_defs_sync(Defs*, std::vector<ecf::Aspect::Type>& aspects, bool) const {}
+    friend class CompoundMemento;
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+// Used for storing all the memento's associated with a single node
+// This allows to make only *ONE* call to find the node.
+// The mementos are then applied to this single node.
+class CompoundMemento {
+public:
+    explicit CompoundMemento(const std::string& absNodePath) : absNodePath_(absNodePath) {}
+
+    CompoundMemento() = default; // for serialization
+
+    void incremental_sync(defs_ptr client_def) const;
+    void add(memento_ptr m) { vec_.push_back(m); }
+    void clear_attributes() { clear_attributes_ = true; }
+
+    const std::string& abs_node_path() const { return absNodePath_; }
+
+private:
+    std::string absNodePath_;
+    std::vector<memento_ptr> vec_;
+    mutable std::vector<ecf::Aspect::Type> aspects_; // not persisted only used on client side
+    bool clear_attributes_{false};
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class StateMemento : public Memento {
+public:
+    explicit StateMemento(NState::State state) : state_(state) {}
+    StateMemento() = default;
+
+private:
+    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        defs->set_memento(this, aspects, f);
+    }
+
+    NState::State state_{NState::UNKNOWN};
+    friend class Defs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeStateMemento : public Memento {
+public:
+    explicit NodeStateMemento(std::pair<NState::State, boost::posix_time::time_duration> state) : state_(state) {}
+    NodeStateMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    std::pair<NState::State, boost::posix_time::time_duration> state_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class OrderMemento : public Memento {
+public:
+    explicit OrderMemento(const std::vector<std::string>& order) : order_(order) {}
+    OrderMemento() = default;
+
+private:
+    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        defs->set_memento(this, aspects, f);
+    }
+    void do_incremental_suite_sync(Suite* s, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        s->set_memento(this, aspects, f);
+    }
+    void do_incremental_family_sync(Family* f, std::vector<ecf::Aspect::Type>& aspects, bool ff) const override {
+        f->set_memento(this, aspects, ff);
+    }
+    void do_incremental_task_sync(Task* t, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        t->set_memento(this, aspects, f);
+    }
+
+    std::vector<std::string> order_;
+    friend class NodeContainer;
+    friend class Task;
+    friend class Defs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class ChildrenMemento : public Memento {
+public:
+    explicit ChildrenMemento(const std::vector<node_ptr>& children) : children_(children) {}
+    ChildrenMemento() = default;
+
+private:
+    void do_incremental_suite_sync(Suite* s, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        s->set_memento(this, aspects, f);
+    }
+    void do_incremental_family_sync(Family* f, std::vector<ecf::Aspect::Type>& aspects, bool ff) const override {
+        f->set_memento(this, aspects, ff);
+    }
+
+    std::vector<node_ptr> children_;
+    friend class NodeContainer;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class AliasChildrenMemento : public Memento {
+public:
+    explicit AliasChildrenMemento(const std::vector<alias_ptr>& children) : children_(children) {}
+    AliasChildrenMemento() = default;
+
+private:
+    void do_incremental_task_sync(Task* t, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        t->set_memento(this, aspects, f);
+    }
+
+    std::vector<alias_ptr> children_;
+    friend class Task;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class AliasNumberMemento : public Memento {
+public:
+    explicit AliasNumberMemento(unsigned int alias_no) : alias_no_(alias_no) {}
+    AliasNumberMemento() = default;
+
+private:
+    void do_incremental_task_sync(Task* t, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        t->set_memento(this, aspects, f);
+    }
+
+    unsigned int alias_no_{0};
+    friend class Task;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class SuspendedMemento : public Memento {
+public:
+    explicit SuspendedMemento(bool suspended) : suspended_(suspended) {}
+    SuspendedMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    bool suspended_{false};
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class ServerStateMemento : public Memento {
+public:
+    explicit ServerStateMemento(SState::State s) : state_(s) {}
+    ServerStateMemento() = default;
+
+private:
+    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        defs->set_memento(this, aspects, f);
+    }
+
+    SState::State state_{SState::HALTED};
+    friend class Defs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class ServerVariableMemento : public Memento {
+public:
+    explicit ServerVariableMemento(const std::vector<Variable>& vec) : serverEnv_(vec) {}
+    ServerVariableMemento() = default;
+
+private:
+    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        defs->set_memento(this, aspects, f);
+    }
+
+    std::vector<Variable> serverEnv_;
+    friend class Defs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeDefStatusDeltaMemento : public Memento {
+public:
+    explicit NodeDefStatusDeltaMemento(DState::State state) : state_(state) {}
+    NodeDefStatusDeltaMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    DState::State state_{DState::UNKNOWN};
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeEventMemento : public Memento {
+public:
+    explicit NodeEventMemento(const Event& e) : event_(e) {}
+    NodeEventMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Event event_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeMeterMemento : public Memento {
+public:
+    explicit NodeMeterMemento(const Meter& e) : meter_(e) {}
+    NodeMeterMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Meter meter_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeLabelMemento : public Memento {
+public:
+    explicit NodeLabelMemento(const Label& e) : label_(e) {}
+    NodeLabelMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Label label_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeQueueMemento : public Memento {
+public:
+    explicit NodeQueueMemento(const QueueAttr& e) : queue_(e) {}
+    NodeQueueMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    QueueAttr queue_;
+    friend class Node;
+    friend class MiscAttrs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeGenericMemento : public Memento {
+public:
+    explicit NodeGenericMemento(const GenericAttr& e) : generic_(e) {}
+    NodeGenericMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    GenericAttr generic_;
+    friend class Node;
+    friend class MiscAttrs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeQueueIndexMemento : public Memento {
+public:
+    NodeQueueIndexMemento(const std::string& name, int index, const std::vector<NState::State>& state_vec)
+        : name_(name),
+          state_vec_(state_vec),
+          index_(index) {}
+    NodeQueueIndexMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    std::string name_;
+    std::vector<NState::State> state_vec_;
+    int index_{0};
+    friend class Node;
+    friend class MiscAttrs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeTriggerMemento : public Memento {
+public:
+    explicit NodeTriggerMemento(const Expression& e) : exp_(e) {}
+    NodeTriggerMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Expression exp_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeCompleteMemento : public Memento {
+public:
+    explicit NodeCompleteMemento(const Expression& e) : exp_(e) {}
+    NodeCompleteMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Expression exp_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeRepeatMemento : public Memento {
+public:
+    explicit NodeRepeatMemento(const Repeat& e) : repeat_(e) {}
+    NodeRepeatMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Repeat repeat_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeRepeatIndexMemento : public Memento {
+public:
+    explicit NodeRepeatIndexMemento(const Repeat& e) : index_or_value_(e.index_or_value()) {}
+    NodeRepeatIndexMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    long index_or_value_{0};
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeLimitMemento : public Memento {
+public:
+    explicit NodeLimitMemento(const Limit& e) : limit_(e) {}
+    NodeLimitMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Limit limit_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeInLimitMemento : public Memento {
+public:
+    explicit NodeInLimitMemento(const InLimit& e) : inlimit_(e) {}
+    NodeInLimitMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    InLimit inlimit_;
+    friend class Node;
+    friend class InLimitMgr;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeVariableMemento : public Memento {
+public:
+    explicit NodeVariableMemento(const Variable& e) : var_(e) {}
+    NodeVariableMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    Variable var_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeLateMemento : public Memento {
+public:
+    explicit NodeLateMemento(const ecf::LateAttr& e) : late_(e) {}
+    NodeLateMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ecf::LateAttr late_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class FlagMemento : public Memento {
+public:
+    explicit FlagMemento(const ecf::Flag& e) : flag_(e) {}
+    FlagMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+    void do_incremental_defs_sync(Defs* defs, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        defs->set_memento(this, aspects, f);
+    }
+
+    ecf::Flag flag_;
+    friend class Node;
+    friend class Defs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeTodayMemento : public Memento {
+public:
+    explicit NodeTodayMemento(const ecf::TodayAttr& attr) : attr_(attr) {}
+    NodeTodayMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ecf::TodayAttr attr_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeTimeMemento : public Memento {
+public:
+    explicit NodeTimeMemento(const ecf::TimeAttr& attr) : attr_(attr) {}
+    NodeTimeMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ecf::TimeAttr attr_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeDayMemento : public Memento {
+public:
+    explicit NodeDayMemento(const DayAttr& attr) : attr_(attr) {}
+    NodeDayMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    DayAttr attr_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeCronMemento : public Memento {
+public:
+    explicit NodeCronMemento(const ecf::CronAttr& attr) : attr_(attr) {}
+    NodeCronMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ecf::CronAttr attr_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeAvisoMemento : public Memento {
+public:
+    NodeAvisoMemento() = default;
+    explicit NodeAvisoMemento(const ecf::AvisoAttr& a) : aviso_(a.make_detached()) {}
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ecf::AvisoAttr aviso_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeMirrorMemento : public Memento {
+public:
+    NodeMirrorMemento() = default;
+    explicit NodeMirrorMemento(const ecf::MirrorAttr& a) : mirror_(a.make_detached()) {}
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ecf::MirrorAttr mirror_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeDateMemento : public Memento {
+public:
+    explicit NodeDateMemento(const DateAttr& attr) : attr_(attr) {}
+    NodeDateMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    DateAttr attr_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeZombieMemento : public Memento {
+public:
+    explicit NodeZombieMemento(const ZombieAttr& attr) : attr_(attr) {}
+    NodeZombieMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ZombieAttr attr_;
+    friend class Node;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class NodeVerifyMemento : public Memento {
+public:
+    explicit NodeVerifyMemento(const std::vector<VerifyAttr>& attr) : verifys_(attr) {}
+    NodeVerifyMemento() = default;
+
+private:
+    void do_incremental_node_sync(Node* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    std::vector<VerifyAttr> verifys_;
+    friend class Node;
+    friend class MiscAttrs;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class SubmittableMemento : public Memento {
+public:
+    SubmittableMemento(const std::string& jobsPassword,
+                       const std::string& process_or_remote_id,
+                       const std::string& abortedReason,
+                       int tryNo)
+        : paswd_(jobsPassword),
+          rid_(process_or_remote_id),
+          abr_(abortedReason),
+          tryNo_(tryNo) {}
+    SubmittableMemento() = default;
+
+private:
+    void do_incremental_task_sync(Task* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+    void do_incremental_alias_sync(Alias* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    std::string paswd_;
+    std::string rid_;
+    std::string abr_;
+    int tryNo_{0};
+    friend class Submittable;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class SuiteClockMemento : public Memento {
+public:
+    explicit SuiteClockMemento(const ClockAttr& c) : clockAttr_(c) {}
+    SuiteClockMemento() = default;
+
+private:
+    void do_incremental_suite_sync(Suite* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ClockAttr clockAttr_;
+    friend class Suite;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class SuiteBeginDeltaMemento : public Memento {
+public:
+    explicit SuiteBeginDeltaMemento(bool begun) : begun_(begun) {}
+    SuiteBeginDeltaMemento() = default;
+
+private:
+    void do_incremental_suite_sync(Suite* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    bool begun_{false};
+    friend class Suite;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+class SuiteCalendarMemento : public Memento {
+public:
+    explicit SuiteCalendarMemento(const ecf::Calendar& cal) : cal_(cal) {}
+    SuiteCalendarMemento() = default;
+
+private:
+    void do_incremental_suite_sync(Suite* n, std::vector<ecf::Aspect::Type>& aspects, bool f) const override {
+        n->set_memento(this, aspects, f);
+    }
+
+    ecf::Calendar cal_; // *Only* persisted since used by the why() on client side
+    friend class Suite;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_node_Memento_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/MirrorAttr.cpp 5.13.0-1/libs/node/src/ecflow/node/MirrorAttr.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/MirrorAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/MirrorAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,184 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/MirrorAttr.hpp"
+
+#include <sstream>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Message.hpp"
+#include "ecflow/core/Overload.hpp"
+#include "ecflow/core/exceptions/Exceptions.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/Operations.hpp"
+
+namespace ecf {
+
+bool MirrorAttr::is_valid_name(const std::string& name) {
+    return ecf::Str::valid_name(name);
+}
+
+MirrorAttr::MirrorAttr(Node* parent,
+                       name_t name,
+                       remote_path_t remote_path,
+                       remote_host_t remote_host,
+                       remote_port_t remote_port,
+                       polling_t polling,
+                       flag_t ssl,
+                       auth_t auth,
+                       reason_t reason)
+    : parent_{parent},
+      name_{std::move(name)},
+      remote_path_{std::move(remote_path)},
+      remote_host_{std::move(remote_host)},
+      remote_port_{std::move(remote_port)},
+      polling_{std::move(polling)},
+      ssl_{ssl},
+      auth_{std::move(auth)},
+      reason_{std::move(reason)},
+      controller_{nullptr} {
+    if (!is_valid_name(name_)) {
+        throw ecf::InvalidArgument(ecf::Message("Invalid MirrorAttr name :", name_));
+    }
+}
+
+MirrorAttr::~MirrorAttr() {
+    stop_controller();
+}
+
+[[nodiscard]] MirrorAttr MirrorAttr::make_detached() const {
+    MirrorAttr clone{*this};
+    clone.parent_     = nullptr;
+    clone.controller_ = nullptr;
+    return clone;
+}
+
+std::string MirrorAttr::absolute_name() const {
+    return parent_->absNodePath() + ':' + name_;
+}
+
+bool MirrorAttr::why(std::string& theReasonWhy) const {
+    theReasonWhy += ecf::Message(" is a Mirror of ", remote_path(), " at '", remote_host(), ":", remote_port(), "'");
+    return true;
+}
+
+void MirrorAttr::reset() {
+    state_change_no_ = Ecf::incr_state_change_no();
+    start_controller();
+}
+
+void MirrorAttr::finish() {
+    stop_controller();
+}
+
+void MirrorAttr::mirror() {
+    SLOG(D, "MirrorAttr: poll Mirror attribute '" << absolute_name() << "'");
+
+    start_controller();
+
+    // Task associated with Attribute is free when any notification is found
+    if (auto notifications = controller_->get_notifications(remote_path_); !notifications.empty()) {
+
+        // Update the 'local' state change number
+        state_change_no_ = Ecf::incr_state_change_no();
+
+        // Notifications found -- Node state to be updated or error to be reported
+        std::visit(ecf::overload{[this](const service::mirror::MirrorNotification& notification) {
+                                     SLOG(D,
+                                          "MirrorAttr: Updating Mirror attribute (name: " << name_ << ") to state "
+                                                                                          << notification.status());
+                                     auto latest_state = static_cast<NState::State>(notification.status());
+                                     reason_           = "";
+                                     parent_->flag().clear(Flag::REMOTE_ERROR);
+                                     parent_->flag().set_state_change_no(state_change_no_);
+                                     parent_->setStateOnly(latest_state, true);
+                                 },
+                                 [this](const service::mirror::MirrorError& error) {
+                                     SLOG(D,
+                                          "MirrorAttr: Failure detected on Mirror attribute (name: "
+                                              << name_ << ") due to " << error.reason());
+                                     reason_ = error.reason();
+                                     parent_->flag().set(Flag::REMOTE_ERROR);
+                                     parent_->flag().set_state_change_no(state_change_no_);
+                                     parent_->setStateOnly(NState::UNKNOWN, true);
+                                 }},
+                   notifications.back());
+
+        // Propagate the 'local' state change number to all parents
+        ecf::visit_parents(*parent_, [n = this->state_change_no_](Node& node) { node.set_state_change_no(n); });
+
+        // Propagate the 'local' state change number to the top level suite
+        auto find_suite = [](Node* node) -> Suite* {
+            Node* top = node;
+            while (top->parent() != nullptr) {
+                top = top->parent();
+            }
+            if (top->isSuite()) {
+                return static_cast<Suite*>(top);
+            }
+            return nullptr;
+        };
+        if (Suite* suite = find_suite(parent_); suite) {
+            suite->Suite::set_state_change_no(state_change_no_);
+        }
+    }
+    else {
+        SLOG(D, "MirrorAttr: No notifications found for Mirror attribute (name: " << name_ << ")");
+    }
+
+    // No notifications, nothing to do...
+}
+
+void MirrorAttr::start_controller() const {
+    if (controller_ == nullptr) {
+        // Substitute variables in Mirror configuration
+        std::string remote_host = remote_host_;
+        parent_->variableSubstitution(remote_host);
+        std::string remote_port = remote_port_;
+        parent_->variableSubstitution(remote_port);
+        std::string polling = polling_;
+        parent_->variableSubstitution(polling);
+        std::string auth = auth_;
+        parent_->variableSubstitution(auth);
+
+        SLOG(D,
+             "MirrorAttr: start polling Mirror attribute '" << absolute_name() << "', from " << remote_path_ << " @ "
+                                                            << remote_host << ':' << remote_port << ")");
+
+        // Controller -- start up the Mirror controller, and configure the Mirror request
+        controller_ = std::make_shared<controller_t>();
+        controller_->subscribe(ecf::service::mirror::MirrorRequest{
+            remote_path_, remote_host, remote_port, boost::lexical_cast<std::uint32_t>(polling), ssl_, auth});
+        // Controller -- effectively start the Mirror process
+        // n.b. this must be done after subscribing in the controller, so that the polling interval is set
+        controller_->start();
+    }
+}
+
+void MirrorAttr::stop_controller() const {
+    if (controller_ != nullptr) {
+        SLOG(D,
+             "MirrorAttr: finishing polling for Mirror attribute \"" << parent_->absNodePath() << ":" << name_
+                                                                     << "\", from host: " << remote_host_
+                                                                     << ", port: " << remote_port_ << ")");
+
+        controller_->stop();
+        controller_.reset();
+    }
+}
+
+bool operator==(const MirrorAttr& lhs, const MirrorAttr& rhs) {
+    return lhs.name() == rhs.name() && lhs.remote_path() == rhs.remote_path() &&
+           lhs.remote_host() == rhs.remote_host() && lhs.remote_port() == rhs.remote_port() &&
+           lhs.polling() == rhs.polling() && lhs.ssl() == rhs.ssl() && lhs.auth() == rhs.auth() &&
+           lhs.reason() == rhs.reason();
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/MirrorAttr.hpp 5.13.0-1/libs/node/src/ecflow/node/MirrorAttr.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/MirrorAttr.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/MirrorAttr.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,150 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_MirrorAttr_HPP
+#define ecflow_node_MirrorAttr_HPP
+
+#include <cstdint>
+#include <iostream>
+#include <string>
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/service/mirror/MirrorService.hpp"
+
+namespace cereal {
+class access;
+}
+
+class Node;
+
+namespace ecf {
+
+///
+/// \brief MirrorAttr represents an attribute, attached to a \ref Node.
+///
+/// The Mirror attribute effectively mirrors the status of a remote Node, allowing other Nodes to be triggered.
+///
+
+class MirrorAttr {
+public:
+    using name_t        = std::string;
+    using remote_path_t = std::string;
+    using remote_host_t = std::string;
+    using remote_port_t = std::string;
+    using polling_t     = std::string;
+    using flag_t        = bool;
+    using auth_t        = std::string;
+    using reason_t      = std::string;
+
+    using controller_t     = ecf::service::mirror::MirrorController;
+    using controller_ptr_t = std::shared_ptr<controller_t>;
+
+    static constexpr const char* default_remote_host = "%ECF_MIRROR_REMOTE_HOST%";
+    static constexpr const char* default_remote_port = "%ECF_MIRROR_REMOTE_PORT%";
+    static constexpr const char* default_polling     = "%ECF_MIRROR_REMOTE_POLLING%";
+    static constexpr const char* default_remote_auth = "%ECF_MIRROR_REMOTE_AUTH%";
+
+    static bool is_valid_name(const std::string& name);
+
+    /**
+     * Creates a(n invalid) Mirror
+     *
+     * Note: this is required by Cereal serialization
+     *       Cereal invokes the default ctor to create the object and only then proceeds to member-wise serialization.
+     */
+    MirrorAttr() = default;
+    MirrorAttr(Node* parent,
+               name_t name,
+               remote_path_t remote_path,
+               remote_host_t remote_host,
+               remote_port_t remote_port,
+               polling_t polling,
+               flag_t ssl,
+               auth_t auth,
+               reason_t reason);
+
+    MirrorAttr(const MirrorAttr& rhs) = default;
+    ~MirrorAttr();
+
+    MirrorAttr& operator=(const MirrorAttr& rhs) = default;
+
+    [[nodiscard]] MirrorAttr make_detached() const;
+
+    [[nodiscard]] inline const std::string& name() const { return name_; }
+    [[nodiscard]] std::string absolute_name() const;
+
+    [[nodiscard]] inline const std::string& remote_path() const { return remote_path_; }
+    [[nodiscard]] inline const std::string& remote_host() const { return remote_host_; }
+    [[nodiscard]] inline const std::string& remote_port() const { return remote_port_; }
+    [[nodiscard]] inline polling_t polling() const { return polling_; }
+    [[nodiscard]] inline flag_t ssl() const { return ssl_; }
+    [[nodiscard]] inline const std::string& auth() const { return auth_; }
+    [[nodiscard]] inline const std::string& reason() const { return reason_; }
+
+    void set_parent(Node* parent) { parent_ = parent; }
+
+    unsigned int state_change_no() const { return state_change_no_; }
+
+    bool why(std::string& theReasonWhy) const;
+
+    /**
+     * Initialises the Mirror procedure, which effectively starts the background polling mechanism.
+     */
+    void reset();
+    void finish();
+
+    /**
+     * Check if state changes were detected by the background polling mechanism, and if so, reflect it on the Node.
+     */
+    void mirror();
+
+    template <class Archive>
+    friend void serialize(Archive& ar, MirrorAttr& aviso, std::uint32_t version);
+
+private:
+    void start_controller() const;
+    void stop_controller() const;
+
+    Node* parent_{nullptr}; // only ever used on the server side, to update parent Node state
+    name_t name_;
+    remote_path_t remote_path_;
+    remote_host_t remote_host_;
+    remote_port_t remote_port_;
+    polling_t polling_;
+    flag_t ssl_;
+    auth_t auth_;
+    reason_t reason_;
+
+    // The following are mutable as they are modified by the const method isFree()
+    mutable unsigned int state_change_no_{0}; // *not* persisted, only used on server side
+
+    // The controller is only instanciated when the Mirror is reset()
+    // This allows the MirrorAttr have a copy-ctor and assignment operator
+    mutable controller_ptr_t controller_;
+};
+
+bool operator==(const MirrorAttr& lhs, const MirrorAttr& rhs);
+
+template <class Archive>
+void serialize(Archive& ar, MirrorAttr& aviso, [[maybe_unused]] std::uint32_t version) {
+    ar & aviso.name_;
+    ar & aviso.remote_path_;
+    ar & aviso.remote_host_;
+    ar & aviso.remote_port_;
+    ar & aviso.polling_;
+    ar & aviso.ssl_;
+    ar & aviso.auth_;
+    ar & aviso.reason_;
+}
+
+} // namespace ecf
+
+#endif /* ecflow_node_MirrorAttr_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/MiscAttrs.cpp 5.13.0-1/libs/node/src/ecflow/node/MiscAttrs.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/MiscAttrs.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/MiscAttrs.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,356 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/MiscAttrs.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/Node.hpp"
+
+#ifdef DEBUG
+    #include <iostream>
+#endif
+
+using namespace ecf;
+using namespace std;
+
+///////////////////////////////////////////////////////////////////////////////////////////
+
+MiscAttrs::MiscAttrs(const MiscAttrs& rhs)
+    : zombies_(rhs.zombies_),
+      verifys_(rhs.verifys_),
+      queues_(rhs.queues_),
+      generics_(rhs.generics_) {
+}
+
+MiscAttrs::~MiscAttrs() = default;
+
+// needed by node serialisation
+void MiscAttrs::set_node(Node* n) {
+    node_ = n;
+}
+
+bool MiscAttrs::checkInvariants(std::string& errorMsg) const {
+    if (!node_) {
+        errorMsg += "MiscAttrs::checkInvariants: failed node_ is NULL";
+        return false;
+    }
+    return true;
+}
+
+void MiscAttrs::begin() {
+    // reset verification
+    for (auto& verify : verifys_) {
+        verify.reset();
+    }
+    for (auto& queue : queues_) {
+        queue.requeue();
+    }
+}
+
+void MiscAttrs::requeue() {
+    for (auto& queue : queues_) {
+        queue.requeue();
+    }
+}
+
+void MiscAttrs::print(std::string& os) const {
+    for (const ZombieAttr& z : zombies_) {
+        z.print(os);
+    }
+    for (const VerifyAttr& v : verifys_) {
+        v.print(os);
+    }
+    for (const QueueAttr& q : queues_) {
+        q.print(os);
+    }
+    for (const GenericAttr& g : generics_) {
+        g.print(os);
+    }
+}
+
+bool MiscAttrs::operator==(const MiscAttrs& rhs) const {
+    if (zombies_.size() != rhs.zombies_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "MiscAttrs::operator==   (zombies_.size() != rhs.zombies_.size()) " << node_->debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < zombies_.size(); ++i) {
+        if (!(zombies_[i] == rhs.zombies_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "MiscAttrs::operator==   (!(zombies_[i] == rhs.zombies_[i]) " << node_->debugNodePath()
+                          << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (queues_.size() != rhs.queues_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "MiscAttrs::operator==   (queues_.size() != rhs.queues_.size()) " << node_->debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < queues_.size(); ++i) {
+        if (!(queues_[i] == rhs.queues_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "MiscAttrs::operator==   (!(queues_[i] == rhs.queues_[i]) " << node_->debugNodePath()
+                          << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (verifys_.size() != rhs.verifys_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "MiscAttrs::operator==  (verifys_.size() != rhs.verifys_.size()) " << node_->debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < verifys_.size(); ++i) {
+        if (!(verifys_[i] == rhs.verifys_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "MiscAttrs::operator==  (!(verifys_[i] == rhs.verifys_[i] ))  " << node_->debugNodePath()
+                          << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (generics_.size() != rhs.generics_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "MiscAttrs::operator==  (generics_.size() != rhs.generics_.size()) " << node_->debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < generics_.size(); ++i) {
+        if (!(generics_[i] == rhs.generics_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "MiscAttrs::operator==  (!(generics_ [i] == rhs.generics_[i] ))  "
+                          << node_->debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+    return true;
+}
+
+void MiscAttrs::verification(std::string& errorMsg) const {
+    for (const VerifyAttr& v : verifys_) {
+        if (v.expected() != v.actual()) {
+            std::stringstream ss;
+            ss << node_->debugNodePath() << " expected " << v.expected() << " " << NState::toString(v.state())
+               << " but found " << v.actual() << "\n";
+            errorMsg += ss.str();
+        }
+    }
+}
+
+void MiscAttrs::addZombie(const ZombieAttr& z) {
+    const ZombieAttr& theFndOne = findZombie(z.zombie_type());
+    if (!theFndOne.empty()) {
+        std::stringstream ss;
+        ss << "MiscAttrs::addZombie: Node " << node_->absNodePath() << " already has a zombie attribute of type "
+           << Child::to_string(theFndOne.zombie_type()) << "\n";
+        throw std::runtime_error(ss.str());
+    }
+    zombies_.push_back(z);
+    node_->state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "MiscAttrs::addZombie()\n";
+#endif
+}
+
+void MiscAttrs::deleteZombie(const std::string& zombie_type) {
+    if (zombie_type.empty()) {
+        zombies_.clear();
+        node_->state_change_no_ = Ecf::incr_state_change_no();
+        return;
+    }
+
+    if (!Child::valid_zombie_type(zombie_type)) {
+        throw std::runtime_error(
+            "MiscAttrs::deleteZombie failed: Expected one of [ ecf | path | user ] or empty string but found " +
+            zombie_type);
+    }
+    delete_zombie(Child::zombie_type(zombie_type));
+}
+
+void MiscAttrs::delete_zombie(Child::ZombieType zt) {
+    for (size_t i = 0; i < zombies_.size(); ++i) {
+        if (zombies_[i].zombie_type() == zt) {
+            zombies_.erase(zombies_.begin() + i);
+            node_->state_change_no_ = Ecf::incr_state_change_no();
+            return;
+        }
+    }
+}
+
+const ZombieAttr& MiscAttrs::findZombie(ecf::Child::ZombieType zombie_type) const {
+    /// There should only be one of each type
+    for (const auto& zombie : zombies_) {
+        if (zombie.zombie_type() == zombie_type) {
+            return zombie;
+        }
+    }
+    return ZombieAttr::EMPTY();
+}
+
+void MiscAttrs::add_generic(const GenericAttr& z) {
+    const GenericAttr& theFndOne = find_generic(z.name());
+    if (!theFndOne.empty()) {
+        std::stringstream ss;
+        ss << "MiscAttrs::add_generic : Node " << node_->absNodePath() << " already has a generic attribute of name "
+           << z.name() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+    generics_.push_back(z);
+    node_->state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
+}
+
+void MiscAttrs::addVerify(const VerifyAttr& v) {
+    if (findVerify(v)) {
+        std::stringstream ss;
+        ss << "Add Verify failed: Duplicate '" << v.toString() << "' already exist for node " << node_->debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    verifys_.push_back(v);
+    node_->state_change_no_ = Ecf::incr_state_change_no();
+}
+
+bool MiscAttrs::findVerify(const VerifyAttr& v) const {
+    size_t theSize = verifys_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (verifys_[i].state() == v.state()) {
+            return true;
+        }
+    }
+    return false;
+}
+
+void MiscAttrs::add_queue(const QueueAttr& q) {
+    const QueueAttr& theFndOne = find_queue(q.name());
+    if (!theFndOne.empty()) {
+        std::stringstream ss;
+        ss << "MiscAttrs::add_queue: Node " << node_->absNodePath() << " already has a queue attribute of name "
+           << q.name() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+    queues_.push_back(q);
+    node_->state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
+}
+
+void MiscAttrs::delete_queue(const std::string& name) {
+    if (name.empty()) {
+        queues_.clear();
+        node_->state_change_no_ = Ecf::incr_state_change_no();
+        return;
+    }
+    for (size_t i = 0; i < queues_.size(); ++i) {
+        if (queues_[i].name() == name) {
+            queues_.erase(queues_.begin() + i);
+            node_->state_change_no_ = Ecf::incr_state_change_no();
+            return;
+        }
+    }
+}
+
+const QueueAttr& MiscAttrs::find_queue(const std::string& name) const {
+    for (const auto& queue : queues_) {
+        if (queue.name() == name) {
+            return queue;
+        }
+    }
+    return QueueAttr::EMPTY();
+}
+
+QueueAttr& MiscAttrs::findQueue(const std::string& name) {
+    for (auto& queue : queues_) {
+        if (queue.name() == name) {
+            return queue;
+        }
+    }
+    return QueueAttr::EMPTY1();
+}
+
+void MiscAttrs::delete_generic(const std::string& name) {
+    if (name.empty()) {
+        generics_.clear();
+        node_->state_change_no_ = Ecf::incr_state_change_no();
+        return;
+    }
+    for (size_t i = 0; i < generics_.size(); ++i) {
+        if (generics_[i].name() == name) {
+            generics_.erase(generics_.begin() + i);
+            node_->state_change_no_ = Ecf::incr_state_change_no();
+            return;
+        }
+    }
+}
+
+const GenericAttr& MiscAttrs::find_generic(const std::string& name) const {
+    for (const auto& generic : generics_) {
+        if (generic.name() == name) {
+            return generic;
+        }
+    }
+    return GenericAttr::EMPTY();
+}
+
+void MiscAttrs::set_memento(const NodeQueueMemento* m) {
+    add_queue(m->queue_);
+}
+
+void MiscAttrs::set_memento(const NodeGenericMemento* m) {
+    add_generic(m->generic_);
+}
+
+void MiscAttrs::set_memento(const NodeQueueIndexMemento* m) {
+    for (auto& queue : queues_) {
+        if (queue.name() == m->name_) {
+            queue.set_index(m->index_);
+            queue.set_state_vec(m->state_vec_);
+        }
+    }
+}
+
+template <class Archive>
+void MiscAttrs::serialize(Archive& ar, std::uint32_t const version) {
+    CEREAL_OPTIONAL_NVP(ar, zombies_, [this]() { return !zombies_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, verifys_, [this]() { return !verifys_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, queues_, [this]() { return !queues_.empty(); });     // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, generics_, [this]() { return !generics_.empty(); }); // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(MiscAttrs);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/MiscAttrs.hpp 5.13.0-1/libs/node/src/ecflow/node/MiscAttrs.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/MiscAttrs.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/MiscAttrs.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,107 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_MiscAttrs_HPP
+#define ecflow_node_MiscAttrs_HPP
+
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/node/Node.hpp"
+
+class MiscAttrs {
+public:
+    MiscAttrs() = default;
+    MiscAttrs(const MiscAttrs& rhs);
+    explicit MiscAttrs(Node* node) : node_(node) {}
+    ~MiscAttrs();
+
+    MiscAttrs& operator=(const MiscAttrs&) = delete;
+
+    // needed by node serialisation
+    void set_node(Node* n);
+    bool checkInvariants(std::string& errorMsg) const;
+
+    void begin();
+    void requeue();
+
+    // standard functions: ==============================================
+    void print(std::string&) const;
+    bool operator==(const MiscAttrs&) const;
+
+    // Access functions: ======================================================
+    const std::vector<VerifyAttr>& verifys() const { return verifys_; }
+    const std::vector<ZombieAttr>& zombies() const { return zombies_; }
+    const std::vector<QueueAttr>& queues() const { return queues_; }
+    const std::vector<GenericAttr>& generics() const { return generics_; }
+    std::vector<QueueAttr>& ref_queues() { return queues_; } // allow simulator access
+
+    // Add functions: ===============================================================
+    void addVerify(const VerifyAttr&);    // for testing and verification Can throw std::runtime_error
+    void addZombie(const ZombieAttr&);    // will throw std::runtime_error if duplicate
+    void add_queue(const QueueAttr&);     // will throw std::runtime_error if duplicate
+    void add_generic(const GenericAttr&); // will throw std::runtime_error if duplicate, must be unique on the key
+
+    /// Check to see if auto_restore can reference the nodes
+    void check(std::string& errorMsg) const;
+
+    // Delete functions: can throw std::runtime_error ===================================
+    // if name argument is empty, delete all attributes of that type
+    // Can throw std::runtime_error of the attribute cannot be found
+    void delete_zombie(const ecf::Child::ZombieType);
+    void deleteZombie(const std::string& type);   // string must be one of [ user | ecf | path ]
+    void delete_queue(const std::string& name);   // empty string means delete all queue's
+    void delete_generic(const std::string& name); // empty string means delete all generics
+
+    // Find functions: ============================================================
+    bool findVerify(const VerifyAttr&) const;
+    const ZombieAttr& findZombie(ecf::Child::ZombieType) const;
+    const QueueAttr& find_queue(const std::string& name) const;
+    const GenericAttr& find_generic(const std::string& name) const;
+    QueueAttr& findQueue(const std::string& name);
+
+    void verification(std::string& errorMsg) const;
+
+    void set_memento(const NodeGenericMemento*);
+    void set_memento(const NodeQueueMemento*);
+    void set_memento(const NodeQueueIndexMemento*);
+
+    bool empty() const {
+        return (zombies_.empty() && verifys_.empty() && queues_.empty() && generics_.empty()) ? true : false;
+    }
+
+private:
+    std::vector<ZombieAttr>::const_iterator zombie_begin() const { return zombies_.begin(); }
+    std::vector<ZombieAttr>::const_iterator zombie_end() const { return zombies_.end(); }
+    std::vector<VerifyAttr>::const_iterator verify_begin() const { return verifys_.begin(); }
+    std::vector<VerifyAttr>::const_iterator verify_end() const { return verifys_.end(); }
+    std::vector<QueueAttr>::const_iterator queue_begin() const { return queues_.begin(); }
+    std::vector<QueueAttr>::const_iterator queue_end() const { return queues_.end(); }
+    std::vector<GenericAttr>::const_iterator generic_begin() const { return generics_.begin(); }
+    std::vector<GenericAttr>::const_iterator generic_end() const { return generics_.end(); }
+
+private:
+    Node* node_{nullptr}; // *NOT* persisted must be set by the parent class
+    friend class Node;
+
+private:
+    std::vector<ZombieAttr> zombies_;   // can be added/removed via AlterCmd
+    std::vector<VerifyAttr> verifys_;   // used for statistics and test verification
+    std::vector<QueueAttr> queues_;     // experimental
+    std::vector<GenericAttr> generics_; // experimental
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_node_MiscAttrs_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Node.cpp 5.13.0-1/libs/node/src/ecflow/node/Node.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Node.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Node.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2969 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cassert>
+#include <stdexcept>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Stl.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/cereal_boost_time.hpp"
+#include "ecflow/node/AbstractObserver.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/CmdContext.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/ExprAstVisitor.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/MiscAttrs.hpp"
+#include "ecflow/node/NodeStats.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/formatter/Format.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///////////////////////////////////////////////////////////////////////////////////////////
+// #define DEBUG_DEPENDENCIES 1
+// #define DEBUG_REQUEUE 1
+// #define DEBUG_FIND_REFERENCED_NODE 1
+
+Node::Node(const std::string& n, bool check) : n_(n) {
+    if (check) {
+        string msg;
+        if (!Str::valid_name(n, msg)) {
+            throw std::runtime_error("Invalid node name : " + msg);
+        }
+    }
+}
+
+Node::Node() = default;
+
+Node::Node(const Node& rhs)
+    : enable_shared_from_this(rhs),
+      parent_(nullptr),
+      n_(rhs.n_),
+      st_(rhs.st_),
+      d_st_(rhs.d_st_),
+      vars_(rhs.vars_),
+      c_expr_((rhs.c_expr_) ? new Expression(*rhs.c_expr_) : nullptr),
+      t_expr_((rhs.t_expr_) ? new Expression(*rhs.t_expr_) : nullptr),
+      meters_(rhs.meters_),
+      events_(rhs.events_),
+      labels_(rhs.labels_),
+      times_(rhs.times_),
+      todays_(rhs.todays_),
+      crons_(rhs.crons_),
+      dates_(rhs.dates_),
+      days_(rhs.days_),
+      late_((rhs.late_) ? new ecf::LateAttr(*rhs.late_) : nullptr),
+      misc_attrs_((rhs.misc_attrs_) ? new MiscAttrs(*rhs.misc_attrs_) : nullptr),
+      repeat_(rhs.repeat_),
+      inLimitMgr_(rhs.inLimitMgr_),
+      flag_(rhs.flag_),
+      auto_cancel_((rhs.auto_cancel_) ? new AutoCancelAttr(*rhs.auto_cancel_) : nullptr),
+      auto_archive_((rhs.auto_archive_) ? new AutoArchiveAttr(*rhs.auto_archive_) : nullptr),
+      auto_restore_((rhs.auto_restore_) ? new AutoRestoreAttr(*rhs.auto_restore_) : nullptr),
+      suspended_(rhs.suspended_) {
+    inLimitMgr_.set_node(this);
+    if (misc_attrs_)
+        misc_attrs_->set_node(this);
+
+    if (auto_restore_)
+        auto_restore_->set_node(this);
+
+    for (const auto& limit : rhs.limits_) {
+        limit_ptr the_limit = std::make_shared<Limit>(*limit);
+        the_limit->set_node(this);
+        limits_.push_back(the_limit);
+    }
+}
+
+bool Node::check_defaults() const {
+    if (parent_ != nullptr)
+        throw std::runtime_error("Node::check_defaults(): parent_ != nullptr");
+    if (graphic_ptr_ != nullptr)
+        throw std::runtime_error("Node::check_defaults(): graphic_ptr_  != nullptr");
+    if (suspended_ != false)
+        throw std::runtime_error("Node::check_defaults(): suspended_ != false");
+    if (state_change_no_ != 0)
+        throw std::runtime_error("Node::check_defaults(): state_change_no_ != 0");
+    if (variable_change_no_ != 0)
+        throw std::runtime_error("Node::check_defaults(): variable_change_no_  != 0");
+    if (suspended_change_no_ != 0)
+        throw std::runtime_error("Node::check_defaults():  suspended_change_no_ != 0");
+    if (d_st_.state() != DState::QUEUED)
+        throw std::runtime_error("Node::check_defaults(): d_st_.state() != DState::QUEUED");
+    return true;
+}
+
+void Node::delete_attributes() {
+    c_expr_.reset(nullptr);
+    t_expr_.reset(nullptr);
+    late_.reset(nullptr);
+    misc_attrs_.reset(nullptr);
+}
+
+node_ptr Node::create(const std::string& node_string) {
+    DefsStructureParser parser(node_string);
+    std::string errorMsg, warningMsg;
+    (void)parser.doParse(errorMsg, warningMsg);
+    return parser.the_node_ptr(); // can return NULL
+}
+
+node_ptr Node::create(const std::string& node_string, std::string& error_msg) {
+    DefsStructureParser parser(node_string);
+    std::string warningMsg;
+    if (!parser.doParse(error_msg, warningMsg))
+        return node_ptr();
+    return parser.the_node_ptr();
+}
+
+Node& Node::operator=(const Node& rhs) {
+    // Note:: Defs assignment operator use copy/swap, hence this assignment note used
+    // parent must set parent_
+    if (this != &rhs) {
+        n_         = rhs.n_;
+        suspended_ = rhs.suspended_;
+        st_        = rhs.st_;
+        d_st_      = rhs.d_st_;
+
+        vars_ = rhs.vars_;
+
+        delete_attributes();
+
+        meters_ = rhs.meters_;
+        events_ = rhs.events_;
+        labels_ = rhs.labels_;
+
+        times_  = rhs.times_;
+        todays_ = rhs.todays_;
+        crons_  = rhs.crons_;
+        dates_  = rhs.dates_;
+        days_   = rhs.days_;
+
+        if (rhs.c_expr_)
+            c_expr_ = std::make_unique<Expression>(*rhs.c_expr_);
+        if (rhs.t_expr_)
+            t_expr_ = std::make_unique<Expression>(*rhs.t_expr_);
+        if (rhs.late_)
+            late_ = std::make_unique<ecf::LateAttr>(*rhs.late_);
+        if (rhs.misc_attrs_)
+            misc_attrs_ = std::make_unique<MiscAttrs>(*rhs.misc_attrs_);
+
+        if (rhs.auto_cancel_)
+            auto_cancel_ = std::make_unique<AutoCancelAttr>(*rhs.auto_cancel_);
+        if (rhs.auto_archive_)
+            auto_archive_ = std::make_unique<AutoArchiveAttr>(*rhs.auto_archive_);
+        if (rhs.auto_restore_)
+            auto_restore_ = std::make_unique<AutoRestoreAttr>(*rhs.auto_restore_);
+
+        repeat_     = rhs.repeat_;
+        inLimitMgr_ = rhs.inLimitMgr_;
+        inLimitMgr_.set_node(this);
+        flag_ = rhs.flag_;
+
+        state_change_no_     = 0;
+        variable_change_no_  = 0;
+        suspended_change_no_ = 0;
+        graphic_ptr_         = nullptr;
+
+        if (misc_attrs_)
+            misc_attrs_->set_node(this);
+
+        if (auto_restore_)
+            auto_restore_->set_node(this);
+
+        limits_.clear();
+        for (const auto& limit : rhs.limits_) {
+            limit_ptr the_limit = std::make_shared<Limit>(*limit);
+            the_limit->set_node(this);
+            limits_.push_back(the_limit);
+        }
+    }
+    return *this;
+}
+
+Node::~Node() = default;
+
+bool Node::isParentSuspended() const {
+    Node* theParent = parent();
+    if (theParent) {
+        if (theParent->isSuspended())
+            return true;
+        return theParent->isParentSuspended();
+    }
+    return defs()->isSuspended(); // obtained from the server states
+}
+
+void Node::resume() {
+    /// Guard against unnecessary creation of memento's
+    if (suspended_) {
+        suspended_           = false;
+        suspended_change_no_ = Ecf::incr_state_change_no();
+    }
+}
+
+void Node::suspend() {
+    // Typically called via user action or via defstatus
+    suspended_           = true;
+    suspended_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::begin() {
+    // record effect of defstatus for node changes, for verify attributes
+    if (misc_attrs_)
+        misc_attrs_->begin();
+
+    // Set the state without causing any side effects
+    initState(0);
+
+    if (!mirrors_.empty()) {
+        // In case mirror attributes are available, the node state becomes UNKNOWN
+        setStateOnly(NState::State::UNKNOWN, true /*force*/, Str::EMPTY() /* additional info to log */, false);
+    }
+
+    clearTrigger();
+    clearComplete();
+
+    flag_.reset();
+    repeat_.reset(); // if repeat is empty reset() does nothing
+
+    for (auto& meter : meters_) {
+        meter.reset();
+    }
+    for (auto& event : events_) {
+        event.reset();
+    }
+    for (auto& label : labels_) {
+        label.reset();
+    }
+
+    if (late_)
+        late_->reset();
+    for (auto& limit : limits_) {
+        limit->reset();
+    }
+
+    // Let time base attributes use, relative duration if applicable
+    {
+        const Calendar& calendar = suite()->calendar();
+        for (auto& today : todays_) {
+            today.reset(calendar);
+        }
+        for (auto& time : times_) {
+            time.reset(calendar);
+        }
+        for (auto& cron : crons_) {
+            cron.reset(calendar);
+        }
+
+        for (auto& day : days_) {
+            day.reset(calendar);
+        }
+        for (auto& date : dates_) {
+            date.reset();
+        }
+        markHybridTimeDependentsAsComplete();
+
+        for (auto& aviso : avisos_) {
+            aviso.reset();
+        }
+    }
+
+    for (auto& mirror : mirrors_) {
+        mirror.reset();
+    }
+
+    inLimitMgr_.reset(); // new to 5.0.0 clear inlimit.incremented() flag
+
+    // DO *NOT* call update_generated_variables(). Called on a type specific bases, for begin
+    // Typically we need only call update_generated_variables() for a task, at job creation time.
+    // so that ECF_OUT, ECF_TRYNO, ECF_JOBOUT, ECF_PASS(paswd_) can be updated.
+    // However, the generated variables are used when within job generation and can be referenced by AST
+    // Hence to avoid excessive memory consumption, they are created on demand
+}
+
+void Node::requeue(Requeue_args& args) {
+#ifdef DEBUG_REQUEUE
+    LOG(Log::DBG, "      Node::requeue() " << absNodePath() << " resetRepeats = " << args.resetRepeats_);
+#endif
+    // Note: we don't reset verify attributes as they record state stat's
+
+    if (!mirrors_.empty()) {
+        // In case mirror attributes are available, the node state becomes UNKNOWN
+        setStateOnly(NState::State::UNKNOWN, true /*force*/, Str::EMPTY() /* additional info to log */, false);
+    }
+
+    // Set the state without causing any side effects
+    initState(args.clear_suspended_in_child_nodes_, args.log_state_changes_);
+
+    clearTrigger();
+    clearComplete();
+
+    if (args.resetRepeats_)
+        repeat_.reset(); // if repeat is empty reset() does nothing
+
+    /// If a job takes longer than it slots, then that slot is missed, and next slot is used
+    /// Note we do *NOT* reset for requeue as we want to advance the valid time slots.
+    /// *NOTE* Update calendar will *free* time dependencies *even* time series. They rely
+    /// on this function to clear the time dependencies so they *HOLD* the task.
+    if (has_time_dependencies()) {
+
+        /// Requeue has several contexts:
+        ///   1/ manual requeue
+        ///   2/ automated requeue due to repeats
+        ///   3/ automated requeue due to time dependencies
+        /// For manual and automated reueue due to repeat's we always clear Flag::NO_REQUE_IF_SINGLE_TIME_DEP
+        /// since in those context we do NOT want miss any time slots
+        bool reset_next_time_slot = true;
+        if (args.reset_next_time_slot_) {
+            reset_next_time_slot = true;
+        }
+        else {
+            if (flag().is_set(Flag::NO_REQUE_IF_SINGLE_TIME_DEP)) {
+                /// If we have done an interactive run or complete, *dont* increment next_time_slot_
+                /// allow next time on time based attributes to be incremented and *not* reset,
+                /// when force and run commands used
+                reset_next_time_slot = false;
+            }
+        }
+
+        // must be done before the re-queue
+        do_requeue_time_attrs(reset_next_time_slot, args.reset_relative_duration_, args.requeue_t);
+        markHybridTimeDependentsAsComplete();
+    }
+
+    // Should *NOT* clear, archived flag, as this is done via autorestore or --restore
+    // reset the flags, however remember if edit were made
+    bool edit_history_set = flag().is_set(ecf::Flag::MESSAGE);
+    bool archived_set     = flag().is_set(ecf::Flag::ARCHIVED);
+    flag_.reset(); // will CLEAR NO_REQUE_IF_SINGLE_TIME_DEP
+    if (edit_history_set)
+        flag().set(ecf::Flag::MESSAGE);
+    if (archived_set)
+        flag().set(ecf::Flag::ARCHIVED);
+
+    if (late_)
+        late_->reset();
+
+    for (auto& meter : meters_) {
+        meter.reset();
+    }
+    for (auto& event : events_) {
+        event.reset();
+    }
+    // ECFLOW-195, only clear labels, if they are on Suites/Family not tasks(typically only specified on tasks)
+    if (isNodeContainer()) {
+        for (auto& label : labels_) {
+            label.reset();
+        }
+    }
+
+    if (misc_attrs_)
+        misc_attrs_->requeue();
+
+    for (auto& limit : limits_) {
+        limit->reset();
+    }
+    inLimitMgr_.reset(); // new to 5.0.0 clear inlimit.incremented() flag
+
+    // ECFLOW-196, ensure the re-queue release tokens held by Limits higher up the tree.
+    // Note: Its safe to call decrementInLimit, even when no limit consumed
+    std::set<Limit*> limitSet;  // ensure local limit have preference over parent
+    decrementInLimit(limitSet); // will recurse up, expensive but needed
+}
+
+void Node::reset_late_event_meters() {
+    if (late_)
+        late_->reset();
+    for (auto& meter : meters_) {
+        meter.reset();
+    }
+    for (auto& event : events_) {
+        event.reset();
+    }
+}
+
+void Node::reset() {
+    // Set the state without causing any side effects
+    initState(1);
+
+    if (!mirrors_.empty()) {
+        // In case of mirror attributes, the node state becomes UNKNOWN
+        setStateOnly(NState::State::UNKNOWN, true /*force*/, Str::EMPTY() /* additional info to log */, false);
+    }
+
+    clearTrigger();
+    clearComplete();
+
+    repeat_.reset(); // if repeat is empty reset() does nothing
+
+    for (auto& today : todays_) {
+        today.resetRelativeDuration();
+        today.reset_only();
+    }
+    for (auto& time : times_) {
+        time.resetRelativeDuration();
+        time.reset_only();
+    }
+    for (auto& cron : crons_) {
+        cron.resetRelativeDuration();
+        cron.reset_only();
+    }
+    for (auto& date : dates_) {
+        date.reset();
+    }
+    for (auto& day : days_) {
+        day.reset();
+    }
+
+    flag_.reset();
+
+    if (late_)
+        late_->reset();
+
+    for (auto& meter : meters_) {
+        meter.reset();
+    }
+    for (auto& event : events_) {
+        event.reset();
+    }
+    if (isNodeContainer()) {
+        for (auto& label : labels_) {
+            label.reset();
+        }
+    }
+
+    for (auto& limit : limits_) {
+        limit->reset();
+    }
+}
+
+void Node::handle_migration(const ecf::Calendar& c) {
+    // called when defs created by reading from a file on disk. i.e. checkpoint
+    // handle any migration
+    for (auto& day : days_) {
+        day.handle_migration(c);
+    }
+}
+
+void Node::requeue_time_attrs() {
+    // Note: we *don't* mark hybrid time dependencies as complete.
+    //       i.e. since this is called during alter command, it could be that
+    //        the task is in a submitted or active state.
+    do_requeue_time_attrs(true /*reset_next_time_slot*/, true /*reset_relative_duration*/, Requeue_args::FULL);
+}
+
+void Node::requeue_labels() {
+    // ECFLOW-195, clear labels before a task is run.
+    for (auto& label : labels_) {
+        label.reset();
+    }
+}
+
+// #define DEBUG_DAYS 1
+bool Node::calendarChanged(const ecf::Calendar& c,
+                           Node::Calendar_args& cal_args,
+                           const ecf::LateAttr*,
+                           bool holding_parent_day_or_date) {
+    // cout << " Node:calendarChanged: " << debugNodePath() << " holding_parent_day_or_date " <<
+    // holding_parent_day_or_date << "\n";
+
+    if (!holding_parent_day_or_date) {
+        holding_parent_day_or_date = calendar_changed_timeattrs(c, cal_args);
+
+#ifdef DEBUG_DAYS
+        if (holding_parent_day_or_date) {
+            cout << " Node::calendarChanged: " << debugNodePath() << " SETTING holding_parent_day_or_date "
+                 << holding_parent_day_or_date << " ***********\n";
+        }
+#endif
+    }
+#ifdef DEBUG_DAYS
+    else {
+        cout << " Node::calendarChanged: " << debugNodePath()
+             << " IGNORING since holding_parent_day_or_date  <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n";
+    }
+#endif
+
+    if (checkForAutoCancel(c)) {
+        cal_args.auto_cancelled_nodes_.push_back(shared_from_this());
+    }
+
+    // Avoid automatically archiving a restored node. Wait till begin/re-queue
+    if (!flag().is_set(ecf::Flag::RESTORED) && check_for_auto_archive(c)) {
+        cal_args.auto_archive_nodes_.push_back(shared_from_this());
+    }
+    return holding_parent_day_or_date;
+}
+
+void Node::check_for_lateness(const ecf::Calendar& c, const ecf::LateAttr* inherited_late) {
+    // Late flag should ONLY be set on Submittable
+    if (late_) {
+        // Only check for lateness if we are not late.
+        if (!late_->isLate()) {
+            if (!inherited_late || inherited_late->isNull())
+                checkForLateness(c);
+            else {
+                LateAttr overridden_late = *inherited_late;
+                overridden_late.override_with(late_.get());
+                if (overridden_late.check_for_lateness(st_, c)) {
+                    late_->setLate(true);
+                    flag().set(ecf::Flag::LATE);
+                }
+            }
+        }
+    }
+    else {
+        // inherited late, we can only set late flag.
+        if (inherited_late && !flag().is_set(ecf::Flag::LATE) && inherited_late->check_for_lateness(st_, c)) {
+            flag().set(ecf::Flag::LATE);
+        }
+    }
+}
+
+void Node::checkForLateness(const ecf::Calendar& c) {
+    if (late_ && late_->check_for_lateness(st_, c)) {
+        late_->setLate(true);
+        flag().set(ecf::Flag::LATE);
+        // cout << "Node::checkForLateness late flag set on " << absNodePath() << "\n";
+    }
+}
+
+void Node::initState(int clear_suspended_in_child_nodes, bool log_state_changes) {
+    // The state duration is ONLY updated *IF* state has changed.
+    // However, on re-queue *ALWAYS* reset state time.
+    // Otherwise, we can end up showing time in the future. SEE ECFLOW-1215
+    Suite* theSuite = suite();
+    if (theSuite) {
+        const Calendar& calendar = theSuite->calendar();
+        st_.second               = calendar.duration();
+    }
+
+    if (d_st_ == DState::SUSPENDED) {
+        /// Note: DState::SUSPENDED is not a real state, its really a user interaction
+        /// Replace with suspend, and set underlying state as queued
+        suspend();
+        setStateOnly(NState::QUEUED, false /*force*/, Str::EMPTY() /* additional info to log */, log_state_changes);
+    }
+    else {
+
+        if (clear_suspended_in_child_nodes > 0) {
+            resume();
+        }
+
+        // convert DState --> NState.
+        // NOTE::  NState does *NOT* have SUSPENDED
+        setStateOnly(DState::convert(d_st_.state()),
+                     false /*force*/,
+                     Str::EMPTY() /* additional info to log */,
+                     log_state_changes);
+    }
+}
+
+void Node::requeueOrSetMostSignificantStateUpNodeTree() {
+    // Get the computed state of my immediate children
+    // *** A family can be marked as complete, via complete trigger when not all its children
+    // *** are complete, hence computedState() *MUST* first check the immediate state  ,
+    // *** before considering its immediate children
+    NState::State computedStateOfImmediateChildren = computedState(Node::IMMEDIATE_CHILDREN);
+
+#ifdef DEBUG_REQUEUE
+    LogToCout toCoutAsWell;
+    cout << "\n";
+    Indentor indent;
+    LOG(Log::DBG,
+        "requeueOrSetMostSignificantStateUpNodeTree() " << debugNodePath() << "(" << NState::toString(state())
+                                                        << ") computed("
+                                                        << NState::toString(computedStateOfImmediateChildren) << ")");
+#endif
+
+    if (computedStateOfImmediateChildren == NState::COMPLETE) {
+
+        // set most significant state of my immediate children
+        // Record: That Suite/Family completed.
+        if (computedStateOfImmediateChildren != state()) {
+            setStateOnly(computedStateOfImmediateChildren);
+        }
+
+        // For automated re-queue do *not* clear suspended state in *child* nodes
+        int clear_suspended_in_child_nodes = -1;
+
+        if (!repeat_.empty()) {
+
+            repeat_.increment();
+
+            // If the repeat is still valid, re-queue the node
+#ifdef DEBUG_REQUEUE
+            LOG(Log::DBG,
+                "requeueOrSetMostSignificantStateUpNodeTree " << debugNodePath() << " for repeat "
+                                                              << repeat_.toString());
+#endif
+            if (repeat_.valid()) {
+#ifdef DEBUG_REQUEUE
+                LOG(Log::DBG,
+                    "requeueOrSetMostSignificantStateUpNodeTree() VALID for requeue "
+                        << debugNodePath() << " for repeat at " << repeat_.toString());
+#endif
+
+                // Remove effects of RUN and Force complete interactive commands
+                // For automated re-queue *DUE* to Repeats, *CLEAR* any user interaction that would miss the next time
+                // slots. *Down* the hierarchy This handles the case where a user, has manually intervened (i.e. via run
+                // or complete) and we had a time attribute That time attribute will have expired, typically we show
+                // next day. In the case where we have a parent repeat we need to clear the flag, otherwise the
+                // task/family with time based attribute would wait for next day.
+                Node::Requeue_args args(Node::Requeue_args::REPEAT_INCREMENT,
+                                        false /* don't reset repeats */,
+                                        clear_suspended_in_child_nodes,
+                                        true /* reset_next_time_slot */,
+                                        true /* reset relative duration */);
+                requeue(args);
+                set_most_significant_state_up_node_tree();
+                return;
+            }
+        }
+
+        /// If user has *INTERACTIVLY* forced changed in state to complete *OR* run the job.
+        /// This would cause Node to miss the next time slot. i.e. expire the time slot
+        /// In which case testTimeDependenciesForRequeue should return false for a single time/today dependency
+        /// and not requeue the node.
+        if (has_time_dependencies() && testTimeDependenciesForRequeue()) {
+
+            // This is the only place we do not explicitly reset_next_time_slot
+            bool reset_next_time_slot = false;
+
+            // Remove effects of RUN and Force complete interactive commands, *BUT* only if *not* applied to this cron
+            if (!crons().empty()) {
+                if (!flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP)) {
+                    reset_next_time_slot = true;
+                }
+            }
+
+            Node::Requeue_args args(Node::Requeue_args::TIME,
+                                    false /* don't reset repeats */,
+                                    clear_suspended_in_child_nodes,
+                                    reset_next_time_slot,
+                                    false /*  don't reset relative duration */);
+            requeue(args); // time +00:01 00:07 00:03 # here task re-queued many times, relative time must be preserved.
+            set_most_significant_state_up_node_tree();
+            return;
+        }
+    }
+
+    // In case compute state is other that COMPLETE, update. i,e for Family/Suite
+    if (computedStateOfImmediateChildren != state()) {
+        setStateOnly(computedStateOfImmediateChildren);
+    }
+
+    // recurse up the node tree
+    Node* theParentNode = parent();
+    if (theParentNode) {
+        theParentNode->requeueOrSetMostSignificantStateUpNodeTree();
+    }
+    else {
+        // No parent, hence next level is the root, ie the Defs
+        // Reflect the status of all the suite's
+        // **** This should not recurse down, just reflect status of suites
+        defs()->set_most_significant_state();
+    }
+}
+
+void Node::set_most_significant_state_up_node_tree() {
+    if (isTask()) {
+        parent()->set_most_significant_state_up_node_tree();
+        return;
+    }
+
+    // set most significant state  of my immediate children
+    NState::State computedStateOfImmediateChildren = computedState(Node::IMMEDIATE_CHILDREN);
+    if (computedStateOfImmediateChildren != state()) {
+        setStateOnly(computedStateOfImmediateChildren);
+    }
+
+    // recurse up the node tree
+    Node* theParentNode = parent();
+    if (theParentNode) {
+        theParentNode->set_most_significant_state_up_node_tree();
+    }
+    else {
+        // No parent, hence next level is the root, ie the Defs
+        // Reflect the status of all the suite's
+        // **** This should not recurse down, just reflect status of suites
+        defs()->set_most_significant_state();
+    }
+}
+
+// Returning false, *STOPS* further traversal *DOWN* the node tree
+bool Node::resolveDependencies(JobsParam& jobsParam) {
+    // This function is called:
+    //    a/ Periodically by the server, i.e. every minute
+    //    b/ Asynchronously, after child command, via job submission
+#ifdef DEBUG_DEPENDENCIES
+    LogToCout toCoutAsWell;
+    cout << "\n";
+    LOG(Log::DBG,
+        "   " << debugNodePath() << "::resolveDependencies " << NState::toString(state()) << " AT "
+              << suite()->calendar().toString());
+#endif
+
+    // A node that is archived should not allow any change of state.
+    if (get_flag().is_set(ecf::Flag::ARCHIVED))
+        return false;
+
+    if (isSuspended()) {
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG,
+            "   Node::resolveDependencies() " << absNodePath() << " HOLDING as node state " << NState::toString(state())
+                                              << " is SUSPENDED ");
+#endif
+        return false;
+    }
+
+    if (state() == NState::COMPLETE) {
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG,
+            "   Node::resolveDependencies() " << absNodePath() << " HOLDING as node state " << NState::toString(state())
+                                              << " is not valid for job submission");
+#endif
+        return false;
+    }
+
+    if (!mirrors_.empty()) {
+        // In case mirror attributes are configured, the node is never free (i.e. will not be run)
+        return false;
+    }
+
+    if (!timeDependenciesFree()) {
+#ifdef DEBUG_DEPENDENCIES
+        const Calendar& calendar = suite()->calendar();
+        LOG(Log::DBG,
+            "   Node::resolveDependencies() " << absNodePath() << " HOLDING due to time dependencies at "
+                                              << calendar.toString());
+#endif
+        return false;
+    }
+
+    // Complete *MUST* be evaluated before trigger. As it can affect the other
+    // i.e. A state change to COMPLETE, in which case no need to submit tasks
+    // However if the complete does *not* evaluate it should *NOT* hold the node.
+    if (evaluateComplete()) {
+        if (completeAst()) {
+
+            flag().set(ecf::Flag::BYRULE);
+
+            // If we are a parent sets the state first. then set state on all the children
+            set_state_hierarchically(NState::COMPLETE,
+                                     false); // reset try no and decrement inlimit resources & update repeats
+
+#ifdef DEBUG_DEPENDENCIES
+            LOG(Log::DBG,
+                "   Node::resolveDependencies() " << absNodePath() << " HOLDING since evaluation of COMPLETE");
+#endif
+            // We have a complete By returning false here, we stop dependency evaluation for any children
+            return false;
+        }
+    }
+    // No complete, or we have a complete  that does not evaluate.(this should not hold the node)
+
+    if (evaluateTrigger()) {
+        // WE only get here **IF** :
+        // 1/ There is no trigger
+        // 2/ WE have a trigger, and it evaluates to true
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG, "   Node::resolveDependencies() " << absNodePath() << " FREE of TRIGGER");
+#endif
+        return true;
+    }
+
+    // We *have* a trigger, and it does not evaluate, hold the node
+#ifdef DEBUG_DEPENDENCIES
+    LOG(Log::DBG, "   Node::resolveDependencies() " << absNodePath() << " HOLDING due to TRIGGER");
+#endif
+    return false;
+}
+
+bool Node::has_time_based_attributes() const {
+    if (has_time_dependencies())
+        return true;
+    if (auto_cancel_)
+        return true;
+    if (auto_archive_)
+        return true;
+    if (late_)
+        return true;
+    return false;
+}
+
+void Node::freeTrigger() const {
+    if (t_expr_)
+        t_expr_->setFree();
+}
+
+void Node::clearTrigger() const {
+    if (t_expr_)
+        t_expr_->clearFree();
+}
+
+void Node::freeComplete() const {
+    if (c_expr_)
+        c_expr_->setFree();
+}
+
+void Node::clearComplete() const {
+    if (c_expr_)
+        c_expr_->clearFree();
+}
+
+bool Node::evaluateComplete() const {
+    // Complete *MUST* be evaluated before trigger. As it can affect the other
+    AstTop* theCompeteAst = completeAst();
+    if (theCompeteAst) {
+        // *NOTE* if we have a non-NULL complete ast, we must have complete expression
+        // The freed state is stored on the expression ( i.e. not on the ast)
+        // ISSUE: Complete expression cannot be by-passed in the GUI
+        if (c_expr_->isFree() || theCompeteAst->evaluate()) {
+
+            // Note: if a task has been set complete, the use may decide to place into queued state( via GUI)
+            //       In which case, we *want* this complete expression to be re-evaluated.
+            //       Hence, the old code below has been commented out.
+            // >>old: Set the complete as free, until begin()/requeue, // Only update state change no, if state has
+            // changed.
+            // >>old:if (!c_expr_->isFree()) freeComplete();
+
+            // ECFLOW-247 Family goes complete despite active child
+            //            Typically we have a complete expression on the family i/e f1/t1 == complete
+            //            However if we have another child that is active,submitted forcing family to complete will
+            //            cause zombies Another child could be a family which could be aborted.
+            // if computedState state is:
+            //    NState::ABORTED   -> don't complete if any of the children are aborted  -> ECFLOW-247
+            //                         This can hide active/submitted nodes, as abort has higher priority, could cause
+            //                         zombies
+            //    NState::ACTIVE    -> can cause zombies
+            //    NState::SUBMITTED -> can cause zombies
+            // hence only allow complete is we are in a NState::QUEUED state
+            NState::State theComputedState = computedState(Node::HIERARCHICAL);
+            if (theComputedState != NState::QUEUED) {
+#ifdef DEBUG_DEPENDENCIES
+                LOG(Log::DBG,
+                    "   Node::evaluateComplete() " << absNodePath() << " AST evaluation succeeded *BUT* " << debugType()
+                                                   << " has children in ACTIVE or SUBMITTED States");
+#endif
+                return false;
+            }
+
+#ifdef DEBUG_DEPENDENCIES
+            LOG(Log::DBG,
+                "   Node::evaluateComplete() " << debugNodePath() << " FREE, COMPLETE AST evaluation succeeded ");
+#endif
+            return true;
+        }
+        else {
+            /// *IMPORTANT* When a complete does not evaluate, it should *NOT* stop further tree walking
+#ifdef DEBUG_DEPENDENCIES
+            LOG(Log::DBG,
+                "   Node::evaluateComplete() " << debugNodePath() << " HOLDING, COMPLETE AST evaluation failed");
+#endif
+            return false;
+        }
+    }
+    return true;
+}
+
+bool Node::evaluateTrigger() const {
+    AstTop* theTriggerAst = triggerAst();
+    if (theTriggerAst) {
+
+        // Note 1: A trigger can be freed by the ForceCmd
+        // Note 2: if we have a non-NULL trigger ast, we must have trigger expression
+        // Note 3: The freed state is stored on the expression ( i.e. *NOT* on the ast (abstract syntax tree) )
+        if (t_expr_->isFree() || theTriggerAst->evaluate()) {
+
+            // *ALWAYS* evaluate trigger expression unless user has forcibly removed trigger dependencies
+            // ******** This allows force queued functionality, to work as expected, since trigger's will be honoured
+            // The old code below has been commented out.
+            // >> old: Set the trigger as free, until begin()/requeue.  Only update state change no, when required
+            // >> old: if (!t_expr_->isFree()) freeTrigger();
+
+#ifdef DEBUG_DEPENDENCIES
+            LOG(Log::DBG,
+                "   Node::evaluateTrigger() " << debugNodePath() << " FREE, TRIGGER AST evaluation succeeded");
+#endif
+            return true;
+        }
+
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG, "   Node::evaluateTrigger() " << debugNodePath() << " HOLDING  TRIGGER AST evaluation failed");
+#endif
+        return false; // evaluation failed. this Node holds
+    }
+
+#ifdef DEBUG_DEPENDENCIES
+    LOG(Log::DBG, "   Node::evaluateTrigger() " << debugNodePath() << " FREE NO TRIGGER defined");
+#endif
+    return true;
+}
+
+const std::string& Node::abortedReason() const {
+    return Str::EMPTY();
+}
+
+void Node::set_state(NState::State newState, bool force, const std::string& additional_info_to_log) {
+    if (st_.first.state() != newState) {
+
+        setStateOnly(newState, false, additional_info_to_log);
+
+        // Handle any state change specific functionality. This will update any repeats
+        // This is a virtual function, since we want different behaviour during state change
+        handleStateChange();
+    }
+}
+
+void Node::handleStateChange() {
+    if (state() == NState::COMPLETE) {
+        if (auto_restore_)
+            auto_restore_->do_autorestore();
+
+        Node* the_parent = parent();
+        while (the_parent) {
+            if (the_parent->state() == NState::COMPLETE && the_parent->get_autorestore()) {
+                the_parent->get_autorestore()->do_autorestore();
+            }
+            the_parent = the_parent->parent();
+        }
+    }
+}
+
+void Node::setStateOnly(NState::State newState,
+                        bool force,
+                        const std::string& additional_info_to_log,
+                        bool do_log_state_changes) {
+    if (st_.first.state() == newState) {
+        return; // if old and new state the same don't do anything
+    }
+
+    Suite* theSuite          = suite();
+    const Calendar& calendar = theSuite->calendar();
+
+#ifdef DEBUG_JOB_SUBMISSION_INTERVAL
+    // check sub submission interval/calendar increment for tasks only
+    // The job submission interval is set/obtained from the server environment and
+    // is configurable for testing.
+    // **** This is only used when jobSubmissionInterval is less than 60 ****
+    // We are attempting to refine job submission interval such that it is just
+    // greater than time taken for state change from submit->active->complete
+    // There by speeding up the test where we generate .ecf
+
+    // Ignore this during simulation, ie defs()->server().jobSubmissionInterval() = 0; for simulation
+    int jobSubmissionInterval = theSuite->defs()->server().jobSubmissionInterval();
+    if (isSubmittable() && jobSubmissionInterval != 0 && jobSubmissionInterval < 60) {
+
+        if (newState == NState::SUBMITTED)
+            submit_to_complete_duration_ = Calendar::second_clock_time();
+        else if (newState == NState::COMPLETE && !submit_to_complete_duration_.is_special()) {
+
+            // Under HYBRID we can go from UNKNOWN->COMPLETE, missing out SUBMITTED
+            // hence: submit_to_complete_duration_ is never initialised
+            // ie when we have a,date,cron dependency that relies on a day change
+
+            time_duration td = (Calendar::second_clock_time() - submit_to_complete_duration_);
+            // cout << debugNodePath() << " submit->active->complete time = " << td.total_seconds()  << " seconds.\n";
+
+            // Avoid this check if we have meters. as we wait a second between each meter update
+            if (td.total_seconds() >= jobSubmissionInterval && meters_.empty()) {
+
+                const Variable& do_check = theSuite->findVariable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL");
+                if (!do_check.empty()) {
+                    // 				cout << "Calendar::second_clock_time() = " <<
+                    // to_simple_string(Calendar::second_clock_time())
+                    // << "\n"; 				cout << "submit_to_complete_duration_ = " <<
+                    // to_simple_string(submit_to_complete_duration_) << "\n"; 				cout <<
+                    // "(Calendar::second_clock_time() - submit_to_complete_duration_) = " << to_simple_string(td) <<
+                    // "\n";
+                    cout << "Testing::" << debugNodePath() << " For each job submission interval of "
+                         << jobSubmissionInterval << " seconds, the calendar is increment by 60 seconds.\n"
+                         << " The job submission interval is too small as it takes " << td.total_seconds()
+                         << " seconds for state change of submit->active->complete, for an empty job.\n"
+                         << " Please increase the job submission interval to at least " << (td.total_seconds() + 1)
+                         << " seconds.\n";
+                }
+            }
+        }
+    }
+#endif
+
+    // Change format is significant it is used in verification of log files
+    // Please change/update LogVerification::extractNodePathAndState() all verification relies on this one function
+    //           " " +  submitted(max) + ": " + path(estimate)  + " try-no: " + try_no(estimate)  + " reason: " +
+    //           reason(estimate)
+    // reserve : 1   +  9              + 2    + 100             + 9           + 3                 + 9           + 12   =
+    // 145
+    std::string log_state_change;
+    if (do_log_state_changes) {
+        log_state_change.reserve(145 + additional_info_to_log.size());
+        log_state_change += " ";
+        log_state_change += NState::toString(newState);
+        log_state_change += ": ";
+        log_state_change += absNodePath();
+        if (!additional_info_to_log.empty()) {
+            log_state_change += " ";
+            log_state_change += additional_info_to_log;
+        }
+    }
+
+    if (newState == NState::ABORTED) {
+        if (force)
+            flag().set(ecf::Flag::FORCE_ABORT);
+        Submittable* submittable = isSubmittable();
+        if (submittable) {
+            flag().set(ecf::Flag::TASK_ABORTED);
+            if (do_log_state_changes) {
+                log_state_change += " try-no: ";
+                log_state_change += submittable->tryNo();
+                log_state_change += " reason: ";
+                log_state_change += abortedReason();
+            }
+        }
+    }
+    else {
+        flag().clear(ecf::Flag::TASK_ABORTED);
+        flag().clear(ecf::Flag::FORCE_ABORT);
+    }
+
+    if (do_log_state_changes) {
+        // SUP-408 what does submitted mean in log?
+        // We want to minimize the calls to create a new time stamp in the log file.
+        // A time stamp is automatically created, whenever a *new* client request is received, & then cached
+        // However we can get a change in state, during tree traversal, when a node is free of its dependencies
+        // If we were to just log the message it would use the last cached time stamp. Giving misleading info:
+        // Since state changes are bubbled up, we need only update the time stamp for tasks, when not in a command
+        if (!CmdContext::in_command() && isTask() && Log::instance()) {
+            // std::cout << "!!!!! NOT in cmd context updating time stamp before logging\n";
+            Log::instance()->cache_time_stamp();
+        }
+        ecf::log(Log::LOG, log_state_change); // Note: log type, must be same for debug & release for test, i.e. for log
+                                              // file verification
+    }
+
+    st_.first.setState(newState); // this will update state_change_no
+    if (newState == NState::QUEUED)
+        sc_rt_ = boost::posix_time::time_duration(0, 0, 0, 0);
+    else
+        sc_rt_ = calendar.duration() - st_.second;
+    st_.second = calendar.duration(); // record state change duration for late, autocancel,autoarchive,etc
+
+    // Record state changes for verification
+    if (misc_attrs_) {
+        for (auto& verify : misc_attrs_->verifys_) {
+            if (verify.state() == newState) {
+                verify.incrementActual();
+            }
+        }
+    }
+}
+
+boost::posix_time::ptime Node::state_change_time() const {
+    const Calendar& calendar                       = suite()->calendar();
+    boost::posix_time::ptime the_state_change_time = calendar.begin_time();
+    the_state_change_time += st_.second; // st_.second is calendar duration relative to calendar begin_time
+    return the_state_change_time;
+}
+
+DState::State Node::dstate() const {
+
+    // ECFLOW-139, check for suspended must be done first
+    if (isSuspended())
+        return DState::SUSPENDED;
+
+    switch (state()) {
+        case NState::COMPLETE:
+            return DState::COMPLETE;
+            break;
+        case NState::ABORTED:
+            return DState::ABORTED;
+            break;
+        case NState::ACTIVE:
+            return DState::ACTIVE;
+            break;
+        case NState::SUBMITTED:
+            return DState::SUBMITTED;
+            break;
+        case NState::QUEUED:
+            return DState::QUEUED;
+            break;
+        case NState::UNKNOWN:
+            return DState::UNKNOWN;
+            break;
+    }
+    return DState::UNKNOWN;
+}
+
+bool Node::set_event(const std::string& event_name_or_number) {
+    auto found = ecf::algorithm::find_by(
+        events_, [&](const auto& item) { return item.name_or_number() == event_name_or_number; });
+
+    if (found == std::end(events_)) {
+        return false;
+    }
+
+    found->set_value(true);
+    return true;
+}
+
+bool Node::clear_event(const std::string& event_name_or_number) {
+    auto found = ecf::algorithm::find_by(
+        events_, [&](const auto& item) { return item.name_or_number() == event_name_or_number; });
+
+    if (found == std::end(events_)) {
+        return false;
+    }
+
+    found->set_value(false);
+    return true;
+}
+
+void Node::setRepeatToLastValue() {
+    repeat_.setToLastValue(); // no op for empty repeat
+    repeat_.increment();      // make repeat invalid
+}
+
+bool Node::check_in_limit_up_node_tree() const {
+    if (!inLimitMgr_.inLimit())
+        return false;
+
+    Node* theParent = parent();
+    while (theParent) {
+        if (!theParent->inLimitMgr_.inLimit())
+            return false;
+        theParent = theParent->parent();
+    }
+    return true;
+}
+
+void Node::incrementInLimit(std::set<Limit*>& limitSet) {
+    // cout << "Node::incrementInLimit " << absNodePath() << endl;
+    std::string the_abs_node_path = absNodePath();
+    inLimitMgr_.incrementInLimit(limitSet, the_abs_node_path);
+
+    Node* theParent = parent();
+    while (theParent) {
+        theParent->inLimitMgr_.incrementInLimit(limitSet, the_abs_node_path);
+        theParent = theParent->parent();
+    }
+}
+
+void Node::decrementInLimit(std::set<Limit*>& limitSet) {
+    // cout << "Node::decrementInLimit " << absNodePath() << endl;
+    std::string the_abs_node_path = absNodePath();
+    inLimitMgr_.decrementInLimit(limitSet, the_abs_node_path);
+
+    Node* theParent = parent();
+    while (theParent) {
+        theParent->inLimitMgr_.decrementInLimit(limitSet, the_abs_node_path);
+        theParent = theParent->parent();
+    }
+}
+
+void Node::decrementInLimitForSubmission(std::set<Limit*>& limitSet) {
+    // cout << "Node::decrementInLimit " << absNodePath() << endl;
+    std::string the_abs_node_path = absNodePath();
+    inLimitMgr_.decrementInLimitForSubmission(limitSet, the_abs_node_path);
+
+    Node* theParent = parent();
+    while (theParent) {
+        theParent->inLimitMgr_.decrementInLimitForSubmission(limitSet, the_abs_node_path);
+        theParent = theParent->parent();
+    }
+}
+
+static bool
+search_user_edit_variables(const std::string& name, std::string& value, const NameValueMap& user_edit_variables) {
+    auto i = user_edit_variables.find(name);
+    if (i != user_edit_variables.end()) {
+        if (((*i).second).empty()) {
+            // when we call --edit_script submit file, before a job is submitted the values
+            // of generated variables like  ECF_RID, ECF_TRYNO, ECF_NAME, ECF_PASS, ECF_JOB, ECF_JOBOUT, ECF_SCRIPT
+            // will be empty. In this case return false, so that we pick up the values from the node.
+            return false;
+        }
+        value = (*i).second;
+        return true;
+    }
+    return false;
+}
+
+// #define DEBUG_S 1
+bool Node::variableSubstitution(std::string& cmd) const {
+    char micro = '%';
+    std::string micro_char;
+    findParentUserVariableValue(Str::ECF_MICRO(), micro_char);
+    if (!micro_char.empty() && micro_char.size() == 1) {
+        micro = micro_char[0];
+    }
+
+    NameValueMap user_edit_variables;
+    return variable_substitution(cmd, user_edit_variables, micro);
+}
+
+bool Node::variable_substitution(std::string& cmd, const NameValueMap& user_edit_variables, char micro) const {
+    // scan the command for variables, and substitute
+    // edit cmd "/home/ma/map/sms/smsfectch -F %ECF_FILES% -I %ECF_INCLUDE%"
+    // We can also have
+    //
+    // "%<VAR>:<substitute>% i.e. if VAR exist use it, else use substitute
+    //
+    // ************************************************************************************************************
+    // Special case handling for user variables, and generated variables, which take precedence over node variables
+    // ************************************************************************************************************
+    //
+    // i.e. VAR is defined as BILL
+    //  %VAR:fred --f%  will either be "BILL" or if VAR is not defined "fred --f"
+    //
+    // Infinite recursion. It is possible to end up with infinite recursion:
+    //   	edit hello '%hello%'  # string like %hello% will cause infinite recursion
+    //   	edit fred '%bill%'
+    //	 	edit bill '%fred%'   # should be 10
+    // To prevent this we will use a simple count
+#ifdef DEBUG_S
+    cout << "cmd  = " << cmd << "\n";
+#endif
+    bool double_micro_found    = false;
+    std::string::size_type pos = 0;
+    int count                  = 0;
+    Alias* is_a_alias          = isAlias();
+    while (true) {
+        // A while loop here is used to:
+        //   a/ Allow for multiple substitution on a single line. i.e. `%ECF_FILES% -I %ECF_INCLUDE%`
+        //   b/ Allow for recursive substitution. %fred% -> %bill% -> 10
+
+        size_t firstPercentPos = cmd.find(micro, pos);
+        if (firstPercentPos == string::npos)
+            break;
+
+        size_t secondPercentPos = cmd.find(micro, firstPercentPos + 1);
+        if (secondPercentPos == string::npos)
+            break;
+
+        pos = 0;
+        if (secondPercentPos - firstPercentPos <= 1) {
+            // handle %% with no characters in between, skip over
+            // i.e. to handle "printf %%02d %HOUR:00%" --> "printf %02d 00" i.e. if HOUR not defined
+            pos                = secondPercentPos + 1;
+            double_micro_found = true;
+            continue;
+        }
+
+        string percentVar(cmd.begin() + firstPercentPos + 1, cmd.begin() + secondPercentPos);
+        // cout << percentVar << "\n";
+#ifdef DEBUG_S
+        cout << "   Found percentVar " << percentVar << "\n";
+#endif
+
+        // ****************************************************************************************
+        // Look for generated variables that should NOT be overridden first:
+        //    Variable like ECF_PASS can be overridden, i.e. with FREE_JOBS_PASSWORD
+        //    However for job file generation we should use the generated variables first.
+        //    if the user removes ECF_PASS then we are stuck with the wrong value in the script file
+        //    FREE_JOBS_PASSWORD is left for the server to deal with
+        // Leave ECF_JOB and ECF_JOBOUT out of this list: As user may legitimately override these. ECFLOW-999
+        bool generated_variable = false;
+        if (percentVar.find("ECF_") == 0) {
+            if (percentVar.find(Str::ECF_HOST()) != std::string::npos)
+                generated_variable = true;
+            else if (percentVar.find(Str::ECF_PORT()) != std::string::npos)
+                generated_variable = true;
+            else if (percentVar.find(Str::ECF_TRYNO()) != std::string::npos)
+                generated_variable = true;
+            else if (percentVar.find(Str::ECF_NAME()) != std::string::npos)
+                generated_variable = true;
+            else if (percentVar.find(Str::ECF_PASS()) != std::string::npos)
+                generated_variable = true;
+        }
+
+        size_t firstColon = percentVar.find(':');
+
+        // First search user variable (*ONLY* set user edit's the script)
+        // Handle case: cmd = "%fred:bill% and where we have user variable "fred:bill"
+        // Handle case: cmd = "%fred%      and where we have user variable "fred"
+        // If we fail to find the variable we return false.
+        // Note: When a variable is found, it can have an empty value  which is still valid
+        std::string varValue;
+        if (!user_edit_variables.empty() && search_user_edit_variables(percentVar, varValue, user_edit_variables)) {
+            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+        }
+        else if (generated_variable && firstColon == string::npos &&
+                 find_parent_gen_variable_value(percentVar, varValue)) {
+            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+        }
+        else {
+            if (firstColon != string::npos) {
+
+                if (is_a_alias && findParentVariableValue(percentVar, varValue)) {
+                    // For alias, we could have added variables with %A:0%, %A:1%.
+                    // Aliases allow variables with ':' in the name.
+                    cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+                }
+                else {
+                    // ':' is not a valid in variables, hence split, and search, if search fails use replacement
+                    string var(percentVar.begin(), percentVar.begin() + firstColon);
+#ifdef DEBUG_S
+                    cout << "   var " << var << "\n";
+#endif
+                    if (!user_edit_variables.empty() &&
+                        search_user_edit_variables(var, varValue, user_edit_variables)) {
+#ifdef DEBUG_S
+                        cout << "   user var value = " << varValue << "\n";
+#endif
+                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+                    }
+                    else if (generated_variable && find_parent_gen_variable_value(var, varValue)) {
+#ifdef DEBUG_S
+                        cout << "   generated var value = " << varValue << "\n";
+#endif
+                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+                    }
+                    else if (findParentVariableValue(var, varValue)) {
+                        // Note: variable can exist, but have an empty value
+#ifdef DEBUG_S
+                        cout << "   var value = " << varValue << "\n";
+#endif
+                        // replace the "%VAR:fred --f%" with var
+                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+                    }
+                    else {
+                        string substitute(percentVar.begin() + firstColon + 1, percentVar.end());
+#ifdef DEBUG_S
+                        cout << "  substitute value = " << substitute << "\n";
+#endif
+                        cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, substitute);
+                    }
+#ifdef DEBUG_S
+                    cout << "   cmd = " << cmd << "\n";
+#endif
+                }
+            }
+            else if (findParentVariableValue(percentVar, varValue)) {
+                // No ':' search user variables, repeat, and then generated variables.
+                cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+            }
+            else {
+                // Can't find in user variables, or node variable, hence can't go any further
+                return false;
+            }
+        }
+
+        // Simple Check for infinite recursion
+        if (count > 1000)
+            return false;
+        count++;
+    }
+
+    if (double_micro_found) {
+        // replace all double micro with a single micro, this must be a single parse
+        // date +%%Y%%m%%d" ==> date +%Y%m%d
+        // %%%%             ==> %%            // i.e. single parse
+        std::string doubleEcfMicro;
+        doubleEcfMicro += micro;
+        doubleEcfMicro += micro;
+        size_t last_pos = 0;
+        while (true) {
+            string::size_type ecf_double_micro_pos = cmd.find(doubleEcfMicro, last_pos);
+            if (ecf_double_micro_pos != std::string::npos) {
+                cmd.erase(cmd.begin() + ecf_double_micro_pos);
+                last_pos = ecf_double_micro_pos + 1;
+            }
+            else
+                break;
+        }
+    }
+
+    return true;
+}
+
+bool Node::find_all_used_variables(std::string& cmd, NameValueMap& used_variables, char micro) const {
+#ifdef DEBUG_S
+    cout << "cmd  = " << cmd << "\n";
+#endif
+    int count = 0;
+    while (true) {
+        // A while loop here is used to:
+        //   a/ Allow for multiple substitution on a single line. i.e. `%ECF_FILES% -I %ECF_INCLUDE%`
+        //   b/ Allow for recursive substitution. %fred% -> %bill% -> 10
+
+        size_t firstPercentPos = cmd.find(micro);
+        if (firstPercentPos == string::npos)
+            break;
+        size_t secondPercentPos = cmd.find(micro, firstPercentPos + 1);
+        if (secondPercentPos == string::npos)
+            break;
+        if (secondPercentPos - firstPercentPos <= 1)
+            break; // handle %% with no characters in between
+
+        string percentVar(cmd.begin() + firstPercentPos + 1, cmd.begin() + secondPercentPos);
+#ifdef DEBUG_S
+        cout << "   Found percentVar " << percentVar << "\n";
+#endif
+
+        size_t firstColon = percentVar.find(':');
+        if (firstColon != string::npos) {
+
+            string var(percentVar.begin(), percentVar.begin() + firstColon);
+#ifdef DEBUG_S
+            cout << "   var " << var << "\n";
+#endif
+
+            std::string varValue;
+            if (findParentVariableValue(var, varValue)) {
+                // Note: variable can exist, but have an empty value
+#ifdef DEBUG_S
+                cout << "   var value = " << theFoundVariable.value() << "\n";
+#endif
+                // %VAR:fred% --->  name("VAR:fred") value(theFoundVariable.value())
+                used_variables.insert(std::make_pair(percentVar, varValue));
+
+                // replace the "%VAR:fred --f%" with variable value, so that we don't process it again
+                cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+            }
+            else {
+                string substitute(percentVar.begin() + firstColon + 1, percentVar.end());
+#ifdef DEBUG_S
+                cout << "  substitute value = " << substitute << "\n";
+#endif
+
+                // %VAR:fred% --->  name("VAR:fred") value(fred)
+                used_variables.insert(std::make_pair(percentVar, substitute));
+
+                cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, substitute);
+            }
+#ifdef DEBUG_S
+            cout << "   cmd = " << cmd << "\n";
+#endif
+        }
+        else {
+
+            // If we fail to find the variable we return false.
+            // Note: When a variable is found, it can have an empty value
+            //       which is still valid
+            std::string varValue;
+            if (!findParentVariableValue(percentVar, varValue))
+                return false;
+
+            used_variables.insert(std::make_pair(percentVar, varValue));
+            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+        }
+
+        // Simple Check for infinite recursion
+        if (count > 100)
+            return false;
+        count++;
+    }
+    return true;
+}
+
+bool Node::variable_dollar_substitution(std::string& cmd) const {
+    // scan command for environment variables, and substitute
+    // edit ECF_INCLUDE $ECF_HOME/include
+
+    while (true) {
+        size_t firstPos = cmd.find('$');
+        if (firstPos == string::npos)
+            break;
+
+        size_t secondPos = cmd.find_first_not_of(Str::ALPHANUMERIC_UNDERSCORE(), firstPos + 1);
+        if (secondPos == string::npos)
+            secondPos = cmd.size();
+        if (secondPos - firstPos <= 1)
+            break; // handle $/ with no characters in between
+
+        string env(cmd.begin() + firstPos + 1, cmd.begin() + secondPos);
+        // cout << "find env " << env << "\n";
+
+        std::string envValue;
+        if (!findParentVariableValue(env, envValue)) {
+            // cout << " could not find " << env << "\n";
+            return false;
+        }
+
+        cmd.replace(firstPos, secondPos - firstPos, envValue);
+
+        if (envValue.find(env) != std::string::npos) {
+            // infinite loop
+            break;
+        }
+    }
+    return true;
+}
+
+std::string Node::completeExpression() const {
+    if (c_expr_) {
+        string ret = "complete ";
+        ret += c_expr_->expression();
+        return ret;
+    }
+    return string();
+}
+
+std::string Node::triggerExpression() const {
+    if (t_expr_) {
+        string ret = "trigger ";
+        ret += t_expr_->expression();
+        return ret;
+    }
+    return string();
+}
+
+bool Node::check_expressions(Ast* ast, const std::string& expr, bool trigger, std::string& errorMsg) const {
+    if (ast) {
+        // The expression has been parsed, and we have created the abstract syntax tree.
+        // We now try to resolve the path/node references in the expressions.
+        // And, also, resolve references to events, meter, repeats and variables.
+        AstResolveVisitor astVisitor(this);
+        ast->accept(astVisitor);
+        if (!astVisitor.errorMsg().empty()) {
+            errorMsg += "Error: Expression node tree references failed for '";
+            if (trigger)
+                errorMsg += "trigger ";
+            else
+                errorMsg += "complete ";
+            errorMsg += expr;
+            errorMsg += "' at ";
+            errorMsg += debugNodePath();
+            errorMsg += "\n ";
+            errorMsg += astVisitor.errorMsg();
+            return false;
+        }
+
+        // check divide by zero and module by zero
+        if (!ast->check(errorMsg)) {
+            errorMsg += " Error: Expression checking failed for '";
+            if (trigger)
+                errorMsg += "trigger ";
+            else
+                errorMsg += "complete ";
+            errorMsg += expr;
+            errorMsg += "' at ";
+            errorMsg += debugNodePath();
+            return false;
+        }
+    }
+    return true;
+}
+
+std::unique_ptr<AstTop>
+Node::parse_and_check_expressions(const std::string& expr, bool trigger, const std::string& context) {
+    std::unique_ptr<AstTop> ast = Expression::parse(expr, context); // will throw for errors
+
+    std::string errorMsg;
+    if (!check_expressions(ast.get(), expr, trigger, errorMsg)) {
+        std::stringstream ss;
+        ss << context << " " << errorMsg;
+        throw std::runtime_error(ss.str());
+    }
+    return ast;
+}
+
+bool Node::check(std::string& errorMsg, std::string& warningMsg) const {
+    // #ifdef DEBUG
+    //  	cout << "Node::check " << debugNodePath() << " complete and trigger\n";
+    // #endif
+
+    /// ************************************************************************************
+    /// *IMPORTANT side effect: *
+    /// The simulator relies AstResolveVisitor to set usedInTrigger() for events and meters
+    /// *************************************************************************************
+
+    /// Make Sure: To sure capture parser errors:
+    /// defs which fail parse errors should not be allowed to be loaded into the server
+    /// Even if the code parses, check the expression for divide by zero, for divide and modulo operators
+    AstTop* ctop = completeAst(errorMsg);
+    if (ctop) {
+        // capture node path resolve errors, and expression divide/module by zero
+        std::string expr;
+        if (c_expr_)
+            expr = c_expr_->expression();
+        (void)check_expressions(ctop, expr, false, errorMsg);
+    }
+
+    AstTop* ttop = triggerAst(errorMsg);
+    if (ttop) {
+        std::string expr;
+        if (t_expr_)
+            expr = t_expr_->expression();
+        (void)check_expressions(ttop, expr, true, errorMsg);
+    }
+
+    // check inLimit references to limits.
+    // Client: Unresolved references, which are not in the externs reported as errors/warnings
+    // Server: There are no externs, all unresolved references reported as errors
+    bool reportErrors   = true;
+    bool reportWarnings = true;
+    inLimitMgr_.check(errorMsg, warningMsg, reportErrors, reportWarnings);
+
+    /// Check that the references to nodes in autorestore resolve
+    if (auto_restore_)
+        auto_restore_->check(errorMsg);
+
+    return errorMsg.empty();
+}
+
+void Node::add_comment_char(std::string& ret, bool& added_comment_char) const {
+    if (!added_comment_char) {
+        ret += " #";
+        added_comment_char = true;
+    }
+}
+
+void Node::write_state(std::string& ret, bool& added_comment_char) const {
+    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e. `task a; task b;`
+    // If attribute correspond to the defaults don't write then out
+    if (state() != NState::UNKNOWN) {
+        add_comment_char(ret, added_comment_char);
+        ret += " state:";
+        ret += NState::toString(state());
+    }
+    if (st_.second.total_seconds() != 0) {
+        add_comment_char(ret, added_comment_char);
+        ret += " dur:";
+        ret += to_simple_string(st_.second);
+    }
+    if (flag_.flag() != 0) {
+        add_comment_char(ret, added_comment_char);
+        ret += " flag:";
+        flag_.write(ret);
+    }
+    if (suspended_) {
+        add_comment_char(ret, added_comment_char);
+        ret += " suspended:1";
+    }
+    if (!sc_rt_.is_special() && (sc_rt_.hours() != 0 || sc_rt_.minutes() != 0 || sc_rt_.seconds() != 0)) {
+        add_comment_char(ret, added_comment_char);
+        ret += " rt:";
+        ret += to_simple_string(sc_rt_);
+    }
+}
+
+void Node::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
+    //  0    1   2
+    // task name #
+    std::string token;
+    size_t line_tokens_size = lineTokens.size();
+    for (size_t i = 3; i < line_tokens_size; i++) {
+        token.clear();
+        const std::string& line_token_i = lineTokens[i];
+        if (line_token_i.find("state:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Node::read_state Invalid state specified for node " + name());
+            std::pair<NState::State, bool> state_pair = NState::to_state(token);
+            if (!state_pair.second)
+                throw std::runtime_error("Node::read_state Invalid state specified for node : " + name());
+            set_state_only(state_pair.first);
+        }
+        else if (line_token_i.find("flag:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Node::read_state invalid flags for node " + name());
+            flag().set_flag(token); // this can throw
+        }
+        else if (line_token_i.find("dur:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Node::read_state invalid duration for node: " + name());
+            st_.second = duration_from_string(token);
+        }
+        else if (line_token_i.find("rt:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, token))
+                throw std::runtime_error("Node::read_state invalid runtime duration for node: " + name());
+            sc_rt_ = duration_from_string(token);
+        }
+        else if (line_token_i == "suspended:1")
+            suspend();
+    }
+}
+
+std::string Node::print() const {
+    std::string s;
+    print(s);
+    return s;
+}
+
+void Node::print(std::string& os) const {
+    if (d_st_ != DState::default_state()) {
+        Indentor in;
+        Indentor::indent(os);
+        os += "defstatus ";
+        os += DState::toString(d_st_);
+        os += "\n";
+    }
+
+    if (late_)
+        late_->print(os);
+
+    if (c_expr_) {
+        c_expr_->print(os, "complete");
+        if (PrintStyle::getStyle() == PrintStyle::STATE) {
+            Indentor in;
+            if (c_expr_->isFree()) {
+                Indentor::indent(os);
+                os += "# (free)\n";
+            }
+            if (completeAst()) {
+                if (!defs()) {
+                    // Full defs is required for extern checking, and finding absolute node paths
+                    // Hence print will with no defs can give in-accurate information
+                    Indentor in2;
+                    Indentor::indent(os);
+                    os += "# Warning: Full/correct AST evaluation requires the definition\n";
+                }
+                std::stringstream ss;
+                completeAst()->print(ss);
+                os += ss.str();
+            }
+        }
+    }
+    if (t_expr_) {
+        t_expr_->print(os, "trigger");
+        if (PrintStyle::getStyle() == PrintStyle::STATE) {
+            Indentor in;
+            if (t_expr_->isFree()) {
+                Indentor::indent(os);
+                os += "# (free)\n";
+            }
+            if (triggerAst()) {
+                if (!defs()) {
+                    Indentor in2;
+                    Indentor::indent(os);
+                    os += "# Warning: Full/correct AST evaluation requires the definition\n";
+                }
+                std::stringstream ss;
+                triggerAst()->print(ss);
+                os += ss.str();
+            }
+        }
+    }
+    repeat_.print(os); // if repeat is empty print(..) does nothing
+
+    for (const Variable& v : vars_) {
+        v.print(os);
+    }
+
+    if (PrintStyle::getStyle() == PrintStyle::STATE) {
+        // Distinguish normal variable from generated, by adding a #
+        // This also allows it to be read in again and compared in the AParser/tests
+        std::vector<Variable> gvec;
+        gen_variables(gvec);
+        for (const Variable& v : gvec) {
+            v.print_generated(os);
+        }
+    }
+
+    for (limit_ptr l : limits_) {
+        l->print(os);
+    }
+    inLimitMgr_.print(os);
+
+    for (const Label& la : labels_) {
+        la.print(os);
+    }
+    for (const Meter& m : meters_) {
+        m.print(os);
+    }
+    for (const Event& e : events_) {
+        e.print(os);
+    }
+
+    for (const ecf::TimeAttr& t : times_) {
+        t.print(os);
+    }
+    for (const ecf::TodayAttr& t : todays_) {
+        t.print(os);
+    }
+    for (const DateAttr& date : dates_) {
+        date.print(os);
+    }
+    for (const DayAttr& day : days_) {
+        day.print(os);
+    }
+    for (const CronAttr& cron : crons_) {
+        cron.print(os);
+    }
+    for (const AvisoAttr& a : avisos_) {
+        ecf::format_as_defs(a, os);
+    }
+    for (const MirrorAttr& m : mirrors_) {
+        ecf::format_as_defs(m, os);
+    }
+
+    if (auto_cancel_)
+        auto_cancel_->print(os);
+    if (auto_archive_)
+        auto_archive_->print(os);
+    if (auto_restore_)
+        auto_restore_->print(os);
+
+    if (misc_attrs_)
+        misc_attrs_->print(os);
+}
+
+std::string Node::print(PrintStyle::Type_t p_style) const {
+    PrintStyle print_style(p_style);
+    return to_string();
+}
+
+std::string Node::to_string() const {
+    std::string ss;
+    print(ss);
+    return ss;
+}
+
+bool Node::operator==(const Node& rhs) const {
+    if (n_ != rhs.n_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==( n_(" << n_ << ") != rhs.n_(" << rhs.n_ << ")) for: " << debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (state() != rhs.state()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  state(" << NState::toString(state()) << ") != rhs.state("
+                      << NState::toString(rhs.state()) << ")) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (d_st_ != rhs.d_st_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  ( d_st_ != rhs.d_st_) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (suspended_ != rhs.suspended_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator== suspended_ != rhs.suspended_ " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (flag_ != rhs.flag_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator== ( flag_ != rhs.flag_) : '" << flag_.to_string() << "' != '"
+                      << rhs.flag_.to_string() << "' : " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if ((t_expr_ && !rhs.t_expr_) || (!t_expr_ && rhs.t_expr_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (t_expr_ && !rhs.t_expr_) || (!t_expr_&& rhs.t_expr_)  " << debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (t_expr_ && rhs.t_expr_ && (*t_expr_ != *rhs.t_expr_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  t_expr_ && rhs.t_expr_ && (*t_expr_ != *rhs.t_expr_) " << debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if ((c_expr_ && !rhs.c_expr_) || (!c_expr_ && rhs.c_expr_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (c_expr_ && !rhs.c_expr_) || (!c_expr_&& rhs.c_expr_)  " << debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (c_expr_ && rhs.c_expr_ && (*c_expr_ != *rhs.c_expr_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  c_expr_ && rhs.c_expr_ && (*c_expr_ != *rhs.c_expr_) " << debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (vars_.size() != rhs.vars_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (vars_.size() != rhs.vars_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < vars_.size(); ++i) {
+        if (!(vars_[i] == rhs.vars_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==  (!(vars_[i] == rhs.vars_[i] )) " << debugNodePath() << "\n";
+                std::cout << "     vars_[i] name = '" << vars_[i].name() << "' value = '" << vars_[i].theValue()
+                          << "'\n";
+                std::cout << " rhs.vars_[i] name = '" << rhs.vars_[i].name() << "' value = '" << rhs.vars_[i].theValue()
+                          << "'\n";
+            }
+#endif
+            return false;
+        }
+    }
+    // We don't compare `genvar` as this is only used in server environment
+
+    if (!(inLimitMgr_ == rhs.inLimitMgr_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (!(inLimitMgr == rhs.inLimitMgr)) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (limits_.size() != rhs.limits_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (limits_.size(" << limits_.size() << ") != rhs.limits_.size("
+                      << rhs.limits_.size() << ")) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < limits_.size(); ++i) {
+        if (!(*limits_[i] == *rhs.limits_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==  (!(*limits_[i] == *rhs.limits_[i] )) " << debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (times_.size() != rhs.times_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (times_.size() != rhs.times_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < times_.size(); ++i) {
+        if (!(times_[i] == rhs.times_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==  (!(times_[i] == rhs.times_[i] ))  " << debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (todays_.size() != rhs.todays_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (todays_.size() != rhs.todays_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < todays_.size(); ++i) {
+        if (!(todays_[i] == rhs.todays_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==  (!(todays_[i] == rhs.todays_[i] ))  " << debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (dates_.size() != rhs.dates_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==   (dates_.size() != rhs.dates_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < dates_.size(); ++i) {
+        if (!(dates_[i] == rhs.dates_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==   (!(dates_[i] == rhs.dates_[i]) " << debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (days_.size() != rhs.days_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==   (days_.size() != rhs.days_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < days_.size(); ++i) {
+        if (!(days_[i] == rhs.days_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==   (!(days_[i] == rhs.days_[i]) " << debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (crons_.size() != rhs.crons_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==   (crons_.size() != rhs.crons_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < crons_.size(); ++i) {
+        if (!(crons_[i] == rhs.crons_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==   (!(crons_[i] == rhs.crons_[i]) " << debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (labels_.size() != rhs.labels_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (labels_.size() != rhs.labels_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (unsigned i = 0; i < labels_.size(); ++i) {
+        if (labels_[i] != rhs.labels_[i]) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==  (labels_[i] != rhs.labels_[i]) " << debugNodePath() << "\n";
+                std::cout << "   lhs = " << labels_[i].dump() << "\n";
+                std::cout << "   rhs = " << rhs.labels_[i].dump() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if (meters_.size() != rhs.meters_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  (meters_.size() != rhs.meters_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (size_t i = 0; i < meters_.size(); ++i) {
+        if (!(meters_[i] == rhs.meters_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==   (!(meters_[i] == rhs.meters_[i] )) " << debugNodePath() << "\n";
+                std::cout << "   " << meters_[i].dump() << "\n";
+                std::cout << "   " << rhs.meters_[i].dump() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+    if (events_.size() != rhs.events_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==   (events_.size() != rhs.events_.size()) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    for (size_t i = 0; i < events_.size(); ++i) {
+        if (!(events_[i] == rhs.events_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Node::operator==   (!(events_[i] == rhs.events_[i] )) " << debugNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    if ((misc_attrs_ && !rhs.misc_attrs_) || (!misc_attrs_ && rhs.misc_attrs_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator== (( misc_attrs_ && !rhs.misc_attrs_) || ( !misc_attrs_ && rhs.misc_attrs_)) "
+                      << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (misc_attrs_ && rhs.misc_attrs_ && !(*misc_attrs_ == *rhs.misc_attrs_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator== ( misc_attrs_ && rhs.misc_attrs_ && !(*misc_attrs_ == *(rhs.misc_attrs_))) "
+                      << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (!(repeat_ == rhs.repeat_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==   if (!(repeat_ == rhs.repeat_)) " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if ((late_ && !rhs.late_) || (!late_ && rhs.late_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator== (( late_ && !rhs.late_) || ( !late_ && rhs.late_)) " << debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+    if (late_ && rhs.late_ && !(*late_ == *rhs.late_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator== ( late_ &&   rhs.late_ && !(*late_ == *(rhs.late_))) " << debugNodePath()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (auto_restore_ && rhs.auto_restore_) {
+        if (*auto_restore_ == *rhs.auto_restore_) {
+            return true;
+        }
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator== auto_restore_ && rhs.auto_restore_   " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    else if (!auto_restore_ && rhs.auto_restore_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  !auto_restore_ && rhs.auto_restore_ " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    else if (auto_restore_ && !rhs.auto_restore_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  auto_restore_ && !rhs.auto_restore_  " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (auto_cancel_ && !rhs.auto_cancel_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  if (auto_cancel_ && !rhs.auto_cancel_)  " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (!auto_cancel_ && rhs.auto_cancel_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  if (!auto_cancel_ && rhs.auto_cancel_)  " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (auto_cancel_ && rhs.auto_cancel_ && !(*auto_cancel_ == *rhs.auto_cancel_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout
+                << "Node::operator==  (auto_cancel_ && rhs.auto_cancel_ && !(*auto_cancel_ == *rhs.auto_cancel_)) "
+                << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (auto_archive_ && !rhs.auto_archive_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  if (auto_archive_ && !rhs.auto_archive_)  " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (!auto_archive_ && rhs.auto_archive_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Node::operator==  if (!auto_archive_ && rhs.auto_archive_)  " << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (auto_archive_ && rhs.auto_archive_ && !(*auto_archive_ == *rhs.auto_archive_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout
+                << "Node::operator==  (auto_archive_ && rhs.auto_archive_ && !(*auto_archive_ == *rhs.auto_archive_)) "
+                << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    return true;
+}
+
+// #define DEBUG_WHY 1
+
+bool Node::top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
+#ifdef DEBUG_WHY
+    cout << "Node::top_down_why\n";
+#endif
+    return why(theReasonWhy, html_tags);
+}
+
+void Node::bottom_up_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
+#ifdef DEBUG_WHY
+    cout << "Node::bottom_up_why\n";
+#endif
+
+    defs()->why(theReasonWhy, html_tags);
+
+    std::vector<Node*> vec;
+    vec.push_back(const_cast<Node*>(this));
+    Node* theParent = parent();
+    while (theParent) {
+        vec.push_back(theParent);
+        theParent = theParent->parent();
+    }
+    auto r_end = vec.rend();
+    for (auto r = vec.rbegin(); r != r_end; ++r) {
+        (void)(*r)->why(theReasonWhy, html_tags);
+    }
+}
+
+bool Node::why(std::vector<std::string>& vec, bool html) const {
+#ifdef DEBUG_WHY
+    std::cout << "Node::why " << debugNodePath() << " (" << NState::toString(state()) << ") top_down(" << top_down
+              << ") html(" << html << ")\n";
+#endif
+    bool why_found = false;
+    if (isSuspended()) {
+        std::string theReasonWhy;
+        if (html) {
+            theReasonWhy = path_href();
+            theReasonWhy += " is ";
+            theReasonWhy += DState::to_html(DState::SUSPENDED);
+        }
+        else {
+            theReasonWhy = debugNodePath();
+            theReasonWhy += " is suspended";
+        }
+        vec.push_back(theReasonWhy);
+        why_found = true; // return true if why found
+    }
+    else if (state() != NState::QUEUED && state() != NState::ABORTED) {
+        std::stringstream ss;
+        if (html)
+            ss << path_href() << " (" << NState::to_html(state()) << ") is not queued or aborted";
+        else
+            ss << debugNodePath() << " (" << NState::toString(state()) << ") is not queued or aborted";
+        vec.push_back(ss.str());
+
+        // When task is active/submitted no point, going any further.
+        // However, for FAMILY/SUITE we still need to proceed
+        if (isTask())
+            return why_found;
+        why_found = true; // return true if why found
+    }
+
+    // Check limits using in limit manager
+    if (inLimitMgr_.why(vec, html))
+        why_found = true; // return true if why found
+
+    // Prefix <node-type> <path> <state>
+    std::string prefix = debugType();
+    prefix += " ";
+    if (html)
+        prefix += path_href_attribute(absNodePath());
+    else
+        prefix += absNodePath();
+    prefix += "(";
+    if (html)
+        prefix += NState::to_html(state());
+    else
+        prefix += NState::toString(state());
+    prefix += ") ";
+
+    {
+        // postfix  = <attr-type dependent> <next run time > < optional current state>
+        std::string postFix;
+        const Calendar& c = suite()->calendar();
+        for (auto day : days_) {
+            postFix.clear();
+            if (day.why(c, postFix)) {
+                vec.push_back(prefix + postFix);
+                why_found = true;
+            }
+        }
+        for (const auto& date : dates_) {
+            postFix.clear();
+            if (date.why(c, postFix)) {
+                vec.push_back(prefix + postFix);
+                why_found = true;
+            }
+        }
+        for (const auto& today : todays_) {
+            postFix.clear();
+            if (today.why(c, days_, dates_, postFix)) {
+                vec.push_back(prefix + postFix);
+                why_found = true;
+            }
+        }
+        for (const auto& time : times_) {
+            postFix.clear();
+            if (time.why(c, days_, dates_, postFix)) {
+                vec.push_back(prefix + postFix);
+                why_found = true;
+            }
+        }
+        for (const auto& cron : crons_) {
+            postFix.clear();
+            if (cron.why(c, postFix)) {
+                vec.push_back(prefix + postFix);
+                why_found = true;
+            }
+        }
+        for (const auto& aviso : avisos_) {
+            postFix.clear();
+            if (aviso.why(postFix)) {
+                vec.push_back(prefix + postFix);
+                why_found = true;
+            }
+        }
+        for (const auto& mirror : mirrors_) {
+            postFix.clear();
+            if (mirror.why(postFix)) {
+                vec.push_back(prefix + postFix);
+                why_found = true;
+            }
+        }
+    }
+
+    // **************************************************************************************
+    // If we have a complete expression that does not evaluate then it should *NOT* hold the node.
+    // The complete expression is used to set node to complete, when it evaluates and hence
+    // should not prevent further tree walking. evaluate each leaf branch
+    // **************************************************************************************
+
+    // Only report on trigger expression, if:
+    // 1/ No complete expression
+    // 2/ Have complete expression, but it does not evaluate
+    bool report_on_trigger_expression = true;
+    AstTop* theCompleteAst            = completeAst();
+    if (theCompleteAst) {
+        if (c_expr_->isFree() || theCompleteAst->evaluate()) {
+            report_on_trigger_expression = false; // complete is free, hence we do not look at trigger
+        }
+    }
+
+    AstTop* theTriggerAst = triggerAst();
+    if (report_on_trigger_expression && theTriggerAst) {
+        // Note 1: A trigger can be freed by the ForceCmd
+        // Note 2: if we have a non-NULL trigger ast, we must have trigger expression
+        // Note 3: The freed state is stored on the expression ( i.e. *NOT* on the ast (abstract syntax tree) )
+        if (!t_expr_->isFree()) {
+#ifdef DEBUG_WHY
+            std::cout << "   Node::why " << debugNodePath() << " checking trigger dependencies\n";
+#endif
+            std::string postFix;
+            if (theTriggerAst->why(postFix, html)) {
+                vec.push_back(prefix + postFix);
+                why_found = true; // return true if why found
+            }
+        }
+    }
+
+#ifdef DEBUG_WHY
+    std::cout << "   Node::why " << debugNodePath() << " why found(" << why_found << ")\n";
+#endif
+    return why_found; // no why found
+}
+
+bool Node::checkInvariants(std::string& errorMsg) const {
+    for (const ecf::TimeAttr& t : times_) {
+        if (!t.checkInvariants(errorMsg))
+            return false;
+    }
+    for (const ecf::TodayAttr& t : todays_) {
+        if (!t.checkInvariants(errorMsg))
+            return false;
+    }
+    for (const CronAttr& cron : crons_) {
+        if (!cron.checkInvariants(errorMsg))
+            return false;
+    }
+
+    if (misc_attrs_) {
+        if (!misc_attrs_->checkInvariants(errorMsg)) {
+            return false;
+        }
+    }
+    if (!repeat_.empty()) {
+        if (repeat_.name().empty()) {
+            errorMsg += "Repeat name empty ???";
+            return false;
+        }
+    }
+    return true;
+}
+
+std::string Node::absNodePath() const {
+    std::vector<std::string> vec;
+    vec.reserve(Str::reserve_16());
+    vec.push_back(name());
+    Node* theParent = parent();
+    while (theParent) {
+        vec.push_back(theParent->name());
+        theParent = theParent->parent();
+    }
+    std::string ret;
+    ret.reserve(Str::reserve_64());
+    auto r_end = vec.rend();
+    for (auto r = vec.rbegin(); r != r_end; ++r) {
+        ret += '/';
+        ret += *r;
+    }
+
+    //	// Another algorithm broadly similar results
+    //	std::string ret; ret.reserve(Str::reserve_64());
+    // 	ret += '/';
+    //	ret += name();
+    // 	Node* theParent = parent();
+    //	while (theParent) {
+    //		ret.insert(0,"/");
+    //		ret.insert(1,theParent->name());
+    // 		theParent = theParent->parent();
+    //	}
+
+    return ret;
+}
+
+std::string Node::debugNodePath() const {
+    std::string ret = debugType();
+    ret += Str::COLON();
+    ret += absNodePath();
+    return ret;
+}
+
+std::string Node::path_href_attribute(const std::string& path) {
+    std::string ret = "<a href=\"";
+    ret += path;
+    ret += "\">";
+    ret += path;
+    ret += "</a>";
+    return ret;
+}
+
+std::string Node::path_href_attribute(const std::string& path, const std::string& path2) {
+    std::string ret = "<a href=\"";
+    ret += path;
+    ret += "\">";
+    ret += path2;
+    ret += "</a>";
+    return ret;
+}
+
+std::string Node::path_href() const {
+    std::string ret = debugType();
+    ret += " ";
+    ret += path_href_attribute(absNodePath());
+    return ret;
+}
+
+void Node::verification(std::string& errorMsg) const {
+    if (misc_attrs_)
+        misc_attrs_->verification(errorMsg);
+}
+
+void Node::getAllAstNodes(std::set<Node*>& theSet) const {
+    if (completeAst()) {
+        AstCollateNodesVisitor astVisitor(theSet);
+        completeAst()->accept(astVisitor);
+    }
+    if (triggerAst()) {
+        AstCollateNodesVisitor astVisitor(theSet);
+        triggerAst()->accept(astVisitor);
+    }
+}
+
+AstTop* Node::completeAst() const {
+    if (c_expr_) {
+        std::string ignoredErrorMsg;
+        return completeAst(ignoredErrorMsg);
+    }
+    return nullptr;
+}
+
+AstTop* Node::triggerAst() const {
+    if (t_expr_) {
+        std::string ignoredErrorMsg;
+        return triggerAst(ignoredErrorMsg);
+    }
+    return nullptr;
+}
+
+AstTop* Node::completeAst(std::string& errorMsg) const {
+    if (c_expr_) {
+        if (c_expr_->get_ast() == nullptr) {
+
+            c_expr_->createAST(const_cast<Node*>(this), "complete", errorMsg);
+#ifdef DEBUG
+            if (errorMsg.empty())
+                LOG_ASSERT(c_expr_->get_ast(), "");
+#endif
+        }
+        return c_expr_->get_ast();
+    }
+    return nullptr;
+}
+
+AstTop* Node::triggerAst(std::string& errorMsg) const {
+    if (t_expr_) {
+        if (t_expr_->get_ast() == nullptr) {
+
+            t_expr_->createAST(const_cast<Node*>(this), "trigger", errorMsg);
+#ifdef DEBUG
+            if (errorMsg.empty())
+                LOG_ASSERT(t_expr_->get_ast(), "");
+#endif
+        }
+        return t_expr_->get_ast();
+    }
+    return nullptr;
+}
+
+void Node::invalidate_trigger_references() const {
+    if (t_expr_) {
+        if (t_expr_->get_ast()) {
+            t_expr_->get_ast()->invalidate_trigger_references();
+        }
+    }
+    if (c_expr_) {
+        if (c_expr_->get_ast()) {
+            c_expr_->get_ast()->invalidate_trigger_references();
+        }
+    }
+}
+
+node_ptr Node::remove() {
+    SuiteChanged0 changed(shared_from_this());
+
+    Node* theParent = parent();
+    if (theParent)
+        return theParent->removeChild(this);
+    return defs()->removeChild(this);
+}
+
+bool Node::getLabelValue(const std::string& labelName, std::string& value) const {
+    size_t theSize = labels_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (labels_[i].name() == labelName) {
+            if (!(labels_[i].new_value().empty()))
+                value = labels_[i].new_value();
+            else
+                value = labels_[i].value();
+            return true;
+        }
+    }
+    return false;
+}
+
+bool Node::getLabelNewValue(const std::string& labelName, std::string& value) const {
+    size_t theSize = labels_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (labels_[i].name() == labelName) {
+            value = labels_[i].new_value();
+            return true;
+        }
+    }
+    return false;
+}
+
+size_t Node::position() const {
+    Node* theParent = parent();
+    if (theParent) {
+        return theParent->child_position(this);
+    }
+    else {
+        Defs* theDefs = defs();
+        if (theDefs) {
+            return theDefs->child_position(this);
+        }
+    }
+    return std::numeric_limits<std::size_t>::max();
+}
+
+void Node::gen_variables(std::vector<Variable>& vec) const {
+    repeat_.gen_variables(vec); // if repeat_ is empty vec is unchanged
+}
+
+const Variable& Node::findGenVariable(const std::string& name) const {
+    return repeat_.find_gen_variable(name); // if repeat_ is empty find returns empty variable by ref
+}
+
+void Node::update_repeat_genvar() const {
+    repeat_.update_repeat_genvar(); // if repeat_ is empty update_repeat_genvar() does nothing
+}
+
+void Node::notify_delete() {
+    // make a copy, to avoid iterating over observer list that is being changed
+    std::vector<AbstractObserver*> copy_of_observers = observers_;
+    for (auto& copy_of_observer : copy_of_observers) {
+        copy_of_observer->update_delete(this);
+    }
+
+    /// Check to make sure that the Observer called detach
+    /// We cannot call detach ourselves, since the the client needs to
+    /// call detach in the case where the graphical tree is destroyed by user
+    /// In this case the Subject/Node is being deleted.
+    assert(observers_.empty());
+
+#ifdef DEBUG_NODE
+    if (!observers_.empty()) {
+        /// Its not safe to call debugNodePath()/absNodePath() since that will traverse the parent
+        /// This may not be safe during a delete.
+        std::cout << "notify_delete : Node is not observed : " << name() << "\n";
+    }
+#endif
+}
+
+void Node::notify_start(const std::vector<ecf::Aspect::Type>& aspects) {
+    size_t observers_size = observers_.size();
+    for (size_t i = 0; i < observers_size; i++) {
+        observers_[i]->update_start(this, aspects);
+    }
+}
+
+void Node::notify(const std::vector<ecf::Aspect::Type>& aspects) {
+    size_t observers_size = observers_.size();
+    for (size_t i = 0; i < observers_size; i++) {
+        observers_[i]->update(this, aspects);
+    }
+}
+
+void Node::attach(AbstractObserver* obs) {
+    observers_.push_back(obs);
+}
+
+void Node::detach(AbstractObserver* obs) {
+    for (size_t i = 0; i < observers_.size(); i++) {
+        if (observers_[i] == obs) {
+            observers_.erase(observers_.begin() + i);
+            return;
+        }
+    }
+}
+
+bool Node::is_observed(AbstractObserver* obs) const {
+    for (auto observer : observers_) {
+        if (observer == obs) {
+            return true;
+        }
+    }
+    return false;
+}
+
+void Node::sort_attributes(ecf::Attr::Type attr, bool recursive, const std::vector<std::string>& no_sort) {
+    // cout << "Node::sort_attributes " << absNodePath() << "  " << attr << " recursive " << recursive << "
+    // no_sort.size() " << no_sort.size() << "\n";
+
+    if (recursive && !no_sort.empty()) {
+        std::string path = absNodePath();
+        for (const auto& p : no_sort) {
+            // cout << " no_sort: " << p << "\n";
+            if (p == path) {
+                return;
+            }
+        }
+    }
+    auto caseInsen = [](const auto& a, const auto& b) { return Str::caseInsLess(a.name(), b.name()); };
+
+    state_change_no_ = Ecf::incr_state_change_no();
+    switch (attr) {
+        case Attr::EVENT:
+            sort(events_.begin(), events_.end(), [](const Event& a, const Event& b) {
+                return Str::caseInsLess(a.name_or_number(), b.name_or_number());
+            });
+            break;
+        case Attr::METER:
+            sort(meters_.begin(), meters_.end(), caseInsen);
+            break;
+        case Attr::LABEL:
+            sort(labels_.begin(), labels_.end(), caseInsen);
+            break;
+        case Attr::LIMIT:
+            sort(limits_.begin(), limits_.end(), [](const limit_ptr& a, const limit_ptr& b) {
+                return Str::caseInsLess(a->name(), b->name());
+            });
+            break;
+        case Attr::VARIABLE:
+            sort(vars_.begin(), vars_.end(), caseInsen);
+            break;
+        case Attr::ALL:
+            sort(vars_.begin(), vars_.end(), caseInsen);
+            sort(events_.begin(), events_.end(), [](const Event& a, const Event& b) {
+                return Str::caseInsLess(a.name_or_number(), b.name_or_number());
+            });
+            sort(meters_.begin(), meters_.end(), caseInsen);
+            sort(labels_.begin(), labels_.end(), caseInsen);
+            sort(limits_.begin(), limits_.end(), [](const limit_ptr& a, const limit_ptr& b) {
+                return Str::caseInsLess(a->name(), b->name());
+            });
+            break;
+        case Attr::UNKNOWN:
+            break;
+        default:
+            break;
+    }
+}
+
+bool Node::checkForAutoCancel(const ecf::Calendar& calendar) const {
+    if (auto_cancel_ && state() == NState::COMPLETE) {
+        if (auto_cancel_->isFree(calendar, get_state().second)) {
+
+            /// *Only* delete this node if we don't create zombies
+            /// anywhere for our children
+            vector<Task*> taskVec;
+            getAllTasks(taskVec);
+            for (Task* t : taskVec) {
+                if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
+                    return false;
+                }
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
+bool Node::check_for_auto_archive(const ecf::Calendar& calendar) const {
+    if (auto_archive_ && !isSuspended() && !isParentSuspended()) {
+        if (auto_archive_->isFree(calendar, get_state())) {
+
+            /// *Only* archive this node if we don't create zombies anywhere for our children
+            /// The most significant state could be ABORTED in family, but we could still have active tasks.
+            vector<Task*> taskVec;
+            getAllTasks(taskVec);
+            for (Task* t : taskVec) {
+                if (t->state() == NState::ACTIVE || t->state() == NState::SUBMITTED) {
+                    return false;
+                }
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
+void Node::stats(NodeStats& stats) {
+    stats.vars_ += vars_.size();
+    if (c_expr_)
+        stats.c_trigger_++;
+    if (t_expr_)
+        stats.trigger_++;
+    stats.meters_ += meters_.size();
+    stats.events_ += events_.size();
+    stats.labels_ += labels_.size();
+    stats.times_ += times_.size();
+    stats.todays_ += todays_.size();
+    stats.crons_ += crons_.size();
+    stats.dates_ += dates_.size();
+    stats.days_ += days_.size();
+
+    if (late_)
+        stats.late_++;
+    if (misc_attrs_) {
+        stats.verifys_ += misc_attrs_->verifys().size();
+        stats.zombies_ += misc_attrs_->zombies().size();
+        stats.queues_ += misc_attrs_->queues().size();
+        stats.generics_ += misc_attrs_->generics().size();
+    }
+    if (!repeat_.empty())
+        stats.repeats_++;
+
+    stats.limits_ += limits_.size();
+    stats.inlimits_ += inLimitMgr_.inlimits().size();
+    if (auto_cancel_)
+        stats.auto_cancel_++;
+    if (auto_archive_)
+        stats.auto_archive_++;
+    if (auto_restore_)
+        stats.auto_restore_++;
+}
+
+static std::vector<VerifyAttr> verifys_;
+static std::vector<ZombieAttr> zombies_;
+static std::vector<QueueAttr> queues_;
+static std::vector<GenericAttr> generics_;
+const std::vector<VerifyAttr>& Node::verifys() const {
+    if (misc_attrs_)
+        return misc_attrs_->verifys();
+    return verifys_;
+}
+const std::vector<ZombieAttr>& Node::zombies() const {
+    if (misc_attrs_)
+        return misc_attrs_->zombies();
+    return zombies_;
+}
+const std::vector<QueueAttr>& Node::queues() const {
+    if (misc_attrs_)
+        return misc_attrs_->queues();
+    return queues_;
+}
+std::vector<QueueAttr>& Node::ref_queues() {
+    if (misc_attrs_)
+        return misc_attrs_->ref_queues();
+    return queues_;
+}
+const std::vector<GenericAttr>& Node::generics() const {
+    if (misc_attrs_)
+        return misc_attrs_->generics();
+    return generics_;
+}
+
+std::vector<ZombieAttr>::const_iterator Node::zombie_begin() const {
+    if (misc_attrs_)
+        return misc_attrs_->zombie_begin();
+    return zombies_.begin();
+}
+std::vector<ZombieAttr>::const_iterator Node::zombie_end() const {
+    if (misc_attrs_)
+        return misc_attrs_->zombie_end();
+    return zombies_.end();
+}
+std::vector<VerifyAttr>::const_iterator Node::verify_begin() const {
+    if (misc_attrs_)
+        return misc_attrs_->verify_begin();
+    return verifys_.begin();
+}
+std::vector<VerifyAttr>::const_iterator Node::verify_end() const {
+    if (misc_attrs_)
+        return misc_attrs_->verify_end();
+    return verifys_.end();
+}
+std::vector<QueueAttr>::const_iterator Node::queue_begin() const {
+    if (misc_attrs_)
+        return misc_attrs_->queue_begin();
+    return queues_.begin();
+}
+std::vector<QueueAttr>::const_iterator Node::queue_end() const {
+    if (misc_attrs_)
+        return misc_attrs_->queue_end();
+    return queues_.end();
+}
+std::vector<GenericAttr>::const_iterator Node::generic_begin() const {
+    if (misc_attrs_)
+        return misc_attrs_->generic_begin();
+    return generics_.begin();
+}
+std::vector<GenericAttr>::const_iterator Node::generic_end() const {
+    if (misc_attrs_)
+        return misc_attrs_->generic_end();
+    return generics_.end();
+}
+
+template <class Archive>
+void Node::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(n_));
+
+    CEREAL_OPTIONAL_NVP(ar, st_, [this]() { return st_.first != NState::default_state(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, suspended_, [this]() { return suspended_; });
+    CEREAL_OPTIONAL_NVP(ar, d_st_, [this]() { return d_st_.state() != DState::default_state(); }); // conditionally save
+
+    CEREAL_OPTIONAL_NVP(ar, vars_, [this]() { return !vars_.empty(); });  // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, c_expr_, [this]() { return c_expr_.get(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, t_expr_, [this]() { return t_expr_.get(); }); // conditionally save
+
+    CEREAL_OPTIONAL_NVP(ar, meters_, [this]() { return !meters_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, events_, [this]() { return !events_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, labels_, [this]() { return !labels_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, avisos_, [this]() { return !avisos_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, mirrors_, [this]() { return !mirrors_.empty(); }); // conditionally save
+
+    CEREAL_OPTIONAL_NVP(ar, times_, [this]() { return !times_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, todays_, [this]() { return !todays_.empty(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, crons_, [this]() { return !crons_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, dates_, [this]() { return !dates_.empty(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, days_, [this]() { return !days_.empty(); });     // conditionally save
+
+    CEREAL_OPTIONAL_NVP(ar, late_, [this]() { return late_.get(); });             // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, misc_attrs_, [this]() { return misc_attrs_.get(); }); // conditionally save
+
+    CEREAL_OPTIONAL_NVP(ar, repeat_, [this]() { return !repeat_.empty(); });                    // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, limits_, [this]() { return !limits_.empty(); });                    // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, inLimitMgr_, [this]() { return !inLimitMgr_.inlimits().empty(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, flag_, [this]() { return flag_.flag() != 0; });                     // conditionally save
+
+    CEREAL_OPTIONAL_NVP(ar, auto_cancel_, [this]() { return auto_cancel_.get(); });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, auto_archive_, [this]() { return auto_archive_.get(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, auto_restore_, [this]() { return auto_restore_.get(); }); // conditionally save
+
+    if (Archive::is_loading::value) {
+        if (auto_restore_)
+            auto_restore_->set_node(this);
+        if (misc_attrs_)
+            misc_attrs_->set_node(this);
+        for (auto& limit : limits_)
+            limit->set_node(this);
+    }
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(Node);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Node.hpp 5.13.0-1/libs/node/src/ecflow/node/Node.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Node.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Node.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,953 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Node_HPP
+#define ecflow_node_Node_HPP
+
+///
+/// \note The node class does NOT serialise the triggers and complete.
+/// These are created on demand in the server. However when the client code
+/// loads the definition file, the Defs::check will create AST for trigger and
+/// complete expressions, because:
+///  1/ the AST are created, so that any parser errors can be _reported_ to the user
+///  2/ References in the AST expressions are resolved, and errors flagged.
+///
+/// This information could have been saved, however was _not_, because:
+///  1/ problems on AIX
+///  2/ Cut down on IPC load between client/server
+///
+
+#include <iosfwd>
+#include <limits>
+
+#include "ecflow/attribute/CronAttr.hpp"
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/attribute/RepeatAttr.hpp"
+#include "ecflow/attribute/TimeAttr.hpp"
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/DState.hpp"
+#include "ecflow/core/NOrder.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Aspect.hpp"
+#include "ecflow/node/Attr.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/InLimit.hpp"
+#include "ecflow/node/InLimitMgr.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+namespace ecf {
+class Simulator;
+class SimulatorVisitor;
+class DefsAnalyserVisitor;
+class FlatAnalyserVisitor;
+} // namespace ecf
+
+namespace ecf {
+class Calendar;
+class NodeTreeVisitor;
+class LateAttr;
+class AvisoAttr;
+class MirrorAttr;
+} // namespace ecf
+
+class Node : public std::enable_shared_from_this<Node> {
+protected:
+    Node(const std::string& name, bool check);
+    Node();
+
+public:
+    Node& operator=(const Node&);
+    bool operator<(const Node& rhs) { return name() < rhs.name(); }
+
+    Node(const Node& rhs);
+    virtual ~Node();
+
+    virtual bool check_defaults() const;
+
+    // parse string and create suite || family || task || alias. Can return a NULL node_ptr() for errors
+    static node_ptr create(const std::string& node_string);
+    static node_ptr create(const std::string& node_string, std::string& error_msg);
+
+    /// The Parent Must set the parent pointer. For a Suite however this will be NULL
+    void set_parent(Node* p) { parent_ = p; }
+
+    virtual node_ptr clone() const = 0;
+
+    // Server called functions:
+    //   Required when we have time attributes, when time related attribute are free they stay free, until re-queue
+    struct Calendar_args
+    {
+        Calendar_args() = default;
+
+        std::vector<node_ptr> auto_cancelled_nodes_;
+        std::vector<node_ptr> auto_archive_nodes_;
+    };
+    virtual bool calendarChanged(const ecf::Calendar&,
+                                 Node::Calendar_args&,
+                                 const ecf::LateAttr* inherited_late,
+                                 bool holding_parent_day_or_date);
+
+    /// resolving dependencies means we look at day,date,time and triggers and check to
+    /// to see if a node is free or still holding. When a node if free of its dependencies and limits
+    /// Its state is changed to submitted. When a task is in a the submitted state its
+    /// associated ecf file can be submitted.
+    /// ************************************************************************************
+    /// There is no point in resolving child dependencies if the parent is not FREE
+    //  We will return a bool, true means we are free, false for holding
+    // *************************************************************************************
+    virtual bool resolveDependencies(JobsParam& jobsParam);
+
+    /// When the server is terminated and then restarted, Allow time attributes to catch up.
+    /// We need to check all attributes dependent on time.
+    virtual bool has_time_based_attributes() const;
+
+    /// Command related functions:
+    /// suspend generation of jobs. Below this node.
+    /// Note: When a node is suspended. time/date dependencies are still handled
+    ///       A node which is free of time is marked.
+    /// Note: suspended is *NOT* a node state. It just an *attribute*. NState::State
+    /// represents all the life cycle change a Node can go through. Suspended does
+    /// not real fit into this and has been separated out.
+    bool isSuspended() const { return suspended_; }
+    bool isParentSuspended() const;
+    void suspend();
+
+    /// resume generation of jobs, and kick of an immediate job generation
+    /// If not previously suspended does nothing
+    void resume();
+
+    /// Kill the task if it is active. For NodeContainers do it hierarchically
+    /// will throw std::runtime_error for any errors
+    virtual void kill(const std::string& zombie_pid = "") = 0;
+
+    /// Show status of a node. For NodeContainers do it hierarchically
+    /// will throw std::runtime_error for any errors
+    virtual void status() = 0;
+
+    /// Order the node using the second parameter
+    virtual void order(Node* /*immediateChild*/, NOrder::Order) {}
+    virtual void move_peer(Node* /*src*/, Node* /*dest*/) {}
+
+    /// called when definition is restored from a file/checkpoint
+    virtual void handle_migration(const ecf::Calendar&);
+
+    /// reset all. Used after job generation.
+    /// Unlike re-queue/begin, will reset time attributes. see ECFLOW-1204
+    virtual void reset();
+
+    /// For suites it allows dependencies to be resolved, and changes state to defStatus
+    virtual void begin();
+
+    /// re queue this node. States are reset to defStatus
+    /// Typically resetRepeats is set to true, when called from user command
+    /// or when re-queue is called from NodeContainer/parent
+    ///
+    /// With user interaction : we need to clear the suspended state for *child* nodes
+    /// To distinguish between child and parent, we use a integer 'level'
+    /// This was done so that if user had suspended a task deep in the hierarchy. (which is then
+    /// not displayed in the GUI), and then chooses to re-queue at a *high* level,
+    /// we need to clear child suspended state.(Principle of least surprise)
+    /// However we will preserve def status.
+    /// If a user re-queues a node that is suspended then it stays suspended
+    /// We use -1 to mean leave suspended state as is
+    ///
+    /// When the user issues force-complete or run interactive commands, we want to miss
+    /// the next-time slot. (i.e to avoid running the job again).
+    /// This is done by using NO_REQUE_IF_SINGLE_TIME_DEP flag.
+    /// The flag remain set until we get to *this* function. We use it to avoid
+    /// resetting the time slots, effectively missing the next time slot. we then clear the flag.
+    /// However if the JOB *abort* we clear NO_REQUE_IF_SINGLE_TIME_DEP
+    /// Otherwise if we run again, we miss additional time slots necessarily
+    struct Requeue_args
+    {
+        enum Requeue_t { REPEAT_INCREMENT = 1, TIME = 2, FULL = 3 };
+        Requeue_args() = default;
+        explicit Requeue_args(Requeue_t r_t) : requeue_t(r_t){};
+        Requeue_args(Requeue_t r_t,
+                     bool resetRepeats,
+                     int clear_suspended_in_child_nodes,
+                     bool reset_next_time_slot,
+                     bool reset_relative_duration,
+                     bool log_state_changes = true)
+            : requeue_t(r_t),
+              clear_suspended_in_child_nodes_(clear_suspended_in_child_nodes),
+              resetRepeats_(resetRepeats),
+              reset_next_time_slot_(reset_next_time_slot),
+              reset_relative_duration_(reset_relative_duration),
+              log_state_changes_(log_state_changes) {}
+        const Requeue_t requeue_t{FULL};
+        int clear_suspended_in_child_nodes_{0};
+        const bool resetRepeats_{true};
+        const bool reset_next_time_slot_{true};
+        const bool reset_relative_duration_{true};
+        const bool log_state_changes_{true};
+    };
+    virtual void requeue(Requeue_args&);
+
+    // force queued allows a job to re-run preserving job output.
+    // However, other nodes may reference this node's events/meters/late in trigger expression,
+    // and reset events, meters and late flag ECFLOW-1617
+    virtual void reset_late_event_meters();
+
+    /// Re queue the time based attributes only.
+    /// Used as a part of Alter (clock) functionality.
+    /// Note: Under the hybrid clock this will not mark node as complete, (if we have day,date,cron attributes)
+    /// Since alter clock, should not change node state. This is left for user to re-queue the suite
+    virtual void requeue_time_attrs();
+
+    /// Previously < 4.0.6 requeue always reset the labels on requeue.
+    /// However ECFLOW-195 suggest some user prefer to see the last label value.
+    /// hence we will only reset the labels on the tasks when task is being run.
+    void requeue_labels();
+
+    /// This functionality is only required during interactive force or run
+    /// Avoid running the task on the same time slot, by missing the next time slot.
+    /// Requires we set a flag, to avoid the requeue resetting the time slots
+    void miss_next_time_slot();
+
+    /// Recursively run the tasks under this node, ignore suspend,limits,triggers, and time dependencies
+    /// if force is set, run even if task is submitted or active. (will create zombies)
+    virtual bool run(JobsParam& jobsParam, bool force) = 0;
+
+    /// Recursively determines why the node is not running.
+    virtual bool top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
+    void bottom_up_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
+
+    void freeTrigger() const;
+    void clearTrigger() const;
+    void freeComplete() const;
+    void clearComplete() const;
+    void freeHoldingDateDependencies();
+    void freeHoldingTimeDependencies();
+
+    // Used in the force cmd
+    bool set_event(const std::string& event_name_or_number);
+    bool clear_event(const std::string& event_name_or_number);
+    void setRepeatToLastValue();
+    virtual void setRepeatToLastValueHierarchically() { setRepeatToLastValue(); }
+
+    /// find all %VAR% and replaces with variable values, returns false on the
+    /// first variable that can't be found, cmd will be left half processed.
+    /// Will search for ECF_MICRO, if not found assumes % as the micro char
+    bool variableSubstitution(std::string& cmd) const;
+
+    bool variable_substitution(std::string& cmd, const NameValueMap& user_edit_variables, char micro = '%') const;
+
+    /// Find all %VAR% and add to the list, there can be more than one. i.e %ECF_FILES% -I %ECF_INCLUDE%"
+    bool find_all_used_variables(std::string& cmd, NameValueMap& used_variables, char micro = '%') const;
+
+    /// Find all environment variables, in the input string and substitute.
+    /// with correspondingly named variable value.
+    /// i.e search for ${ENV} and replace
+    bool variable_dollar_substitution(std::string& cmd) const;
+
+    /// Resolve inlimit references to limits, and check trigger and complete expression
+    virtual bool check(std::string& errorMsg, std::string& warningMsg) const;
+
+    /// Generated variables. Suites can have thousands of tasks. If the generated variables associated with
+    /// tasks are sent to the client, it can amount to a very large network traffic.
+    /// To minimise this bandwidth the generated variables for tasks/families are not persisted.
+    /// However client can demand create the generated  variable by calling this function.
+    virtual void update_generated_variables() const = 0;
+
+    ///  generates job file independent of dependencies
+    virtual void check_job_creation(job_creation_ctrl_ptr jobCtrl) = 0;
+
+    node_ptr remove(); // gets the parent then calls removeChild
+    virtual node_ptr removeChild(Node* child) = 0;
+    virtual bool
+    addChild(const node_ptr& child,
+             size_t position =
+                 std::numeric_limits<std::size_t>::max()) = 0; // return false if child of same name exist, leak!!!
+    virtual bool isAddChildOk(Node* child, std::string& errorMsg) const = 0; // return false if child of same name
+
+    virtual void verification(std::string& errorMsg) const;
+
+    /// See defs.hpp
+    virtual void generate_scripts(const std::map<std::string, std::string>& override) const = 0;
+
+    // standard functions: ==============================================
+    std::string print() const;
+    virtual void print(std::string&) const;
+    std::string print(PrintStyle::Type_t type) const;
+    bool operator==(const Node& rhs) const;
+    virtual bool checkInvariants(std::string& errorMsg) const;
+
+    /// Implements the visitor pattern
+    virtual void accept(ecf::NodeTreeVisitor&)               = 0;
+    virtual void acceptVisitTraversor(ecf::NodeTreeVisitor&) = 0; // Visitor does the traversal
+
+    // state related functions: ========================================
+
+    /// If the task was aborted provide the reason, default returns empty string
+    /// Only the task will return the reason for abort.
+    virtual const std::string& abortedReason() const;
+
+    /// This state added as an convenience, it includes Suspended attribute returned as enum
+    DState::State dstate() const;
+
+    /// This represents the persisted/saved state // First = NState, Second = time_duration
+    /// The State represent the life cycle changes of a node.
+    NState::State state() const { return st_.first.state(); }
+
+    /// return the state and duration time(relative to when suite was begun) when the state change happened
+    std::pair<NState, boost::posix_time::time_duration> get_state() const { return st_; }
+
+    /// Set the state, this can have side affects. To handle state changes
+    ///	  Should family triggers use saved state, or computed state.
+    ///	  *** If we use computed state, this may be wrong, since computed state
+    ///	  *** does not take repeats, or time dependencies into account
+    ///	  *** Hence after each state change, we bubble up node tree, work out if
+    ///	  *** Node is free of repeat, and time dependencies,
+    /// 	** Every time we set the state on a nodecontainer, we call handleStateChange
+    /// 	** This by default works out the most significant state of the children
+    /// 	** ie. the computed state. Hence setting the state on Suite/Family is really
+    /// 	** meaningless, since it will always be the computed state.
+    void set_state(NState::State s, bool force = false, const std::string& additional_info_to_log = "");
+    virtual void set_state_hierarchically(NState::State s, bool force) { set_state(s, force); }
+
+    /// Set state only, has no side effects
+    void setStateOnly(NState::State s,
+                      bool force                                = false,
+                      const std::string& additional_info_to_log = "",
+                      bool log_state_changes                    = true);
+    virtual void setStateOnlyHierarchically(NState::State s, bool force = false) { setStateOnly(s, force); }
+
+    /// This returns the time of state change: (relative to real time when the suite calendar was begun)
+    /// The returned time is *real time/computer UTC time* and *not* suite real time.
+    boost::posix_time::ptime state_change_time() const;
+
+    /// Returns the difference between last two state changes, effectively state change runtime.
+    /// queued    -> submitted : 1hr 30s,  submitted -> active    : 30s, active    -> complete  : 59m  etc
+    const boost::posix_time::time_duration& state_change_runtime() const { return sc_rt_; }
+
+    /// Sets the default status the node should have when the begin/re-queue is called
+    /// *Distinguish* between adding a def status and changing it.
+    /// Changing via d_st_.setState(s);  should alter state_change_no
+    void addDefStatus(DState::State s) { d_st_ = DState(s); }
+    DState::State defStatus() const { return d_st_.state(); }
+
+    // Query functions: =========================================================
+    /// returns my parent, for suite will return NULL;
+    Node* parent() const { return parent_; }
+    virtual Suite* suite() const = 0;
+    virtual Defs* defs() const   = 0;
+
+    // Performance hack, to avoid casts
+    virtual Task* isTask() const { return nullptr; }
+    virtual Alias* isAlias() const { return nullptr; }
+    virtual Submittable* isSubmittable() const { return nullptr; }
+    virtual NodeContainer* isNodeContainer() const { return nullptr; }
+    virtual Family* isFamily() const { return nullptr; }
+    virtual Suite* isSuite() const { return nullptr; }
+    virtual bool has_archive() const { return false; }
+
+    ///  returns the absolute node path
+    std::string absNodePath() const;
+    virtual const std::string& debugType() const = 0;
+
+    /// returns abs node path preceded by the type of the node
+    std::string debugNodePath() const;
+    static std::string path_href_attribute(const std::string& path);
+    static std::string path_href_attribute(const std::string& path, const std::string& path2);
+    std::string path_href() const;
+
+    /// returns true if this node OR any of its children
+    /// has cron,time,day,date or today time dependencies
+    virtual bool hasTimeDependencies() const { return has_time_dependencies(); }
+    bool isTimeFree() const { return (hasTimeDependencies()) ? timeDependenciesFree() : false; }
+    bool time_today_cron_is_free() const; /* used by viewer */
+
+    /// If no time dependencies then we have a resolution of 1 hour.
+    /// If we have just day/date then we have a resolution of 1 hour
+    /// Otherwise if we have time/today/cron with minutes, then resolution is 1 minute
+    void get_time_resolution_for_simulation(boost::posix_time::time_duration& resol) const;
+    void get_max_simulation_duration(boost::posix_time::time_duration& resol) const;
+
+    /// hierarchical function
+    virtual bool hasAutoCancel() const { return (auto_cancel_) ? true : false; }
+    virtual void invalidate_trigger_references() const;
+
+    // Access functions: ======================================================
+    const std::string& name() const { return n_; }
+    const Repeat& repeat() const { return repeat_; } // can be empty()
+    const std::vector<Variable>& variables() const { return vars_; }
+    const std::vector<limit_ptr>& limits() const { return limits_; }
+    const std::vector<InLimit>& inlimits() const { return inLimitMgr_.inlimits(); }
+
+    const std::vector<Meter>& meters() const { return meters_; }
+    const std::vector<Event>& events() const { return events_; }
+    const std::vector<Label>& labels() const { return labels_; }
+
+    const std::vector<ecf::TimeAttr>& timeVec() const { return times_; }
+    const std::vector<ecf::TodayAttr>& todayVec() const { return todays_; }
+    const std::vector<DateAttr>& dates() const { return dates_; }
+    const std::vector<DayAttr>& days() const { return days_; }
+    const std::vector<ecf::CronAttr>& crons() const { return crons_; }
+
+    std::vector<ecf::AvisoAttr>& avisos() { return avisos_; }
+    const std::vector<ecf::AvisoAttr>& avisos() const { return avisos_; }
+
+    std::vector<ecf::MirrorAttr>& mirrors() { return mirrors_; }
+    const std::vector<ecf::MirrorAttr>& mirrors() const { return mirrors_; }
+
+    const std::vector<VerifyAttr>& verifys() const;
+    const std::vector<ZombieAttr>& zombies() const;
+    const std::vector<QueueAttr>& queues() const;
+    const std::vector<GenericAttr>& generics() const;
+    ecf::LateAttr* get_late() const { return late_.get(); }
+    ecf::AutoRestoreAttr* get_autorestore() const { return auto_restore_.get(); }
+    ecf::AutoCancelAttr* get_autocancel() const { return auto_cancel_.get(); }
+    ecf::AutoArchiveAttr* get_autoarchive() const { return auto_archive_.get(); }
+    ecf::Flag& flag() { return flag_; }
+    const ecf::Flag& get_flag() const { return flag_; }
+
+    virtual void gen_variables(std::vector<Variable>&) const;
+    bool getLabelValue(const std::string& name, std::string& value) const;
+    bool getLabelNewValue(const std::string& name, std::string& value) const;
+
+    // Use get_trigger()/get_complete() for determining if we have trigger
+    // and complete expressions. This is many times faster than calling
+    // triggerAst()/completeAst() as this will force a parse and construction
+    // of Abstract syntax tree, first time it is called.
+    Expression* get_trigger() const { return t_expr_.get(); }
+    Expression* get_complete() const { return c_expr_.get(); }
+    AstTop* completeAst() const; // Will create AST on demand
+    AstTop* triggerAst() const;  // Will create AST on demand
+    std::string completeExpression() const;
+    std::string triggerExpression() const;
+
+    virtual void get_all_tasks(std::vector<task_ptr>&) const                   = 0;
+    virtual void get_all_nodes(std::vector<node_ptr>&) const                   = 0;
+    virtual void get_all_aliases(std::vector<alias_ptr>&) const                = 0;
+    virtual void getAllTasks(std::vector<Task*>&) const                        = 0;
+    virtual void getAllSubmittables(std::vector<Submittable*>&) const          = 0;
+    virtual void get_all_active_submittables(std::vector<Submittable*>&) const = 0;
+    virtual void getAllNodes(std::vector<Node*>&) const                        = 0;
+    virtual void getAllAstNodes(std::set<Node*>&) const;
+
+    /// returns the immediate children
+    virtual void immediateChildren(std::vector<node_ptr>&) const {}
+
+    /// retrieve _ALL_ children by hierarchically traversing down the node tree
+    virtual void allChildren(std::vector<node_ptr>&) const {}
+
+    // Add functions: ===============================================================
+    void addVerify(const VerifyAttr&); // for testing and verification Can throw std::runtime_error
+    void addVariable(const Variable&); // will update if duplicate
+    void add_variable(const std::string& name, const std::string& value); // will write to std:out if duplicates
+    void add_variable_bypass_name_check(const std::string& name,
+                                        const std::string& value); // will write to std:out if duplicates
+    void add_variable_int(const std::string& name, int);           // will throw std::runtime_error if duplicate
+
+    void add_trigger(const std::string&);          // use for short complete expressions,Can throw std::runtime_error
+    void add_complete(const std::string&);         // use for short complete expressions,Can throw std::runtime_error
+    void add_trigger_expr(const Expression&);      // Can throw std::runtime_error
+    void add_complete_expr(const Expression&);     // Can throw std::runtime_error
+    void add_part_trigger(const PartExpression&);  // for adding multiple and/or expression,Can throw std::runtime_error
+    void add_part_complete(const PartExpression&); // for adding multiple and/or expression,Can throw std::runtime_error
+    void py_add_trigger_expr(const std::vector<PartExpression>&);  // used by python api to add expression cumulative
+    void py_add_complete_expr(const std::vector<PartExpression>&); // used by python api to add expression cumulative
+
+    void addTime(const ecf::TimeAttr&);
+    void addToday(const ecf::TodayAttr&);
+    void addDate(const DateAttr&);
+    void addDay(const DayAttr&);
+    void addCron(const ecf::CronAttr&);
+    void addAviso(const ecf::AvisoAttr&);
+    void addMirror(const ecf::MirrorAttr&);
+
+    void addLimit(const Limit&, bool check = true);       // will throw std::runtime_error if duplicate
+    void addInLimit(const InLimit& l, bool check = true); // will throw std::runtime_error if duplicate
+    void auto_add_inlimit_externs(Defs* defs) { inLimitMgr_.auto_add_inlimit_externs(defs); }
+    void addEvent(const Event&, bool check = true); // will throw std::runtime_error if duplicate
+    void addMeter(const Meter&, bool check = true); // will throw std::runtime_error if duplicate
+    void add_meter(const std::string& name,
+                   int min,
+                   int max,
+                   int color_change,
+                   int value,
+                   bool check = true); // will throw std::runtime_error if duplicate
+    void addLabel(const Label&);       // will throw std::runtime_error if duplicate
+    void add_label(const std::string& name, const std::string& value, const std::string& new_value, bool check = true);
+    void addAutoCancel(const ecf::AutoCancelAttr&);
+    void add_autoarchive(const ecf::AutoArchiveAttr&);
+    void add_autorestore(const ecf::AutoRestoreAttr&);
+    void addLate(const ecf::LateAttr&);
+    void addRepeat(Repeat&&);             // will throw std::runtime_error if duplicate
+    void addRepeat(const Repeat&);        // will throw std::runtime_error if duplicate
+    void addZombie(const ZombieAttr&);    // will throw std::runtime_error if duplicate
+    void add_queue(const QueueAttr&);     // will throw std::runtime_error if duplicate
+    void add_generic(const GenericAttr&); // will throw std::runtime_error if duplicate
+
+    // sort
+    // expect one attr to be [ event | meter | label | limits | variable ]
+    virtual void sort_attributes(ecf::Attr::Type at,
+                                 bool recursive                          = true,
+                                 const std::vector<std::string>& no_sort = std::vector<std::string>());
+
+    // Delete functions: can throw std::runtime_error ===================================
+    // if name argument is empty, delete all attributes of that type
+    // Can throw std::runtime_error of the attribute cannot be found
+    void deleteTime(const std::string& name);
+    void delete_time(const ecf::TimeAttr&);
+    void deleteToday(const std::string& name);
+    void delete_today(const ecf::TodayAttr&);
+    void deleteDate(const std::string& name);
+    void delete_date(const DateAttr&);
+    void deleteDay(const std::string& name);
+    void delete_day(const DayAttr&);
+    void deleteCron(const std::string& name);
+    void delete_cron(const ecf::CronAttr&);
+
+    void delete_zombie(const ecf::Child::ZombieType);
+    void deleteVariable(const std::string& name); // if name not found throw, if name empty delete all variables
+    void
+    delete_variable_no_error(const std::string& name); // if variable not found don't error, if name empty do nothing
+    void deleteEvent(const std::string& name);
+    void deleteMeter(const std::string& name);
+    void deleteLabel(const std::string& name);
+    void deleteAviso(const std::string& name);
+    void deleteMirror(const std::string& name);
+    void delete_queue(const std::string& name);
+    void delete_generic(const std::string& name);
+    void deleteTrigger();
+    void deleteComplete();
+    void deleteRepeat();
+    void deleteLimit(const std::string& name);
+    void delete_limit_path(const std::string& limit_name, const std::string& limit_path);
+    void deleteInlimit(const std::string& name);
+    void deleteZombie(const std::string& type); // string must be one of [ user | ecf | path ]
+    void deleteLate();
+    void deleteAutoCancel();
+    void deleteAutoRestore();
+    void deleteAutoArchive();
+
+    // Change functions: ================================================================
+    /// returns true the change was made else false, Can throw std::runtime_error for parse errors
+    void changeVariable(const std::string& name, const std::string& value);
+    void changeEvent(const std::string& name, const std::string& setOrClear = "");
+    void changeEvent(const std::string& name, bool value);
+    void changeMeter(const std::string& name, const std::string& value);
+    void changeMeter(const std::string& name, int value);
+    void changeLabel(const std::string& name, const std::string& value);
+    void changeAviso(const std::string& name, const std::string& value);
+    void changeAviso(const std::string& name, const std::string& value, uint64_t revision);
+    void changeMirror(const std::string& name, const std::string& value);
+    void changeTrigger(const std::string& expression);
+    void changeComplete(const std::string& expression);
+    void changeRepeat(const std::string& value);
+    void changeLimitMax(const std::string& name, const std::string& maxValue);
+    void changeLimitMax(const std::string& name, int maxValue);
+    void changeLimitValue(const std::string& name, const std::string& value);
+    void changeLimitValue(const std::string& name, int value);
+    void changeDefstatus(const std::string& state);
+    void changeLate(const ecf::LateAttr&);
+    void change_time(const std::string&, const std::string&);
+    void change_today(const std::string&, const std::string&);
+
+    bool set_meter(const std::string& name, int value);  // does not throw if meter not found
+    bool set_event(const std::string& name, bool value); // does not throw if event not found
+
+    void increment_repeat(); // used in test only
+
+    // mementos functions:
+    /// Collect all the state changes, so that only small subset is returned to client
+    virtual void collateChanges(DefsDelta&) const = 0;
+    void incremental_changes(DefsDelta&, compound_memento_ptr& comp) const;
+
+    void set_memento(const NodeStateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeDefStatusDeltaMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const SuspendedMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeEventMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeMeterMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeLabelMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeAvisoMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeMirrorMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeQueueMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeGenericMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeQueueIndexMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeTriggerMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeCompleteMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeRepeatMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeRepeatIndexMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeLimitMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeInLimitMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeVariableMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeLateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeTodayMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeTimeMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeDayMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeCronMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeDateMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeZombieMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const NodeVerifyMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const FlagMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+
+    // Find functions: ============================================================
+    // Will search for a node by name(ie not a path) first on siblings, then on a parent
+    // then up the node tree, will stop at the suite .
+    virtual node_ptr find_node_up_the_tree(const std::string& name) const = 0;
+
+    // This is used to find relative nodes.
+    virtual node_ptr find_relative_node(const std::vector<std::string>& pathToNode) = 0;
+
+    /// Look for user,generated and repeat variables
+    /// Find variable corresponding to the given name, by search up the parent hierarchy
+    /// ** We need to distinguish between a variable the exists, but has an empty value
+    /// ** hence we return true if variable is found, and false otherwise
+    bool findParentVariableValue(const std::string& name, std::string& theValue) const;
+
+    /// Look for the parent generated variable only
+    bool find_parent_gen_variable_value(const std::string& name, std::string& theValue) const;
+
+    /// Only looks at user variables
+    /// Find variable corresponding to the given name, by search up the parent hierarchy
+    /// Use when we know that variable is user defined. This is more efficient than
+    /// calling findParentVariableValue.
+    /// *** We need to distinguish between a variable the exists, but has an empty value
+    /// *** hence we return true if variable is found, and false otherwise
+    bool findParentUserVariableValue(const std::string& name, std::string& theValue) const;
+
+    /// This function should be used, when we don't care about the distinctions between
+    /// a variable that exist but has a empty value, and variable not found.(still return empty string)
+    /// Useful when we want to return by reference
+    const std::string& find_parent_user_variable_value(const std::string& name) const;
+
+    /// Search up the hierarchy, simply checks for existence independent of variable value
+    bool user_variable_exists(const std::string& name) const;
+
+    virtual node_ptr findImmediateChild(const std::string& /*name*/, size_t& /*child_pos*/) const { return node_ptr(); }
+    virtual node_ptr find_immediate_child(const std::string_view&) const { return node_ptr(); }
+    virtual std::string find_node_path(const std::string& /*type*/, const std::string& /*name*/) const {
+        return std::string();
+    }
+    const Variable& findVariable(const std::string& name) const;
+    std::string find_parent_variable_sub_value(const std::string& name) const;
+    const Variable& find_parent_variable(const std::string& name) const;
+    virtual const Variable& findGenVariable(const std::string& name) const;
+    bool findVariableValue(const std::string& name, std::string& returnedValue) const;
+    bool findGenVariableValue(const std::string& name, std::string& returnedValue) const;
+
+    bool findVerify(const VerifyAttr&) const;
+    bool findLimit(const Limit&) const;
+    bool findLabel(const std::string& name) const;
+    const Label& find_label(const std::string& name) const;
+    bool findAviso(const std::string& name) const;
+    bool findMirror(const std::string& name) const;
+    const QueueAttr& find_queue(const std::string& name) const;
+    QueueAttr& findQueue(const std::string& name);
+    const GenericAttr& find_generic(const std::string& name) const;
+
+    limit_ptr find_limit(const std::string& name) const;
+    limit_ptr findLimitUpNodeTree(const std::string& name) const;
+    Limit* findLimitViaInLimit(const InLimit& l) const {
+        return inLimitMgr_.findLimitViaInLimit(l);
+    } // used in *test* only
+    bool findInLimitByNameAndPath(const InLimit& l) const {
+        return inLimitMgr_.findInLimitByNameAndPath(l);
+    } // use name,path,token,
+    const Repeat& findRepeat(const std::string& name) const;
+    const Meter& findMeter(const std::string& name) const;
+    Meter& find_meter(const std::string& name);
+    const Event& findEvent(const Event&) const;
+    const Event& findEventByNameOrNumber(const std::string& name) const;
+
+    const ZombieAttr& findZombie(ecf::Child::ZombieType) const;
+    bool findParentZombie(ecf::Child::ZombieType, ZombieAttr&) const;
+
+    /// Finds the referenced node. The node path can be relative or absolute or a extern path
+    /// however if its an extern path, and corresponding suite is loaded, but we still
+    /// can't find the path, then an error is returned
+    node_ptr findReferencedNode(const std::string& nodePath, std::string& errorMsg) const;
+    node_ptr findReferencedNode(const std::string& nodePath, const std::string& externObj, std::string& errorMsg) const;
+
+    /// return true if we can find a event, meter, user, repeat or generated variable with the given name
+    bool findExprVariable(const std::string& name); // update event & meter as used in trigger for simulator
+
+    /// The status of family/suite is the inherited most significant status of all its children
+    enum TraverseType { IMMEDIATE_CHILDREN, HIERARCHICAL };
+    virtual NState::State computedState(Node::TraverseType) const = 0;
+
+    /// Sets the most significant state up the node tree. Ignores tasks
+    void set_most_significant_state_up_node_tree();
+
+    /// For use with GUI only
+    void set_graphic_ptr(void* p) { graphic_ptr_ = p; }
+    void* graphic_ptr() const { return graphic_ptr_; }
+
+    /// returns the position of this node relative to its peers
+    /// If not attached to parent returns std::numeric_limits<std::size_t>::max();
+    size_t position() const;
+
+    void stats(NodeStats&);
+
+    /// called at the end of state change function
+    /// ** Every time we set the state on a nodecontainer, we call handleStateChange
+    /// ** This by default works out the most significant state of the children
+    /// ** ie. the computed state. Hence setting the state on Suite/Family is really
+    /// ** meaningless, since it will always be the computed state.
+    /// ** For Aliases we only update the limits, and do not bubble up state changes
+    virtual void handleStateChange() = 0; // can end up changing state
+
+    /// update change numbers to force sync
+    virtual void force_sync() {};
+
+    /// check trigger expression have nodes and events,meter,repeat that resolve
+    bool check_expressions(Ast*, const std::string& expr, bool trigger, std::string& errorMsg) const;
+
+    /// check trigger expression have nodes and events,meter,repeat that resolve, will throw for error
+    std::unique_ptr<AstTop>
+    parse_and_check_expressions(const std::string& expr, bool trigger, const std::string& context);
+
+    virtual boost::posix_time::time_duration sum_runtime() { return sc_rt_; }
+
+    void set_state_change_no(unsigned int x) { state_change_no_ = x; }
+    unsigned int state_change_no() const { return state_change_no_; }
+
+protected:
+    void set_runtime(const boost::posix_time::time_duration& rt) { sc_rt_ = rt; }
+
+    /// Used in conjunction with Node::position()
+    /// returns std::numeric_limits<std::size_t>::max() if child not found
+    virtual size_t child_position(const Node*) const = 0;
+
+    /// The set_state_only() requires a correctly formed tree, ie since it needs suite()/calendar
+    /// to initialise the duration. We need a way set the state directly. For initialization
+    void set_state_only(NState::State s) { st_.first.setState(s); }
+
+    /// based on the *current* state increment or decrements the limits
+    /// Should *only* be called within a task
+    virtual void update_limits() = 0;
+
+    /// After job submission we need to increment the in limit, to indicate that a
+    /// resource is consumed. The set ensure we only update once during a traversal
+    void incrementInLimit(std::set<Limit*>& limitSet);
+
+    /// After job aborts or completes we need to decrement the in limit, to indicate that
+    /// additional resource is available. The set ensure we only update once during a traversal
+    void decrementInLimit(std::set<Limit*>& limitSet);
+    void decrementInLimitForSubmission(std::set<Limit*>& limitSet);
+
+    friend class InLimitMgr;
+    bool check_in_limit() const { return inLimitMgr_.inLimit(); }
+    bool check_in_limit_up_node_tree() const;
+
+    friend class Defs;
+    friend class Family;
+    friend class NodeContainer;
+    friend class HoldingDayOrDate;
+    virtual bool doDeleteChild(Node*) { return false; }
+
+    /// This function is called as a part of handling state change.
+    /// When a suite completes it can be re-queued due to:
+    ///   o repeat attribute
+    ///     When going up the hierarchy we should not reset Repeats
+    ///     The inner repeat must complete before parent repeat (if any) is incremented
+    ///     (i.e Mimics a nested loops)
+    ///  o Time, Today, cron attributes
+    ///
+    ///  Otherwise we need to traverse up the node tree and set the most significant state
+    void requeueOrSetMostSignificantStateUpNodeTree();
+
+    node_ptr non_const_this() const;
+
+    void update_repeat_genvar() const;
+
+    // returns node state without trailing new lines
+    virtual void write_state(std::string& ret, bool& added_comment_char) const;
+    void add_comment_char(std::string& ret, bool& added_comment_char) const;
+    virtual void read_state(const std::string& line, const std::vector<std::string>& lineTokens);
+
+    // Observer notifications
+protected:
+    std::vector<AbstractObserver*> observers_;
+    void notify_delete();
+    void checkForLateness(const ecf::Calendar&);
+    void check_for_lateness(const ecf::Calendar& c, const ecf::LateAttr*);
+
+public:
+    void notify_start(const std::vector<ecf::Aspect::Type>& aspects);
+    void notify(const std::vector<ecf::Aspect::Type>& aspects);
+    void attach(AbstractObserver*);
+    void detach(AbstractObserver*);
+    bool is_observed(AbstractObserver*) const; // return true if we have this observer in our list
+
+private:
+    bool why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const;
+    /// Function used as a part of trigger and complete expressions.
+    /// The search pattern is event,meter,user-variable,repeat, generated-variable
+    int findExprVariableValue(const std::string& name) const;
+    int findExprVariableValueAndPlus(const std::string& name, int val) const;
+    int findExprVariableValueAndMinus(const std::string& name, int val) const;
+    int findExprVariableValueAndType(const std::string& name, std::string& varType) const;
+    void findExprVariableAndPrint(const std::string& name, std::ostream& os) const;
+    friend class VariableHelper;
+    friend class AstParentVariable;
+    bool update_variable(const std::string& name, const std::string& value);
+
+private:
+    void add_trigger_expression(const Expression&);  // Can throw std::runtime_error
+    void add_complete_expression(const Expression&); // Can throw std::runtime_error
+    const Event& findEventByNumber(int number) const;
+    const Event& findEventByName(const std::string& name) const;
+    bool set_meter_used_in_trigger(const std::string& name);
+    bool set_event_used_in_trigger(const std::string& name);
+
+    /// When the begin/re-queue is called this function will initialise the state
+    /// on the node. If node has a default state this is applied to the node, and
+    /// hierarchically to all the children
+    /// Can also clear suspended see re-queue()
+    void initState(int clear_suspended_in_child_nodes, bool log_state_changes = true);
+
+    void delete_misc_attrs_if_empty();
+
+    /// Under the hybrid calendar some time dependent attributes may not be applicable
+    /// i.e if day,date,cron attributes does correspond to 24 hours of today, then we
+    /// need make them as complete.
+    void markHybridTimeDependentsAsComplete();
+    bool testTimeDependenciesForRequeue();
+    bool calendar_changed_timeattrs(const ecf::Calendar& c, Node::Calendar_args&);
+    bool holding_day_or_date(const ecf::Calendar& c) const;
+    void do_requeue_time_attrs(bool reset_next_time_slot, bool reset_relative_duration, Requeue_args::Requeue_t);
+    bool has_time_dependencies() const;
+
+private: // allow simulator access
+    friend class ecf::DefsAnalyserVisitor;
+    friend class ecf::FlatAnalyserVisitor;
+    friend class ecf::SimulatorVisitor;
+    friend class ecf::Simulator;
+    std::vector<Meter>& ref_meters() { return meters_; } // allow simulator set meter value
+    std::vector<Event>& ref_events() { return events_; } // allow simulator set event value
+    std::vector<QueueAttr>& ref_queues();                // allow simulator set event value
+
+    /// Note: If the complete expression evaluation fails. we should continue resolving dependencies
+    ///       If the complete expression evaluation evaluates, then we set node to complete
+    bool evaluateComplete() const;
+    bool evaluateTrigger() const;
+    bool timeDependenciesFree() const;
+
+    AstTop* completeAst(std::string& errorMsg) const; // Will create AST on demand
+    AstTop* triggerAst(std::string& errorMsg) const;  // Will create AST on demand
+
+private:
+    bool check_for_auto_archive(const ecf::Calendar& calendar) const;
+    bool checkForAutoCancel(const ecf::Calendar& calendar) const;
+
+private: // All mementos access
+    friend class CompoundMemento;
+    void clear(); /// Clear *ALL* internal attributes
+    void delete_attributes();
+
+private: /// For use by python interface,
+    friend void export_Node();
+    friend void export_Task();
+    friend void export_SuiteAndFamily();
+    std::vector<Meter>::const_iterator meter_begin() const { return meters_.begin(); }
+    std::vector<Meter>::const_iterator meter_end() const { return meters_.end(); }
+    std::vector<Event>::const_iterator event_begin() const { return events_.begin(); }
+    std::vector<Event>::const_iterator event_end() const { return events_.end(); }
+    std::vector<Label>::const_iterator label_begin() const { return labels_.begin(); }
+    std::vector<Label>::const_iterator label_end() const { return labels_.end(); }
+    std::vector<ecf::AvisoAttr>::const_iterator aviso_begin() const { return avisos_.begin(); }
+    std::vector<ecf::AvisoAttr>::const_iterator aviso_end() const { return avisos_.end(); }
+    std::vector<ecf::MirrorAttr>::const_iterator mirror_begin() const { return mirrors_.begin(); }
+    std::vector<ecf::MirrorAttr>::const_iterator mirror_end() const { return mirrors_.end(); }
+    std::vector<ecf::TimeAttr>::const_iterator time_begin() const { return times_.begin(); }
+    std::vector<ecf::TimeAttr>::const_iterator time_end() const { return times_.end(); }
+    std::vector<ecf::TodayAttr>::const_iterator today_begin() const { return todays_.begin(); }
+    std::vector<ecf::TodayAttr>::const_iterator today_end() const { return todays_.end(); }
+    std::vector<DateAttr>::const_iterator date_begin() const { return dates_.begin(); }
+    std::vector<DateAttr>::const_iterator date_end() const { return dates_.end(); }
+    std::vector<DayAttr>::const_iterator day_begin() const { return days_.begin(); }
+    std::vector<DayAttr>::const_iterator day_end() const { return days_.end(); }
+    std::vector<ecf::CronAttr>::const_iterator cron_begin() const { return crons_.begin(); }
+    std::vector<ecf::CronAttr>::const_iterator cron_end() const { return crons_.end(); }
+    std::vector<ZombieAttr>::const_iterator zombie_begin() const;
+    std::vector<ZombieAttr>::const_iterator zombie_end() const;
+    std::vector<VerifyAttr>::const_iterator verify_begin() const;
+    std::vector<VerifyAttr>::const_iterator verify_end() const;
+    std::vector<QueueAttr>::const_iterator queue_begin() const;
+    std::vector<QueueAttr>::const_iterator queue_end() const;
+    std::vector<GenericAttr>::const_iterator generic_begin() const;
+    std::vector<GenericAttr>::const_iterator generic_end() const;
+    std::vector<Variable>::const_iterator variable_begin() const { return vars_.begin(); }
+    std::vector<Variable>::const_iterator variable_end() const { return vars_.end(); }
+    std::vector<limit_ptr>::const_iterator limit_begin() const { return limits_.begin(); }
+    std::vector<limit_ptr>::const_iterator limit_end() const { return limits_.end(); }
+    std::vector<InLimit>::const_iterator inlimit_begin() const { return inLimitMgr_.inlimit_begin(); }
+    std::vector<InLimit>::const_iterator inlimit_end() const { return inLimitMgr_.inlimit_end(); }
+    std::string to_string() const; // For python interface
+
+private:
+    Node* parent_{nullptr}; // *NOT* persisted must be set by the parent class
+    std::string n_;
+    boost::posix_time::time_duration
+        sc_rt_; // state change runtime, Used to order peers, no persistence in cereal only defs.
+    std::pair<NState, boost::posix_time::time_duration> st_{
+        NState(),
+        boost::posix_time::time_duration(0, 0, 0, 0)}; // state and duration since suite start when state changed
+    DState d_st_;                                      // default value is QUEUED
+
+    std::vector<Variable> vars_;
+    mutable std::unique_ptr<Expression> c_expr_; // can only have one complete expression
+    mutable std::unique_ptr<Expression> t_expr_; // can only have one trigger expression
+
+    std::vector<Meter> meters_;
+    std::vector<Event> events_;
+    std::vector<Label> labels_;
+    std::vector<ecf::AvisoAttr> avisos_;
+    std::vector<ecf::MirrorAttr> mirrors_;
+
+    std::vector<ecf::TimeAttr> times_;
+    std::vector<ecf::TodayAttr> todays_;
+    std::vector<ecf::CronAttr> crons_;
+    std::vector<DateAttr> dates_;
+    std::vector<DayAttr> days_;
+
+    std::unique_ptr<ecf::LateAttr> late_;   // Can only have one late attribute per node
+    std::unique_ptr<MiscAttrs> misc_attrs_; // VerifyAttr(used for statistics and test verification) & Zombies
+    Repeat repeat_;                         // each node can only have one repeat. By value, since has pimpl
+
+    std::vector<limit_ptr> limits_; // Ptrs since many in-limits can point to a single limit
+    InLimitMgr inLimitMgr_{this};   // manages the inlimit
+
+    ecf::Flag flag_;
+
+    std::unique_ptr<ecf::AutoCancelAttr> auto_cancel_;   // Can only have 1 auto cancel per node
+    std::unique_ptr<ecf::AutoArchiveAttr> auto_archive_; // Can only have 1 auto archive per node
+    std::unique_ptr<ecf::AutoRestoreAttr> auto_restore_; // Can only have 1 autorestore per node
+    void* graphic_ptr_{nullptr};                         // for use with the gui only
+
+    unsigned int state_change_no_{
+        0}; // *not* persisted, only used on server side,Used to indicate addition or deletion of attribute
+    unsigned int variable_change_no_{0};  // *not* persisted, placed here rather than Variable, to save memory
+    unsigned int suspended_change_no_{0}; // *not* persisted,
+
+#ifdef DEBUG_JOB_SUBMISSION_INTERVAL
+    boost::posix_time::ptime submit_to_complete_duration_; // *not* persisted
+#endif
+
+    bool suspended_{false};
+
+    friend class MiscAttrs;
+
+private:
+    // conditionally save to cut down on client/server bandwidth.
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_node_Node_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeAdd.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeAdd.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeAdd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeAdd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,450 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Message.hpp"
+#include "ecflow/core/Stl.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/MiscAttrs.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool Node::update_variable(const std::string& name, const std::string& value) {
+    auto found = ecf::algorithm::find_by_name(vars_, name);
+
+    if (found == std::end(vars_)) {
+        return false;
+    }
+
+    found->set_value(value);
+    if (0 == Ecf::debug_level()) {
+        std::cerr << "Node::addVariable: Variable of name '" << name << "' already exist for node " << debugNodePath()
+                  << " updating with value '" << value << "'\n";
+    }
+    return true;
+}
+
+void Node::addVariable(const Variable& v) {
+    state_change_no_ = Ecf::incr_state_change_no();
+    if (update_variable(v.name(), v.theValue()))
+        return;
+    if (vars_.capacity() == 0)
+        vars_.reserve(5);
+    vars_.push_back(v);
+}
+
+void Node::add_variable(const std::string& name, const std::string& value) {
+    state_change_no_ = Ecf::incr_state_change_no();
+    if (update_variable(name, value))
+        return;
+    if (vars_.capacity() == 0)
+        vars_.reserve(5);
+    vars_.emplace_back(name, value);
+}
+
+void Node::add_variable_bypass_name_check(const std::string& name, const std::string& value) {
+    state_change_no_ = Ecf::incr_state_change_no();
+    if (update_variable(name, value))
+        return;
+    if (vars_.capacity() == 0)
+        vars_.reserve(5);
+    vars_.emplace_back(name, value, false);
+}
+
+void Node::add_variable_int(const std::string& name, int some_int) {
+    std::string value = ecf::convert_to<std::string>(some_int);
+    add_variable(name, value);
+}
+
+void Node::add_trigger(const std::string& string_expression) {
+    add_trigger_expression(Expression(string_expression));
+}
+void Node::add_complete(const std::string& string_expression) {
+    add_complete_expression(Expression(string_expression));
+}
+void Node::add_trigger_expr(const Expression& expr) {
+    add_trigger_expression(expr);
+}
+void Node::add_complete_expr(const Expression& expr) {
+    add_complete_expression(expr);
+}
+void Node::add_trigger_expression(const Expression& t) {
+    if (t_expr_) {
+        std::stringstream ss;
+        ss << "Node::add_trigger_expression. A Node(" << absNodePath() << " can only have one trigger ";
+        ss << "to add large triggers use multiple calls to Node::add_part_trigger( PartExpression('t1 == complete') )";
+        throw std::runtime_error(ss.str());
+    }
+    if (isSuite())
+        throw std::runtime_error("Cannot add trigger on a suite");
+
+    t_expr_          = std::make_unique<Expression>(t);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::add_complete_expression(const Expression& t) {
+    if (c_expr_) {
+        std::stringstream ss;
+        ss << "Node::add_complete_expression. A Node(" << absNodePath() << " can only have one complete expression ";
+        ss << "to add large complete expressions use multiple calls to Node::add_part_complete( PartExpression('t1 == "
+              "complete') )";
+        throw std::runtime_error(ss.str());
+    }
+    if (isSuite())
+        throw std::runtime_error("Cannot add complete trigger on a suite");
+
+    c_expr_          = std::make_unique<Expression>(t);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::py_add_trigger_expr(const std::vector<PartExpression>& vec) {
+    if (t_expr_) {
+        if (isSuite())
+            throw std::runtime_error("Cannot add trigger on a suite");
+        t_expr_->add_expr(vec);
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+    else {
+        Expression expr;
+        for (const auto& i : vec)
+            expr.add(i);
+        add_trigger_expression(expr);
+    }
+}
+
+void Node::py_add_complete_expr(const std::vector<PartExpression>& vec) {
+    if (c_expr_) {
+        if (isSuite())
+            throw std::runtime_error("Cannot add complete on a suite");
+        c_expr_->add_expr(vec);
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+    else {
+        Expression expr;
+        for (const auto& i : vec)
+            expr.add(i);
+        add_complete_expression(expr);
+    }
+}
+
+void Node::add_part_trigger(const PartExpression& part) {
+    if (isSuite())
+        throw std::runtime_error("Cannot add trigger on a suite");
+
+    if (!t_expr_)
+        t_expr_ = std::make_unique<Expression>();
+    t_expr_->add(part);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+void Node::add_part_complete(const PartExpression& part) {
+    if (isSuite())
+        throw std::runtime_error("Cannot add complete trigger on a suite");
+
+    if (!c_expr_)
+        c_expr_ = std::make_unique<Expression>();
+    c_expr_->add(part);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addTime(const ecf::TimeAttr& t) {
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::addTime\n";
+#endif
+
+    if (isSuite()) {
+        throw std::runtime_error("Cannot add time based dependency on a suite");
+    }
+
+    times_.push_back(t);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addToday(const ecf::TodayAttr& t) {
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::addToday()\n";
+#endif
+
+    if (isSuite()) {
+        throw std::runtime_error("Cannot add time based dependency on a suite");
+    }
+
+    todays_.push_back(t);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addDate(const DateAttr& d) {
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::addDate()\n";
+#endif
+
+    // By disallowing what effect would it have on existing suites ?
+    if (isSuite()) {
+        throw std::runtime_error("Cannot add time based dependency on a suite"); // Added at 4.0.2
+    }
+
+    dates_.push_back(d);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addDay(const DayAttr& d) {
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::addDay\n";
+#endif
+
+    // By disallowing what effect would it have on existing suites ?
+    if (isSuite()) {
+        throw std::runtime_error("Cannot add time based dependency on a suite"); // Added at 4.0.2
+    }
+
+    days_.push_back(d);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addCron(const CronAttr& d) {
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::addCron()\n";
+#endif
+
+    if (d.time().isNULL()) {
+        throw std::runtime_error("Node::addCron: The cron is in-complete, no time specified");
+    }
+    if (d.time().hasIncrement() && !repeat_.empty()) {
+        std::stringstream ss;
+        ss << "Node::addCron: Node " << absNodePath()
+           << " already has a repeat. Inappropriate to add two looping structures at the same level\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    crons_.push_back(d);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addLabel(const Label& l) {
+    if (findLabel(l.name())) {
+        std::stringstream ss;
+        ss << "Add Label failed: Duplicate label of name '" << l.name() << "' already exist for node "
+           << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    labels_.push_back(l);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::add_label(const std::string& name, const std::string& value, const std::string& new_value, bool check) {
+    if (check && findLabel(name)) {
+        std::stringstream ss;
+        ss << "Add Label failed: Duplicate label of name '" << name << "' already exist for node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    labels_.emplace_back(name, value, new_value, check);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addMeter(const Meter& m, bool check) {
+    if (check) {
+        const Meter& meter = findMeter(m.name());
+        if (!meter.empty()) {
+            std::stringstream ss;
+            ss << "Add Meter failed: Duplicate Meter of name '" << m.name() << "' already exist for node "
+               << debugNodePath();
+            throw std::runtime_error(ss.str());
+        }
+    }
+    meters_.push_back(m);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::add_meter(const std::string& name, int min, int max, int color_change, int value, bool check) {
+    if (check) {
+        const Meter& meter = findMeter(name);
+        if (!meter.empty()) {
+            std::stringstream ss;
+            ss << "Add Meter failed: Duplicate Meter of name '" << name << "' already exist for node "
+               << debugNodePath();
+            throw std::runtime_error(ss.str());
+        }
+    }
+    meters_.emplace_back(name, min, max, color_change, value, check);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addEvent(const Event& e, bool check) {
+    if (check) {
+        const Event& event = findEvent(e);
+        if (!event.empty()) {
+            std::stringstream ss;
+            ss << "Add Event failed: Duplicate Event of name '" << e.name_or_number() << "' already exist for node "
+               << debugNodePath();
+            throw std::runtime_error(ss.str());
+        }
+    }
+    events_.push_back(e);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addAviso(const AvisoAttr& a) {
+    if (!avisos_.empty()) {
+        throw std::runtime_error(
+            ecf::Message("Unable to add Aviso '", a.name(), "'. Only 1 Aviso allowed per node.").str());
+    }
+    avisos_.push_back(a);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addMirror(const MirrorAttr& m) {
+    if (!mirrors_.empty()) {
+        throw std::runtime_error(
+            ecf::Message("Unable to add Mirror '", m.name(), "'. Only 1 Mirror allowed per node.").str());
+    }
+    mirrors_.push_back(m);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addLimit(const Limit& l, bool check) {
+    if (check && findLimit(l)) {
+        std::stringstream ss;
+        ss << "Add Limit failed: Duplicate Limit of name '" << l.name() << "' already exist for node "
+           << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    limit_ptr the_limit = std::make_shared<Limit>(l);
+    the_limit->set_node(this);
+    limits_.push_back(the_limit);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addInLimit(const InLimit& l, bool check) {
+    inLimitMgr_.addInLimit(l, check);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+static void throwIfRepeatAlreadyExists(Node* node) {
+    if (!node->repeat().empty()) {
+        std::stringstream ss;
+        ss << "Add Repeat failed: Repeat of name '" << node->repeat().name() << "' already exist for node "
+           << node->debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+
+    if (!node->crons().empty()) {
+        std::stringstream ss;
+        ss << "Node::addRepeat: Node " << node->absNodePath()
+           << " already has a cron. Inappropriate to add two looping structures at the same level\n";
+        throw std::runtime_error(ss.str());
+    }
+}
+void Node::addRepeat(Repeat&& r) {
+    throwIfRepeatAlreadyExists(this);
+    repeat_ = std::move(r);
+    repeat_.update_repeat_genvar();
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+void Node::addRepeat(const Repeat& r) {
+    throwIfRepeatAlreadyExists(this);
+    repeat_ = r;
+    repeat_.update_repeat_genvar();
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::addAutoCancel(const ecf::AutoCancelAttr& ac) {
+    if (auto_archive_) {
+        std::stringstream ss;
+        ss << "Node::addAutoCancel: Cannot add autocancel and autoarchive on the same node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    if (auto_cancel_) {
+        std::stringstream ss;
+        ss << "Node::addAutoCancel: A node can only have one autocancel, see node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    auto_cancel_     = std::make_unique<ecf::AutoCancelAttr>(ac);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::add_autoarchive(const ecf::AutoArchiveAttr& aa) {
+    if (auto_cancel_) {
+        std::stringstream ss;
+        ss << "Node::add_autoarchive: Cannot add autocancel and autoarchive on the same node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    if (auto_archive_) {
+        std::stringstream ss;
+        ss << "Node::add_autoarchive: A node can only have one autoarchive, see node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    auto_archive_    = std::make_unique<ecf::AutoArchiveAttr>(aa);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::add_autorestore(const ecf::AutoRestoreAttr& ar) {
+    if (auto_restore_) {
+        std::stringstream ss;
+        ss << "Node::add_auto_restore: Can only have one autorestore per node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    auto_restore_ = std::make_unique<ecf::AutoRestoreAttr>(ar);
+    auto_restore_->set_node(this);
+    state_change_no_ = Ecf::incr_state_change_no(); // Only add where used in AlterCmd
+}
+
+void Node::addLate(const ecf::LateAttr& l) {
+    if (!late_) {
+        late_            = std::make_unique<ecf::LateAttr>(l);
+        state_change_no_ = Ecf::incr_state_change_no();
+        return;
+    }
+    throw std::runtime_error("Add Late failed: A node can only have one Late attribute, see node " + debugNodePath());
+}
+
+void Node::addVerify(const VerifyAttr& v) {
+    if (misc_attrs_) {
+        misc_attrs_->addVerify(v); // can throw
+        return;
+    }
+    misc_attrs_ = std::make_unique<MiscAttrs>(this);
+    misc_attrs_->addVerify(v);
+}
+
+void Node::addZombie(const ZombieAttr& z) {
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::addZombie()\n";
+#endif
+
+    if (misc_attrs_) {
+        misc_attrs_->addZombie(z); // can throw
+        return;
+    }
+    misc_attrs_ = std::make_unique<MiscAttrs>(this);
+    misc_attrs_->addZombie(z);
+}
+
+void Node::add_queue(const QueueAttr& q) {
+    if (!misc_attrs_)
+        misc_attrs_ = std::make_unique<MiscAttrs>(this);
+    misc_attrs_->add_queue(q);
+}
+
+void Node::add_generic(const GenericAttr& q) {
+    if (!misc_attrs_)
+        misc_attrs_ = std::make_unique<MiscAttrs>(this);
+    misc_attrs_->add_generic(q);
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeChange.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeChange.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeChange.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeChange.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,315 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Stl.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/AvisoParser.hpp"
+#include "ecflow/node/parser/MirrorParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+void Node::changeVariable(const std::string& name, const std::string& value) {
+    auto found = ecf::algorithm::find_by_name(vars_, name);
+
+    if (found == std::end(vars_)) {
+        throw std::runtime_error("Node::changeVariable: Could not find variable " + name);
+    }
+
+    found->set_value(value);
+    variable_change_no_ = Ecf::incr_state_change_no();
+}
+
+bool Node::set_event(const std::string& event_name_or_number, bool value) {
+    if (events_.empty()) {
+        return false;
+    }
+
+    // find by name first
+    {
+        auto found = ecf::algorithm::find_by_name(events_, event_name_or_number);
+        if (found != std::end(events_)) {
+            found->set_value(value);
+            return true;
+        }
+    }
+
+    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
+    if (event_name_or_number.find_first_of(Str::NUMERIC()) == 0) {
+        try {
+            auto number = ecf::convert_to<int>(event_name_or_number);
+            auto found  = ecf::algorithm::find_by_number(events_, number);
+            if (found != std::end(events_)) {
+                found->set_value(value);
+                return true;
+            }
+        }
+        catch (const ecf::bad_conversion&) {
+        }
+    }
+    return false;
+}
+
+bool Node::set_event_used_in_trigger(const std::string& event_name_or_number) {
+    if (events_.empty()) {
+        return false;
+    }
+
+    // find by name first
+    {
+        auto found = ecf::algorithm::find_by_name(events_, event_name_or_number);
+        if (found != std::end(events_)) {
+            found->usedInTrigger(true);
+            return true;
+        }
+    }
+
+    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
+    if (event_name_or_number.find_first_of(Str::NUMERIC()) == 0) {
+        try {
+            auto number = ecf::convert_to<int>(event_name_or_number);
+            auto found  = ecf::algorithm::find_by_number(events_, number);
+            if (found != std::end(events_)) {
+                found->usedInTrigger(true);
+                return true;
+            }
+        }
+        catch (const ecf::bad_conversion&) {
+        }
+    }
+
+    return false;
+}
+void Node::changeEvent(const std::string& event_name_or_number, const std::string& setOrClear) {
+    bool value;
+    if (!setOrClear.empty()) {
+        if (setOrClear != Event::SET() && setOrClear != Event::CLEAR()) {
+            throw std::runtime_error("Node::changeEvent: Expected empty string, 'set' or 'clear' but found " +
+                                     setOrClear + " for event " + event_name_or_number);
+        }
+        value = (setOrClear == Event::SET());
+    }
+    else
+        value = true;
+
+    changeEvent(event_name_or_number, value);
+}
+
+void Node::changeEvent(const std::string& event_name_or_number, bool value) {
+    if (set_event(event_name_or_number, value))
+        return;
+    throw std::runtime_error("Node::changeEvent: Could not find event " + event_name_or_number);
+}
+
+bool Node::set_meter(const std::string& name, int value) {
+    auto found = ecf::algorithm::find_by_name(meters_, name);
+
+    if (found == std::end(meters_)) {
+        return false;
+    }
+
+    found->set_value(value);
+    return true;
+}
+bool Node::set_meter_used_in_trigger(const std::string& name) {
+    auto found = ecf::algorithm::find_by_name(meters_, name);
+
+    if (found == std::end(meters_)) {
+        return false;
+    }
+
+    found->usedInTrigger(true);
+    return true;
+}
+void Node::changeMeter(const std::string& meter_name, const std::string& value) {
+    int theValue = 0;
+    try {
+        theValue = ecf::convert_to<int>(value);
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error("Node::changeMeter expected integer value but found " + value);
+    }
+    changeMeter(meter_name, theValue);
+}
+
+void Node::changeMeter(const std::string& meter_name, int value) {
+    if (set_meter(meter_name, value))
+        return;
+    throw std::runtime_error("Node::changeMeter: Could not find meter " + meter_name);
+}
+
+void Node::changeLabel(const std::string& name, const std::string& value) {
+    auto found = ecf::algorithm::find_by_name(labels_, name);
+
+    if (found == std::end(labels_)) {
+        throw std::runtime_error("Node::changeLabel: Could not find label " + name);
+    }
+
+    found->set_new_value(value);
+}
+
+void Node::changeAviso(const std::string& name, const std::string& value) {
+    auto found = ecf::algorithm::find_by_name(avisos_, name);
+
+    if (found == std::end(avisos_)) {
+        throw std::runtime_error("Node::changeAviso: Could not find aviso " + name);
+    }
+
+    *found = AvisoParser::parse_aviso_line(value, name);
+
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::changeAviso(const std::string& name, const std::string& value, uint64_t revision) {
+    auto found = ecf::algorithm::find_by_name(avisos_, name);
+
+    if (found == std::end(avisos_)) {
+        throw std::runtime_error("Node::changeAviso: Could not find aviso " + name);
+    }
+
+    auto attr = AvisoParser::parse_aviso_line(value, name);
+    attr.set_revision(revision);
+
+    // The following delete/add enforces the reconfiguration of the attribute backend thread
+    this->deleteAviso(name); // delete the aviso if it exists (to avoid duplicates
+    this->addAviso(attr);
+
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::changeMirror(const std::string& name, const std::string& value) {
+    auto found = ecf::algorithm::find_by_name(mirrors_, name);
+
+    if (found == std::end(mirrors_)) {
+        throw std::runtime_error("Node::changeMirror: Could not find mirror " + name);
+    }
+
+    auto attr = MirrorParser::parse_mirror_line(value, name, this);
+
+    // The following delete/add enforces the reconfiguration of the attribute backend thread
+    this->deleteMirror(name); // delete the mirror if it exists (to avoid duplicates
+    this->addMirror(attr);
+
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::changeTrigger(const std::string& expression) {
+    (void)parse_and_check_expressions(expression, true /*trigger*/, "Node::changeTrigger:"); // will throw for errors
+    deleteTrigger();
+    add_trigger(expression);
+}
+
+void Node::changeComplete(const std::string& expression) {
+    (void)parse_and_check_expressions(expression, false /*complete*/, "Node::changeComplete:"); // will throw for errors
+    deleteComplete();
+    add_complete(expression);
+}
+
+void Node::changeRepeat(const std::string& value) {
+    if (repeat_.empty())
+        throw std::runtime_error("Node::changeRepeat: Could not find repeat on " + absNodePath());
+    repeat_.change(value); // this can throw std::runtime_error
+}
+
+void Node::increment_repeat() {
+    if (repeat_.empty())
+        throw std::runtime_error("Node::increment_repeat: Could not find repeat on " + absNodePath());
+    repeat_.increment();
+}
+
+void Node::changeLimitMax(const std::string& name, const std::string& maxValue) {
+    int theValue = 0;
+    try {
+        theValue = ecf::convert_to<int>(maxValue);
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error("Node::changeLimitMax expected integer value but found " + maxValue);
+    }
+    changeLimitMax(name, theValue);
+}
+
+void Node::changeLimitMax(const std::string& name, int maxValue) {
+    limit_ptr limit = find_limit(name);
+    if (!limit.get())
+        throw std::runtime_error("Node::changeLimitMax: Could not find limit " + name);
+    limit->setLimit(maxValue);
+}
+
+void Node::changeLimitValue(const std::string& name, const std::string& value) {
+    int theValue = 0;
+    try {
+        theValue = ecf::convert_to<int>(value);
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error("Node::changeLimitValue expected integer value but found " + value);
+    }
+    changeLimitValue(name, theValue);
+}
+
+void Node::changeLimitValue(const std::string& name, int value) {
+    limit_ptr limit = find_limit(name);
+    if (!limit.get())
+        throw std::runtime_error("Node::changeLimitValue: Could not find limit " + name);
+    limit->setValue(value);
+}
+
+void Node::changeDefstatus(const std::string& theState) {
+    if (!DState::isValid(theState)) {
+        throw std::runtime_error("Node::changeDefstatus expected a state but found " + theState);
+    }
+
+    // Updates state_change_no on the defStatus
+    d_st_.setState(DState::toState(theState));
+}
+
+void Node::changeLate(const ecf::LateAttr& late) {
+    late_            = std::make_unique<ecf::LateAttr>(late);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::change_time(const std::string& old, const std::string& new_time) {
+    TimeAttr old_attr(TimeSeries::create(old));      // can throw if parse fails
+    TimeAttr new_attr(TimeSeries::create(new_time)); // can throw if parse fails
+
+    // Don't use '==' since that compares additional state like free_
+    auto found = ecf::algorithm::find_by(times_, [&](const auto& item) { return item.structureEquals(old_attr); });
+
+    if (found == std::end(times_)) {
+        throw std::runtime_error("Node::change_time : Cannot find time attribute: ");
+    }
+
+    *found           = new_attr;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::change_today(const std::string& old, const std::string& new_time) {
+    TodayAttr old_attr(TimeSeries::create(old));      // can throw if parse fails
+    TodayAttr new_attr(TimeSeries::create(new_time)); // can throw if parse fails
+
+    // Don't use '==' since that compares additional state like free_
+    auto found = ecf::algorithm::find_by(todays_, [&](const auto& item) { return item.structureEquals(old_attr); });
+
+    if (found == std::end(todays_)) {
+        throw std::runtime_error("Node::change_today : Cannot find time attribute: ");
+    }
+
+    *found           = new_attr;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeContainer.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeContainer.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeContainer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeContainer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1416 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/NodeContainer.hpp"
+
+#include <cassert>
+#include <limits>
+#include <sstream>
+#include <stdexcept>
+
+#include <boost/filesystem/operations.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/DefsDelta.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/NodeState.hpp"
+#include "ecflow/node/NodeTreeVisitor.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/move_peer.hpp"
+
+using namespace ecf;
+using namespace std;
+
+///////////////////////////////////////////////////////////////////////////////////////////
+// #define DEBUG_FIND_NODE 1
+// #define DEBUG_DEPENDENCIES 1
+
+/////////////////////////////////////////////////////////////////////////////////////////
+NodeContainer::NodeContainer(const std::string& name, bool check) : Node(name, check) {
+}
+
+NodeContainer::NodeContainer() = default;
+
+void NodeContainer::copy(const NodeContainer& rhs) {
+    for (const auto& r_n : rhs.nodes_) {
+        Task* task = r_n->isTask();
+        if (task) {
+            task_ptr task_copy = std::make_shared<Task>(*task);
+            task_copy->set_parent(this);
+            nodes_.push_back(task_copy);
+        }
+        else {
+            Family* family = r_n->isFamily();
+            assert(family);
+            family_ptr family_copy = std::make_shared<Family>(*family);
+            family_copy->set_parent(this);
+            nodes_.push_back(family_copy);
+        }
+    }
+}
+
+NodeContainer::NodeContainer(const NodeContainer& rhs) : Node(rhs) {
+    copy(rhs);
+}
+
+NodeContainer& NodeContainer::operator=(const NodeContainer& rhs) {
+    if (this != &rhs) {
+        Node::operator=(rhs);
+        nodes_.clear();
+        copy(rhs);
+        order_state_change_no_      = 0;
+        add_remove_state_change_no_ = Ecf::incr_state_change_no();
+    }
+    return *this;
+}
+
+NodeContainer::~NodeContainer() = default;
+
+bool NodeContainer::check_defaults() const {
+    if (order_state_change_no_ != 0)
+        throw std::runtime_error("NodeContainer::check_defaults(): order_state_change_no_ != 0");
+    if (add_remove_state_change_no_ != 0)
+        throw std::runtime_error("NodeContainer::check_defaults(): add_remove_state_change_no_ != 0");
+    return Node::check_defaults();
+}
+
+void NodeContainer::accept(ecf::NodeTreeVisitor& v) {
+    v.visitNodeContainer(this);
+    for (const auto& n : nodes_) {
+        n->accept(v);
+    }
+}
+
+void NodeContainer::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
+    v.visitNodeContainer(this);
+}
+
+void NodeContainer::begin() {
+    restore_on_begin_or_requeue();
+    Node::begin();
+    for (const auto& n : nodes_) {
+        n->begin();
+    }
+    handle_defstatus_propagation();
+}
+
+void NodeContainer::reset() {
+    Node::reset();
+    for (const auto& n : nodes_) {
+        n->reset();
+    }
+}
+
+void NodeContainer::handle_migration(const ecf::Calendar& c) {
+    Node::handle_migration(c);
+    for (const auto& n : nodes_) {
+        n->handle_migration(c);
+    }
+}
+
+void NodeContainer::requeue(Requeue_args& args) {
+    //	LOG(Log::DBG,"   " << debugType() << "::requeue() " << absNodePath() << " resetRepeats = " << resetRepeats);
+
+    restore_on_begin_or_requeue();
+    Node::requeue(args);
+
+    // For negative numbers, do nothing, i.e. do not clear
+    if (args.clear_suspended_in_child_nodes_ >= 0)
+        args.clear_suspended_in_child_nodes_++;
+
+    // If the node `default status` == COMPLETE, we don't log the change of state when re-queueing the descendants.
+    // Without this optimization, all children would change state to QUEUED, and eventually change back to COMPLETE.
+    // This avoids flooding the log with unnecessary messages regarding several thousand children
+    // (e.g. as it happens in operations). See ECFLOW-1239 for details.
+    bool log_state_changes_descendents = (d_st_ != DState::COMPLETE);
+
+    Node::Requeue_args largs(args.requeue_t,
+                             true /* reset repeats, Moot for tasks */,
+                             args.clear_suspended_in_child_nodes_,
+                             args.reset_next_time_slot_,
+                             true /* reset relative duration */,
+                             log_state_changes_descendents);
+
+    for (const auto& n : nodes_) {
+        n->requeue(largs);
+    }
+
+    handle_defstatus_propagation();
+}
+
+void NodeContainer::requeue_time_attrs() {
+    Node::requeue_time_attrs();
+    for (const auto& n : nodes_) {
+        n->requeue_time_attrs();
+    }
+}
+
+void NodeContainer::reset_late_event_meters() {
+    Node::reset_late_event_meters();
+    for (const auto& n : nodes_) {
+        n->reset_late_event_meters();
+    }
+}
+
+void NodeContainer::handle_defstatus_propagation() {
+    if (d_st_ == DState::COMPLETE) {
+        /// A defstatus of complete and *ONLY* complete should always be applied
+        /// hierarchically downwards
+        setStateOnlyHierarchically(NState::COMPLETE);
+    }
+    else if (d_st_ == DState::default_state()) {
+        /// Reflect that the status of the children.
+        /// *However* do NOT override the defstatus setting
+        NState::State theSignificantStateOfImmediateChildren = computedState(Node::IMMEDIATE_CHILDREN);
+        if (theSignificantStateOfImmediateChildren != state()) {
+            setStateOnly(theSignificantStateOfImmediateChildren);
+        }
+    }
+}
+
+bool NodeContainer::run(JobsParam& jobsParam, bool force) {
+    for (const auto& n : nodes_) {
+        (void)n->run(jobsParam, force);
+    }
+    return jobsParam.getErrorMsg().empty();
+}
+
+void NodeContainer::kill(const std::string& /* zombie_pid, only valid for single task */) {
+    for (const auto& n : nodes_) {
+        n->kill();
+    }
+}
+
+void NodeContainer::status() {
+    for (const auto& n : nodes_) {
+        // Avoid exception for top-down case, if Task is not active or submitted
+        // Allows status cmd to run over more Tasks, without early exit, when some tasks are not active/submitted
+        if (n->isTask() && (n->state() != NState::ACTIVE && n->state() != NState::SUBMITTED)) {
+            continue;
+        }
+        n->status();
+    }
+}
+
+bool NodeContainer::top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags) const {
+    bool why_found = Node::why(theReasonWhy, html_tags);
+    if (!why_found) {
+        for (const auto& n : nodes_) {
+            if (n->top_down_why(theReasonWhy, html_tags)) {
+                why_found = true;
+            }
+        }
+    }
+    return why_found;
+}
+
+void NodeContainer::incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const {
+    /// There no point doing a OrderMemento if children have been added/delete
+    if (add_remove_state_change_no_ > changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<ChildrenMemento>(nodes_));
+    }
+    else if (order_state_change_no_ > changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        std::vector<std::string> order_vec;
+        order_vec.reserve(nodes_.size());
+
+        for (const auto& n : nodes_)
+            order_vec.push_back(n->name());
+        comp->add(std::make_shared<OrderMemento>(order_vec));
+    }
+
+    Node::incremental_changes(changes, comp);
+}
+
+void NodeContainer::set_memento(const OrderMemento* memento,
+                                std::vector<ecf::Aspect::Type>& aspects,
+                                bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "NodeContainer::set_memento( const OrderMemento* ) " << debugNodePath() << "\n";
+#endif
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::ORDER);
+        return;
+    }
+
+    // Order nodes_ according to memento ordering
+    const std::vector<std::string>& order = memento->order_;
+    if (order.size() != nodes_.size()) {
+        // something gone wrong.
+        std::cout << "NodeContainer::set_memento OrderMemento, memento.size() " << order.size()
+                  << " Not the same as nodes_size() " << nodes_.size() << "\n";
+        return;
+    }
+
+    std::vector<node_ptr> vec;
+    vec.reserve(nodes_.size());
+    for (const auto& i : order) {
+        for (const auto& n : nodes_) {
+            if (i == n->name()) {
+                vec.push_back(n);
+                break;
+            }
+        }
+    }
+    if (vec.size() != nodes_.size()) {
+        std::cout << "NodeContainer::set_memento could not find all the names\n";
+        return;
+    }
+
+    nodes_ = vec;
+}
+
+void NodeContainer::set_memento(const ChildrenMemento* memento,
+                                std::vector<ecf::Aspect::Type>& aspects,
+                                bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "NodeContainer::set_memento( const ChildrenMemento * ) " << debugNodePath() << "\n";
+#endif
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::ADD_REMOVE_NODE);
+        return;
+    }
+
+    // setup child parent pointers
+    nodes_ = memento->children_;
+    for (auto& n : nodes_) {
+        n->set_parent(this);
+    }
+}
+
+void NodeContainer::collateChanges(DefsDelta& changes) const {
+    /// Theres no point in traversing children if we have added/removed children
+    /// since ChildrenMemento will copy all children.
+    if (add_remove_state_change_no_ > changes.client_state_change_no()) {
+        return;
+    }
+
+    // Traversal to children
+    for (const auto& n : nodes_) {
+        n->collateChanges(changes);
+    }
+}
+
+void NodeContainer::order(Node* immediateChild, NOrder::Order ord) {
+    SuiteChanged1 changed(suite());
+    switch (ord) {
+        case NOrder::TOP: {
+            for (auto i = nodes_.begin(); i != nodes_.end(); ++i) {
+                if ((*i).get() == immediateChild) {
+                    node_ptr node = (*i);
+                    nodes_.erase(i);
+                    nodes_.insert(nodes_.begin(), node);
+                    order_state_change_no_ = Ecf::incr_state_change_no();
+                    return;
+                }
+            }
+            throw std::runtime_error("NodeContainer::order TOP, immediate child not found");
+        }
+        case NOrder::BOTTOM: {
+            for (auto i = nodes_.begin(); i != nodes_.end(); ++i) {
+                if ((*i).get() == immediateChild) {
+                    node_ptr node = (*i);
+                    nodes_.erase(i);
+                    nodes_.push_back(node);
+                    order_state_change_no_ = Ecf::incr_state_change_no();
+                    return;
+                }
+            }
+            throw std::runtime_error("NodeContainer::order BOTTOM, immediate child not found");
+        }
+        case NOrder::ALPHA: {
+            std::sort(nodes_.begin(), nodes_.end(), [](const node_ptr& a, const node_ptr& b) {
+                try {
+                    int a_as_int = ecf::convert_to<int>(a->name());
+                    int b_as_int = ecf::convert_to<int>(b->name());
+                    return a_as_int < b_as_int;
+                }
+                catch (const ecf::bad_conversion&) {
+                }
+
+                return Str::caseInsLess(a->name(), b->name());
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            break;
+        }
+        case NOrder::ORDER: {
+            std::sort(nodes_.begin(), nodes_.end(), [](const node_ptr& a, const node_ptr& b) {
+                return Str::caseInsGreater(a->name(), b->name());
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            break;
+        }
+        case NOrder::UP: {
+            for (size_t t = 0; t < nodes_.size(); t++) {
+                if (nodes_[t].get() == immediateChild) {
+                    if (t != 0) {
+                        node_ptr node = nodes_[t];
+                        nodes_.erase(nodes_.begin() + t);
+                        t--;
+                        nodes_.insert(nodes_.begin() + t, node);
+                        order_state_change_no_ = Ecf::incr_state_change_no();
+                    }
+                    return;
+                }
+            }
+            throw std::runtime_error("NodeContainer::order UP, immediate child not found");
+        }
+        case NOrder::DOWN: {
+            for (size_t t = 0; t < nodes_.size(); t++) {
+                if (nodes_[t].get() == immediateChild) {
+                    if (t != nodes_.size() - 1) {
+                        node_ptr node = nodes_[t];
+                        nodes_.erase(nodes_.begin() + t);
+                        t++;
+                        nodes_.insert(nodes_.begin() + t, node);
+                        order_state_change_no_ = Ecf::incr_state_change_no();
+                    }
+                    return;
+                }
+            }
+            throw std::runtime_error("NodeContainer::order DOWN, immediate child not found");
+        }
+        case NOrder::RUNTIME: {
+            for (node_ptr node : nodes_) {
+                if (node->state() != NState::COMPLETE) {
+                    throw std::runtime_error("NodeContainer::order: To order by RUNTIME All nodes must be complete");
+                }
+            }
+            (void)sum_runtime();
+            std::sort(nodes_.begin(), nodes_.end(), [](const node_ptr& a, const node_ptr& b) {
+                return a->state_change_runtime() > b->state_change_runtime();
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            break;
+        }
+    }
+}
+
+void NodeContainer::move_peer(Node* src, Node* dest) {
+    move_peer_node(nodes_, src, dest, "NodeContainer");
+    order_state_change_no_ = Ecf::incr_state_change_no();
+}
+
+boost::posix_time::time_duration NodeContainer::sum_runtime() {
+    boost::posix_time::time_duration rt;
+    for (const auto& n : nodes_)
+        rt += n->sum_runtime();
+    set_runtime(rt);
+    return rt;
+}
+
+bool NodeContainer::calendarChanged(const ecf::Calendar& c,
+                                    Node::Calendar_args& cal_args,
+                                    const ecf::LateAttr* inherited_late,
+                                    bool holding_parent_day_or_date) {
+    // A node that is archived should not allow any change of state.
+    if (get_flag().is_set(ecf::Flag::ARCHIVED)) {
+        return false;
+    }
+
+    // holding_parent_day_or_date_ is used to avoid freeing time attributes, when we have a holding parent day/date
+    holding_parent_day_or_date = Node::calendarChanged(c, cal_args, nullptr, holding_parent_day_or_date);
+
+    // if (holding_parent_day_or_date)
+    //    cout << " calendarChanged: " << debugNodePath() << " " << holding_parent_day_or_date << " •••••••••• \n";
+
+    // The late attribute is inherited, we only set late on the task/alias
+    LateAttr overridden_late;
+    if (inherited_late && !inherited_late->isNull()) {
+        overridden_late = *inherited_late;
+    }
+    if (late_.get() != inherited_late) {
+        overridden_late.override_with(late_.get());
+    }
+
+    for (const auto& n : nodes_) {
+        (void)n->calendarChanged(c, cal_args, &overridden_late, holding_parent_day_or_date);
+    }
+    return false;
+}
+
+bool NodeContainer::hasAutoCancel() const {
+    if (Node::hasAutoCancel())
+        return true;
+    for (const auto& n : nodes_) {
+        if (n->hasAutoCancel())
+            return true;
+    }
+    return false;
+}
+
+void NodeContainer::invalidate_trigger_references() const {
+    Node::invalidate_trigger_references();
+    for (const auto& n : nodes_) {
+        n->invalidate_trigger_references();
+    }
+}
+
+bool NodeContainer::resolveDependencies(JobsParam& jobsParam) {
+#ifdef DEBUG_DEPENDENCIES
+    LogToCout toCoutAsWell;
+#endif
+
+    // cout << "NodeContainer::resolveDependencies " << absNodePath() << endl;
+    //  Don't evaluate children unless parent is free. BOMB out early for this case.
+    //  Note:: Task::resolveDependencies() will check inLimit up front. *** THIS CHECKS UP THE HIERARCHY ***
+    //  Note:: Node::resolveDependencies() may have forced family node to complete, should have
+    //         returned false in this case, to stop any job submission
+    if (!Node::resolveDependencies(jobsParam)) {
+
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG,
+            "   NodeContainer::resolveDependencies " << absNodePath()
+                                                     << " could not resolve dependencies, may have completed HOLDING");
+#endif
+        return false;
+    }
+
+    /// During *top down* traversal we check in limits at this level. Done here rather than
+    /// in Node::resolveDependencies(). Otherwise this particular check will get duplicated
+    /// since the task, will do *bottom up* traversal.
+    if (!check_in_limit()) {
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG, "   NodeContainer::resolveDependencies() " << absNodePath() << " HOLDING due to inLIMIT");
+#endif
+        return false;
+    }
+
+    for (const auto& n : nodes_) {
+        // Note: we don't bomb out early here. Since a later child could be free e.g. f1/ty or t4
+        // child t1 holding
+        // child t2 holding
+        // child f1 free
+        //   child tx holding
+        //   child ty free
+        // child t3 holding
+        // child t4 free
+        (void)n->resolveDependencies(jobsParam);
+    }
+
+    return true;
+}
+
+bool NodeContainer::has_time_based_attributes() const {
+    if (Node::has_time_based_attributes())
+        return true;
+    for (const auto& node : nodes_) {
+        if (node->has_time_based_attributes())
+            return true;
+    }
+    return false;
+}
+
+NState::State NodeContainer::computedState(Node::TraverseType traverseType) const {
+    if (nodes_.empty()) {
+        /// Note: theComputedNodeState will return unknown if no children, in this
+        /// case just return the current state.
+        return state();
+    }
+
+    // returns the computed state depending on traverseType
+    // If not IMMEDIATE_CHILDREN, will recurse down calling each child's computedState() function
+    return ecf::theComputedNodeState(nodes_, (traverseType == Node::IMMEDIATE_CHILDREN));
+}
+
+void NodeContainer::force_sync() {
+    add_remove_state_change_no_ = Ecf::incr_state_change_no();
+}
+
+node_ptr NodeContainer::removeChild(Node* child) {
+    size_t node_vec_size = nodes_.size();
+    for (size_t t = 0; t < node_vec_size; t++) {
+        if (nodes_[t].get() == child) {
+            node_ptr node = std::dynamic_pointer_cast<Node>(nodes_[t]);
+            child->set_parent(nullptr); // must set to NULL, allows it to be re-added to different parent
+            nodes_.erase(nodes_.begin() + t);
+            add_remove_state_change_no_ = Ecf::incr_state_change_no();
+            return node;
+        }
+    }
+    // Should never happen
+    LOG_ASSERT(false, "NodeContainer::removeChild: Could not remove child");
+    return node_ptr();
+}
+
+bool NodeContainer::addChild(const node_ptr& child, size_t position) {
+    // *** CANT construct shared_ptr from a raw pointer, must use dynamic_pointer_cast,
+    // *** otherwise the reference counts will get messed up.
+    try {
+        if (child->isTask()) {
+            // can throw if duplicate names
+            addTask(std::dynamic_pointer_cast<Task>(child), position);
+            return true;
+        }
+
+        if (child->isFamily()) {
+            // can throw if duplicate names
+            addFamily(std::dynamic_pointer_cast<Family>(child), position);
+            return true;
+        }
+    }
+    catch (std::runtime_error& e) {
+        return false; // Duplicate names, or trying to add a Suite?
+    }
+
+    // Duplicate names, or trying to add a Suite?
+    return false;
+}
+
+bool NodeContainer::isAddChildOk(Node* theChild, std::string& errorMsg) const {
+    Task* theTaskChild = theChild->isTask();
+    if (theTaskChild) {
+
+        node_ptr theTask = find_by_name(theChild->name());
+        if (!theTask.get())
+            return true;
+
+        std::stringstream ss;
+        ss << "Task/Family of name " << theChild->name() << " already exist in container node " << name();
+        errorMsg += ss.str();
+        return false;
+    }
+
+    Family* theFamilyChild = theChild->isFamily();
+    if (theFamilyChild) {
+
+        node_ptr theFamily = find_by_name(theChild->name());
+        if (!theFamily.get())
+            return true;
+
+        std::stringstream ss;
+        ss << "Family/Task of name " << theChild->name() << " already exist in container node " << name();
+        errorMsg += ss.str();
+        return false;
+    }
+
+    Suite* theSuite = theChild->isSuite();
+    if (theSuite) {
+        errorMsg += "Cannot add a suite as child.";
+        return false;
+    }
+
+    errorMsg += "Unknown node type";
+    return false;
+}
+
+void NodeContainer::handleStateChange() {
+    // Increment any repeats & requeue
+    requeueOrSetMostSignificantStateUpNodeTree();
+
+    Node::handleStateChange(); // may result in an auto-restore, if state is COMPLETE
+}
+
+size_t NodeContainer::child_position(const Node* child) const {
+    size_t node_vec_size = nodes_.size();
+    for (size_t t = 0; t < node_vec_size; t++) {
+        if (nodes_[t].get() == child) {
+            return t;
+        }
+    }
+    return std::numeric_limits<std::size_t>::max();
+}
+
+task_ptr NodeContainer::add_task(const std::string& task_name) {
+    if (find_by_name(task_name).get()) {
+        std::stringstream ss;
+        ss << "Add Task failed: A task/family of name '" << task_name << "' already exist on node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    task_ptr the_task = Task::create(task_name);
+    add_task_only(the_task);
+    return the_task;
+}
+
+family_ptr NodeContainer::add_family(const std::string& family_name) {
+    if (find_by_name(family_name).get()) {
+        std::stringstream ss;
+        ss << "Add Family failed: A Family/Task of name '" << family_name << "' already exist on node "
+           << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    family_ptr the_family = Family::create(family_name);
+    add_family_only(the_family);
+    return the_family;
+}
+
+void NodeContainer::addTask(const task_ptr& t, size_t position) {
+    if (find_by_name(t->name()).get()) {
+        std::stringstream ss;
+        ss << "Add Task failed: A Task/Family of name '" << t->name() << "' already exist on node " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    add_task_only(t, position);
+}
+
+void NodeContainer::add_task_only(const task_ptr& t, size_t position) {
+    if (t->parent()) {
+        std::stringstream ss;
+        ss << debugNodePath() << ": Add Task failed: A task of name '" << t->name()
+           << "' is already owned by another node";
+        throw std::runtime_error(ss.str());
+    }
+
+    t->set_parent(this);
+    if (position >= nodes_.size()) {
+        nodes_.push_back(t);
+    }
+    else {
+        nodes_.insert(nodes_.begin() + position, t);
+    }
+    add_remove_state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void NodeContainer::add_family_only(const family_ptr& f, size_t position) {
+    if (f->parent()) {
+        std::stringstream ss;
+        ss << debugNodePath() << ": Add Family failed: A family of name '" << f->name()
+           << "' is already owned by another node";
+        throw std::runtime_error(ss.str());
+    }
+
+    f->set_parent(this);
+    if (position >= nodes_.size()) {
+        nodes_.push_back(f);
+    }
+    else {
+        nodes_.insert(nodes_.begin() + position, f);
+    }
+    add_remove_state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void NodeContainer::addFamily(const family_ptr& f, size_t position) {
+    if (find_by_name(f->name()).get()) {
+        std::stringstream ss;
+        ss << "Add Family failed: A Family/Task of name '" << f->name() << "' already exist on node "
+           << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+    add_family_only(f, position);
+}
+
+void NodeContainer::add_child(const node_ptr& child, size_t position) {
+    if (child->isTask()) {
+        task_ptr task_child = std::dynamic_pointer_cast<Task>(child);
+        addTask(task_child, position);
+    }
+    else if (child->isFamily()) {
+        family_ptr family_child = std::dynamic_pointer_cast<Family>(child);
+        addFamily(family_child, position);
+    }
+}
+
+node_ptr NodeContainer::findImmediateChild(const std::string& theName, size_t& child_pos) const {
+    size_t node_vec_size = nodes_.size();
+    for (size_t t = 0; t < node_vec_size; t++) {
+        if (nodes_[t]->name() == theName) {
+            child_pos = t;
+            return nodes_[t];
+        }
+    }
+    child_pos = std::numeric_limits<std::size_t>::max();
+    return node_ptr();
+}
+
+node_ptr NodeContainer::find_immediate_child(const std::string_view& name) const {
+    for (const auto& n : nodes_) {
+        if (name == n->name()) {
+            return n;
+        }
+    }
+    return node_ptr();
+}
+
+node_ptr NodeContainer::find_node_up_the_tree(const std::string& the_name) const {
+    if (name() == the_name) {
+        return non_const_this();
+    }
+
+    size_t not_used;
+    node_ptr fnd_node = findImmediateChild(the_name, not_used);
+    if (fnd_node)
+        return fnd_node;
+
+    Node* the_parent = parent();
+    if (the_parent)
+        return the_parent->find_node_up_the_tree(the_name);
+    return node_ptr();
+}
+
+node_ptr NodeContainer::find_relative_node(const std::vector<std::string>& pathToNode) {
+#ifdef DEBUG_FIND_NODE
+    cout << "NodeContainer::find_relative_node for '" << name() << "\n";
+    cout << " path :";
+    for (const std::string& s : pathToNode) {
+        cout << " " << s;
+    }
+    cout << "\n";
+    for (node_ptr t : nodes_) {
+        cout << " " << t->name();
+    }
+    cout << "\n";
+#endif
+    if (pathToNode.empty())
+        return node_ptr();
+    auto pathSize = static_cast<int>(pathToNode.size());
+
+#ifdef DEBUG_FIND_NODE
+    cout << "NodeContainer::find_relative_node name = '" << name() << "' pathToNode[0] = '" << pathToNode[0] << "'\n";
+#endif
+
+    // Must match all children
+    int index         = 0;
+    size_t child_pos  = 0; // unused
+    node_ptr the_node = shared_from_this();
+    while (index < pathSize) {
+        the_node = the_node->findImmediateChild(pathToNode[index], child_pos);
+        if (the_node) {
+            if (index == pathSize - 1)
+                return the_node;
+            index++;
+        }
+        else {
+            return node_ptr();
+        }
+    }
+    return node_ptr();
+}
+
+void NodeContainer::find_closest_matching_node(const std::vector<std::string>& pathToNode,
+                                               int indexIntoPathNode,
+                                               node_ptr& closest_matching_node) {
+    auto pathSize = static_cast<int>(pathToNode.size());
+    if (indexIntoPathNode >= pathSize)
+        return;
+
+    int index = indexIntoPathNode;
+    if (name() == pathToNode[indexIntoPathNode]) {
+
+        closest_matching_node = shared_from_this();
+
+        // Match the Container i.e. family or suite
+        bool lastIndex = (indexIntoPathNode == pathSize - 1);
+        if (lastIndex) {
+            return;
+        }
+
+        // Match the Children, i.e. go down the hierarchy
+        index++;
+        match_closest_children(pathToNode, index, closest_matching_node);
+    }
+}
+
+void NodeContainer::match_closest_children(const std::vector<std::string>& pathToNode,
+                                           int indexIntoPathNode,
+                                           node_ptr& closest_matching_node) {
+    auto pathSize = static_cast<int>(pathToNode.size());
+    if (indexIntoPathNode >= pathSize)
+        return;
+
+    bool lastIndex = (indexIntoPathNode == pathSize - 1);
+    if (lastIndex) {
+        // Even if the name matches, it is only valid if the index is the last index
+        // e.g. given a suite /a/b/c/d/e
+        //      and the path  /a/b/c/d/e/f/g
+        // The path will match with e, but it invalid since it is not the last index
+        for (const auto& n : nodes_) {
+            if (n->name() == pathToNode[indexIntoPathNode]) {
+                closest_matching_node = n;
+                return;
+            }
+        }
+    }
+    else {
+        // Path to node is of the form "/family/task" or "/family/family/task"
+        // Path to node is of the form "/suite/task" or "/suite/family/task"
+        for (const auto& n : nodes_) {
+            Family* family = n->isFamily();
+            if (family) {
+                node_ptr matching_node;
+                family->find_closest_matching_node(pathToNode, indexIntoPathNode, matching_node);
+                if (matching_node.get()) {
+                    closest_matching_node = matching_node;
+                    return;
+                }
+            }
+        }
+    }
+}
+
+node_ptr NodeContainer::find_by_name(const std::string& name) const {
+    for (const auto& n : nodes_) {
+        if (n->name() == name) {
+            return n;
+        }
+    }
+    return node_ptr();
+}
+
+family_ptr NodeContainer::findFamily(const std::string& familyName) const {
+    for (const auto& n : nodes_) {
+        if (n->name() == familyName && n->isFamily()) {
+            return std::dynamic_pointer_cast<Family>(n);
+        }
+    }
+    return family_ptr();
+}
+
+task_ptr NodeContainer::findTask(const std::string& taskName) const {
+    for (const auto& n : nodes_) {
+        if (n->name() == taskName && n->isTask()) {
+            return std::dynamic_pointer_cast<Task>(n);
+        }
+    }
+    return task_ptr();
+}
+
+std::string NodeContainer::find_node_path(const std::string& type, const std::string& node_name) const {
+    for (const auto& n : nodes_) {
+        std::string res = n->find_node_path(type, node_name);
+        if (!res.empty()) {
+            return res;
+        }
+    }
+    return string();
+}
+
+bool NodeContainer::hasTimeDependencies() const {
+    for (const auto& n : nodes_) {
+        if (n->hasTimeDependencies())
+            return true;
+    }
+    return false;
+}
+
+void NodeContainer::immediateChildren(std::vector<node_ptr>& theChildren) const {
+    theChildren.reserve(theChildren.size() + nodes_.size());
+    for (const auto& n : nodes_) {
+        theChildren.push_back(n);
+    }
+}
+
+void NodeContainer::allChildren(std::vector<node_ptr>& vec) const {
+    for (const auto& n : nodes_) {
+        vec.push_back(n);
+        n->allChildren(vec); // for task does nothing
+    }
+}
+
+void NodeContainer::getAllFamilies(std::vector<Family*>& vec) const {
+    for (const auto& n : nodes_) {
+        Family* family = n->isFamily();
+        if (family) {
+            vec.push_back(family);
+            family->getAllFamilies(vec);
+        }
+    }
+}
+
+void NodeContainer::getAllNodes(std::vector<Node*>& vec) const {
+    for (const auto& n : nodes_) {
+        vec.push_back(n.get());
+        n->getAllNodes(vec);
+    }
+}
+
+void NodeContainer::getAllTasks(std::vector<Task*>& tasks) const {
+    for (const auto& n : nodes_) {
+        n->getAllTasks(tasks);
+    }
+}
+
+void NodeContainer::getAllSubmittables(std::vector<Submittable*>& tasks) const {
+    for (const auto& n : nodes_) {
+        n->getAllSubmittables(tasks);
+    }
+}
+
+void NodeContainer::get_all_active_submittables(std::vector<Submittable*>& tasks) const {
+    for (const auto& n : nodes_) {
+        n->get_all_active_submittables(tasks);
+    }
+}
+
+void NodeContainer::get_all_tasks(std::vector<task_ptr>& tasks) const {
+    for (const auto& n : nodes_) {
+        n->get_all_tasks(tasks);
+    }
+}
+
+void NodeContainer::get_all_nodes(std::vector<node_ptr>& nodes) const {
+    nodes.push_back(non_const_this());
+    for (const auto& n : nodes_) {
+        n->get_all_nodes(nodes);
+    }
+}
+
+void NodeContainer::get_all_aliases(std::vector<alias_ptr>& aliases) const {
+    for (const auto& n : nodes_) {
+        n->get_all_aliases(aliases);
+    }
+}
+
+void NodeContainer::getAllAstNodes(std::set<Node*>& vec) const {
+    Node::getAllAstNodes(vec);
+    for (const auto& n : nodes_) {
+        n->getAllAstNodes(vec);
+    }
+}
+
+bool NodeContainer::check(std::string& errorMsg, std::string& warningMsg) const {
+    Node::check(errorMsg, warningMsg);
+
+    // recursive to handle hierarchical families
+    for (const auto& n : nodes_) {
+        n->check(errorMsg, warningMsg);
+        // if (!errorMsg.empty()) break;
+    }
+
+    return errorMsg.empty();
+}
+
+std::vector<task_ptr> NodeContainer::taskVec() const {
+    std::vector<task_ptr> vec;
+    vec.reserve(nodes_.size());
+    for (const auto& n : nodes_) {
+        if (n->isTask()) {
+            vec.push_back(std::dynamic_pointer_cast<Task>(n));
+        }
+    }
+    return vec;
+}
+
+std::vector<family_ptr> NodeContainer::familyVec() const {
+    std::vector<family_ptr> vec;
+    for (const auto& n : nodes_) {
+        if (n->isFamily()) {
+            vec.push_back(std::dynamic_pointer_cast<Family>(n));
+        }
+    }
+    return vec;
+}
+
+bool NodeContainer::operator==(const NodeContainer& rhs) const {
+    size_t node_vec_size = nodes_.size();
+    if (node_vec_size != rhs.nodes_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "NodeContainer::operator==  node_vec_size != rhs.nodes_.size() " << absNodePath() << "\n";
+            std::cout << "   nodes_.size() = " << node_vec_size << "  rhs.nodes_.size() = " << rhs.nodes_.size()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+
+    for (size_t i = 0; i < node_vec_size; ++i) {
+
+        Task* task = nodes_[i]->isTask();
+        if (task) {
+            Task* rhs_task = rhs.nodes_[i]->isTask();
+            if (!rhs_task) {
+#ifdef DEBUG
+                if (Ecf::debug_equality()) {
+                    std::cout << "NodeContainer::operator==  if ( !rhs_task ) " << absNodePath() << "\n";
+                }
+#endif
+                return false;
+            }
+
+            if (!(*task == *rhs_task)) {
+#ifdef DEBUG
+                if (Ecf::debug_equality()) {
+                    std::cout << "NodeContainer::operator==  if ( !( *task == *rhs_task )) " << absNodePath() << "\n";
+                }
+#endif
+                return false;
+            }
+        }
+        else {
+            Family* rhs_family = rhs.nodes_[i]->isFamily();
+            if (!rhs_family) {
+#ifdef DEBUG
+                if (Ecf::debug_equality()) {
+                    std::cout << "NodeContainer::operator==  if ( !rhs_family ) " << absNodePath() << "\n";
+                }
+#endif
+                return false;
+            }
+
+            Family* family = nodes_[i]->isFamily();
+            LOG_ASSERT(family, "");
+            if (family /*keep clang happy*/ && !(*family == *rhs_family)) {
+#ifdef DEBUG
+                if (Ecf::debug_equality()) {
+                    std::cout << "NodeContainer::operator==  if ( !( *family == *rhs_family )) " << absNodePath()
+                              << "\n";
+                }
+#endif
+                return false;
+            }
+        }
+    }
+
+    return Node::operator==(rhs);
+}
+
+void NodeContainer::print(std::string& os) const {
+    for (const auto& node : nodes_) {
+        node->print(os);
+    }
+}
+
+bool NodeContainer::checkInvariants(std::string& errorMsg) const {
+    if (!Node::checkInvariants(errorMsg))
+        return false;
+
+    for (const auto& n : nodes_) {
+        if (n->parent() != this) {
+            errorMsg += "NodeContainer::checkInvariants family/task parent() not correct";
+            return false;
+        }
+        if (!n->checkInvariants(errorMsg)) {
+            return false;
+        }
+    }
+    return true;
+}
+
+void NodeContainer::verification(std::string& errorMsg) const {
+    Node::verification(errorMsg);
+    for (const auto& n : nodes_) {
+        n->verification(errorMsg);
+    }
+}
+
+void NodeContainer::setRepeatToLastValueHierarchically() {
+    setRepeatToLastValue();
+    for (const auto& n : nodes_) {
+        n->setRepeatToLastValueHierarchically();
+    }
+}
+
+void NodeContainer::setStateOnlyHierarchically(NState::State s, bool force) {
+    setStateOnly(s, force);
+    for (const auto& n : nodes_) {
+        n->setStateOnlyHierarchically(s, force);
+    }
+}
+
+void NodeContainer::set_state_hierarchically(NState::State s, bool force) {
+    setStateOnlyHierarchically(s, force);
+    if (force) {
+        // *force* is only set via ForceCmd.
+        update_limits(); // hierarchical
+    }
+    handleStateChange(); // non-hierarchical
+}
+
+void NodeContainer::update_limits() {
+    /// Only tasks can affect the limits, hence no point calling locally
+    for (const auto& n : nodes_) {
+        n->update_limits();
+    }
+}
+
+std::string NodeContainer::archive_path() const {
+    std::string the_archive_path;
+    if (!findParentUserVariableValue(Str::ECF_HOME(), the_archive_path)) {
+        std::stringstream ss;
+        ss << "NodeContainer::archive_path: cannot find ECF_HOME from " << debugNodePath();
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string the_archive_file_name = absNodePath();
+    Str::replaceall(the_archive_file_name, "/", ":"); // we use ':' since it is not allowed in the node names
+    the_archive_file_name += ".check";
+
+    std::string port = Str::DEFAULT_PORT_NUMBER();
+    Defs* the_defs   = defs();
+    if (the_defs) {
+        port = the_defs->server().find_variable(Str::ECF_PORT());
+        if (port.empty())
+            port = Str::DEFAULT_PORT_NUMBER();
+    }
+    Host host;
+    the_archive_file_name = host.prefix_host_and_port(port, the_archive_file_name);
+
+    the_archive_path += "/";
+    the_archive_path += the_archive_file_name;
+    return the_archive_path;
+}
+
+void NodeContainer::archive() {
+    if (nodes_.empty())
+        return; // nothing to archive
+
+    SuiteChanged1 changed(suite());
+
+    // make a clone of this node DEEP COPY
+    node_ptr this_clone = clone();
+
+    // re-create node tree up to the def. Do *NOT* clone we just need a SHALLOW hierarchy
+    defs_ptr archive_defs = Defs::create();
+    if (isSuite()) {
+        suite_ptr suite_clone = std::dynamic_pointer_cast<Suite>(this_clone);
+        archive_defs->addSuite(suite_clone);
+    }
+    else {
+        Node* parent_ptr = parent();
+        while (parent_ptr) {
+            if (parent_ptr->isSuite()) {
+                suite_ptr parent_suite = Suite::create(parent_ptr->name());
+                parent_suite->addChild(this_clone);
+                archive_defs->addSuite(parent_suite);
+                break;
+            }
+            else {
+                family_ptr parent_family = Family::create(parent_ptr->name());
+                parent_family->addChild(this_clone);
+                this_clone = parent_family;
+            }
+            parent_ptr = parent_ptr->parent();
+        }
+    }
+
+    // save the created defs, to disk
+    archive_defs->save_as_checkpt(archive_path());
+
+    flag().set(ecf::Flag::ARCHIVED); // flag as archived
+    flag().clear(ecf::Flag::RESTORED);
+
+    // delete the child nodes, set parent to null first.
+    for (auto& n : nodes_) {
+        n->set_parent(nullptr);
+    }
+    nodes_.clear();
+
+    std::vector<node_ptr>().swap(nodes_);                      // reclaim vector memory
+    add_remove_state_change_no_ = Ecf::incr_state_change_no(); // For sync
+    string msg                  = " autoarchive ";
+    msg += debugNodePath(); // inform user via log
+    ecf::log(Log::LOG, msg);
+}
+
+void NodeContainer::swap(NodeContainer& rhs) {
+    std::swap(nodes_, rhs.nodes_);
+    for (auto& n : nodes_) {
+        n->set_parent(this);
+    }
+}
+
+void NodeContainer::restore_on_begin_or_requeue() {
+    if (!flag().is_set(ecf::Flag::ARCHIVED))
+        return;
+    if (!nodes_.empty())
+        return;
+    if (!fs::exists(archive_path()))
+        return;
+
+    // Node::requeue(...) will clear ecf::Flag::RESTORED, set in restore()
+    try {
+        restore();
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "NodeContainer::restore_on_begin_or_requeue(): failed : " << e.what();
+        log(Log::ERR, ss.str());
+    }
+}
+
+void NodeContainer::restore() {
+    if (!flag().is_set(ecf::Flag::ARCHIVED)) {
+        std::stringstream ss;
+        ss << "NodeContainer::restore() Node " << absNodePath() << " can't restore, ecf::Flag::ARCHIVED not set";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (!nodes_.empty()) {
+        std::stringstream ss;
+        ss << "NodeContainer::restore() Node " << absNodePath() << " can't restore, Container already has children ?";
+        throw std::runtime_error(ss.str());
+    }
+
+    defs_ptr archive_defs        = Defs::create();
+    std::string the_archive_path = archive_path();
+    try {
+        archive_defs->restore(the_archive_path);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "NodeContainer::restore() Node " << absNodePath() << " could not restore file at  " << the_archive_path
+           << "  : " << e.what();
+        throw std::runtime_error(ss.str());
+    }
+
+    // find the same node in the defs.
+    node_ptr archived_node = archive_defs->findAbsNode(absNodePath());
+    if (!archived_node) {
+        std::stringstream ss;
+        ss << "NodeContainer::restore() could not find " << absNodePath() << " in the archived file "
+           << the_archive_path;
+        throw std::runtime_error(ss.str());
+    }
+    NodeContainer* archived_node_container = archived_node->isNodeContainer();
+    if (!archived_node_container) {
+        std::stringstream ss;
+        ss << "NodeContainer::restore() The node at " << absNodePath() << " recovered from " << the_archive_path
+           << " is not a container(suite/family)";
+        throw std::runtime_error(ss.str());
+    }
+
+    swap(*archived_node_container);                            // swap the children, and set parent pointers
+    flag().clear(ecf::Flag::ARCHIVED);                         // clear flag archived
+    flag().set(ecf::Flag::RESTORED);                           // set restored flag, to stop automatic autoarchive
+    add_remove_state_change_no_ = Ecf::incr_state_change_no(); // For sync
+
+    string msg = " autorestore ";
+    msg += debugNodePath(); // inform user via log
+    ecf::log(Log::LOG, msg);
+
+    fs::remove(the_archive_path); // remove the file, could still throw
+}
+
+bool NodeContainer::has_archive() const {
+    if (get_flag().is_set(ecf::Flag::ARCHIVED))
+        return true;
+    for (auto& n : nodes_) {
+        if (n->has_archive())
+            return true;
+    }
+    return false;
+}
+
+void NodeContainer::remove_archived_files() {
+    /// Called during delete, remove all child archived files
+    if (!has_archive()) {
+        return;
+    }
+
+    std::string ecf_home;
+    if (!findParentUserVariableValue(Str::ECF_HOME(), ecf_home)) {
+        return;
+    }
+
+    // <host>.<port>.ECF_NAME.check
+    // for /ecflow =  Avis-MacBook-Pro.local.4040.:ecflow.check
+    std::string the_archive_path = archive_path();
+
+    // remove trailing '.check'
+    std::string::size_type check_pos = the_archive_path.rfind(".check");
+    if (check_pos == std::string::npos) {
+        // something has gone wrong
+        return;
+    }
+    the_archive_path.erase(the_archive_path.begin() + check_pos, the_archive_path.end());
+
+    // Find *all* archived files in ECF_HOME
+    std::vector<fs::path> archived_file_vec;
+    File::find_files_with_extn(ecf_home, ".check", archived_file_vec);
+    if (archived_file_vec.empty())
+        return;
+
+    // if this nodes archive file is a prefix for any archived file, then it is child archived file and needs
+    // to be deleted. i.e. if /ecflow is being deleted then:
+    // the_archive_path = Avis-MacBook-Pro.local.4040.:ecflow
+    // Hence if this matches as a prefix for any archive file, then it needs to be deleted.
+    //  Avis-MacBook-Pro.local.4040.:ecflow.check
+    //  Avis-MacBook-Pro.local.4040.:ecflow:darwin.check
+    //  Avis-MacBook-Pro.local.4040.:ecflow:darwin:apple_clang.check
+    //  Avis-MacBook-Pro.local.4040.:ecflow:darwin:gnu.10.check
+
+    for (const auto& file_path : archived_file_vec) {
+        std::string path = file_path.string();
+
+        if (path.find(the_archive_path) == 0) {
+            try {
+                fs::remove(path);
+            }
+            catch (...) {
+            };
+        }
+    }
+}
+
+void NodeContainer::sort_attributes(ecf::Attr::Type attr, bool recursive, const std::vector<std::string>& no_sort) {
+    Node::sort_attributes(attr, recursive, no_sort);
+    if (recursive) {
+        for (const auto& n : nodes_) {
+            n->sort_attributes(attr, recursive, no_sort);
+        }
+    }
+}
+
+bool NodeContainer::doDeleteChild(Node* child) {
+    SuiteChanged1 changed(suite());
+    auto theTaskEnd = nodes_.end();
+    for (auto t = nodes_.begin(); t != theTaskEnd; ++t) {
+        if ((*t).get() == child) {
+
+            // Remove any child archived file
+            Family* fam = (*t)->isFamily();
+            if (fam) {
+                fam->remove_archived_files();
+            }
+
+            child->set_parent(nullptr); // must set to NULL, allow it to be re-added to different parent
+            nodes_.erase(t);
+            add_remove_state_change_no_ = Ecf::incr_state_change_no();
+            set_most_significant_state_up_node_tree();
+            return true;
+        }
+        if ((*t)->doDeleteChild(child)) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+void NodeContainer::check_job_creation(job_creation_ctrl_ptr jobCtrl) {
+
+    if (defStatus() != DState::COMPLETE) {
+        for (const auto& n : nodes_) {
+            n->check_job_creation(jobCtrl);
+        }
+    }
+}
+
+void NodeContainer::generate_scripts(const std::map<std::string, std::string>& override) const {
+    for (const auto& n : nodes_) {
+        n->generate_scripts(override);
+    }
+}
+
+template <class Archive>
+void NodeContainer::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Node>(this), CEREAL_NVP(nodes_));
+
+    // Set up the parent pointers. Since they are not serialised
+    if (Archive::is_loading::value) {
+        for (auto& n : nodes_) {
+            n->set_parent(this);
+        }
+    }
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(NodeContainer);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeContainer.hpp 5.13.0-1/libs/node/src/ecflow/node/NodeContainer.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeContainer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeContainer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,176 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_NodeContainer_HPP
+#define ecflow_node_NodeContainer_HPP
+
+///
+/// \brief The NodeContainer class holds families and tasks
+///
+
+#include <limits>
+
+#include "ecflow/node/Node.hpp"
+
+class NodeContainer : public Node {
+protected:
+    NodeContainer& operator=(const NodeContainer&);
+
+public:
+    explicit NodeContainer(const std::string& name, bool check);
+    NodeContainer(const NodeContainer&);
+    NodeContainer();
+    ~NodeContainer() override;
+
+    bool check_defaults() const override;
+
+    void accept(ecf::NodeTreeVisitor&) override;
+    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
+    void reset() override;
+    void begin() override;
+    void requeue(Requeue_args&) override;
+    void requeue_time_attrs() override;
+    void handle_migration(const ecf::Calendar&) override;
+    void reset_late_event_meters() override;
+    bool run(JobsParam& jobsParam, bool force) override;
+    void kill(const std::string& zombie_pid = "") override;
+    void status() override;
+    bool top_down_why(std::vector<std::string>& theReasonWhy, bool html_tags = false) const override;
+    void collateChanges(DefsDelta&) const override;
+    void set_memento(const OrderMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void set_memento(const ChildrenMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+    void order(Node* immediateChild, NOrder::Order) override;
+    void move_peer(Node* src, Node* dest) override;
+
+    bool hasAutoCancel() const override;
+    bool calendarChanged(const ecf::Calendar&,
+                         Node::Calendar_args&,
+                         const ecf::LateAttr* inherited_late,
+                         bool holding_parent_day_or_date) override;
+    bool resolveDependencies(JobsParam&) override;
+    bool has_time_based_attributes() const override;
+    bool check(std::string& errorMsg, std::string& warningMsg) const override;
+    void invalidate_trigger_references() const override;
+
+    task_ptr add_task(const std::string& task_name);
+    family_ptr add_family(const std::string& family_name);
+    void addTask(const task_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
+    void addFamily(const family_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
+    void add_child(const node_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
+
+    const std::vector<node_ptr>& children() const { return nodes_; }
+    void immediateChildren(std::vector<node_ptr>&) const override;
+    void allChildren(std::vector<node_ptr>&) const override;
+
+    node_ptr findImmediateChild(const std::string& name, size_t& child_pos) const override;
+    node_ptr find_immediate_child(const std::string_view&) const override;
+    node_ptr find_node_up_the_tree(const std::string& name) const override;
+
+    node_ptr find_relative_node(const std::vector<std::string>& pathToNode) override;
+    void find_closest_matching_node(const std::vector<std::string>& pathToNode,
+                                    int indexIntoPathNode,
+                                    node_ptr& closest_matching_node);
+
+    node_ptr find_by_name(const std::string& name) const;
+    family_ptr findFamily(const std::string& familyName) const;
+    task_ptr findTask(const std::string& taskName) const;
+
+    std::string find_node_path(const std::string& type, const std::string& name) const override;
+
+    void getAllFamilies(std::vector<Family*>&) const;
+    void getAllNodes(std::vector<Node*>&) const override;
+    void getAllTasks(std::vector<Task*>&) const override;
+    void getAllSubmittables(std::vector<Submittable*>&) const override;
+    void get_all_active_submittables(std::vector<Submittable*>&) const override;
+    void get_all_tasks(std::vector<task_ptr>&) const override;
+    void get_all_nodes(std::vector<node_ptr>&) const override;
+    void get_all_aliases(std::vector<alias_ptr>&) const override;
+    void getAllAstNodes(std::set<Node*>&) const override;
+    const std::vector<node_ptr>& nodeVec() const { return nodes_; }
+    std::vector<task_ptr> taskVec() const;
+    std::vector<family_ptr> familyVec() const;
+
+    void print(std::string&) const override;
+    bool operator==(const NodeContainer& rhs) const;
+
+    bool hasTimeDependencies() const override;
+
+    void check_job_creation(job_creation_ctrl_ptr jobCtrl) override;
+    void generate_scripts(const std::map<std::string, std::string>& override) const override;
+
+    bool checkInvariants(std::string& errorMsg) const override;
+    void verification(std::string& errorMsg) const override;
+
+    NState::State computedState(Node::TraverseType) const override;
+
+    node_ptr removeChild(Node* child) override;
+    bool addChild(const node_ptr& child, size_t position = std::numeric_limits<std::size_t>::max()) override;
+    bool isAddChildOk(Node* child, std::string& errorMsg) const override;
+
+    void setRepeatToLastValueHierarchically() override;
+    void setStateOnlyHierarchically(NState::State s, bool force = false) override;
+    void set_state_hierarchically(NState::State s, bool force) override;
+    void update_limits() override;
+    void sort_attributes(ecf::Attr::Type attr,
+                         bool recursive                          = true,
+                         const std::vector<std::string>& no_sort = std::vector<std::string>()) override;
+
+    bool has_archive() const override;
+    void archive();
+    void restore();
+    void remove_archived_files();     // used in delete
+    std::string archive_path() const; // can throw if ECF_HOME not defined
+
+    boost::posix_time::time_duration sum_runtime() override;
+
+private:
+    void restore_on_begin_or_requeue();
+
+    size_t child_position(const Node*) const override;
+    void add_task_only(const task_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
+    void add_family_only(const family_ptr&, size_t position = std::numeric_limits<std::size_t>::max());
+
+    void handle_defstatus_propagation();
+    void match_closest_children(const std::vector<std::string>& pathToNode,
+                                int indexIntoPathToNode,
+                                node_ptr& closest_matching_node);
+
+    void handleStateChange() override; // called when a state change happens
+
+    friend class Defs;
+    friend class Family;
+    bool doDeleteChild(Node* child) override;
+
+    /// For use by python interface,
+    std::vector<node_ptr>::const_iterator node_begin() const { return nodes_.begin(); }
+    std::vector<node_ptr>::const_iterator node_end() const { return nodes_.end(); }
+    friend void export_SuiteAndFamily();
+
+protected:
+    void force_sync() override;
+    void incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const;
+
+private:
+    void copy(const NodeContainer& rhs);
+    void swap(NodeContainer& rhs);
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+
+private:
+    std::vector<node_ptr> nodes_;
+
+protected:
+    unsigned int order_state_change_no_{0};      // no need to persist
+    unsigned int add_remove_state_change_no_{0}; // no need to persist
+};
+
+#endif /* ecflow_node_NodeContainer_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeDelete.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeDelete.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeDelete.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeDelete.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,466 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Stl.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/MiscAttrs.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+void Node::deleteTime(const std::string& name) {
+    if (name.empty()) {
+        times_.clear(); // delete all
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteTime\n";
+#endif
+        return;
+    }
+    TimeAttr attr(TimeSeries::create(name)); // can throw if parse fails
+    delete_time(attr);                       // can throw if search fails
+}
+
+void Node::delete_time(const ecf::TimeAttr& attr) {
+    auto found = ecf::algorithm::find_by(times_, [&](const auto& item) { return item.structureEquals(attr); });
+
+    if (found == std::end(times_)) {
+        throw std::runtime_error("Node::delete_time: Cannot find time attribute: ");
+    }
+
+    times_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::delete_time\n";
+#endif
+}
+
+void Node::deleteToday(const std::string& name) {
+    if (name.empty()) {
+        todays_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteToday\n";
+#endif
+        return;
+    }
+
+    TodayAttr attr(TimeSeries::create(name)); // can throw if parse fails
+    delete_today(attr);                       // can throw if search fails
+}
+
+void Node::delete_today(const ecf::TodayAttr& attr) {
+    // Don't use '==' since that compares additional state like free_
+    auto found = ecf::algorithm::find_by(todays_, [&](const auto& item) { return item.structureEquals(attr); });
+
+    if (found == std::end(todays_)) {
+        throw std::runtime_error("Node::delete_today: Cannot find today attribute: " + attr.toString());
+    }
+
+    todays_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::delete_today\n";
+#endif
+}
+
+void Node::deleteDate(const std::string& name) {
+    if (name.empty()) {
+        dates_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteDate\n";
+#endif
+        return;
+    }
+
+    DateAttr attr(DateAttr::create(name)); // can throw if parse fails
+    delete_date(attr);                     // can throw if search fails
+}
+
+void Node::delete_date(const DateAttr& attr) {
+    // Don't use '==' since that compares additional state like free_
+    auto found = ecf::algorithm::find_by(dates_, [&](const auto& item) { return item.structureEquals(attr); });
+
+    if (found == std::end(dates_)) {
+        throw std::runtime_error("Node::delete_date: Cannot find date attribute: " + attr.toString());
+    }
+
+    dates_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::delete_date\n";
+#endif
+}
+
+void Node::deleteDay(const std::string& name) {
+    if (name.empty()) {
+        days_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteDay\n";
+#endif
+        return;
+    }
+
+    DayAttr attr(DayAttr::create(name)); // can throw if parse fails.
+    delete_day(attr);                    // can throw if search fails
+}
+
+void Node::delete_day(const DayAttr& attr) {
+    // Don't use '==' since that compares additional state like free_
+    auto found = ecf::algorithm::find_by(days_, [&](const auto& item) { return item.structureEquals(attr); });
+
+    if (found == std::end(days_)) {
+        throw std::runtime_error("Node::delete_day: Cannot find day attribute: " + attr.toString());
+    }
+
+    days_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::delete_day\n";
+#endif
+}
+
+void Node::deleteCron(const std::string& name) {
+    if (name.empty()) {
+        crons_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteCron\n";
+#endif
+        return;
+    }
+
+    CronAttr attr = CronAttr::create(name); // can throw if parse fails
+    delete_cron(attr);                      // can throw if search fails
+}
+
+void Node::delete_cron(const ecf::CronAttr& attr) {
+    // Don't use '==' since that compares additional state like free_
+    auto found = ecf::algorithm::find_by(crons_, [&](const auto& item) { return item.structureEquals(attr); });
+
+    if (found == std::end(crons_)) {
+        throw std::runtime_error("Node::delete_cron: Cannot find cron attribute: " + attr.toString());
+    }
+
+    crons_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::delete_cron\n";
+#endif
+}
+
+void Node::deleteVariable(const std::string& name) {
+    if (name.empty()) {
+        vars_.clear(); // delete all
+        state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteVariable\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by_name(vars_, name);
+
+    if (found == std::end(vars_)) {
+        throw std::runtime_error("Node::deleteVariable: Cannot find 'user' variable of name " + name);
+    }
+
+    vars_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::deleteVariable\n";
+#endif
+}
+
+void Node::delete_variable_no_error(const std::string& name) {
+    if (name.empty()) {
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::delete_variable_no_error\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by_name(vars_, name);
+
+    if (found != std::end(vars_)) {
+        vars_.erase(found);
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::delete_variable_no_error\n";
+#endif
+    }
+}
+
+void Node::deleteEvent(const std::string& name) {
+    if (name.empty()) {
+        events_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteEvent\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by(events_, [&](const auto& item) { return item.name_or_number() == name; });
+
+    if (found == std::end(events_)) {
+        throw std::runtime_error("Node::deleteEvent: Cannot find event: " + name);
+    }
+
+    events_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::deleteEvent\n";
+#endif
+}
+
+void Node::deleteMeter(const std::string& name) {
+    if (name.empty()) {
+        meters_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Expression::clearFree()\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by_name(meters_, name);
+
+    if (found == std::end(meters_)) {
+        throw std::runtime_error("Node::deleteMeter: Cannot find meter: " + name);
+    }
+
+    meters_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Expression::clearFree()\n";
+#endif
+}
+
+void Node::deleteLabel(const std::string& name) {
+    if (name.empty()) {
+        labels_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteLabel\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by_name(labels_, name);
+
+    if (found == std::end(labels_)) {
+        throw std::runtime_error("Node::deleteLabel: Cannot find label: " + name);
+    }
+
+    labels_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::deleteLabel\n";
+#endif
+}
+
+void Node::deleteAviso(const std::string& name) {
+    if (name.empty()) {
+        avisos_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteAviso\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by_name(avisos_, name);
+
+    if (found == std::end(avisos_)) {
+        throw std::runtime_error("Node::deleteAviso: Cannot find aviso: " + name);
+    }
+
+    avisos_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::deleteAviso\n";
+#endif
+}
+
+void Node::deleteMirror(const std::string& name) {
+    if (name.empty()) {
+        mirrors_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteAviso\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by_name(mirrors_, name);
+
+    if (found == std::end(mirrors_)) {
+        throw std::runtime_error("Node::deleteMirror: Cannot find mirror: " + name);
+    }
+
+    mirrors_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::deleteAviso\n";
+#endif
+}
+
+void Node::delete_queue(const std::string& name) {
+    if (misc_attrs_) {
+        misc_attrs_->delete_queue(name);
+        return;
+    }
+    throw std::runtime_error("Node::delete_queue: Cannot find queue: " + name);
+}
+
+void Node::delete_generic(const std::string& name) {
+    if (misc_attrs_) {
+        misc_attrs_->delete_generic(name);
+        return;
+    }
+    throw std::runtime_error("Node::delete_generic : Cannot find generic: " + name);
+}
+
+void Node::deleteTrigger() {
+    if (t_expr_) {
+        t_expr_.reset(nullptr);
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteTrigger()\n";
+#endif
+    }
+}
+
+void Node::deleteComplete() {
+    if (c_expr_) {
+        c_expr_.reset(nullptr);
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteComplete()\n";
+#endif
+    }
+}
+
+void Node::deleteRepeat() {
+    if (!repeat_.empty()) {
+        repeat_.clear(); // will delete the pimple
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteRepeat())\n";
+#endif
+    }
+}
+
+void Node::deleteLimit(const std::string& name) {
+    if (name.empty()) {
+        limits_.clear();
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteLimit\n";
+#endif
+        return;
+    }
+
+    auto found = ecf::algorithm::find_by_name(limits_, name);
+
+    if (found == std::end(limits_)) {
+        throw std::runtime_error("Node::deleteLimit: Cannot find limit: " + name);
+    }
+
+    limits_.erase(found);
+    state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Node::deleteLimit\n";
+#endif
+}
+
+void Node::delete_limit_path(const std::string& name, const std::string& path) {
+    if (name.empty()) {
+        throw std::runtime_error("Node::delete_limit_path: the limit name must be provided");
+    }
+    if (path.empty()) {
+        throw std::runtime_error("Node::delete_limit_path: the limit path must be provided");
+    }
+
+    auto found = ecf::algorithm::find_by_name(limits_, name);
+
+    if (found == std::end(limits_)) {
+        throw std::runtime_error("Node::delete_limit_path: Cannot find limit: " + name);
+    }
+
+    (*found)->delete_path(path);
+}
+
+void Node::deleteInlimit(const std::string& name) {
+    // if name exists but no corresponding in limit found raises an exception
+    if (inLimitMgr_.deleteInlimit(name)) {
+        state_change_no_ = Ecf::incr_state_change_no();
+#ifdef DEBUG_STATE_CHANGE_NO
+        std::cout << "Node::deleteInlimit\n";
+#endif
+    }
+}
+
+void Node::delete_misc_attrs_if_empty() {
+    if (misc_attrs_ && misc_attrs_->empty()) {
+        misc_attrs_.reset(nullptr);
+    }
+}
+
+void Node::deleteZombie(const std::string& zombie_type) {
+    if (misc_attrs_) {
+        misc_attrs_->deleteZombie(zombie_type);
+        delete_misc_attrs_if_empty();
+    }
+}
+
+void Node::delete_zombie(Child::ZombieType zt) {
+    if (misc_attrs_) {
+        misc_attrs_->delete_zombie(zt);
+        delete_misc_attrs_if_empty();
+    }
+}
+
+void Node::deleteLate() {
+    late_.reset(nullptr);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::deleteAutoCancel() {
+    auto_cancel_.reset(nullptr);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::deleteAutoArchive() {
+    auto_archive_.reset(nullptr);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Node::deleteAutoRestore() {
+    auto_restore_.reset(nullptr);
+    state_change_no_ = Ecf::incr_state_change_no();
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeFind.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeFind.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeFind.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeFind.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,938 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/NodePath.hpp"
+#include "ecflow/core/Stl.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/MiscAttrs.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+/// Output a vector to cout
+template <class T>
+ostream& operator<<(ostream& os, const vector<T>& v) {
+    copy(v.begin(), v.end(), ostream_iterator<T>(cout, " "));
+    return os;
+}
+
+bool Node::findParentVariableValue(const std::string& name, std::string& theValue) const {
+    if (!vars_.empty() && findVariableValue(name, theValue))
+        return true;
+    if (!repeat_.empty() && repeat_.name() == name) {
+        theValue = repeat_.valueAsString();
+        return true;
+    }
+    if (findGenVariableValue(name, theValue))
+        return true;
+
+    Node* theParent = parent();
+    while (theParent) {
+
+        if (theParent->findVariableValue(name, theValue))
+            return true;
+        const Repeat& rep = theParent->repeat();
+        if (!rep.empty() && rep.name() == name) {
+            theValue = rep.valueAsString();
+            return true;
+        }
+        if (theParent->findGenVariableValue(name, theValue))
+            return true;
+
+        theParent = theParent->parent();
+    }
+
+    // If all else fails search defs environment, returns empty string if match not found
+    // The defs environment is constructed via:
+    //   o/ default settings for ECF_HOME,ECF_LOG, ECF_CHECK,ECF_CHECKOLD,ECF_CHECKINTERVAL
+    //                           ECF_INTERVAL ECF_CHECKMODE ECF_JOB_CMD ECF_MICRO ECF_TRIES ECF_PORT, ECF_HOST
+    //   o/ These values are updated from the server environment when the `BEGIN` command is called.
+    Defs* the_defs = defs();
+    if (the_defs) {
+        theValue = the_defs->server().find_variable(name);
+        if (!theValue.empty())
+            return true;
+    }
+    return false; // the variable cannot be found
+}
+
+bool Node::find_parent_gen_variable_value(const std::string& name, std::string& theValue) const {
+    if (findGenVariableValue(name, theValue))
+        return true;
+
+    Node* theParent = parent();
+    while (theParent) {
+        if (theParent->findGenVariableValue(name, theValue))
+            return true;
+        theParent = theParent->parent();
+    }
+
+    // If all else fails search defs environment, returns empty string if match not found
+    // The defs environment is constructed via:
+    //   o/ default settings for ECF_HOME,ECF_LOG, ECF_CHECK,ECF_CHECKOLD,ECF_CHECKINTERVAL
+    //                           ECF_INTERVAL ECF_CHECKMODE ECF_JOB_CMD ECF_MICRO ECF_TRIES ECF_PORT, ECF_HOST
+    //   o/ These values are updated from the server environment when the `BEGIN` command is called.
+    Defs* the_defs = defs();
+    if (the_defs) {
+        theValue = the_defs->server().find_variable(name);
+        if (!theValue.empty())
+            return true;
+    }
+    return false; // the variable cannot be found
+}
+
+bool Node::findParentUserVariableValue(const std::string& name, std::string& theValue) const {
+    if (findVariableValue(name, theValue))
+        return true;
+
+    Node* theParent = parent();
+    while (theParent) {
+        if (theParent->findVariableValue(name, theValue))
+            return true;
+        theParent = theParent->parent();
+    }
+
+    // If all else fails search defs environment, returns empty string if match not found
+    Defs* the_defs = defs();
+    if (the_defs) {
+        // Note: when calling ecflow_client --get_state=/suite/task
+        // The node can be detached from the defs.
+        theValue = the_defs->server().find_variable(name);
+        if (!theValue.empty())
+            return true;
+    }
+    return false; // the variable cannot be found
+}
+
+const std::string& Node::find_parent_user_variable_value(const std::string& name) const {
+    const Variable& var = findVariable(name);
+    if (!var.empty())
+        return var.theValue();
+
+    Node* theParent = parent();
+    while (theParent) {
+        const Variable& pvar = theParent->findVariable(name);
+        if (!pvar.empty())
+            return pvar.theValue();
+        theParent = theParent->parent();
+    }
+
+    Defs* the_defs = defs();
+    if (the_defs) {
+        // Note: when calling ecflow_client --get_state=/suite/task
+        // The node can be detached from the defs.
+        return the_defs->server().find_variable(name);
+    }
+    return Str::EMPTY();
+}
+
+bool Node::user_variable_exists(const std::string& name) const {
+    const Variable& var = findVariable(name);
+    if (!var.empty())
+        return true;
+
+    Node* theParent = parent();
+    while (theParent) {
+        const Variable& pvar = theParent->findVariable(name);
+        if (!pvar.empty())
+            return true;
+        theParent = theParent->parent();
+    }
+
+    // If all else fails search defs environment, returns empty string if match not found
+    Defs* the_defs = defs();
+    if (the_defs) {
+        // Note: when calling ecflow_client --get_state=/suite/task
+        // The node can be detached from the defs.
+        return the_defs->server().variable_exists(name);
+    }
+    return false;
+}
+
+const Variable& Node::findVariable(const std::string& name) const {
+    auto found = ecf::algorithm::find_by_name(vars_, name);
+    return found == std::end(vars_) ? Variable::EMPTY() : *found;
+}
+
+std::string Node::find_parent_variable_sub_value(const std::string& name) const {
+    std::string ret;
+    const Variable& var = findVariable(name);
+    if (!var.empty()) {
+        ret = var.theValue();
+        variableSubstitution(ret);
+        return ret;
+    }
+
+    Node* theParent = parent();
+    while (theParent) {
+        const Variable& pvar = theParent->findVariable(name);
+        if (!pvar.empty()) {
+            ret = pvar.theValue();
+            variableSubstitution(ret);
+            return ret;
+        }
+        theParent = theParent->parent();
+    }
+
+    // If all else fails search defs environment
+    Defs* the_defs = defs();
+    if (the_defs) {
+        const Variable& pvar = the_defs->server().findVariable(name);
+        ret                  = pvar.theValue();
+        the_defs->variableSubsitution(ret);
+        return ret;
+    }
+
+    return string();
+}
+
+const Variable& Node::find_parent_variable(const std::string& name) const {
+    const Variable& var = findVariable(name);
+    if (!var.empty())
+        return var;
+
+    Node* theParent = parent();
+    while (theParent) {
+        const Variable& pvar = theParent->findVariable(name);
+        if (!pvar.empty())
+            return pvar;
+        theParent = theParent->parent();
+    }
+
+    // If all else fails search defs environment
+    Defs* the_defs = defs();
+    if (the_defs) {
+        return the_defs->server().findVariable(name);
+    }
+
+    return Variable::EMPTY();
+}
+
+bool Node::findVariableValue(const std::string& name, std::string& returnedValue) const {
+    auto found = ecf::algorithm::find_by_name(vars_, name);
+
+    if (found == std::end(vars_)) {
+        return false;
+    }
+
+    returnedValue = found->theValue();
+    return true;
+}
+
+bool Node::findGenVariableValue(const std::string& name, std::string& returnedValue) const {
+    const Variable& genVar = findGenVariable(name);
+    if (!genVar.empty()) {
+        returnedValue = genVar.theValue();
+        return true;
+    }
+    return false;
+}
+
+bool Node::findLimit(const Limit& theLimit) const {
+    auto found = ecf::algorithm::find_by_name(limits_, theLimit.name());
+    return found != std::end(limits_);
+}
+
+limit_ptr Node::find_limit(const std::string& theName) const {
+    auto found = ecf::algorithm::find_by_name(limits_, theName);
+    return found == std::end(limits_) ? limit_ptr() : *found;
+}
+
+limit_ptr Node::findLimitUpNodeTree(const std::string& name) const {
+    limit_ptr theFndLimit = find_limit(name);
+    if (theFndLimit.get())
+        return theFndLimit;
+
+    Node* theParent = parent();
+    while (theParent != nullptr) {
+
+        limit_ptr theFndLimit2 = theParent->find_limit(name);
+        if (theFndLimit2.get())
+            return theFndLimit2;
+
+        theParent = theParent->parent();
+    }
+    return limit_ptr();
+}
+
+const Event& Node::findEvent(const Event& theEvent) const {
+    auto found = ecf::algorithm::find_by(events_, [&](const auto& item) { return item.compare(theEvent); });
+    return found == std::end(events_) ? Event::EMPTY() : *found;
+}
+
+const Event& Node::findEventByNumber(int number) const {
+    auto found = ecf::algorithm::find_by_number(events_, number);
+    return found == std::end(events_) ? Event::EMPTY() : *found;
+}
+
+const Event& Node::findEventByName(const std::string& event_name) const {
+    auto found = ecf::algorithm::find_by_name(events_, event_name);
+    return found == std::end(events_) ? Event::EMPTY() : *found;
+}
+
+const Event& Node::findEventByNameOrNumber(const std::string& theName) const {
+    const Event& event = findEventByName(theName);
+    if (!event.empty()) {
+        return event;
+    }
+
+    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
+    if (theName.find_first_of(Str::NUMERIC(), 0) == 0) {
+        try {
+            auto eventNumber = ecf::convert_to<int>(theName);
+            return findEventByNumber(eventNumber);
+        }
+        catch (const ecf::bad_conversion&) {
+        }
+    }
+    return Event::EMPTY();
+}
+
+const Meter& Node::findMeter(const std::string& name) const {
+    auto found = ecf::algorithm::find_by_name(meters_, name);
+    return found == std::end(meters_) ? Meter::EMPTY() : *found;
+}
+
+Meter& Node::find_meter(const std::string& name) {
+    auto found = ecf::algorithm::find_by_name(meters_, name);
+    return found == std::end(meters_) ? const_cast<Meter&>(Meter::EMPTY()) : *found;
+}
+
+bool Node::findLabel(const std::string& name) const {
+    auto found = ecf::algorithm::find_by_name(labels_, name);
+    return found != std::end(labels_);
+}
+
+const Label& Node::find_label(const std::string& name) const {
+    auto found = ecf::algorithm::find_by_name(labels_, name);
+    return found == std::end(labels_) ? Label::EMPTY() : *found;
+}
+
+bool Node::findAviso(const std::string& name) const {
+    auto found = ecf::algorithm::find_by_name(avisos_, name);
+    return found != std::end(avisos_);
+}
+
+bool Node::findMirror(const std::string& name) const {
+    auto found = ecf::algorithm::find_by_name(mirrors_, name);
+    return found != std::end(mirrors_);
+}
+
+bool Node::findVerify(const VerifyAttr& v) const {
+    if (misc_attrs_)
+        return misc_attrs_->findVerify(v);
+    return false;
+}
+
+const QueueAttr& Node::find_queue(const std::string& name) const {
+    if (misc_attrs_)
+        return misc_attrs_->find_queue(name);
+    return QueueAttr::EMPTY();
+}
+
+QueueAttr& Node::findQueue(const std::string& name) {
+    if (misc_attrs_)
+        return misc_attrs_->findQueue(name);
+    return QueueAttr::EMPTY1();
+}
+
+const GenericAttr& Node::find_generic(const std::string& name) const {
+    if (misc_attrs_)
+        return misc_attrs_->find_generic(name);
+    return GenericAttr::EMPTY();
+}
+
+const Repeat& Node::findRepeat(const std::string& name) const {
+    if (!repeat_.empty() && repeat_.name() == name) {
+        return repeat_;
+    }
+    return Repeat::EMPTY();
+}
+
+bool Node::findExprVariable(const std::string& name) {
+    // if event found return true; also, mark this event so simulator know it's used in a trigger
+    if (set_event_used_in_trigger(name)) {
+        return true;
+    }
+
+    // if meter found mark as used in trigger for simulator, and return
+    if (set_meter_used_in_trigger(name)) {
+        return true;
+    }
+
+    const Variable& user_variable = findVariable(name);
+    if (!user_variable.empty())
+        return true;
+
+    const Repeat& repeat = findRepeat(name);
+    if (!repeat.empty())
+        return true;
+
+    const Variable& gen_variable = findGenVariable(name);
+    if (!gen_variable.empty())
+        return true;
+
+    limit_ptr limit = find_limit(name);
+    if (limit.get())
+        return true;
+
+    QueueAttr& queue_attr = findQueue(name);
+    if (!queue_attr.empty()) {
+        queue_attr.set_used_in_trigger(true);
+        return true;
+    }
+
+    return false;
+}
+
+int Node::findExprVariableValue(const std::string& name) const {
+    const Event& event = findEventByNameOrNumber(name);
+    if (!event.empty())
+        return (event.value() ? 1 : 0);
+
+    const Meter& meter = findMeter(name);
+    if (!meter.empty())
+        return meter.value();
+
+    const Variable& variable = findVariable(name);
+    if (!variable.empty())
+        return variable.value();
+
+    const Repeat& repeat = findRepeat(name);
+    if (!repeat.empty()) {
+        // RepeatDate       last_valid_value() returns the date by its real value as a long
+        // RepeatDatelist   last_valid_value() returns the date by its real value as a long
+        // RepeatInteger    last_valid_value() returns the value, by the current value of integer
+        // RepeatEnumerated last_valid_value() returns the current value if cast-able to integer otherwise
+        // position/index,
+        //                                     (i.e. since enum can be anything)
+        // RepeatString     last_valid_value() returns the current position/index  ( Alternatives? )
+        // RepeatDay        last_valid_value() returns the current step
+        // Note: At Repeat expiration Repeat::value() may be out of range of start-end
+        //       But Repeat::last_valid_value() should always be in range, hence at Repeat expiration
+        //       will return the last valid value.
+        return repeat.last_valid_value();
+    }
+
+    const Variable& gen_variable = findGenVariable(name);
+    if (!gen_variable.empty())
+        return gen_variable.value();
+
+    limit_ptr limit = find_limit(name);
+    if (limit.get())
+        return limit->value();
+
+    const QueueAttr& queue_attr = find_queue(name);
+    if (!queue_attr.empty())
+        return queue_attr.index_or_value();
+
+    return 0;
+}
+
+int Node::findExprVariableValueAndPlus(const std::string& name, int val) const {
+    const Event& event = findEventByNameOrNumber(name);
+    if (!event.empty())
+        return ((event.value() ? 1 : 0) + val);
+
+    const Meter& meter = findMeter(name);
+    if (!meter.empty())
+        return (meter.value() + val);
+
+    const Variable& variable = findVariable(name);
+    if (!variable.empty())
+        return (variable.value() + val);
+
+    const Repeat& repeat = findRepeat(name);
+    if (!repeat.empty()) {
+        // RepeatDate       last_valid_value() returns the date by its real value as a long
+        // RepeatInteger    last_valid_value() returns the value, by the current value of integer
+        // RepeatEnumerated last_valid_value() returns the current value if cast-able as integer otherwise
+        // position/index,
+        //                                    (i.e. since enum can be anything)
+        // RepeatString     last_valid_value() returns the current position/index  ( Alternatives? )
+        // RepeatDay        last_valid_value() returns the current step
+        // Note: At Repeat expiration Repeat::value() may be out of range of start-end
+        //       But Repeat::last_valid_value() should always be in range, hence at Repeat expiration
+        //       will return the last valid value.
+        return repeat.last_valid_value_plus(val);
+    }
+
+    const Variable& gen_variable = findGenVariable(name);
+    if (!gen_variable.empty())
+        return (gen_variable.value() + val);
+
+    limit_ptr limit = find_limit(name);
+    if (limit.get())
+        return (limit->value() + val);
+
+    const QueueAttr& queue_attr = find_queue(name);
+    if (!queue_attr.empty())
+        return (queue_attr.index_or_value() + val);
+
+    return val;
+}
+
+int Node::findExprVariableValueAndMinus(const std::string& name, int val) const {
+    const Event& event = findEventByNameOrNumber(name);
+    if (!event.empty())
+        return ((event.value() ? 1 : 0) - val);
+
+    const Meter& meter = findMeter(name);
+    if (!meter.empty())
+        return (meter.value() - val);
+
+    const Variable& variable = findVariable(name);
+    if (!variable.empty())
+        return (variable.value() - val);
+
+    const Repeat& repeat = findRepeat(name);
+    if (!repeat.empty()) {
+        // RepeatDate       last_valid_value() returns the date by its real value as a long
+        // RepeatInteger    last_valid_value() returns the value, by the current value of integer
+        // RepeatEnumerated last_valid_value() returns the current value if cast-able as integer, else position/index, (
+        //                                     i.e. since enum can be anything)
+        // RepeatString     last_valid_value() returns the current position/index  ( Alternatives? )
+        // RepeatDay        last_valid_value() returns the current step
+        // Note: At Repeat expiration Repeat::value() may be out of range of start-end
+        //       But Repeat::last_valid_value() should always be in range, hence at Repeat expiration
+        //       will return the last valid value.
+        return repeat.last_valid_value_minus(val);
+    }
+
+    const Variable& gen_variable = findGenVariable(name);
+    if (!gen_variable.empty())
+        return (gen_variable.value() - val);
+
+    limit_ptr limit = find_limit(name);
+    if (limit.get())
+        return (limit->value() - val);
+
+    const QueueAttr& queue_attr = find_queue(name);
+    if (!queue_attr.empty())
+        return (queue_attr.index_or_value() - val);
+
+    return -val;
+}
+
+int Node::findExprVariableValueAndType(const std::string& name, std::string& varType) const {
+    const Event& event = findEventByNameOrNumber(name);
+    if (!event.empty()) {
+        varType = "event";
+        return (event.value() ? 1 : 0);
+    }
+    const Meter& meter = findMeter(name);
+    if (!meter.empty()) {
+        varType = "meter";
+        return meter.value();
+    }
+    const Variable& variable = findVariable(name);
+    if (!variable.empty()) {
+        varType = "user-variable";
+        return variable.value();
+    }
+    const Repeat& repeat = findRepeat(name);
+    if (!repeat.empty()) {
+        varType = "repeat";
+        return repeat.last_valid_value();
+    }
+    const Variable& gen_variable = findGenVariable(name);
+    if (!gen_variable.empty()) {
+        varType = "gen-variable";
+        return gen_variable.value();
+    }
+    limit_ptr limit = find_limit(name);
+    if (limit.get()) {
+        varType = "limit";
+        return limit->value();
+    }
+    const QueueAttr& queue_attr = find_queue(name);
+    if (!queue_attr.empty()) {
+        varType = "queue";
+        return queue_attr.index_or_value();
+    }
+
+    varType = "variable-not-found";
+    return 0;
+}
+
+void Node::findExprVariableAndPrint(const std::string& name, ostream& os) const {
+    const Event& event = findEventByNameOrNumber(name);
+    if (!event.empty()) {
+        os << "EVENT value(" << event.value() << ")";
+        return;
+    }
+    const Meter& meter = findMeter(name);
+    if (!meter.empty()) {
+        os << "METER value(" << meter.value() << ")";
+        return;
+    }
+    const Variable& variable = findVariable(name);
+    if (!variable.empty()) {
+        os << "USER-VARIABLE value(" << variable.value() << ")";
+        return;
+    }
+    const Repeat& repeat = findRepeat(name);
+    if (!repeat.empty()) {
+        os << "REPEAT value(" << repeat.value() << ")";
+        return;
+    }
+    const Variable& gen_variable = findGenVariable(name);
+    if (!gen_variable.empty()) {
+        os << "GEN-VARIABLE value(" << gen_variable.value() << ")";
+        return;
+    }
+    limit_ptr limit = find_limit(name);
+    if (limit.get()) {
+        os << limit->toString() << " value(" << limit->value() << ")";
+        return;
+    }
+    const QueueAttr& queue_attr = find_queue(name);
+    if (!queue_attr.empty()) {
+        os << "QUEUE " << queue_attr.name() << " value(" << queue_attr.index_or_value() << ")";
+        return;
+    }
+}
+
+node_ptr findRelativeNode(const vector<std::string>& theExtractedPath, node_ptr triggerNode, std::string& errorMsg) {
+    // The referenced node could be itself(error) or most likely a sibling node.
+    auto extractedPathSize = static_cast<int>(theExtractedPath.size());
+    if (extractedPathSize == 1 && triggerNode->name() == theExtractedPath[0]) {
+        // self referencing node ?
+        return triggerNode;
+    }
+
+    // Can only find *sibling* if triggerNode has a parent
+    if (!triggerNode->parent()) {
+        errorMsg = "Parent empty. Could not find referenced node\n";
+        return node_ptr();
+    }
+    if (extractedPathSize == 1) {
+        size_t child_pos; // not used
+        node_ptr theNode = triggerNode->parent()->findImmediateChild(theExtractedPath[0], child_pos);
+        if (theNode.get()) {
+            return theNode;
+        }
+    }
+    else {
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        cout << "triggerNode: " << triggerNode->debugNodePath() << "\n";
+        cout << "triggerNode->parent(): " << triggerNode->parent()->debugNodePath() << "\n";
+#endif
+        node_ptr constNode = triggerNode->parent()->find_relative_node(theExtractedPath);
+        if (constNode.get()) {
+            return constNode;
+        }
+        constNode = triggerNode->find_relative_node(theExtractedPath);
+        if (constNode.get()) {
+            return constNode;
+        }
+    }
+
+    errorMsg = "Could not find node '";
+    if (extractedPathSize == 1)
+        errorMsg += theExtractedPath[0];
+    else {
+        for (const string& s : theExtractedPath) {
+            errorMsg += s;
+            errorMsg += Str::PATH_SEPERATOR();
+        }
+    }
+    errorMsg += "' from node ";
+    errorMsg += triggerNode->absNodePath();
+    if (extractedPathSize == 1) {
+        errorMsg += " . Expected '";
+        errorMsg += theExtractedPath[0];
+        errorMsg += "' to be a sibling.";
+    }
+    errorMsg += "\n";
+    return node_ptr();
+}
+
+node_ptr Node::non_const_this() const {
+    return const_pointer_cast<Node>(shared_from_this());
+}
+
+node_ptr Node::findReferencedNode(const std::string& nodePath, std::string& errorMsg) const {
+    return findReferencedNode(nodePath, Str::EMPTY(), errorMsg);
+}
+
+// #define DEBUG_FIND_REFERENCED_NODE 1
+node_ptr
+Node::findReferencedNode(const std::string& nodePath, const std::string& extern_obj, std::string& errorMsg) const {
+#ifdef DEBUG_FIND_REFERENCED_NODE
+    cout << "Node::findReferencedNode path:" << nodePath << " extern_obj:" << extern_obj << "\n";
+#endif
+    Defs* theDefs = defs();
+    if (!theDefs) {
+        // In the case where we have a standalone Node i.e. no parent set. The Defs will be NULL.
+        // Take the case where we want to dump the state of a single node.
+        //    ecflow_client --get_state=/test/f2 --port=4141
+        // Here we are printing the state of the Node only, *NO* defs is returned.
+        // The print will cause the AST to be evaluated. The trigger evaluation will require chasing
+        // down reference nodes. Hence, we will end up here. Rather than crashing, just return a NULL Pointer.
+        return node_ptr();
+    }
+
+    /// findReferencedNode:: is used to locate references:
+    ///      a/ Trigger & complete expressions, this is where extern_obj is used.
+    ///      b/ Inlimit nodepaths.
+    ///  In *both* the case above, the node path may not exist, in the definition. Hence::
+    ///  On client side:: references not defined in externs are considered errors
+    ///  On server side:: No externs are stored, hence for unresolved node paths, we return NULL
+
+#ifdef DEBUG_FIND_REFERENCED_NODE
+    string debug_path = "Searching for path " + nodePath + " from " + debugType() + Str::COLON() + absNodePath() + "\n";
+#endif
+
+    // if an absolute path cut in early
+    if (!nodePath.empty() && nodePath[0] == '/') {
+
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        debug_path += "(!nodePath.empty() && nodePath[0] == '/') \n";
+#endif
+
+        // Must be an absolute path. i.e. /suite/family/path
+        node_ptr constNode = theDefs->findAbsNode(nodePath);
+        if (constNode.get()) {
+            return constNode;
+        }
+
+        // *NOTE*: The server does *NOT* store externs, hence the check below, will always return false, for the server:
+        // Must be an extern:
+        //    extern /referenceSuite/family/task:obj
+        //    extern /referenceSuite/family/task
+        if (theDefs->find_extern(nodePath, extern_obj)) {
+
+            // =================================================================
+            // **Client side* specific: Only client side defs, stores extrens
+            // =================================================================
+#ifdef DEBUG_FIND_REFERENCED_NODE
+            debug_path += "theDefs->find_extern(nodePath) \n";
+#endif
+
+            // return NULL *without* setting an error message as node path is defined as an extern
+
+            // OK: the node path appears in the extern list. This may be because that suite  has not been loaded.
+            // *** If the suite is loaded, then it's an error that we did not
+            // *** locate the node. i.e. in the previous call to defs->findAbsNode(nodePath);
+            vector<string> theExtractedPath;
+            NodePath::split(nodePath, theExtractedPath);
+
+            std::string referenceSuite = theExtractedPath[0];
+            if (theDefs->findSuite(referenceSuite)) {
+                // The suite referenced in the extern is LOADED, but path did not resolve,
+                // in previous call to defs->findAbsNode(nodePath);
+                errorMsg = "Extern path ";
+                errorMsg += nodePath;
+                errorMsg += " does not exist on suite ";
+                errorMsg += referenceSuite;
+                errorMsg += "\n";
+#ifdef DEBUG_FIND_REFERENCED_NODE
+                errorMsg += debug_path;
+#endif
+            }
+
+            // It's an extern path that references a suite that's NOT loaded yet
+            return node_ptr();
+        }
+
+        errorMsg = ": Could not find referenced node, using absolute path '";
+        errorMsg += nodePath;
+        errorMsg += "\n";
+        return node_ptr();
+    }
+
+    /// =============================================================================
+    /// Path is something other than ABSOLUTE path
+    /// =============================================================================
+    vector<string> theExtractedPath;
+    NodePath::split(nodePath, theExtractedPath);
+
+#ifdef DEBUG_FIND_REFERENCED_NODE
+    debug_path += "extracted path = ";
+    for (const string& s : theExtractedPath) {
+        debug_path += ",";
+        debug_path += s;
+    }
+    debug_path += "\n";
+#endif
+
+    if (theExtractedPath.empty()) {
+        std::stringstream ss;
+        ss << ": Could not find referenced node '" << nodePath << "' from node " << absNodePath() << "\n";
+        errorMsg = ss.str();
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        errorMsg += debug_path;
+#endif
+        return node_ptr();
+    }
+
+    //  i.e.   " a == complete" =====>        nodePath = a
+    if (theExtractedPath.size() == 1) {
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        debug_path += "( theExtractedPath.size() == 1)\n";
+#endif
+        // Search for a relative node first
+        string localErrorMsg;
+        node_ptr res = findRelativeNode(theExtractedPath, non_const_this(), localErrorMsg);
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        if (!localErrorMsg.empty()) {
+            debug_path += localErrorMsg;
+            localErrorMsg = debug_path;
+        }
+#endif
+
+        if (!res.get()) {
+            // Let's see if it is in an extern Node. Externs can have absolute and relative paths.
+            // In this case, it will be a relative path, and thus there is no point trying to see if suite is loaded
+            if (theDefs->find_extern(nodePath, extern_obj)) {
+                // =================================================================
+                // **Client side* specific: Only client side defs, stores externs
+                // =================================================================
+                // The path exist in the extern, and we know it is relative
+                return node_ptr();
+            }
+        }
+
+        errorMsg += localErrorMsg;
+        return res;
+    }
+
+    // handle Node path of type   a/b/c
+    if (theExtractedPath.size() >= 2 && theExtractedPath[0] != "." && theExtractedPath[0] != "..") {
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        debug_path +=
+            "(theExtractedPath.size() >= 2 && theExtractedPath[0] != \".\") && theExtractedPath[0] != \"..\"\n";
+#endif
+        // First check to see if it is in the externs
+        if (theDefs->find_extern(nodePath, extern_obj)) {
+            // =================================================================
+            // **Client side* specific: Only client side defs, stores externs
+            // =================================================================
+            // The path a/b/c exist in the extern, and we know its relative
+            // Again no point in checking to see if suite is loaded if path is relative
+            return node_ptr();
+        }
+
+        // In this case its equivalent to: ./a/b/c
+        theExtractedPath.insert(theExtractedPath.begin(), ".");
+    }
+
+    // node path == "./a"
+    if (theExtractedPath.size() >= 2 && theExtractedPath[0] == ".") {
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        debug_path += "theExtractedPath.size() == 2 && theExtractedPath[0] == \".\" \n";
+#endif
+        theExtractedPath.erase(theExtractedPath.begin() + 0);
+        node_ptr res = findRelativeNode(theExtractedPath, non_const_this(), errorMsg);
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        if (!errorMsg.empty()) {
+            debug_path += errorMsg;
+            errorMsg = debug_path;
+        }
+#endif
+        return res;
+    }
+
+    // ********************************************************************
+    // Note  ./   sibling go to parent and search down
+    //       ../  search at the level of the parent, requires we go up to parent and search down
+    // **********************************************************************
+    // Handle node path of the type "../a/b/c"  "../../a/b/c"
+    if (theExtractedPath.size() >= 2 && theExtractedPath[0] == "..") {
+
+#ifdef DEBUG_FIND_REFERENCED_NODE
+        debug_path += "( theExtractedPath.size() >= 2 && theExtractedPath[0] == \"..\")\n";
+#endif
+
+        Node* theParent = parent(); // get past the first parent
+        while (static_cast<int>(theExtractedPath.size()) && theParent && theExtractedPath[0] == "..") {
+            theExtractedPath.erase(theExtractedPath.begin() + 0);
+            theParent = theParent->parent(); // for each `..` go up the parent
+#ifdef DEBUG_FIND_REFERENCED_NODE
+            debug_path += "..: thepParent = ";
+            if (theParent)
+                debug_path += theParent->absNodePath();
+            else
+                debug_path += "NULL";
+#endif
+        }
+
+        if (theParent) {
+
+#ifdef DEBUG_FIND_REFERENCED_NODE
+            debug_path += "searching = " + theParent->name() + "\n";
+            for (const std::string& s : theExtractedPath) {
+                debug_path += Str::PATH_SEPERATOR() + s;
+            }
+            debug_path += "\n";
+#endif
+
+            node_ptr constNode = theParent->find_relative_node(theExtractedPath);
+            if (constNode) {
+                return constNode;
+            }
+        }
+        else {
+            // search suites, with the remaining path in theExtractedPath
+            std::string path;
+            for (const auto& i : theExtractedPath) {
+                path += Str::PATH_SEPERATOR();
+                path += i;
+            }
+            node_ptr fndNode = theDefs->findAbsNode(path);
+            if (fndNode) {
+                return fndNode;
+            }
+        }
+    }
+
+    errorMsg = "Unrecognised path ";
+    errorMsg += nodePath;
+    errorMsg += " for Node ";
+    errorMsg += absNodePath();
+    errorMsg += "\n";
+#ifdef DEBUG_FIND_REFERENCED_NODE
+    errorMsg += debug_path;
+#endif
+    return node_ptr();
+}
+
+const ZombieAttr& Node::findZombie(ecf::Child::ZombieType zombie_type) const {
+    if (misc_attrs_)
+        return misc_attrs_->findZombie(zombie_type);
+    return ZombieAttr::EMPTY();
+}
+
+bool Node::findParentZombie(ecf::Child::ZombieType z_type, ZombieAttr& z) const {
+    const ZombieAttr& the_zombie = findZombie(z_type);
+    if (!the_zombie.empty()) {
+        z = the_zombie;
+        return true;
+    }
+
+    Node* theParent = parent();
+    while (theParent) {
+        const ZombieAttr& the_zombie2 = theParent->findZombie(z_type);
+        if (!the_zombie2.empty()) {
+            z = the_zombie2;
+            return true;
+        }
+        theParent = theParent->parent();
+    }
+    return false;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeFwd.hpp 5.13.0-1/libs/node/src/ecflow/node/NodeFwd.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeFwd.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeFwd.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,122 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_NodeFwd_HPP
+#define ecflow_node_NodeFwd_HPP
+
+#include <map>
+#include <memory>
+#include <string>
+#include <vector>
+
+class AbstractObserver;
+class Suite;
+class Family;
+class Task;
+class Alias;
+class Submittable;
+class Node;
+class Defs;
+class Repeat;
+class Expression;
+class Memento;
+class CompoundMemento;
+class ClockAttr;
+class JobCreationCtrl;
+class Event;
+class Meter;
+class Repeat;
+class Variable;
+class Zombie;
+struct NodeStats;
+class MiscAttrs;
+class VerifyAttr;
+class ZombieAttr;
+class QueueAttr;
+class GenericAttr;
+class PartExpression;
+
+namespace ecf {
+class LateAttr;
+class AutoCancelAttr;
+class AutoArchiveAttr;
+class AutoRestoreAttr;
+} // namespace ecf
+
+typedef std::shared_ptr<Memento> memento_ptr;
+typedef std::shared_ptr<CompoundMemento> compound_memento_ptr;
+typedef std::shared_ptr<ClockAttr> clock_ptr;
+
+typedef std::shared_ptr<JobCreationCtrl> job_creation_ctrl_ptr;
+typedef std::shared_ptr<Node> node_ptr;
+typedef std::shared_ptr<Task> task_ptr;
+typedef std::shared_ptr<Alias> alias_ptr;
+typedef std::shared_ptr<Submittable> submittable_ptr;
+typedef std::shared_ptr<Family> family_ptr;
+typedef std::shared_ptr<Suite> suite_ptr;
+typedef std::shared_ptr<Defs> defs_ptr;
+
+typedef std::weak_ptr<Defs> weak_defs_ptr;
+typedef std::weak_ptr<Suite> weak_suite_ptr;
+typedef std::weak_ptr<Task> weak_task_ptr;
+typedef std::weak_ptr<Alias> weak_alias_ptr;
+typedef std::weak_ptr<Submittable> weak_submittable_ptr;
+typedef std::weak_ptr<Node> weak_node_ptr;
+
+typedef std::map<std::string, std::string> NameValueMap;
+typedef std::vector<std::pair<std::string, std::string>> NameValueVec;
+
+class NodeContainer;
+class DefsDelta;
+class JobsParam;
+class JobCreationCtrl;
+class AstTop;
+class Ast;
+
+class StateMemento;
+class NodeStateMemento;
+class NodeDefStatusDeltaMemento;
+class SuspendedMemento;
+class ServerStateMemento;
+class ServerVariableMemento;
+class NodeEventMemento;
+class NodeMeterMemento;
+class NodeLabelMemento;
+class NodeAvisoMemento;
+class NodeMirrorMemento;
+class NodeTriggerMemento;
+class NodeCompleteMemento;
+class NodeRepeatMemento;
+class NodeRepeatIndexMemento;
+class NodeLimitMemento;
+class NodeInLimitMemento;
+class NodeVariableMemento;
+class NodeLateMemento;
+class NodeTodayMemento;
+class NodeTimeMemento;
+class NodeDayMemento;
+class NodeCronMemento;
+class NodeDateMemento;
+class NodeZombieMemento;
+class NodeVerifyMemento;
+class FlagMemento;
+class SubmittableMemento;
+class SuiteClockMemento;
+class SuiteBeginDeltaMemento;
+class SuiteCalendarMemento;
+class OrderMemento;
+class ChildrenMemento;
+class AliasChildrenMemento;
+class AliasNumberMemento;
+class NodeQueueMemento;
+class NodeGenericMemento;
+class NodeQueueIndexMemento;
+
+#endif /* ecflow_node_NodeFwd_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeMemento.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeMemento.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeMemento.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeMemento.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,862 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/DefsDelta.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/MiscAttrs.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// #define DEBUG_MEMENTO 1
+
+/// CompoundMemento relies all clearing all attributes with state
+void Node::clear() {
+    late_.reset(nullptr);
+    c_expr_.reset(nullptr);
+    t_expr_.reset(nullptr);
+
+    misc_attrs_.reset(nullptr);
+
+    todays_.clear();
+    times_.clear();
+    crons_.clear();
+    days_.clear();
+    dates_.clear();
+
+    // ************************************************************
+    // Note: auto cancel, auto restore, auto archive does not have any
+    //       changeable state, Hence it is not cleared.
+    //       Hence, no need for memento
+    // ************************************************************
+
+    meters_.clear();
+    events_.clear();
+    labels_.clear();
+
+    avisos_.clear();
+    mirrors_.clear();
+
+    repeat_.clear();
+    vars_.clear();
+    limits_.clear();
+    inLimitMgr_.clear();
+}
+
+void Node::incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::incremental_changes(DefsDelta& changes) " << debugNodePath() << "\n";
+#endif
+
+    unsigned int client_state_change_no = changes.client_state_change_no();
+
+    // determine if state changed
+    if (st_.first.state_change_no() > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<NodeStateMemento>(std::make_pair(st_.first.state(), st_.second)));
+    }
+
+    // determine if def status changed
+    if (d_st_.state_change_no() > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<NodeDefStatusDeltaMemento>(d_st_.state()));
+    }
+
+    // determine if node suspend changed
+    if (suspended_change_no_ > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<SuspendedMemento>(suspended_));
+    }
+
+    // Determine if node attributes DELETED or ADDED, We copy **all** internal state
+    // When applying on the client side, we clear all node attributes( ie Node::clear())
+    // and re-add
+    if (state_change_no_ > client_state_change_no) {
+
+        /// *****************************************************************************************
+        /// Node attributes DELETED or ADDED, i.e we call comp->clear_attributes()
+        /// *****************************************************************************************
+
+#ifdef DEBUG_MEMENTO
+        std::cout << "    Node::incremental_changes()    Attributes added or deleted\n";
+#endif
+        // Note: auto-cancel does not have any alterable state hence, *NO* memento
+
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->clear_attributes();
+
+        for (const Meter& m : meters_) {
+            comp->add(std::make_shared<NodeMeterMemento>(m));
+        }
+        for (const Event& e : events_) {
+            comp->add(std::make_shared<NodeEventMemento>(e));
+        }
+        for (const Label& l : labels_) {
+            comp->add(std::make_shared<NodeLabelMemento>(l));
+        }
+        for (const auto& a : avisos_) {
+            comp->add(std::make_shared<NodeAvisoMemento>(a));
+        }
+        for (const auto& m : mirrors_) {
+            comp->add(std::make_shared<NodeMirrorMemento>(m));
+        }
+        for (const ecf::TodayAttr& attr : todays_) {
+            comp->add(std::make_shared<NodeTodayMemento>(attr));
+        }
+        for (const ecf::TimeAttr& attr : times_) {
+            comp->add(std::make_shared<NodeTimeMemento>(attr));
+        }
+        for (const DayAttr& attr : days_) {
+            comp->add(std::make_shared<NodeDayMemento>(attr));
+        }
+        for (const DateAttr& attr : dates_) {
+            comp->add(std::make_shared<NodeDateMemento>(attr));
+        }
+        for (const CronAttr& attr : crons_) {
+            comp->add(std::make_shared<NodeCronMemento>(attr));
+        }
+
+        if (misc_attrs_) {
+            const std::vector<VerifyAttr>& verify_attrs = misc_attrs_->verifys();
+            if (!verify_attrs.empty())
+                comp->add(std::make_shared<NodeVerifyMemento>(verify_attrs));
+
+            const std::vector<ZombieAttr>& zombie_attrs = misc_attrs_->zombies();
+            for (const ZombieAttr& attr : zombie_attrs) {
+                comp->add(std::make_shared<NodeZombieMemento>(attr));
+            }
+
+            const std::vector<QueueAttr>& queue_attrs = misc_attrs_->queues();
+            for (const QueueAttr& attr : queue_attrs) {
+                comp->add(std::make_shared<NodeQueueMemento>(attr));
+            }
+
+            const std::vector<GenericAttr>& generic_attrs = misc_attrs_->generics();
+            for (const GenericAttr& attr : generic_attrs) {
+                comp->add(std::make_shared<NodeGenericMemento>(attr));
+            }
+        }
+
+        for (limit_ptr l : limits_) {
+            comp->add(std::make_shared<NodeLimitMemento>(*l));
+        }
+        for (const Variable& v : vars_) {
+            comp->add(std::make_shared<NodeVariableMemento>(v));
+        }
+
+        inLimitMgr_.get_memento(comp);
+
+        if (t_expr_)
+            comp->add(std::make_shared<NodeTriggerMemento>(*t_expr_));
+        if (c_expr_)
+            comp->add(std::make_shared<NodeCompleteMemento>(*c_expr_));
+        if (!repeat_.empty())
+            comp->add(std::make_shared<NodeRepeatMemento>(repeat_));
+        if (late_)
+            comp->add(std::make_shared<NodeLateMemento>(*late_));
+
+        comp->add(std::make_shared<FlagMemento>(flag_));
+
+        changes.add(comp);
+        return;
+    }
+
+    /// *****************************************************************************************
+    /// Node attributes CHANGED
+    /// *****************************************************************************************
+
+    // ** if start to Change ZombieAttr then it needs to be added here, currently we only add/delete.
+
+    // determine if event, meter, label   changed.
+    for (const Event& e : events_) {
+        if (e.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeEventMemento>(e));
+        }
+    }
+    for (const Meter& m : meters_) {
+        if (m.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeMeterMemento>(m));
+        }
+    }
+    for (const Label& l : labels_) {
+        if (l.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeLabelMemento>(l));
+        }
+    }
+    for (const auto& a : avisos_) {
+        if (a.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeAvisoMemento>(a));
+        }
+    }
+    for (const auto& a : mirrors_) {
+        if (a.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeMirrorMemento>(a));
+        }
+    }
+
+    // Determine if the time related dependency changed
+    for (const TodayAttr& attr : todays_) {
+        if (attr.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeTodayMemento>(attr));
+        }
+    }
+    for (const TimeAttr& attr : times_) {
+        if (attr.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeTimeMemento>(attr));
+        }
+    }
+    for (const DayAttr& attr : days_) {
+        if (attr.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeDayMemento>(attr));
+        }
+    }
+    for (const DateAttr& attr : dates_) {
+        if (attr.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeDateMemento>(attr));
+        }
+    }
+    for (const CronAttr& attr : crons_) {
+        if (attr.state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeCronMemento>(attr));
+        }
+    }
+
+    if (misc_attrs_) {
+
+        const std::vector<QueueAttr>& queue_attrs = misc_attrs_->queues();
+        for (const QueueAttr& attr : queue_attrs) {
+            if (attr.state_change_no() > client_state_change_no) {
+                if (!comp.get())
+                    comp = std::make_shared<CompoundMemento>(absNodePath());
+                comp->add(std::make_shared<NodeQueueIndexMemento>(attr.name(), attr.index(), attr.state_vec()));
+            }
+        }
+
+        // zombies have no state that changes
+        // If one verify changes then copy all. Avoids having to work out which one changed
+        const std::vector<VerifyAttr>& verify_attrs = misc_attrs_->verifys();
+        for (const VerifyAttr& v : verify_attrs) {
+            if (v.state_change_no() > client_state_change_no) {
+                if (!comp.get())
+                    comp = std::make_shared<CompoundMemento>(absNodePath());
+                comp->add(std::make_shared<NodeVerifyMemento>(verify_attrs));
+                break;
+            }
+        }
+    }
+
+    // determine if the trigger or complete changed
+    if (t_expr_ && t_expr_->state_change_no() > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<NodeTriggerMemento>(*t_expr_));
+    }
+    if (c_expr_ && c_expr_->state_change_no() > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<NodeCompleteMemento>(*c_expr_));
+    }
+
+    // determine if the repeat changed
+    if (!repeat_.empty() && repeat_.state_change_no() > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<NodeRepeatIndexMemento>(repeat_));
+    }
+
+    // determine if limits changed.
+    for (limit_ptr l : limits_) {
+        if (l->state_change_no() > client_state_change_no) {
+            if (!comp.get())
+                comp = std::make_shared<CompoundMemento>(absNodePath());
+            comp->add(std::make_shared<NodeLimitMemento>(*l));
+        }
+    }
+
+    // determine if variable values changed. Copy all variables. Save on having variable_change_no_ per variable
+    if (variable_change_no_ > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        for (const Variable& v : vars_) {
+            comp->add(std::make_shared<NodeVariableMemento>(v));
+        }
+    }
+
+    // Determine if the late attribute has changed
+    if (late_ && late_->state_change_no() > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<NodeLateMemento>(*late_));
+    }
+
+    // Determine if the flag changed
+    if (flag_.state_change_no() > client_state_change_no) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<FlagMemento>(flag_));
+    }
+
+    if (comp.get()) {
+        changes.add(comp);
+    }
+}
+
+void Node::set_memento(const NodeStateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const StateMemento* memento) " << debugNodePath() << "  "
+              << NState::toString(memento->state_) << "\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::STATE);
+    else {
+        setStateOnly(memento->state_.first);
+        st_.second = memento->state_.second;
+    }
+}
+
+void Node::set_memento(const NodeDefStatusDeltaMemento* memento,
+                       std::vector<ecf::Aspect::Type>& aspects,
+                       bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeDefStatusDeltaMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::DEFSTATUS);
+    else
+        d_st_.setState(memento->state_);
+}
+
+void Node::set_memento(const SuspendedMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const SuspendedMemento* memento) " << debugNodePath() << "\n";
+#endif
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::SUSPENDED);
+        return;
+    }
+
+    if (memento->suspended_)
+        suspend();
+    else
+        resume();
+}
+
+void Node::set_memento(const NodeEventMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeEventMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::EVENT);
+        return;
+    }
+
+    if (set_event(memento->event_.name_or_number(), memento->event_.value())) {
+        return;
+    }
+    addEvent(memento->event_);
+}
+
+void Node::set_memento(const NodeMeterMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeMeterMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::METER);
+        return;
+    }
+
+    if (set_meter(memento->meter_.name(), memento->meter_.value())) {
+        return;
+    }
+    addMeter(memento->meter_);
+}
+
+void Node::set_memento(const NodeLabelMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeLabelMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::LABEL);
+        return;
+    }
+
+    size_t theSize = labels_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (labels_[i].name() == memento->label_.name()) {
+            labels_[i] = memento->label_;
+            return;
+        }
+    }
+    addLabel(memento->label_);
+}
+
+void Node::set_memento(const NodeAvisoMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeAvisoMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::AVISO);
+        return;
+    }
+
+    size_t theSize = avisos_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (avisos_[i].name() == memento->aviso_.name()) {
+            avisos_[i] = memento->aviso_;
+            return;
+        }
+    }
+    addAviso(memento->aviso_);
+}
+
+void Node::set_memento(const NodeMirrorMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeMirrorMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::MIRROR);
+        return;
+    }
+
+    size_t theSize = mirrors_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (mirrors_[i].name() == memento->mirror_.name()) {
+            mirrors_[i] = memento->mirror_;
+            return;
+        }
+    }
+    addMirror(memento->mirror_);
+}
+
+void Node::set_memento(const NodeQueueMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::QUEUE);
+        return;
+    }
+    if (misc_attrs_) {
+        misc_attrs_->set_memento(m);
+        return;
+    }
+    add_queue(m->queue_);
+}
+
+void Node::set_memento(const NodeGenericMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::GENERIC);
+        return;
+    }
+    if (misc_attrs_) {
+        misc_attrs_->set_memento(m);
+        return;
+    }
+    add_generic(m->generic_);
+}
+
+void Node::set_memento(const NodeQueueIndexMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+    if (aspect_only) {
+        // For attribute add/delete Should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::QUEUE_INDEX);
+        return;
+    }
+
+    // The queue must exist
+    if (misc_attrs_) {
+        misc_attrs_->set_memento(m);
+        return;
+    }
+}
+
+void Node::set_memento(const NodeTriggerMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeTriggerMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::EXPR_TRIGGER);
+        return;
+    }
+
+    if (t_expr_) {
+        if (memento->exp_.isFree())
+            freeTrigger();
+        else
+            clearTrigger();
+        return;
+    }
+    add_trigger_expression(memento->exp_);
+}
+
+void Node::set_memento(const NodeCompleteMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeCompleteMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::EXPR_COMPLETE);
+        return;
+    }
+
+    if (c_expr_) {
+        if (memento->exp_.isFree())
+            freeComplete();
+        else
+            clearComplete();
+        return;
+    }
+    add_complete_expression(memento->exp_);
+}
+
+void Node::set_memento(const NodeRepeatMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeRepeatMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::REPEAT);
+        return;
+    }
+
+    if (!repeat_.empty()) {
+
+        // Note: the node is incremented one past the last value.
+        // In Node, we increment() then check for validity so the_new_value may be outside the valid range.
+        // This may happen when doing an incremental sync, *hence*, allow memento to copy the value as is.
+        repeat_.set_value(memento->repeat_.index_or_value());
+
+        // Alternative, but expensive since relies on cloning and coping potentially very large vectors
+        // repeat_ = memento->repeat_;
+        return;
+    }
+
+    addRepeat(memento->repeat_);
+}
+
+void Node::set_memento(const NodeRepeatIndexMemento* memento,
+                       std::vector<ecf::Aspect::Type>& aspects,
+                       bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeRepeatIndexMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::REPEAT_INDEX);
+        return;
+    }
+
+    if (!repeat_.empty()) {
+
+        // Note: the node is incremented one past the last value.
+        // In Node we increment() then check for validity so the_new_value may be outside the valid range.
+        // This may happen when doing an incremental sync, *hence*, allow memento to copy the value as is.
+        repeat_.set_value(memento->index_or_value_);
+    }
+}
+
+void Node::set_memento(const NodeLimitMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeLimitMemento* memento) " << debugNodePath() << "  "
+              << memento->limit_.toString() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::LIMIT);
+        return;
+    }
+
+    limit_ptr limit = find_limit(memento->limit_.name());
+    if (limit.get()) {
+        limit->set_state(memento->limit_.theLimit(), memento->limit_.value(), memento->limit_.paths());
+        return;
+    }
+    addLimit(memento->limit_);
+}
+
+void Node::set_memento(const NodeInLimitMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeInLimitMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // ADD_REMOVE_ATTR aspect only, since no state
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        return;
+    }
+
+    addInLimit(memento->inlimit_);
+}
+
+void Node::set_memento(const NodeVariableMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeVariableMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    // If we have added/delete variables then ecf::Aspect::ADD_REMOVE_ATTR has already been added to aspects
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::NODE_VARIABLE);
+        return;
+    }
+
+    size_t theSize = vars_.size();
+    for (size_t i = 0; i < theSize; i++) {
+        if (vars_[i].name() == memento->var_.name()) {
+            vars_[i].set_value(memento->var_.theValue());
+            return;
+        }
+    }
+    addVariable(memento->var_);
+}
+
+void Node::set_memento(const NodeLateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeLateMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::LATE);
+        return;
+    }
+
+    if (late_) {
+        late_->setLate(memento->late_.isLate());
+        return;
+    }
+    addLate(memento->late_);
+}
+
+void Node::set_memento(const NodeTodayMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeTodayMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::TODAY);
+        return;
+    }
+
+    for (auto& today : todays_) {
+        // We need to ignore state changes in TodayAttr, (ie we don't use equality operator)
+        // otherwise today will never compare
+        if (today.structureEquals(memento->attr_)) {
+            today = memento->attr_; // need to copy over time series state
+            return;
+        }
+    }
+    addToday(memento->attr_);
+}
+
+void Node::set_memento(const NodeTimeMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeTimeMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::TIME);
+        return;
+    }
+
+    for (auto& time : times_) {
+        // We need to ignore state changes in TimeAttr, (ie we don't use equality operator)
+        // otherwise time will never compare
+        if (time.structureEquals(memento->attr_)) {
+            time = memento->attr_; // need to copy over time series state
+            return;
+        }
+    }
+    addTime(memento->attr_);
+}
+
+void Node::set_memento(const NodeDayMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeDayMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::DAY);
+        return;
+    }
+
+    for (auto& day : days_) {
+        // We need to ignore state changes (ie we don't use equality operator)
+        // otherwise attributes will never compare
+        if (day.structureEquals(memento->attr_)) {
+            day = memento->attr_;
+            return;
+        }
+    }
+    addDay(memento->attr_);
+}
+
+void Node::set_memento(const NodeDateMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeDateMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::DATE);
+        return;
+    }
+
+    for (auto& date : dates_) {
+        // We need to ignore state changes (ie we don't use equality operator)
+        // otherwise attributes will never compare
+        if (date.structureEquals(memento->attr_)) {
+            if (memento->attr_.isSetFree())
+                date.setFree();
+            else
+                date.clearFree();
+            return;
+        }
+    }
+    addDate(memento->attr_);
+}
+
+void Node::set_memento(const NodeCronMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeCronMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        aspects.push_back(ecf::Aspect::CRON);
+        return;
+    }
+
+    for (auto& cron : crons_) {
+        // We need to ignore state changes (ie we don't use equality operator)
+        // otherwise attributes will never compare
+        if (cron.structureEquals(memento->attr_)) {
+            cron = memento->attr_; // need to copy over time series state
+            return;
+        }
+    }
+    addCron(memento->attr_);
+}
+
+void Node::set_memento(const FlagMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const FlagMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::FLAG);
+    else
+        flag_.set_flag(memento->flag_.flag());
+}
+
+void Node::set_memento(const NodeZombieMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeZombieMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        // No state, only ADD_REMOVE_ATTR aspect
+        return;
+    }
+
+    // Zombie attributes should always be via ADD_REMOVE_ATTR
+    // See Node::incremental_changes
+    // Since there is no state to change
+
+    /// remove existing attribute of same type, as duplicate of same type not allowed
+    delete_zombie(memento->attr_.zombie_type());
+    addZombie(memento->attr_);
+}
+
+void Node::set_memento(const NodeVerifyMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Node::set_memento(const NodeVerifyMemento* memento) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        // For attribute add/delete, should have already added ecf::Aspect::ADD_REMOVE_ATTR to aspects
+        return;
+    }
+
+    if (misc_attrs_) {
+        misc_attrs_->verifys_.clear();
+        misc_attrs_->verifys_ = memento->verifys_;
+        return;
+    }
+
+    misc_attrs_           = std::make_unique<MiscAttrs>(this);
+    misc_attrs_->verifys_ = memento->verifys_;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeState.hpp 5.13.0-1/libs/node/src/ecflow/node/NodeState.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeState.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeState.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_NodeState_HPP
+#define ecflow_node_NodeState_HPP
+
+#include "ecflow/core/NState.hpp"
+
+///
+/// \brief Given a set of nodes, theComputedNodeState returns the most significant state
+/// Depend on the Node::computedState, hence include after Node.hpp
+/// This will recurse down ****
+///
+
+namespace ecf {
+
+template <class T>
+NState::State theComputedNodeState(const std::vector<T>& nodeVec, bool immediate) {
+    // std::cout << "theComputedNodeState vec size = " << nodeVec.size() << " immediate  = " <<  immediate << "\n";
+    int completeCount  = 0;
+    int queuedCount    = 0;
+    int submittedCount = 0;
+    int activeCount    = 0;
+    int abortedCount   = 0;
+
+    // We don't know the order, hence we must collate first
+    size_t theVecSize = nodeVec.size();
+    for (size_t n = 0; n < theVecSize; n++) {
+        NState::State theState;
+        if (immediate)
+            theState = nodeVec[n]->state();
+        else
+            theState = nodeVec[n]->computedState(Node::HIERARCHICAL);
+
+        // std::cout << "the computed state for " << nodeVec[n]->debugNodePath() << " is " << NState::toString(theState)
+        // << "\n";
+
+        switch (theState) {
+            case NState::ABORTED:
+                abortedCount++;
+                break;
+            case NState::ACTIVE:
+                activeCount++;
+                break;
+            case NState::SUBMITTED:
+                submittedCount++;
+                break;
+            case NState::QUEUED:
+                queuedCount++;
+                break;
+            case NState::COMPLETE:
+                completeCount++;
+                break;
+            case NState::UNKNOWN:
+                // Does nothing...
+                break;
+            default:
+                assert(false);
+                break;
+        }
+    }
+    if (abortedCount > 0)
+        return NState::ABORTED;
+    if (activeCount > 0)
+        return NState::ACTIVE;
+    if (submittedCount > 0)
+        return NState::SUBMITTED;
+    if (queuedCount > 0)
+        return NState::QUEUED;
+    if (completeCount > 0)
+        return NState::COMPLETE;
+    return NState::UNKNOWN;
+}
+
+} // namespace ecf
+
+#endif /* ecflow_node_NodeState_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeStats.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeStats.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeStats.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeStats.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/NodeStats.hpp"
+
+#include <sstream>
+using namespace std;
+
+std::string NodeStats::print() const {
+    stringstream ss;
+    ss << "Definition statistics\n";
+    ss << "Nodes               " << nodes_ << "\n";
+    ss << "Suites              " << suites_ << "\n";
+    ss << "Family              " << family_ << "\n";
+    ss << "Task                " << task_ << "\n";
+    ss << "Alias               " << alias_ << "\n\n";
+    if (suites_ + family_ + task_ + alias_ != nodes_)
+        ss << "suites_ + family_ +  task_ + alias_ != nodes_ ?\n";
+
+    ss << "Edit history nodes  " << edit_history_nodes_ << "\n";
+    ss << "Edit history paths  " << edit_history_paths_ << "\n\n";
+
+    ss << "vars                " << vars_ << "\n";
+    ss << "triggers            " << trigger_ << "\n";
+    ss << "complete triggers   " << c_trigger_ << "\n";
+    ss << "events              " << events_ << "\n";
+    ss << "labels              " << labels_ << "\n";
+    ss << "meters              " << meters_ << "\n\n";
+
+    ss << "times               " << times_ << "\n";
+    ss << "todays              " << todays_ << "\n";
+    ss << "crons               " << crons_ << "\n";
+    ss << "dates               " << dates_ << "\n";
+    ss << "days                " << days_ << "\n\n";
+
+    ss << "late                " << late_ << "\n";
+    ss << "inlimits            " << inlimits_ << "\n";
+    ss << "limits              " << limits_ << "\n";
+    ss << "repeats             " << repeats_ << "\n";
+    ss << "zombies             " << zombies_ << "\n\n";
+
+    ss << "auto_cancel         " << auto_cancel_ << "\n";
+    ss << "auto_archive        " << auto_archive_ << "\n";
+    ss << "auto_restore        " << auto_restore_ << "\n";
+    ss << "verifys             " << verifys_ << "\n";
+    ss << "queues              " << queues_ << "\n";
+    ss << "generics            " << generics_ << "\n";
+    return ss.str();
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeStats.hpp 5.13.0-1/libs/node/src/ecflow/node/NodeStats.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeStats.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeStats.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_NodeStats_HPP
+#define ecflow_node_NodeStats_HPP
+
+#include <string>
+
+struct NodeStats
+{
+    NodeStats() = default;
+
+    std::string print() const;
+
+    size_t suites_{0};
+    size_t family_{0};
+    size_t task_{0};
+    size_t alias_{0};
+    size_t nodes_{0};
+
+    size_t edit_history_nodes_{0};
+    size_t edit_history_paths_{0};
+
+    size_t vars_{0};
+    size_t c_trigger_{0};
+    size_t trigger_{0};
+    size_t meters_{0};
+    size_t events_{0};
+    size_t labels_{0};
+
+    size_t times_{0};
+    size_t todays_{0};
+    size_t crons_{0};
+    size_t dates_{0};
+    size_t days_{0};
+
+    size_t late_{0};
+    size_t zombies_{0};
+    size_t verifys_{0};
+    size_t queues_{0};
+    size_t generics_{0};
+
+    size_t repeats_{0};
+    size_t limits_{0};
+    size_t inlimits_{0};
+
+    size_t auto_cancel_{0};
+    size_t auto_archive_{0};
+    size_t auto_restore_{0};
+};
+
+#endif /* ecflow_node_NodeStats_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeTime.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeTime.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeTime.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeTime.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,914 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/CmdContext.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+// #define DEBUG_DAY 1
+
+///////////////////////////////////////////////////////////////////////////////////////////
+
+void Node::do_requeue_time_attrs(bool reset_next_time_slot, bool reset_relative_duration, Requeue_args::Requeue_t rt) {
+    // must be done before the re-queue
+    if (reset_relative_duration) {
+        for (auto& cron : crons_) {
+            cron.resetRelativeDuration();
+        }
+        for (auto& today : todays_) {
+            today.resetRelativeDuration();
+        }
+        for (auto& time : times_) {
+            time.resetRelativeDuration();
+        }
+    }
+
+    /// If a job takes longer than it slots, then that slot is missed, and next slot is used
+    /// Note we do *NOT* reset for requeue as we want to advance to the next time slot
+    /// *NOTE* Update calendar will *free* time dependencies *even* time series. They rely
+    /// on this function to clear the time dependencies so they *HOLD* the task.
+    const Calendar& calendar = suite()->calendar();
+    for (auto& today : todays_) {
+        today.requeue(calendar, reset_next_time_slot);
+    }
+    for (auto& time : times_) {
+        time.requeue(calendar, reset_next_time_slot);
+    }
+    for (auto& cron : crons_) {
+        cron.requeue(calendar, reset_next_time_slot);
+    }
+    for (auto& aviso : avisos_) {
+        aviso.start();
+    }
+
+    for (auto& date : dates_) {
+        date.requeue();
+    } // make sure only run once
+
+    if (!days_.empty()) {
+        // The day attribute, is matched with the corresponding *date* under requeue.
+        // HOWEVER, when re-queueing due to a *TIME* dependency we MUST keep the current date on the day attribute
+        // ADDITIONALLY WE use expired_ to remove days which have *EXPIRED* (i.e. failed for check for re-queue), thus
+        // avoiding is_free() OTHERWISE when we have multiple days, even the days which have expired are considered for
+        // running the task.
+        switch (rt) {
+            case Requeue_args::FULL: {
+#ifdef DEBUG_DAY
+                cout << " Node::do_requeue_time_attrs  Requeue_args::FULL \n";
+#endif
+                for (auto& day : days_) {
+                    day.requeue_manual(calendar);
+                }
+                break;
+            }
+            case Requeue_args::REPEAT_INCREMENT: {
+#ifdef DEBUG_DAY
+                cout << " Node::do_requeue_time_attrs  Requeue_args::REPEAT_INCREMENT \n";
+#endif
+                for (auto& day : days_) {
+                    day.requeue_repeat_increment(calendar);
+                }
+                break;
+            }
+            case Requeue_args::TIME: {
+#ifdef DEBUG_DAY
+                cout << " Node::do_requeue_time_attrs  Requeue_args::TIME \n";
+#endif
+                for (auto& day : days_) {
+                    day.requeue_time();
+                }
+                break;
+            }
+        }
+    }
+}
+
+bool Node::calendar_changed_timeattrs(const ecf::Calendar& c, Node::Calendar_args& cal_args) {
+#ifdef DEBUG_DAY
+    cout << "Node::calendar_changed_timeattrs " << debugNodePath() << " " << c.suite_time_str() << "\n";
+#endif
+
+    // For time/today/cron attributes if the time is free, it *remains* free until re-queued
+    // However if we have day/date dependencies, that do NOT match, then we should *NOT* free
+    // any time/today/cron attributes.
+    //
+    //   task t
+    //     day Monday   # this will guard the time.
+    //     time 10:00
+    //
+    // Hence if we are on Sunday we do *NOT* want to free the time on SUNDAY
+    // (Otherwise we will end up running the task at Monday Midnight
+    //  and not Monday at 10.00)
+    //
+    // Likewise:
+    //   family f1
+    //     day monday     # this will guard the time(this is different to ecflow 4.0) holding_parent_day_or_date_
+    //     task t
+    //       time 10:00
+    //
+    //   family f1
+    //      time 10:00    # time will be set down at 10.00 am
+    //      task t
+    //        day monday  # Job will run at Monday morning *AND* at 10:00
+
+    // cout << "Node::calendar_changed_timeattrs " << c.toString() << "\n";
+    //   std::vector<node_ptr> all_children1;
+    //   allChildren(all_children1);
+    //   for(size_t t = 0; t <  all_children1.size(); t++) {
+    //       cout << "   " << all_children1[t]->debugNodePath() << " " << NState::toString(all_children1[t]->state()) <<
+    //       "\n";
+    //   }
+    //   AstTop* ast = triggerAst();
+    //   if (ast) {
+    //      ast->print(cout);
+    //      cout << "\n";
+    //   }
+
+    if (days_.empty() && dates_.empty()) {
+
+        // No Day or Date, If time matches  calendarChanged(c) will free time dependencies
+        for (auto& time : times_) {
+            time.calendarChanged(c);
+        }
+        for (auto& today : todays_) {
+            today.calendarChanged(c);
+        }
+        for (auto& cron : crons_) {
+            cron.calendarChanged(c);
+        }
+    }
+    else {
+
+        // If *BEFORE* midnight we have FREE day/date and submitted or active jobs, don't clear the day/dates
+        // i.e. take:
+        //    family f1
+        //       day monday
+        //       time 23:00
+        //       task t1  # This took longer than 1 hour
+        //       task t2  # allow task to continue to the next day
+        //         trigger t1 == complete
+        // This is only applicable for NodeContainers, for task with day/date always CLEAR at midnight
+        // ECFLOW-337 versus ECFLOW-1550
+
+        bool clear_day_at_midnight  = true;
+        bool clear_date_at_midnight = true;
+        if (c.dayChanged() && isNodeContainer()) {
+
+#ifdef DEBUG_DAY
+            cout << "  Node::calendar_changed_timeattrs DAY CHANGED " << debugNodePath() << " " << c.suite_time_str()
+                 << "\n";
+#endif
+            // Check if day/date are free *BEFORE* midnight and *BEFORE* calendarChanged called(since that clears
+            // Day::makeFree_) The isFree below relies on Day::makeFree_/Date:makeFree_ not being cleared till after
+            // midnight
+            bool free_date = false;
+            bool free_day  = false;
+            for (const auto& date : dates_) {
+                if (date.isFree(c)) {
+                    free_date = true;
+                    break;
+                }
+            }
+            for (const auto& day : days_) {
+                if (day.isFree(c)) {
+                    free_day = true;
+                    break;
+                }
+            }
+
+#ifdef DEBUG_DAY
+            cout << "  Node::calendar_changed_timeattrs free_day " << free_day << " free_date " << free_date << "\n";
+#endif
+            if (free_date || free_day) {
+                // See if we have any complete submitted or active children,
+                // if so DON'T clear day/date at midnight. hence day/date will *STAY* *FREE*
+                // Allow following tasks to complete
+                std::vector<node_ptr> all_children;
+                allChildren(all_children);
+                int completed = 0;
+                int submitted = 0;
+                int queued    = 0;
+                int active    = 0;
+                for (auto& t : all_children) {
+                    // cout << all_children[t]->debugNodePath() << " " << NState::toString(all_children[t]->state()) <<
+                    // "\n";
+                    if (t->isTask()) {
+                        if (t->state() == NState::SUBMITTED)
+                            submitted++;
+                        else if (t->state() == NState::ACTIVE)
+                            active++;
+                        else if (t->state() == NState::COMPLETE)
+                            completed++;
+                        else if (t->state() == NState::QUEUED)
+                            queued++;
+                        if (active || submitted) {
+                            if (free_date)
+                                clear_date_at_midnight = false;
+                            if (free_day)
+                                clear_day_at_midnight = false;
+#ifdef DEBUG_DAY
+                            cout << "  if (active || submitted ) clear_day_date_at_midnight = false\n";
+#endif
+                            break;
+                        }
+                        if (completed && (active || submitted || queued)) {
+                            if (free_date)
+                                clear_date_at_midnight = false;
+                            if (free_day)
+                                clear_day_at_midnight = false;
+#ifdef DEBUG_DAY
+                            cout << "  if (completed && (active || submitted || queued)) clear_day_date_at_midnight = "
+                                    "false\n";
+#endif
+                            break;
+                        }
+                    }
+                }
+            }
+        }
+
+        bool at_least_one_day_free = false;
+        for (auto& day : days_) {
+            day.calendarChanged(c, clear_day_at_midnight);
+            if (!at_least_one_day_free)
+                at_least_one_day_free = day.isFree(c);
+        }
+
+        bool at_least_one_date_free = false;
+        for (auto& date : dates_) {
+            date.calendarChanged(c, clear_date_at_midnight);
+            if (!at_least_one_date_free)
+                at_least_one_date_free = date.isFree(c);
+        }
+
+        if (at_least_one_day_free || at_least_one_date_free) {
+            for (auto& time : times_) {
+                time.calendarChanged(c);
+            }
+            for (auto& today : todays_) {
+                today.calendarChanged(c);
+            }
+            for (auto& cron : crons_) {
+                cron.calendarChanged(c);
+            }
+        }
+        else {
+            // Node has *HOLDING* day or date dependency. Avoid free time dependencies of *ANY* child nodes
+#ifdef DEBUG_DAY
+            cout << "Node::calendar_changed_timeattrs " << debugNodePath()
+                 << " SETTING holding_parent_day_or_date_  at " << c.suite_time_str() << "\n";
+#endif
+            return true;
+        }
+    }
+    return false;
+}
+
+void Node::markHybridTimeDependentsAsComplete() {
+    // If hybrid clock, then we may have day/date/cron time dependencies
+    // which mean that node will be stuck in the QUEUED state, i.e. since the
+    // date/day does not change with the hybrid clock.
+    // hence Mark these Nodes as complete
+    const Calendar& calendar = suite()->calendar();
+    if (state() != NState::COMPLETE && calendar.hybrid()) {
+        if (!dates_.empty() || !days_.empty() || !crons_.empty()) {
+
+            int noOfTimeDependencies = 0;
+            if (!dates_.empty())
+                noOfTimeDependencies++;
+            if (!days_.empty())
+                noOfTimeDependencies++;
+            if (!crons_.empty())
+                noOfTimeDependencies++;
+
+            bool oneDateIsFree = false;
+            bool oneDayIsFree  = false;
+            bool oneCronIsFree = false;
+
+            for (auto& date : dates_) {
+                if (date.validForHybrid(calendar)) {
+                    if (noOfTimeDependencies == 1) {
+                        setStateOnly(NState::QUEUED);
+                        return;
+                    }
+                    oneDateIsFree = true;
+                    break;
+                }
+            }
+            for (auto& day : days_) {
+                if (day.validForHybrid(calendar)) {
+                    if (noOfTimeDependencies == 1) {
+                        setStateOnly(NState::QUEUED);
+                        return;
+                    }
+                    oneDayIsFree = true;
+                    break;
+                }
+            }
+            for (auto& cron : crons_) {
+                if (cron.validForHybrid(calendar)) {
+                    if (noOfTimeDependencies == 1) {
+                        setStateOnly(NState::QUEUED);
+                        return;
+                    }
+                    oneCronIsFree = true;
+                    break;
+                }
+            }
+
+            if (oneDateIsFree || oneDayIsFree || oneCronIsFree) {
+                if (noOfTimeDependencies > 1) {
+                    // when we have multiple time dependencies their results *MUST* be added for the node to be free.
+                    if (!dates_.empty() && !oneDateIsFree) {
+                        setStateOnly(NState::COMPLETE);
+                        return;
+                    }
+                    if (!days_.empty() && !oneDayIsFree) {
+                        setStateOnly(NState::COMPLETE);
+                        return;
+                    }
+                    if (!crons_.empty() && !oneCronIsFree) {
+                        setStateOnly(NState::COMPLETE);
+                        return;
+                    }
+
+                    // We will only get here, if we have a multiple time dependencies any there is one free in each
+                    // category
+                    setStateOnly(NState::QUEUED);
+                    return;
+                }
+            }
+
+            setStateOnly(NState::COMPLETE);
+        }
+    }
+}
+
+// #define DEBUG_REQUEUE 1
+// #include "ecflow/core/Log.hpp"
+bool Node::testTimeDependenciesForRequeue() {
+    // This function is called as a part of handling state change.
+    // We only get here if the Node has *COMPLETED* ( either automatically, or manually i.e. force complete)
+    // We are now determining if the node should be re-queued due to time dependency in the *FUTURE*
+    const Calendar& calendar = suite()->calendar();
+
+#ifdef DEBUG_REQUEUE
+    LogToCout logtocout;
+    LOG(Log::DBG, "Node::testTimeDependenciesForRequeue() " << debugNodePath() << " calendar " << calendar.toString());
+#endif
+
+    // When we have a mixture of cron *with* other time based attributes
+    // The cron *takes* priority.  Crons should always return true, for checkForRequeue
+    for (const CronAttr& cron : crons_) {
+        if (cron.checkForRequeue(calendar)) { // will always return true
+#ifdef DEBUG_REQUEUE
+            LOG(Log::DBG,
+                "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for cron -> allow-requeue");
+#endif
+            return true;
+        }
+    }
+
+    // When in a CmdContext. If we are *BEFORE* the scheduled time, then *ALLOW* re-queue
+    bool cmd_context = CmdContext::in_command();
+    if (!times_.empty()) {
+        TimeSlot the_min, the_max; // Needs to handle multiple single slot time attributes
+        for (const ecf::TimeAttr& time : times_) {
+            time.min_max_time_slots(the_min, the_max);
+        }
+        for (const ecf::TimeAttr& time : times_) {
+            if (time.checkForRequeue(calendar, the_min, the_max, cmd_context)) {
+#ifdef DEBUG_REQUEUE
+                LOG(Log::DBG,
+                    "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for " << time.toString()
+                                                                 << " -> allow-requeue");
+#endif
+                return true;
+            }
+        }
+    }
+
+    if (!todays_.empty()) {
+        TimeSlot the_min, the_max; // Needs to handle multiple single slot today attributes
+        for (const ecf::TodayAttr& today : todays_) {
+            today.min_max_time_slots(the_min, the_max);
+        }
+        for (const ecf::TodayAttr& today : todays_) {
+            if (today.checkForRequeue(calendar, the_min, the_max, cmd_context)) {
+#ifdef DEBUG_REQUEUE
+                LOG(Log::DBG,
+                    "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for " << today.toString()
+                                                                 << " -> allow-requeue");
+#endif
+                return true;
+                ;
+            }
+        }
+    }
+
+    // **********************************************************************
+    // If we get here there are **NO** time/today/cron dependencies which are free
+    // We now need to determine if this node has a *FUTURE* time dependency which
+    // should re-queue this node.
+    // *********************************************************************
+    for (const DateAttr& date : dates_) {
+        if (date.checkForRequeue(calendar)) {
+#ifdef DEBUG_REQUEUE
+            LOG(Log::DBG,
+                "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for " << date.toString()
+                                                             << " -> allow-requeue");
+#endif
+            return true;
+        }
+    }
+
+    for (DayAttr& day : days_) {
+        if (cmd_context) {
+            // In the command context,i.e. force complete or task runs and completes, then expire the day.
+            // *EVEN* if the day is in the future: why?: The user has taken control, *TYPICALLY* the day is under
+            // a repeat, by expiring, we allow the repeat to increment
+            //       before *only* if the day matched under the command context, we got this behaviour. i.e. with
+            //       check_for_expiration
+            day.set_expired();
+        }
+        else {
+            // If any day matches calendar day or is in the past, then expire it, so we don't run again on that day.
+            // Must be done BEFORE checkForRequeue
+            //   task t1
+            //      time 09:00    # time attribute get considered before day/date, allowing multiple re-queues on the
+            //      same day time 10:00    # day saturday  # After time expiration, day must be expired day sunday
+            day.check_for_expiration(calendar);
+        }
+    }
+    for (const DayAttr& day : days_) {
+        if (day.checkForRequeue(calendar)) {
+#ifdef DEBUG_REQUEUE
+            LOG(Log::DBG,
+                "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " for days  -> allow-requeue");
+#endif
+            return true;
+        }
+    }
+
+#ifdef DEBUG_REQUEUE
+    LOG(Log::DBG, "   Node::testTimeDependenciesForRequeue() " << debugNodePath() << " HOLDING");
+#endif
+    return false;
+}
+
+void Node::miss_next_time_slot() {
+    // Why do we need to set NO_REQUE_IF_SINGLE_TIME_DEP flag ?
+    // This is required when we have time based attributes, which we want to miss.
+    //    time 10:00
+    //    time 12:00
+    // Essentially this avoids an automated job run, *IF* the job was run manually for a given time slot.
+    // If we call this function before 10:00, we want to miss the next time slot (i.e. 10:00)
+    // and want to *requeue*, for 12:00 time slot. However, at re-queue, we need to ensure
+    // we do *not* reset the 10:00 time slot. hence by setting NO_REQUE_IF_SINGLE_TIME_DEP
+    // we allow requeue to query this flag, and hence avoid resetting the time based attribute
+    // Note: requeue will *always* clear NO_REQUE_IF_SINGLE_TIME_DEP afterward.
+    //
+    // In the case above when we reach the last time slot, there is *NO* automatic requeue, and
+    // hence, *no* clearing of NO_REQUE_IF_SINGLE_TIME_DEP flag.
+    // This will then be up to any top level parent that has a Repeat/cron to force a requeue
+    // when all the children are complete. *or* user does a manual re-queue
+    //
+    // Additionally if the job *aborts*, we clear NO_REQUE_IF_SINGLE_TIME_DEP if it was set.
+    // Otherwise, if manually run again, we will miss further time slots.
+    if (has_time_dependencies()) {
+
+        /// Handle abort
+        /// The flag: NO_REQUE_IF_SINGLE_TIME_DEP is *only* set when doing an interactive force complete or run command.
+        /// What happens if the job aborts during the run command ?
+        ///     time 10:00
+        ///     time 11:00
+        /// If at 9.00am we used the run command, we want to miss the 10:00 time slot.
+        /// However if the run at 9.00 fails, and we run again, we also miss 11:00 time slot.
+        /// During the run the flag is still set.
+        /// Hence *ONLY* miss the next time slot *IF* Flag::NO_REQUE_IF_SINGLE_TIME_DEP is NOT set
+        if (!flag().is_set(Flag::NO_REQUE_IF_SINGLE_TIME_DEP)) {
+
+            SuiteChanged0 changed(shared_from_this());
+            flag().set(Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
+
+            // Note: when we have multiple time dependencies.
+            // We need find valid next time dependency:
+            //   time 10:00
+            //   time 11:00
+            //   time 12:00 14:00 00:30
+            // Also we could have a mix:
+            //   time  10:00
+            //   today 10:30
+            //   time 11:00
+            //   time 12:00 14:00 00:30
+
+            // for the moment assume, they have been added sequentially,
+            // hence only first non expired time is updated to miss next time slot
+            for (auto& time : times_) {
+                if (time.time_series().is_valid()) {
+                    time.miss_next_time_slot();
+                    break;
+                }
+            }
+            for (auto& today : todays_) {
+                if (today.time_series().is_valid()) {
+                    today.miss_next_time_slot();
+                    break;
+                }
+            }
+            for (auto& cron : crons_) {
+                if (cron.time_series().is_valid()) {
+                    cron.miss_next_time_slot();
+                    break;
+                }
+            }
+        }
+    }
+}
+
+void Node::freeHoldingDateDependencies() {
+    // Multiple time dependencies of the same type are *ORed*
+    // Multiple time dependencies of different types are *ANDed*
+    //
+    // Hence since we have multiple time dependencies of the same
+    // type here, we need free only one of them
+    const Calendar& calendar = suite()->calendar();
+    for (auto& date : dates_) {
+        if (!date.isFree(calendar)) {
+            date.setFree();
+            break;
+        }
+    }
+}
+
+void Node::freeHoldingTimeDependencies() {
+    // Multiple time dependencies of the same type are *ORed*
+    // Multiple time dependencies of different types are *ANDed*
+    //
+    // If we have multiple time dependencies of different types
+    // we need only free one in each category
+    const Calendar& calendar = suite()->calendar();
+    for (auto& time : times_) {
+        if (!time.isFree(calendar)) {
+            time.setFree();
+            time.miss_next_time_slot();
+            break;
+        }
+    }
+    for (auto& today : todays_) {
+        if (!today.isFree(calendar)) {
+            today.setFree();
+            today.miss_next_time_slot();
+            break;
+        }
+    }
+    for (auto& day : days_) {
+        if (!day.isFree(calendar)) {
+            day.setFree();
+            break;
+        }
+    }
+    for (auto& cron : crons_) {
+        if (!cron.isFree(calendar)) {
+            cron.setFree();
+            cron.miss_next_time_slot();
+            break;
+        }
+    }
+}
+
+bool Node::has_time_dependencies() const {
+    if (!times_.empty())
+        return true;
+    if (!todays_.empty())
+        return true;
+    if (!crons_.empty())
+        return true;
+    if (!dates_.empty())
+        return true;
+    if (!days_.empty())
+        return true;
+    if (!avisos_.empty())
+        return true;
+    return false;
+}
+
+bool Node::holding_day_or_date(const ecf::Calendar& c) const {
+    if (days_.empty() && dates_.empty())
+        return false;
+
+    bool at_least_one_day_free = false;
+    for (auto& day : days_) {
+        if (!at_least_one_day_free)
+            at_least_one_day_free = day.isFree(c);
+    }
+
+    bool at_least_one_date_free = false;
+    for (auto& date : dates_) {
+        if (!at_least_one_date_free)
+            at_least_one_date_free = date.isFree(c);
+    }
+
+    if (at_least_one_day_free || at_least_one_date_free) {
+        return false;
+    }
+    return true;
+}
+
+bool Node::timeDependenciesFree() const {
+    int noOfTimeDependencies = 0;
+    if (!times_.empty())
+        noOfTimeDependencies++;
+    if (!todays_.empty())
+        noOfTimeDependencies++;
+    if (!dates_.empty())
+        noOfTimeDependencies++;
+    if (!days_.empty())
+        noOfTimeDependencies++;
+    if (!crons_.empty())
+        noOfTimeDependencies++;
+    if (!avisos_.empty()) // TODO: Not really time related! Should be moved to another member function
+        noOfTimeDependencies++;
+
+    // if no time dependencies we are free
+    if (noOfTimeDependencies == 0)
+        return true;
+
+    // if we have a holding day/date don't consider other time attributes
+    const Calendar& calendar = suite()->calendar();
+    if (holding_day_or_date(calendar)) {
+        return false;
+    }
+
+    bool oneDateIsFree  = false;
+    bool oneDayIsFree   = false;
+    bool oneTodayIsFree = false;
+    bool oneTimeIsFree  = false;
+    bool oneCronIsFree  = false;
+    bool oneAvisoIsFree = false;
+
+    for (const auto& time : times_) {
+        if (time.isFree(calendar)) {
+            if (noOfTimeDependencies == 1)
+                return true;
+            oneTimeIsFree = true;
+            break;
+        }
+    }
+    for (const auto& cron : crons_) {
+        if (cron.isFree(calendar)) {
+            if (noOfTimeDependencies == 1)
+                return true;
+            oneCronIsFree = true;
+            break;
+        }
+    }
+    for (const auto& date : dates_) {
+        if (date.isFree(calendar)) {
+            if (noOfTimeDependencies == 1)
+                return true;
+            oneDateIsFree = true;
+            break;
+        }
+    }
+    for (const auto& day : days_) {
+        if (day.isFree(calendar)) {
+            if (noOfTimeDependencies == 1)
+                return true;
+            oneDayIsFree = true;
+            break;
+        }
+    }
+    for (const auto& aviso : avisos_) {
+        if (aviso.isFree()) {
+            LOG(Log::DBG, "NodeTime: checking Aviso isFree: true, for " << aviso.path() << ":" << aviso.name());
+            if (noOfTimeDependencies == 1) {
+                return true;
+            }
+            oneAvisoIsFree = true;
+            break;
+        }
+        else {
+            LOG(Log::DBG, "NodeTime: checking Aviso isFree: false");
+        }
+    }
+
+    if (!todays_.empty()) {
+        // : single Today: (single-time)    is free, if calendar time >= today_time
+        // : single Today: (range)          is free, if calendar time == (one of the time ranges)
+        // : multi Today : (single | range) is free, if calendar time == (one of the time ranges | today_time)
+        // : multi Today : (single | range) is free, all are free
+        if (todays_.size() == 1) {
+            // Single Today Attribute: could be single slot or range
+            if (todays_[0].isFree(calendar)) {
+                if (noOfTimeDependencies == 1)
+                    return true;
+                oneTodayIsFree = true;
+            }
+        }
+        else {
+            // Multiple Today Attributes, each could single, or range
+            size_t free_count = 0;
+            for (const auto& today : todays_) {
+                if (today.isFreeMultipleContext(calendar)) {
+                    if (noOfTimeDependencies == 1)
+                        return true;
+                    oneTodayIsFree = true;
+                    break;
+                }
+                if (today.isFree(calendar))
+                    free_count++;
+            }
+            if (free_count == todays_.size()) {
+                if (noOfTimeDependencies == 1)
+                    return true;
+                oneTodayIsFree = true;
+            }
+        }
+    }
+
+    if (oneDateIsFree || oneDayIsFree || oneTodayIsFree || oneTimeIsFree || oneCronIsFree || oneAvisoIsFree) {
+        if (noOfTimeDependencies > 1) {
+            // *When* we have multiple time dependencies of *different types* then the results
+            // *MUST* be added for the node to be free.
+            if (!dates_.empty() && !oneDateIsFree)
+                return false;
+            if (!days_.empty() && !oneDayIsFree)
+                return false;
+            if (!todays_.empty() && !oneTodayIsFree)
+                return false;
+            if (!times_.empty() && !oneTimeIsFree)
+                return false;
+            if (!crons_.empty() && !oneCronIsFree)
+                return false;
+            if (!avisos_.empty() && !oneAvisoIsFree)
+                return false;
+
+            // We will only get here, if we have a multiple time dependencies and they are free
+            return true;
+        }
+    }
+
+    return false;
+}
+
+bool Node::time_today_cron_is_free() const {
+    if (!times_.empty() || !todays_.empty() || !crons_.empty()) {
+
+        int noOfTimeDependencies = 0;
+        if (!times_.empty())
+            noOfTimeDependencies++;
+        if (!todays_.empty())
+            noOfTimeDependencies++;
+        if (!crons_.empty())
+            noOfTimeDependencies++;
+
+        bool oneTodayIsFree = false;
+        bool oneTimeIsFree  = false;
+        bool oneCronIsFree  = false;
+
+        const Calendar& calendar = suite()->calendar();
+        for (const auto& time : times_) {
+            if (time.isFree(calendar)) {
+                if (noOfTimeDependencies == 1)
+                    return true;
+                oneTimeIsFree = true;
+                break;
+            }
+        }
+        for (const auto& cron : crons_) {
+            if (cron.isFree(calendar)) {
+                if (noOfTimeDependencies == 1)
+                    return true;
+                oneCronIsFree = true;
+                break;
+            }
+        }
+
+        if (!todays_.empty()) {
+            // : single Today: (single-time)   is free, if calendar time >= today_time
+            // : single Today: (range)         is free, if calendar time == (one of the time ranges)
+            // : multi Today : (single | range)is free, if calendar time == (one of the time ranges | today_time)
+            if (todays_.size() == 1) {
+                // Single Today Attribute: could be single slot or range
+                if (todays_[0].isFree(calendar)) {
+                    if (noOfTimeDependencies == 1)
+                        return true;
+                    oneTodayIsFree = true;
+                }
+            }
+            else {
+                // Multiple Today Attributes, each could single, or range
+                for (const auto& today : todays_) {
+                    if (today.isFreeMultipleContext(calendar)) {
+                        if (noOfTimeDependencies == 1)
+                            return true;
+                        oneTodayIsFree = true;
+                        break;
+                    }
+                }
+            }
+        }
+
+        if (oneTodayIsFree || oneTimeIsFree || oneCronIsFree) {
+            if (noOfTimeDependencies > 1) {
+                // *When* we have multiple time dependencies of *different types* then the results
+                // *MUST* be added for the node to be free.
+                if (!todays_.empty() && !oneTodayIsFree)
+                    return false;
+                if (!times_.empty() && !oneTimeIsFree)
+                    return false;
+                if (!crons_.empty() && !oneCronIsFree)
+                    return false;
+
+                // We will only get here, if we have a multiple time dependencies and they are free
+                return true;
+            }
+        }
+    }
+
+    return false;
+}
+
+void Node::get_time_resolution_for_simulation(boost::posix_time::time_duration& resol) const {
+    for (const auto& time : times_) {
+        const TimeSeries& time_series = time.time_series();
+        if (time_series.start().minute() != 0) {
+            resol = minutes(1);
+            return;
+        }
+        if (time_series.hasIncrement()) {
+            if (time_series.finish().minute() != 0) {
+                resol = minutes(1);
+                return;
+            }
+            if (time_series.incr().minute() != 0) {
+                resol = minutes(1);
+                return;
+            }
+        }
+    }
+
+    for (const auto& today : todays_) {
+        const TimeSeries& time_series = today.time_series();
+        if (time_series.start().minute() != 0) {
+            resol = minutes(1);
+            return;
+        }
+        if (time_series.hasIncrement()) {
+            if (time_series.finish().minute() != 0) {
+                resol = minutes(1);
+                return;
+            }
+            if (time_series.incr().minute() != 0) {
+                resol = minutes(1);
+                return;
+            }
+        }
+    }
+
+    for (const auto& cron : crons_) {
+        const TimeSeries& time_series = cron.time_series();
+        if (time_series.start().minute() != 0) {
+            resol = minutes(1);
+            return;
+        }
+        if (time_series.hasIncrement()) {
+            if (time_series.finish().minute() != 0) {
+                resol = minutes(1);
+                return;
+            }
+            if (time_series.incr().minute() != 0) {
+                resol = minutes(1);
+                return;
+            }
+        }
+    }
+}
+
+void Node::get_max_simulation_duration(boost::posix_time::time_duration& duration) const {
+    // don't override a higher value of duration
+    if ((!times_.empty() || !todays_.empty()) && duration < hours(24))
+        duration = hours(24); // day
+    if (!days_.empty() && duration < hours(168))
+        duration = hours(168); // week
+    if (!dates_.empty() && duration < hours(24 * 7 * 31))
+        duration = hours(24 * 7 * 31); // month
+    if (!crons_.empty())
+        duration = hours(8760); // year
+    if (!repeat_.empty())
+        duration = hours(8760); // year
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeTreeVisitor.cpp 5.13.0-1/libs/node/src/ecflow/node/NodeTreeVisitor.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeTreeVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeTreeVisitor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/NodeTreeVisitor.hpp"
+
+namespace ecf {
+
+NodeTreeVisitor::~NodeTreeVisitor() = default;
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/NodeTreeVisitor.hpp 5.13.0-1/libs/node/src/ecflow/node/NodeTreeVisitor.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/NodeTreeVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/NodeTreeVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_NodeTreeVisitor_HPP
+#define ecflow_node_NodeTreeVisitor_HPP
+
+class Defs;
+class Suite;
+class Family;
+class Task;
+class NodeContainer;
+
+namespace ecf {
+
+class NodeTreeVisitor {
+public:
+    virtual ~NodeTreeVisitor();
+
+    virtual bool traverseObjectStructureViaVisitors() const { return false; }
+    virtual void visitDefs(Defs*)                   = 0;
+    virtual void visitSuite(Suite*)                 = 0;
+    virtual void visitFamily(Family*)               = 0;
+    virtual void visitNodeContainer(NodeContainer*) = 0;
+    virtual void visitTask(Task*)                   = 0;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_NodeTreeVisitor_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Operations.hpp 5.13.0-1/libs/node/src/ecflow/node/Operations.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Operations.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Operations.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,206 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Operations_HPP
+#define ecflow_node_Operations_HPP
+
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+namespace ecf {
+
+/**
+ * BootstrapDefs, traverses the Node tree when the the server (re)starts or when a new suite is loaded,
+ * and is used to bootstrap all required nodes and attributes.
+ */
+struct BootstrapDefs
+{
+    inline void operator()(AvisoAttr& attr) const {
+        if (attr.parent()->state() == NState::QUEUED) {
+            attr.start();
+        }
+    }
+    inline void operator()(MirrorAttr& attr) const { attr.mirror(); }
+
+    template <typename T>
+    void operator()(T&& t) const { /* Nothing to do... */ }
+};
+
+/**
+ * ShutdownDefs, traverses the Node tree when the the server shutsdown/halts,,
+ * and is used to shutdown all required nodes and attributes.
+ */
+struct ShutdownDefs
+{
+    inline void operator()(AvisoAttr& attr) const { attr.finish(); }
+    inline void operator()(MirrorAttr& attr) const { attr.finish(); }
+
+    template <typename T>
+    void operator()(T&& t) const { /* Nothing to do... */ }
+};
+
+/**
+ * ActivateAll, traverses the Node tree periodicablly, and effectively triggers the synchronization between the
+ * main and background threads.
+ */
+struct ActivateAll
+{
+    inline void operator()(MirrorAttr& attr) const { attr.mirror(); }
+
+    template <typename T>
+    void operator()(T&& t) const { /* Nothing to do... */ }
+};
+
+namespace detail {
+
+template <typename V, typename I>
+void visit_all(const std::vector<std::shared_ptr<I>>& all, V&& visitor) {
+    for (auto& item : all) {
+        visit_all(*item, std::forward<V>(visitor));
+    }
+}
+
+template <typename V, typename I>
+void visit_attrs(std::vector<I>& all, V&& visitor) {
+    for (auto& i : all) {
+        visit_all(i, std::forward<V>(visitor));
+    }
+}
+
+template <typename I>
+struct VisitorAll
+{
+    template <typename V>
+    void operator()(V&& v) {
+        v(item_);
+    }
+
+    I& item_;
+};
+
+template <>
+struct VisitorAll<Task>
+{
+    template <typename V>
+    void operator()(V&& v) {
+        v(task_);
+        visit_attrs(task_.avisos(), std::forward<V>(v));
+        visit_attrs(task_.mirrors(), std::forward<V>(v));
+    }
+
+    Task& task_;
+};
+
+template <>
+struct VisitorAll<Family>
+{
+    template <typename V>
+    void operator()(V&& v) {
+        v(family_);
+        visit_all(family_.children(), std::forward<V>(v));
+    }
+
+    Family& family_;
+};
+
+template <>
+struct VisitorAll<Node>
+{
+    template <typename V>
+    void operator()(V&& v) {
+        if (auto* family_ptr = dynamic_cast<Family*>(&node_)) {
+            visit_all(*family_ptr, std::forward<V>(v));
+        }
+        else if (auto* task_ptr = dynamic_cast<Task*>(&node_)) {
+            visit_all(*task_ptr, std::forward<V>(v));
+        }
+        if (auto* alias_ptr = dynamic_cast<Alias*>(&node_)) {
+            visit_all(*alias_ptr, std::forward<V>(v));
+        }
+    }
+
+    Node& node_;
+};
+
+template <>
+struct VisitorAll<Suite>
+{
+    template <typename V>
+    void operator()(V&& v) {
+        v(*this);
+        visit_all(suite_.children(), std::forward<V>(v));
+    }
+
+    Suite& suite_;
+};
+
+template <>
+struct VisitorAll<Defs>
+{
+    template <typename V>
+    void operator()(V&& v) {
+        v(*this);
+
+        visit_all(defs_.suiteVec(), std::forward<V>(v));
+    }
+
+    Defs& defs_;
+};
+
+template <typename I>
+struct VisitorParent
+{
+    template <typename V>
+    void operator()(V&& v) {
+        v(item_);
+        if (auto* parent = item_.parent(); parent) {
+            visit_parents(*parent, std::forward<V>(v));
+        }
+    }
+
+    I& item_;
+};
+
+} // namespace detail
+
+/**
+ * Traverses all nodes downwards in the tree, including the given item and all its children.
+ *
+ * @tparam V - Visitor type
+ * @tparam I - Item type
+ * @param item - The 'root' item to traverse
+ * @param visitor - The visitor to apply to each item
+ */
+template <typename V, typename I>
+void visit_all(I& item, V&& visitor) {
+    detail::VisitorAll<I>{item}(std::forward<V>(visitor));
+}
+
+/**
+ * Traverses nodes upwards in the tree, including the given item and all its parents.
+ *
+ * @tparam V - Visitor type
+ * @tparam I - Item type
+ * @param item - The 'leaf' item to traverse
+ * @param visitor - The visitor to apply to each item
+ */
+template <typename V, typename I>
+void visit_parents(I& item, V&& visitor) {
+    detail::VisitorParent<I>{item}(std::forward<V>(visitor));
+}
+
+} // namespace ecf
+
+#endif // ecflow_node_Operations_HPP
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ResolveExternsVisitor.cpp 5.13.0-1/libs/node/src/ecflow/node/ResolveExternsVisitor.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ResolveExternsVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ResolveExternsVisitor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,150 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/ResolveExternsVisitor.hpp"
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+///////////////////////////////////////////////////////////////////////////////
+// ResolveExternsVisitor: Will traverse node tree hierarchy
+ResolveExternsVisitor::ResolveExternsVisitor(Defs* defs) : defs_(defs) {
+}
+
+void ResolveExternsVisitor::visitDefs(Defs* d) {
+    for (suite_ptr s : d->suiteVec()) {
+        s->acceptVisitTraversor(*this);
+    }
+}
+
+void ResolveExternsVisitor::visitSuite(Suite* s) {
+    visitNodeContainer(s);
+}
+void ResolveExternsVisitor::visitFamily(Family* f) {
+    visitNodeContainer(f);
+}
+
+void ResolveExternsVisitor::visitNodeContainer(NodeContainer* nc) {
+
+    setup(nc);
+
+    for (node_ptr t : nc->nodeVec()) {
+        t->acceptVisitTraversor(*this);
+    }
+}
+
+void ResolveExternsVisitor::visitTask(Task* t) {
+    setup(t);
+}
+
+void ResolveExternsVisitor::setup(Node* n) {
+    // Defs passed in to avoid, traversing up the node tree
+    n->auto_add_inlimit_externs(defs_);
+    doSetup(n, n->completeAst());
+    doSetup(n, n->triggerAst());
+}
+
+void ResolveExternsVisitor::doSetup(Node* node, Ast* ast) {
+    if (ast) {
+        // The complete expression have been parsed and we have created the abstract syntax tree
+        AstResolveExternVisitor astVisitor(node, defs_);
+        ast->accept(astVisitor);
+    }
+}
+
+//======================================================================================
+// AstResolveExternVisitor: Will traverse ASR tree hierarchy
+AstResolveExternVisitor::AstResolveExternVisitor(Node* node, Defs* defs) : triggerNode_(node), defs_(defs) {
+}
+
+AstResolveExternVisitor::~AstResolveExternVisitor() = default;
+
+void AstResolveExternVisitor::visitNode(AstNode* astNode) {
+    // std::cout << " AstResolveExternVisitor::visitNode " << triggerNode_->debugNodePath() << "\n";
+
+    astNode->setParentNode(triggerNode_);
+
+    // See if can reference the path, on the AstNode, if we can't, it should be added as an extern
+    std::string errorMsg;
+    Node* node = astNode->referencedNode(errorMsg);
+    if (!node) {
+        /// Add this path to the extern's. Avoid adding duplicates
+        addExtern(astNode->nodePath());
+    }
+}
+
+void AstResolveExternVisitor::visitVariable(AstVariable* astVar) {
+    // std::cout << " AstResolveExternVisitor::visitNode " << triggerNode_->debugNodePath() << "\n";
+
+    astVar->setParentNode(triggerNode_);
+
+    // See if can reference the path, on the AstVariable, if we can't, it should be added as an extern
+    std::string errorMsg;
+    Node* theReferencedNode = astVar->referencedNode(errorMsg);
+    if (!theReferencedNode) {
+        addExtern(astVar->nodePath(), astVar->name());
+        return;
+    }
+    LOG_ASSERT(errorMsg.empty(), "");
+
+    // Ok,we found the referenced, node, now see if we can reference the attribute name
+    // Find in order, event, meter, user variable, repeat, generated variable
+    if (theReferencedNode->findExprVariable(astVar->name())) {
+        return;
+    }
+
+    // Can't find name, in event, meter, user variable, repeat, generated variable, add as extern
+    addExtern(astVar->nodePath(), astVar->name());
+}
+
+void AstResolveExternVisitor::visitParentVariable(AstParentVariable* astvar) {
+    // std::cout << " AstResolveExternVisitor::visitParentVariable  " << triggerNode_->debugNodePath() << "\n";
+
+    astvar->setParentNode(const_cast<Node*>(triggerNode_));
+
+    if (!astvar->find_node_which_references_variable()) {
+
+        addExtern(triggerNode_->absNodePath(), astvar->name()); // absolute var
+    }
+}
+
+void AstResolveExternVisitor::visitFlag(AstFlag* astVar) {
+    // std::cout << " AstResolveExternVisitor::visitFlag " << triggerNode_->debugNodePath() << "\n";
+
+    astVar->setParentNode(triggerNode_);
+
+    // See if can reference the path, on the AstFlag, if we can't, it should be added as an extern
+    std::string errorMsg;
+    Node* theReferencedNode = astVar->referencedNode(errorMsg);
+    if (!theReferencedNode) {
+        addExtern(astVar->nodePath(), astVar->name()); // return flag:late
+        return;
+    }
+}
+
+void AstResolveExternVisitor::addExtern(const std::string& absNodePath, const std::string& var) {
+    string ext = absNodePath;
+    if (!var.empty()) {
+        ext += Str::COLON();
+        ext += var;
+    }
+    // cout << " AstResolveExternVisitor::addExtern " << ext << "\n";
+    defs_->add_extern(ext); // stored in a set:
+}
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ResolveExternsVisitor.hpp 5.13.0-1/libs/node/src/ecflow/node/ResolveExternsVisitor.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ResolveExternsVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ResolveExternsVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,80 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ResolveExternsVisitor_HPP
+#define ecflow_node_ResolveExternsVisitor_HPP
+
+#include "ecflow/node/ExprAstVisitor.hpp"
+#include "ecflow/node/NodeTreeVisitor.hpp"
+
+class Node;
+class Ast;
+
+namespace ecf {
+
+class ResolveExternsVisitor final : public NodeTreeVisitor {
+public:
+    explicit ResolveExternsVisitor(Defs*);
+
+    bool traverseObjectStructureViaVisitors() const override { return true; }
+    void visitDefs(Defs*) override;
+    void visitSuite(Suite*) override;
+    void visitFamily(Family*) override;
+    void visitNodeContainer(NodeContainer*) override;
+    void visitTask(Task*) override;
+
+private:
+    void setup(Node*);
+    void doSetup(Node* node, Ast* ast);
+
+    Defs* defs_;
+};
+
+class AstResolveExternVisitor : public ExprAstVisitor {
+public:
+    AstResolveExternVisitor(Node*, Defs*);
+    ~AstResolveExternVisitor() override;
+
+    void visitTop(AstTop*) override {}
+    void visitRoot(AstRoot*) override {}
+    void visitAnd(AstAnd*) override {}
+    void visitNot(AstNot*) override {}
+    void visitPlus(AstPlus*) override {}
+    void visitMinus(AstMinus*) override {}
+    void visitDivide(AstDivide*) override {}
+    void visitMultiply(AstMultiply*) override {}
+    void visitModulo(AstModulo*) override {}
+    void visitOr(AstOr*) override {}
+    void visitEqual(AstEqual*) override {}
+    void visitNotEqual(AstNotEqual*) override {}
+    void visitLessEqual(AstLessEqual*) override {}
+    void visitGreaterEqual(AstGreaterEqual*) override {}
+    void visitGreaterThan(AstGreaterThan*) override {}
+    void visitLessThan(AstLessThan*) override {}
+    void visitLeaf(AstLeaf*) override {}
+    void visitInteger(AstInteger*) override {}
+    void visitInstant(AstInstant*) override {}
+    void visitFunction(AstFunction*) override {}
+    void visitNodeState(AstNodeState*) override {}
+    void visitEventState(AstEventState*) override {}
+    void visitNode(AstNode*) override;
+    void visitVariable(AstVariable*) override;
+    void visitParentVariable(AstParentVariable*) override;
+    void visitFlag(AstFlag*) override;
+
+private:
+    void addExtern(const std::string& absNodePath, const std::string& var = "");
+    Node* triggerNode_;
+    Defs* defs_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_ResolveExternsVisitor_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ServerState.cpp 5.13.0-1/libs/node/src/ecflow/node/ServerState.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/ServerState.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ServerState.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,478 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/ServerState.hpp"
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+// When a Defs is loaded into a server:
+//       	o the jobSubmissionInterval_ is set
+//       	o the jobGeneration_ is set
+ServerState::ServerState() : server_state_(default_state()) {
+    setup_default_env(Str::DEFAULT_PORT_NUMBER());
+}
+
+ServerState::ServerState(const std::string& port) : server_state_(default_state()) {
+    setup_default_env(port);
+}
+
+bool ServerState::operator==(const ServerState& rhs) const {
+    if (get_state() != rhs.get_state()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "ServerState::operator== get_state(" << SState::to_string(get_state()) << ") != rhs.get_state("
+                      << SState::to_string(rhs.get_state()) << ")\n";
+        }
+#endif
+        return false;
+    }
+
+    if (user_variables_ != rhs.user_variables_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "ServerState::compare user_variables_ != rhs.user_variables_\n";
+            std::cout << "user_variables_:\n";
+            for (std::vector<Variable>::const_iterator i = user_variables_.begin(); i != user_variables_.end(); ++i) {
+                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
+            }
+            std::cout << "rhs.user_variables_:\n";
+            for (std::vector<Variable>::const_iterator i = rhs.user_variables_.begin(); i != rhs.user_variables_.end();
+                 ++i) {
+                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
+            }
+        }
+#endif
+        return false;
+    }
+
+    /// Check pointing and PrintStyle::MIGRATE, SAVES server variables, since they are visualised by client like
+    /// ecflow_ui However the server does NOT load the server variable in the DEFS. Otherwise uses can change ECF_PID.
+
+    if (!DebugEquality::ignore_server_variables() && server_variables_ != rhs.server_variables_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "ServerState::compare server_variables_ != rhs.server_variables_ \n";
+            std::cout << "server_variables_:\n";
+            for (std::vector<Variable>::const_iterator i = server_variables_.begin(); i != server_variables_.end();
+                 ++i) {
+                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
+            }
+            std::cout << "rhs.server_variables_:\n";
+            for (std::vector<Variable>::const_iterator i = rhs.server_variables_.begin();
+                 i != rhs.server_variables_.end();
+                 ++i) {
+                std::cout << "   " << (*i).name() << " " << (*i).theValue() << "\n";
+            }
+        }
+#endif
+        return false;
+    }
+
+    return true;
+}
+
+bool ServerState::compare(const ServerState& rhs) const {
+    if (get_state() != rhs.get_state()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "ServerState::compare get_state(" << SState::to_string(get_state()) << ") != rhs.get_state("
+                      << SState::to_string(rhs.get_state()) << ")\n";
+        }
+#endif
+        return false;
+    }
+
+    if (user_variables_ != rhs.user_variables_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "ServerState::compare user_variables_ != rhs.user_variables_\n";
+            std::cout << "user_variables_:\n";
+            for (const auto& u : user_variables_)
+                std::cout << "   " << u.name() << " " << u.theValue() << "\n";
+
+            std::cout << "rhs.user_variables_:\n";
+            for (const auto& u : rhs.user_variables_)
+                std::cout << "   " << u.name() << " " << u.theValue() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (!DebugEquality::ignore_server_variables() && server_variables_ != rhs.server_variables_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "ServerState::compare server_variables_ != rhs.server_variables_\n";
+            std::cout << "server_variables_:\n";
+            for (const auto& s : server_variables_)
+                std::cout << "   " << s.name() << " " << s.theValue() << "\n";
+
+            std::cout << "rhs.server_variables_:\n";
+            for (const auto& s : rhs.server_variables_)
+                std::cout << "   " << s.name() << " " << s.theValue() << "\n";
+        }
+#endif
+        return false;
+    }
+    return true;
+}
+
+void ServerState::sort_variables() {
+    variable_state_change_no_ = Ecf::incr_state_change_no();
+
+    auto caseless = [](const Variable& a, const Variable& b) { return Str::caseInsLess(a.name(), b.name()); };
+    sort(user_variables_.begin(), user_variables_.end(), caseless);
+    sort(server_variables_.begin(), server_variables_.end(), caseless);
+}
+
+// server variable CANNOT be modified or deleted, only overridden
+void ServerState::add_or_update_server_variables(const NameValueVec& env) {
+    for (const auto& p : env) {
+        add_or_update_server_variable(p.first, p.second);
+    }
+}
+void ServerState::add_or_update_server_variable(const std::string& name, const std::string& value) {
+    for (auto& s : server_variables_) {
+        if (s.name() == name) {
+            s.set_value(value);
+            //         std::cout << "   Server Variables: Updating " << name << "   " << value << "\n";
+            return;
+        }
+    }
+    //   std::cout << "   Server Variables: Adding " << name << "   " << value << "\n";
+    server_variables_.emplace_back(name, value);
+}
+
+void ServerState::set_server_variables(const std::vector<Variable>& e) {
+    server_variables_ = e;
+}
+
+void ServerState::delete_server_variable(const std::string& var) {
+    auto var_end = server_variables_.end();
+    for (auto i = server_variables_.begin(); i != var_end; ++i) {
+        if ((*i).name() == var) {
+            server_variables_.erase(i);
+            break;
+        }
+    }
+}
+
+// ================================================================================
+
+void ServerState::add_or_update_user_variables(const NameValueVec& env) {
+    for (const auto& p : env) {
+        add_or_update_user_variables(p.first, p.second);
+    }
+}
+
+void ServerState::add_or_update_user_variables(const std::vector<Variable>& env) {
+    for (const auto& v : env) {
+        add_or_update_user_variables(v.name(), v.theValue());
+    }
+}
+
+void ServerState::add_or_update_user_variables(const std::string& name, const std::string& value) {
+    for (auto& u : user_variables_) {
+        if (u.name() == name) {
+            u.set_value(value);
+            variable_state_change_no_ = Ecf::incr_state_change_no();
+            //         std::cout << "   ServerState::add_or_update_user_variables: Updating " << name << "   " << value
+            //         << "\n";
+            return;
+        }
+    }
+
+    //	std::cout << "   ServerState::add_or_update_user_variables: Adding " << name << "   " << value << "\n";
+    user_variables_.emplace_back(name, value);
+    variable_state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ServerState::delete_user_variable(const std::string& var) {
+    if (var.empty()) {
+        // delete all user variables
+        user_variables_.clear();
+        variable_state_change_no_ = Ecf::incr_state_change_no();
+        return;
+    }
+
+    auto var_end = user_variables_.end();
+    for (auto i = user_variables_.begin(); i != var_end; ++i) {
+        if ((*i).name() == var) {
+            user_variables_.erase(i);
+            variable_state_change_no_ = Ecf::incr_state_change_no();
+            break;
+        }
+    }
+}
+
+bool ServerState::find_user_variable(const std::string& name, std::string& value) const {
+    for (const auto& u : user_variables_) {
+        if (u.name() == name) {
+            value = u.theValue();
+            return true;
+        }
+    }
+    return false;
+}
+
+const std::string& ServerState::find_variable(const std::string& theVarName) const {
+    // SEARCH USER variables FIRST
+    for (const auto& u : user_variables_) {
+        if (u.name() == theVarName) {
+            return u.theValue();
+        }
+    }
+
+    // NOW search server variables
+    for (const auto& s : server_variables_) {
+        if (s.name() == theVarName) {
+            LOG_ASSERT(!s.theValue().empty(), "");
+            return s.theValue();
+        }
+    }
+
+    //	cerr << "FAILED to FIND '" << theVarName << "'\n";
+    return Str::EMPTY();
+}
+
+const Variable& ServerState::findVariable(const std::string& name) const {
+    // SEARCH USER variables FIRST
+    for (const auto& u : user_variables_) {
+        if (u.name() == name) {
+            // if (u.theValue().empty() )  std::cout << u.name() << " has a empty value\n";
+            return u;
+        }
+    }
+
+    // NOW search server variables
+    for (const auto& s : server_variables_) {
+        if (s.name() == name) {
+            LOG_ASSERT(!s.theValue().empty(), "");
+            // if (s.theValue().empty() )  std::cout << s.name() << " has a empty value\n";
+            return s;
+        }
+    }
+
+    // cerr << "FAILED to FIND '" << theVarName << "'\n";
+    return Variable::EMPTY();
+}
+
+bool ServerState::variable_exists(const std::string& name) const {
+    // SEARCH USER variables FIRST
+    for (const auto& u : user_variables_) {
+        if (u.name() == name)
+            return true;
+    }
+
+    // NOW search server variables
+    for (const auto& s : server_variables_) {
+        if (s.name() == name)
+            return true;
+    }
+
+    return false;
+}
+
+bool ServerState::variableSubsitution(std::string& cmd) const {
+    // scan the command for variables, and substitute
+    // We can also have
+    //
+    // "%<VAR>:<substitute>% i.e if VAR exist use it, else use substitute
+    //
+    // ************************************************************************************************************
+    // Special case handling for user variables, and generated variables, which take precedence over node variables
+    // ************************************************************************************************************
+    //
+    // i.e VAR is defined as BILL
+    //  %VAR:fred --f%  will either be "BILL" or if VAR is not defined "fred --f"
+    //
+    // Infinite recursion. Its possible to end up with infinite recursion:
+    //    edit hello '%hello%'  # string like %hello% will cause infinite recursion
+    //    edit fred '%bill%'
+    //    edit bill '%fred%'   # should be 10
+    // To prevent this we will use a simple count
+    char micro                = '%';
+    const Variable& micro_var = findVariable(Str::ECF_MICRO());
+    if (!micro_var.empty() && !micro_var.theValue().empty())
+        micro = micro_var.theValue()[0];
+
+    bool double_micro_found    = false;
+    std::string::size_type pos = 0;
+    int count                  = 0;
+    while (true) {
+        // A while loop here is used to:
+        //    a/ Allow for multiple substitution on a single line. i.e %ECF_FILES% -I %ECF_INCLUDE%"
+        //    b/ Allow for recursive substitution. %fred% -> %bill%--> 10
+
+        size_t firstPercentPos = cmd.find(micro, pos);
+        if (firstPercentPos == string::npos)
+            break;
+
+        size_t secondPercentPos = cmd.find(micro, firstPercentPos + 1);
+        if (secondPercentPos == string::npos)
+            break;
+
+        if (secondPercentPos - firstPercentPos <= 1) {
+            // handle %% with no characters in between, skip over
+            // i.e to handle "printf %%02d %HOUR:00%" --> "printf %02d 00"   i.e if HOUR not defined
+            pos                = secondPercentPos + 1;
+            double_micro_found = true;
+            continue;
+        }
+        else
+            pos = 0;
+
+        string percentVar(cmd.begin() + firstPercentPos + 1, cmd.begin() + secondPercentPos);
+
+        // First search user variable (*ONLY* set when doing user edit's the script)
+        // Handle case: cmd = "%fred:bill% and where we have user variable "fred:bill"
+        // Handle case: cmd = "%fred%      and where we have user variable "fred"
+        // If we fail to find the variable we return false.
+        // Note: When a variable is found, it can have an empty value  which is still valid
+        const Variable& variable = findVariable(percentVar);
+        if (!variable.empty()) {
+            std::string varValue = variable.theValue();
+            cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+        }
+        else {
+
+            size_t firstColon = percentVar.find(':');
+            if (firstColon != string::npos) {
+
+                string var(percentVar.begin(), percentVar.begin() + firstColon);
+
+                const Variable& variable2 = findVariable(var);
+                if (!variable2.empty()) {
+                    std::string varValue = variable2.theValue();
+                    cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, varValue);
+                }
+                else {
+                    string substitute(percentVar.begin() + firstColon + 1, percentVar.end());
+                    cmd.replace(firstPercentPos, secondPercentPos - firstPercentPos + 1, substitute);
+                }
+            }
+            else {
+                // No Colon, Can't find in user variables, or node variable, hence can't go any further
+                return false;
+            }
+        }
+
+        // Simple Check for infinite recursion
+        if (count > 100)
+            return false;
+        count++;
+    }
+
+    if (double_micro_found) {
+        // replace all double micro with a single micro, this must be a single parse
+        // date +%%Y%%m%%d" ==> date +%Y%m%d
+        // %%%%             ==> %%            // i.e single parse
+        std::string doubleEcfMicro;
+        doubleEcfMicro += micro;
+        doubleEcfMicro += micro;
+        size_t last_pos = 0;
+        while (true) {
+            string::size_type ecf_double_micro_pos = cmd.find(doubleEcfMicro, last_pos);
+            if (ecf_double_micro_pos != std::string::npos) {
+                cmd.erase(cmd.begin() + ecf_double_micro_pos);
+                last_pos = ecf_double_micro_pos + 1;
+            }
+            else
+                break;
+        }
+    }
+
+    return true;
+}
+
+void ServerState::set_user_variables(const std::vector<Variable>& e) {
+    user_variables_           = e;
+    variable_state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ServerState::set_state(SState::State s) {
+    server_state_    = s;
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+void ServerState::setup_default_env(const std::string& port) {
+    // This environment is required for testing in the absence of the server.
+    // When the defs file is begun in the server this environment get *overridden*
+    hostPort_ = std::make_pair(Str::LOCALHOST(), port);
+
+    setup_default_server_variables(server_variables_, port);
+}
+
+void ServerState::setup_default_server_variables(std::vector<Variable>& server_variables, const std::string& port) {
+    Host host;
+    server_variables.emplace_back(Str::ECF_MICRO(),
+                                  Ecf::MICRO()); // Preprocessor character for variable substitution and including files
+    server_variables.emplace_back(Str::ECF_HOME(), string("."));
+    server_variables.emplace_back(string("ECF_JOB_CMD"), Ecf::JOB_CMD());   // Command to be executed to submit a job
+    server_variables.emplace_back(string("ECF_KILL_CMD"), Ecf::KILL_CMD()); // Command to be executed to kill a job
+    server_variables.emplace_back(string("ECF_STATUS_CMD"),
+                                  Ecf::STATUS_CMD()); // Command to be executed to get status of job
+    server_variables.emplace_back(string("ECF_URL_CMD"), Ecf::URL_CMD());
+    server_variables.emplace_back(string("ECF_URL_BASE"), Ecf::URL_BASE());
+    server_variables.emplace_back(string("ECF_URL"), Ecf::URL());
+    server_variables.emplace_back(string("ECF_LOG"), host.ecf_log_file(port));
+    server_variables.emplace_back(string("ECF_INTERVAL"), string("60")); // Check time dependencies and submit any jobs
+    server_variables.emplace_back(string("ECF_LISTS"), host.ecf_lists_file(port));
+    server_variables.emplace_back(string("ECF_PASSWD"), host.ecf_passwd_file(port));
+    server_variables.emplace_back(string("ECF_CUSTOM_PASSWD"), host.ecf_custom_passwd_file(port));
+    server_variables.emplace_back(string("ECF_CHECK"), host.ecf_checkpt_file(port));
+    server_variables.emplace_back(string("ECF_CHECKOLD"), host.ecf_backup_checkpt_file(port));
+    server_variables.emplace_back(string("ECF_CHECKINTERVAL"),
+                                  string("120")); // The interval in seconds to save check point file
+    server_variables.emplace_back(string("ECF_CHECKMODE"),
+                                  string("CHECK_ON_TIME")); // The check mode, must be one of NEVER, ON_TIME, ALWAYS
+
+    // Number of times a job should rerun if it aborts. If more than one and
+    // job aborts, the job is automatically re-run. Useful when jobs are run in
+    // an unreliable environments. For example using using commands like ftp(1)
+    // in a job can fail easily, but re-running the job will often work
+    server_variables.emplace_back(Str::ECF_TRIES(), string("2"));
+
+    server_variables.emplace_back(string("ECF_VERSION"), Version::raw()); // server version
+
+    // Needed to setup client environment.
+    // The server sets these variable for use by the client. i.e when creating the jobs
+    // The clients then uses them to communicate with the server.
+    server_variables.emplace_back(Str::ECF_PORT(), port);
+    server_variables.emplace_back(Str::ECF_HOST(), Str::LOCALHOST());
+}
+
+/// determines why the node is not running.
+bool ServerState::why(std::vector<std::string>& theReasonWhy) const {
+    if (server_state_ == SState::HALTED) {
+        theReasonWhy.emplace_back("The server is halted");
+        return true;
+    }
+    if (server_state_ == SState::SHUTDOWN) {
+        theReasonWhy.emplace_back("The server is shutdown");
+        return true;
+    }
+    return false;
+}
+
+template <class Archive>
+void ServerState::serialize(Archive& ar, std::uint32_t const version) {
+    ar(CEREAL_NVP(server_state_), CEREAL_NVP(server_variables_));
+    CEREAL_OPTIONAL_NVP(ar, user_variables_, [this]() { return !user_variables_.empty(); });
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(ServerState);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/ServerState.hpp 5.13.0-1/libs/node/src/ecflow/node/ServerState.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/ServerState.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/ServerState.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,128 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_ServerState_HPP
+#define ecflow_node_ServerState_HPP
+
+#include <cstdint>
+
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/core/SState.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+/// This class stores the server state, so that it is accessible by the node tree
+///
+/// The server variables could have been added/deleted or changed, hence these
+/// variables are serialised, also:  it has proved useful i.e for
+///    a/ Client to visualise the server environment during a call like -group="get; show state"
+///    b/ Allows the test code to update environment. ie. use ECF_CLIENT
+////      allows us to replace smsinit, smscomplete,etc, with the ECF client exe
+//
+// Note The default state here is RUNNING while in the server the default state is HALTED
+// By choosing RUNNING, it allows the Defs related test, to run without explicitly setting the state
+class ServerState {
+public:
+    ServerState();
+    explicit ServerState(const std::string& port); // used in test to init server variables
+    ServerState(const ServerState& other)            = default;
+    ServerState& operator=(const ServerState& other) = default;
+
+    /// Check pointing, SAVES server variables, since they are visualised by client like ecflow_ui
+    /// HOWEVER PrintStyle::MIGRATE does not save the server variables, since they should
+    /// not take part in migration. However the testing compares migration files with check point files
+    /// This would always fail. Hence we do not compare server variables.
+    /// This does not compare server variables
+    bool operator==(const ServerState& rhs) const;
+    bool operator!=(const ServerState& rhs) const { return !operator==(rhs); }
+
+    /// This does compare server variables. Used in testing
+    bool compare(const ServerState& rhs) const;
+
+    void sort_variables();
+
+    /// The server variable: are automatically added by the server
+    /// on STARTUP and when a checkpoint file is reloaded.
+    /// The variable are required by Job creation & needed in creation of generated variables
+    /// The variables should NOT be modified.
+    ///
+    /// However user variables can be freely added,deleted and modified
+    /// They will override server variables of the same name
+
+    void add_or_update_server_variable(const std::string&, const std::string&);
+    void add_or_update_server_variables(const NameValueVec& env);
+    void delete_server_variable(const std::string&); // should only be used by test
+    void set_server_variables(const std::vector<Variable>& e);
+    const std::vector<Variable>& server_variables() const { return server_variables_; }
+
+    void add_or_update_user_variables(const NameValueVec& env);
+    void add_or_update_user_variables(const std::vector<Variable>& env);
+    void add_or_update_user_variables(const std::string&, const std::string&);
+    void delete_user_variable(const std::string&);
+
+    void set_user_variables(const std::vector<Variable>& e);
+    const std::vector<Variable>& user_variables() const { return user_variables_; }
+    bool find_user_variable(const std::string& name, std::string& value) const;
+
+    // Search user variables, and then server variables
+    const std::string& find_variable(const std::string& name) const;
+    const Variable& findVariable(const std::string& name) const;
+    bool variable_exists(const std::string& name) const;
+
+    /// find all %VAR% and replaces with variable values, returns false on the
+    /// first variable that can't be found, cmd will be left half processed.
+    /// Will search for ECF_MICRO, if not found assumes % as the micro char
+    bool variableSubsitution(std::string& cmd) const;
+
+    // These functions/data are used to during job generation
+    void jobSubmissionInterval(int s) { jobSubmissionInterval_ = s; }
+    int jobSubmissionInterval() const { return jobSubmissionInterval_; }
+    bool jobGeneration() const { return jobGeneration_; } // testing may disable job generation
+    void jobGeneration(bool f) { jobGeneration_ = f; }
+
+    void set_state(SState::State s);
+    SState::State get_state() const { return server_state_; }
+    static SState::State default_state() { return SState::RUNNING; }
+
+    // set by the server hence no need persist
+    void hostPort(const std::pair<std::string, std::string>& hostPort) { hostPort_ = hostPort; }
+    std::pair<std::string, std::string> hostPort() const { return hostPort_; }
+
+    /// Currently only SState::State server_state_ recorded
+    unsigned int state_change_no() const { return state_change_no_; }
+    unsigned int variable_state_change_no() const { return variable_state_change_no_; }
+
+    /// determines why the node is not running.
+    bool why(std::vector<std::string>& theReasonWhy) const; // return true if why found
+
+    /// Used in test
+    static void setup_default_server_variables(std::vector<Variable>& server_variables, const std::string& port);
+
+private:
+    void setup_default_env(const std::string& port);
+
+private:
+    int jobSubmissionInterval_{60};            // NOT persisted, since set in the server
+    unsigned int state_change_no_{0};          // *not* persisted, only used on server side
+    unsigned int variable_state_change_no_{0}; // *not* persisted, only used on server side
+
+    SState::State server_state_;
+    std::vector<Variable> server_variables_;
+    std::vector<Variable> user_variables_;
+
+    std::pair<std::string, std::string> hostPort_; // NOT persisted, set by server hence no need to persist
+    bool jobGeneration_{true};                     // NOT persisted, since set in the server
+
+private:
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+#endif /* ecflow_node_ServerState_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Signal.cpp 5.13.0-1/libs/node/src/ecflow/node/Signal.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Signal.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Signal.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Signal.hpp"
+
+#include <csignal>
+
+namespace ecf {
+
+// SIGCHLD : Child status has changed (POSIX)
+// Signal sent to parent process whenever one of its child processes terminates or stops.
+
+Signal::Signal() = default;
+
+Signal::~Signal() {
+    // Unblock SIGCHLD. This will call the signal-handler in System.cpp,
+    // *IF* we have pending SIGCHLD
+    // This will not return until we have handled all the pending SIGCHLD signal
+    unblock_sigchild();
+
+    // Once the signals are processed, block them until we come in here again
+    // Now block again.
+    block_sigchild();
+}
+
+void Signal::block_sigchild() {
+    // Now block again.
+    sigset_t set;
+    sigemptyset(&set);
+    sigaddset(&set, SIGCHLD);
+    sigprocmask(SIG_BLOCK, &set, nullptr);
+}
+
+void Signal::unblock_sigchild() {
+    sigset_t set;
+    sigemptyset(&set);
+    sigaddset(&set, SIGCHLD);
+    sigprocmask(SIG_UNBLOCK, &set, nullptr);
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Signal.hpp 5.13.0-1/libs/node/src/ecflow/node/Signal.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Signal.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Signal.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Signal_HPP
+#define ecflow_node_Signal_HPP
+
+///
+/// \brief The Signal class will, during destruction, un-block SIGCHILD and then
+/// reapply the block. During job generation we want to avoid being notified of
+/// of child process termination.
+/// We want to control when child process termination is handled.
+///
+
+namespace ecf {
+
+class Signal {
+public:
+    Signal();
+    // Disable copy (and move) semantics
+    Signal(const Signal&)                  = delete;
+    const Signal& operator=(const Signal&) = delete;
+
+    /// UNBLOCK SIGCHLD at start of destructor
+    /// BLOCK SIGCHLD and the end of the destructor
+    /// During the gap in between handle process termination
+    ~Signal();
+
+    static void block_sigchild();
+    static void unblock_sigchild();
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_Signal_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Submittable.cpp 5.13.0-1/libs/node/src/ecflow/node/Submittable.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Submittable.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Submittable.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1193 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Submittable.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Passwd.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/DefsDelta.hpp"
+#include "ecflow/node/EcfFile.hpp"
+#include "ecflow/node/JobCreationCtrl.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// #define DEBUG_TASK_LOCATION 1
+
+/////////////////////////////////////////////////////////////////////////////////////////////////////
+// init static
+const std::string& Submittable::DUMMY_JOBS_PASSWORD() {
+    static const std::string DUMMY_JOBS_PASSWORD = "_DJP_";
+    return DUMMY_JOBS_PASSWORD;
+}
+const std::string& Submittable::FREE_JOBS_PASSWORD() {
+    static const std::string FREE_JOBS_PASSWORD = "FREE";
+    return FREE_JOBS_PASSWORD;
+}
+const std::string& Submittable::DUMMY_PROCESS_OR_REMOTE_ID() {
+    static const std::string DUMMY_PROCESS_OR_REMOTE_ID = "_RID_";
+    return DUMMY_PROCESS_OR_REMOTE_ID;
+}
+
+Submittable& Submittable::operator=(const Submittable& rhs) {
+    if (this != &rhs) {
+        Node::operator=(rhs);
+        paswd_ = rhs.paswd_;
+        rid_   = rhs.rid_;
+        abr_   = rhs.abr_;
+        tryNo_ = rhs.tryNo_;
+
+        delete sub_gen_variables_;
+        sub_gen_variables_ = nullptr;
+
+        state_change_no_ = Ecf::incr_state_change_no();
+    }
+    return *this;
+}
+
+Submittable::~Submittable() {
+    delete sub_gen_variables_;
+}
+
+bool Submittable::check_defaults() const {
+    if (tryNo_ != 0)
+        throw std::runtime_error("Submittable::check_defaults(): tryNo_ != 0");
+    if (state_change_no_ != 0)
+        throw std::runtime_error("Submittable::check_defaults(): state_change_no_ != 0");
+    if (sub_gen_variables_ != nullptr)
+        throw std::runtime_error("Submittable::check_defaults(): sub_gen_variables_ != nullptr");
+    return Node::check_defaults();
+}
+
+void Submittable::init(const std::string& the_process_or_remote_id) {
+    set_state(NState::ACTIVE);
+    set_process_or_remote_id(the_process_or_remote_id);
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Submittable::init\n";
+#endif
+}
+
+void Submittable::complete() {
+    // cout << "Completed " << debugNodePath() << " at " << suite()->calendar().toString() << "\n";
+    set_state(NState::COMPLETE);
+    flag().clear(ecf::Flag::ZOMBIE);
+
+    /// Should we clear paswd_ & process_id? It can be argued that
+    /// we should keep this. In case it is needed. i.e. The job may not really be
+    /// complete. However keeping, this means the memory usage will continue to rise
+    /// Dependent on number of tasks. This can affect network bandwidth as well.
+    /// Hence to reduce network bandwidth we chose to clear the strings
+    clear(); // jobs password, process_id, aborted_reason
+
+    for (auto&& aviso : avisos()) {
+        aviso.finish();
+    }
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Submittable::complete()\n";
+#endif
+}
+
+void Submittable::aborted(const std::string& reason) {
+    // Called during *abnormal* child termination
+    // This will bubble the state, and decrement any limits
+    set_aborted_only(reason);
+
+    for (auto&& aviso : avisos()) {
+        aviso.finish();
+    }
+}
+
+void Submittable::set_process_or_remote_id(const std::string& id) {
+    rid_ = id;
+    set_genvar_ecfrid(rid_);
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG
+    if (tryNo_ == 0 && rid_ != Submittable::DUMMY_PROCESS_OR_REMOTE_ID()) {
+        LogToCout logToCout;
+        LOG(Log::ERR,
+            "Submittable::set_process_or_remote_id: " << absNodePath() << " process_id(" << id
+                                                      << ") tryNo == 0, how can this be ???");
+    }
+#endif
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Submittable::set_process_or_remote_id\n";
+#endif
+}
+
+void Submittable::reset() {
+    tryNo_ = 0; // reset try number
+    clear();    // jobs password, process_id, aborted_reason
+    Node::reset();
+}
+
+void Submittable::begin() {
+    /// It is *very* important that we reset the passwords. This allows us to detect zombies.
+    tryNo_ = 0; // reset try number
+    clear();    // jobs password, process_id, aborted_reason
+
+    Node::begin(); // see  Notes in: Node::begin() about update_generated_variables()
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Submittable::begin()\n";
+#endif
+}
+
+void Submittable::requeue(Requeue_args& args) {
+    /// It is *very* important that we reset the passwords. This allows us to detect zombies.
+    tryNo_ = 0; // reset try number
+    clear();    // jobs password, process_id, aborted_reason
+
+    Node::requeue(args);
+    update_generated_variables();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Submittable::requeue\n";
+#endif
+}
+
+bool Submittable::calendarChanged(const ecf::Calendar& c,
+                                  Node::Calendar_args& cal_args,
+                                  const ecf::LateAttr* inherited_late,
+                                  bool holding_parent_day_or_date) {
+    (void)Node::calendarChanged(c, cal_args, nullptr, holding_parent_day_or_date);
+
+    // Late flag should ONLY be set on Submittable
+    check_for_lateness(c, inherited_late);
+    return false;
+}
+
+void Submittable::write_state(std::string& ret, bool& added_comment_char) const {
+    // *IMPORTANT* we *CAN'T* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e.
+    //                 `task a; task b;`
+    if (!paswd_.empty() && paswd_ != Submittable::DUMMY_JOBS_PASSWORD()) {
+        add_comment_char(ret, added_comment_char);
+        ret += " passwd:";
+        ret += paswd_;
+    }
+    if (!rid_.empty()) {
+        add_comment_char(ret, added_comment_char);
+        ret += " rid:";
+        ret += rid_;
+    }
+
+    // The abr_, can contain user generated messages, including \n and ;, hence remove these
+    // as they can mess up the parsing on reload.
+    if (!abr_.empty()) {
+        add_comment_char(ret, added_comment_char);
+        std::string the_abort_reason = abr_;
+        Str::replaceall(the_abort_reason, "\n", "\\n");
+        Str::replaceall(the_abort_reason, ";", " ");
+        ret += " abort<:";
+        ret += the_abort_reason;
+        ret += ">abort";
+    }
+    if (tryNo_ != 0) {
+        add_comment_char(ret, added_comment_char);
+        ret += " try:";
+        ret += ecf::convert_to<std::string>(tryNo_);
+    }
+    Node::write_state(ret, added_comment_char);
+}
+
+void Submittable::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
+    //  0    1   2
+    // task name #
+    size_t line_tokens_size = lineTokens.size();
+    for (size_t i = 3; i < line_tokens_size; i++) {
+        const std::string& line_token_i = lineTokens[i];
+
+        if (line_token_i.find("passwd:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, paswd_))
+                throw std::runtime_error("Submittable::read_state failed for jobs password : " + name());
+        }
+        else if (line_token_i.find("rid:") != std::string::npos) {
+            if (!Extract::split_get_second(line_token_i, rid_))
+                throw std::runtime_error("Submittable::read_state failed for rid : " + name());
+        }
+        else if (line_token_i.find("try:") != std::string::npos) {
+            std::string try_number;
+            if (!Extract::split_get_second(line_token_i, try_number))
+                throw std::runtime_error("Submittable::read_state failed for try number : " + name());
+            tryNo_ = Extract::theInt(try_number, "Submittable::read_state failed for try number");
+        }
+    }
+
+    // extract aborted reason
+    // The line tokens will truncate multiple spaces into a single space chars
+    // Hence use the line to extract the abort reason: This will preserve spaces
+    size_t first_pos = line.find("abort<:");
+    size_t last_pos  = line.find(">abort");
+    if (first_pos != std::string::npos) {
+        if (last_pos != std::string::npos) {
+            abr_ = line.substr(first_pos + 7, (last_pos - first_pos - 7));
+        }
+        else {
+            throw std::runtime_error(
+                "Submittable::read_state failed for abort reason. Expected abort reason to on single line;");
+        }
+    }
+
+    Node::read_state(line, lineTokens);
+}
+
+bool Submittable::operator==(const Submittable& rhs) const {
+    if (paswd_ != rhs.paswd_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Submittable::operator==  paswd_(" << paswd_ << ") != rhs.paswd_(" << rhs.paswd_ << ") "
+                      << debugNodePath() << "\n";
+            std::cout << "Submittable::operator==  state(" << NState::toString(state()) << ")  rhs.state("
+                      << NState::toString(rhs.state()) << ") \n";
+            // No point dumping out change numbers, since we don't persist them, hence values will always be zero on
+            // client side.
+        }
+#endif
+        return false;
+    }
+
+    if (rid_ != rhs.rid_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Submittable::operator==  rid_(" << rid_ << ") != rhs.rid_(" << rhs.rid_ << ") "
+                      << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (tryNo_ != rhs.tryNo_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Submittable::operator==  tryNo_(" << tryNo_ << ") != rhs.tryNo_(" << rhs.tryNo_ << ") "
+                      << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if (abr_ != rhs.abr_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Submittable::operator==  abr_(" << abr_ << ") != rhs.abr_(" << rhs.abr_ << ") "
+                      << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    return Node::operator==(rhs);
+}
+
+string Submittable::tryNo() const {
+    try {
+        return ecf::convert_to<std::string>(tryNo_);
+    }
+    catch (const ecf::bad_conversion&) {
+    }
+
+    LOG_ASSERT(false, "Submittable::tryNo() corrupt?");
+    return string();
+}
+
+EcfFile Submittable::locatedEcfFile() const {
+    // Look for scripts file(Task->.ecf | Alias->.usr) in the following order
+    // o/ ECF_SCRIPT Generated VARIABLE  absolute path, check if files exists
+    //    The variable MUST exist, but the file may not
+    // o/ ECF_FETCH (user variable)
+    //    if this variable exist, we need to flag it,
+    //    So that that file is obtained from running the command. (Output of popen)
+    // o/ ECF_SCRIPT_CMD (user variable)
+    //    if this variable exist, we need to flag it,
+    //    So that that file is obtained from running the command. (Output of popen)
+    // o/ ECF_FILES (Typically in the definition file, defines a directory) (backward search)
+    //    if ECF_FILES_LOOKUP=PRUNE_LEAF (forward_search)
+    // o/ ECF_HOME (backward search)
+    //    if ECF_FILES_LOOKUP=PRUNE_LEAF (forward_search)
+    //    where: backward search is root_path = (ECF_FILES | ECF_HOME) (PRUNE_ROOT)
+    //           <root-path>/suite/family/family2/task.ecf
+    //           <root-path>/family/family2/task.ecf
+    //           <root-path>/family2/task.ecf
+    //           <root-path>/task.ecf
+    //    where: forward search is root_path = (ECF_FILES | ECF_HOME) (PRUNE_LEAF)
+    //           <root-path>/suite/family/family2/task.ecf
+    //           <root-path>/suite/family/task.ecf
+    //           <root-path>/suite/task.ecf
+    //           <root-path>/task.ecf
+
+    std::string reasonEcfFileNotFound;
+    std::string theAbsNodePath = absNodePath();
+    std::string ecf_home;
+    findParentUserVariableValue(Str::ECF_HOME(), ecf_home);
+
+    /// Update local ECF_SCRIPT variable, ECF_SCRIPT is a generated variable. IT *MUST* exist
+    /// Likewise generated variable like TASK and ECF_NAME as they may occur in ECF_FETCH_CMD/ECF_SCRIPT_CMD
+    update_static_generated_variables(ecf_home, theAbsNodePath);
+
+    const Variable& genvar_ecfscript = get_genvar_ecfscript();
+
+#ifdef DEBUG_TASK_LOCATION
+    std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " searching ECF_SCRIPT = '"
+              << genvar_ecfscript.theValue() << "'\n";
+#endif
+    if (fs::exists(genvar_ecfscript.theValue())) {
+#ifdef DEBUG_TASK_LOCATION
+        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " ECF_SCRIPT = '"
+                  << genvar_ecfscript.theValue() << "' exists\n";
+#endif
+        return EcfFile(const_cast<Submittable*>(this), genvar_ecfscript.theValue(), EcfFile::ECF_SCRIPT);
+    }
+    else {
+        reasonEcfFileNotFound += "   ECF_SCRIPT(";
+        reasonEcfFileNotFound += genvar_ecfscript.theValue();
+        reasonEcfFileNotFound += ") does not exist:\n";
+    }
+
+    // Caution: This is not used in operations or research; equally it has not been tested.
+    std::string ecf_fetch_cmd;
+    findParentVariableValue(Str::ECF_FETCH(), ecf_fetch_cmd);
+    if (!ecf_fetch_cmd.empty()) {
+#ifdef DEBUG_TASK_LOCATION
+        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " ECF_FETCH = '" << ecf_fetch_cmd
+                  << "' variable exists\n";
+#endif
+        if (variableSubstitution(ecf_fetch_cmd)) {
+            return EcfFile(const_cast<Submittable*>(this), ecf_fetch_cmd, EcfFile::ECF_FETCH_CMD);
+        }
+        else {
+            reasonEcfFileNotFound += "   Variable ECF_FETCH(";
+            reasonEcfFileNotFound += ecf_fetch_cmd;
+            reasonEcfFileNotFound += ") defined, but variable substitution has failed:\n";
+            throw std::runtime_error(reasonEcfFileNotFound);
+        }
+    }
+    else {
+        reasonEcfFileNotFound += "   Variable ECF_FETCH not defined:\n";
+    }
+
+    std::string ecf_script_cmd; // ECFLOW-427
+    findParentVariableValue("ECF_SCRIPT_CMD", ecf_script_cmd);
+    if (!ecf_script_cmd.empty()) {
+#ifdef DEBUG_TASK_LOCATION
+        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " ECF_SCRIPT_CMD = '" << ecf_script_cmd
+                  << "' variable exists\n";
+#endif
+        if (variableSubstitution(ecf_script_cmd)) {
+            return EcfFile(const_cast<Submittable*>(this), ecf_script_cmd, EcfFile::ECF_SCRIPT_CMD);
+        }
+        else {
+            reasonEcfFileNotFound += "   Variable ECF_SCRIPT_CMD(";
+            reasonEcfFileNotFound += ecf_script_cmd;
+            reasonEcfFileNotFound += ") defined, but variable substitution has failed:\n";
+            throw std::runtime_error(reasonEcfFileNotFound);
+        }
+    }
+    else {
+        reasonEcfFileNotFound += "   Variable ECF_SCRIPT_CMD not defined:\n";
+    }
+
+    EcfFile::EcfFileSearchAlgorithm file_search_algo = EcfFile::PRUNE_ROOT;
+    std::string ecf_files_lookup;
+    if (findParentUserVariableValue("ECF_FILES_LOOKUP", ecf_files_lookup)) {
+        if (ecf_files_lookup == "prune_leaf" || ecf_files_lookup == "PRUNE_LEAF")
+            file_search_algo = EcfFile::PRUNE_LEAF;
+    }
+
+    std::string ecf_filesDirectory;
+    if (findParentUserVariableValue(Str::ECF_FILES(), ecf_filesDirectory)) {
+#ifdef DEBUG_TASK_LOCATION
+        std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " searching ECF_FILES = '"
+                  << ecf_filesDirectory << "' backwards\n";
+#endif
+        if (!ecf_filesDirectory.empty() && fs::is_directory(ecf_filesDirectory)) {
+            // If File::backwardSearch fails it returns an empty string, i.e. failure to locate script (Task/.ecf ||
+            // Alias/.usr) file
+            std::string searchResult;
+            if (file_search_algo == EcfFile::PRUNE_ROOT)
+                searchResult = File::backwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
+            else
+                searchResult = File::forwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
+            if (searchResult.empty()) {
+                reasonEcfFileNotFound += "   Search of directory ECF_FILES(";
+                reasonEcfFileNotFound += ecf_filesDirectory;
+                reasonEcfFileNotFound += ") failed ";
+                if (file_search_algo == EcfFile::PRUNE_ROOT)
+                    reasonEcfFileNotFound += "using prune_root:\n";
+                else
+                    reasonEcfFileNotFound += "using prune_leaf:\n";
+            }
+            else
+                return EcfFile(const_cast<Submittable*>(this), searchResult, EcfFile::ECF_FILES, file_search_algo);
+        }
+        else {
+            // Before failing try again but with variable Substitution. ECFLOW-788
+            std::string original_ecf_filesDirectory = ecf_filesDirectory;
+            variableSubstitution(ecf_filesDirectory);
+            if (!ecf_filesDirectory.empty() && fs::is_directory(ecf_filesDirectory)) {
+                // If search fails it returns an empty string, i.e. failure to locate script (Task/.ecf || Alias/.usr)
+                // file
+                std::string searchResult;
+                if (file_search_algo == EcfFile::PRUNE_ROOT)
+                    searchResult = File::backwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
+                else
+                    searchResult = File::forwardSearch(ecf_filesDirectory, theAbsNodePath, script_extension());
+                if (searchResult.empty()) {
+                    std::stringstream ss;
+                    ss << "   Search of directory ECF_FILES(variable substituted)(" << ecf_filesDirectory
+                       << ") failed:\n";
+                    reasonEcfFileNotFound += ss.str();
+                }
+                else
+                    return EcfFile(const_cast<Submittable*>(this), searchResult, EcfFile::ECF_FILES, file_search_algo);
+            }
+            else {
+                std::stringstream ss;
+                ss << "   Directory ECF_FILES(" << original_ecf_filesDirectory << ") does not exist:\n";
+                if (original_ecf_filesDirectory != ecf_filesDirectory)
+                    ss << "   Directory ECF_FILES(" << ecf_filesDirectory
+                       << ") after variable substitution does not exist:\n";
+                reasonEcfFileNotFound += ss.str();
+            }
+        }
+    }
+    else {
+        reasonEcfFileNotFound += "   Variable ECF_FILES not defined:\n";
+    }
+
+#ifdef DEBUG_TASK_LOCATION
+    std::cout << "Submittable::locatedEcfFile() Submittable " << name() << " searching ECF_HOME = '" << ecf_home
+              << "' backwards\n";
+#endif
+    if (!ecf_home.empty() && fs::is_directory(ecf_home)) {
+        // If search fails it returns an empty string, i.e. failure to locate script (Task/.ecf || Alias/.usr) file
+        std::string searchResult;
+        if (file_search_algo == EcfFile::PRUNE_ROOT)
+            searchResult = File::backwardSearch(ecf_home, theAbsNodePath, script_extension());
+        else
+            searchResult = File::forwardSearch(ecf_home, theAbsNodePath, script_extension());
+        if (searchResult.empty()) {
+            reasonEcfFileNotFound += "   Search of directory ECF_HOME(";
+            reasonEcfFileNotFound += ecf_home;
+            reasonEcfFileNotFound += ") failed ";
+            if (file_search_algo == EcfFile::PRUNE_ROOT)
+                reasonEcfFileNotFound += "using prune_root:\n";
+            else
+                reasonEcfFileNotFound += "using prune_leaf:\n";
+        }
+        else {
+            return EcfFile(const_cast<Submittable*>(this), searchResult, EcfFile::ECF_HOME, file_search_algo);
+        }
+    }
+    else {
+        reasonEcfFileNotFound += "   Directory ECF_HOME(";
+        reasonEcfFileNotFound += ecf_home;
+        reasonEcfFileNotFound += ") does not exist:\n";
+    }
+
+    // failed to find  .ecf file
+    std::string error_msg = "   Script for ";
+    error_msg += theAbsNodePath;
+    error_msg += " cannot be found:\n";
+    error_msg += reasonEcfFileNotFound;
+    throw std::runtime_error(error_msg);
+}
+
+void Submittable::set_jobs_password(const std::string& p) {
+    paswd_           = p;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Submittable::set_jobs_password\n";
+#endif
+}
+
+void Submittable::increment_try_no() {
+    // EVERY time we SUBMIT a job we must:
+    // - generate a password, and hence updated generated variable ECF_PASS
+    // - increment the try number
+    //   This means we also need to regenerate the variables
+    //   since ECF_TRYNO , ECF_JOB, ECF_JOBOUT depend on the try number.
+    //   ALSO, ECF_RID is updated with empty string
+    // - Clear the process/remote id. These will be reset by the child commands
+    // *** This MUST be done before pre-processing as it uses these variables ***
+    tryNo_++;
+    rid_.clear();
+    abr_.clear();
+    paswd_           = Passwd::generate();
+    state_change_no_ = Ecf::incr_state_change_no();
+    update_generated_variables();
+}
+
+void Submittable::clear() {
+    abr_.clear();   // reset reason aborted
+    paswd_.clear(); // reset password, it will be regenerated before submission
+    rid_.clear();   // reset process id
+    state_change_no_ = Ecf::incr_state_change_no();
+}
+
+bool Submittable::submitJob(JobsParam& jobsParam) {
+    increment_try_no();
+
+    return submit_job_only(jobsParam);
+}
+
+bool Submittable::submit_job_only(JobsParam& jobsParam) {
+#ifdef DEBUG_JOB_SUBMISSION
+    cerr << "Submittable::submit_job_only for task " << name() << endl;
+#endif
+
+    if (state() == NState::ACTIVE || state() == NState::SUBMITTED) {
+        std::stringstream ss;
+        ss << "Submittable::submit_job_only: failed: Submittable " << absNodePath() << " is already "
+           << NState::toString(state()) << " : ";
+        jobsParam.errorMsg() += ss.str();
+        flag().set(ecf::Flag::EDIT_FAILED);
+        return false;
+    }
+
+    // If the task is a dummy task, return true
+    std::string theValue;
+    if (findParentUserVariableValue(Str::ECF_DUMMY_TASK(), theValue)) {
+        return true;
+    }
+
+    // state change
+    flag().clear(ecf::Flag::NO_SCRIPT);
+    flag().clear(ecf::Flag::EDIT_FAILED);
+    flag().clear(ecf::Flag::JOBCMD_FAILED);
+    flag().clear(ecf::Flag::KILLCMD_FAILED);
+    flag().clear(ecf::Flag::STATUSCMD_FAILED);
+    flag().clear(ecf::Flag::KILLED);
+    flag().clear(ecf::Flag::STATUS);
+    requeue_labels(); // ECFLOW-195, requeue no longer resets labels on tasks, hence we do it at task run time.
+
+    theValue.clear();
+    if (findParentUserVariableValue(Str::ECF_NO_SCRIPT(), theValue)) {
+        // The script is based on the ECF_JOB_CMD
+        return non_script_based_job_submission(jobsParam);
+    }
+
+    return script_based_job_submission(jobsParam);
+}
+
+bool Submittable::script_based_job_submission(JobsParam& jobsParam) {
+    try {
+        // Locate the ecf files corresponding to the task.
+        // Assign lifetime of EcfFile to JobsParam.
+        // Minimise memory allocation/de-allocation with Job lines, and allow _include file_ caching
+        jobsParam.set_ecf_file(locatedEcfFile());
+
+        // Pre-process ecf file (i.e. expand includes, remove comments,manual) and perform
+        // variable substitution. This will then form the '.job' files.
+        // If the job file already exist it is overridden
+        // The job file SHOULD be referenced in ECF_JOB_CMD
+        try {
+            const std::string& job_size = jobsParam.ecf_file().create_job(jobsParam);
+
+            //... make sure ECF_PASS is set on the task, This is substituted in <head.h> file
+            //... and hence must be done before variable substitution in ECF_/JOB file
+            //... This is used by client->server authentication
+            if (createChildProcess(jobsParam)) {
+                set_state(NState::SUBMITTED, false, job_size);
+                return true;
+            }
+            // Fall through job submission failed.
+        }
+        catch (std::exception& e) {
+            flag().set(ecf::Flag::EDIT_FAILED);
+            std::string reason = "Submittable::submit_job_only: Job creation failed for task ";
+            reason += absNodePath();
+            reason += " : \n   ";
+            reason += e.what();
+            reason += "\n";
+            jobsParam.errorMsg() += reason;
+            set_aborted_only(reason);
+            return false;
+        }
+    }
+    catch (std::exception& e) {
+        flag().set(ecf::Flag::NO_SCRIPT);
+        std::stringstream ss;
+        ss << "Submittable::submit_job_only: Script location failed for task " << absNodePath() << " :\n"
+           << e.what() << "\n";
+        jobsParam.errorMsg() += ss.str();
+        set_aborted_only(e.what()); // remember jobsParam.errorMsg() is accumulated
+        return false;
+    }
+
+    flag().set(ecf::Flag::JOBCMD_FAILED);
+    std::string reason = " Job creation failed for task ";
+    reason += absNodePath();
+    reason += " could not create child process.";
+    jobsParam.errorMsg() += reason;
+    set_aborted_only(reason);
+    return false;
+}
+
+bool Submittable::non_script_based_job_submission(JobsParam& jobsParam) {
+    // No script(i.e. .ecf file), hence it is assumed the ECF_JOB_CMD will call:
+    //  ECF_PASS=%ECF_PASS%;ECF_PORT=%ECF_PORT%;ECF_HOST=%ECF_HOST%;ECF_NAME=%ECF_NAME%;ECF_TRYNO=%ECF_TRYNO%;
+    //  ecflow_client --init %%;
+    //     . some user script, or in-line command, should use full path.;
+    //     ecflow_client (--meter,--event,--label);
+    //  ecflow_client --hcomplete
+
+    if (createChildProcess(jobsParam)) {
+        set_state(NState::SUBMITTED, false, Str::EMPTY() /*job size*/);
+        return true;
+    }
+
+    // Fall through job submission failed.
+    flag().set(ecf::Flag::JOBCMD_FAILED);
+    std::string reason = " Job creation failed for task ";
+    reason += absNodePath();
+    reason += " could not create child process.";
+    jobsParam.errorMsg() += reason;
+    set_aborted_only(reason);
+    return false;
+}
+
+class JobCreationTimer {
+public:
+    explicit JobCreationTimer(Submittable* sub) : enabled_(false), failed_(false), sub_(sub) {}
+    // Disable copy (and move) semantics
+    JobCreationTimer(const JobCreationTimer&)                  = delete;
+    const JobCreationTimer& operator=(const JobCreationTimer&) = delete;
+
+    ~JobCreationTimer() {
+        if (enabled_) {
+            std::cout << " " << sub_->absNodePath();
+            if (failed_)
+                std::cout << " (FAILED)\n";
+            else {
+                boost::posix_time::time_duration duration = Calendar::second_clock_time() - start_;
+                std::cout << " (" << duration.total_microseconds() << " ms)\n";
+            }
+        }
+    }
+
+    void set_enabled() {
+        enabled_ = true;
+        start_   = Calendar::second_clock_time();
+    }
+
+    void set_failed() { failed_ = true; }
+
+private:
+    bool enabled_;
+    bool failed_;
+    Submittable* sub_;
+    boost::posix_time::ptime start_;
+};
+
+void Submittable::check_job_creation(job_creation_ctrl_ptr jobCtrl) {
+    JobCreationTimer output_tasks_being_checked(this);
+    if (jobCtrl->verbose())
+        output_tasks_being_checked.set_enabled();
+
+    // Typically a valid try number is >=1.
+    // Since check_job_creation is only used for testing/python, we will initialise tryNum to -1
+    // so that when it is incremented it will be a try_no of zero. *zero is an invalid try_no *
+    tryNo_ = -1;
+
+    /// call just before job submission, reset data members, update try_no, and *** generate variable ***
+    increment_try_no();
+
+    if (!jobCtrl->dir_for_job_creation().empty()) {
+        /// Override ECF_JOB, can be done by either adding a new user variable of same name
+        /// or the generated variable. We choose generated, since this is automatically reset.
+        /// before a real job submission
+        std::string tmpLocationForJob = jobCtrl->dir_for_job_creation();
+        tmpLocationForJob += absNodePath();
+        tmpLocationForJob += File::JOB_EXTN();
+        tmpLocationForJob += "0"; // try number of zero ( i.e. an invalid try number)
+        set_genvar_ecfjob(tmpLocationForJob);
+    }
+
+    // Before we had a Local JobsParam  here
+    // By using the JobsParam on job_creation_ctrl_ptr, we get the effect of USING a cache.
+    // EcfFile stored on JobsParam has cache. This cache avoids opening include files more than once.
+    // Since we have a Single job_creation_ctrl_ptr, hence single JobsParam, hence single EcfFile
+    // the cache is applied for ALL tasks. See ECFLOW-1210
+    jobCtrl->jobsParam().clear(); // allow jobsParam to be re-used by clearing
+    LOG_ASSERT(!jobCtrl->jobsParam().spawnJobs(), "spawn jobs should be disabled for check job creation");
+    LOG_ASSERT(!jobCtrl->jobsParam().createJobs(), "create jobs should be disabled for check job creation");
+    if (submit_job_only(jobCtrl->jobsParam())) {
+        return;
+    }
+    output_tasks_being_checked.set_failed();
+
+    std::string errorMsg = jobCtrl->jobsParam().getErrorMsg();
+    LOG_ASSERT(!errorMsg.empty(), "failing to submit must raise an error message");
+
+    jobCtrl->error_msg() += errorMsg;
+    jobCtrl->push_back_failing_submittable(dynamic_pointer_cast<Submittable>(shared_from_this()));
+}
+
+bool Submittable::run(JobsParam& jobsParam, bool force) {
+    if (force || ((state() != NState::SUBMITTED) && (state() != NState::ACTIVE))) {
+
+        if (jobsParam.createJobs()) {
+
+            return submitJob(jobsParam);
+        }
+        else {
+            /// This is only for test path. Just return true
+            return true;
+        }
+    }
+    std::stringstream ss;
+    ss << "Submittable::run: Aborted for task " << absNodePath() << " because state is " << NState::toString(state())
+       << " and force not set\n";
+    jobsParam.errorMsg() += ss.str();
+    return false;
+}
+
+void Submittable::kill(const std::string& zombie_pid) {
+    flag().clear(ecf::Flag::KILLCMD_FAILED);
+    flag().clear(ecf::Flag::KILLED);
+
+    std::string ecf_kill_cmd;
+    if (zombie_pid.empty()) {
+        if (state() != NState::ACTIVE && state() != NState::SUBMITTED) {
+            return;
+        }
+
+        // *** Generated variables are *NOT* persisted.                                     ***
+        // *** Hence if we have recovered from a check point file, then they will be empty. ***
+        // *** i.e. terminate server with active jobs, restart from saved check_pt file
+        // *** and then try to kill the active job, will get an exception( see below) since
+        // *** Generated variable ECF_RID will be empty.
+        if (!sub_gen_variables_) {
+            // std::cout << "Generated variables empty, regenerating !!!!!\n";
+            update_generated_variables();
+        }
+
+        /// If we are in active state, then ECF_RID must have been setup
+        /// This is typically used in the KILL CMD, make sure its there
+        if (state() == NState::ACTIVE && get_genvar_ecfrid().theValue().empty()) {
+            flag().set(ecf::Flag::KILLCMD_FAILED);
+            std::stringstream ss;
+            ss << "Submittable::kill: Generated variable ECF_RID is empty for task " << absNodePath();
+            throw std::runtime_error(ss.str());
+        }
+
+        if (!findParentUserVariableValue(Str::ECF_KILL_CMD(), ecf_kill_cmd) || ecf_kill_cmd.empty()) {
+            flag().set(ecf::Flag::KILLCMD_FAILED);
+            std::stringstream ss;
+            ss << "Submittable::kill: ECF_KILL_CMD not defined, for task " << absNodePath() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+    }
+    else {
+        // Use input
+        if (!findParentUserVariableValue(Str::ECF_KILL_CMD(), ecf_kill_cmd) || ecf_kill_cmd.empty()) {
+            flag().set(ecf::Flag::KILLCMD_FAILED);
+            std::stringstream ss;
+            ss << "Submittable::kill: ECF_KILL_CMD not defined, for task " << absNodePath() << "\n";
+            throw std::runtime_error(ss.str());
+        }
+
+        // replace %ECF_RID% with the input args
+        Str::replace(ecf_kill_cmd, "%ECF_RID%", zombie_pid);
+    }
+
+    if (!variableSubstitution(ecf_kill_cmd)) {
+        flag().set(ecf::Flag::KILLCMD_FAILED);
+        std::stringstream ss;
+        ss << "Submittable::kill: Variable substitution failed for ECF_KILL_CMD(" << ecf_kill_cmd << ") on task "
+           << absNodePath() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // Please note: this is *non-blocking* the output of the command(ECF_KILL_CMD) should be written to %ECF_JOB%.kill
+    // The output is accessible via the --file cmd
+    // Done as two separate steps as kill command is not blocking on the server
+    //   LOG(Log::DBG,"Submittable::kill " << absNodePath() << "  " << ecf_kill_cmd );
+    std::string errorMsg;
+    if (!System::instance()->spawn(System::ECF_KILL_CMD, ecf_kill_cmd, absNodePath(), errorMsg)) {
+        flag().set(ecf::Flag::KILLCMD_FAILED);
+        throw std::runtime_error(errorMsg);
+    }
+    flag().set(ecf::Flag::KILLED);
+}
+
+void Submittable::status() {
+    // Jobs::generate will un-block SIGCHLD (by using Signal class)
+    // This will allow child process termination to handled by the signal handler in System
+    // Note:: Jobs::generate is called every minute *AND* when there is a state change.
+    flag().clear(ecf::Flag::STATUSCMD_FAILED);
+    flag().clear(ecf::Flag::STATUS);
+
+    // Note: Only is active state do we have a ECF_RID
+    if (state() != NState::ACTIVE && state() != NState::SUBMITTED) {
+        flag().set(ecf::Flag::STATUSCMD_FAILED);
+        std::stringstream ss;
+        ss << "Submittable::status: To use status command on a *single* node(" << absNodePath()
+           << ") it must be active or submitted";
+        throw std::runtime_error(ss.str());
+    }
+
+    // *** Generated variables are *NOT* persisted.                                     ***
+    // *** Hence if we have recovered from a check point file, then they will be empty. ***
+    // *** i.e. terminate server with active jobs, restart from saved check_pt file
+    // *** and then try to kill/status the active job, will get an exception(see below) since
+    // *** Generated variable ECF_RID will be empty.
+    if (!sub_gen_variables_) {
+        // std::cout << "Generated variables empty, regenerating !!!!!\n";
+        update_generated_variables();
+    }
+
+    /// If we are in active state, then ECF_RID must have been setup
+    if (state() == NState::ACTIVE && get_genvar_ecfrid().theValue().empty()) {
+        flag().set(ecf::Flag::STATUSCMD_FAILED);
+        std::stringstream ss;
+        ss << "Submittable::status: Generated variable ECF_RID is empty for ACTIVE task " << absNodePath();
+        throw std::runtime_error(ss.str());
+    }
+
+    std::string ecf_status_cmd;
+    if (!findParentUserVariableValue(Str::ECF_STATUS_CMD(), ecf_status_cmd) || ecf_status_cmd.empty()) {
+        flag().set(ecf::Flag::STATUSCMD_FAILED);
+        std::stringstream ss;
+        ss << "Submittable::status: ECF_STATUS_CMD not defined, for task " << absNodePath() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    if (!variableSubstitution(ecf_status_cmd)) {
+        flag().set(ecf::Flag::STATUSCMD_FAILED);
+        std::stringstream ss;
+        ss << "Submittable::status: Variable substitution failed for ECF_STATUS_CMD(" << ecf_status_cmd << ") on task "
+           << absNodePath() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // Please note: this is *non-blocking* the output of the command(ECF_STATUS_CMD) should be written to %ECF_JOB%.stat
+    // SPAWN process, attach signal to monitor process. returns true
+    std::string errorMsg;
+    if (!System::instance()->spawn(System::ECF_STATUS_CMD, ecf_status_cmd, absNodePath(), errorMsg)) {
+        flag().set(ecf::Flag::STATUSCMD_FAILED);
+        throw std::runtime_error(errorMsg);
+    }
+
+    flag().set(ecf::Flag::STATUS);
+}
+
+bool Submittable::createChildProcess(JobsParam& jobsParam) {
+#ifdef DEBUG_JOB_SUBMISSION
+    cout << "Submittable::createChildProcess for task " << name() << endl;
+#endif
+    std::string ecf_job_cmd;
+    findParentUserVariableValue(Str::ECF_JOB_CMD(), ecf_job_cmd);
+    if (ecf_job_cmd.empty()) {
+        jobsParam.errorMsg() += "Submittable::createChildProcess: Could not find ECF_JOB_CMD : ";
+        return false;
+    }
+
+    if (!variableSubstitution(ecf_job_cmd)) {
+        jobsParam.errorMsg() +=
+            "Submittable::createChildProcess: Variable substitution failed for ECF_JOB_CMD(" + ecf_job_cmd + ") :";
+        return false;
+    }
+
+    // Keep tabs on what was submitted for testing purposes
+    jobsParam.push_back_submittable(this);
+
+    if (jobsParam.spawnJobs()) {
+
+        // SPAWN process, attach signal to monitor process. returns true
+        return System::instance()->spawn(System::ECF_JOB_CMD, ecf_job_cmd, absNodePath(), jobsParam.errorMsg());
+    }
+
+    // Test path ONLY
+    return true;
+}
+
+void Submittable::set_aborted_only(const std::string& reason) {
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Submittable::set_aborted_only\n";
+#endif
+
+    abr_             = reason;
+    state_change_no_ = Ecf::incr_state_change_no();
+
+    // Do not use "\n" | ';' in abr_, as this can mess up, --migrate output
+    // Which would then affect --load.
+    Str::replace(abr_, "\n", "");
+    Str::replace(abr_, ";", " ");
+
+    // This will set the state and bubble up the most significant state
+    set_state(NState::ABORTED);
+}
+
+void Submittable::update_limits() {
+    NState::State task_state = state();
+    std::set<Limit*> limitSet; // ensure local limit have preference over parent
+    if (task_state == NState::COMPLETE) {
+        decrementInLimit(limitSet); // will recurse up
+    }
+    else if (task_state == NState::ABORTED) {
+        decrementInLimit(limitSet); // will recurse up
+    }
+    else if (task_state == NState::SUBMITTED) {
+        incrementInLimit(limitSet); // will recurse up
+    }
+    else if (task_state == NState::ACTIVE) {
+        // Only change those LIMITs where in-limit has -s i.e. limit submission
+        decrementInLimitForSubmission(limitSet); // will recurse up
+    }
+    else {
+        // UNKNOWN, QUEUED
+        // For all other states, this task should NOT be consuming a limit token.
+        // During interactive use a Submittable may get re-queued. In case its consuming
+        // a limit token, we decrement the limit. If we are NOT consuming
+        // a token, it's still *SAFE* to call decrementInLimit
+        decrementInLimit(limitSet); // will recurse up
+    }
+}
+
+// Memento ==========================================================
+void Submittable::incremental_changes(DefsDelta& changes, compound_memento_ptr& comp) const {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Submittable::incremental_changes() " << debugNodePath() << "\n";
+#endif
+
+    if (state_change_no_ > changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<SubmittableMemento>(paswd_, rid_, abr_, tryNo_));
+    }
+
+    // ** if compound memento has children base class, will add it to DefsDelta
+    Node::incremental_changes(changes, comp);
+}
+
+void Submittable::set_memento(const SubmittableMemento* memento,
+                              std::vector<ecf::Aspect::Type>& aspects,
+                              bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Submittable::set_memento(const SubmittableMemento*) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::SUBMITTABLE);
+        return;
+    }
+
+    paswd_ = memento->paswd_;
+    rid_   = memento->rid_;
+    abr_   = memento->abr_;
+    tryNo_ = memento->tryNo_;
+}
+
+// Generated variables ---------------------------------------------------------------------------------
+
+void Submittable::update_generated_variables() const {
+    if (!sub_gen_variables_)
+        sub_gen_variables_ = new SubGenVariables(this);
+    sub_gen_variables_->update_generated_variables();
+    update_repeat_genvar();
+}
+
+void Submittable::update_static_generated_variables(const std::string& ecf_home,
+                                                    const std::string& theAbsNodePath) const {
+    if (!sub_gen_variables_)
+        sub_gen_variables_ = new SubGenVariables(this);
+    sub_gen_variables_->update_static_generated_variables(ecf_home, theAbsNodePath);
+}
+
+const Variable& Submittable::findGenVariable(const std::string& name) const {
+    // AST can reference generated variables. Currently, integer based values
+    // The task names can be integers, other valid option is try_no
+    if (!sub_gen_variables_)
+        update_generated_variables();
+
+    const Variable& gen_var = sub_gen_variables_->findGenVariable(name);
+    if (!gen_var.empty())
+        return gen_var;
+
+    return Node::findGenVariable(name);
+}
+
+void Submittable::gen_variables(std::vector<Variable>& vec) const {
+    if (!sub_gen_variables_)
+        update_generated_variables();
+
+    vec.reserve(vec.size() + 9);
+    sub_gen_variables_->gen_variables(vec);
+    Node::gen_variables(vec);
+}
+
+const Variable& Submittable::get_genvar_ecfrid() const {
+    if (!sub_gen_variables_)
+        return Variable::EMPTY();
+    return sub_gen_variables_->genvar_ecfrid();
+}
+
+const Variable& Submittable::get_genvar_ecfscript() const {
+    if (!sub_gen_variables_)
+        return Variable::EMPTY();
+    return sub_gen_variables_->genvar_ecfscript();
+}
+
+void Submittable::set_genvar_ecfjob(const std::string& value) {
+    if (!sub_gen_variables_)
+        sub_gen_variables_ = new SubGenVariables(this);
+    sub_gen_variables_->set_genvar_ecfjob(value);
+}
+
+void Submittable::set_genvar_ecfrid(const std::string& value) {
+    if (!sub_gen_variables_)
+        sub_gen_variables_ = new SubGenVariables(this);
+    sub_gen_variables_->set_genvar_ecfrid(value);
+}
+
+// Generated Variables ================================================================================================
+// The false below is used as a dummy argument to call the Variable constructor that does not
+// Check the variable names. i.e. we know they are valid
+SubGenVariables::SubGenVariables(const Submittable* sub)
+    : submittable_(sub),
+      genvar_ecfjob_(Str::ECF_JOB(), "", false),
+      genvar_ecfjobout_(Str::ECF_JOBOUT(), "", false),
+      genvar_ecftryno_(Str::ECF_TRYNO(), "", false),
+      genvar_task_("TASK", "", false),
+      genvar_ecfpass_(Str::ECF_PASS(), "", false),
+      genvar_ecfscript_(Str::ECF_SCRIPT(), "", false),
+      genvar_ecfname_(Str::ECF_NAME(), "", false),
+      genvar_ecfrid_(Str::ECF_RID(), "", false) {
+}
+
+void SubGenVariables::update_generated_variables() const {
+    // cache strings that are used in many variables
+    std::string theAbsNodePath = submittable_->absNodePath();
+    std::string ecf_home;
+    submittable_->findParentUserVariableValue(Str::ECF_HOME(), ecf_home);
+    update_static_generated_variables(ecf_home, theAbsNodePath);
+    update_dynamic_generated_variables(ecf_home, theAbsNodePath);
+}
+
+void SubGenVariables::update_static_generated_variables(const std::string& ecf_home,
+                                                        const std::string& theAbsNodePath) const {
+    // cache strings that are used in many variables
+    if (submittable_->isAlias() && submittable_->parent())
+        genvar_task_.set_value(submittable_->parent()->name()); // does *not* modify Variable::state_change_no
+    else
+        genvar_task_.set_value(submittable_->name());
+
+    genvar_ecfname_.set_value(theAbsNodePath); // does *not* modify Variable::state_change_no
+
+    genvar_ecfscript_.value_by_ref().reserve(ecf_home.size() + theAbsNodePath.size() + 4);
+    genvar_ecfscript_.value_by_ref() = ecf_home; // does *not* modify Variable::state_change_no
+    genvar_ecfscript_.value_by_ref() += theAbsNodePath;
+    genvar_ecfscript_.value_by_ref() += submittable_->script_extension();
+}
+
+void SubGenVariables::update_dynamic_generated_variables(const std::string& ecf_home,
+                                                         const std::string& theAbsNodePath) const {
+    // cache strings that are used in many variables
+    std::string the_try_no = submittable_->tryNo();
+
+    genvar_ecfrid_.set_value(submittable_->rid_);    // does *not* modify Variable::state_change_no
+    genvar_ecftryno_.set_value(the_try_no);          // does *not* modify Variable::state_change_no
+    genvar_ecfpass_.set_value(submittable_->paswd_); // does *not* modify Variable::state_change_no
+
+    /// The directory associated with ECF_JOB is automatically created if it does not exist.
+    /// This is Done during Job generation. See EcfFile::doCreateJobFile()
+    if (genvar_ecfjob_.value_by_ref().capacity() == 0) {
+        genvar_ecfjob_.value_by_ref().reserve(ecf_home.size() + theAbsNodePath.size() + File::JOB_EXTN().size() +
+                                              the_try_no.size());
+    }
+    genvar_ecfjob_.value_by_ref() = ecf_home; // does *not* modify Variable::state_change_no
+    genvar_ecfjob_.value_by_ref() += theAbsNodePath;
+    genvar_ecfjob_.value_by_ref() += File::JOB_EXTN();
+    genvar_ecfjob_.value_by_ref() += the_try_no;
+
+    /// If ECF_OUT is specified the user must ensure the directory exists, along with directories
+    /// associated with Suites/Families nodes.
+    /// Bottom up. Can be expensive when we have thousands of tasks.
+    std::string ecf_out;
+    submittable_->findParentUserVariableValue(Str::ECF_OUT(), ecf_out);
+
+    if (ecf_out.empty()) {
+        genvar_ecfjobout_.value_by_ref().reserve(ecf_home.size() + theAbsNodePath.size() + 1 + the_try_no.size());
+        genvar_ecfjobout_.value_by_ref() = ecf_home;
+    }
+    else {
+        // For metabuilder, where we use %ECF_HOME% for ECF_OUT
+        char micro = '%';
+        if (ecf_out.find(micro) != std::string::npos) {
+            NameValueMap user_edit_variables;
+            submittable_->variable_substitution(ecf_out, user_edit_variables, micro);
+        }
+        genvar_ecfjobout_.value_by_ref().reserve(ecf_out.size() + theAbsNodePath.size() + 1 + the_try_no.size());
+        genvar_ecfjobout_.value_by_ref() = ecf_out;
+    }
+    genvar_ecfjobout_.value_by_ref() += theAbsNodePath;
+    genvar_ecfjobout_.value_by_ref() += ".";
+    genvar_ecfjobout_.value_by_ref() += the_try_no;
+}
+
+const Variable& SubGenVariables::findGenVariable(const std::string& name) const {
+    if (genvar_ecfjob_.name() == name)
+        return genvar_ecfjob_;
+    if (genvar_ecfjobout_.name() == name)
+        return genvar_ecfjobout_;
+    if (genvar_ecftryno_.name() == name)
+        return genvar_ecftryno_;
+    if (genvar_ecfname_.name() == name)
+        return genvar_ecfname_;
+    if (genvar_task_.name() == name)
+        return genvar_task_;
+    if (genvar_ecfpass_.name() == name)
+        return genvar_ecfpass_;
+    if (genvar_ecfscript_.name() == name)
+        return genvar_ecfscript_;
+    if (genvar_ecfrid_.name() == name)
+        return genvar_ecfrid_;
+    return Variable::EMPTY();
+}
+
+void SubGenVariables::gen_variables(std::vector<Variable>& vec) const {
+    vec.push_back(genvar_task_);
+    vec.push_back(genvar_ecfjob_);
+    vec.push_back(genvar_ecfscript_);
+    vec.push_back(genvar_ecfjobout_);
+    vec.push_back(genvar_ecftryno_);
+    vec.push_back(genvar_ecfrid_);
+    vec.push_back(genvar_ecfname_);
+    vec.push_back(genvar_ecfpass_);
+}
+
+template <class Archive>
+void Submittable::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Node>(this));
+
+    CEREAL_OPTIONAL_NVP(ar, paswd_, [this]() { return !paswd_.empty(); }); // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, rid_, [this]() { return !rid_.empty(); });     // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, abr_, [this]() { return !abr_.empty(); });     // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, tryNo_, [this]() { return tryNo_ != 0; });     // conditionally save
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(Submittable);
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Submittable.hpp 5.13.0-1/libs/node/src/ecflow/node/Submittable.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Submittable.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Submittable.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,204 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Submittable_HPP
+#define ecflow_node_Submittable_HPP
+
+#include "ecflow/node/Node.hpp"
+
+class EcfFile;
+class SubGenVariables;
+
+class Submittable : public Node {
+protected:
+    Submittable(const std::string& name, bool check) : Node(name, check) {}
+    Submittable() = default;
+    Submittable(const Submittable& rhs)
+        : Node(rhs),
+          paswd_(rhs.paswd_),
+          rid_(rhs.rid_),
+          abr_(rhs.abr_),
+          tryNo_(rhs.tryNo_),
+          state_change_no_(0) {}
+
+    Submittable& operator=(const Submittable&);
+
+    bool operator==(const Submittable& rhs) const;
+
+public:
+    ~Submittable() override;
+
+    bool check_defaults() const override;
+
+    /// Initialise the task. will set the state to NState::ACTIVE
+    void init(const std::string& processId);
+
+    /// complete the task. Will set the state to NState::COMPLETE
+    /// However if there is a valid Repeat or time dependencies then
+    /// task will be re-queued afterwards
+    void complete();
+
+    /// The late attribute, ONLY applies to the Submittable and not NodeContainer
+    bool calendarChanged(const ecf::Calendar&,
+                         Node::Calendar_args&,
+                         const ecf::LateAttr* inherited_late,
+                         bool holding_parent_day_or_date) override;
+
+    /// Overridden to reset the try number
+    /// The tasks job can be invoked multiple times. For each invocation we want to preserve
+    /// the output. The try number is used in SMSJOB/SMSJOBOUT to preserve the output when
+    /// there are multiple runs.  re-queue/begin() resets the try Number
+    void reset() override;
+    void begin() override;
+    void requeue(Requeue_args&) override;
+    bool run(JobsParam& jobsParam, bool force) override;
+    void kill(const std::string& zombie_pid = "") override;
+    void status() override;
+
+    void update_generated_variables() const override;
+    const Variable& findGenVariable(const std::string& name) const override;
+    void gen_variables(std::vector<Variable>& vec) const override;
+
+    static const std::string& DUMMY_JOBS_PASSWORD();
+    static const std::string& FREE_JOBS_PASSWORD();
+    static const std::string& DUMMY_PROCESS_OR_REMOTE_ID();
+
+    // returns the corresponding .ecf file.
+    // i.e if the ecf file is missing or empty std::runtime_error is thrown
+    // For dummy tasks, i.e tasks with no .ecf file user should add ECF_DUMMY_TASK variable
+    EcfFile locatedEcfFile() const;
+    virtual const std::string& script_extension() const = 0;
+
+    /// Spawn of a child process. Clear process and remote id before jobs is spawned
+    /// Will increment try no first, and then update generated varaibles
+    bool submitJob(JobsParam&);
+
+    /// generates job file independent of dependencies, resets the try Number
+    void check_job_creation(job_creation_ctrl_ptr jobCtrl) override;
+
+    /// See Defs.hpp
+    void generate_scripts(const std::map<std::string, std::string>&) const override {}
+
+    NState::State computedState(Node::TraverseType) const override { return state(); }
+
+    /// data members accessor's and mutators:
+    /// return the current try number as a string, and int
+    std::string tryNo() const;
+    int try_no() const { return tryNo_; }
+
+    const std::string& jobsPassword() const { return paswd_; }
+
+    /// The remote id (ECF_RID) allows a jobs to be killed when added via a queueing system
+    /// in which case the remote id is really the queueing id.
+    const std::string& process_or_remote_id() const { return rid_; }
+
+    /// Set the task to aborted, providing a reason. Will set the state to NState::ABORTED
+    /// This should only be called in two context's:
+    ///    1/ Called via Child Cmd (AbortCmd) i.e job raised a trap,
+    ///    2/ Abnormal process termination. i.e job killed by signal
+    /// *IMPORTANT* If task try number is less than ECF_TRIES then we should
+    /// resubmit the job. However we *should* not do this immediately here, instead we
+    /// wait of *next* call to resolveDependencies, as that will check if we are *inlimit*
+    void aborted(const std::string& reason);
+    const std::string& abortedReason() const override { return abr_; }
+
+    // Memento functions:
+    void incremental_changes(DefsDelta&, compound_memento_ptr& comp) const;
+    void set_memento(const SubmittableMemento*, std::vector<ecf::Aspect::Type>& aspects, bool f);
+
+    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
+
+protected:
+    void write_state(std::string&, bool&) const override;
+
+    /// call just before job submission, reset data members, update try_no, and generate variable
+    void increment_try_no(); // will increment state_change_no
+
+    /// Submits the job *WITHOUT* incrementing the try number
+    bool submit_job_only(JobsParam&);
+
+    // Overridden from Node to increment/decrement limits
+    void update_limits() override;
+
+private:
+    friend class ZombieCtrl;
+    friend class AlterCmd;
+
+    void set_jobs_password(const std::string& p);
+    void set_process_or_remote_id(const std::string&);
+
+    // Use when we _only_ want to set the state,
+    void set_aborted_only(const std::string& reason);
+    bool createChildProcess(JobsParam& jobsParam);
+    void clear(); // process_id password and aborted reason
+
+    bool script_based_job_submission(JobsParam& jobsParam);
+    bool non_script_based_job_submission(JobsParam& jobsParam);
+
+    void update_static_generated_variables(const std::string& ecf_home, const std::string& theAbsNodePath) const;
+    const Variable& get_genvar_ecfrid() const;
+    const Variable& get_genvar_ecfscript() const;
+    void set_genvar_ecfjob(const std::string& value);
+    void set_genvar_ecfrid(const std::string& value);
+
+private:
+    std::string paswd_;
+    std::string rid_;
+    std::string abr_;
+    int tryNo_{0};
+    unsigned int state_change_no_{0};                     // *not* persisted, only used on server side
+    mutable SubGenVariables* sub_gen_variables_{nullptr}; // *not* persisted since they can be generated
+    friend class SubGenVariables;
+
+private:
+    // never change defaults !! or will mess up client/server protocol
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+};
+
+// We can have several thousands Submittables. This class helps in avoiding
+// the creation of generated variables until required.
+// This improves client->server down load times by avoiding thousands of string constructions
+class SubGenVariables {
+public:
+    explicit SubGenVariables(const Submittable*);
+    // Disable copy (and move) semantics
+    SubGenVariables(const SubGenVariables&)                  = delete;
+    const SubGenVariables& operator=(const SubGenVariables&) = delete;
+
+    void update_generated_variables() const;
+
+    /// distinguish between the two kinds of generated variables
+    void update_static_generated_variables(const std::string& ecf_home, const std::string& theAbsNodePath) const;
+    void update_dynamic_generated_variables(const std::string& ecf_home, const std::string& theAbsNodePath) const;
+
+    const Variable& findGenVariable(const std::string& name) const;
+    void gen_variables(std::vector<Variable>& vec) const;
+
+    const Variable& genvar_ecfrid() const { return genvar_ecfrid_; }
+    const Variable& genvar_ecfscript() const { return genvar_ecfscript_; }
+
+    void set_genvar_ecfjob(const std::string& value) { genvar_ecfjob_.set_value(value); }
+    void set_genvar_ecfrid(const std::string& value) { genvar_ecfrid_.set_value(value); }
+
+private:
+    const Submittable* submittable_;
+    mutable Variable genvar_ecfjob_;
+    mutable Variable genvar_ecfjobout_;
+    mutable Variable genvar_ecftryno_;
+    mutable Variable genvar_task_;
+    mutable Variable genvar_ecfpass_;
+    mutable Variable genvar_ecfscript_;
+    mutable Variable genvar_ecfname_;
+    mutable Variable genvar_ecfrid_;
+};
+
+#endif /* ecflow_node_Submittable_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Suite.cpp 5.13.0-1/libs/node/src/ecflow/node/Suite.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Suite.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Suite.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,982 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Suite.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/DefsDelta.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/NodeTreeVisitor.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+///////////////////////////////////////////////////////////////////////////////////////////
+// #define DEBUG_FIND_NODE 1
+
+// Create the generated variable up-front. This allows them to be referenced
+// is abstract syntax tree during the post process call
+
+Suite::Suite(const Suite& rhs) : NodeContainer(rhs), begun_(rhs.begun_) {
+    if (rhs.clockAttr_.get())
+        clockAttr_ = std::make_shared<ClockAttr>(*rhs.clockAttr_);
+
+    if (rhs.clock_end_attr_.get())
+        clock_end_attr_ = std::make_shared<ClockAttr>(*rhs.clock_end_attr_);
+
+    cal_ = rhs.cal_;
+}
+
+node_ptr Suite::clone() const {
+    return std::make_shared<Suite>(*this);
+}
+
+Suite& Suite::operator=(const Suite& rhs) {
+    // defs_ not set
+    if (this != &rhs) {
+        NodeContainer::operator=(rhs);
+        begun_ = rhs.begun_;
+        if (rhs.clockAttr_.get())
+            clockAttr_ = std::make_shared<ClockAttr>(*rhs.clockAttr_);
+        if (rhs.clock_end_attr_.get())
+            clock_end_attr_ = std::make_shared<ClockAttr>(*rhs.clock_end_attr_);
+        cal_ = rhs.cal_;
+
+        state_change_no_    = 0;
+        modify_change_no_   = Ecf::incr_modify_change_no();
+        begun_change_no_    = 0;
+        calendar_change_no_ = 0;
+
+        delete suite_gen_variables_;
+        suite_gen_variables_ = nullptr;
+    }
+    return *this;
+}
+
+Suite::~Suite() {
+    //	std::cout << "Suite::~Suite() " << debugNodePath() << "\n";
+    if (!Ecf::server()) {
+        notify_delete();
+    }
+    delete suite_gen_variables_;
+}
+
+suite_ptr Suite::create(const std::string& name, bool check) {
+    return std::make_shared<Suite>(name, check);
+}
+
+suite_ptr Suite::create_me(const std::string& name) {
+    return std::make_shared<Suite>(name, true);
+}
+
+bool Suite::check_defaults() const {
+    if (defs_ != nullptr)
+        throw std::runtime_error("Suite::check_defaults(): defs_ != nullptr");
+    if (begun_ != false)
+        throw std::runtime_error("Suite::check_defaults():  begun_ != false");
+    if (state_change_no_ != 0)
+        throw std::runtime_error("Suite::check_defaults():  state_change_no_ != 0");
+    if (modify_change_no_ != 0)
+        throw std::runtime_error("Suite::check_defaults(): modify_change_no_ != 0 ");
+    if (begun_change_no_ != 0)
+        throw std::runtime_error("Suite::check_defaults():  begun_change_no_ != 0");
+    if (calendar_change_no_ != 0)
+        throw std::runtime_error("Suite::check_defaults(): calendar_change_no_ != 0");
+    if (suite_gen_variables_ != nullptr)
+        throw std::runtime_error("Suite::check_defaults(): suite_gen_variables_ != nullptr");
+    return NodeContainer::check_defaults();
+}
+
+void Suite::accept(ecf::NodeTreeVisitor& v) {
+    SuiteChanged1 changed(this);
+    v.visitSuite(this);
+    NodeContainer::accept(v);
+}
+
+void Suite::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
+    SuiteChanged1 changed(this);
+    v.visitSuite(this);
+}
+
+void Suite::begin() {
+    if (false == begun_) {
+
+        // begin will change all the states of all child nodes, reset all attributes
+        SuiteChanged1 changed(this);
+
+        // begin can cause thousands of mementos to be created, to avoid this we
+        // update the modify change number.
+        Ecf::incr_modify_change_no();
+
+        begun_           = true;
+        begun_change_no_ = Ecf::incr_state_change_no();
+
+        begin_calendar();
+
+        NodeContainer::begin();
+
+        update_generated_variables();
+    }
+}
+
+void Suite::requeue(Requeue_args& args) {
+    if (false == begun_) {
+        std::stringstream ss;
+        ss << "Suite::requeue: The suite " << name() << " must be 'begun' first\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // This is more efficient than: since no locking is required
+    //    SuiteChanged changed(std::dynamic_pointer_cast<Suite>(shared_from_this()));
+    // since no locking is required in SuiteChanged
+    SuiteChanged1 changed(this); //
+
+    // requeue can cause thousands of mementos to be created, to avoid this we
+    // update the modify change number, this will force a full sync in client
+    Ecf::incr_modify_change_no();
+
+    requeue_calendar();
+
+    NodeContainer::requeue(args);
+
+    update_generated_variables();
+}
+
+void Suite::reset() {
+    // reset will change all the states of all child nodes, reset all attributes
+    SuiteChanged1 changed(this);
+
+    // reset can cause thousands of mementos to be created, to avoid this we
+    // update the modify change number.
+    Ecf::incr_modify_change_no();
+
+    reset_begin_only();
+
+    requeue_calendar();
+
+    NodeContainer::reset();
+}
+
+void Suite::handle_migration(const ecf::Calendar& c) {
+    // called when defs is read in from a file i.e. checkpoint
+
+    NodeContainer::handle_migration(c);
+}
+
+void Suite::reset_begin() {
+    SuiteChanged1 changed(this);
+    reset_begin_only();
+}
+
+void Suite::reset_begin_only() // private
+{
+    begun_           = false;
+    begun_change_no_ = Ecf::incr_state_change_no();
+}
+
+void Suite::begin_calendar() {
+    // Begin the calendar, from the clock attribute _ELSE_
+    // Get the local time, second level resolution, based on the
+    // time zone settings of the computer.
+    if (clockAttr_.get()) {
+        clockAttr_->init_calendar(cal_); // *IF* AlterCmd was used, wait till Suite is requed
+        clockAttr_->begin_calendar(cal_);
+    }
+    else {
+        cal_.begin(Calendar::second_clock_time());
+    }
+}
+
+void Suite::requeue_calendar() {
+    // ECFLOW-417
+    // Need special handling for a Suite with hybrid clock and repeat day variable.
+    // Basically on re-queue, we need to update calendar date by the repeat day variable
+    if (clockAttr_.get() && clockAttr_->hybrid() && repeat().is_repeat_day()) {
+
+        // Get the current time, but with the *existing* date of the suite
+        boost::gregorian::date suite_date = cal_.suiteTime().date();
+        suite_date += date_duration(repeat().step());
+
+        ptime suiteTime = ptime(suite_date, Calendar::second_clock_time().time_of_day());
+        cal_.begin(suiteTime);
+
+        // make sure update variable regenerates all suite variables, i.e like ECF_DATE, etc
+        // Needed since we have changed calendar date
+        if (suite_gen_variables_)
+            suite_gen_variables_->force_update();
+
+        return;
+    }
+
+    // Carry on same as before
+    begin_calendar();
+}
+
+void Suite::updateCalendar(const ecf::CalendarUpdateParams& calParams, Node::Calendar_args& cal_args) {
+    if (begun_) {
+        //		cout << "Suite::updateCalendar " << debugNodePath()   << " serverRunning = " <<
+        // calParams.serverRunning() << " jobSubInterval = " << to_simple_string(calParams.serverPollPeriod());
+        // cout <<
+        //"\n";
+
+        SuiteChanged1 changed(this);
+
+        /// The cal_ will cache server poll period/job submission interval, as calendar increment for easy access
+        cal_.update(calParams);
+        calendar_change_no_ = Ecf::state_change_no() + 1; // ** See: collateChanges **
+
+        update_generated_variables();
+
+        (void)calendarChanged(cal_, cal_args, get_late(), false /*holding_parent_day_or_date*/);
+    }
+}
+
+bool Suite::resolveDependencies(JobsParam& jobsParam) {
+    if (begun_) {
+        SuiteChanged1 changed(this);
+
+        // improve resolution of state change time. ECFLOW-1512
+        boost::posix_time::ptime time_now = Calendar::second_clock_time();
+        cal_.update_duration_only(time_now);
+
+        //  ** See: collateChanges  and ECFLOW-1512
+        // Updating calendar_change_no_ ensure we sync suite calendar.
+        // additionally this will end up adding one more memento(SuiteCalendarMemento),
+        // and thus affects python changed_node_paths
+        calendar_change_no_ = Ecf::state_change_no() + 1;
+
+        if (jobsParam.check_for_job_generation_timeout(time_now))
+            return false;
+        return NodeContainer::resolveDependencies(jobsParam);
+    }
+    return true;
+}
+
+bool Suite::operator==(const Suite& rhs) const {
+    if (begun_ != rhs.begun_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Suite::operator==  (begun_(" << begun_ << ") != rhs.begun_(" << rhs.begun_ << ")) "
+                      << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    if ((clockAttr_.get() && !rhs.clockAttr_.get()) || (!clockAttr_.get() && rhs.clockAttr_.get())) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Suite::operator==(clockAttr_.get() && !rhs.clockAttr_.get()) || (!clockAttr_.get() && "
+                         "rhs.clockAttr_.get() "
+                      << debugNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+    if (clockAttr_.get() && rhs.clockAttr_.get() && !(*clockAttr_ == *rhs.clockAttr_)) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Suite::operator== (clockAttr_ && rhs.clockAttr_ && !(*clockAttr_ == *rhs.clockAttr_)) "
+                      << debugNodePath() << "\n";
+            std::cout << "clockAttr_: " << clockAttr_->toString() << "  rhs.clockAttr_: " << rhs.clockAttr_->toString()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+
+    return NodeContainer::operator==(rhs);
+}
+
+void Suite::print(std::string& os) const {
+    Indentor::indent(os);
+    os += "suite ";
+    os += name();
+    if (!PrintStyle::defsStyle()) {
+        bool added_comment_char = false;
+        write_state(os, added_comment_char);
+    }
+    os += "\n";
+
+    Node::print(os);
+
+    // make sure clock attribute is written before
+    if (clockAttr_.get())
+        clockAttr_->print(os);
+    if (clock_end_attr_.get())
+        clock_end_attr_->print(os);
+    if (!PrintStyle::defsStyle()) {
+        if (!cal_.is_special()) {
+            Indentor indent;
+            Indentor::indent(os);
+            os += "calendar";
+            cal_.write_state(os);
+            os += "\n";
+        }
+    }
+
+    NodeContainer::print(os);
+    Indentor::indent(os);
+    os += "endsuite\n";
+}
+
+void Suite::write_state(std::string& ret, bool& added_comment_char) const {
+    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e.
+    //                 `task a; task b;`
+    if (begun_) {
+        add_comment_char(ret, added_comment_char);
+        ret += " begun:1";
+    }
+    NodeContainer::write_state(ret, added_comment_char);
+}
+void Suite::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
+
+    // suite s1 # begun:1 state:queued flag:edit_failed suspended:1
+    if (lineTokens.size() >= 4 && lineTokens[3] == "begun:1")
+        begun_ = true;
+    NodeContainer::read_state(line, lineTokens);
+}
+
+const std::string& Suite::debugType() const {
+    return ecf::Str::SUITE();
+}
+
+std::ostream& operator<<(std::ostream& os, const Suite& d) {
+    std::string s;
+    d.print(s);
+    os << s;
+    return os;
+}
+
+void Suite::addClock(const ClockAttr& c, bool initialize_calendar) {
+    if (clockAttr_.get()) {
+        throw std::runtime_error("Add Clock failed: Suite can only have one clock " + absNodePath());
+    }
+    if (clock_end_attr_.get()) {
+        if (clock_end_attr_->ptime() <= c.ptime()) {
+            throw std::runtime_error("Add Clock failed:: End time must be greater than start time " + absNodePath());
+        }
+    }
+
+    clockAttr_ = std::make_shared<ClockAttr>(c);
+    if (initialize_calendar)
+        clockAttr_->init_calendar(cal_);
+
+    // clock_end_attr_ is always same type as clock
+    if (clock_end_attr_.get())
+        clock_end_attr_->hybrid(clockAttr_->hybrid());
+}
+
+void Suite::changeClock(const ClockAttr& c) {
+    // When changing the clock, *WAIT* till requeue/begin to init the calendar
+    clockAttr_.reset();
+    addClock(c, false);
+}
+
+void Suite::add_end_clock(const ClockAttr& c) {
+    // end clock is for simulator only
+    if (clock_end_attr_.get()) {
+        throw std::runtime_error("Add end Clock failed: Suite can only have one end clock " + absNodePath());
+    }
+    if (clockAttr_.get()) {
+        if (c.ptime() <= clockAttr_->ptime()) {
+            throw std::runtime_error("Add end Clock failed: End time must be greater than start time " + absNodePath());
+        }
+    }
+
+    clock_end_attr_ = std::make_shared<ClockAttr>(c);
+    clock_end_attr_->set_end_clock();
+
+    // clock_end_attr_ is always same type as clock
+    if (clockAttr_.get())
+        clock_end_attr_->hybrid(clockAttr_->hybrid());
+}
+
+void Suite::changeClockType(const std::string& clockType) {
+    // ISSUES:
+    // Whenever the user *alters* the clock attributes, it needs to be followed by a re-queue of the suite, because:
+    //   o/ if we change from real ->hybrid, then we need to set cron, etc. time based nodes to complete
+    //      Since we could have running tasks, it is up to user to decide when.
+    //   o/ If we change from hybrid ->real, then Node with cron attributes etc., need to be re-queued.
+    //   o/ Any relative times are no longer valid
+    //   o/ Time attributes will be incorrect, and hence may fail/pass incorrectly during dependency evaluation.
+    //   o/ Why command may be wrong
+    //
+    //
+    // *IF* the user *forgets* to do this, it can cause spurious errors, hence to *minimise* these
+    // the best we can do is to :
+    //   o/ re-sync suite calendar for clock attribute
+    //   o/ re-queue all time based attributes, *avoiding*
+    //      change of state when switching to hybrid clock (i.e. due to day,date,cron time attrs)
+    // This is handled in handle_clock_attribute_change()
+    //
+
+    if (clockType != "hybrid" && clockType != "real") {
+        throw std::runtime_error("Suite::changeClockType: expected clock type to be 'hybrid' or 'real'  but found " +
+                                 clockType);
+    }
+
+    SuiteChanged1 changed(this);
+    if (clockAttr_.get()) {
+        clockAttr_->hybrid(clockType == "hybrid"); // will update state change_no
+    }
+    else {
+        addClock(ClockAttr(clockType == "hybrid")); // will update state change_no
+    }
+
+    // clock_end_attr_ is always same type as clock
+    if (clock_end_attr_.get())
+        clock_end_attr_->hybrid(clockAttr_->hybrid());
+
+    // re-sync suite calendar for clock attribute, re-queue all time based attributes
+    handle_clock_attribute_change();
+}
+
+void Suite::changeClockDate(const std::string& theDate) {
+    // See ISSUES: Suite::changeClockType
+    int dayy, month, year;
+    DateAttr::getDate(theDate, dayy, month, year);
+    if (dayy == 0 || month == 0 || year == 0)
+        throw std::runtime_error("Suite::changeClockDate Invalid clock date:" + theDate);
+
+    // ECFLOW-417
+    // By default the user *IS* expected to requeue afterward. However, in the case where we
+    // have a hybrid clock *AND* repeat day, the calendar date will be updated after the requeue.
+    // This will update calendar by repeat days.
+    // Hence, take this into account by decrementing by number of days
+    if (clockAttr_.get() && clockAttr_->hybrid() && repeat().is_repeat_day()) {
+        boost::gregorian::date the_date(year, month, dayy);
+        the_date -= date_duration(repeat().step());
+        dayy  = the_date.day();
+        month = the_date.month();
+        year  = the_date.year();
+    }
+
+    SuiteChanged1 changed(this);
+    if (clockAttr_.get()) {
+        clockAttr_->date(dayy, month, year); // this will check the date and update state change_no
+    }
+    else {
+        addClock(ClockAttr(dayy, month, year)); // will update state change_no
+    }
+
+    handle_clock_attribute_change();
+}
+
+void Suite::changeClockGain(const std::string& gain) {
+    // See: ISSUES on Suite::changeClockType
+    long theGain = 0;
+    try {
+        theGain = ecf::convert_to<long>(gain);
+    }
+    catch (const ecf::bad_conversion&) {
+        throw std::runtime_error("Suite::changeClockGain: value '" + gain +
+                                 "' is not convertible to an long, for suite " + name());
+    }
+
+    SuiteChanged1 changed(this);
+    if (!clockAttr_.get()) {
+        addClock(ClockAttr()); // will update state change_no
+    }
+
+    if (theGain > 0) {
+        clockAttr_->set_gain_in_seconds(theGain, true); // will update state change_no
+    }
+    else {
+        clockAttr_->set_gain_in_seconds(theGain, false); // will update state change_no
+    }
+
+    handle_clock_attribute_change();
+}
+
+void Suite::changeClockSync() {
+    // See: ISSUES on Suite::changeClockType
+    SuiteChanged1 changed(this);
+    if (clockAttr_.get()) {
+        clockAttr_->sync(); // clear so that on re-queue we sync with computer, + will update state change_no
+    }
+    else {
+        addClock(ClockAttr()); // will update state change_no
+    }
+
+    handle_clock_attribute_change();
+}
+
+void Suite::handle_clock_attribute_change() {
+    // re-queue time could cause thousands of mementos to be created, to avoid this we
+    // update the modify change number.
+    Ecf::incr_modify_change_no();
+
+    // Since the suite clock attribute has changed, re-sync the suite calendar
+    begin_calendar();
+
+    // re-queue all the time attributes, since clock attribute has changed, avoid changing node state.
+    // Note: when switching to hybrid clock the re-queue of time dependencies will
+    //       *not* mark hybrid (day,date,cron) as complete
+    //       since these nodes could be in an active/submitted state.
+    NodeContainer::requeue_time_attrs();
+
+    // make sure we regenerate all suite variables, i.e like ECF_DATE, etc
+    if (suite_gen_variables_)
+        suite_gen_variables_->force_update();
+
+    update_generated_variables();
+}
+
+bool Suite::checkInvariants(std::string& errorMsg) const {
+    if (!cal_.checkInvariants(errorMsg)) {
+        return false;
+    }
+    if (clockAttr_.get()) {
+        if (calendar().hybrid() != clockAttr_->hybrid()) {
+            std::stringstream ss;
+            ss << "Suite:" << name() << " Calendar(hybrid(" << calendar().hybrid() << ")) and Clock attribute(hybrid("
+               << clockAttr_->hybrid() << ")) must be in sync, clock types differs";
+            errorMsg += ss.str();
+            return false;
+        }
+    }
+
+    if (Ecf::server()) {
+        if (state_change_no_ > Ecf::state_change_no()) {
+            std::stringstream ss;
+            ss << "Suite::checkInvariants: suite_change_no(" << state_change_no_ << ") > Ecf::state_change_no("
+               << Ecf::state_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+        if (begun_change_no_ > Ecf::state_change_no()) {
+            std::stringstream ss;
+            ss << "Suite::checkInvariants: begun_change_no_(" << begun_change_no_ << ") > Ecf::state_change_no("
+               << Ecf::state_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+        if (calendar_change_no_ > Ecf::state_change_no() + 1) {
+            std::stringstream ss;
+            ss << "Suite::checkInvariants: calendar_change_no_(" << calendar_change_no_ << ") > Ecf::state_change_no("
+               << Ecf::state_change_no() + 1 << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+        if (modify_change_no_ > Ecf::modify_change_no()) {
+            std::stringstream ss;
+            ss << "Suite::checkInvariants: modify_change_no_(" << modify_change_no_ << ") > Ecf::modify_change_no("
+               << Ecf::modify_change_no() << ")\n";
+            errorMsg += ss.str();
+            return false;
+        }
+    }
+    return NodeContainer::checkInvariants(errorMsg);
+}
+
+void Suite::collateChanges(DefsDelta& changes) const {
+    /// The suite hold the max state change no, for all its children and attributes
+
+    // Optimising updates:
+    // Problem:
+    //    User has requested 1 second updated in the viewer. We used add SuiteCalendarMemento
+    //    when ever there were changes in the suite. However, this causes the suite in the
+    //    viewer to *refresh* too often.
+    //
+    // Soln 1:
+    //   Use:
+    //      calendar_change_no_ = Ecf::incr_state_change_no();
+    //
+    //   plus only create SuiteCalendarMemento, where the suite changes *AND*
+    //   calendar has actually changed.
+    //   - This fixes the problem, at the expense of *always* creating a SuiteCalendarMemento
+    //     every 60 seconds. Thus adding to network traffic.
+    //   - The regression tests will fail, since a change is made in the server,
+    //     for which the sync does nothing. *************************************
+    //     This could be fixed by creating a SuiteCalendarMemento when calendar changes
+    //     However we then go back always creating SuiteCalendarMemento every 60 seconds
+    //     even when there are **no other** changes
+    //
+    // Soln 2:
+    //    Use:
+    //       calendar_change_no_ = Ecf::state_change_no() + 1
+    //
+    //    We mimick updating Ecf::state_change_no(), thus we can create memento when required
+    //    They should however not be recognised as state change.
+    //    + This fixes the problem, and the regression test will also work
+    //    This is the solution that has been implemented
+    //
+    //    + ECFLOW-631 updated, to allow client to sync clock, before calling why cmd.
+
+    // ********************************************************************
+    // Note: we separate determining incremental changes from the traversal
+    // ********************************************************************
+
+#ifdef DEBUG_MEMENTO
+    std::cout << "Suite::collateChanges()\n";
+    std::cout << "  " << debugNodePath() << "\n";
+    std::cout << "  client_state_change_no(" << changes.client_state_change_no() << ")\n";
+    std::cout << "  suite state_change_no (" << state_change_no() << ")\n";
+    std::cout << "  calendar_change_no_   (" << calendar_change_no_ << ")\n";
+    std::cout << "  sync_suite_clock      (" << changes.sync_suite_clock() << ")\n";
+#endif
+
+    if (state_change_no() > changes.client_state_change_no() ||
+        (changes.sync_suite_clock() && calendar_change_no_ > changes.client_state_change_no())) {
+
+        // *TREAT* All changes to *a* Node, in a single compound_memento_ptr
+        size_t before = changes.size();
+
+        compound_memento_ptr suite_compound_mememto;
+        if (clockAttr_.get() && clockAttr_->state_change_no() > changes.client_state_change_no()) {
+            if (!suite_compound_mememto.get())
+                suite_compound_mememto = std::make_shared<CompoundMemento>(absNodePath());
+            suite_compound_mememto->add(std::make_shared<SuiteClockMemento>(*clockAttr_));
+        }
+        if (begun_change_no_ > changes.client_state_change_no()) {
+            if (!suite_compound_mememto.get())
+                suite_compound_mememto = std::make_shared<CompoundMemento>(absNodePath());
+            suite_compound_mememto->add(std::make_shared<SuiteBeginDeltaMemento>(begun_));
+        }
+
+        /// Collate NodeContainer and Node changes into *SAME* compound_memento_ptr
+        NodeContainer::incremental_changes(changes, suite_compound_mememto);
+
+        // Traversal, we have finished with this node:
+        // Traverse children : *SEPARATE* compound_memento_ptr created on demand
+        NodeContainer::collateChanges(changes);
+
+        /// *ONLY* create SuiteCalendarMemento, if something changed in the suite.
+        /// *OR* if it has been specifically requested. see ECFLOW-631
+        /// Additionally calendar_change_no_ updates should not register as a state change, i.e for tests
+        /// *AND* for showing the state change times.
+        /// SuiteCalendarMemento is needed so that WhyCmd can work on the client side.
+        /// Need to use new compound since the suite may not have change, but it children may have.
+        /// Hence as side affect why command with reference to time will only be accurate
+        /// after some kind of state change. Fixed with ECFLOW-631 (Client must do sync_clock, before calling why)
+        size_t after = changes.size();
+        if ((before != after || changes.sync_suite_clock()) && calendar_change_no_ > changes.client_state_change_no()) {
+            compound_memento_ptr compound_ptr = std::make_shared<CompoundMemento>(absNodePath());
+            compound_ptr->add(std::make_shared<SuiteCalendarMemento>(cal_));
+            changes.add(compound_ptr);
+        }
+    }
+}
+
+void Suite::set_memento(const SuiteClockMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Suite::set_memento( const SuiteClockMemento*) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::SUITE_CLOCK);
+    else
+        changeClock(memento->clockAttr_);
+}
+
+void Suite::set_memento(const SuiteBeginDeltaMemento* memento,
+                        std::vector<ecf::Aspect::Type>& aspects,
+                        bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Suite::set_memento( const SuiteBeginDeltaMemento* ) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only)
+        aspects.push_back(ecf::Aspect::SUITE_BEGIN);
+    else
+        begun_ = memento->begun_;
+}
+
+void Suite::set_memento(const SuiteCalendarMemento* memento,
+                        std::vector<ecf::Aspect::Type>& aspects,
+                        bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Suite::set_memento( const SuiteCalendarMemento* ) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::SUITE_CALENDAR);
+        return;
+    }
+
+    // The calendar does *NOT* persist the calendar type (hybrid/real) since we can derive this for clock attribute
+    // Hence make sure calendar/clock are in sync. part of the suite invariants
+    cal_ = memento->cal_;
+    if (clockAttr_.get()) {
+        if (clockAttr_->hybrid())
+            cal_.set_clock_type(ecf::Calendar::HYBRID);
+        else
+            cal_.set_clock_type(ecf::Calendar::REAL);
+    }
+}
+
+// generated variables ---------------------------------------------------------------------
+void Suite::update_generated_variables() const {
+    // This function is called during:
+    //   o begin()
+    //   o requeue()
+    //   o when calendar changes
+    if (!suite_gen_variables_)
+        suite_gen_variables_ = new SuiteGenVariables(this);
+    suite_gen_variables_->update_generated_variables();
+    update_repeat_genvar();
+}
+
+const Variable& Suite::findGenVariable(const std::string& name) const {
+    if (!suite_gen_variables_)
+        update_generated_variables();
+
+    const Variable& gen_var = suite_gen_variables_->findGenVariable(name);
+    if (!gen_var.empty())
+        return gen_var;
+    return NodeContainer::findGenVariable(name);
+}
+
+void Suite::gen_variables(std::vector<Variable>& vec) const {
+    if (!suite_gen_variables_)
+        update_generated_variables();
+
+    vec.reserve(vec.size() + 13);
+    NodeContainer::gen_variables(vec);
+    suite_gen_variables_->gen_variables(vec);
+}
+
+std::string Suite::find_node_path(const std::string& type, const std::string& node_name) const {
+    if (Str::caseInsCompare(type, "suite") && node_name == name()) {
+        return absNodePath();
+    }
+    return NodeContainer::find_node_path(type, node_name);
+}
+
+// =======================================================================================
+
+// The false below is used as a dummy argument to call the Variable constructor that does not
+// check the variable names. i.e. we know they are valid
+SuiteGenVariables::SuiteGenVariables(const Suite* s)
+    : suite_(s),
+      genvar_suite_("SUITE", "", false),
+      genvar_ecf_time_("ECF_TIME", "", false),
+      genvar_time_("TIME", "", false),
+      genvar_yyyy_("YYYY", "", false),
+      genvar_dow_("DOW", "", false),
+      genvar_doy_("DOY", "", false),
+      genvar_date_("DATE", "", false),
+      genvar_day_("DAY", "", false),
+      genvar_dd_("DD", "", false),
+      genvar_mm_("MM", "", false),
+      genvar_month_("MONTH", "", false),
+      genvar_ecf_date_("ECF_DATE", "", false),
+      genvar_ecf_clock_("ECF_CLOCK", "", false),
+      genvar_ecf_julian_("ECF_JULIAN", "", false),
+      force_update_(false) {
+}
+
+void SuiteGenVariables::update_generated_variables() const {
+    genvar_suite_.set_value(suite_->name());
+
+    // The cal_ is only initialised once the suite has begun
+    if (!suite_->begun_) {
+        return;
+    }
+
+    // The code below ASSUMES calendar has been initialised
+    boost::posix_time::time_duration time_of_day = suite_->cal_.suiteTime().time_of_day();
+
+    // #ifdef DEBUG
+    //     using namespace boost::gregorian;
+    //     tm t = to_tm(suite_->cal_.suiteTime());  // to_tm can be a bit of a performance hog
+    ////  cerr << "\ntm_year = " << t.tm_year << "\n";  /* year - 1900              */
+    ////  cerr << "tm_mon = " << t.tm_mon << "\n";      /* month of year (0 - 11)   */
+    ////  cerr << "tm_mday = " << t.tm_mday << "\n";    /* day of month (1 - 31)    */
+    ////  cerr << "tm_wday = " << t.tm_wday << "\n";    /* day of week (Sunday = 0) */
+    ////  cerr << "tm_yday = " << t.tm_yday << "\n";    /* day of year (0 - 365)    */
+    ////  cerr << "tm_hour = " << t.tm_hour << "\n";    /* hours (0 - 23)           */
+    ////  cerr << "tm_min = " << t.tm_min << "\n";      /* minutes (0 - 59)         */
+    ////  cerr << "tm_sec = " << t.tm_sec << "\n";      /* seconds (0 - 59)         */
+    //
+    //    // ***IMPORTANT*** suiteTime is only valid for real clock, note that
+    //    // *************** for hybrid the day does not change. hence assertion
+    //    // *************** needs to take into account calendar type
+    //       if (!suite_->cal_.hybrid()) {
+    //          assert( t.tm_wday   == cal_.day_of_week());
+    //          assert( t.tm_mday   == cal_.day_of_month());
+    //          assert( t.tm_yday+1 == cal_.day_of_year());
+    //          assert( t.tm_mon+1  == cal_.month());
+    //       }
+    //    assert( time_of_day.hours() == t.tm_hour);
+    //    assert( time_of_day.minutes() == t.tm_min);
+    //    assert( t.tm_year + 1900 == cal_.year());
+    // #endif
+
+    int hours   = time_of_day.hours();
+    int minutes = time_of_day.minutes();
+
+    constexpr int buff_size = 255;
+    char buffer[buff_size];
+    snprintf(buffer, buff_size, "%02d%02d", hours, minutes);
+    genvar_time_.set_value(buffer);
+
+    snprintf(buffer, buff_size, "%02d:%02d", hours, minutes);
+    genvar_ecf_time_.set_value(buffer);
+
+    // cout << "genvar_time_ = " << genvar_time_.theValue() << "\n";
+    // cout << "genvar_ecf_time_ = " << genvar_ecf_time_.theValue() << "\n";
+
+    // **********************************************************************
+    // The following generated variable need only be updated if NULL or if day changed
+    // Under: HYBRID the day will never change, hence a one time update
+    // **********************************************************************
+    if (suite_->cal_.dayChanged() || genvar_yyyy_.theValue().empty() || force_update_) {
+
+        force_update_ = false;
+        genvar_yyyy_.set_value(ecf::convert_to<std::string>(suite_->cal_.year()));
+        genvar_dow_.set_value(ecf::convert_to<std::string>(suite_->cal_.day_of_week()));
+        genvar_doy_.set_value(ecf::convert_to<std::string>(suite_->cal_.day_of_year()));
+        // cout << "genvar_yyyy_ = " << genvar_yyyy_.theValue() << "\n";
+        // cout << "genvar_dow_ = " << genvar_dow_.theValue() << "\n";
+        // cout << "genvar_doy_ = " << genvar_doy_.theValue() << "\n";
+
+        snprintf(buffer,
+                 buff_size,
+                 "%02d.%02d.%04d",
+                 suite_->cal_.day_of_month(),
+                 suite_->cal_.month(),
+                 suite_->cal_.year());
+        genvar_date_.set_value(buffer);
+        // cout << "genvar_date_ = " << genvar_date_.theValue() << "\n";
+
+        char* day_name[] = {const_cast<char*>("sunday"),
+                            const_cast<char*>("monday"),
+                            const_cast<char*>("tuesday"),
+                            const_cast<char*>("wednesday"),
+                            const_cast<char*>("thursday"),
+                            const_cast<char*>("friday"),
+                            const_cast<char*>("saturday"),
+                            nullptr};
+        genvar_day_.set_value(day_name[suite_->cal_.day_of_week()]);
+        // cout << "genvar_day_ = " << genvar_day_.theValue() << "\n";
+
+        snprintf(buffer, buff_size, "%02d", suite_->cal_.day_of_month());
+        genvar_dd_.set_value(buffer);
+        // cout << "genvar_dd_ = " << genvar_dd_.theValue() << "\n";
+
+        snprintf(buffer, buff_size, "%02d", suite_->cal_.month());
+        genvar_mm_.set_value(buffer);
+        // cout << "genvar_mm_ = " << genvar_mm_.theValue() << "\n";
+
+        char* month_name[] = {const_cast<char*>("january"),
+                              const_cast<char*>("february"),
+                              const_cast<char*>("march"),
+                              const_cast<char*>("april"),
+                              const_cast<char*>("may"),
+                              const_cast<char*>("june"),
+                              const_cast<char*>("july"),
+                              const_cast<char*>("august"),
+                              const_cast<char*>("september"),
+                              const_cast<char*>("october"),
+                              const_cast<char*>("november"),
+                              const_cast<char*>("december"),
+                              nullptr};
+        genvar_month_.set_value(month_name[suite_->cal_.month() - 1]);
+        // cout << "genvar_month_ = " << genvar_month_.theValue() << "\n";
+
+        snprintf(
+            buffer, buff_size, "%04d%02d%02d", suite_->cal_.year(), suite_->cal_.month(), suite_->cal_.day_of_month());
+        genvar_ecf_date_.set_value(buffer);
+        // cout << "genvar_ecf_date_ = " << genvar_ecf_date_.theValue() << "\n";
+
+        snprintf(buffer,
+                 buff_size,
+                 "%s:%s:%d:%d",
+                 day_name[suite_->cal_.day_of_week()],
+                 month_name[suite_->cal_.month() - 1],
+                 suite_->cal_.day_of_week(),
+                 suite_->cal_.day_of_year());
+        genvar_ecf_clock_.set_value(buffer);
+        // cout << "genvar_ecf_clock_ = " << genvar_ecf_clock_.theValue() << "\n";
+
+        genvar_ecf_julian_.set_value(ecf::convert_to<std::string>(suite_->cal_.suiteTime().date().julian_day()));
+    }
+}
+
+const Variable& SuiteGenVariables::findGenVariable(const std::string& name) const {
+    if (genvar_suite_.name() == name)
+        return genvar_suite_;
+    if (genvar_ecf_date_.name() == name)
+        return genvar_ecf_date_;
+    if (genvar_yyyy_.name() == name)
+        return genvar_yyyy_;
+    if (genvar_dow_.name() == name)
+        return genvar_dow_;
+    if (genvar_doy_.name() == name)
+        return genvar_doy_;
+    if (genvar_date_.name() == name)
+        return genvar_date_;
+    if (genvar_day_.name() == name)
+        return genvar_day_;
+    if (genvar_dd_.name() == name)
+        return genvar_dd_;
+    if (genvar_mm_.name() == name)
+        return genvar_mm_;
+    if (genvar_month_.name() == name)
+        return genvar_month_;
+    if (genvar_ecf_clock_.name() == name)
+        return genvar_ecf_clock_;
+    if (genvar_ecf_time_.name() == name)
+        return genvar_ecf_time_;
+    if (genvar_ecf_julian_.name() == name)
+        return genvar_ecf_julian_;
+    if (genvar_time_.name() == name)
+        return genvar_time_;
+    return Variable::EMPTY();
+}
+
+void SuiteGenVariables::gen_variables(std::vector<Variable>& vec) const {
+    vec.push_back(genvar_suite_);
+    vec.push_back(genvar_ecf_date_);
+    vec.push_back(genvar_yyyy_);
+    vec.push_back(genvar_dow_);
+    vec.push_back(genvar_doy_);
+    vec.push_back(genvar_date_);
+    vec.push_back(genvar_day_);
+    vec.push_back(genvar_dd_);
+    vec.push_back(genvar_mm_);
+    vec.push_back(genvar_month_);
+    vec.push_back(genvar_ecf_clock_);
+    vec.push_back(genvar_ecf_time_);
+    vec.push_back(genvar_ecf_julian_);
+    vec.push_back(genvar_time_);
+}
+
+template <class Archive>
+void Suite::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<NodeContainer>(this));
+    CEREAL_OPTIONAL_NVP(ar, begun_, [this]() { return begun_; });               // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, clockAttr_, [this]() { return clockAttr_.get(); }); // conditionally save
+    ar(CEREAL_NVP(cal_));
+
+    // The calendar does not persist the clock type or start stop with server since
+    // that is persisted with the clock attribute
+    if (Archive::is_loading::value) {
+        if (clockAttr_.get())
+            clockAttr_->init_calendar(cal_);
+    }
+}
+CEREAL_TEMPLATE_SPECIALIZE_V(Suite);
+CEREAL_REGISTER_TYPE(Suite)
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Suite.hpp 5.13.0-1/libs/node/src/ecflow/node/Suite.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Suite.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Suite.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,167 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Suite_HPP
+#define ecflow_node_Suite_HPP
+
+#include "ecflow/attribute/ClockAttr.hpp" // IWYU pragma: keep
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/node/NodeContainer.hpp"
+
+class SuiteGenVariables;
+namespace ecf {
+class CalendarUpdateParams;
+} // namespace ecf
+
+class Suite final : public NodeContainer {
+public:
+    explicit Suite(const std::string& name, bool check = true) : NodeContainer(name, check) {}
+    Suite() = default;
+
+    Suite(const Suite&);
+    Suite& operator=(const Suite&);
+    node_ptr clone() const override;
+
+    ~Suite() override;
+
+    static suite_ptr create(const std::string& name, bool check = true);
+    static suite_ptr create_me(const std::string& name); // python api, to pick correct init function
+
+    bool check_defaults() const override;
+
+    Suite* suite() const override { return const_cast<Suite*>(this); }
+    Defs* defs() const override { return defs_; }
+    void set_defs(Defs* d) { defs_ = d; }
+    Suite* isSuite() const override { return const_cast<Suite*>(this); }
+    NodeContainer* isNodeContainer() const override { return const_cast<Suite*>(this); }
+
+    /// Overridden to take into account begin()
+    bool resolveDependencies(JobsParam&) override;
+
+    void accept(ecf::NodeTreeVisitor&) override;
+    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
+    void reset() override;
+    void handle_migration(const ecf::Calendar&) override;
+    void begin() override;
+    void requeue(Requeue_args& args) override;
+    bool begun() const { return begun_; }
+    void reset_begin();
+    void update_generated_variables() const override;
+
+    const Variable& findGenVariable(const std::string& name) const override;
+    std::string find_node_path(const std::string& type, const std::string& name) const override;
+
+    void gen_variables(std::vector<Variable>&) const override;
+
+    void updateCalendar(const ecf::CalendarUpdateParams&, Node::Calendar_args&);
+
+    const std::string& debugType() const override;
+
+    bool operator==(const Suite& rhs) const;
+    void print(std::string&) const override;
+
+    void addClock(const ClockAttr&,
+                  bool initialize_calendar = true); // throw std::run_time if more than one clock is added
+    void add_end_clock(const ClockAttr&);
+    void changeClock(const ClockAttr&);
+    void changeClockType(const std::string& theType);
+    void changeClockDate(const std::string& theDate);
+    void changeClockGain(const std::string& theIntGain);
+    void changeClockSync();
+
+    /// return the suites calendar
+    const ecf::Calendar& calendar() const { return cal_; }
+    ecf::Calendar& set_calendar() { return cal_; }
+    clock_ptr clockAttr() const { return clockAttr_; }
+    clock_ptr clock_end_attr() const { return clock_end_attr_; }
+
+    bool checkInvariants(std::string& errorMsg) const override;
+
+    // Memento functions
+    void collateChanges(DefsDelta&) const override;
+    void set_memento(const SuiteClockMemento*, std::vector<ecf::Aspect::Type>& aspects, bool);
+    void set_memento(const SuiteBeginDeltaMemento*, std::vector<ecf::Aspect::Type>& aspects, bool);
+    void set_memento(const SuiteCalendarMemento*, std::vector<ecf::Aspect::Type>& aspects, bool);
+    void set_memento(const OrderMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
+        NodeContainer::set_memento(m, aspects, f);
+    }
+    void set_memento(const ChildrenMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
+        NodeContainer::set_memento(m, aspects, f);
+    }
+
+    void set_state_change_no(unsigned int x) { state_change_no_ = x; }
+    unsigned int state_change_no() const { return state_change_no_; }
+    void set_modify_change_no(unsigned int x) { modify_change_no_ = x; }
+    unsigned int modify_change_no() const { return modify_change_no_; }
+
+    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
+
+private:
+    void reset_begin_only();
+    void begin_calendar();
+    void requeue_calendar();
+    void handle_clock_attribute_change();
+    void write_state(std::string&, bool&) const override;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+
+private:
+    Defs* defs_{nullptr}; // *NOT* persisted, set by parent Defs
+    clock_ptr clockAttr_;
+    clock_ptr clock_end_attr_;           // *NOT* persisted, used by simulator only
+    ecf::Calendar cal_;                  // *Only* persisted since used by the why() on client side
+    unsigned int state_change_no_{0};    // no need to persist
+    unsigned int modify_change_no_{0};   // no need to persist
+    unsigned int begun_change_no_{0};    // no need to persist,  record changes to begun_. Needed for SSyncCmd
+    unsigned int calendar_change_no_{0}; // no need to persist,
+    mutable SuiteGenVariables* suite_gen_variables_{
+        nullptr}; // NOT persisted can be generated by calling update_generated_variables()
+    bool begun_{false};
+    friend class SuiteGenVariables;
+};
+
+std::ostream& operator<<(std::ostream& os, const Suite&);
+
+// This class helps in avoiding the creation of generated variables until required.
+// This improves client->server down load times by avoiding thousands of string constructions
+class SuiteGenVariables {
+public:
+    explicit SuiteGenVariables(const Suite*);
+    // Disable copy (and move) semantics
+    SuiteGenVariables(const SuiteGenVariables&)                  = delete;
+    const SuiteGenVariables& operator=(const SuiteGenVariables&) = delete;
+
+    void force_update() { force_update_ = true; }
+    void update_generated_variables() const;
+    const Variable& findGenVariable(const std::string& name) const;
+    void gen_variables(std::vector<Variable>& vec) const;
+
+private:
+    const Suite* suite_;
+    mutable Variable genvar_suite_;      // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_ecf_time_;   // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_time_;       // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_yyyy_;       // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_dow_;        // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_doy_;        // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_date_;       // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_day_;        // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_dd_;         // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_mm_;         // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_month_;      // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_ecf_date_;   // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_ecf_clock_;  // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable Variable genvar_ecf_julian_; // *NOT* persisted, can be generated by calling update_generated_variables()
+    mutable bool force_update_;
+};
+
+#endif /* ecflow_node_Suite_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/SuiteChanged.cpp 5.13.0-1/libs/node/src/ecflow/node/SuiteChanged.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/SuiteChanged.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/SuiteChanged.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifdef DEBUG
+    #include <iostream>
+#endif
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+
+namespace ecf {
+
+SuiteChanged::SuiteChanged(suite_ptr s)
+    : suite_(s),
+      state_change_no_(Ecf::state_change_no()),
+      modify_change_no_(Ecf::modify_change_no()) {
+}
+
+SuiteChanged::~SuiteChanged() {
+    suite_ptr suite = suite_.lock();
+    if (suite.get()) {
+        if (modify_change_no_ != Ecf::modify_change_no()) {
+            suite->set_modify_change_no(Ecf::modify_change_no());
+        }
+        if (state_change_no_ != Ecf::state_change_no()) {
+            suite->set_state_change_no(Ecf::state_change_no());
+        }
+    }
+}
+
+// ============================================================================
+SuiteChanged0::SuiteChanged0(node_ptr s)
+    : node_(s),
+      suite_(s->suite()),
+      state_change_no_(Ecf::state_change_no()),
+      modify_change_no_(Ecf::modify_change_no()) {
+}
+
+SuiteChanged0::~SuiteChanged0() {
+    node_ptr node = node_.lock();
+    if (node.get() && suite_) {
+        if (modify_change_no_ != Ecf::modify_change_no()) {
+            suite_->set_modify_change_no(Ecf::modify_change_no());
+            // std::cout << "SuiteChanged0::~SuiteChanged0() modify_ changed \n";
+        }
+        if (state_change_no_ != Ecf::state_change_no()) {
+            suite_->set_state_change_no(Ecf::state_change_no());
+            // std::cout << "SuiteChanged0::~SuiteChanged0() state changed \n";
+        }
+    }
+}
+
+// ============================================================================
+SuiteChangedPtr::SuiteChangedPtr(Node* s)
+    : suite_(s->suite()),
+      state_change_no_(Ecf::state_change_no()),
+      modify_change_no_(Ecf::modify_change_no()) {
+}
+
+SuiteChangedPtr::~SuiteChangedPtr() {
+    if (suite_) {
+        if (modify_change_no_ != Ecf::modify_change_no()) {
+            suite_->set_modify_change_no(Ecf::modify_change_no());
+            // std::cout << "SuiteChangedPtr::~SuiteChangedPtr() modify_ changed \n";
+        }
+        if (state_change_no_ != Ecf::state_change_no()) {
+            suite_->set_state_change_no(Ecf::state_change_no());
+            // std::cout << "SuiteChangedPtr::~SuiteChangedPtr() state changed \n";
+        }
+    }
+}
+//================================================================
+
+SuiteChanged1::SuiteChanged1(Suite* s)
+    : suite_(s),
+      state_change_no_(Ecf::state_change_no()),
+      modify_change_no_(Ecf::modify_change_no()) {
+}
+
+SuiteChanged1::~SuiteChanged1() {
+    if (modify_change_no_ != Ecf::modify_change_no()) {
+        suite_->set_modify_change_no(Ecf::modify_change_no());
+        // std::cout << "SuiteChanged1::~SuiteChanged0() modify_ changed \n";
+    }
+    if (state_change_no_ != Ecf::state_change_no()) {
+        suite_->set_state_change_no(Ecf::state_change_no());
+        // std::cout << "SuiteChanged1::~SuiteChanged0() modify_ changed \n";
+    }
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/SuiteChanged.hpp 5.13.0-1/libs/node/src/ecflow/node/SuiteChanged.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/SuiteChanged.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/SuiteChanged.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,93 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_SuiteChanged_HPP
+#define ecflow_node_SuiteChanged_HPP
+
+#include "ecflow/node/NodeFwd.hpp"
+
+namespace ecf {
+
+// Determine if suite was changed or modified if so, update suite change no
+// This mechanism was used because, when changing some attributes, we cannot
+// immediately access the parent suites, to update the change numbers.
+//
+// When given a choice between where to add SuiteChanged, i.e in Node Tree or Commands
+// Generally favour commands, as it will require less maintenance over time.
+//
+// This mechanism was added specifically to support changes over client handles
+// i.e suites are added to handles, hence we need a way to determine which
+// suites (and hence handle) changed, and hence minimise the need for updates.
+
+class SuiteChanged {
+public:
+    explicit SuiteChanged(suite_ptr s);
+    // Disable copy (and move) semantics
+    SuiteChanged(const SuiteChanged&)                  = delete;
+    const SuiteChanged& operator=(const SuiteChanged&) = delete;
+
+    ~SuiteChanged();
+
+private:
+    weak_suite_ptr suite_;
+    unsigned int state_change_no_;
+    unsigned int modify_change_no_;
+};
+
+class SuiteChanged0 {
+public:
+    explicit SuiteChanged0(node_ptr s);
+    // Disable copy (and move) semantics
+    SuiteChanged0(const SuiteChanged0&)                  = delete;
+    const SuiteChanged0& operator=(const SuiteChanged0&) = delete;
+
+    ~SuiteChanged0();
+
+private:
+    weak_node_ptr node_;
+    Suite* suite_; // if node is removed suite pointer is not accessible, hence store first
+    unsigned int state_change_no_;
+    unsigned int modify_change_no_;
+};
+
+// Faster than using node_ptr.
+class SuiteChangedPtr {
+public:
+    explicit SuiteChangedPtr(Node* s);
+    // Disable copy (and move) semantics
+    SuiteChangedPtr(const SuiteChangedPtr&)                  = delete;
+    const SuiteChangedPtr& operator=(const SuiteChangedPtr&) = delete;
+
+    ~SuiteChangedPtr();
+
+private:
+    Suite* suite_; // if node is removed suite pointer is not accessible, hence store first
+    unsigned int state_change_no_;
+    unsigned int modify_change_no_;
+};
+
+class SuiteChanged1 {
+public:
+    explicit SuiteChanged1(Suite* s);
+    // Disable copy (and move) semantics
+    SuiteChanged1(const SuiteChanged1&)                  = delete;
+    const SuiteChanged1& operator=(const SuiteChanged1&) = delete;
+
+    ~SuiteChanged1();
+
+private:
+    Suite* suite_;
+    unsigned int state_change_no_;
+    unsigned int modify_change_no_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_SuiteChanged_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/System.cpp 5.13.0-1/libs/node/src/ecflow/node/System.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/System.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/System.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,471 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cerrno>
+#include <csignal>
+
+#include <sys/wait.h> // for waitpid
+
+#ifndef O_WRONLY
+    #include <fcntl.h>
+#endif
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Signal.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/System.hpp"
+
+// #define DEBUG_FORK 1
+// #define DEBUG_CATCH_CHILD 1
+// #define DEBUG_TERMINATED_CHILD 1
+// #define DEBUG_CHILD_ABORT 1
+
+#ifdef DEBUG_FORK
+    #include <iostream>
+#endif
+
+using namespace std;
+
+namespace ecf {
+
+// ===========================================================================
+// Process
+// ===========================================================================
+struct Process
+{
+public:
+    Process(const std::string& absPath, const std::string& cmdToSpawn, System::CmdType cmd_type, pid_t pid)
+        : absNodePath_(absPath),
+          cmd_(cmdToSpawn),
+          cmd_type_(cmd_type),
+          have_status_(0),
+          pid_(pid),
+          status_(0) {}
+
+    std::string absNodePath_;  // Path to Task(ECF_JOB_CMD), empty for ECF_KILL_CMD & ECF_STATUS_CMD
+    std::string cmd_;          // the command that was spawned
+    System::CmdType cmd_type_; // Type of command
+    sig_atomic_t have_status_; // Nonzero if this process has stopped or terminated.  */
+    pid_t pid_;                // The process ID of this child.
+    int status_;               // The status of this child; 0 if running,
+                               // otherwise a status value from waitpid
+};
+std::vector<Process> processVec_;
+
+/* Nonzero means some child's status has changed
+   so look at process_list for the details.  */
+volatile int process_status_change_ = 0;
+
+// ===========================================================================
+// System
+// ===========================================================================
+System* System::instance_ = nullptr;
+
+System* System::instance() {
+    if (instance_ == nullptr) {
+
+        // Block SIGCHLD so that we control, when child process termination is handled
+        ecf::Signal::block_sigchild();
+
+        // install signal handler, that will catch Child process termination
+        // The install function can be called asynchronously, and hence deserves
+        // special consideration. Currently we temporarily unblock pending
+        // SIGCHLD signals at the end of Job generation, and then block them again.
+        // During the brief moment between unblock/block we expect
+        // the handler to be called.
+        catchChildProcessTermination();
+
+        instance_ = new System();
+    }
+    return instance_;
+}
+
+void System::destroy() {
+    delete instance_;
+    instance_ = nullptr;
+}
+
+System::System()  = default;
+System::~System() = default;
+
+bool System::spawn(System::CmdType cmd_type,
+                   const std::string& cmdToSpawn,
+                   const std::string& absPath,
+                   std::string& errorMsg) {
+#ifdef DEBUG_FORK
+    LogToCout logToCoutAsWell;
+    LOG(Log::DBG, "  System::spawn path(" << absPath << ") cmd(" << cmdToSpawn << ") cmd_type(" << cmd_type << ")\n");
+#endif
+
+    std::string msg;
+    if (sys(cmd_type, cmdToSpawn, absPath, msg)) {
+        std::stringstream ss;
+        ss << "Child process creation failed( " << msg << ") for command " << cmdToSpawn;
+        if (!absPath.empty())
+            ss << " at path(" << absPath << ")";
+        errorMsg = ss.str();
+#ifdef DEBUG_FORK
+        LOG(Log::DBG, "  System::spawn returning false\n");
+#endif
+        return false;
+    }
+    return true;
+}
+
+int System::sys(System::CmdType cmd_type,
+                const std::string& cmdToSpawn,
+                const std::string& absPath,
+                std::string& errorMsg) {
+#ifdef DEBUG_FORK
+    LogToCout logToCoutAsWell;
+    LOG(Log::DBG, "  System::sys path(" << absPath << ")  cmd(" << cmdToSpawn << ")  cmd_type(" << cmd_type << ")\n");
+#endif
+    /**************************************************************************
+     ?  Execute the command (cmdToSpawn) and return, DO NOT WAIT for the termination
+     |  of the children.
+     |  The stdin, stdout and stderr are closed (or redirected to /dev/null)
+     =  PID in case of success or 0 in case of errors.
+     ************************************o*************************************/
+    pid_t child_pid;
+    if ((child_pid = fork()) == 0) { /* The child */
+
+        int f;
+        close(2);
+        if ((f = open("/dev/null", O_WRONLY)) != 2)
+            close(f);
+
+        close(1);
+        if ((f = open("/dev/null", O_WRONLY)) != 1)
+            close(f);
+
+        close(0);
+        if ((f = open("/dev/null", O_RDONLY)) != 0)
+            close(f);
+
+        // ==============================================================================
+        // Ideally we should close all open file descriptors in the child process
+        //    On Linux: sysconf(_SC_OPEN_MAX); returns 1024
+        //    This means making 1024 - 3 system calls
+        // This is especially import for socket descriptors, since if the server goes down
+        // The children/zombies will prevent the server restart on the same port.
+        // i.e the classic Address in use
+        // Its not clear how big a performance issue this, an alternative would be, to only close
+        // open socket file descriptors. But this will require a singleton of some sort
+        // ===============================================================================
+        int fd_limit = sysconf(_SC_OPEN_MAX);
+        for (int i = 3; i < fd_limit; i++)
+            close(i);
+
+        execl("/bin/sh", "sh", "-c", cmdToSpawn.c_str(), (char*)nullptr);
+        /*
+         *  Maybe the file protection failed (no executable bit set)
+         *  or the shell couldn't be found. Look at man execve(2).
+         */
+        _exit(127);
+    }
+
+    if (child_pid == -1) {
+        std::stringstream ss;
+        ss << "fork() error(" << strerror(errno) << ")";
+        errorMsg = ss.str();
+        return 1;
+    }
+
+    // Store the process pid, so that we can wait for it. ho ho.
+    processVec_.emplace_back(absPath, cmdToSpawn, cmd_type, child_pid);
+
+#ifdef DEBUG_FORK
+    // LogToCout logToCoutAsWell;
+    LOG(Log::DBG, "   submit: Path(" << absPath << ") child_pid(" << child_pid << ") cmd(" << cmdToSpawn << ")");
+#endif
+    return 0;
+}
+
+static void catch_child(int sig)
+/**************************************************************************
+?  Catch the death of the child process
+|  This function can be called asynchronously hence it could interfere
+   with the rest of program. Hence this function does not allocate or
+   free memory. We simply store the status, for later processing
+************************************o*************************************/
+{
+#ifdef DEBUG_CATCH_CHILD
+    std::cout << "   catch_child (process death) sig = " << sig << endl;
+#endif
+
+    int saved_errno = errno; // save error number since waitpid can change this
+    int status;
+    pid_t child_pid;
+
+    // waitpid returns:
+    //  - on success, returns the process ID of the child whose state has changed
+    //  - if WNOHANG was specified and one or more child(ren) specified by pid exist,
+    //    but have *NOT* yet changed state, then *0* is returned
+    //    *** hence we MUST check for 0, other wise we will end up in an infinite loop **
+    //  - returns -1 on error
+    while ((child_pid = waitpid(-1, &status, WNOHANG)) != -1 && child_pid != 0) {
+
+        auto theEnd = processVec_.end();
+        for (auto i = processVec_.begin(); i != theEnd; ++i) {
+            if ((*i).pid_ == child_pid) {
+
+#ifdef DEBUG_CATCH_CHILD
+                std::cout << "   catch_child Found pid " << child_pid << endl;
+#endif
+                // Indicate that the status field
+                // has data to look at.  We do this only after storing it.
+                (*i).have_status_ = 1;
+
+                // store the status
+                (*i).status_ = status;
+
+                // The program should check this flag from time to time
+                // to see if there is any news in processVec_.
+                process_status_change_++;
+                break;
+            }
+        }
+    }
+
+    // restore error number
+    errno = saved_errno;
+}
+
+void System::processTerminatedChildren() {
+#ifdef DEBUG_TERMINATED_CHILD
+    std::cout << "System::processTerminatedChildren() process_status_change_ = " << process_status_change_
+              << "   processVec_.size() = " << processVec_.size() << endl;
+    LogToCout logToCoutAsWell;
+#endif
+    if (process_status_change_ == 0) {
+        return;
+    }
+
+    // Must be the first thing we do.
+    process_status_change_ = 0;
+
+    std::vector<Process>::iterator i;
+    for (i = processVec_.begin(); i != processVec_.end(); ++i) {
+
+        if ((*i).have_status_) {
+
+#ifdef DEBUG_TERMINATED_CHILD
+            std::cout << "System::processTerminatedChildren(): " << System::cmd_type((*i).cmd_type_) << " path("
+                      << (*i).absNodePath_ << ") pid(" << (*i).pid_ << ") has status(stopped or terminated)" << endl;
+#endif
+            // exit status is one of mutually exclusive [ WIFEXITED | WIFSIGNALED | WIFSTOPPED | WIFCONTINUED ]
+            if (WIFEXITED((*i).status_)) {
+
+                // *Normal* termination via exit
+                if (WEXITSTATUS((*i).status_)) {
+                    // exit is non zero.
+                    std::stringstream ss;
+                    ss << System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") path(" << (*i).absNodePath_
+                       << ") exited with status " << WEXITSTATUS((*i).status_) << " [ " << (*i).cmd_ << " ]";
+                    died((*i).absNodePath_, (*i).cmd_type_, ss.str());
+                }
+                else {
+                    // exit(0) child terminated normally
+#ifdef DEBUG_TERMINATED_CHILD
+                    LOG(Log::DBG,
+                        System::cmd_type((*i).cmd_type_)
+                            << " PID(" << (*i).pid_ << ") exited normally [ " << (*i).cmd_ << " ]");
+#endif
+                }
+
+                // remove the process since it has terminated
+                processVec_.erase(i--);
+            }
+            else if (WIFSIGNALED((*i).status_)) {
+
+                // *abnormal* child process terminated by a signal
+                std::stringstream ss;
+                ss << System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") path(" << (*i).absNodePath_
+                   << ") died of signal " << WTERMSIG((*i).status_) << " [ " << (*i).cmd_ << " ]";
+                died((*i).absNodePath_, (*i).cmd_type_, ss.str());
+
+                // remove the process since it has terminated
+                processVec_.erase(i--);
+            }
+            else if (WIFSTOPPED((*i).status_)) {
+
+                LOG(Log::WAR,
+                    System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") STOPPED? [ " << (*i).absNodePath_
+                                                     << " ] [ " << (*i).cmd_ << " ]");
+            }
+            else {
+
+                // Can only be WIFCONTINUED. (XSI extension to POSIX)
+                LOG(Log::WAR,
+                    System::cmd_type((*i).cmd_type_) << " PID(" << (*i).pid_ << ") CONTINUED? [ " << (*i).absNodePath_
+                                                     << " ] [ " << (*i).cmd_ << " ]");
+            }
+        }
+        else {
+#ifdef DEBUG_TERMINATED_CHILD
+            LOG(Log::DBG,
+                System::cmd_type((*i).cmd_type_)
+                    << " stray PID(" << (*i).pid_ << ") (ignored) [ " << (*i).cmd_ << " ]");
+#endif
+        }
+    }
+
+#ifdef DEBUG_TERMINATED_CHILD
+    std::cout << "System::processTerminatedChildren() process size = " << processVec_.size() << endl;
+#endif
+}
+
+int System::process() const {
+    return static_cast<int>(processVec_.size());
+}
+
+// ============================================================================
+// See: Advanced programming in the UNIX environment: Page 328
+// Note: with sigaction the handle stays installed, until changed
+//       this is different to the signal(..) which on some system needs
+//       to be reinstalled at start/end of SignalFunction.
+// ============================================================================
+typedef void SignalFunction(int);
+SignalFunction* signal_(int signo, SignalFunction* func) {
+    struct sigaction act, oact;
+    act.sa_handler = func;
+    sigemptyset(&act.sa_mask);
+    act.sa_flags = 0;
+    if (signo == SIGALRM) {
+#ifdef SA_INTERRUPT
+        act.sa_flags |= SA_INTERRUPT;
+#endif
+    }
+    else {
+        // We intentionally try to set the SA_RESTART flag for all signals other than SIGALRM
+        // so that any system call interrupted by these other signals in automatically restarted
+#ifdef SA_RESTART
+        act.sa_flags |= SA_RESTART;
+#endif
+    }
+
+    if (sigaction(signo, &act, &oact) < 0)
+        return (SIG_ERR);
+
+    // Return the old handler
+    return oact.sa_handler;
+}
+
+void System::catchChildProcessTermination() {
+    // Call our local version (which uses sigaction) rather than the out date signal(..)
+    signal_(SIGCHLD, catch_child);
+}
+
+void System::died(const std::string& absNodePath, CmdType cmd_type, const std::string& reason)
+/**************************************************************************
+ ?  Process the death of the process. This is most unwanted and implies
+ |  that the shell died abnormally.
+ ************************************o*************************************/
+{
+#ifdef DEBUG_CHILD_ABORT
+    std::cout << "System::died path = '" << absNodePath << "'" << endl;
+#endif
+
+    /// always write to log, before returning
+    ecf::log(Log::ERR, reason);
+
+    /// If the Path is empty, then this could be something *OTHER THAN* job submission
+    /// Typically testing, don't assert
+    if (absNodePath.empty()) {
+        return;
+    }
+
+    defs_ptr defs = defs_.lock();
+    if (!defs.get()) {
+        LOG_ASSERT(defs.get(), "System::died, defs not defined ???");
+        return;
+    }
+
+    node_ptr node = defs->findAbsNode(absNodePath);
+    if (!node.get()) {
+#ifdef DEBUG_CHILD_ABORT
+        std::cout << "System::died " << absNodePath << " could not be found in defs \n";
+#endif
+        return;
+    }
+
+    Submittable* submittable = node->isSubmittable();
+    if (!submittable) {
+#ifdef DEBUG_CHILD_ABORT
+        std::cout << "System::died " << absNodePath << " path is NOT a Task or Alias \n";
+#endif
+        return;
+    }
+
+    // This function can get called at any time.
+    // AND out of context of any command, hence we must handle case where Suite handles are used.
+    // Otherwise the view will not know about aborted states.
+    // ECFLOW-104 aborted state for a task following an error at submission
+    SuiteChanged1 changed(submittable->suite());
+
+    // Only failure of the JOB command should cause SUBMITTABLE to abort.
+    // i.e Badly formed status and kill commands should not abort a running job
+    switch (cmd_type) {
+        case System::ECF_JOB_CMD: {
+            submittable->flag().set(ecf::Flag::JOBCMD_FAILED);
+
+            if (submittable->state() == NState::COMPLETE || submittable->state() == NState::ACTIVE) {
+                // ABNORMAL flow
+                // Occasionally TRIMURTI can time out and fail, even when the job is active or complete.(i.e for super
+                // fast jobs) queued->submitted->active->complete  See: ECFLOW-1589 In this case we should *AVOID*
+                // setting node to aborted.
+                std::string str = "System::died: ECF_JOB_CMD *failed*, but state is ";
+                str += NState::toString(submittable->state());
+                str += "(";
+                str += absNodePath;
+                str += ") setting zombie flag";
+                ecf::log(Log::ERR, str);
+                submittable->flag().set(ecf::Flag::ZOMBIE);
+#ifdef DEBUG_CHILD_ABORT
+                std::cout << str << "\n";
+#endif
+                return;
+            }
+
+#ifdef DEBUG_CHILD_ABORT
+            std::cout << "System::died aborting task " << absNodePath << "\n";
+#endif
+            // NORMAL flow   :  queued->submitted->abort  : for failing ECF_JOB_CMD
+            //
+            // Set state aborted since the job terminated abnormally, and provide a reason
+            submittable->aborted(reason);
+            break;
+        }
+        case System::ECF_KILL_CMD:
+            submittable->flag().set(ecf::Flag::KILLCMD_FAILED);
+            break;
+        case System::ECF_STATUS_CMD:
+            submittable->flag().set(ecf::Flag::STATUSCMD_FAILED);
+            break;
+    };
+}
+
+std::string System::cmd_type(System::CmdType cmd_type) {
+    switch (cmd_type) {
+        case System::ECF_JOB_CMD:
+            return "ECF_JOB_CMD";
+        case System::ECF_KILL_CMD:
+            return "ECF_KILL_CMD";
+        case System::ECF_STATUS_CMD:
+            return "ECF_STATUS_CMD";
+        default:
+            assert(false);
+    }
+    return "ECF_JOB_CMD";
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/System.hpp 5.13.0-1/libs/node/src/ecflow/node/System.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/System.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/System.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,108 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_System_HPP
+#define ecflow_node_System_HPP
+
+///
+/// \brief Works with class Signal
+///
+/// When a child process terminates it does not disappear entirely.
+/// Instead, it becomes a ‘zombie process’ which is no longer capable of executing,
+/// but which still has a PID and an entry in the process table.
+/// This is indicated by the state code Z in ps or top.
+///
+/// The presence of a moderate number of zombie processes is not particularly harmful,
+/// but they add unnecessary clutter that can be confusing to the administrator.
+/// In extreme cases they could exhaust the number of available process table slots.
+///
+/// For these reasons, well-behaved programs should ensure that zombie processes are removed in a timely manner.
+/// The process of eliminating zombie processes is known as ‘reaping’.
+/// The simplest method is to call wait, but this will block the parent process if the child has not yet terminated.
+/// Alternatives are to use waitpid to poll or SIGCHLD to reap asynchronously.
+/// The Class uses waitpid.
+///
+
+#include <string>
+
+#include "ecflow/node/NodeFwd.hpp"
+
+namespace ecf {
+
+/// Job submission in ECF is a two phase step.
+/// phase 1: Spawn of ECF_JOB_CMD
+/// phase 2: Invocation of ECF_JOB_CMD, this creates the *real* job which communicates with the server
+/// For TEST     :ECF_JOB_CMD = "%ECF_JOB% 1> %ECF_JOBOUT% 2>&1
+///     this collapses phase 1 and 2, to a single step
+/// For Operation:ECF_JOB_CMD = ecf_submit %USER% %REMOTE_HOST% %ECFJOB% %ECFJOBOUT%'
+///     This uses ecf_submit,This spawns the process to the different load levellers depending on OS, etc.
+///   and hence involves at least 2 process.
+/// This class handles phase 1, we capture the death of the child process
+/// and hence this class will not in operations handle the death of the real job
+/// created by ecf_submit.
+
+class System {
+public:
+    // Disable copy (and move) semantics
+    System(const System&)                  = delete;
+    const System& operator=(const System&) = delete;
+
+    static System* instance();
+
+    /// Destroy the singleton. used in test only, to avoid valgrind issues
+    static void destroy();
+
+    /// Let the server set this. Typically only set once, however in test  can be many times
+    /// Note:: In test the Defs file in the server can be cleared, i.e. for each new test
+    ///        Hence we maintain a weak_ptr to the Defs.
+    void setDefs(const defs_ptr& defs) { defs_ = defs; }
+
+    // return true, if command can be spawned, else false.
+    // For jobs, We can't store reference to Task*, as future functionality like
+    // auto-migrate, etc, means we may end up pointing to garbage.
+    // so instead we will store absNodePath. For other commands this can be empty
+    enum CmdType { ECF_JOB_CMD, ECF_KILL_CMD, ECF_STATUS_CMD };
+    bool spawn(CmdType, const std::string& cmdToSpawn, const std::string& absPath, std::string& errorMsg);
+
+    // Handle children that have stopped,aborted or terminated, etc.
+    // The signal handler is kept as light as possible, since it is re-entrant.
+    // So Signal handles stores the termination state which handled later
+    // by processTerminatedChildren. Typically, when we un-block SIGCHILD
+    void processTerminatedChildren();
+
+    /// returns the number of active process.
+    /// for debug only
+    int process() const;
+
+private:
+    ~System();
+    System();
+
+    /// Install signals that can catch signal from child process termination
+    static void catchChildProcessTermination();
+
+    // When a process terminates abnormally. This function is used to find the
+    // associated task, and set it to the abort state.
+    // Relies on the stored Defs ptr. which was set in the server
+    void died(const std::string& absNodePath, CmdType, const std::string& reason);
+
+    /// Does the real work of spawning children
+    int sys(CmdType, const std::string& cmdToSpawn, const std::string& absPath, std::string& errorMsg);
+
+    static std::string cmd_type(CmdType);
+
+private:
+    weak_defs_ptr defs_; // weak_ptr is an observer of a shared_ptr
+    static System* instance_;
+};
+
+} // namespace ecf
+
+#endif
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Task.cpp 5.13.0-1/libs/node/src/ecflow/node/Task.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/Task.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Task.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,962 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/Task.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Serialization.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/DefsDelta.hpp"
+#include "ecflow/node/JobProfiler.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/NodeTreeVisitor.hpp"
+#include "ecflow/node/SuiteChanged.hpp"
+#include "ecflow/node/TaskScriptGenerator.hpp"
+#include "ecflow/node/move_peer.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// #define DEBUG_TASK_LOCATION 1
+void Task::copy(const Task& rhs) {
+    size_t theSize = rhs.aliases_.size();
+    for (size_t s = 0; s < theSize; s++) {
+        alias_ptr alias_copy = std::make_shared<Alias>(*rhs.aliases_[s]);
+        alias_copy->set_parent(this);
+        aliases_.push_back(alias_copy);
+    }
+}
+
+Task::Task(const Task& rhs) : Submittable(rhs), alias_no_(rhs.alias_no_) {
+    copy(rhs);
+}
+
+node_ptr Task::clone() const {
+    return std::make_shared<Task>(*this);
+}
+
+bool Task::check_defaults() const {
+    if (order_state_change_no_ != 0)
+        throw std::runtime_error("Task::check_defaults(): order_state_change_no_ != 0");
+    if (add_remove_state_change_no_ != 0)
+        throw std::runtime_error("Task::check_defaults(): add_remove_state_change_no_ != 0");
+    if (alias_change_no_ != 0)
+        throw std::runtime_error("Task::check_defaults(): alias_change_no_ != 0");
+    if (alias_no_ != 0)
+        throw std::runtime_error("Task::check_defaults(): alias_no_ != 0");
+    return Submittable::check_defaults();
+}
+
+Task& Task::operator=(const Task& rhs) {
+    if (this != &rhs) {
+        Submittable::operator=(rhs);
+        aliases_.clear();
+        alias_no_ = rhs.alias_no_;
+        copy(rhs);
+
+        order_state_change_no_      = 0;
+        alias_change_no_            = 0;
+        add_remove_state_change_no_ = Ecf::incr_state_change_no();
+    }
+    return *this;
+}
+
+Task::~Task() {
+    if (!Ecf::server()) {
+        notify_delete();
+    }
+}
+
+task_ptr Task::create(const std::string& name, bool check) {
+    return std::make_shared<Task>(name, check);
+}
+
+task_ptr Task::create_me(const std::string& name) {
+    return std::make_shared<Task>(name, true);
+}
+
+void Task::print(std::string& os) const {
+    Indentor in;
+    Indentor::indent(os);
+    os += "task ";
+    os += name();
+    if (!PrintStyle::defsStyle()) {
+        bool added_comment_char = false;
+        write_state(os, added_comment_char);
+    }
+    os += "\n";
+
+    Node::print(os);
+
+    // Generated variable are not persisted since they are created on demand
+    // There *NO* point in printing them they will always be empty
+
+    // Alias are not printed, but are check point able.
+    if (!PrintStyle::defsStyle()) {
+        Indentor in2;
+        size_t node_vec_size = aliases_.size();
+        for (size_t t = 0; t < node_vec_size; t++) {
+            aliases_[t]->print(os);
+        }
+        if (node_vec_size != 0) {
+            Indentor in3;
+            Indentor::indent(os);
+            os += "endalias\n";
+        }
+    }
+
+    // if ( PrintStyle::defsStyle() ) Indentor::indent(os); os += "endtask\n";
+}
+
+void Task::write_state(std::string& ret, bool& added_comment_char) const {
+    // *IMPORTANT* we *CANT* use ';' character, since is used in the parser, when we have
+    //             multiple statement on a single line i.e.
+    //                 task a; task b;
+    if (alias_no_ != 0) {
+        add_comment_char(ret, added_comment_char);
+        ret += " alias_no:";
+        ret += ecf::convert_to<std::string>(alias_no_);
+    }
+    Submittable::write_state(ret, added_comment_char);
+}
+
+void Task::read_state(const std::string& line, const std::vector<std::string>& lineTokens) {
+
+    if (line.find("alias_no:") != std::string::npos) {
+        // task t1 # alias_no:0 passwd:_DJP_
+        size_t line_tokens_size = lineTokens.size();
+        for (size_t i = 3; i < line_tokens_size; i++) {
+            if (lineTokens[i].find("alias_no:") != std::string::npos) {
+                std::string token;
+                if (!Extract::split_get_second(lineTokens[i], token))
+                    throw std::runtime_error("Task::read_state could not read alias_no for task " + name());
+                alias_no_ = Extract::theInt(token, "Task::read_state: invalid alias_no specified : " + line);
+                break;
+            }
+        }
+    }
+    Submittable::read_state(line, lineTokens);
+}
+
+std::ostream& operator<<(std::ostream& os, const Task& d) {
+    std::string s;
+    d.print(s);
+    os << s;
+    return os;
+}
+
+bool Task::operator==(const Task& rhs) const {
+    if (alias_no_ != rhs.alias_no_) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Task::operator==  alias_no_(" << alias_no_ << ")  != rhs.alias_no_(" << rhs.alias_no_
+                      << ") : " << absNodePath() << "\n";
+        }
+#endif
+        return false;
+    }
+
+    size_t vec_size = aliases_.size();
+    if (vec_size != rhs.aliases_.size()) {
+#ifdef DEBUG
+        if (Ecf::debug_equality()) {
+            std::cout << "Task::operator==  aliases_.size() != rhs.aliases_.size() " << absNodePath() << "\n";
+            std::cout << "   aliases_.size() = " << vec_size << "  rhs.aliases_.size() = " << rhs.aliases_.size()
+                      << "\n";
+        }
+#endif
+        return false;
+    }
+
+    for (size_t i = 0; i < vec_size; ++i) {
+
+        if (!(*aliases_[i] == *rhs.aliases_[i])) {
+#ifdef DEBUG
+            if (Ecf::debug_equality()) {
+                std::cout << "Task::operator==  !( *aliases_[i] == *rhs.aliases_[i] : " << absNodePath() << "\n";
+            }
+#endif
+            return false;
+        }
+    }
+
+    return Submittable::operator==(rhs);
+}
+
+alias_ptr Task::add_alias(std::vector<std::string>& user_file_contents,
+                          const NameValueVec& user_variables,
+                          bool create_directory) {
+    // Create directory
+    std::string dir_to_create;
+    if (create_directory) {
+
+        if (user_file_contents.empty()) {
+            std::stringstream ss;
+            ss << "Task::add_alias: No .usr file contents specified. Alias creation failed for task " << absNodePath();
+            throw std::runtime_error(ss.str());
+        }
+
+        findParentUserVariableValue(Str::ECF_HOME(), dir_to_create);
+        dir_to_create += absNodePath();
+        if (!File::createDirectories(dir_to_create)) {
+            throw std::runtime_error("Task::add_alias: could not create directory " + dir_to_create);
+        }
+    }
+
+    // create alias
+    std::string alias_name = "alias" + ecf::convert_to<std::string>(alias_no_);
+    alias_ptr alias        = Alias::create(alias_name);
+    alias->set_parent(this);
+
+    // create .usr file
+    if (create_directory) {
+        std::string file_path = dir_to_create + "/" + alias_name + alias->script_extension();
+        std::string error_msg;
+        if (!File::create(file_path, user_file_contents, error_msg)) {
+            std::stringstream ss;
+            ss << "Task::add_alias: could not create .usr file at path(" << file_path << "): " << error_msg.c_str();
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    // copy over events, meters, labels, but clear state (ECFLOW-1278)
+    for (Meter meter : meters()) {
+        meter.reset();
+        alias->addMeter(meter);
+    }
+    for (Event event : events()) {
+        event.reset();
+        alias->addEvent(event);
+    }
+    for (Label label : labels()) {
+        label.reset();
+        alias->addLabel(label);
+    }
+
+    // Add user_variables as variables. Note: to reduce memory we could choose
+    // to only add those variable that have been changed/added. However this
+    // would mean an alias could be affected by changed to an inherited variable.
+    // Hence kept as existing sms functionality
+    //
+    // The variables may be **different** to normal variables in that they may contain a ":" & $
+    // This is **not** allowed in normal variables.
+    // i.e it allows for  %A:1%, %A:2%, %A:3%
+    // This is not really recommended but its what the old system supported.
+    // **** Hence add_alias_variable by passes variable name checking ***
+    auto theEnd = user_variables.end();
+    for (auto i = user_variables.begin(); i != theEnd; ++i) {
+        alias->add_alias_variable((*i).first, (*i).second);
+    }
+
+    // increment alias number and store, alias in vector
+    alias_no_++; // Alias number must be set to next valid alias number
+    aliases_.push_back(alias);
+
+    alias_change_no_            = Ecf::incr_state_change_no();
+    add_remove_state_change_no_ = alias_change_no_;
+    return alias;
+}
+
+alias_ptr Task::add_alias_only() {
+    std::vector<std::string> empty_user_file_contents;
+    NameValueVec empty_user_variables;
+    return add_alias(empty_user_file_contents, empty_user_variables, false /* don't create directory or .usr file*/);
+}
+
+alias_ptr Task::add_alias(const std::string& name) {
+    // Do not update alias_no, since that will be read in
+    alias_ptr alias = Alias::create(name);
+    alias->set_parent(this);
+    aliases_.push_back(alias);
+    return alias;
+}
+
+alias_ptr Task::find_alias(const std::string& name) const {
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (aliases_[i]->name() == name) {
+            return aliases_[i];
+        }
+    }
+    return alias_ptr();
+}
+
+void Task::reset_alias_number() {
+    alias_no_        = 0;
+    alias_change_no_ = Ecf::incr_state_change_no();
+}
+
+node_ptr Task::findImmediateChild(const std::string& name, size_t& child_pos) const {
+    child_pos       = std::numeric_limits<std::size_t>::max();
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (aliases_[i]->name() == name) {
+            child_pos = i;
+            return aliases_[i];
+        }
+    }
+    return node_ptr();
+}
+
+node_ptr Task::find_immediate_child(const std::string_view& name) const {
+    for (const auto& n : aliases_) {
+        if (name == n->name()) {
+            return n;
+        }
+    }
+    return node_ptr();
+}
+
+std::string Task::find_node_path(const std::string& type, const std::string& node_name) const {
+    if (Str::caseInsCompare(type, "task")) {
+        if (node_name == name()) {
+            return absNodePath();
+        }
+    }
+    return string();
+}
+
+void Task::reset() {
+    if (aliases_.empty()) {
+        if (alias_no_ != 0) {
+            reset_alias_number();
+        }
+    }
+    Submittable::reset();
+}
+
+void Task::begin() {
+    if (aliases_.empty()) {
+        if (alias_no_ != 0) {
+            reset_alias_number();
+        }
+    }
+
+    Submittable::begin();
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Task::begin()\n";
+#endif
+}
+
+void Task::requeue(Requeue_args& args) {
+    if (aliases_.empty()) {
+        if (alias_no_ != 0) {
+            reset_alias_number();
+        }
+    }
+
+    Submittable::requeue(args);
+
+#ifdef DEBUG_STATE_CHANGE_NO
+    std::cout << "Task::requeue\n";
+#endif
+}
+
+void Task::accept(ecf::NodeTreeVisitor& v) {
+    v.visitTask(this);
+}
+
+void Task::acceptVisitTraversor(ecf::NodeTreeVisitor& v) {
+    v.visitTask(this);
+}
+
+const std::string& Task::debugType() const {
+    return ecf::Str::TASK();
+}
+
+void Task::getAllNodes(std::vector<Node*>& vec) const {
+    // See notes: getAllSubmittables, about reserve
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        vec.push_back(aliases_[i].get());
+    }
+}
+
+void Task::immediateChildren(std::vector<node_ptr>& vec) const {
+    size_t vec_size = aliases_.size();
+    vec.reserve(vec.size() + vec_size);
+    for (size_t i = 0; i < vec_size; i++) {
+        vec.push_back(std::dynamic_pointer_cast<Node>(aliases_[i]));
+    }
+}
+
+void Task::getAllTasks(std::vector<Task*>& vec) const {
+    vec.push_back(const_cast<Task*>(this));
+}
+
+void Task::getAllSubmittables(std::vector<Submittable*>& vec) const {
+    // *DO NOT reserve here, as it dominate time , for very large defs */
+    // * Previously we had::
+    //    vec.reserve(vec.size() + vec_size + 1);
+    // * This took 47 seconds when delete the full defs, i.e when check for active tasks
+
+    vec.push_back(const_cast<Task*>(this));
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        vec.push_back(aliases_[i].get());
+    }
+}
+
+node_ptr Task::find_node_up_the_tree(const std::string& name) const {
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (aliases_[i]->name() == name) {
+            return aliases_[i];
+        }
+    }
+    Node* the_parent = parent();
+    if (the_parent)
+        return the_parent->find_node_up_the_tree(name);
+    return node_ptr();
+}
+
+void Task::get_all_active_submittables(std::vector<Submittable*>& vec) const {
+    // See notes: getAllSubmittables, about reserve
+    if (state() == NState::ACTIVE || state() == NState::SUBMITTED) {
+        vec.push_back(const_cast<Task*>(this));
+    }
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        if (aliases_[i]->state() == NState::ACTIVE || aliases_[i]->state() == NState::SUBMITTED) {
+            vec.push_back(aliases_[i].get());
+        }
+    }
+}
+
+void Task::get_all_tasks(std::vector<task_ptr>& vec) const {
+    vec.push_back(std::dynamic_pointer_cast<Task>(non_const_this()));
+}
+
+void Task::get_all_nodes(std::vector<node_ptr>& nodes) const {
+    nodes.push_back(non_const_this());
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        aliases_[i]->get_all_nodes(nodes);
+    }
+}
+
+void Task::get_all_aliases(std::vector<alias_ptr>& destinationVec) const {
+    destinationVec.reserve(destinationVec.size() + aliases_.size());
+    std::copy(aliases_.begin(), aliases_.end(), std::back_inserter(destinationVec));
+}
+
+bool Task::resolveDependencies(JobsParam& jobsParam) {
+    if (jobsParam.timed_out_of_job_generation())
+        return false;
+    JobProfiler profile_me(this, jobsParam, JobProfiler::task_threshold());
+    if (jobsParam.timed_out_of_job_generation())
+        return false;
+
+    // Calling Submittable::resolveDependencies(jobsParam) up front can be expensive.
+    // Due to trigger and complete evaluations. Hence low cost state checks first
+
+    // Do state checking for tasks only. Note: container nodes inherit the most significant state
+    // from the children, hence we can't use the same same algorithm for containers nodes and leaf
+    // nodes like task.
+    NState::State task_state = state();
+    if (task_state == NState::COMPLETE || task_state == NState::ACTIVE || task_state == NState::SUBMITTED ||
+        task_state == NState::UNKNOWN) {
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG,
+            "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state " << NState::toString(state())
+                                              << " is not valid for job submission");
+#endif
+        return false;
+    }
+    else if (task_state == NState::ABORTED) {
+
+        /// If we have been forcibly aborted by the user. Do not resubmit jobs, until *begin* or *re-queue*. ECFLOW-344
+        if (get_flag().is_set(ecf::Flag::FORCE_ABORT)) {
+#ifdef DEBUG_DEPENDENCIES
+            LOG(Log::DBG,
+                "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state "
+                                                  << NState::toString(state()) << " has been forcibly aborted.");
+#endif
+            return false;
+        }
+
+        /// If we have been killed by the user. Do not resubmit jobs, until *begin* or *re-queue*
+        if (get_flag().is_set(ecf::Flag::KILLED)) {
+#ifdef DEBUG_DEPENDENCIES
+            LOG(Log::DBG,
+                "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state "
+                                                  << NState::toString(state()) << " has been killed.");
+#endif
+            return false;
+        }
+
+        // Job cmd failed. Do not resubmit jobs, until *begin* or *re-queue*. ECFLOW-1216
+        if (get_flag().is_set(ecf::Flag::EDIT_FAILED)) {
+            return false; // pre-processing, variable subs, create directory, change job file permission failed
+        }
+        if (get_flag().is_set(ecf::Flag::NO_SCRIPT)) {
+            return false; // .ecf file location failed
+        }
+        if (get_flag().is_set(ecf::Flag::JOBCMD_FAILED)) {
+            return false; // Process exited with non-zero exit.
+                          // *OR* Job submission failed.
+        }
+
+        // If the task was aborted, and we have not exceeded ECF_TRIES, then resubmit
+        // otherwise ONLY in state QUEUED can we submit jobs
+        std::string varValue;
+        if (findParentUserVariableValue(Str::ECF_TRIES(), varValue)) {
+            // std::cout << "tryNo_ = " << tryNo_ << " ECF_TRIES = " <<  varValue << "\n";
+            try {
+                auto ecf_tries = ecf::convert_to<int>(varValue);
+                if (try_no() >= ecf_tries) {
+#ifdef DEBUG_DEPENDENCIES
+                    LOG(Log::DBG,
+                        "   Task::resolveDependencies() " << absNodePath() << " HOLDING as tryNo_("
+                                                          << tryNo_ ") >= ECF_TRIES(" << ecf_tries
+                                                          << ") state = " << NState::toString(state()));
+#endif
+                    return false;
+                }
+            }
+            catch (const ecf::bad_conversion&) {
+                LOG(Log::ERR,
+                    "Variable ECF_TRIES must be convertible to an integer. Cannot resubmit job for task:"
+                        << absNodePath());
+                return false;
+            }
+        }
+    }
+#ifdef DEBUG
+    else {
+        /// Only one state left
+        assert(task_state == NState::QUEUED);
+    }
+#endif
+
+    /// If we have been forcibly aborted by the user. Do not resubmit jobs, until *begin* or *re-queue*
+    /// ***** This can be set via ALTER, so independent of state ***********
+    if (get_flag().is_set(ecf::Flag::FORCE_ABORT)) {
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG,
+            "   Task::resolveDependencies() " << absNodePath() << " HOLDING as task state " << NState::toString(state())
+                                              << " has been forcibly aborted.");
+#endif
+        return false;
+    }
+
+    // Improve the granularity for the check for lateness (during job submission). See SUP-873 "late" functionality
+    // Does not deal with inherited late
+    if (get_late()) {
+        // since the suite() traverse up the tree, only call when have a late attribute
+        checkForLateness(suite()->calendar());
+    }
+
+    if (!Node::resolveDependencies(jobsParam)) {
+
+#ifdef DEBUG_JOB_SUBMISSION
+        LOG(Log::DBG,
+            "   Task::resolveDependencies " << absNodePath() << " could not resolve dependencies, may have completed");
+        cout << "Task::resolveDependencies " << absNodePath() << " could not resolve dependencies may have completed"
+             << endl;
+#endif
+        return false;
+    }
+
+    /// By default node tree traversal is top down. hence we only check in limits, at *that* level.
+    /// However *EACH* job submission can *affect* the in limits, hence we *must* check we are in
+    /// limit *up* the node tree. Done last and only in this function (as opposed to Node) as an optimisation
+    if (!check_in_limit_up_node_tree()) {
+#ifdef DEBUG_DEPENDENCIES
+        LOG(Log::DBG, "   Task::resolveDependencies() " << absNodePath() << " FREE of TRIGGER and inLIMIT");
+#endif
+        return false;
+    }
+
+    // call just before job submission, reset data members, update try_no, and generate variable
+    // *PLACED* outside of submitJob() so that we can configure job generation file ECF_JOB for test/python
+    increment_try_no(); // will increment state_change_no
+
+    if (jobsParam.createJobs()) {
+        // The task are ready for job submission.Clear process id and remote id (ECF_RID)
+        // Locate the ecf files corresponding to the task. Pre-process
+        // them(i.e expand includes, remove comments,manual) and perform
+        // variable substitution. This will then form the jobs file.
+        // If the job file already exist it is overridden
+        submit_job_only(jobsParam);
+    }
+    else {
+        // *************************************************************************************
+        // Debug/test path only... Enabled for testing when we don't want to create/spawn jobs
+        // ** Simulate ** job submission as closely as possible. For testing
+        // *************************************************************************************
+        jobsParam.push_back_submittable(this);
+
+        // follow normal life cycle queued->submitted->active. In real life there may be a noticeable
+        // time delay between process creation (via a user command, which could do anything)
+        // and when created process start talking back to the server.
+        // *** Setting state to SUBMITTED will increment any inlimit/Limit via handleStateChange
+        set_state(NState::SUBMITTED);
+
+        // The spawned process will typically call this, via client api. Set task into active state
+        // *** Test path, we take the hit of calling handleStateChange again.
+        init(Submittable::DUMMY_PROCESS_OR_REMOTE_ID());
+    }
+    return true;
+}
+
+void Task::generate_scripts(const std::map<std::string, std::string>& override) const {
+    TaskScriptGenerator ecf(this);
+    ecf.generate(override);
+}
+
+node_ptr Task::removeChild(Node* child) {
+#ifdef DEBUG
+    assert(child);
+    assert(child->isAlias());
+#endif
+    SuiteChanged1 changed(suite());
+    size_t node_vec_size = aliases_.size();
+    for (size_t t = 0; t < node_vec_size; t++) {
+        if (aliases_[t].get() == child) {
+            child->set_parent(nullptr);
+            node_ptr node = std::dynamic_pointer_cast<Alias>(aliases_[t]);
+            aliases_.erase(aliases_.begin() + t);
+            add_remove_state_change_no_ = Ecf::incr_state_change_no();
+            return node;
+        }
+    }
+    // Should never happen
+    LOG_ASSERT(false, "Task::removeChild: Could not remove child");
+    return node_ptr();
+}
+
+bool Task::doDeleteChild(Node* child) {
+    SuiteChanged1 changed(suite());
+    auto the_end = aliases_.end();
+    for (auto t = aliases_.begin(); t != the_end; ++t) {
+        if ((*t).get() == child) {
+            if (child && child->parent())
+                child->set_parent(nullptr);
+            aliases_.erase(t);
+            add_remove_state_change_no_ = Ecf::incr_state_change_no();
+            return true;
+        }
+    }
+    return false;
+}
+
+bool Task::addChild(const node_ptr&, size_t) {
+    // Only used during PLUG: aliases can't be plugged.
+    LOG_ASSERT(false, "");
+    return false;
+}
+
+bool Task::isAddChildOk(Node*, std::string& errorMsg) const {
+    // Only used during PLUG: aliases can't be plugged.
+    errorMsg += "Cannot add children to a task node.";
+    return false;
+}
+
+size_t Task::child_position(const Node* child) const {
+    size_t vec_size = aliases_.size();
+    for (size_t t = 0; t < vec_size; t++) {
+        if (aliases_[t].get() == child) {
+            return t;
+        }
+    }
+    return std::numeric_limits<std::size_t>::max();
+}
+
+void Task::order(Node* immediateChild, NOrder::Order ord) {
+    SuiteChanged1 changed(suite());
+    switch (ord) {
+        case NOrder::TOP: {
+            for (auto i = aliases_.begin(); i != aliases_.end(); ++i) {
+                if ((*i).get() == immediateChild) {
+                    alias_ptr node = (*i);
+                    aliases_.erase(i);
+                    aliases_.insert(aliases_.begin(), node);
+                    order_state_change_no_ = Ecf::incr_state_change_no();
+                    return;
+                }
+            }
+            throw std::runtime_error("Task::order TOP, immediate child not found");
+        }
+        case NOrder::BOTTOM: {
+            for (auto i = aliases_.begin(); i != aliases_.end(); ++i) {
+                if ((*i).get() == immediateChild) {
+                    alias_ptr node = (*i);
+                    aliases_.erase(i);
+                    aliases_.push_back(node);
+                    order_state_change_no_ = Ecf::incr_state_change_no();
+                    return;
+                }
+            }
+            throw std::runtime_error("Task::order BOTTOM, immediate child not found");
+        }
+        case NOrder::ALPHA: {
+            std::sort(aliases_.begin(), aliases_.end(), [](const alias_ptr& a, const alias_ptr& b) {
+                return Str::caseInsLess(a->name(), b->name());
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            break;
+        }
+        case NOrder::ORDER: {
+            std::sort(aliases_.begin(), aliases_.end(), [](const alias_ptr& a, const alias_ptr& b) {
+                return Str::caseInsGreater(a->name(), b->name());
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            break;
+        }
+        case NOrder::UP: {
+            for (size_t t = 0; t < aliases_.size(); t++) {
+                if (aliases_[t].get() == immediateChild) {
+                    if (t != 0) {
+                        alias_ptr node = aliases_[t];
+                        aliases_.erase(aliases_.begin() + t);
+                        t--;
+                        aliases_.insert(aliases_.begin() + t, node);
+                        order_state_change_no_ = Ecf::incr_state_change_no();
+                    }
+                    return;
+                }
+            }
+            throw std::runtime_error("Task::order UP, immediate child not found");
+        }
+        case NOrder::DOWN: {
+            for (size_t t = 0; t < aliases_.size(); t++) {
+                if (aliases_[t].get() == immediateChild) {
+                    if (t != aliases_.size() - 1) {
+                        alias_ptr node = aliases_[t];
+                        aliases_.erase(aliases_.begin() + t);
+                        t++;
+                        aliases_.insert(aliases_.begin() + t, node);
+                        order_state_change_no_ = Ecf::incr_state_change_no();
+                    }
+                    return;
+                }
+            }
+            throw std::runtime_error("Task::order DOWN, immediate child not found");
+        }
+        case NOrder::RUNTIME: {
+            for (alias_ptr alias : aliases_) {
+                if (alias->state() != NState::COMPLETE) {
+                    throw std::runtime_error("Task::order: To order by RUNTIME All aliases must be complete");
+                }
+            }
+            (void)sum_runtime();
+            std::sort(aliases_.begin(), aliases_.end(), [](const alias_ptr& a, const alias_ptr& b) {
+                return a->state_change_runtime() > b->state_change_runtime();
+            });
+            order_state_change_no_ = Ecf::incr_state_change_no();
+            break;
+        }
+    }
+}
+
+void Task::move_peer(Node* src, Node* dest) {
+    move_peer_node(aliases_, src, dest, "Task");
+    order_state_change_no_ = Ecf::incr_state_change_no();
+}
+
+bool Task::checkInvariants(std::string& errorMsg) const {
+    if (!Node::checkInvariants(errorMsg))
+        return false;
+
+    size_t vec_size = aliases_.size();
+    for (size_t t = 0; t < vec_size; t++) {
+        if (aliases_[t]->parent() != this) {
+            std::stringstream ss;
+            ss << "Task::checkInvariants alias(" << aliases_[t]->name()
+               << ") parent() not correct. See task : " << absNodePath();
+            errorMsg += ss.str();
+            return false;
+        }
+        if (!aliases_[t]->checkInvariants(errorMsg)) {
+            return false;
+        }
+    }
+    //   if ( vec_size > alias_no_ ) {
+    //      std::stringstream ss;
+    //      ss << "Task::checkInvariants: alias vector size " << vec_size << " should be less or equal to alias_no_ " <<
+    //      alias_no_ << " for task " << absNodePath() << "\n"; errorMsg += ss.str(); return false;
+    //   }
+    return true;
+}
+
+void Task::handleStateChange() {
+    /// Increment/decrement limits based on the current state
+    update_limits();
+
+    // Check if a re queue is required, then can eventually change the state, if
+    // repeats, time,today, or cron are involved, hence must be done last
+    // This will recurse up the node tree, causing repeats to increment, at the parent
+    // level and resetting repeats in the children. To mimic nested loops.
+    requeueOrSetMostSignificantStateUpNodeTree();
+
+    Node::handleStateChange(); // may do a autorestore, if state is COMPLETE
+}
+
+const std::string& Task::script_extension() const {
+    // Migration support, allow user to specify extension. This allows users to use '.sms'
+    // Note: This should be removed in the future since there is performance hit.
+    //       searching up the node tree, when most of the time we are using .ecf
+    const std::string& ecf_extn = find_parent_user_variable_value(Str::ECF_EXTN());
+    if (!ecf_extn.empty())
+        return ecf_extn;
+    return File::ECF_EXTN(); // ".ecf"
+}
+
+void Task::collateChanges(DefsDelta& changes) const {
+    //   std::cout << "Task::collateChanges " << debugNodePath()
+    //             << " changes.client_state_change_no() = " << changes.client_state_change_no()
+    //             << " add_remove_state_change_no_ = " << add_remove_state_change_no_
+    //             << " order_state_change_no_ = " << order_state_change_no_
+    //             << " alias_change_no_ " << alias_change_no_
+    //             << "\n";
+
+    /// All changes to Task should be on ONE compound_memento_ptr
+    compound_memento_ptr comp;
+
+    /// There no point doing a OrderMemento if children have been added/delete
+    if (add_remove_state_change_no_ > changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<AliasChildrenMemento>(aliases_));
+    }
+    else if (order_state_change_no_ > changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        std::vector<std::string> order_vec;
+        order_vec.reserve(aliases_.size());
+        size_t node_vec_size = aliases_.size();
+        for (size_t i = 0; i < node_vec_size; i++)
+            order_vec.push_back(aliases_[i]->name());
+        comp->add(std::make_shared<OrderMemento>(order_vec));
+    }
+
+    if (alias_change_no_ > changes.client_state_change_no()) {
+        if (!comp.get())
+            comp = std::make_shared<CompoundMemento>(absNodePath());
+        comp->add(std::make_shared<AliasNumberMemento>(alias_no_));
+    }
+
+    // ** base class will add compound memento into changes.
+    Submittable::incremental_changes(changes, comp);
+
+    // Traversal to children
+    size_t vec_size = aliases_.size();
+    for (size_t t = 0; t < vec_size; t++) {
+        aliases_[t]->collateChanges(changes);
+    }
+}
+
+void Task::set_memento(const OrderMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Task::set_memento( const OrderMemento* ) " << debugNodePath() << "\n";
+#endif
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::ORDER);
+        return;
+    }
+
+    // Order aliases_ according to memento ordering
+    const std::vector<std::string>& order = memento->order_;
+    if (order.size() != aliases_.size()) {
+        // something gone wrong.
+        std::cout << "Task::set_memento OrderMemento, memento.size() " << order.size()
+                  << " Not the same as aliases_size() " << aliases_.size() << "\n";
+        return;
+    }
+
+    std::vector<alias_ptr> vec;
+    vec.reserve(aliases_.size());
+    size_t node_vec_size = aliases_.size();
+    for (const auto& i : order) {
+        for (size_t t = 0; t < node_vec_size; t++) {
+            if (i == aliases_[t]->name()) {
+                vec.push_back(aliases_[t]);
+                break;
+            }
+        }
+    }
+    if (vec.size() != aliases_.size()) {
+        std::cout << "Task::set_memento(const OrderMemento* memento) could not find all the names\n";
+        return;
+    }
+
+    aliases_ = vec;
+}
+
+void Task::set_memento(const AliasChildrenMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Task::set_memento( const AliasChildrenMemento* ) " << debugNodePath() << "\n";
+#endif
+
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::ADD_REMOVE_NODE);
+        return;
+    }
+
+    // set up alias parent pointers. since they are *NOT* serialised.
+    aliases_        = memento->children_;
+    size_t vec_size = aliases_.size();
+    for (size_t i = 0; i < vec_size; i++) {
+        aliases_[i]->set_parent(this);
+    }
+}
+
+void Task::set_memento(const AliasNumberMemento* memento, std::vector<ecf::Aspect::Type>& aspects, bool aspect_only) {
+#ifdef DEBUG_MEMENTO
+    std::cout << "Task::set_memento( const AliasNumberMemento* ) " << debugNodePath() << "\n";
+#endif
+    if (aspect_only) {
+        aspects.push_back(ecf::Aspect::ALIAS_NUMBER);
+        return;
+    }
+
+    alias_no_ = memento->alias_no_;
+}
+
+template <class Archive>
+void Task::serialize(Archive& ar, std::uint32_t const version) {
+    ar(cereal::base_class<Submittable>(this));
+    CEREAL_OPTIONAL_NVP(ar, alias_no_, [this]() { return alias_no_ != 0; });   // conditionally save
+    CEREAL_OPTIONAL_NVP(ar, aliases_, [this]() { return !aliases_.empty(); }); // conditionally save
+
+    // Setup the alias parent pointers. Since they are not serialised
+    // ********************************************************************
+    // WE do not serialise the Alias parent pointer:
+    // WHY: AliasChildrenMenento saves a vector of aliases, had we serialised
+    //      the parent, it would also serialise the parent pointer(Task)
+    //      i.e the ENTIRE task, and then Task parent, and so on, up the parent hierarchy.
+    //      In our case it lead to unregistered class exception when trying to
+    //      serialise the Task's parent.
+    // SOLN: WE will not serialise the alias parent pointer. This will be left to
+    //       Parent task.
+    // ********************************************************************
+    if (Archive::is_loading::value) {
+        size_t vec_size = aliases_.size();
+        for (size_t i = 0; i < vec_size; i++) {
+            aliases_[i]->set_parent(this);
+        }
+    }
+}
+
+CEREAL_TEMPLATE_SPECIALIZE_V(Task);
+CEREAL_REGISTER_TYPE(Task)
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/Task.hpp 5.13.0-1/libs/node/src/ecflow/node/Task.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/Task.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/Task.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,152 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_Task_HPP
+#define ecflow_node_Task_HPP
+
+#include "ecflow/node/Submittable.hpp"
+
+class Task final : public Submittable {
+public:
+    explicit Task(const std::string& name, bool check = true) : Submittable(name, check) {}
+    Task() = default;
+    Task(const Task& rhs);
+    Task& operator=(const Task&);
+    node_ptr clone() const override;
+    ~Task() override;
+
+    bool check_defaults() const override;
+
+    static task_ptr create(const std::string& name, bool check = true);
+    static task_ptr create_me(const std::string& name); // python api, to pick correct init function
+
+    void print(std::string&) const override;
+    bool operator==(const Task& rhs) const;
+
+    /// Add an alias. The .usr is populated with contents of user_file_contents
+    /// If create_directory is unset we create the alias with creating directory or .usr file
+    alias_ptr add_alias(std::vector<std::string>& user_file_contents,
+                        const NameValueVec& user_variables,
+                        bool create_directory = true);
+
+    /// Add alias without creating directory & user file
+    alias_ptr add_alias_only();
+
+    /// For Addition of alias via Defs Files
+    alias_ptr add_alias(const std::string& name);
+
+    /// Given a name find the alias.
+    alias_ptr find_alias(const std::string& name) const;
+
+    /// Reset alias number. Used in testing
+    void reset_alias_number();
+
+    /// return list of aliases held by this task
+    const std::vector<alias_ptr>& aliases() { return aliases_; }
+    void immediateChildren(std::vector<node_ptr>&) const override;
+
+    /// Overidden from Submittable
+    const std::string& script_extension() const override;
+
+    node_ptr find_node_up_the_tree(const std::string& name) const override;
+
+    std::string find_node_path(const std::string& type, const std::string& name) const override;
+
+    /// Added for consistency, really used to find relative nodes, aliases should never, be in referenced nodes
+    node_ptr find_relative_node(const std::vector<std::string>& pathToNode) override { return node_ptr(); }
+
+    /// Overridden to reset the try number
+    /// The tasks job can be invoked multiple times. For each invocation we want to preserve
+    /// the output. The try number is used in SMSJOB/SMSJOBOUT to preserve the output when
+    /// there are multiple runs.  re-queue/begin() resets the try Number
+    void reset() override;
+    void begin() override;
+    void requeue(Requeue_args&) override;
+
+    Suite* suite() const override { return parent()->suite(); }
+    Defs* defs() const override {
+        return (parent()) ? parent()->defs() : nullptr;
+    } // exposed to python hence check for NULL first
+    Task* isTask() const override { return const_cast<Task*>(this); }
+    Submittable* isSubmittable() const override { return const_cast<Task*>(this); }
+
+    void accept(ecf::NodeTreeVisitor&) override;
+    void acceptVisitTraversor(ecf::NodeTreeVisitor& v) override;
+
+    void getAllNodes(std::vector<Node*>&) const override;
+    void getAllTasks(std::vector<Task*>&) const override;
+    void getAllSubmittables(std::vector<Submittable*>&) const override;
+    void get_all_active_submittables(std::vector<Submittable*>&) const override;
+    void get_all_tasks(std::vector<task_ptr>&) const override;
+    void get_all_nodes(std::vector<node_ptr>&) const override;
+    void get_all_aliases(std::vector<alias_ptr>&) const override;
+
+    const std::string& debugType() const override;
+
+    /// submits the jobs of the dependencies resolve
+    bool resolveDependencies(JobsParam& jobsParam) override;
+
+    node_ptr removeChild(Node* child) override;
+    bool addChild(const node_ptr& child, size_t position = std::numeric_limits<std::size_t>::max()) override;
+    bool isAddChildOk(Node* child, std::string& errorMsg) const override;
+
+    void order(Node* immediateChild, NOrder::Order) override;
+    void move_peer(Node* src, Node* dest) override;
+
+    void generate_scripts(const std::map<std::string, std::string>& override) const override;
+
+    bool checkInvariants(std::string& errorMsg) const override;
+
+    void collateChanges(DefsDelta&) const override;
+    void set_memento(const OrderMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool);
+    void set_memento(const AliasChildrenMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool);
+    void set_memento(const AliasNumberMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool);
+    void set_memento(const SubmittableMemento* m, std::vector<ecf::Aspect::Type>& aspects, bool f) {
+        Submittable::set_memento(m, aspects, f);
+    }
+
+    void read_state(const std::string& line, const std::vector<std::string>& lineTokens) override;
+
+private:
+    void copy(const Task&);
+    size_t child_position(const Node*) const override;
+    void write_state(std::string&, bool&) const override;
+
+private:
+    /// For use by python interface,
+    std::vector<alias_ptr>::const_iterator alias_begin() const { return aliases_.begin(); }
+    std::vector<alias_ptr>::const_iterator alias_end() const { return aliases_.end(); }
+    friend void export_Task();
+
+private:
+    // Overridden from Node to increment/decrement limits
+    void handleStateChange() override;
+    bool doDeleteChild(Node* child) override;
+
+    // Overridden to locate alias's
+    node_ptr findImmediateChild(const std::string& name, size_t& child_pos) const override;
+    node_ptr find_immediate_child(const std::string_view&) const override;
+
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version);
+
+private:
+    unsigned int order_state_change_no_{0};      // no need to persist
+    unsigned int add_remove_state_change_no_{0}; // no need to persist
+
+    unsigned int alias_change_no_{0}; // no need to persist, for alias number only
+    unsigned int alias_no_{0};
+    std::vector<alias_ptr> aliases_;
+};
+
+std::ostream& operator<<(std::ostream& os, const Task&);
+
+#endif /* ecflow_node_Task_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/TaskScriptGenerator.cpp 5.13.0-1/libs/node/src/ecflow/node/TaskScriptGenerator.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/TaskScriptGenerator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/TaskScriptGenerator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,328 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/TaskScriptGenerator.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace boost;
+
+namespace ecf {
+
+TaskScriptGenerator::TaskScriptGenerator(const Task* task) : task_(task), is_dummy_task_(false) {
+    /// if ECF_DUMMY_TASK specified ignore
+    std::string theValue;
+    is_dummy_task_ = task_->findParentUserVariableValue(Str::ECF_DUMMY_TASK(), theValue);
+    if (is_dummy_task_)
+        return;
+
+    /// if ECF_FILES specified use this before ECF_HOME
+    if (task_->findParentUserVariableValue(Str::ECF_FILES(), ecf_files_)) {
+        // Create any missing directories if ECF_FILES is specified
+        try {
+            fs::create_directories(ecf_files_);
+        }
+        catch (std::exception& e) {
+            std::stringstream ss;
+            ss << "TaskScriptGenerator: Could not create directories for ECF_FILES " << ecf_files_ << " " << e.what();
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    /// Find ECF_HOME and ECF_INCLUDE
+    if (!task_->findParentUserVariableValue(Str::ECF_HOME(), ecf_home_)) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator: Could not generate scripts for task " << task_->absNodePath()
+           << " no ECF_HOME specified\n";
+        throw std::runtime_error(ss.str());
+    }
+    if (!task_->findParentUserVariableValue(Str::ECF_INCLUDE(), ecf_include_)) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator: Could not generate scripts for task " << task_->absNodePath()
+           << " no ECF_INCLUDE specified\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // Create any missing directories,
+    try {
+        fs::create_directories(ecf_home_);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator: Could not create directories for ECF_HOME " << ecf_home_ << " " << e.what();
+        throw std::runtime_error(ss.str());
+    }
+
+    try {
+        fs::create_directories(ecf_include_);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator: Could not create directories for ECF_INCLUDE " << ecf_include_ << " " << e.what();
+        throw std::runtime_error(ss.str());
+    }
+}
+
+void TaskScriptGenerator::generate(const std::map<std::string, std::string>& override) {
+    // Ignore generation for dummy tasks
+    if (is_dummy_task_)
+        return;
+
+    // If ECF_FILES was specified use that in preference to ECF_HOME for the ecf files.
+    std::string root_directory_for_ecf_files;
+    if (!ecf_files_.empty())
+        root_directory_for_ecf_files = ecf_files_;
+    else
+        root_directory_for_ecf_files = ecf_home_;
+
+    // Note: task_->absNodePath() starts with /.
+    std::string ecf_file_path = root_directory_for_ecf_files + task_->absNodePath() + task_->script_extension();
+    if (fs::exists(ecf_file_path)) {
+        std::cout << "Cannot generate. Script file " << ecf_file_path << " already exists\n";
+        return;
+    }
+
+    if (!File::createMissingDirectories(ecf_file_path)) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator::generate: Could not create missing directories '" << ecf_file_path << "' for task "
+           << task_->absNodePath();
+        throw std::runtime_error(ss.str());
+    }
+
+    // Create file head.h and tail.h in directory ECF_INCLUDE, check to see if they exist first
+    // If the variable ECF_CLIENT_EXE_PATH is specified use it
+    generate_head_file();
+    generate_tail_file();
+
+    // Create ECF file with default template or custom  file.
+    // cout << "creating ecf file  " << ecf_file_path << "\n";
+    std::string contents;
+    auto it = override.find(task_->absNodePath());
+    if (it == override.end()) {
+        contents = getDefaultTemplateEcfFile();
+    }
+    else {
+        contents = (*it).second;
+    }
+
+    std::string errorMsg;
+    if (!File::create(ecf_file_path, contents, errorMsg)) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator::generate: Could not create '.ecf' script for task " << task_->absNodePath() << " "
+           << errorMsg;
+        throw std::runtime_error(ss.str());
+    }
+    std::cout << "Generated script file " << ecf_file_path << "\n";
+}
+
+static void add_queue(std::string& content, const std::string& client_exe, const std::string& sleep, const Node* node) {
+    const std::vector<QueueAttr>& queues = node->queues();
+    for (const QueueAttr& queue : queues) {
+        content += "\n";
+        content += "for i in";
+        const std::vector<std::string>& queue_list = queue.list();
+        for (const auto& i : queue_list) {
+            content += " ";
+            content += i;
+        }
+        content += "\n";
+        content += "do\n";
+        content += "   step=$(" + client_exe + "--queue=" + queue.name() + " active " + node->absNodePath() + " )\n";
+        content += "   echo $step\n";
+        content += "   " + sleep;
+        content += "   " + client_exe + "--queue=" + queue.name() + " complete $step " + node->absNodePath() + "\n";
+        content += "done\n";
+    }
+}
+
+std::string TaskScriptGenerator::getDefaultTemplateEcfFile() const {
+    std::string content;
+
+    std::string sleep, var_sleep;
+    if (task_->findParentUserVariableValue("SLEEP", var_sleep))
+        sleep = "sleep %SLEEP%\n";
+    else
+        sleep = "sleep 1\n";
+
+    std::string client_exe = "%ECF_CLIENT_EXE_PATH:";
+    client_exe += Ecf::CLIENT_NAME();
+    client_exe += "% ";
+
+    content += "%include <head.h>\n";
+    content += "%manual\n";
+    content += "This is the default **generated** ecf script file\n";
+    content += "If the task has events, meters or labels then the associated client\n";
+    content += "to server commands are automatically generated.\n";
+    content += "Will default to sleep for one second in between calls to the events, meters & labels,\n";
+    content += "this can be overridden by adding a variable SLEEP\n";
+    content += "%end\n";
+    content += "\n";
+    content += "%comment\n";
+    content += "#============================================================\n";
+    content += "# Using angle brackets means we look in directory ECF_INCLUDE\n";
+    content += "# and then ECF_HOME\n";
+    content += "#============================================================\n";
+    content += "%end\n";
+    content += "\n";
+    content += "echo do some work\n";
+    for (const Event& e : task_->events()) {
+        if (e.initial_value())
+            content += client_exe + "--event=" + e.name_or_number() + " clear\n";
+        else
+            content += client_exe + "--event=" + e.name_or_number() + "\n"; // same as set
+        content += sleep;
+    }
+
+    content += "\n";
+    for (const Meter& m : task_->meters()) {
+        content += "for i in";
+        for (int i = m.min(); i <= m.max(); i = i + 1) {
+            content += " ";
+            content += ecf::convert_to<std::string>(i);
+        }
+        content += "\n";
+        content += "do\n";
+        content += "   " + client_exe + "--meter=" + m.name() + " $i\n";
+        content += "   " + sleep;
+        content += "done\n";
+    }
+    content += "\n";
+
+    /// labels require at least 2 arguments,
+    for (const Label& label : task_->labels()) {
+
+        if (!label.new_value().empty()) {
+            content += client_exe + "--label=" + label.name() + " " + label.new_value() + "\n";
+        }
+        else if (!label.value().empty()) {
+            content += client_exe + "--label=" + label.name() + " " + label.value() + "\n";
+        }
+        content += sleep;
+    }
+
+    /// Queues
+    add_queue(content, client_exe, sleep, task_);
+    Node* parent = task_->parent();
+    while (parent) {
+        add_queue(content, client_exe, sleep, parent);
+        parent = parent->parent();
+    }
+
+    content += "\n";
+    if (task_->events().empty() && task_->meters().empty() && task_->queues().empty()) {
+        content += sleep;
+    }
+    content += "\necho end of job\n";
+    content += "\n%include <tail.h>\n";
+    return content;
+}
+
+void TaskScriptGenerator::generate_head_file() const {
+    std::string path = ecf_include_ + "/head.h";
+    if (fs::exists(path)) {
+        std::cout << "Skipping generation of head file: " << path << " as it already exists\n";
+        return;
+    }
+
+    std::string client_exe = "%ECF_CLIENT_EXE_PATH:";
+    client_exe += Ecf::CLIENT_NAME();
+    client_exe += "% ";
+
+    std::string contents;
+    contents += "#!/usr/bin/env bash\n";
+    contents += "set -e          # stop the shell on first error X\n";
+    contents += "set -u          # fail when using an undefined variable\n";
+    contents += "set -o pipefail # fail if last(rightmost) command exits with a non-zero status\n";
+    contents += "set -x          # echo script lines as they are executed\n";
+    contents += "\n";
+    contents += "# Defines the variables that are needed for any communication with ECF\n";
+    contents += "export ECF_PORT=%ECF_PORT%    # The server port number\n";
+    contents += "export ECF_HOST=%ECF_HOST%    # The name of ecf host that issued this task\n";
+    contents += "export ECF_NAME=%ECF_NAME%    # The name of this current task\n";
+    contents += "export ECF_PASS=%ECF_PASS%    # A unique password\n";
+    contents += "export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task\n";
+    contents += "export ECF_RID=$$\n";
+    contents += "export ECF_TIMEOUT=300 # Only wait 5 minutes, if the server cannot be contacted (note default is 24 "
+                "hours) before failing\n";
+    contents += "if [[ \"%ECF_SSL:%\" != \"\" ]] ; then\n";
+    contents += "   export ECF_SSL=%ECF_SSL:%\n";
+    contents += "fi\n";
+    contents += "#export ECF_DEBUG_CLIENT=1\n";
+    contents += "\n";
+    contents +=
+        "# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address\n";
+    contents += "os_name=$(uname -s)\n";
+    contents += "if [[ $os_name = Linux ]] ; then\n";
+    contents += "   ping -c 1 %ECF_HOST%\n";
+    contents += "fi\n";
+    contents += "\n";
+    contents += "# Tell ecFlow we have started\n";
+    contents += client_exe + "--init=$$\n";
+    contents += "\n";
+    contents += "# Defined a error handler\n";
+    contents += "ERROR() {\n";
+    contents += "   echo 'ERROR() called'\n";
+    contents += "   set +e                      # Clear -e flag, so we don't fail\n";
+    contents += "   wait                        # wait for background process to stop\n";
+    contents +=
+        "   " + client_exe + "--abort=trap   # Notify ecFlow that something went wrong, using 'trap' as the reason\n";
+    contents += "   trap 0                      # Remove the trap\n";
+    contents += "   exit 0                      # End the script\n";
+    contents += "}\n";
+    contents += "\n";
+    contents += "# Trap any calls to exit and errors caught by the -e flag\n";
+    contents += "trap ERROR 0\n";
+    contents += "\n";
+    contents += "# Trap any signal that may cause the script to fail\n";
+    contents += "trap '{ echo \"Killed by a signal\"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15\n";
+
+    std::string errorMsg;
+    if (!File::create(path, contents, errorMsg)) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator::generate_tail_file: Could not create head.h " << path << " " << errorMsg;
+        throw std::runtime_error(ss.str());
+    }
+
+    std::cout << "Generated header file: " << path << "\n";
+}
+
+void TaskScriptGenerator::generate_tail_file() const {
+    std::string path = ecf_include_ + "/tail.h";
+    if (fs::exists(path)) {
+        std::cout << "Skipping generation of tail file: " << path << " as it already exists\n";
+        return;
+    }
+
+    std::string contents = "%ECF_CLIENT_EXE_PATH:";
+    contents += Ecf::CLIENT_NAME();
+    contents += "% --complete    # Notify ecFlow of a normal end\n";
+
+    contents += "trap 0                 # Remove all traps\n";
+    contents += "exit 0                 # End the shell\n";
+
+    std::string errorMsg;
+    if (!File::create(path, contents, errorMsg)) {
+        std::stringstream ss;
+        ss << "TaskScriptGenerator::generate_tail_file: Could not create tail.h " << path << " " << errorMsg;
+        throw std::runtime_error(ss.str());
+    }
+
+    std::cout << "Generated tail file: " << path << "\n";
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/TaskScriptGenerator.hpp 5.13.0-1/libs/node/src/ecflow/node/TaskScriptGenerator.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/TaskScriptGenerator.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/TaskScriptGenerator.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_TaskScriptGenerator_HPP
+#define ecflow_node_TaskScriptGenerator_HPP
+
+#include <map>
+#include <string>
+class Task;
+
+namespace ecf {
+
+class TaskScriptGenerator {
+public:
+    explicit TaskScriptGenerator(const Task*);
+
+    // Disable copy (and move) semantics
+    TaskScriptGenerator(const TaskScriptGenerator&)                  = delete;
+    const TaskScriptGenerator& operator=(const TaskScriptGenerator&) = delete;
+
+    void generate(const std::map<std::string, std::string>& override);
+
+private:
+    void generate_head_file() const;
+    void generate_tail_file() const;
+    std::string getDefaultTemplateEcfFile() const;
+
+private:
+    const Task* task_;
+    bool is_dummy_task_;
+    std::string ecf_files_;
+    std::string ecf_home_;
+    std::string ecf_include_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_node_TaskScriptGenerator_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/formatter/AvisoFormatter.hpp 5.13.0-1/libs/node/src/ecflow/node/formatter/AvisoFormatter.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/formatter/AvisoFormatter.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/formatter/AvisoFormatter.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,52 @@
+
+#ifndef ecflow_node_formatter_AvisoFormatter_hpp
+#define ecflow_node_formatter_AvisoFormatter_hpp
+
+#include "ecflow/node/formatter/Formatter.hpp"
+
+namespace ecf {
+namespace implementation {
+
+template <typename Stream>
+struct Formatter<AvisoAttr, Stream>
+{
+    static void format(const std::vector<AvisoAttr>& items, Stream& output) { format_vector_as_defs(items, output); }
+
+    static void format(const AvisoAttr& item, Stream& output) {
+        ecf::Indentor in;
+        ecf::Indentor::indent(output);
+        output << "aviso";
+        output << " --name ";
+        output << item.name();
+        output << " --listener ";
+        output << item.listener();
+        if (const auto& url = item.url(); !url.empty() && url != AvisoAttr::default_url) {
+            output << " --url ";
+            output << item.url();
+        }
+        if (const auto& schema = item.schema(); !schema.empty() && schema != AvisoAttr::default_schema) {
+            output << " --schema ";
+            output << item.schema();
+        }
+        if (const auto& polling = item.polling(); !polling.empty() && polling != AvisoAttr::default_polling) {
+            output << " --polling ";
+            output << item.polling();
+        }
+        output << " --revision ";
+        output << std::to_string(item.revision());
+        if (const auto& auth = item.auth(); !auth.empty() && auth != AvisoAttr::default_auth) {
+            output << " --auth ";
+            output << item.auth();
+        }
+        if (const auto& reason = item.reason(); !reason.empty()) {
+            output << " --reason ";
+            output << item.reason();
+        }
+        output << '\n';
+    }
+};
+
+} // namespace implementation
+} // namespace ecf
+
+#endif /* ecflow_node_formatter_AvisoFormatter.hpp */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/formatter/Format.hpp 5.13.0-1/libs/node/src/ecflow/node/formatter/Format.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/formatter/Format.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/formatter/Format.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,43 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_formatter_Format_HPP
+#define ecflow_node_formatter_Format_HPP
+
+#include "ecflow/node/formatter/AvisoFormatter.hpp"
+#include "ecflow/node/formatter/MirrorFormatter.hpp"
+
+namespace ecf {
+
+struct stringstreambuf
+{
+    std::string& buf;
+};
+
+template <typename S>
+inline void operator<<(stringstreambuf& sb, S&& s) {
+    sb.buf += std::forward<S>(s);
+}
+
+template <typename T>
+void format_as_defs(const T& value, std::string& buffer) {
+    buffer.reserve(1024 * 4);
+    stringstreambuf output{buffer};
+    implementation::Formatter<T, stringstreambuf>::format(value, output);
+}
+
+template <typename T, typename Stream>
+void format_as_defs(const T& value, Stream& output) {
+    implementation::Formatter<T, Stream>::format(value, output);
+}
+
+} // namespace ecf
+
+#endif /* ecflow_node_formatter_Format_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/formatter/Formatter.hpp 5.13.0-1/libs/node/src/ecflow/node/formatter/Formatter.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/formatter/Formatter.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/formatter/Formatter.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,50 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_formatter_Formatter_HPP
+#define ecflow_node_formatter_Formatter_HPP
+
+#include <string>
+#include <vector>
+
+namespace ecf {
+namespace implementation {
+
+template <typename T, typename Stream>
+struct Formatter
+{
+};
+
+namespace {
+
+/// Some utilities to be used by the formatters
+
+template <typename T, typename Stream>
+static void format_vector_as_defs(const std::vector<T>& items, Stream& output) {
+    for (const auto& item : items) {
+        Formatter<T, Stream>::format(item, output);
+    }
+}
+
+template <typename T, typename Stream>
+static void format_vector_as_defs(const std::vector<std::shared_ptr<T>>& items, Stream& output) {
+    for (const auto& item : items) {
+        if (item) {
+            Formatter<T, Stream>::format(*item, output);
+        }
+    }
+}
+
+} // namespace
+
+} // namespace implementation
+} // namespace ecf
+
+#endif /* ecflow_node_formatter_Formatter_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/formatter/MirrorFormatter.hpp 5.13.0-1/libs/node/src/ecflow/node/formatter/MirrorFormatter.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/formatter/MirrorFormatter.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/formatter/MirrorFormatter.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,53 @@
+
+#ifndef ecflow_node_formatter_MirrorFormatter_hpp
+#define ecflow_node_formatter_MirrorFormatter_hpp
+
+#include "ecflow/node/formatter/Formatter.hpp"
+
+namespace ecf {
+namespace implementation {
+
+template <typename Stream>
+struct Formatter<MirrorAttr, Stream>
+{
+    static void format(const std::vector<MirrorAttr>& items, Stream& output) { format_vector_as_defs(items, output); }
+
+    static void format(const MirrorAttr& item, Stream& output) {
+        ecf::Indentor in;
+        ecf::Indentor::indent(output);
+        output << "mirror";
+        output << " --name ";
+        output << item.name();
+        output << " --remote_path ";
+        output << item.remote_path();
+        if (const auto& host = item.remote_host(); !host.empty() && host != MirrorAttr::default_remote_host) {
+            output << " --remote_host ";
+            output << item.remote_host();
+        }
+        if (const auto& port = item.remote_port(); !port.empty() && port != MirrorAttr::default_remote_port) {
+            output << " --remote_port ";
+            output << item.remote_port();
+        }
+        if (const auto& polling = item.polling(); !polling.empty() && polling != MirrorAttr::default_polling) {
+            output << " --polling ";
+            output << item.polling();
+        }
+        if (item.ssl()) {
+            output << " --ssl";
+        }
+        if (const auto& auth = item.auth(); !auth.empty() && auth != MirrorAttr::default_remote_auth) {
+            output << " --remote_auth ";
+            output << item.auth();
+        }
+        if (const auto& reason = item.reason(); !reason.empty()) {
+            output << " --reason ";
+            output << item.reason();
+        }
+        output << '\n';
+    }
+};
+
+} // namespace implementation
+} // namespace ecf
+
+#endif /* ecflow_node_formatter_MirrorFormatter.hpp */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/move_peer.hpp 5.13.0-1/libs/node/src/ecflow/node/move_peer.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/move_peer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/move_peer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_move_peer_HPP
+#define ecflow_node_move_peer_HPP
+
+#include "ecflow/node/Node.hpp"
+
+template <typename ct>
+void move_peer_node(std::vector<ct>& vec, Node* source, Node* dest, const std::string& error_str) {
+    if (!source) {
+        std::stringstream ss;
+        ss << error_str << "::move source is NULL";
+        throw std::runtime_error(ss.str());
+    }
+    if (!dest) {
+        std::stringstream ss;
+        ss << error_str << "::move destination is NULL";
+        throw std::runtime_error(ss.str());
+    }
+    if (source == dest) {
+        std::stringstream ss;
+        ss << error_str << "move choose a different location as sibling " << dest->absNodePath()
+           << " matches node to be moved";
+        throw std::runtime_error(ss.str());
+    }
+    if (source->parent() != dest->parent()) {
+        std::stringstream ss;
+        ss << error_str << "move source and destination node are not siblings";
+        throw std::runtime_error(ss.str());
+    }
+
+    for (size_t t = 0; t < vec.size(); t++) {
+        if (vec[t].get() == source) {
+            for (size_t s = 0; s < vec.size(); s++) {
+                if (vec[s].get() == dest) {
+
+                    ct node = vec[t];
+                    vec.erase(vec.begin() + t);
+
+                    vec.insert(vec.begin() + s, node);
+                    return;
+                }
+            }
+            std::stringstream ss;
+            ss << error_str << "::move could not find sibling node " << dest->absNodePath() << " when moving node "
+               << source->absNodePath();
+            throw std::runtime_error(ss.str());
+        }
+    }
+
+    std::stringstream ss;
+    ss << error_str << "::move source node " << source->absNodePath() << " not found on parent";
+    throw std::runtime_error(ss.str());
+}
+
+#endif /* ecflow_node_move_peer_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/AutoArchiveParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+// The -i is the last token before the comments start.
+static bool has_idle_flag(std::vector<std::string>& lineTokens) {
+    return (lineTokens.size() >= 3 && lineTokens[2] == "-i");
+}
+
+bool AutoArchiveParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // autoarchive +01:00    # archive one hour after complete
+    // autoarchive 01:00     # archive at 1 am in morning after complete
+    // autoarchive 10        # archive 10 days after complete
+    // autoarchive 0         # archive immediately after complete
+
+    // autoarchive +01:00 -i   # archive one hour after complete,queued,aborted
+    // autoarchive 01:00  -i   # archive at 1 am in morning after complete,queued,aborted
+    // autoarchive 10     -i   # archive 10 days after complete,queued,aborted
+    // autoarchive 0      -i   # archive immediately after complete,queued,aborted
+
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("AutoArchiveParser::doParse: Invalid autoarchive :" + line);
+    if (nodeStack().empty())
+        throw std::runtime_error(
+            "AutoArchiveParser::doParse: Could not add autoarchive as node stack is empty at line: " + line);
+
+    if (lineTokens[1].find_first_of(':') == string::npos) {
+        // Must be of the form:
+        // autoarchive 10        # archive 10 days after complete
+        // autoarchive 0         # archive immediately after complete
+        int days = Extract::theInt(lineTokens[1], "invalid autoarchive " + line);
+
+        nodeStack_top()->add_autoarchive(AutoArchiveAttr(days, has_idle_flag(lineTokens)));
+    }
+    else {
+        // Must be of the form:
+        // autoarchive +01:00    # archive one hour after complete
+        // autoarchive 01:00     # archive at 1 am in morning after complete
+        int hour      = 0;
+        int min       = 0;
+        bool relative = TimeSeries::getTime(lineTokens[1], hour, min);
+
+        nodeStack_top()->add_autoarchive(AutoArchiveAttr(TimeSlot(hour, min), relative, has_idle_flag(lineTokens)));
+    }
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AutoArchiveParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_AutoArchiveParser_HPP
+#define ecflow_node_parser_AutoArchiveParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class AutoArchiveParser : public Parser {
+public:
+    explicit AutoArchiveParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "autoarchive"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_AutoArchiveParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AutoCancelParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/AutoCancelParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AutoCancelParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AutoCancelParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,54 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/AutoCancelParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool AutoCancelParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // autocancel +01:00    # cancel one hour after complete
+    // autocancel 01:00     # cancel at 1 am in morning after complete
+    // autocancel 10        # cancel 10 days after complete
+    // autocancel 0         # cancel immediately after complete
+
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("AutoCancelParser::doParse: Invalid autocancel :" + line);
+    if (nodeStack().empty())
+        throw std::runtime_error(
+            "AutoCancelParser::doParse: Could not add autocancel as node stack is empty at line: " + line);
+
+    if (lineTokens[1].find_first_of(':') == string::npos) {
+        // Must be of the form:
+        // autocancel 10        # cancel 10 days after complete
+        // autocancel 0         # cancel immediately after complete
+        int days = Extract::theInt(lineTokens[1], "invalid autocancel " + line);
+
+        nodeStack_top()->addAutoCancel(AutoCancelAttr(days));
+    }
+    else {
+        // Must be of the form:
+        // autocancel +01:00    # cancel one hour after complete
+        // autocancel 01:00     # cancel at 1 am in morning after complete
+        int hour      = 0;
+        int min       = 0;
+        bool relative = TimeSeries::getTime(lineTokens[1], hour, min);
+
+        nodeStack_top()->addAutoCancel(AutoCancelAttr(TimeSlot(hour, min), relative));
+    }
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AutoCancelParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/AutoCancelParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AutoCancelParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AutoCancelParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_AutoCancelParser_HPP
+#define ecflow_node_parser_AutoCancelParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class AutoCancelParser : public Parser {
+public:
+    explicit AutoCancelParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "autocancel"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_AutoCancelParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,44 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/AutoRestoreParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool AutoRestoreParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // autorestore /s1/f1
+    // autorestore ../f1
+
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("AutoRestoreParser::doParse: Invalid autorestore :" + line);
+    if (nodeStack().empty())
+        throw std::runtime_error(
+            "AutoRestoreParser::doParse: Could not add autorestore as node stack is empty at line: " + line);
+
+    std::vector<std::string> nodes_to_restore;
+    for (size_t i = 1; i < lineTokens.size(); i++) {
+        if (lineTokens[i][0] == '#')
+            break;
+        nodes_to_restore.push_back(lineTokens[i]);
+    }
+
+    if (nodes_to_restore.empty())
+        throw std::runtime_error("AutoRestoreParser::doParse: no paths specified " + line);
+
+    nodeStack_top()->add_autorestore(ecf::AutoRestoreAttr(nodes_to_restore));
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AutoRestoreParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_AutoRestoreParser_HPP
+#define ecflow_node_parser_AutoRestoreParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class AutoRestoreParser : public Parser {
+public:
+    explicit AutoRestoreParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "autorestore"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_AutoRestoreParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AvisoParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/AvisoParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AvisoParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AvisoParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,100 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/AvisoParser.hpp"
+
+#include <stdexcept>
+
+#include <boost/program_options.hpp>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+namespace {
+
+template <typename T>
+auto get_option_value(const boost::program_options::variables_map& vm,
+                      const std::string& option_name,
+                      const std::string& line) {
+    if (!vm.count(option_name)) {
+        throw std::runtime_error("AvisoParser::doParse: Could not find '" + option_name + "' option in line: " + line);
+    }
+    return vm[option_name].as<T>();
+}
+
+} // namespace
+
+ecf::AvisoAttr AvisoParser::parse_aviso_line(const std::string& line) {
+    return parse_aviso_line(line, nullptr);
+}
+
+ecf::AvisoAttr AvisoParser::parse_aviso_line(const std::string& line, const std::string& name) {
+    return parse_aviso_line(line, name, nullptr);
+}
+
+ecf::AvisoAttr AvisoParser::parse_aviso_line(const std::string& line, const std::string& name, Node* parent) {
+    auto updated_line = line + " --name " + name;
+    return parse_aviso_line(updated_line, parent);
+}
+
+ecf::AvisoAttr AvisoParser::parse_aviso_line(const std::string& line, Node* parent) {
+    std::vector<std::string> tokens;
+    {
+        // Since po::command_line_parser requires a vector of strings, we need convert from string_view to string
+        std::vector<std::string_view> extracted = ecf::Str::tokenize_quotation(line, "'");
+        std::transform(std::begin(extracted),
+                       std::end(extracted),
+                       std::back_inserter(tokens),
+                       [](const std::string_view& sv) { return std::string{sv}; });
+    }
+
+    namespace po = boost::program_options;
+    po::options_description description("AvisoParser");
+    description.add_options()(option_name, po::value<std::string>());
+    description.add_options()(option_listener, po::value<std::string>());
+    description.add_options()(option_url, po::value<std::string>()->default_value(ecf::AvisoAttr::default_url));
+    description.add_options()(option_schema, po::value<std::string>()->default_value(ecf::AvisoAttr::default_schema));
+    description.add_options()(option_polling, po::value<std::string>()->default_value(ecf::AvisoAttr::default_polling));
+    description.add_options()(option_revision, po::value<uint64_t>()->default_value(0));
+    description.add_options()(option_auth, po::value<std::string>()->default_value(ecf::AvisoAttr::default_auth));
+    description.add_options()(option_reason, po::value<std::string>()->default_value(""));
+
+    po::parsed_options parsed_options = po::command_line_parser(tokens).options(description).run();
+
+    po::variables_map vm;
+    po::store(parsed_options, vm);
+    po::notify(vm);
+
+    auto name     = get_option_value<ecf::AvisoAttr::name_t>(vm, option_name, line);
+    auto listener = get_option_value<ecf::AvisoAttr::listener_t>(vm, option_listener, line);
+    auto url      = get_option_value<ecf::AvisoAttr::url_t>(vm, option_url, line);
+    auto schema   = get_option_value<ecf::AvisoAttr::schema_t>(vm, option_schema, line);
+    auto polling  = get_option_value<ecf::AvisoAttr::polling_t>(vm, option_polling, line);
+    auto revision = get_option_value<ecf::AvisoAttr::revision_t>(vm, option_revision, line);
+    auto auth     = get_option_value<ecf::AvisoAttr::auth_t>(vm, option_auth, line);
+    auto reason   = get_option_value<ecf::AvisoAttr::reason_t>(vm, option_reason, line);
+
+    return ecf::AvisoAttr{parent, name, listener, url, schema, polling, revision, auth, reason};
+}
+
+bool AvisoParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (nodeStack().empty()) {
+        throw std::runtime_error("AvisoParser::doParse: Could not add aviso as node stack is empty at line: " + line);
+    }
+
+    Node* parent = nodeStack_top();
+
+    auto parsed = parse_aviso_line(line, parent);
+    nodeStack_top()->addAviso(parsed);
+    nodeStack_top()->absNodePath();
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/AvisoParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/AvisoParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/AvisoParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/AvisoParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,61 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_AvisoParser_HPP
+#define ecflow_node_parser_AvisoParser_HPP
+
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/parser/Parser.hpp"
+
+/**
+ * This class is used to parse an Aviso attribute for a Node, stored in a single line of a definition file.
+ *
+ * The Aviso definition line is composed of the following tokens:
+ *  "aviso"
+ *    - keyword, mandatory
+ *  --name <value>
+ *    - string value (must be valid name), mandatory
+ *  --listener '<value>'
+ *    - json value (enclosed in single quotes), mandatory
+ *  --url <value>
+ *    - string value (formed of <scheme>://<host>[:<port>]), mandatory
+ *  --schema <value>
+ *    - string value (path to the Aviso schema file, accessible to the ecFlow server), mandatory
+ *  --revision <value>
+ *    - unsigned integer value, optional (default: 0)
+ *
+ * The tokens can be separated provided in any order, with any number of spaces between them being disregarded.
+ * Apart from the tokens above, retrieved from the definition line, the parser also determines the 'path' of the Node
+ * to which the 'Aviso' attribute belongs -- this is stored in the parsed 'Aviso' object.
+ */
+
+class AvisoParser : public Parser {
+public:
+    static constexpr const char* keyword_aviso   = "aviso";
+    static constexpr const char* option_name     = "name";
+    static constexpr const char* option_listener = "listener";
+    static constexpr const char* option_url      = "url";
+    static constexpr const char* option_schema   = "schema";
+    static constexpr const char* option_polling  = "polling";
+    static constexpr const char* option_revision = "revision";
+    static constexpr const char* option_auth     = "auth";
+    static constexpr const char* option_reason   = "reason";
+
+    static ecf::AvisoAttr parse_aviso_line(const std::string& line);
+    static ecf::AvisoAttr parse_aviso_line(const std::string& line, const std::string& name);
+    static ecf::AvisoAttr parse_aviso_line(const std::string& line, const std::string& name, Node* parent);
+    static ecf::AvisoAttr parse_aviso_line(const std::string& line, Node* parent);
+
+    explicit AvisoParser(DefsStructureParser* p) : Parser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return "aviso"; }
+};
+
+#endif /* ecflow_node_parser_AvisoParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/CalendarParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/CalendarParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/CalendarParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/CalendarParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,35 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/CalendarParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Suite.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool CalendarParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (lineTokens.size() < 2) {
+        throw std::runtime_error("CalendarParser::doParse: Invalid calendar :" + line);
+    }
+    if (nodeStack().empty()) {
+        throw std::runtime_error("CalendarParser::doParse: Could not add calendar as node stack is empty at line: " +
+                                 line);
+    }
+
+    Suite* suite = nodeStack_top()->isSuite();
+    if (!suite)
+        throw std::runtime_error("Calendar can only be added to suites and not " + nodeStack_top()->debugType());
+    suite->set_calendar().read_state(line, lineTokens);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/CalendarParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/CalendarParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/CalendarParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/CalendarParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_CalendarParser_HPP
+#define ecflow_node_parser_CalendarParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class CalendarParser : public Parser {
+public:
+    explicit CalendarParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "calendar"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_CalendarParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/ClockParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/ClockParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/ClockParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/ClockParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,183 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/ClockParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace ecf;
+using namespace std;
+
+static void extractTheGain(const std::string& theGainToken, ClockAttr& clockAttr) {
+    if (theGainToken.find(Str::COLON()) != std::string::npos) {
+        // clock real +01:00
+        // clock real  01:36
+        int hour, min;
+        bool positiveGain = TimeSeries::getTime(theGainToken, hour, min);
+        clockAttr.set_gain(hour, min, positiveGain);
+        return;
+    }
+
+    long theGain           = 0;
+    std::string theGainStr = theGainToken;
+    bool positiveGain      = false;
+    if (theGainStr[0] == '+') {
+        positiveGain = true;
+        theGainStr.erase(theGainStr.begin());
+    }
+    theGain = Extract::theInt(theGainStr, "Invalid clock gain:" + theGainToken);
+    clockAttr.set_gain_in_seconds(theGain, positiveGain);
+}
+
+bool ClockParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // clock hybrid   # a comment
+    // clock hybrid
+    // clock real                  #a comment
+    // clock real 300
+    // clock real +01:00
+    // clock real 20.1.2007
+    // clock real 20.1.2007 +01:00
+
+    // For Testing we allow calendar increment to be change on a per suite basis
+    // -c is optional
+    // clock real 20.1.2007 +01:00
+    // clock hybrid
+
+    // Allow clock to be stopped/started when the server is stopped/started
+    // and hence always honour time dependencies. See Calendar.h for more details
+    // This is optional.( Need to advertise this functionality)
+    // clock real 20.1.2007 +01:00 -s
+    // clock hybrid -s
+    if (lineTokens.size() < 2) {
+        throw std::runtime_error("ClockParser::doParse: Invalid clock :" + line);
+    }
+    if (nodeStack().empty()) {
+        throw std::runtime_error("ClockParser::doParse: Could not add clock as node stack is empty at line: " + line);
+    }
+
+    bool hybrid = true;
+    if (lineTokens[1] == "real")
+        hybrid = false;
+    else if (lineTokens[1] == "hybrid")
+        hybrid = true;
+    else
+        throw std::runtime_error("Invalid clock :" + line);
+
+    ClockAttr clockAttr(hybrid);
+
+    if (lineTokens.size() >= 3 && lineTokens[2][0] != '#') {
+        // if third token is not a comment the time must be of the form
+        // clock real 300
+        // clock real +01:00
+        // clock real 20.1.2007
+        // clock real 20.1.2007
+        // clock real           # on requeue we use current date
+        // clock real -s
+
+        if (lineTokens[2].find(".") != std::string::npos) {
+            // clock real 20.1.2007
+
+            // If 0 returned then day,month,year is of form *, and not valid
+            int day, month, year;
+            DateAttr::getDate(lineTokens[2], day, month, year);
+
+            // This will throw std::aout_of_range for an invalid clock date. Note no wild carding allowed.
+            clockAttr.date(day, month, year); // this will check the date
+
+            if (lineTokens.size() >= 4 && lineTokens[3][0] != '#') {
+                // clock real 20.1.2007 +01:00
+                // clock real 20.1.2007 +300
+                // clock real 20.1.2007 350
+                extractTheGain(lineTokens[3], clockAttr);
+            }
+        }
+        else {
+            if (lineTokens[2] != "-s") {
+                // clock real 300
+                // clock real +01:00
+                extractTheGain(lineTokens[2], clockAttr);
+            }
+        }
+    }
+
+    Suite* suite = nodeStack_top()->isSuite();
+    if (!suite)
+        throw std::runtime_error("Clock can only be added to suites and not " + nodeStack_top()->debugType());
+
+    suite->addClock(clockAttr);
+
+    return true;
+}
+
+bool EndClockParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // Note: endclock > clock
+    // Also endclock will be same type as the clock
+
+    // endclock 300
+    // endclock 300
+    // endclock +01:00
+    // endclock 20.1.2007
+    // endclock 20.1.2007 +01:00
+
+    // Allow clock to be stopped/started when the server is stopped/started
+    // and hence always honour time dependencies. See Calendar.h for more details
+    if (lineTokens.size() < 2) {
+        throw std::runtime_error("ClockEndParser::doParse: Invalid clock :" + line);
+    }
+    if (nodeStack().empty()) {
+        throw std::runtime_error("ClockEndParser::doParse: Could not add end clock as node stack is empty at line: " +
+                                 line);
+    }
+
+    ClockAttr clockAttr(false);
+
+    if (lineTokens.size() >= 2 && lineTokens[1][0] != '#') {
+        // if third token is not a comment the time must be of the form
+        // endclock 300
+        // endclock +01:00
+        // endclock 20.1.2007
+
+        if (lineTokens[1].find(".") != std::string::npos) {
+            // endclock 20.1.2007
+
+            // If 0 returned then day,month,year is of form *, and not valid
+            int day, month, year;
+            DateAttr::getDate(lineTokens[1], day, month, year);
+
+            // This will throw std::out_of_range for an invalid clock date. Note no wild carding allowed.
+            clockAttr.date(day, month, year); // this will check the date
+
+            if (lineTokens.size() >= 3 && lineTokens[2][0] != '#') {
+                // endclock 20.1.2007 +01:00
+                // endclock 20.1.2007 +300
+                // endclock 20.1.2007 350
+                extractTheGain(lineTokens[2], clockAttr);
+            }
+        }
+        else {
+            // endclock 300
+            // endclock +01:00
+            extractTheGain(lineTokens[1], clockAttr);
+        }
+    }
+
+    Suite* suite = nodeStack_top()->isSuite();
+    if (!suite)
+        throw std::runtime_error("Clock can only be added to suites and not " + nodeStack_top()->debugType());
+
+    suite->add_end_clock(clockAttr);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/ClockParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/ClockParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/ClockParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/ClockParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_ClockParser_HPP
+#define ecflow_node_parser_ClockParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class ClockParser : public Parser {
+public:
+    explicit ClockParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "clock"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+class EndClockParser : public Parser {
+public:
+    explicit EndClockParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "endclock"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_ClockParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/CronParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/CronParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/CronParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/CronParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/CronParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+// #define DEBUG_CRON 1
+
+bool CronParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // cron 23:00                 # run every day at 23:00
+    // cron 10:00 20:00 01:00     # run every hour between 10am and 8pm
+    // cron -w 0,1 10:00          # run every sunday and monday at 10am
+    // cron -d 10,11,12 12:00     # run 10th, 11th and 12th of each month at noon
+    // cron -m 1,2,3 12:00        # run on Jan,Feb and March every day at noon.
+    // cron -w 0 -m 5,6,7,8 10:00 20:00 01:00 # run every sunday, between May-Aug, every hour between 10am and 8pm
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("CronParser::doParse: Invalid cron: " + line);
+
+#ifdef DEBUG_CRON
+    cerr << "CronParser::doParse " << line << "\n";
+#endif
+
+    bool parse_state = (rootParser()->get_file_type() != PrintStyle::DEFS);
+
+    size_t index = 1; // to get over the cron
+    CronAttr cronAttr;
+    CronAttr::parse(cronAttr, lineTokens, index, parse_state);
+
+    nodeStack_top()->addCron(cronAttr);
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/CronParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/CronParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/CronParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/CronParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_CronParser_HPP
+#define ecflow_node_parser_CronParser_HPP
+
+//============================================================================
+// Name        :
+// Author      : Avi
+// Revision    : $Revision: #6 $
+//
+// Copyright 2009- ECMWF.
+// This software is licensed under the terms of the Apache Licence version 2.0
+// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+// In applying this licence, ECMWF does not waive the privileges and immunities
+// granted to it by virtue of its status as an intergovernmental organisation
+// nor does it submit to any jurisdiction.
+//
+// Description :
+//============================================================================
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class CronParser : public Parser {
+public:
+    explicit CronParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "cron"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_CronParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DateParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/DateParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DateParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DateParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,37 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/DateParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool DateParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    //  date 15.11.2009 # <value>   // with PersistStyle::STATE & MIGRATE
+    //  date 15.*.*
+    //  date *.1.*
+    if (lineTokens.size() < 2) {
+        throw std::runtime_error("DateParser::doParse: Invalid date :" + line);
+    }
+
+    if (nodeStack().empty()) {
+        throw std::runtime_error("DateParser::doParse: Could not add date as node stack is empty at line: " + line);
+    }
+
+    // DateAttr::create can throw for invalid dates
+    nodeStack_top()->addDate(DateAttr::create(lineTokens, rootParser()->get_file_type() != PrintStyle::DEFS));
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DateParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/DateParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DateParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DateParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_DateParser_HPP
+#define ecflow_node_parser_DateParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class DateParser : public Parser {
+public:
+    explicit DateParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "date"; }
+    bool doParse(const std::string& /*line*/, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_DateParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DayParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/DayParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DayParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DayParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,34 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/DayParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+
+bool DayParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    //  day monday  # free expired
+    //  day tuesday # expired
+    if (lineTokens.size() < 2) {
+        throw std::runtime_error("DayParser::doParse: Invalid day :" + line);
+    }
+    if (nodeStack().empty()) {
+        throw std::runtime_error("DayParser::doParse: Could not add day as node stack is empty at line: " + line);
+    }
+
+    // parse day and state
+    nodeStack_top()->addDay(DayAttr::create(lineTokens, rootParser()->get_file_type() != PrintStyle::DEFS));
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DayParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/DayParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DayParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DayParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_DayParser_HPP
+#define ecflow_node_parser_DayParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class DayParser : public Parser {
+public:
+    explicit DayParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "day"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_DayParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,474 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/DefsParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/parser/AutoArchiveParser.hpp"
+#include "ecflow/node/parser/AutoCancelParser.hpp"
+#include "ecflow/node/parser/AutoRestoreParser.hpp"
+#include "ecflow/node/parser/AvisoParser.hpp"
+#include "ecflow/node/parser/CalendarParser.hpp"
+#include "ecflow/node/parser/ClockParser.hpp"
+#include "ecflow/node/parser/CronParser.hpp"
+#include "ecflow/node/parser/DateParser.hpp"
+#include "ecflow/node/parser/DayParser.hpp"
+#include "ecflow/node/parser/DefsStateParser.hpp"
+#include "ecflow/node/parser/DefsStatusParser.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+#include "ecflow/node/parser/EventParser.hpp"
+#include "ecflow/node/parser/ExternParser.hpp"
+#include "ecflow/node/parser/GenericParser.hpp"
+#include "ecflow/node/parser/InlimitParser.hpp"
+#include "ecflow/node/parser/LabelParser.hpp"
+#include "ecflow/node/parser/LateParser.hpp"
+#include "ecflow/node/parser/LimitParser.hpp"
+#include "ecflow/node/parser/MeterParser.hpp"
+#include "ecflow/node/parser/MirrorParser.hpp"
+#include "ecflow/node/parser/QueueParser.hpp"
+#include "ecflow/node/parser/RepeatParser.hpp"
+#include "ecflow/node/parser/TimeParser.hpp"
+#include "ecflow/node/parser/TodayParser.hpp"
+#include "ecflow/node/parser/TriggerParser.hpp"
+#include "ecflow/node/parser/VariableParser.hpp"
+#include "ecflow/node/parser/VerifyParser.hpp"
+#include "ecflow/node/parser/ZombieAttrParser.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+// #define DEBUG_PARSER 1
+
+template <class T>
+ostream& operator<<(ostream& os, const vector<T>& v) {
+    copy(v.begin(), v.end(), ostream_iterator<T>(cout, ","));
+    return os;
+}
+
+class AliasParser : public Parser {
+public:
+    explicit AliasParser(DefsStructureParser* p) : Parser(p) {
+        reserve_vec(21);
+        addParser(new VariableParser(p));
+        addParser(new LabelParser(p));
+        addParser(new MeterParser(p));
+        addParser(new EventParser(p));
+        addParser(new TriggerParser(p));
+        addParser(new InlimitParser(p));
+        addParser(new LateParser(p));
+        addParser(new DefsStatusParser(p));
+        addParser(new CompleteParser(p));
+        addParser(new TimeParser(p));
+        addParser(new RepeatParser(p));
+        addParser(new TodayParser(p));
+        addParser(new CronParser(p));
+        addParser(new LimitParser(p));
+        addParser(new DateParser(p));
+        addParser(new DayParser(p));
+        addParser(new AutoCancelParser(p));
+        addParser(new VerifyParser(p));
+        addParser(new ZombieAttrParser(p));
+        addParser(new QueueParser(p));
+        addParser(new GenericParser(p));
+        addParser(new AvisoParser(p));
+        addParser(new MirrorParser(p));
+    }
+
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
+
+        const char* first_token = lineTokens[0].c_str();
+        if (Str::local_strcmp(first_token, keyword()) == 0) {
+
+            if (lineTokens.size() < 2)
+                throw std::runtime_error("Alias name missing.");
+
+            addAlias(line, lineTokens);
+
+            return true;
+        }
+        else if (Str::local_strcmp(first_token, "endalias") == 0) { // required at the end
+            popNode();
+            return true;
+        }
+        return Parser::doParse(line, lineTokens);
+    }
+
+    const char* keyword() const override { return "alias"; }
+
+private:
+    void addAlias(const std::string& line, std::vector<std::string>& lineTokens) const {
+        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+
+        if (nodeStack().empty() && rootParser()->parsing_node_string()) {
+            alias_ptr alias = Alias::create(lineTokens[1], check);
+            if (rootParser()->get_file_type() != PrintStyle::DEFS)
+                alias->read_state(line, lineTokens);
+            nodeStack().emplace(alias.get(), this);
+            rootParser()->set_node_ptr(alias);
+            return;
+        }
+
+        // bad test data can mean that last node is not a suite family or task, will fail parse
+        if (nodeStack().empty())
+            throw std::runtime_error("Add alias failed empty node stack");
+
+        // alias can only be added to tasks
+        Task* lastAddedTask = nodeStack_top()->isTask();
+        if (lastAddedTask) {
+
+            alias_ptr alias = lastAddedTask->add_alias(lineTokens[1]);
+            alias->read_state(line, lineTokens);
+            nodeStack().emplace(alias.get(), this);
+        }
+        else {
+            if (nodeStack_top()->isAlias()) {
+
+                // Alias can _only_ be added to tasks pop the top Node to get to the task
+                popNode();
+                addAlias(line, lineTokens);
+            }
+            else
+                throw std::runtime_error("Add alias failed, expected task on node stack");
+        }
+    }
+};
+
+//================================================================================
+
+class TaskParser : public Parser {
+public:
+    explicit TaskParser(DefsStructureParser* p) : Parser(p) {
+        reserve_vec(25);
+        addParser(new VariableParser(p));
+        addParser(new TriggerParser(p));
+        addParser(new LabelParser(p));
+        addParser(new InlimitParser(p));
+        addParser(new EventParser(p));
+        addParser(new LateParser(p));
+        addParser(new MeterParser(p));
+        addParser(new DefsStatusParser(p));
+        addParser(new CompleteParser(p));
+        addParser(new TimeParser(p));
+        addParser(new RepeatParser(p));
+        addParser(new TodayParser(p));
+        addParser(new CronParser(p));
+        addParser(new LimitParser(p));
+        addParser(new DateParser(p));
+        addParser(new DayParser(p));
+        addParser(new AutoCancelParser(p));
+        addParser(new VerifyParser(p));
+        addParser(new ZombieAttrParser(p));
+        addParser(new AliasParser(p));
+        addParser(new QueueParser(p));
+        addParser(new AutoRestoreParser(p));
+        addParser(new GenericParser(p));
+        addParser(new AvisoParser(p));
+        addParser(new MirrorParser(p));
+    }
+
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
+
+        const char* first_token = lineTokens[0].c_str();
+        if (Str::local_strcmp(first_token, keyword()) == 0) {
+            if (lineTokens.size() < 2)
+                throw std::runtime_error("Task name missing.");
+            addTask(line, lineTokens);
+            return true;
+        }
+        else if (Str::local_strcmp(first_token, "endfamily") == 0) {
+            if (parent())
+                return parent()->doParse(line, lineTokens);
+        }
+        else if (Str::local_strcmp(first_token, "endtask") == 0) { // optional
+            popToContainerNode();
+            return true;
+        }
+        return Parser::doParse(line, lineTokens);
+    }
+
+    const char* keyword() const override { return "task"; }
+
+private:
+    void addTask(const std::string& line, std::vector<std::string>& lineTokens) const {
+        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+
+        if (nodeStack().empty() && rootParser()->parsing_node_string()) {
+            task_ptr task = Task::create(lineTokens[1], check);
+            if (rootParser()->get_file_type() != PrintStyle::DEFS)
+                task->read_state(line, lineTokens);
+            nodeStack().emplace(task.get(), this);
+            rootParser()->set_node_ptr(task);
+            return;
+        }
+
+        // bad test data can mean that last node is not a suite family or task, will fail parse
+        if (nodeStack().empty())
+            throw std::runtime_error("Add task failed empty node stack");
+
+        // end task is optional, so if we get another task, whilst in a task pop the parser
+        if (nodeStack_top()->isTask()) {
+            popToContainerNode(); // pop the node stack
+        }
+
+        NodeContainer* lastAddedContainer = nodeStack_top()->isNodeContainer();
+        if (lastAddedContainer) {
+
+            task_ptr task = Task::create(lineTokens[1], check);
+            if (rootParser()->get_file_type() != PrintStyle::DEFS)
+                task->read_state(line, lineTokens);
+            nodeStack().emplace(task.get(), this);
+            lastAddedContainer->addTask(task);
+        }
+        else {
+            if (nodeStack_top()->isTask()) {
+
+                // Task can _only_ be added to suite and families.
+                // pop the top Node to get to the Container(suite or family), then call recursively to add task
+                popNode();
+                addTask(line, lineTokens);
+            }
+        }
+    }
+};
+
+//================================================================================
+
+class FamilyParser : public Parser {
+public:
+    explicit FamilyParser(DefsStructureParser* p) : Parser(p) {
+        reserve_vec(25);
+        addParser(new VariableParser(p));
+        addParser(new TaskParser(p));
+        addParser(new TriggerParser(p));
+        addParser(new InlimitParser(p));
+        addParser(new DefsStatusParser(p));
+        addParser(new LimitParser(p));
+        addParser(new CompleteParser(p));
+        addParser(new MeterParser(p));
+        addParser(new TimeParser(p));
+        addParser(new LabelParser(p));
+        addParser(new RepeatParser(p));
+        addParser(new LateParser(p));
+        addParser(new EventParser(p));
+        addParser(new TodayParser(p));
+        addParser(new CronParser(p));
+        addParser(new DateParser(p));
+        addParser(new DayParser(p));
+        addParser(new AutoCancelParser(p));
+        addParser(new VerifyParser(p));
+        addParser(new ZombieAttrParser(p));
+        addParser(new QueueParser(p));
+        addParser(new AutoArchiveParser(p));
+        addParser(new AutoRestoreParser(p));
+        addParser(new GenericParser(p));
+        addParser(new AvisoParser(p));
+        addParser(new MirrorParser(p));
+    }
+
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
+
+        const char* first_token = lineTokens[0].c_str();
+        if (Str::local_strcmp(first_token, keyword()) == 0) {
+
+            if (lineTokens.size() < 2)
+                throw std::runtime_error("Family name missing.");
+
+            addFamily(line, lineTokens);
+
+            return true;
+        }
+        else if (Str::local_strcmp(first_token, "endfamily") == 0) {
+
+            popFamily();
+            return true;
+        }
+        else if (Str::local_strcmp(first_token, "endtask") == 0) { // optional
+            popNode();
+            return true;
+        }
+        return Parser::doParse(line, lineTokens);
+    }
+
+    const char* keyword() const override { return "family"; }
+
+private:
+    void addFamily(const std::string& line, const std::vector<std::string>& lineTokens) const {
+        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+
+        if (nodeStack().empty() && rootParser()->parsing_node_string()) {
+            family_ptr family = Family::create(lineTokens[1], check);
+            rootParser()->set_node_ptr(family);
+            if (rootParser()->get_file_type() != PrintStyle::DEFS)
+                family->read_state(line, lineTokens);
+            nodeStack().emplace(family.get(), this);
+        }
+        else {
+            assert(!nodeStack().empty());
+            Suite* lastAddedSuite = nodeStack_top()->isSuite();
+            if (lastAddedSuite) {
+
+                family_ptr family = Family::create(lineTokens[1], check);
+                if (rootParser()->get_file_type() != PrintStyle::DEFS)
+                    family->read_state(line, lineTokens);
+
+                nodeStack().emplace(family.get(), this);
+                lastAddedSuite->addFamily(family);
+            }
+            else {
+                // support hierarchical families
+                Family* lastAddedFamily = nodeStack_top()->isFamily();
+                if (lastAddedFamily) {
+
+                    family_ptr family = Family::create(lineTokens[1], check);
+                    if (rootParser()->get_file_type() != PrintStyle::DEFS)
+                        family->read_state(line, lineTokens);
+
+                    nodeStack().emplace(family.get(), this);
+                    lastAddedFamily->addFamily(family);
+                }
+                else {
+                    Task* lastAddedTask = nodeStack_top()->isTask();
+                    if (lastAddedTask) {
+                        // Pop the node, since tasks don't always have end task
+                        popNode();
+                        addFamily(line, lineTokens);
+                    }
+                }
+            }
+        }
+    }
+
+    void popFamily() const {
+        // Compensate for the fact that Task don't have endtask, hence when we pop for a
+        // family, the top should be a suite/family
+        if (nodeStack_top()->isTask()) {
+            nodeStack().pop(); // pop the task
+            nodeStack().pop(); // pop the family to get to suite/family
+        }
+        else {
+            nodeStack().pop(); // pop the family to get to suite/family
+        }
+    }
+};
+
+//================================================================================
+
+// See ECFLOW-106, and SUP-1198, why we don't allow time,today,date,day ate the suite level.
+class SuiteParser : public Parser {
+public:
+    explicit SuiteParser(DefsStructureParser* p) : Parser(p), started_(false) {
+        reserve_vec(25);
+        addParser(new VariableParser(p));
+        addParser(new FamilyParser(p));
+        addParser(new TaskParser(p));
+        addParser(new LimitParser(p));
+        addParser(new DefsStatusParser(p));
+        addParser(new ClockParser(p));
+        addParser(new InlimitParser(p));
+        addParser(new RepeatParser(p));
+        addParser(new LateParser(p));
+        addParser(new CronParser(p));
+        addParser(new AutoCancelParser(p));
+        addParser(new VerifyParser(p));
+        addParser(new ZombieAttrParser(p));
+        addParser(new EventParser(p));
+        addParser(new LabelParser(p));
+        addParser(new CalendarParser(p));
+        addParser(new MeterParser(p));
+        addParser(new EndClockParser(p));
+        addParser(new QueueParser(p));
+        addParser(new AutoArchiveParser(p));
+        addParser(new AutoRestoreParser(p));
+        addParser(new GenericParser(p));
+        addParser(new AvisoParser(p));
+        addParser(new MirrorParser(p));
+    }
+
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override {
+
+        const char* first_token = lineTokens[0].c_str();
+        if (Str::local_strcmp(first_token, keyword()) == 0) {
+
+            if (started_)
+                throw std::runtime_error("Can't have hierarchical suites.");
+            if (lineTokens.size() < 2)
+                throw std::runtime_error("Suite name missing.");
+            started_ = true;
+
+            addSuite(line, lineTokens);
+
+            return true;
+        }
+        else if (Str::local_strcmp(first_token, "endsuite") == 0) {
+
+            if (!started_) {
+                throw std::runtime_error("Misplaced endsuite..");
+            }
+
+            // ... process end suite
+            while (!nodeStack().empty())
+                nodeStack().pop();
+            started_ = false; // since this parser is reused
+            return true;
+        }
+        return Parser::doParse(line, lineTokens);
+    }
+
+    const char* keyword() const override { return "suite"; }
+
+private:
+    void addSuite(const std::string& line, std::vector<std::string>& lineTokens) const {
+
+        if (!nodeStack().empty()) {
+            throw std::runtime_error("SuiteParser::addSuite node stack should be empty");
+        }
+
+        bool check      = (rootParser()->get_file_type() != PrintStyle::NET);
+        suite_ptr suite = Suite::create(lineTokens[1], check);
+        if (rootParser()->get_file_type() != PrintStyle::DEFS)
+            suite->read_state(line, lineTokens);
+
+        nodeStack().emplace(suite.get(), this);
+        if (defsfile())
+            defsfile()->addSuite(suite);
+        rootParser()->set_node_ptr(suite);
+    }
+
+    bool started_;
+};
+
+//================================================================================
+
+DefsParser::DefsParser(DefsStructureParser* p) : Parser(p) {
+    reserve_vec(5);
+    addParser(new HistoryParser(p));
+    addParser(new SuiteParser(p));
+    addParser(new VariableParser(p, true));
+    addParser(new ExternParser(p));
+
+    // for defs stat only
+    addParser(new DefsStateParser(p));
+}
+
+DefsParser::DefsParser(DefsStructureParser* p, bool /*node_parser_only*/) : Parser(p) {
+    reserve_vec(4);
+    addParser(new TaskParser(p));
+    addParser(new FamilyParser(p));
+    addParser(new SuiteParser(p));
+    addParser(new AliasParser(p));
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_DefsParser_HPP
+#define ecflow_node_parser_DefsParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class DefsParser : public Parser {
+public:
+    explicit DefsParser(DefsStructureParser* p);
+    DefsParser(DefsStructureParser* p, bool node_parser_only);
+    const char* keyword() const override { return "DEFS"; }
+};
+
+#endif /* ecflow_node_parser_DefsParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStateParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStateParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStateParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStateParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/DefsStateParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+
+bool DefsStateParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // cout << "line = " << line << "\n";
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("DefsStateParser::doParse Invalid defs_state " + line);
+
+    if (lineTokens[1] == PrintStyle::to_string(PrintStyle::STATE))
+        rootParser()->set_file_type(PrintStyle::STATE);
+    else if (lineTokens[1] == PrintStyle::to_string(PrintStyle::MIGRATE))
+        rootParser()->set_file_type(PrintStyle::MIGRATE);
+    else if (lineTokens[1] == PrintStyle::to_string(PrintStyle::NET))
+        rootParser()->set_file_type(PrintStyle::NET);
+    else
+        throw std::runtime_error("DefsStateParser::doParse: file type not specified : " + line);
+
+    defsfile()->read_state(line, lineTokens); // this can throw
+    return true;
+}
+
+bool HistoryParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // cout << "line = " << line << "\n";
+    defsfile()->read_history(line, lineTokens); // this can throw
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStateParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStateParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStateParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStateParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_DefsStateParser_HPP
+#define ecflow_node_parser_DefsStateParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class DefsStateParser : public Parser {
+public:
+    explicit DefsStateParser(DefsStructureParser* p) : Parser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return "defs_state"; }
+};
+
+class HistoryParser : public Parser {
+public:
+    explicit HistoryParser(DefsStructureParser* p) : Parser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return "history"; }
+};
+
+#endif /* ecflow_node_parser_DefsStateParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStatusParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStatusParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStatusParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStatusParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/DefsStatusParser.hpp"
+
+#include <sstream>
+#include <stdexcept>
+
+#include "ecflow/core/DState.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+bool DefsStatusParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("DefsStatusParser::doParse: Invalid defstatus :" + line);
+
+    if (!DState::isValid(lineTokens[1])) {
+        throw std::runtime_error("DefsStatusParser::doParse: Invalid defstatus state :" + line);
+    }
+
+    if (!nodeStack().empty()) {
+        Node* node = nodeStack_top();
+
+        // Check default status not already defined for this node.
+        auto it = defStatusMap().find(node);
+        if (it != defStatusMap().end()) {
+            if ((*it).second) {
+                std::stringstream ss;
+                ss << "DefsStatusParser::doParse: " << node->debugType() << " " << node->name()
+                   << " already has a default status\n";
+                throw std::runtime_error(ss.str());
+            }
+        }
+        defStatusMap()[node] = true;
+        node->addDefStatus(DState::toState(lineTokens[1]));
+    }
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStatusParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStatusParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStatusParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStatusParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_DefsStatusParser_HPP
+#define ecflow_node_parser_DefsStatusParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class DefsStatusParser : public Parser {
+public:
+    explicit DefsStatusParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "defstatus"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_DefsStatusParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStructureParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStructureParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStructureParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStructureParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,290 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+#include <sstream>
+
+#include <boost/tokenizer.hpp>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/node/Defs.hpp"
+
+// #define DEBUG_PARSER 1
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+/////////////////////////////////////////////////////////////////////////////////////
+DefsStructureParser::DefsStructureParser(Defs* defsfile, const std::string& file_name)
+    : parsing_node_string_(false),
+      infile_(file_name),
+      defsfile_(defsfile),
+      defsParser_(this),
+      lineNumber_(0),
+      file_type_(PrintStyle::DEFS),
+      defs_as_string_(Str::EMPTY()) {
+    if (!infile_.ok()) {
+        std::stringstream ss;
+        ss << "DefsStructureParser::DefsStructureParser: Unable to open file! " << infile_.file_name() << "\n\n";
+        ss << Version::description() << "\n";
+        error_ = ss.str();
+    }
+}
+
+DefsStructureParser::DefsStructureParser(Defs* defsfile, const std::string& str, bool)
+    : parsing_node_string_(false),
+      infile_(""),
+      defsfile_(defsfile),
+      defsParser_(this),
+      lineNumber_(0),
+      file_type_(PrintStyle::DEFS),
+      defs_as_string_(str) {
+    if (defs_as_string_.empty()) {
+        std::stringstream ss;
+        ss << "DefsStructureParser::DefsStructureParser :  Unable to parse empty string\n\n";
+        ss << Version::description() << "\n";
+        error_ = ss.str();
+    }
+}
+
+DefsStructureParser::DefsStructureParser(const std::string& defs_node_string)
+    : parsing_node_string_(true),
+      infile_(""),
+      defsfile_(nullptr),
+      defsParser_(this, true /* only parse nodes */),
+      lineNumber_(0),
+      file_type_(PrintStyle::MIGRATE),
+      defs_as_string_(defs_node_string) {
+    if (defs_as_string_.empty()) {
+        std::stringstream ss;
+        ss << "DefsStructureParser::DefsStructureParser :  Unable to parse empty string\n\n";
+        ss << Version::description() << "\n";
+        error_ = ss.str();
+    }
+}
+
+DefsStructureParser::~DefsStructureParser() {
+#ifdef SHOW_PARSER_STATS
+    defsParser_.printStats();
+#endif
+}
+
+bool DefsStructureParser::doParse(std::string& errorMsg, std::string& warningMsg) {
+    if (!error_.empty()) {
+        errorMsg = error_;
+        return false;
+    }
+
+    if (defs_as_string_.empty()) {
+        if (!do_parse_file(errorMsg)) {
+            return false;
+        }
+    }
+    else {
+        if (!do_parse_string(errorMsg)) {
+            return false;
+        }
+    }
+
+    if (PrintStyle::is_persist_style(file_type_) || parsing_node_string_) {
+        warningMsg += faults_;
+        return true;
+    }
+
+    // Note:: if parsing_node_string_ == false, then defsfile_ == NULL
+    // Now parse the trigger/complete expressions and resolve in-limits
+    return defsfile_->check(errorMsg, warningMsg);
+}
+
+bool DefsStructureParser::do_parse_file(std::string& errorMsg) {
+    std::vector<std::string> lineTokens;
+    lineTokens.reserve(64);
+    string line;
+    line.reserve(1024);
+    while (infile_.good()) {
+        getNextLine(line); // will increment lineNumer_
+        if (!do_parse_line(line, lineTokens, errorMsg)) {
+            return false;
+        }
+    }
+    return true;
+}
+
+bool DefsStructureParser::do_parse_string(std::string& errorMsg) {
+    std::vector<std::string> lineTokens;
+    lineTokens.reserve(64);
+    string line;
+    line.reserve(1024);
+    while (defs_as_string_.good()) {
+        getNextLine(line); // will increment lineNumer_
+        if (!do_parse_line(line, lineTokens, errorMsg)) {
+            the_node_ptr_ = node_ptr();
+            return false;
+        }
+    }
+    return true;
+}
+
+bool DefsStructureParser::do_parse_line(const std::string& line,
+                                        std::vector<std::string>& lineTokens,
+                                        std::string& errorMsg) {
+    lineTokens.clear(); // This is re-used, hence clear up front
+    Str::split(line, lineTokens);
+    if (lineTokens.empty())
+        return true; // ignore empty lines
+
+    // Process each line, according to the parser which is on *top* of the stack
+    // If the *top* of the stack is empty use the DefsParser
+    Parser* theCurrentParser = (nodeStack_.empty()) ? &defsParser_ : const_cast<Parser*>(nodeStack_.top().second);
+    if (theCurrentParser == nullptr) {
+        std::stringstream ss;
+        ss << "No parser found: Could not parse '" << line << "' around line number " << lineNumber_ << "\n";
+        ss << Version::description() << "\n\n";
+        errorMsg = ss.str();
+        return false;
+    }
+
+    try {
+        // Note: if the chosen parser does not recognise first token then the parent parser has a go at parsing.
+        //       If first token begins with '#' it is ignored
+        // cout << "DefsStructureParser::currentParser() = " << theCurrentParser->keyword() << "\n";
+        theCurrentParser->doParse(line, lineTokens);
+    }
+    catch (std::exception& e) {
+        std::stringstream ss;
+        ss << e.what() << "\n";
+        ss << "Could not parse '" << line << "' around line number " << lineNumber_ << "\n";
+        ss << Version::description() << "\n\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    return true;
+}
+
+void DefsStructureParser::getNextLine(std::string& line) {
+    // *ALL* the handling of multiple statements per line are handled in this function
+    // The presence of ';' signals multiple statements per line.
+    if (multi_statements_per_line_vec_.empty()) {
+        if (defs_as_string_.empty())
+            infile_.getline(line);
+        else
+            defs_as_string_.getline(line);
+        lineNumber_++;
+        if (PrintStyle::is_persist_style(file_type_)) {
+            return; // ignore multiline for migrate, *BECAUSE* *history* for group command uses ';'
+        }
+
+        if (!line.empty()) {
+
+            // See if there are multi statements per line, ie task a; task b; task b # comment
+            if (line.find(';') != std::string::npos) {
+
+                // ignore lines which have ';' but start with a comment.  i.e.
+                //     # task a, task b
+                /// calling trim can be very expensive, hence avoid if possible
+                std::vector<std::string> lineTokens;
+                Str::split(line, lineTokens);
+                if (!lineTokens.empty()) {
+                    if (lineTokens[0][0] == '#') {
+                        // found leading_comment can ignore this line
+                        return;
+                    }
+
+                    // Can't properly handle labels with ';'. ECFLOW-1554   label foo "a;b;c"
+                    // Just assume labels are on one line. Hence we don't support multiple labels on one line
+                    if (lineTokens[0] == "label") {
+                        return;
+                    }
+                }
+
+                // Handle multiple statement with # comment at the end
+                //      suite fred; task a; task b; endsuite   # suite fred; task a; task b; endsuite
+                // Remove comment at the end, to avoid adding to list of tokens
+                std::string::size_type commentPos = line.find('#');
+                if (commentPos != std::string::npos)
+                    line = line.substr(0, commentPos);
+
+                char_separator<char> sep(";");
+                typedef boost::tokenizer<boost::char_separator<char>> tokenizer;
+                tokenizer tokens(line, sep);
+                std::copy(tokens.begin(), tokens.end(), back_inserter(multi_statements_per_line_vec_));
+                assert(!multi_statements_per_line_vec_.empty());
+
+                if (semiColonInEditVariable()) {
+                    // clear multi_statements_per_line_vec_ since we can't cope with ';' in variable value
+                    // hence    edit VAR1 'A;B';   edit VAR2 "b;C"
+                    // will be treated as one variable and not two
+                    // TODO need more sophisticated parsing
+                    multi_statements_per_line_vec_.clear();
+                }
+                else {
+                    line = *(multi_statements_per_line_vec_.begin());
+                    multi_statements_per_line_vec_.erase(multi_statements_per_line_vec_.begin());
+                }
+            }
+        }
+    }
+    else {
+        line = *(multi_statements_per_line_vec_.begin());
+        multi_statements_per_line_vec_.erase(multi_statements_per_line_vec_.begin());
+    }
+
+#ifdef DEBUG_PARSER
+    Parser* theParser = currentParser();
+    if (theParser == NULL) {
+        cout << lineNumber_ << ": '" << line << "'              parser( NULL ) node(";
+    }
+    else {
+        cout << lineNumber_ << ": '" << line << "'              parser(" << theParser->keyword() << ") ";
+        if (theParser->parent())
+            cout << " parent_parser(" << theParser->parent()->keyword() << ")";
+        cout << " node(";
+    }
+
+    if (!nodeStack_.empty())
+        cout << nodeStack_top()->debugType() << " : " << nodeStack_top()->name() << ")\n";
+    else
+        cout << "NULL)\n";
+#endif
+}
+
+bool DefsStructureParser::semiColonInEditVariable() {
+    if (multi_statements_per_line_vec_[0].find("edit") != std::string::npos) {
+        // all statements must start with a edit, else we have a semi colon inside variable
+        //    edit A fred;        edit B bill         # valid
+        //    edit A 'fred;bill'; edit B 'bill;bill'  # Can't cope with this, will be ONE variable !!!!
+        for (auto& i : multi_statements_per_line_vec_) {
+            ecf::algorithm::trim(i);
+            if (i.find("edit") != 0) {
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////
+DefsString::DefsString(const std::string& defs_as_string) : empty_(defs_as_string.empty()) {
+    if (!empty_) {
+        lines_.reserve(256);
+        Str::split_using_string_view(defs_as_string, lines_, "\n");
+    }
+}
+
+bool DefsString::good() const {
+    return line_pos_ < lines_.size();
+}
+
+void DefsString::getline(std::string& line) {
+    line = lines_[line_pos_++];
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStructureParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStructureParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/DefsStructureParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/DefsStructureParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,116 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_DefsStructureParser_HPP
+#define ecflow_node_parser_DefsStructureParser_HPP
+
+#include <stack>
+#include <string>
+#include <unordered_map>
+#include <vector>
+
+#include "ecflow/core/File_r.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+#include "ecflow/node/parser/DefsParser.hpp"
+
+class Parser;
+
+// This class is used get a line of defs format from a defs string
+class DefsString {
+public:
+    explicit DefsString(const std::string& defs_as_string);
+    // Disable copy (and move) semantics
+    DefsString(const DefsString&)                  = delete;
+    const DefsString& operator=(const DefsString&) = delete;
+
+    bool good() const;
+    void getline(std::string& line);
+    bool empty() const { return empty_; }
+
+private:
+    std::vector<std::string> lines_;
+    size_t line_pos_{0};
+    bool empty_;
+};
+
+// This class is used to parse the DEFS file.
+// The file can be of different styles:
+//    DEFS: This is the structure only (default)
+//    STATE: structure + state
+//    MIGRATE: structure + state (No checking, and no externs and fault tolerant)
+class DefsStructureParser {
+public:
+    DefsStructureParser(Defs* defsfile, const std::string& file_name);
+    DefsStructureParser(Defs* defsfile, const std::string& def_str, bool);
+    explicit DefsStructureParser(const std::string& defs_node_string);
+    // Disable copy (and move) semantics
+    DefsStructureParser(const DefsStructureParser&)                  = delete;
+    const DefsStructureParser& operator=(const DefsStructureParser&) = delete;
+    ~DefsStructureParser();
+
+    /// Parse the definition file, *AND* check expressions and limits
+    /// return true if parse and check are OK, false otherwise
+    /// if false is returned, and error message is also returned
+    bool doParse(std::string& errorMsg, std::string& warningMsg);
+
+    /// The string passed to the DefsStructureParser is node string, and always in MIGRATE mode
+    /// Only used when constructor is DefsStructureParser(const std::string& defs_node_string);
+    node_ptr the_node_ptr() const { return the_node_ptr_; }
+
+    // return the file/string type read in.
+    PrintStyle::Type_t get_file_type() const { return file_type_; }
+
+    // warn about tokens not understood.
+    std::string& faults() { return faults_; }
+
+protected: // allow test code access
+    bool do_parse_file(std::string& errorMsg);
+    bool do_parse_string(std::string& errorMsg);
+
+private:
+    bool parsing_node_string_;
+    ecf::File_r infile_;
+    Defs* defsfile_;
+    DefsParser defsParser_; // Child parsers will be deleted as well
+    int lineNumber_;
+    PrintStyle::Type_t file_type_;
+    DefsString defs_as_string_;
+    node_ptr the_node_ptr_;
+
+    std::stack<std::pair<Node*, const Parser*>> nodeStack_; // stack of nodes used in parsing
+    std::vector<std::string> multi_statements_per_line_vec_;
+    std::string faults_; // In MIGRATE mode we ignore unrecognised tokens, store here for later reporting
+    std::string error_;
+    std::unordered_map<Node*, bool> defStatusMap_; // check for duplicates
+    friend class Parser;
+
+private:
+    // read in the next line form the defs file
+    void getNextLine(std::string& line);
+    void getNextStringLine(std::string& line);
+    bool do_parse_line(const std::string& line, std::vector<std::string>& lineTokens, std::string& errorMsg);
+    bool semiColonInEditVariable();
+
+    void set_node_ptr(node_ptr node) { the_node_ptr_ = node; }
+    bool parsing_node_string() const { return parsing_node_string_; }
+
+    // store file type read in
+    void set_file_type(PrintStyle::Type_t t) { file_type_ = t; }
+
+    friend class FamilyParser; // access set_node_ptr(), parsing_node_string()
+    friend class SuiteParser;  // access set_node_ptr(), parsing_node_string()
+    friend class TaskParser;   // access set_node_ptr(), parsing_node_string()
+    friend class AliasParser;  // access set_node_ptr(), parsing_node_string()
+    friend class TriggerCompleteParser;
+    friend class DefsStateParser;
+};
+
+#endif /* ecflow_node_parser_DefsStructureParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/EventParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/EventParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/EventParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/EventParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,93 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/EventParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+using namespace ecf;
+
+bool EventParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("EventParser::doParse: Invalid event : " + line);
+
+    // Events added to suite/family cannot be signaled by child command
+    // However alter/force should allow events to set/cleared on Family/suite
+    if (nodeStack().empty()) {
+        throw std::runtime_error("EventParser::doParse: Could not add event as node stack is empty at line: " + line);
+    }
+
+    // ===============================================================
+    // Don't use -1, to represent that no number was specified, as on
+    // AIX portable binary archive can't cope with this
+    // use std::numeric_limits<int>::max()
+    // THIS HAS TO BE THE SAME AS THE Event() constructor
+    // ================================================================
+    string name;
+    bool initial_value = false;
+    int number         = std::numeric_limits<int>::max();
+
+    // Test for numeric, and then casting, is ****faster***** than relying on exception alone
+    if (lineTokens[1].find_first_of(Str::NUMERIC()) == 0) {
+        //   event 0
+        //   event 1 eventName
+        //   event 2 eventNamea
+        try {
+            number = ecf::convert_to<int>(lineTokens[1]);
+            if (lineTokens.size() >= 3 && lineTokens[2][0] != '#') {
+                name = lineTokens[2];
+                // event 1 eventName set
+                if (lineTokens.size() >= 4 && lineTokens[3] == "set")
+                    initial_value = true;
+            }
+            else {
+                // event 0 set
+                if (lineTokens.size() >= 3 && lineTokens[2] == "set")
+                    initial_value = true;
+            }
+        }
+        catch (const ecf::bad_conversion&) {
+            name = lineTokens[1];
+            if (lineTokens.size() >= 3 && lineTokens[2] == "set")
+                initial_value = true;
+        }
+    }
+    else {
+        // event name
+        // event name set
+        name = lineTokens[1];
+        if (lineTokens.size() >= 3 && lineTokens[2] == "set")
+            initial_value = true;
+    }
+
+    // structure
+    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+    Event event(number, name, initial_value, check);
+
+    // state
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        if (lineTokens[lineTokens.size() - 1] == Event::SET()) {
+            event.set_value(true);
+        }
+        else if (lineTokens[lineTokens.size() - 1] == Event::CLEAR()) {
+            event.set_value(false);
+        }
+    }
+
+    nodeStack_top()->addEvent(event, check);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/EventParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/EventParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/EventParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/EventParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_EventParser_HPP
+#define ecflow_node_parser_EventParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class EventParser : public Parser {
+public:
+    explicit EventParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "event"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_EventParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/ExternParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/ExternParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/ExternParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/ExternParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/ExternParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+
+bool ExternParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // cout << "line = " << line << "\n";
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("ExternParser::doParse Invalid extern " + line);
+
+    // Guard against
+    // extern   # empty extern with a comment
+    // extern   #empty extern with a comment
+    if (lineTokens[1][0] == '#') {
+        throw std::runtime_error("ExternParser::doParse Invalid extern paths." + line);
+    }
+
+    // Expecting:
+    //   extern <path>
+    //   extern <path>:<attr>
+    // where attr is the name of [ event, meter, repeat, variable, generated variable ]
+    //
+    // We will not split it up:
+
+    // cout << "add extern  = '" << lineTokens[1] << "'\n";
+    defsfile()->add_extern(lineTokens[1]);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/ExternParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/ExternParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/ExternParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/ExternParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_ExternParser_HPP
+#define ecflow_node_parser_ExternParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+///
+/// Externs: will typically have a absolute path, however sometimes when
+///          suite are generated incrementally relative paths can be added
+/// extern a           path =  a
+/// extern /a/b/c      path = /a/b/c
+/// extern a/b/c       path = a/b/c
+/// extern /a/b/c:YMD  path = /a/b/c   variable:YMD (i.e event, meter, variable, repeat, generated variable)
+///
+/// Externs are not persisted, why ?:
+///   o Externs are un-resolved references to node paths in trigger expressions and inlimits
+///     These references could be dynamically generated.
+///   o Saves on network bandwidth and checkpoint file size.
+/// Hence, externs are *ONLY* used on the client side.
+///
+
+class ExternParser : public Parser {
+public:
+    explicit ExternParser(DefsStructureParser* p) : Parser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return "extern"; }
+};
+
+#endif /* ecflow_node_parser_ExternParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/GenericParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/GenericParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/GenericParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/GenericParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,47 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/GenericParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool GenericParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // expected format:
+    //    generic <key> <value1> <value2> .... # any comment after a first # is ignored
+    // examples:
+    //    generic fred va1 val2 # some comment
+    //    generic fred # another comment
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("GenericParser::doParse: Invalid generic :" + line);
+
+    if (nodeStack().empty()) {
+        throw std::runtime_error("GenericParser::doParse: Could not add generic as node stack is empty at line: " +
+                                 line);
+    }
+
+    size_t line_tokens_size = lineTokens.size();
+    std::vector<std::string> values;
+    values.reserve(line_tokens_size);
+    for (size_t i = 2; i < line_tokens_size; i++) {
+        if (lineTokens[i][0] == '#')
+            break;
+        values.push_back(lineTokens[i]);
+    }
+
+    Node* node = nodeStack_top();
+    node->add_generic(GenericAttr(lineTokens[1], values));
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/GenericParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/GenericParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/GenericParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/GenericParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_GenericParser_HPP
+#define ecflow_node_parser_GenericParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class GenericParser : public Parser {
+public:
+    explicit GenericParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "generic"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_GenericParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/InlimitParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/InlimitParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/InlimitParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/InlimitParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,80 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/InlimitParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+
+bool InlimitParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // inlimit /suite:queue1
+    // inlimit disk 50
+    // inlimit -n /suite:queue1 2
+    // inlimit -n fam
+    size_t lineTokens_size = lineTokens.size();
+    if (lineTokens_size < 2)
+        throw std::runtime_error("InlimitParser::doParse: Invalid inlimit :" + line);
+
+    if (nodeStack().empty())
+        throw std::runtime_error("InlimitParser::doParse: Could not add inlimit as node stack is empty at line: " +
+                                 line);
+
+    bool limit_this_node_only = false;
+    int token_pos             = 1;
+    if (lineTokens[token_pos] == "-n") {
+        limit_this_node_only = true;
+        token_pos++;
+    }
+    bool limit_submission = false;
+    if (lineTokens[token_pos] == "-s") {
+        limit_submission = true;
+        token_pos++;
+    }
+    if (limit_this_node_only && limit_submission) {
+        throw std::runtime_error(
+            "InlimitParser::doParse: can't limit family only(-n) and limit submission(-s) at the same time");
+    }
+
+    string path_to_node_holding_the_limit;
+    string limitName;
+    if (!Extract::pathAndName(lineTokens[token_pos], path_to_node_holding_the_limit, limitName)) {
+        throw std::runtime_error("InlimitParser::doParse: Invalid inlimit : " + line);
+    }
+
+    token_pos++;
+    int tokens = Extract::optionalInt(lineTokens, token_pos, 1, "Invalid in limit : " + line);
+
+    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+
+    InLimit inlimit(limitName, path_to_node_holding_the_limit, tokens, limit_this_node_only, limit_submission, check);
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        token_pos++;
+        bool incremented = false;
+        for (size_t i = token_pos; i < lineTokens_size; i++) {
+            // see InLimit::print(..) is to why "incremented:1"
+            if (lineTokens[i].find("incremented:1") != std::string::npos) {
+                incremented = true;
+                break;
+            }
+        }
+        inlimit.set_incremented(incremented);
+    }
+
+    //  cout << inlimit.toString() << "\n";
+    Node* node = nodeStack_top();
+    node->addInLimit(inlimit, check);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/InlimitParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/InlimitParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/InlimitParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/InlimitParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_InlimitParser_HPP
+#define ecflow_node_parser_InlimitParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class InlimitParser : public Parser {
+public:
+    explicit InlimitParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "inlimit"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_InlimitParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/LabelParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/LabelParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/LabelParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/LabelParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,34 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/LabelParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+using namespace ecf;
+
+bool LabelParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (nodeStack().empty()) {
+        throw std::runtime_error("LabelParser::doParse: Could not add label as node stack is empty at line: " + line);
+    }
+
+    std::string name, value, new_value;
+    Label::parse(line, lineTokens, rootParser()->get_file_type() != PrintStyle::DEFS, name, value, new_value);
+
+    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+
+    nodeStack_top()->add_label(name, value, new_value, check);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/LabelParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/LabelParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/LabelParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/LabelParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_LabelParser_HPP
+#define ecflow_node_parser_LabelParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class LabelParser : public Parser {
+public:
+    explicit LabelParser(DefsStructureParser* p) : Parser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return "label"; }
+};
+
+#endif /* ecflow_node_parser_LabelParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/LateParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/LateParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/LateParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/LateParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/LateParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool LateParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (lineTokens.size() < 3)
+        throw std::runtime_error("LateParser::doParse: Invalid late :" + line);
+
+    // late -s +00:15  -a  20:00  -c +02:00     #The option can be in any order
+    //  0   1    2      3   4     5     6        7     8     9  10 11 12  13
+    // late -s +00:15  -c +02:00                # not all options are needed
+    //  0    1   2      3   4                   5
+
+    LateAttr lateAttr; // lateAttr.isNull() will return true;
+    size_t start_index = 1;
+    LateAttr::parse(lateAttr, line, lineTokens, start_index);
+
+    // state
+    if (rootParser()->get_file_type() != PrintStyle::DEFS && lineTokens[lineTokens.size() - 1] == "late") {
+        lateAttr.setLate(true);
+    }
+
+    nodeStack_top()->addLate(lateAttr);
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/LateParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/LateParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/LateParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/LateParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_LateParser_HPP
+#define ecflow_node_parser_LateParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class LateParser : public Parser {
+public:
+    explicit LateParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "late"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_LateParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/LimitParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/LimitParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/LimitParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/LimitParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,65 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/LimitParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+
+bool LimitParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // limit name the_limit # value path1 path2
+    size_t line_tokens_size = lineTokens.size();
+    if (line_tokens_size < 3)
+        throw std::runtime_error("LimitParser::doParse: Invalid limit " + line);
+
+    if (nodeStack().empty())
+        throw std::runtime_error("LimitParser::doParse: Could not add limit as node stack is empty at line: " + line);
+
+    int limitValue = Extract::theInt(lineTokens[2], "LimitParser::doParse: Invalid limit value: " + line);
+
+    Node* node = nodeStack_top();
+
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        // state
+        int value = 0;
+        std::set<std::string> paths;
+        bool comment_fnd     = false;
+        bool value_processed = false;
+        for (size_t i = 3; i < line_tokens_size; i++) {
+            if (comment_fnd) {
+                if (!value_processed) {
+                    value           = Extract::theInt(lineTokens[i],
+                                            "LimitParser::doParse: Could not extract limit value: " + lineTokens[i]);
+                    value_processed = true;
+                }
+                else {
+                    paths.insert(lineTokens[i]);
+                }
+            }
+            if (lineTokens[i] == "#")
+                comment_fnd = true;
+        }
+
+        bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+
+        node->addLimit(Limit(lineTokens[1], limitValue, value, paths, check), check);
+    }
+    else {
+        // structure
+        node->addLimit(Limit(lineTokens[1], limitValue));
+    }
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/LimitParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/LimitParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/LimitParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/LimitParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_LimitParser_HPP
+#define ecflow_node_parser_LimitParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class LimitParser : public Parser {
+public:
+    explicit LimitParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "limit"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_LimitParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/MeterParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/MeterParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/MeterParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/MeterParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/MeterParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool MeterParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // meter 0 100 100 # value
+    size_t line_tokens_size = lineTokens.size();
+    if (line_tokens_size < 4)
+        throw std::runtime_error("MeterParser::doParse: Invalid meter :" + line);
+
+    if (nodeStack().empty()) {
+        throw std::runtime_error("MeterParser::doParse: Could not add meter as node stack is empty at line: " + line);
+    }
+
+    int min         = Extract::theInt(lineTokens[2], "Invalid meter : " + line);
+    int max         = Extract::theInt(lineTokens[3], "Invalid meter : " + line);
+    int colorChange = Extract::optionalInt(lineTokens, 4, std::numeric_limits<int>::max(), "Invalid meter : " + line);
+
+    // state
+    int value = std::numeric_limits<int>::max();
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        bool comment_fnd = false;
+        for (size_t i = 3; i < line_tokens_size; i++) {
+            if (comment_fnd) {
+                // token after comment is the value
+                value = Extract::theInt(lineTokens[i], "MeterParser::doParse, could not extract meter value");
+                break;
+            }
+            if (lineTokens[i] == "#")
+                comment_fnd = true;
+        }
+    }
+
+    bool check = (rootParser()->get_file_type() != PrintStyle::NET);
+
+    nodeStack_top()->add_meter(lineTokens[1], min, max, colorChange, value, check);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/MeterParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/MeterParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/MeterParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/MeterParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_MeterParser_HPP
+#define ecflow_node_parser_MeterParser_HPP
+
+//============================================================================
+// Name        :
+// Author      : Avi
+// Revision    : $Revision: #6 $
+//
+// Copyright 2009- ECMWF.
+// This software is licensed under the terms of the Apache Licence version 2.0
+// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+// In applying this licence, ECMWF does not waive the privileges and immunities
+// granted to it by virtue of its status as an intergovernmental organisation
+// nor does it submit to any jurisdiction.
+//
+// Description :
+//============================================================================
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class MeterParser : public Parser {
+public:
+    explicit MeterParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "meter"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_MeterParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/MirrorParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/MirrorParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/MirrorParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/MirrorParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,112 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/MirrorParser.hpp"
+
+#include <stdexcept>
+
+#include <boost/program_options.hpp>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+namespace {
+
+template <typename T>
+auto get_option_value(const boost::program_options::variables_map& vm,
+                      const std::string& option_name,
+                      const std::string& line) {
+    if (!vm.count(option_name)) {
+        throw std::runtime_error("AvisoParser::doParse: Could not find '" + option_name + "' option in line: " + line);
+    }
+    return vm[option_name].as<T>();
+}
+
+template <>
+auto get_option_value<bool>(const boost::program_options::variables_map& vm,
+                            const std::string& option_name,
+                            const std::string& line) {
+    return vm.count(option_name) ? true : false;
+}
+
+} // namespace
+
+ecf::MirrorAttr MirrorParser::parse_mirror_line(const std::string& line) {
+    return parse_mirror_line(line, nullptr);
+}
+
+ecf::MirrorAttr MirrorParser::parse_mirror_line(const std::string& line, const std::string& name) {
+    return parse_mirror_line(line, name, nullptr);
+}
+
+ecf::MirrorAttr MirrorParser::parse_mirror_line(const std::string& line, const std::string& name, Node* parent) {
+    auto updated_line = line + " --name " + name;
+    return parse_mirror_line(updated_line, parent);
+}
+
+ecf::MirrorAttr MirrorParser::parse_mirror_line(const std::string& line, Node* parent) {
+    std::vector<std::string> tokens;
+    {
+        // Since po::command_line_parser requires a vector of strings, we need convert from string_view to string
+        std::vector<std::string_view> extracted = ecf::Str::tokenize_quotation(line, "'");
+        std::transform(std::begin(extracted),
+                       std::end(extracted),
+                       std::back_inserter(tokens),
+                       [](const std::string_view& sv) { return std::string{sv}; });
+    }
+
+    namespace po = boost::program_options;
+    po::options_description description("MirrorParser");
+    description.add_options()(option_name, po::value<std::string>());
+    description.add_options()(option_remote_path, po::value<std::string>());
+    description.add_options()(option_remote_host,
+                              po::value<std::string>()->default_value(ecf::MirrorAttr::default_remote_host));
+    description.add_options()(option_remote_port,
+                              po::value<std::string>()->default_value(ecf::MirrorAttr::default_remote_port));
+    description.add_options()(option_polling,
+                              po::value<std::string>()->default_value(ecf::MirrorAttr::default_polling));
+    description.add_options()(option_ssl, "Use SSL");
+    description.add_options()(option_remote_auth,
+                              po::value<std::string>()->default_value(ecf::MirrorAttr::default_remote_auth));
+    description.add_options()(option_reason, po::value<std::string>()->default_value(""));
+
+    po::parsed_options parsed_options = po::command_line_parser(tokens).options(description).run();
+
+    po::variables_map vm;
+    po::store(parsed_options, vm);
+    po::notify(vm);
+
+    auto name        = get_option_value<ecf::MirrorAttr::name_t>(vm, option_name, line);
+    auto ecflow_path = get_option_value<ecf::MirrorAttr::remote_path_t>(vm, option_remote_path, line);
+    auto ecflow_host = get_option_value<ecf::MirrorAttr::remote_host_t>(vm, option_remote_host, line);
+    auto ecflow_port = get_option_value<ecf::MirrorAttr::remote_port_t>(vm, option_remote_port, line);
+    auto polling     = get_option_value<ecf::MirrorAttr::polling_t>(vm, option_polling, line);
+    auto ssl         = get_option_value<ecf::MirrorAttr::flag_t>(vm, option_ssl, line);
+    auto auth        = get_option_value<ecf::MirrorAttr::auth_t>(vm, option_remote_auth, line);
+    auto reason      = get_option_value<ecf::MirrorAttr::reason_t>(vm, option_reason, line);
+
+    return ecf::MirrorAttr{parent, name, ecflow_path, ecflow_host, ecflow_port, polling, ssl, auth, reason};
+}
+
+bool MirrorParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (nodeStack().empty()) {
+        throw std::runtime_error("MirrorParser::doParse: Could not add 'mirror' as node stack is empty at line: " +
+                                 line);
+    }
+
+    Node* parent = nodeStack_top();
+
+    auto parsed = parse_mirror_line(line, parent);
+    nodeStack_top()->addMirror(parsed);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/MirrorParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/MirrorParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/MirrorParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/MirrorParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_MirrorParser_HPP
+#define ecflow_node_parser_MirrorParser_HPP
+
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/parser/Parser.hpp"
+
+/**
+ * This class is used to parse an Mirror attribute for a Node, stored in a single line of a definition file.
+ *
+ * The Mirror definition line is composed of the following tokens:
+ *  "mirror"
+ *    - keyword, mandatory
+ *  --name <value>
+ *    - string value (must be valid name), mandatory
+ *  --ecflow_host '<value>'
+ *    - json value (enclosed in single quotes), mandatory
+ *  --ecflow_port <value>
+ *    - string value (formed of <scheme>://<host>[:<port>]), mandatory
+ *  --polling <value>
+ *    - string value (path to the Aviso schema file, accessible to the ecFlow server), mandatory
+ *
+ * The tokens can be separated provided in any order, with any number of spaces between them being disregarded.
+ * Apart from the tokens above, retrieved from the definition line, the parser also determines the 'path' of the Node
+ * to which the 'Aviso' attribute belongs -- this is stored in the parsed 'Aviso' object.
+ */
+
+class MirrorParser : public Parser {
+public:
+    static constexpr const char* keyword_mirror     = "mirror";
+    static constexpr const char* option_name        = "name";
+    static constexpr const char* option_remote_path = "remote_path";
+    static constexpr const char* option_remote_host = "remote_host";
+    static constexpr const char* option_remote_port = "remote_port";
+    static constexpr const char* option_polling     = "polling";
+    static constexpr const char* option_ssl         = "ssl";
+    static constexpr const char* option_remote_auth = "remote_auth";
+    static constexpr const char* option_reason      = "reason";
+
+    static ecf::MirrorAttr parse_mirror_line(const std::string& line);
+    static ecf::MirrorAttr parse_mirror_line(const std::string& line, const std::string& name);
+    static ecf::MirrorAttr parse_mirror_line(const std::string& line, const std::string& name, Node* parent);
+    static ecf::MirrorAttr parse_mirror_line(const std::string& line, Node* parent);
+
+    explicit MirrorParser(DefsStructureParser* p) : Parser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return keyword_mirror; }
+};
+
+#endif /* ecflow_node_parser_AvisoParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/Parser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/Parser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/Parser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/Parser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,173 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/Parser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Stl.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+#ifdef SHOW_PARSER_STATS
+    #include "ecflow/core/Indentor.hpp"
+#endif
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+using namespace boost::gregorian;
+
+// #define DEBUG_PARSER 1
+
+template <class T>
+ostream& operator<<(ostream& os, const vector<T>& v) {
+    copy(v.begin(), v.end(), ostream_iterator<T>(cout, ","));
+    return os;
+}
+
+// ===============================================================================
+
+Parser::Parser(DefsStructureParser* p)
+    : parent_(nullptr),
+      rootParser_(p)
+#ifdef SHOW_PARSER_STATS
+      ,
+      parserCount_(0)
+#endif
+{
+}
+
+Parser::~Parser() {
+    DeletePtrs(expectedParsers_);
+}
+
+bool Parser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    const char* first_token = lineTokens[0].c_str();
+    size_t theSize          = expectedParsers_.size();
+    for (size_t i = 0; i < theSize; ++i) {
+        Parser* p = expectedParsers_[i];
+
+        if (Str::local_strcmp(first_token, p->keyword()) == 0) {
+
+#ifdef SHOW_PARSER_STATS
+            p->incrementParserCount(); // used for stats
+#endif
+
+            return p->doParse(line, lineTokens);
+        }
+    }
+
+#ifdef DEBUG_PARSER
+    cerr << "Parser::" << keyword() << " token = '" << *lineTokens.begin() << "' did not match parsers(";
+    for (Parser* p : expectedParsers_) {
+        cerr << " " << p->keyword();
+    }
+    cerr << ") Trying parent ";
+    if (parent())
+        cout << "Parser::" << parent()->keyword();
+    cerr << "\n";
+#endif
+
+    // Parent should handle "endfamily", "family" and "endsuite" for hierarchical families
+    if (parent() &&
+        ((Str::local_strcmp(first_token, "endfamily") == 0) || (Str::local_strcmp(first_token, "family") == 0) ||
+         (Str::local_strcmp(first_token, "endsuite") == 0))) {
+        return parent()->doParse(line, lineTokens);
+    }
+
+    // Check if first token is '#' comment character
+    // very first non space character is # comment, hence ignore this line
+    if (*first_token == '#') {
+        // std::cout << "Ignoring line with leading comment : " << line << "\n";
+        return true;
+    }
+
+    // Does not match any parser, or leading comment
+    std::string errorMsg = "# Unexpected keyword ";
+    errorMsg += *lineTokens.begin();
+    errorMsg += " found whilst parsing ";
+    errorMsg += keyword();
+    if (!nodeStack().empty()) {
+        errorMsg += " ";
+        errorMsg += nodeStack_top()->absNodePath();
+    }
+
+    // in MIGRATE be fault tolerant, ignore unrecognised tokens
+    if (PrintStyle::is_persist_style(rootParser()->get_file_type())) {
+        rootParser()->faults() += errorMsg + " -> ignoring\n";
+        return true;
+    }
+
+    throw std::runtime_error(errorMsg);
+    return false;
+}
+
+Defs* Parser::defsfile() const {
+    return rootParser_->defsfile_;
+}
+std::stack<std::pair<Node*, const Parser*>>& Parser::nodeStack() const {
+    return rootParser_->nodeStack_;
+}
+Node* Parser::nodeStack_top() const {
+    return rootParser_->nodeStack_.top().first;
+}
+std::unordered_map<Node*, bool>& Parser::defStatusMap() const {
+    return rootParser_->defStatusMap_;
+}
+
+void Parser::dumpStackTop(const std::string& msg, const std::string& msg2) const {
+    std::cout << msg << "  '" << msg2 << "' ++++++++++++++++++++++++++++++++++++++++++++++++++\n";
+    if (rootParser_->nodeStack_.empty())
+        std::cout << "nodeStack_ is EMPTY\n";
+    else
+        std::cout << "TOP = " << rootParser_->nodeStack_.top().first->debugType() << " '"
+                  << rootParser_->nodeStack_.top().first->name() << "'\n";
+}
+
+void Parser::addParser(Parser* p) {
+    p->parent(this);
+    expectedParsers_.push_back(p);
+}
+
+void Parser::popNode() const {
+    nodeStack().pop();
+}
+
+void Parser::popToContainerNode() const {
+    while (!nodeStack().empty() && !nodeStack_top()->isNodeContainer()) {
+        nodeStack().pop(); // keep poping till we get to family or suite
+    }
+}
+
+void Parser::dump(const std::vector<std::string>& lineTokens) {
+    cout << "tokens:";
+    for (const auto& lineToken : lineTokens) {
+        cout << " '" << lineToken << "' ";
+    }
+    cout << "\n";
+}
+
+#ifdef SHOW_PARSER_STATS
+void Parser::printStats() {
+    Indentor::indent(std::cout) << "Parser::" << keyword() << "\n";
+    for (Parser* p : expectedParsers_) {
+        Indentor::indent(std::cout) << p->keyword() << " " << p->parserCount() << "\n";
+    }
+
+    Indentor in;
+    for (Parser* p : expectedParsers_) {
+        if (p->hasChildren()) {
+            p->printStats();
+        }
+    }
+}
+#endif
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/Parser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/Parser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/Parser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/Parser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,73 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_Parser_HPP
+#define ecflow_node_parser_Parser_HPP
+
+#include <stack>
+#include <string>
+#include <unordered_map>
+#include <vector>
+
+class DefsStructureParser;
+class Node;
+class Defs;
+
+// #define SHOW_PARSER_STATS 1
+
+class Parser {
+public:
+    explicit Parser(DefsStructureParser* p);
+    virtual ~Parser();
+
+    // if child does not recognise token try the parent
+    virtual bool doParse(const std::string& line, std::vector<std::string>& lineTokens);
+    Parser* parent() const { return parent_; }
+    void parent(Parser* p) { parent_ = p; }
+
+    virtual const char* keyword() const = 0;
+
+    DefsStructureParser* rootParser() const { return rootParser_; }
+
+    // convenience function that access DefsStructureParser
+    std::stack<std::pair<Node*, const Parser*>>& nodeStack() const;
+    Node* nodeStack_top() const;
+    std::unordered_map<Node*, bool>& defStatusMap() const;
+
+#ifdef SHOW_PARSER_STATS
+    // The following function used in parser stats only
+    void printStats();
+#endif
+
+protected:
+    Defs* defsfile() const;
+    void dumpStackTop(const std::string& msg, const std::string& msg2 = "") const;
+    void addParser(Parser* p);
+    void popNode() const;
+    void popToContainerNode() const;
+    static void dump(const std::vector<std::string>& lineTokens);
+    void reserve_vec(int res) { expectedParsers_.reserve(res); }
+
+private:
+    bool hasChildren() const { return !expectedParsers_.empty(); }
+
+    Parser* parent_;
+    DefsStructureParser* rootParser_;
+    std::vector<Parser*> expectedParsers_;
+
+#ifdef SHOW_PARSER_STATS
+    // The following function used in parser stats only
+    void incrementParserCount() { parserCount_++; }
+    int parserCount() const { return parserCount_; }
+    int parserCount_;
+#endif
+};
+
+#endif /* ecflow_node_parser_Parser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/QueueParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/QueueParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/QueueParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/QueueParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/QueueParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool QueueParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (nodeStack().empty()) {
+        throw std::runtime_error("QueueParser::doParse: Could not add queue, as node stack is empty at line: " + line);
+    }
+
+    bool parse_state = false;
+    if (rootParser()->get_file_type() != PrintStyle::DEFS)
+        parse_state = true;
+
+    QueueAttr queue_attr;
+    QueueAttr::parse(queue_attr, line, lineTokens, parse_state);
+    Node* node = nodeStack_top();
+    node->add_queue(queue_attr);
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/QueueParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/QueueParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/QueueParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/QueueParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_QueueParser_HPP
+#define ecflow_node_parser_QueueParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class QueueParser : public Parser {
+public:
+    explicit QueueParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "queue"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_QueueParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/RepeatParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/RepeatParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/RepeatParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/RepeatParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,266 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/RepeatParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+bool RepeatParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    size_t line_token_size = lineTokens.size();
+    if (line_token_size < 3)
+        throw std::runtime_error("RepeatParser::doParse: Invalid repeat " + line);
+    if (nodeStack().empty())
+        throw std::runtime_error("RepeatParser::doParse: Could not add repeat as node stack is empty at line: " + line);
+
+    string errorMsg = "Invalid repeat : ";
+    errorMsg += line;
+
+    if (lineTokens[1] == "date") {
+        // repeat date VARIABLE yyyymmdd yyyymmdd [delta]
+        if (line_token_size < 5)
+            throw std::runtime_error(errorMsg);
+
+        string name  = lineTokens[2];
+        int startYMD = Extract::ymd(lineTokens[3], errorMsg);
+        int endYMD   = Extract::ymd(lineTokens[4], errorMsg);
+        int delta    = Extract::optionalInt(lineTokens, 5, 1, errorMsg);
+        RepeatDate rep(name, startYMD, endYMD, delta);
+        int value = 0;
+        if (get_value(lineTokens, value))
+            rep.set_value(value);
+
+        nodeStack_top()->addRepeat(Repeat(rep));
+    }
+    else if (lineTokens[1] == "datetime") {
+        // repeat datetime VARIABLE yyyy-mm-ddTMM:HH:SS yyyy-mm-ddTMM:HH:SS [MM:HH[:SS]]
+        if (line_token_size < 5)
+            throw std::runtime_error(errorMsg);
+
+        string name      = lineTokens[2];
+        Instant startYMD = Instant::parse(lineTokens[3]);
+        Instant endYMD   = Instant::parse(lineTokens[4]);
+        Duration delta   = Duration{std::chrono::seconds{86400}}; // by default, consider delta = 24 hours
+        if (line_token_size >= 6) {
+            delta = Duration::parse(lineTokens[5]);
+        }
+        RepeatDateTime rep(name, startYMD, endYMD, delta);
+        ecf::Instant value;
+        if (get_value(lineTokens, value)) {
+            rep.set_value(coerce_from_instant(value));
+        }
+
+        nodeStack_top()->addRepeat(Repeat(rep));
+    }
+    else if (lineTokens[1] == "datelist") {
+
+        if (line_token_size < 4)
+            throw std::runtime_error(errorMsg);
+
+        // repeat datelist VARIABLE "YYYYMMDD" "YYYYMMDD" "YYYYMMDD" # comment
+        string name = lineTokens[2];
+        std::vector<int> theEnums;
+        theEnums.reserve(line_token_size);
+        for (size_t i = 3; i < line_token_size; i++) {
+            std::string theEnum = lineTokens[i];
+            if (theEnum[0] == '#')
+                break;
+            Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
+            Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
+
+            int date = 0;
+            try {
+                date = ecf::convert_to<int>(theEnum);
+            }
+            catch (const ecf::bad_conversion&) {
+                throw std::runtime_error("RepeatParser::doParse: repeat datelist " + name +
+                                         ", invalid date : " + theEnum);
+            }
+            theEnums.push_back(date);
+        }
+        if (theEnums.empty())
+            throw std::runtime_error(errorMsg);
+
+        RepeatDateList rep(name, theEnums);
+        int index = 0; // This is *assumed to be the index* and not the value
+        if (get_value(lineTokens, index))
+            rep.set_value(index);
+
+        nodeStack_top()->addRepeat(Repeat(rep));
+    }
+    else if (lineTokens[1] == "enumerated") {
+
+        if (line_token_size < 4)
+            throw std::runtime_error(errorMsg);
+
+        // repeat enumerated VARIABLE "first" "second" "last" # comment
+        string name = lineTokens[2];
+        std::vector<std::string> theEnums;
+        theEnums.reserve(line_token_size);
+        for (size_t i = 3; i < line_token_size; i++) {
+            std::string theEnum = lineTokens[i];
+            if (theEnum[0] == '#')
+                break;
+            Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
+            Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
+            theEnums.push_back(theEnum);
+        }
+        if (theEnums.empty())
+            throw std::runtime_error(errorMsg);
+
+        RepeatEnumerated rep(name, theEnums);
+        int index = 0; // This is *assumed to be the index* and not the value
+        if (get_value(lineTokens, index))
+            rep.set_value(index);
+
+        nodeStack_top()->addRepeat(Repeat(rep));
+    }
+    else if (lineTokens[1] == "integer") {
+        // repeat integer VARIABLE start end [step]
+        if (line_token_size < 5)
+            throw std::runtime_error(errorMsg);
+
+        string name = lineTokens[2];
+        int start   = Extract::theInt(lineTokens[3], errorMsg);
+        int end     = Extract::theInt(lineTokens[4], errorMsg);
+        int step    = Extract::optionalInt(lineTokens, 5, 1, errorMsg);
+        RepeatInteger rep(name, start, end, step);
+        int value = 0;
+        if (get_value(lineTokens, value))
+            rep.set_value(value);
+
+        nodeStack_top()->addRepeat(Repeat(rep));
+    }
+    else if (lineTokens[1] == "day") {
+        // repeat day step [ yyyymmdd ]  # the step can be positive or negative
+        // *** See RepeatAttr.h ***
+        // *** We will not support end date until there is a clear requirement for this
+        int step = Extract::theInt(lineTokens[2], "Invalid repeat day:");
+
+        // report end date as a parser error
+        if (line_token_size >= 4 && lineTokens[3][0] != '#') {
+            throw std::runtime_error("RepeatParser::doParse: repeat day, <end-date> not supported: " + line);
+        }
+        // day has no state
+        nodeStack_top()->addRepeat(Repeat(RepeatDay(step)));
+    }
+    else if (lineTokens[1] == "string") {
+
+        if (line_token_size < 4)
+            throw std::runtime_error(errorMsg);
+
+        string name = lineTokens[2];
+        std::vector<std::string> theEnums;
+        theEnums.reserve(line_token_size);
+        for (size_t i = 3; i < line_token_size; i++) {
+            std::string theEnum = lineTokens[i];
+            if (theEnum[0] == '#')
+                break;
+            Str::removeSingleQuotes(theEnum); // remove quotes, they get added back when we persist
+            Str::removeQuotes(theEnum);       // remove quotes, they get added back when we persist
+            theEnums.push_back(theEnum);
+        }
+        if (theEnums.empty())
+            throw std::runtime_error(errorMsg);
+
+        RepeatString rep(name, theEnums);
+        int index = 0;
+        if (get_value(lineTokens, index))
+            rep.set_value(index);
+
+        nodeStack_top()->addRepeat(Repeat(rep));
+    }
+    else if (lineTokens[1] == "month") {
+        // repeat month step [ yyyymmdd ]  # the step can be positive or negative
+        throw std::runtime_error("RepeatParser::doParse: repeat month not supported: " + line);
+
+        //		int endDate = 0;
+        //		int step = 0;
+        //		extractDayMonthYear( lineTokens, step, endDate );
+        //		nodeStack_top()->addRepeat( Repeat( RepeatMonth( step, endDate ) ) );
+    }
+    else if (lineTokens[1] == "year") {
+        // repeat year step [ yyyymmdd ]  # the step can be positive or negative
+        throw std::runtime_error("RepeatParser::doParse: repeat year not supported: " + line);
+        //		int endDate = 0;
+        //		int step = 0;
+        //		extractDayMonthYear( lineTokens, step, endDate );
+        //		nodeStack_top()->addRepeat( Repeat( RepeatYear( step, endDate ) ) );
+    }
+    else if (lineTokens[1] == "file") {
+        // NOT SUPPORTED
+    }
+    else {
+        throw std::runtime_error("RepeatParser::doParse: Invalid repeat " + line);
+    }
+    return true;
+}
+
+// void RepeatParser::extractDayMonthYear( const std::vector< std::string >& lineTokens,
+//										int& x,
+//										int& endDate )
+//{
+//	x = Extract::theInt( lineTokens[2], "invalid repeat" );
+//	if ( lineTokens.size() >= 4 && lineTokens[3][0] != '#') {
+//		std::string errorMsg = "Invalid repeat";
+//		endDate = Extract::ymd( lineTokens[3], errorMsg );
+//  	}
+//	if ( ! nodeStack_top()->isSuite() ) {
+//		throw std::runtime_error( "RepeatParser::doParse: Invalid repeat day/month/year only valid for suite "
+//);
+//	}
+// }
+
+bool RepeatParser::get_value(const std::vector<std::string>& lineTokens, int& value) const {
+    // state
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        // search back for comment
+        // repeat integer VARIABLE start end [step] # value
+        std::string token_after_comment;
+        for (size_t i = lineTokens.size() - 1; i > 3; i--) {
+            if (lineTokens[i] == "#") {
+                // token after comment is the value
+                value = Extract::theInt(token_after_comment, "RepeatParser::doParse, could not extract repeat value");
+                return true;
+            }
+            else
+                token_after_comment = lineTokens[i];
+        }
+    }
+    return false;
+}
+
+bool RepeatParser::get_value(const std::vector<std::string>& lineTokens, Instant& value) const {
+    // state
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        // search back for comment
+        // repeat integer VARIABLE start end [step] # value
+        std::string token_after_comment;
+        for (size_t i = lineTokens.size() - 1; i > 3; i--) {
+            if (lineTokens[i] == "#") {
+                // token after comment is the value
+                value = Instant::parse(token_after_comment);
+                return true;
+            }
+            else
+                token_after_comment = lineTokens[i];
+        }
+    }
+    return false;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/RepeatParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/RepeatParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/RepeatParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/RepeatParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_RepeatParser_HPP
+#define ecflow_node_parser_RepeatParser_HPP
+
+#include "ecflow/core/Chrono.hpp"
+#include "ecflow/node/parser/Parser.hpp"
+
+class RepeatParser : public Parser {
+public:
+    explicit RepeatParser(DefsStructureParser* p) : Parser(p) {}
+
+    const char* keyword() const override { return "repeat"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+
+private:
+    // void extractDayMonthYear(const std::vector<std::string>& lineTokens,int& x, int& endDate);
+    bool get_value(const std::vector<std::string>& lineTokens, int& value) const;
+    bool get_value(const std::vector<std::string>& lineTokens, ecf::Instant& value) const;
+};
+
+#endif
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/TimeParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/TimeParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/TimeParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/TimeParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,47 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/TimeParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/TimeSeries.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool TimeParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    size_t line_tokens_size = lineTokens.size();
+    if (line_tokens_size < 2)
+        throw std::runtime_error("TimeParser::doParse: Invalid time :" + line);
+
+    bool parse_state = false;
+    bool isFree      = false;
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        parse_state      = true;
+        bool comment_fnd = false;
+        for (size_t i = 2; i < line_tokens_size; i++) {
+            if (comment_fnd && lineTokens[i] == "free")
+                isFree = true;
+            if (lineTokens[i] == "#")
+                comment_fnd = true;
+        }
+    }
+
+    size_t index = 1;
+    TimeAttr attr(TimeSeries::create(index, lineTokens, parse_state));
+    if (isFree)
+        attr.setFree();
+
+    nodeStack_top()->addTime(attr);
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/TimeParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/TimeParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/TimeParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/TimeParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_TimeParser_HPP
+#define ecflow_node_parser_TimeParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class TimeParser : public Parser {
+public:
+    explicit TimeParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "time"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_TimeParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/TodayParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/TodayParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/TodayParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/TodayParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,47 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/TodayParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool TodayParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    size_t line_tokens_size = lineTokens.size();
+    if (line_tokens_size < 2)
+        throw std::runtime_error("TodayParser::doParse: Invalid today :" + line);
+
+    bool parse_state = false;
+    bool isFree      = false;
+    if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+        parse_state      = true;
+        bool comment_fnd = false;
+        for (size_t i = 2; i < line_tokens_size; i++) {
+            if (comment_fnd && lineTokens[i] == "free")
+                isFree = true;
+            if (lineTokens[i] == "#")
+                comment_fnd = true;
+        }
+    }
+
+    size_t index = 1;
+    TodayAttr attr(TimeSeries::create(index, lineTokens, parse_state));
+    if (isFree)
+        attr.setFree();
+
+    nodeStack_top()->addToday(attr);
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/TodayParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/TodayParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/TodayParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/TodayParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_TodayParser_HPP
+#define ecflow_node_parser_TodayParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class TodayParser : public Parser {
+public:
+    explicit TodayParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "today"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_TodayParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/TriggerParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/TriggerParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/TriggerParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/TriggerParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,182 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/TriggerParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+
+static bool hasExtension(const std::string& line, const std::vector<std::string>& lineTokens) {
+    //    cout << "hasExtension = ";
+    if (line[line.size() - 1] == '\\') {
+        //       cout << "true\n";
+        return true;
+    }
+    const std::string& lastToken = lineTokens.back();
+    if (lastToken == "\\" || lastToken[lastToken.size() - 1] == '\\') {
+        //       cout << "true\n";
+        return true;
+    }
+    //    cout << "false\n";
+    return false;
+}
+
+// ===============================================================================
+
+void TriggerCompleteParser::getExpression(const std::string& line,
+                                          std::vector<std::string>& theLineTokens,
+                                          std::string& expression,
+                                          bool& andExp,
+                                          bool& orExp,
+                                          bool& isFree) const {
+    assert(*theLineTokens.begin() == keyword());
+    if (theLineTokens.size() < 2)
+        throw std::runtime_error("Invalid " + std::string(keyword()) + " " + line);
+
+    // trigger -a n == complete
+    // complete -o n == complete
+    if (theLineTokens[1] == "-a") {
+        andExp = true;
+        theLineTokens.erase(theLineTokens.begin() + 1);
+    }
+    else if (theLineTokens[1] == "-o") {
+        orExp = true;
+        theLineTokens.erase(theLineTokens.begin() + 1);
+    }
+
+    // Handle continuations, by removing them and adding to expression
+    if (hasExtension(line, theLineTokens)) {
+        /*
+             trigger a == complete and  /
+                         b == complete
+         */
+        std::vector<std::string> accumalatedTokens = theLineTokens;
+        while (true) {
+
+            std::string line2;
+            rootParser()->getNextLine(line2);
+
+            std::vector<std::string> lineTokens2;
+            Str::split(line2, lineTokens2);
+
+            std::copy(lineTokens2.begin(), lineTokens2.end(), std::back_inserter(accumalatedTokens));
+
+            if (!hasExtension(line2, lineTokens2)) {
+                break;
+            }
+
+            if (accumalatedTokens.back() == "\\") { // remove continuation
+                accumalatedTokens.pop_back();
+            }
+        }
+
+        size_t accumalated_tokens_size = accumalatedTokens.size();
+        for (size_t i = 1; i < accumalated_tokens_size; i++) {
+            std::string token = accumalatedTokens[i];
+            if (token[token.size() - 1] == '\\') {
+                token.erase(token.begin() + token.size() - 1);
+            }
+            if (token.empty())
+                continue;
+            if (token.at(0) == '#')
+                break;
+            if (i != 1)
+                expression += " ";
+            expression += token;
+        }
+    }
+    else {
+
+        // lineTokens[0] == "trigger";/ "complete"
+        size_t line_token_size = theLineTokens.size();
+        expression.reserve(line.size());
+        for (size_t i = 1; i < line_token_size; i++) {
+            if (theLineTokens[i].at(0) == '#')
+                break;
+            if (i != 1)
+                expression += " ";
+            expression += theLineTokens[i];
+        }
+
+        // state
+        if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+            bool comment_fnd = false;
+            for (size_t i = 3; i < line_token_size; i++) {
+                if (comment_fnd) {
+                    if (theLineTokens[i] == "free") {
+                        isFree = true;
+                        break;
+                    }
+                }
+                if (theLineTokens[i] == "#")
+                    comment_fnd = true;
+            }
+        }
+    }
+
+    //	cout << "expression = '" << expression << "'\n";
+    if (expression.empty())
+        throw std::runtime_error("Invalid trigger " + line);
+}
+
+bool TriggerParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    bool andExp = false;
+    bool orExp  = false;
+    bool isFree = false;
+    std::string expression;
+    getExpression(line, lineTokens, expression, andExp, orExp, isFree);
+
+    if (!nodeStack().empty()) {
+        Node* node = nodeStack_top();
+        if (!andExp && !orExp)
+            node->add_part_trigger(PartExpression(std::move(expression)));
+        else if (andExp)
+            node->add_part_trigger(PartExpression(std::move(expression), true));
+        else if (orExp)
+            node->add_part_trigger(PartExpression(std::move(expression), false));
+        else
+            throw std::runtime_error("Invalid trigger " + line);
+        if (isFree)
+            node->freeTrigger();
+    }
+
+    return true;
+}
+
+bool CompleteParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    bool andExp = false;
+    bool orExp  = false;
+    bool isFree = false;
+    std::string expression;
+    getExpression(line, lineTokens, expression, andExp, orExp, isFree);
+
+    if (!nodeStack().empty()) {
+        Node* node = nodeStack_top();
+        if (!andExp && !orExp)
+            node->add_part_complete(PartExpression(std::move(expression)));
+        else if (andExp)
+            node->add_part_complete(PartExpression(std::move(expression), true));
+        else if (orExp)
+            node->add_part_complete(PartExpression(std::move(expression), false));
+        else
+            throw std::runtime_error("Invalid complete trigger " + line);
+        if (isFree)
+            node->freeComplete();
+    }
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/TriggerParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/TriggerParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/TriggerParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/TriggerParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_TriggerParser_HPP
+#define ecflow_node_parser_TriggerParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class TriggerCompleteParser : public Parser {
+protected:
+    explicit TriggerCompleteParser(DefsStructureParser* p) : Parser(p) {}
+    void getExpression(const std::string& line,
+                       std::vector<std::string>& lineTokens,
+                       std::string& expression,
+                       bool& andExr,
+                       bool& orExpr,
+                       bool& isFree) const;
+};
+
+class TriggerParser : public TriggerCompleteParser {
+public:
+    explicit TriggerParser(DefsStructureParser* p) : TriggerCompleteParser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return "trigger"; }
+};
+
+class CompleteParser : public TriggerCompleteParser {
+public:
+    explicit CompleteParser(DefsStructureParser* p) : TriggerCompleteParser(p) {}
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+    const char* keyword() const override { return "complete"; }
+};
+
+#endif /* ecflow_node_parser_TriggerParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/VariableParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/VariableParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/VariableParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/VariableParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,128 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/VariableParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool VariableParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // Note: For migrate the defs can have variables
+    Node* node = nullptr;
+    if (nodeStack().empty()) {
+        if (!parsing_defs_)
+            throw std::runtime_error(
+                "VariableParser::doParse: Could not add variable, as node stack is empty at line: " + line);
+    }
+    else
+        node = nodeStack_top();
+
+    size_t line_tokens_size = lineTokens.size();
+    if (line_tokens_size < 3) {
+        std::stringstream ss;
+        ss << "VariableParser::doParse: expected at least 3 tokens, found " << line_tokens_size << " on line:" << line
+           << "\n";
+        if (node)
+            ss << "At node: " << node->debugNodePath() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // There is no need check for '#' comment character in variable name
+    // since the variable constructor will check for this
+    // i.e  edit #var value
+    //      edit var# value
+
+    // Make sure value does not begin with '#' comment character
+    if (lineTokens[2][0] == '#') {
+        // edit fred #comment
+        // edit fred #
+        std::stringstream ss;
+        ss << "VariableParser::doParse: Expected value but found comment at line:" << line << "\n";
+        if (node)
+            ss << "At node: " << node->debugNodePath() << "\n";
+        throw std::runtime_error(ss.str());
+    }
+
+    // ** For aliases, the variables may be **different** to normal variables in that they may contain a ":" & $
+    // ** This is **not** allowed in normal variables.
+    // ** i.e it allows for  %A:1%, %A:2%, %A:3%
+    // ** This is not really recommended but its what the old system supported.
+    // ** Hence the variable construction by-passes variable name checking ***
+
+    bool net = (rootParser()->get_file_type() == PrintStyle::NET);
+
+    // Note:
+    // edit OWNER 'fred'               => value = fred
+    // edit OWNER 'fred and "ginger"'  => value = fred and "ginger"
+    // edit OWNER ""                   => value =
+    // edit OWNER ''                   => value =
+    // edit OWNER '"fred"'             => value = "fred"   * quotes are preserved *
+    // edit OWNER "'fred'"             => value = fred     * tick are not preserved *
+    if (line_tokens_size == 3) {
+        // The order of removing double quotes and then single quotes is significant here
+        Str::removeQuotes(lineTokens[2]);       // if first *and* last character is "
+        Str::removeSingleQuotes(lineTokens[2]); // if first *and* last character is '
+        if (node) {
+            if (net || node->isAlias())
+                node->add_variable_bypass_name_check(lineTokens[1], lineTokens[2]); // bypass name checking
+            else
+                node->add_variable(lineTokens[1], lineTokens[2]);
+        }
+        else
+            defsfile()->set_server().add_or_update_user_variables(lineTokens[1], lineTokens[2]);
+        return true;
+    }
+
+    // i.e
+    //  0     1         2
+    // edit var_name "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  #fred
+    // edit var_name "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # server  // server variables on Defs
+    std::string value;
+    value.reserve(line.size() - 4);
+    size_t comment_pos = 0;
+    for (size_t i = 2; i < line_tokens_size; ++i) {
+        if (lineTokens[i].at(0) == '#') {
+            comment_pos = i;
+            break;
+        }
+        if (i != 2)
+            value += " ";
+        value += lineTokens[i];
+    }
+
+    Str::removeQuotes(value);
+    Str::removeSingleQuotes(value);
+    if (node) {
+        if (net || node->isAlias())
+            node->add_variable_bypass_name_check(lineTokens[1], value); // bypass name checking
+        else
+            node->add_variable(lineTokens[1], value);
+    }
+    else {
+        bool server_variable = false;
+        if (comment_pos != 0 && comment_pos + 1 < line_tokens_size) {
+            if (lineTokens[comment_pos + 1] == "server")
+                server_variable = true;
+        }
+        if (server_variable)
+            defsfile()->set_server().add_or_update_server_variable(lineTokens[1], value);
+        else
+            defsfile()->set_server().add_or_update_user_variables(lineTokens[1], value);
+    }
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/VariableParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/VariableParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/VariableParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/VariableParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,51 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_VariableParser_HPP
+#define ecflow_node_parser_VariableParser_HPP
+
+///
+/// \brief
+///   edit fred 'val'
+///   edit FRED "smscheck %WSHOST% %EXPVER% %ECF_JOB%"
+///
+/// In the old SMS single quotes are used if no interpretation
+/// is required and double quotes to allow variable substitution
+/// However this is ONLY a requirement for CDP.
+/// Note when OLD SMS uses the show command it always outputs with single quotes
+///
+/// Do we remove the quotes when we store internally ?
+///   i.e if we have :
+///      edit YMD '20090901'
+/// Then the value '20090901' is not immediately convertible to an integer
+/// *************************************************************
+/// This is required for evaluation in the abstract syntax tree
+/// *************************************************************
+///
+/// Hence we will do the following:
+///   a/ On parsing always remove quotes ie single or double
+///   b/ On serialising always add single quotes
+///
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class VariableParser : public Parser {
+public:
+    explicit VariableParser(DefsStructureParser* p, bool parsing_defs = false)
+        : Parser(p),
+          parsing_defs_(parsing_defs) {}
+    const char* keyword() const override { return "edit"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+
+private:
+    bool parsing_defs_;
+};
+
+#endif
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/VerifyParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/VerifyParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/VerifyParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/VerifyParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,69 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/VerifyParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Extract.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool VerifyParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // expect:
+    //    verify <state>:<expected> # actual  i.e
+    //    verify complete:3 # 2
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("VerifyParser::doParse: Invalid verify :" + line);
+
+    if (!nodeStack().empty()) {
+        Node* node = nodeStack_top();
+
+        std::string stateInt = lineTokens[1];
+
+        size_t colonPos = stateInt.find_first_of(':');
+        if (colonPos == std::string::npos)
+            throw std::runtime_error("Invalid verify :" + line);
+
+        std::string state    = stateInt.substr(0, colonPos);
+        std::string expected = stateInt.substr(colonPos + 1);
+        // cout << "state = " << state << "\n";
+        // cout << "expected = " << expected << "\n";
+
+        if (!NState::isValid(state)) {
+            throw std::runtime_error("VerifyParser::doParse: Invalid state :" + line);
+        }
+
+        NState::State theState  = NState::toState(state);
+        int theExpectedStateCnt = Extract::theInt(expected, "Invalid verify");
+
+        // STATE
+        int actual = 0;
+        if (rootParser()->get_file_type() != PrintStyle::DEFS) {
+            if (lineTokens.size() >= 4) {
+                if (lineTokens[2] == "#") {
+                    try {
+                        actual = ecf::convert_to<int>(lineTokens[3]);
+                    }
+                    catch (const ecf::bad_conversion&) { /* ignore could be other comment */
+                    }
+                }
+            }
+        }
+
+        node->addVerify(VerifyAttr(theState, theExpectedStateCnt, actual));
+    }
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/VerifyParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/VerifyParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/VerifyParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/VerifyParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,29 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_VerifyParser_HPP
+#define ecflow_node_parser_VerifyParser_HPP
+
+///
+/// \brief A verify attribute parser.
+///
+/// Note that verify are only used for verification and do not constitute to the structure of a definition file
+///
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class VerifyParser : public Parser {
+public:
+    explicit VerifyParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "verify"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_VerifyParser_HPP */
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.cpp 5.13.0-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.cpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/node/parser/ZombieAttrParser.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace ecf;
+using namespace std;
+
+bool ZombieAttrParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    // expect:  tokenizer
+    //    zombie <zombie_type>: action : child_cmds :  lifetime
+    //    zombie_type = [ user | ecf | ecf_pid | ecf_pid_passwd | ecf_passwd| path ]  # can only have one
+    //    action      = [ fob | fail | block | remove | adopt ]                       # can only have one
+    //    child_cmd   = [ init, event, meter, label, wait, abort, complete ]          # can have multiple
+    //    zombie ecf:fob::                                                            # fob all child commands
+    //    zombie ecf:fail:event,meter:200                                             # fail child command  event,meter
+    //    and block other children
+    if (lineTokens.size() < 2)
+        throw std::runtime_error("ZombieAttrParser::doParse: Invalid zombie :" + line);
+    if (nodeStack().empty())
+        throw std::runtime_error("Add zombie failed empty node stack");
+
+    // cout << "ZombieAttrParser::doParse: " << lineTokens[1] << "\n";
+
+    nodeStack_top()->addZombie(ZombieAttr::create(lineTokens[1]));
+
+    return true;
+}
diff -pruN 5.12.4-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.hpp 5.13.0-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.hpp
--- 5.12.4-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/src/ecflow/node/parser/ZombieAttrParser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_ZombieAttrParser_HPP
+#define ecflow_node_parser_ZombieAttrParser_HPP
+
+#include "ecflow/node/parser/Parser.hpp"
+
+class ZombieAttrParser : public Parser {
+public:
+    explicit ZombieAttrParser(DefsStructureParser* p) : Parser(p) {}
+    const char* keyword() const override { return "zombie"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+};
+
+#endif /* ecflow_node_parser_ZombieAttrParser_HPP */
diff -pruN 5.12.4-1/libs/node/test/MyDefsFixture.hpp 5.13.0-1/libs/node/test/MyDefsFixture.hpp
--- 5.12.4-1/libs/node/test/MyDefsFixture.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/MyDefsFixture.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,288 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_test_MyDefsFixture_HPP
+#define ecflow_node_test_MyDefsFixture_HPP
+
+///
+/// \brief The structure ONLY used to test the persistence/migration
+/// as each new object is created we add it here, to test Serialisation
+/// read/write and migration of previous fixtures.
+///
+
+#include <algorithm>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MiscAttrs.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+// =======================================================================
+// This struct is used in the node migration tests.
+// If we ever add to this , then update TestMigration.cpp
+// **Ensure** that we keep old fixture.def file, to test that future ecflow
+// versions can migrate old data.
+// =======================================================================
+struct MyDefsFixture
+{
+
+    explicit MyDefsFixture(const std::string& port = ecf::Str::DEFAULT_PORT_NUMBER()) : defsfile_(port) {
+        suite_ptr suite = create_suite();
+
+        // Must be done last
+        defsfile_.addSuite(suite);
+        defsfile_.add_extern("/limits:event");
+        defsfile_.add_extern("/a/b/c:meter");
+        defsfile_.add_extern("/a/b/c/d");
+
+        // add an empty suite. Needed for CHECK_JOB_GEN_ONLY cmd
+        defsfile_.addSuite(Suite::create("EmptySuite"));
+
+        // Check expression parse
+        std::string errorMsg, warningMsg;
+        bool result = defsfile_.check(errorMsg, warningMsg);
+        if (!result || !errorMsg.empty()) {
+            std::cout << errorMsg;
+            assert(false);
+        }
+    }
+    ~MyDefsFixture() = default;
+
+    const Defs& fixtureDefsFile() const { return defsfile_; }
+
+    defs_ptr create_defs(const std::string& port = ecf::Str::DEFAULT_PORT_NUMBER()) const {
+
+        defs_ptr defs = Defs::create(port);
+
+        defs->addSuite(create_suite());
+        defs->add_extern("/limits:event");
+        defs->add_extern("/a/b/c:meter");
+        defs->add_extern("/a/b/c/d");
+        defs->set_server().add_or_update_user_variables("MyDefsFixture_user_variable",
+                                                        "This is a user variable added to server");
+        defs->set_server().add_or_update_server_variable("MyDefsFixture_server_variable", "This is a server variable");
+
+        // add an empty suite. Needed for CHECK_JOB_GEN_ONLY cmd
+        defs->addSuite(Suite::create("EmptySuite"));
+
+        // Check expression parse
+        std::string errorMsg, warningMsg;
+        bool result = defs->check(errorMsg, warningMsg);
+        if (!result || !errorMsg.empty()) {
+            std::cout << errorMsg;
+            assert(false);
+        }
+        return defs;
+    }
+
+    Defs defsfile_;
+
+private:
+    suite_ptr create_suite() const {
+        std::string sname = "suiteName";
+        suite_ptr suite   = Suite::create(sname);
+
+        ClockAttr clockAttr(false);
+        clockAttr.date(1, 1, 2009);
+        clockAttr.set_gain_in_seconds(3600);
+        suite->addClock(clockAttr);
+
+        suite->addAutoCancel(ecf::AutoCancelAttr(2));
+        suite->addVariable(Variable("VAR", "value"));
+        suite->addVariable(Variable("VAR1", "\"value\""));
+        suite->addVariable(Variable("ECF_FETCH", "\"smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%\""));
+
+        std::vector<std::string> queue_items;
+        queue_items.emplace_back("000");
+        queue_items.emplace_back("001");
+        queue_items.emplace_back("002");
+        suite->add_queue(QueueAttr("queue", queue_items));
+        suite->add_queue(QueueAttr("queue1", queue_items));
+        suite->add_generic(GenericAttr("gen1", queue_items));
+        suite->add_generic(GenericAttr("gen2", queue_items));
+        suite->add_task("t1");
+        suite->add_task("t2");
+        task_ptr suiteTask = suite->add_task("t3");
+        suiteTask->add_part_trigger(PartExpression("t1 == complete"));
+        suiteTask->add_part_trigger(PartExpression("t2 == complete", false));
+        suiteTask->add_part_complete(PartExpression("t1 == complete"));
+        suiteTask->add_part_complete(PartExpression("t2 == complete", true));
+
+        std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
+        suiteTask->addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
+        suiteTask->addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
+        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
+        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::FAIL, 100));
+        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::FAIL, 100));
+        suiteTask->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::FAIL, 100));
+
+        task_ptr suiteTask4 = suite->add_task("t4");
+        suiteTask4->addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::ADOPT, 10));
+        suiteTask4->addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
+        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::REMOVE, 100));
+        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::KILL, 100));
+        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::FOB, 100));
+        suiteTask4->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::BLOCK, 100));
+
+        ecf::CronAttr cronAttr;
+        ecf::TimeSlot start(0, 0);
+        ecf::TimeSlot finish(10, 0);
+        ecf::TimeSlot incr(0, 5);
+        std::vector<int> weekdays;
+        for (int i = 0; i < 7; ++i)
+            weekdays.push_back(i);
+        std::vector<int> daysOfMonth;
+        for (int i = 1; i < 32; ++i)
+            daysOfMonth.push_back(i);
+        std::vector<int> months;
+        for (int i = 1; i < 13; ++i)
+            months.push_back(i);
+        cronAttr.addTimeSeries(start, finish, incr);
+        cronAttr.addWeekDays(weekdays);
+        cronAttr.addDaysOfMonth(daysOfMonth);
+        cronAttr.addMonths(months);
+        suite->addCron(cronAttr);
+
+        ecf::LateAttr lateAttr;
+        lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
+        lateAttr.addActive(ecf::TimeSlot(3, 12));
+        lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
+
+        std::string suiteLimit  = "suiteLimit";
+        std::string suiteLimit2 = "suiteLimit2";
+        std::string suiteLimit3 = "suiteLimit3";
+        suite->addLimit(Limit(suiteLimit, 10));
+        suite->addLimit(Limit(suiteLimit2, 10));
+        suite->addLimit(Limit(suiteLimit3, 10));
+
+        // Add tasks with all the repeat variants
+        std::vector<std::string> stringList{"10", "20", "30"};
+        task_ptr t5 = suite->add_task("t5");
+        t5->addRepeat(RepeatEnumerated("AEnum", stringList));
+
+        task_ptr t6 = suite->add_task("t6");
+        t6->addRepeat(RepeatString("aString", stringList));
+
+        task_ptr t7 = suite->add_task("t7");
+        t7->addRepeat(RepeatInteger("rep", 0, 100, 1));
+
+        task_ptr t8 = suite->add_task("t8");
+        t8->addRepeat(RepeatDate("YMD", 20090916, 20090916, 1));
+
+        task_ptr t9 = suite->add_task("t9");
+        t9->addRepeat(RepeatDateList("YMD", {20090916, 20090916}));
+
+        task_ptr t10 = suite->add_task("t10");
+        t10->addRepeat(RepeatDay(2));
+
+        suite->add_family("f1")->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
+        suite->add_family("f2")->add_autoarchive(ecf::AutoArchiveAttr(5, 22, true));
+        suite->add_family("f3")->add_autoarchive(ecf::AutoArchiveAttr(4));
+        suite->add_family("f4")->add_autoarchive(ecf::AutoArchiveAttr(0));
+        suite->add_family("f5")->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true, true));
+        suite->add_family("f6")->add_autoarchive(ecf::AutoArchiveAttr(5, 22, true, true));
+        suite->add_family("f7")->add_autoarchive(ecf::AutoArchiveAttr(4, true));
+        suite->add_family("f8")->add_autoarchive(ecf::AutoArchiveAttr(0, true));
+
+        for (int i = 0; i < 3; ++i) {
+            std::string fname     = "familyName";
+            std::string tname     = "taskName";
+            std::string eventName = "eventName";
+            std::string labelName = "labelName";
+            std::string limitName = "limitName";
+            if (i != 0) {
+                fname += ecf::convert_to<std::string>(i);
+                tname += ecf::convert_to<std::string>(i);
+                labelName += ecf::convert_to<std::string>(i);
+            }
+
+            family_ptr fam = suite->add_family(fname);
+            fam->addDate(DateAttr(0, 0, 2009)); // 0 is equivalent to a *
+            fam->addRepeat(RepeatEnumerated("AEnum", stringList));
+            fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), true));
+            fam->addVariable(Variable("VAR", "value"));
+            fam->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), true));
+            fam->addLimit(Limit(limitName, 20));
+            fam->addLate(lateAttr);
+            fam->addInLimit(InLimit(suiteLimit2, "/" + sname, 2, true /*limit this node only*/));
+            fam->add_queue(QueueAttr("queue1", queue_items));
+            fam->add_generic(GenericAttr("gen1", queue_items));
+
+            task_ptr task = fam->add_task(tname);
+            task->addDate(DateAttr(1, 2, 2009));
+            task->addDay(DayAttr(DayAttr::MONDAY));
+            task->addVariable(Variable("VAR1", "\"value\""));
+            task->addEvent(Event(i));
+            task->addEvent(Event(i + 1, eventName));
+            task->addEvent(Event(i + 2, "my_event", true /*init value*/));
+            task->addMeter(Meter("myMeter", 0, 100, 100));
+            task->addLabel(Label(labelName, "\"labelValue\""));
+            task->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 10), true));
+            task->addToday(ecf::TodayAttr(ecf::TimeSlot(10, 12)));
+            task->addToday(ecf::TodayAttr(ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 3), ecf::TimeSlot(0, 1), true));
+            task->addDefStatus(DState::COMPLETE);
+            task->addInLimit(InLimit(suiteLimit, "/" + sname));
+            task->addInLimit(
+                InLimit(suiteLimit3, "/" + sname, 1, false /*limit this node only*/, true /*limit submission*/));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 3));
+            task->addLate(lateAttr);
+            task->add_queue(QueueAttr("queue1", queue_items));
+            task->add_generic(GenericAttr("gen1", queue_items));
+            task->add_generic(GenericAttr("gen2", std::vector<std::string>()));
+
+            std::vector<std::string> nodes_to_restore;
+            nodes_to_restore.emplace_back("/EmptySuite");
+            task->add_autorestore(ecf::AutoRestoreAttr(nodes_to_restore));
+            if (i == 2) {
+                std::string compExpr = "../familyName" + ecf::convert_to<std::string>(i - 1);
+                compExpr += "/taskName" + ecf::convert_to<std::string>(i - 1);
+                compExpr += ":myMeter ge 10";
+                task->add_complete(compExpr);
+
+                std::string expression = "../familyName" + ecf::convert_to<std::string>(i - 1);
+                expression += "/taskName" + ecf::convert_to<std::string>(i - 1);
+                expression += " == complete";
+                task->add_trigger(expression);
+            }
+            task->add_alias_only(); // add alias without creating dir & .usr file
+            task->add_alias_only();
+
+            // Add a hierarchical family to the first family
+            if (i == 0) {
+                std::string heirFamily = "heir_" + fname;
+                family_ptr hierFam     = fam->add_family(heirFamily);
+                hierFam->addVariable(Variable("VAR1", "value"));
+                hierFam->addRepeat(RepeatString("aString", stringList));
+                hierFam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
+
+                task_ptr task1 = hierFam->add_task(tname);
+                task1->addVariable(Variable("VAR1", "value"));
+                task1->addEvent(Event(i));
+                task1->addEvent(Event(i + 1, eventName));
+                task1->addEvent(Event(i + 2, "my_event", true /*init value*/));
+                task1->addMeter(Meter("myMeter", 0, 100, 100));
+                task1->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(0, 1), false));
+            }
+        }
+        return suite;
+    }
+};
+
+#endif /* ecflow_node_test_MyDefsFixture_HPP */
diff -pruN 5.12.4-1/libs/node/test/TestAdd.cpp 5.13.0-1/libs/node/test/TestAdd.cpp
--- 5.12.4-1/libs/node/test/TestAdd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestAdd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,119 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Add)
+
+BOOST_AUTO_TEST_CASE(test_add) {
+    cout << "ANode:: ...test_add\n";
+
+    defs_ptr defs = Defs::create();
+    task_ptr t1   = Task::create("t1");
+    family_ptr f1 = Family::create("f1");
+    suite_ptr s1  = Suite::create("s1");
+
+    defs->addSuite(s1);
+    s1->addFamily(f1);
+    f1->addTask(t1);
+
+    defs_ptr defs2 = Defs::create();
+    suite_ptr s2   = Suite::create("s2");
+    family_ptr f2  = Family::create("f2");
+
+    // This should all fail since, they are already owned.
+    // Otherwise we end up with two different container owning the same object
+    BOOST_CHECK_THROW(s2->addFamily(f1), std::runtime_error);
+    BOOST_CHECK_THROW(f2->addTask(t1), std::runtime_error);
+    BOOST_CHECK_THROW(defs2->addSuite(s1), std::runtime_error);
+}
+
+BOOST_AUTO_TEST_CASE(test_add_error) {
+    cout << "ANode:: ...test_add_error\n";
+
+    defs_ptr defs = Defs::create();
+    suite_ptr s1  = defs->add_suite("s1");
+    s1->add_task("t1");
+    s1->add_family("f1");
+    BOOST_CHECK_THROW(defs->add_suite("s1"), std::runtime_error); // duplicate suite
+    BOOST_CHECK_THROW(s1->add_task("t1"), std::runtime_error);    // duplicate task
+    BOOST_CHECK_THROW(s1->add_family("t1"), std::runtime_error);  // duplicate name
+    BOOST_CHECK_THROW(s1->add_task("f1"), std::runtime_error);    // duplicate name
+}
+
+BOOST_AUTO_TEST_CASE(test_add_delete_time) {
+    cout << "ANode:: ...test_add_delete_time\n"; // ECFLOW-1260
+
+    // Make sure that if we delete any time based attributes
+    Defs defs;
+    suite_ptr s1 = defs.add_suite("s1");
+    task_ptr t1  = s1->add_task("t1");
+
+    BOOST_REQUIRE_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
+
+    ecf::CronAttr cronAttr;
+    ecf::TimeSlot start(0, 0);
+    ecf::TimeSlot finish(10, 0);
+    ecf::TimeSlot incr(0, 5);
+    std::vector<int> weekdays;
+    for (int i = 0; i < 7; ++i)
+        weekdays.push_back(i);
+    std::vector<int> daysOfMonth;
+    for (int i = 1; i < 32; ++i)
+        daysOfMonth.push_back(i);
+    std::vector<int> months;
+    for (int i = 1; i < 13; ++i)
+        months.push_back(i);
+    cronAttr.addTimeSeries(start, finish, incr);
+    cronAttr.addWeekDays(weekdays);
+    cronAttr.addDaysOfMonth(daysOfMonth);
+    cronAttr.addMonths(months);
+    t1->addCron(cronAttr);
+    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
+    t1->deleteCron("");
+    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
+
+    t1->addDate(DateAttr(1, 2, 2009));
+    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
+    t1->deleteDate("");
+    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
+
+    t1->addDay(DayAttr(DayAttr::MONDAY));
+    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
+    t1->deleteDay("");
+    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
+
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), true));
+    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
+    t1->deleteTime("");
+    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
+
+    t1->addToday(ecf::TodayAttr(ecf::TimeSlot(10, 12)));
+    BOOST_CHECK_MESSAGE(t1->hasTimeDependencies(), "Expected time attributes");
+    t1->deleteToday("");
+    BOOST_CHECK_MESSAGE(!t1->hasTimeDependencies(), "Expected no time attributes");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestAlias.cpp 5.13.0-1/libs/node/test/TestAlias.cpp
--- 5.12.4-1/libs/node/test/TestAlias.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestAlias.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,151 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Alias)
+
+BOOST_AUTO_TEST_CASE(test_alias_create) {
+    cout << "ANode:: ...test_alias_create\n";
+    std::string ecf_home = File::test_data("ANode/test/data/alias", "ANode");
+
+    task_ptr t;
+    Defs theDefs;
+    {
+        suite_ptr s  = theDefs.add_suite("test_alias_create");
+        family_ptr f = s->add_family("f");
+        t            = f->add_task("t");
+        // ECFLOW-1278  set values for event,meter,labels, then ensure alias creation clears them
+        Meter meter1("met", 0, 100, 100);
+        meter1.set_value(10);
+        Meter meter2("met2", 0, 100, 100);
+        meter2.set_value(10);
+        Event event1(1, "event1");
+        event1.set_value(true);
+        Event event2(1, "event2");
+        event2.set_value(true);
+        Label label1("name", "value");
+        label1.set_new_value("new_value");
+        Label label2("name2", "value");
+        label2.set_new_value("new_value");
+        t->addMeter(meter1);
+        t->addMeter(meter2);
+        t->addEvent(event1);
+        t->addEvent(event2);
+        t->addLabel(label1);
+        t->addLabel(label2);
+        s->add_variable(Str::ECF_HOME(), ecf_home);
+    }
+
+    // Create .usr file content
+    std::vector<std::string> usr_file_vec;
+    usr_file_vec.emplace_back("#This is a .usr file.");
+
+    // Create list of variables
+    NameValueVec used_variables;
+    used_variables.push_back(std::make_pair(std::string("a"), std::string("a_value")));
+    used_variables.push_back(std::make_pair(std::string("b"), std::string("b_value")));
+
+    // Finally create the alias.
+    alias_ptr alias = t->add_alias(usr_file_vec, used_variables);
+
+    // Test that default node state is QUEUED
+    BOOST_CHECK_MESSAGE(alias->state() == NState::QUEUED, "Expected initial state of QUEUED");
+
+    // Test that CHILD specific attributes event, meter, labels are copied over from the task  AND that they are reset.
+    BOOST_CHECK_MESSAGE(alias->meters().size() == 2,
+                        "Expected 2 meter to be copied from task but found " << alias->meters().size());
+    BOOST_CHECK_MESSAGE(alias->events().size() == 2,
+                        "Expected 2 events to be copied from task but found " << alias->events().size());
+    BOOST_CHECK_MESSAGE(alias->labels().size() == 2,
+                        "Expected 2 labels to be copied from task but found " << alias->labels().size());
+    for (const Meter& meter : alias->meters()) {
+        BOOST_CHECK_MESSAGE(meter.value() == meter.min(),
+                            "Expected meter value " << meter.min() << " but found " << meter.value() << " for "
+                                                    << meter.dump());
+    }
+    for (const Event& event : alias->events()) {
+        BOOST_CHECK_MESSAGE(!event.value(), "Expected " << event.dump() << " to be clear");
+    }
+    for (const Label& label : alias->labels()) {
+        BOOST_CHECK_MESSAGE(label.new_value().empty(), "Expected " << label.dump() << " to be clear");
+    }
+
+    // Ensure Task state was not changed
+    BOOST_CHECK_MESSAGE(t->meters().size() == 2,
+                        "Did not expect task state to change, expected 2 meter but found: " << t->meters().size());
+    BOOST_CHECK_MESSAGE(t->events().size() == 2,
+                        "Did not expect task state to change, expected 2 events but found:" << t->events().size());
+    BOOST_CHECK_MESSAGE(t->labels().size() == 2,
+                        "Did not expect task state to change, expected 2 labels but found:" << t->labels().size());
+    for (const Meter& meter : t->meters()) {
+        BOOST_CHECK_MESSAGE(meter.value() == 10,
+                            "Expected meter value 10 but found " << meter.value() << " for " << meter.dump());
+    }
+    for (const Event& event : t->events()) {
+        BOOST_CHECK_MESSAGE(event.value(), "Expected " << event.dump() << " to be set");
+    }
+    for (const Label& label : t->labels()) {
+        BOOST_CHECK_MESSAGE(label.new_value() == "new_value",
+                            "Expected label with 'new_value' but found " << label.new_value());
+    }
+
+    // test that user variables passed in got added as Variables
+    BOOST_CHECK_MESSAGE(alias->variables().size() == 2,
+                        "Expected 2 variables to be create from input args but found " << alias->variables().size());
+
+    // Test directory creation
+    fs::path dir(ecf_home + "/" + t->absNodePath());
+    BOOST_CHECK_MESSAGE(fs::exists(dir), "Expected directory to be created " + dir.string());
+
+    // Test alias0.usr file creation
+    fs::path usr_file(ecf_home + "/" + t->absNodePath() + "/" + "alias0.usr");
+    BOOST_CHECK_MESSAGE(fs::exists(usr_file), "Expected alias0.usr file to be created " + usr_file.string());
+
+    // Create another alias. This should get created as alias1.usr
+    alias_ptr alias1 = t->add_alias(usr_file_vec, used_variables);
+    fs::path usr_file1(ecf_home + "/" + t->absNodePath() + "/" + "alias1.usr");
+    BOOST_CHECK_MESSAGE(fs::exists(usr_file1), "Expected alias1.usr file to be created " + usr_file1.string());
+
+    // Test Defs::get_all_aliases()
+    std::vector<alias_ptr> alias_vec;
+    theDefs.get_all_aliases(alias_vec);
+    BOOST_CHECK_MESSAGE(alias_vec.size() == 2, "Expected 2 aliases but found " << alias_vec.size());
+
+    // Check alias remove
+    for (alias_ptr al : alias_vec) {
+        al->remove();
+    }
+    alias_vec.clear();
+    theDefs.get_all_aliases(alias_vec);
+    BOOST_CHECK_MESSAGE(alias_vec.empty(), "Expected no aliases but found " << alias_vec.size());
+
+    // Cleanup by removing the created directory
+    fs::remove_all(ecf_home);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestAssignmentOperator.cpp 5.13.0-1/libs/node/test/TestAssignmentOperator.cpp
--- 5.12.4-1/libs/node/test/TestAssignmentOperator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestAssignmentOperator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,180 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "ecflow/core/Ecf.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_AssignmentOperator)
+
+BOOST_AUTO_TEST_CASE(test_defs_assignment_operator) {
+    cout << "ANode:: ...test_defs_assignment_operator\n";
+    MyDefsFixture theDefsFixture;
+
+    Defs defs;
+    defs = theDefsFixture.defsfile_;
+    Ecf::set_debug_equality(true); // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(defs == theDefsFixture.defsfile_, "assignment failed");
+    Ecf::set_debug_equality(false); // only has affect in DEBUG build
+
+    Defs empty;
+    defs = empty;
+    Ecf::set_debug_equality(true); // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(defs == empty, "assignment failed");
+    Ecf::set_debug_equality(false); // only has affect in DEBUG build
+
+    BOOST_CHECK_MESSAGE(!(defs == theDefsFixture.defsfile_), "assignment failure EXPECTED");
+
+    theDefsFixture.defsfile_ = empty;
+    BOOST_CHECK_MESSAGE(theDefsFixture.defsfile_ == empty, "assignment failed");
+}
+
+BOOST_AUTO_TEST_CASE(test_suite_assignment_operator) {
+    cout << "ANode:: ...test_suite_assignment_operator\n";
+    Suite empty("empty");
+
+    Suite s1("s1");
+    ClockAttr clockAttr(false);
+    clockAttr.date(1, 1, 2009);
+    clockAttr.set_gain_in_seconds(3600);
+    s1.addClock(clockAttr);
+    s1.addAutoCancel(ecf::AutoCancelAttr(2));
+    s1.addVariable(Variable("VAR", "value"));
+    s1.add_task("t1");
+    s1.add_family("f1");
+    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
+    s1.addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
+    s1.addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
+    s1.addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
+
+    ecf::CronAttr cronAttr;
+    ecf::TimeSlot start(0, 0);
+    ecf::TimeSlot finish(10, 0);
+    ecf::TimeSlot incr(0, 5);
+    std::vector<int> weekdays;
+    for (int i = 0; i < 7; ++i)
+        weekdays.push_back(i);
+    std::vector<int> daysOfMonth;
+    for (int i = 1; i < 32; ++i)
+        daysOfMonth.push_back(i);
+    std::vector<int> months;
+    for (int i = 1; i < 13; ++i)
+        months.push_back(i);
+    cronAttr.addTimeSeries(start, finish, incr);
+    cronAttr.addWeekDays(weekdays);
+    cronAttr.addDaysOfMonth(daysOfMonth);
+    cronAttr.addMonths(months);
+    s1.addCron(cronAttr);
+
+    ecf::LateAttr lateAttr;
+    lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
+    lateAttr.addActive(ecf::TimeSlot(3, 12));
+    lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
+
+    std::string suiteLimit = "suiteLimit";
+    s1.addLimit(Limit(suiteLimit, 10));
+
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    Suite s2(s1);                 // s2 is copy
+    BOOST_CHECK_MESSAGE(s1 == s2, "copy constructor failed");
+
+    Suite s3("s3");
+    s3 = empty;
+    BOOST_CHECK_MESSAGE(s3 == empty, "assignment failed");
+
+    s3 = s1;
+    BOOST_CHECK_MESSAGE(s3 == s1, "assignment failed");
+
+    s1 = s2;
+    BOOST_CHECK_MESSAGE(s1 == s2, "assignment failed");
+}
+
+BOOST_AUTO_TEST_CASE(test_task_assignment_operator) {
+    cout << "ANode:: ...test_task_assignment_operator\n";
+    Task empty("empty");
+
+    Task s1("s1");
+    s1.addAutoCancel(ecf::AutoCancelAttr(2));
+    s1.addVariable(Variable("VAR", "value"));
+    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
+    s1.addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
+    s1.addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
+    s1.addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
+
+    ecf::CronAttr cronAttr;
+    ecf::TimeSlot start(0, 0);
+    ecf::TimeSlot finish(10, 0);
+    ecf::TimeSlot incr(0, 5);
+    std::vector<int> weekdays;
+    for (int i = 0; i < 7; ++i)
+        weekdays.push_back(i);
+    std::vector<int> daysOfMonth;
+    for (int i = 1; i < 32; ++i)
+        daysOfMonth.push_back(i);
+    std::vector<int> months;
+    for (int i = 1; i < 13; ++i)
+        months.push_back(i);
+    cronAttr.addTimeSeries(start, finish, incr);
+    cronAttr.addWeekDays(weekdays);
+    cronAttr.addDaysOfMonth(daysOfMonth);
+    cronAttr.addMonths(months);
+    s1.addCron(cronAttr);
+
+    ecf::LateAttr lateAttr;
+    lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
+    lateAttr.addActive(ecf::TimeSlot(3, 12));
+    lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
+
+    std::string suiteLimit = "suiteLimit";
+    s1.addLimit(Limit(suiteLimit, 10));
+
+    s1.addDate(DateAttr(1, 2, 2009));
+    s1.addDay(DayAttr(DayAttr::MONDAY));
+    s1.addVariable(Variable("VAR1", "\"value\""));
+    s1.addEvent(Event(1));
+    s1.addEvent(Event(2, "eventname"));
+    s1.addEvent(Event(3, "eventname2", true /* init value */));
+    s1.addEvent(Event(4, "eventname4", true /* init value */, true /* value */));
+    s1.addMeter(Meter("myMeter", 0, 100, 100));
+    s1.addLabel(Label("label", "\"labelValue\""));
+    s1.addTime(ecf::TimeAttr(ecf::TimeSlot(10, 10), true));
+    s1.addToday(ecf::TodayAttr(ecf::TimeSlot(10, 12)));
+    s1.addToday(ecf::TodayAttr(ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 3), ecf::TimeSlot(0, 1), true));
+    s1.addDefStatus(DState::COMPLETE);
+    s1.addInLimit(InLimit(suiteLimit, "/name"));
+    s1.addVerify(VerifyAttr(NState::COMPLETE, 3));
+    s1.addLate(lateAttr);
+
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    Task s2(s1);                  // s2 is copy
+    BOOST_CHECK_MESSAGE(s1 == s2, "copy constructor failed");
+
+    Task s3("s3");
+    s3 = empty;
+    BOOST_CHECK_MESSAGE(s3 == empty, "assignment failed");
+
+    s3 = s1;
+    BOOST_CHECK_MESSAGE(s3 == s1, "assignment failed");
+
+    s1 = s2;
+    BOOST_CHECK_MESSAGE(s1 == s2, "assignment failed");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestChangeMgrSingleton.cpp 5.13.0-1/libs/node/test/TestChangeMgrSingleton.cpp
--- 5.12.4-1/libs/node/test/TestChangeMgrSingleton.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestChangeMgrSingleton.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,129 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/AbstractObserver.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+class MyObserver : public AbstractObserver {
+public:
+    explicit MyObserver(Defs* defs) : update_count_(0), defs_(defs), node_(nullptr) { defs->attach(this); }
+    explicit MyObserver(Node* node) : update_count_(0), defs_(nullptr), node_(node) { node->attach(this); }
+
+    ~MyObserver() override {
+        /* std::cout << "~MyObserver()\n"; */
+        if (defs_)
+            defs_->detach(this);
+        if (node_)
+            node_->detach(this);
+    }
+
+    void update_start(const Node*, const std::vector<ecf::Aspect::Type>&) override {}
+    void update_start(const Defs*, const std::vector<ecf::Aspect::Type>&) override {}
+
+    void update(const Node*, const std::vector<ecf::Aspect::Type>&) override { update_count_++; }
+    void update(const Defs*, const std::vector<ecf::Aspect::Type>&) override { update_count_++; }
+
+    /// After this call, the node will be deleted, hence observers must *NOT* use the pointers
+    void update_delete(const Node* node) override {
+        // std::cout << "update_delete(const Node* node)\n";
+        const_cast<Node*>(node)->detach(this);
+    }
+    void update_delete(const Defs* defs) override {
+        // std::cout << "update_delete(const Defs* node)\n";
+        const_cast<Defs*>(defs)->detach(this);
+    }
+
+    int update_count() const { return update_count_; }
+
+private:
+    int update_count_;
+    Defs* defs_;
+    Node* node_;
+};
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_ChangeMgrSingleton)
+
+BOOST_AUTO_TEST_CASE(test_change_mgr_singleton) {
+    cout << "ANode:: ...test_change_mgr_singleton\n";
+    {
+        defs_ptr theDefs = Defs::create();
+
+        {
+            // ensure defs pointer out-lives the observer
+            MyObserver defs_obs(theDefs.get());
+
+            std::vector<ecf::Aspect::Type> aspects;
+            theDefs->notify(aspects);
+            theDefs->notify(aspects);
+            theDefs->notify(aspects);
+            theDefs->notify(aspects);
+            theDefs->notify(aspects);
+            BOOST_CHECK_MESSAGE(defs_obs.update_count() == 5, "Expected 5 update");
+        }
+
+        theDefs.reset();
+    }
+
+    {
+        // **** Note using node_ptr can extend the life of the Node, hence we use scoping ***
+        auto* theDefs = new Defs;
+        std::vector<MyObserver*> obs_vec;
+        {
+            {
+                suite_ptr suite = theDefs->add_suite("suite1");
+                family_ptr fam  = suite->add_family("family");
+                fam->add_task("t1");
+            }
+
+            // get all nodes and observer them.
+            std::vector<node_ptr> node_vec;
+            theDefs->get_all_nodes(node_vec);
+
+            // Need to make sure life time of observer is greater than Node tree
+            for (auto& i : node_vec) {
+                obs_vec.push_back(new MyObserver(i.get()));
+            }
+
+            // Do some updates
+            std::vector<ecf::Aspect::Type> aspects;
+            for (auto& i : node_vec) {
+                i->notify(aspects);
+                i->notify(aspects);
+            }
+            for (auto& i : obs_vec) {
+                BOOST_CHECK_MESSAGE(i->update_count() == 2, "Expected 2 updates");
+            }
+
+            // delete observers
+            for (auto& i : obs_vec) {
+                delete i;
+            }
+        }
+
+        // make sure no node_ptr are in scope as they can *delay*
+        // the destructor to the end of the scope, and hence affect this test
+        delete theDefs;
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestClientSuiteMgr.cpp 5.13.0-1/libs/node/test/TestClientSuiteMgr.cpp
--- 5.12.4-1/libs/node/test/TestClientSuiteMgr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestClientSuiteMgr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,139 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/ClientSuiteMgr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_ClientSuiteMgr)
+
+BOOST_AUTO_TEST_CASE(test_client_suite_mgr_remove_user) {
+    cout << "ANode:: ...test_client_suite_mgr_remove_user\n";
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_client_suite_mgr_remove_user");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+    }
+
+    std::vector<std::string> suites  = {"s1", "s2", "s3"};
+    std::vector<std::string> suites1 = {"s1", "s2", "s3", "s4"};
+    std::vector<std::string> names;
+
+    ClientSuiteMgr mgr(&theDefs);
+
+    unsigned int handle = mgr.create_client_suite(true, suites, "avi");
+    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle), "Expected valid handle");
+    BOOST_CHECK_MESSAGE(handle == 1, "Expected handle 1 but found " << handle);
+    mgr.suites(handle, names);
+    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected");
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
+                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
+
+    names.clear();
+    handle = mgr.create_client_suite(true, suites1, "avi");
+    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle), "Expected valid handle");
+    BOOST_CHECK_MESSAGE(handle == 2, "Expected handle 2 but found " << handle);
+    mgr.suites(handle, names);
+    BOOST_CHECK_MESSAGE(names == suites1, "suite not as expected for handle_fred");
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 2,
+                        "Expected client suite of size 2 but found " << mgr.clientSuites().size());
+
+    names.clear();
+    handle = mgr.create_client_suite(true, suites, "fred");
+    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle), "Expected valid handle");
+    BOOST_CHECK_MESSAGE(handle == 3, "Expected handle 3 but found " << handle);
+    mgr.suites(handle, names);
+    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected for handle_fred");
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 3,
+                        "Expected client suite of size 3 but found " << mgr.clientSuites().size());
+
+    mgr.remove_client_suites("avi"); // should remove two handles
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
+                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
+    BOOST_CHECK_THROW(mgr.remove_client_suites("avi"), std::runtime_error);
+
+    mgr.remove_client_suites("fred");
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 0,
+                        "Expected client suite of size 0 but found " << mgr.clientSuites().size());
+    BOOST_CHECK_THROW(mgr.remove_client_suites("fred"), std::runtime_error);
+}
+
+BOOST_AUTO_TEST_CASE(test_client_suite_mgr_remove_handle) {
+    cout << "ANode:: ...test_client_suite_mgr_remove_handle\n";
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_client_suite_mgr_remove_handle");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+    }
+
+    std::vector<std::string> suites  = {"s1", "s2", "s3"};
+    std::vector<std::string> suites1 = {"s1", "s2", "s3", "s4"};
+    std::vector<std::string> names;
+
+    ClientSuiteMgr mgr(&theDefs);
+
+    unsigned int handle1 = mgr.create_client_suite(true, suites, "avi");
+    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle1), "Expected valid handle");
+    BOOST_CHECK_MESSAGE(handle1 == 1, "Expected handle 1 but found " << handle1);
+    mgr.suites(handle1, names);
+    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected");
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
+                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
+
+    names.clear();
+    unsigned int handle2 = mgr.create_client_suite(true, suites1, "avi");
+    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle2), "Expected valid handle");
+    BOOST_CHECK_MESSAGE(handle2 == 2, "Expected handle 2 but found " << handle2);
+    mgr.suites(handle2, names);
+    BOOST_CHECK_MESSAGE(names == suites1, "suite not as expected for handle_fred");
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 2,
+                        "Expected client suite of size 2 but found " << mgr.clientSuites().size());
+
+    names.clear();
+    unsigned int handle3 = mgr.create_client_suite(true, suites, "fred");
+    BOOST_CHECK_MESSAGE(mgr.valid_handle(handle3), "Expected valid handle");
+    BOOST_CHECK_MESSAGE(handle3 == 3, "Expected handle 3 but found " << handle3);
+    mgr.suites(handle3, names);
+    BOOST_CHECK_MESSAGE(names == suites, "suite not as expected for handle_fred");
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 3,
+                        "Expected client suite of size 3 but found " << mgr.clientSuites().size());
+
+    mgr.remove_client_suite(handle1);
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 2,
+                        "Expected client suite of size 2 but found " << mgr.clientSuites().size());
+    BOOST_CHECK_THROW(mgr.remove_client_suite(handle1), std::runtime_error);
+
+    mgr.remove_client_suite(handle2);
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 1,
+                        "Expected client suite of size 1 but found " << mgr.clientSuites().size());
+    BOOST_CHECK_THROW(mgr.remove_client_suite(handle2), std::runtime_error);
+
+    mgr.remove_client_suite(handle3);
+    BOOST_CHECK_MESSAGE(mgr.clientSuites().size() == 0,
+                        "Expected client suite of size 0 but found " << mgr.clientSuites().size());
+    BOOST_CHECK_THROW(mgr.remove_client_suite(handle3), std::runtime_error);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestCopyConstructor.cpp 5.13.0-1/libs/node/test/TestCopyConstructor.cpp
--- 5.12.4-1/libs/node/test/TestCopyConstructor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestCopyConstructor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,58 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "ecflow/core/Ecf.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_CopyConstructor)
+
+BOOST_AUTO_TEST_CASE(test_copy_constructors) {
+    cout << "ANode:: ...test_copy_constructors\n";
+    MyDefsFixture theDefsFixture;
+
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    Defs copy = Defs(theDefsFixture.defsfile_);
+    BOOST_CHECK_MESSAGE(copy == theDefsFixture.defsfile_, "copy constructor failed");
+}
+
+BOOST_AUTO_TEST_CASE(test_default_constructors) {
+    cout << "ANode:: ...test_default_constructors \n";
+
+    Task t;
+    BOOST_CHECK_MESSAGE(t.check_defaults(), "constructor test for defaults failed");
+
+    Task t2("fred");
+    BOOST_CHECK_MESSAGE(t2.check_defaults(), "constructor test for defaults failed");
+
+    Suite s;
+    BOOST_CHECK_MESSAGE(s.check_defaults(), "constructor test for defaults failed");
+
+    Suite s2("fred");
+    BOOST_CHECK_MESSAGE(s2.check_defaults(), "constructor test for defaults failed");
+
+    Family f;
+    BOOST_CHECK_MESSAGE(f.check_defaults(), "constructor test for defaults failed");
+
+    Family f2("fred");
+    BOOST_CHECK_MESSAGE(f2.check_defaults(), "constructor test for defaults failed");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestDefStatus.cpp 5.13.0-1/libs/node/test/TestDefStatus.cpp
--- 5.12.4-1/libs/node/test/TestDefStatus.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestDefStatus.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,178 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_DefsStatus)
+
+BOOST_AUTO_TEST_CASE(test_defstatus) {
+    cout << "ANode:: ...test_defstatus\n";
+
+    // Create a defs file corresponding to:
+    // suite suite1
+    //	family f1
+    //   	task t1
+    //   	task t2
+    //	family f2
+    //   	task t1
+    //   	task t2
+    Defs theDefs;
+    suite_ptr suite = theDefs.add_suite("suite1");
+    family_ptr f1   = suite->add_family("f1");
+    task_ptr t1     = f1->add_task("t1");
+    task_ptr t2     = f1->add_task("t2");
+
+    family_ptr f2  = suite->add_family("f2");
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+
+    // Get all nodes and tasks for ease of test
+    vector<Node*> nodes;
+    vector<Task*> tasks;
+    theDefs.getAllNodes(nodes);
+    theDefs.getAllTasks(tasks);
+
+    BOOST_CHECK_MESSAGE(!suite->begun(), "Expected suite not to be begun ");
+
+    /// It should be noted that once a suite has begun, it stays begun, however for test purposes we had
+    /// added ability to reset the begin state.
+
+    /// Test 1: with no defstatus. All nodes should be set to NState::QUEUED
+    theDefs.beginAll();
+    BOOST_CHECK_MESSAGE(suite->begun(), "Expected suite to be begun ");
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
+    }
+
+    theDefs.requeue();
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
+    }
+
+    /// Test 2: with defstatus on suite. With complete the status should have been propagated down
+    suite->addDefStatus(DState::COMPLETE);
+    theDefs.reset_begin(); // for test purposes only
+    BOOST_CHECK_MESSAGE(!suite->begun(), "Expected suite not to be begun ");
+
+    theDefs.beginAll();
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
+                            "Expected complete but found " << NState::toString(n->state()));
+    }
+
+    theDefs.requeue();
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
+                            "Expected complete but found " << NState::toString(n->state()));
+    }
+
+    /// Test 3: defstatus of family f1 and f2. The parent node(suite) should reflect status of children
+    /// Also setting defstatus complete on a family should have propagated it downwards to tasks
+    suite->addDefStatus(DState::default_state()); // reset defstatus
+    f1->addDefStatus(DState::COMPLETE);
+    f2->addDefStatus(DState::COMPLETE);
+    theDefs.reset_begin(); // for test purposes only
+    theDefs.beginAll();
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
+                            "Expected complete but found " << NState::toString(n->state()));
+    }
+
+    theDefs.requeue();
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::COMPLETE,
+                            "Expected complete but found " << NState::toString(n->state()));
+    }
+
+    // Suspend is really a user interaction the real state suould be queued
+    f1->addDefStatus(DState::default_state()); // reset defstatus
+    f2->addDefStatus(DState::default_state()); // reset defstatus
+    suite->addDefStatus(DState::SUSPENDED);    // reset defstatus
+    theDefs.reset_begin();                     // for test purposes only
+    theDefs.beginAll();
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
+    }
+
+    theDefs.requeue();
+    for (Node* n : nodes) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_139) {
+    cout << "ANode:: ...test_ECFLOW_139\n";
+
+    // Create a defs file corresponding to:
+    // suite suite1
+    // family f1
+    //    task t1; defstatus suspended
+    //    task t2; defstatus suspended
+    // family f2
+    //    task t1; defstatus suspended
+    //    task t2; defstatus suspended
+    Defs theDefs;
+    suite_ptr suite = theDefs.add_suite("suite1");
+    family_ptr f1   = suite->add_family("f1");
+    task_ptr t1     = f1->add_task("t1");
+    task_ptr t2     = f1->add_task("t2");
+    t1->addDefStatus(DState::SUSPENDED);
+    t2->addDefStatus(DState::SUSPENDED);
+
+    family_ptr f2  = suite->add_family("f2");
+    task_ptr f2_t1 = f2->add_task("t1");
+    task_ptr f2_t2 = f2->add_task("t2");
+    f2_t1->addDefStatus(DState::SUSPENDED);
+    f2_t2->addDefStatus(DState::SUSPENDED);
+
+    // Get all nodes and tasks for ease of test
+    vector<Task*> tasks;
+    theDefs.getAllTasks(tasks);
+
+    /// It should be noted that once a suite has begun, it stays begun, however for test purposes we had
+    /// added ability to reset the begin state.
+
+    /// Test 1: Check NODE state All nodes should be set to NState::QUEUED
+    theDefs.beginAll();
+    for (Task* n : tasks) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
+    }
+
+    /// Check: DSTATE
+    for (Task* n : tasks) {
+        BOOST_CHECK_MESSAGE(n->dstate() == DState::SUSPENDED,
+                            "Expected suspended but found " << DState::toString(n->dstate()));
+    }
+
+    theDefs.requeue();
+    for (Task* n : tasks) {
+        BOOST_CHECK_MESSAGE(n->state() == NState::QUEUED, "Expected queued but found " << NState::toString(n->state()));
+    }
+    for (Task* n : tasks) {
+        BOOST_CHECK_MESSAGE(n->dstate() == DState::SUSPENDED,
+                            "Expected suspended but found " << DState::toString(n->dstate()));
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestDefs.cpp 5.13.0-1/libs/node/test/TestDefs.cpp
--- 5.12.4-1/libs/node/test/TestDefs.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestDefs.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,104 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Defs)
+
+BOOST_AUTO_TEST_CASE(test_defs_absorb) {
+    cout << "ANode:: ...test_defs_absorb\n";
+
+    // Create a defs file corresponding to:
+    // suite suite1
+    //  family family
+    //   	task t1
+    //  endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+    }
+    // Then ABSORB a new def
+    // suite suite1-n
+    //   family family
+    //   		task suite1_task1
+    //   endfamily
+    // endsuite
+    Defs otherDefs;
+    {
+        for (int i = 0; i < 14; ++i) {
+            suite_ptr suite1 = otherDefs.add_suite("suite" + ecf::convert_to<std::string>(i));
+            family_ptr fam   = suite1->add_family("family");
+            fam->add_task("suite1_task1");
+        }
+    }
+
+    theDefs.absorb(&otherDefs, true);
+    BOOST_CHECK_MESSAGE(otherDefs.suiteVec().empty(), "absorb failed");
+}
+
+BOOST_AUTO_TEST_CASE(test_defs_absorb_server_user_variables) {
+    cout << "ANode:: ...test_defs_absorb_server_user_variables\n";
+
+    Defs theDefs;
+    Defs otherDefs;
+    {
+        otherDefs.set_server().add_or_update_user_variables("VAR1", "VAL");
+        otherDefs.set_server().add_or_update_user_variables("VAR2", "VAL");
+        otherDefs.set_server().add_or_update_user_variables("VAR3", "VAL");
+        otherDefs.add_suite("suite");
+    }
+
+    BOOST_CHECK_MESSAGE(theDefs.server().user_variables().empty(), "Expected no server user variables");
+
+    theDefs.absorb(&otherDefs, true);
+
+    BOOST_CHECK_MESSAGE(otherDefs.suiteVec().empty(), "absorb failed");
+    BOOST_CHECK_MESSAGE(theDefs.suiteVec().size() == 1, "absorb failed");
+    BOOST_CHECK_MESSAGE(theDefs.server().user_variables().size() == 3, "Expected 3 server user variables");
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_1684) {
+    cout << "ANode:: ...test_ECFLOW_1684\n";
+
+    Defs defs;
+    defs.add_edit_history("/", "request");
+    defs.add_edit_history("/a/made/up/path1", "request");
+    defs.add_edit_history("/a/made/up/path1", "request2");
+    defs.add_edit_history("/a/made/up/path2", "request2");
+    defs.add_edit_history("/a/made/up/path3", "request2");
+
+    BOOST_CHECK_MESSAGE(defs.get_edit_history().size() == 4,
+                        "Expected edit history of size 4 but found " << defs.get_edit_history().size());
+
+    // This should remove all edit history, where the history paths do not exist as nodes in a defs, BUT need to leave
+    // ROOT as is though.
+    defs.handle_migration();
+    BOOST_CHECK_MESSAGE(defs.get_edit_history().size() == 1,
+                        "Expected edit history of size 1 but found " << defs.get_edit_history().size());
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestEcfFile.cpp 5.13.0-1/libs/node/test/TestEcfFile.cpp
--- 5.12.4-1/libs/node/test/TestEcfFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestEcfFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1697 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib> // for getenv
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Pid.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/EcfFile.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_EcfFile)
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_with_bad_ECF_MICRO) {
+    cout << "ANode:: ...test_ecf_file_with_bad_ECF_MICRO\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  task t1
+    //     ECF_MICRO ""   # cannot be empty if overridden
+    //  task t2
+    //     ECF_MICRO "ss" # must be a single char
+    // endsuite
+
+    task_ptr task_t1;
+    task_ptr task_t2;
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        task_t1         = suite->add_task("t1");
+        task_t1->add_variable("ECF_MICRO", "");
+        task_t2 = suite->add_task("t2");
+        task_t2->add_variable("ECF_MICRO", "ss");
+    }
+
+    // Check we throw for bad ECF_MICRO chars
+    std::string ecf_file_location;
+    BOOST_REQUIRE_THROW(EcfFile ecfFile(task_t1.get(), ecf_file_location), std::runtime_error);
+    BOOST_REQUIRE_THROW(EcfFile ecfFile(task_t2.get(), ecf_file_location), std::runtime_error);
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_simple_include_file) {
+    // The specific files are specified in ECF_INCLUDE and common files
+    // are specified in ECF_HOME. This test will ensure that if the file common.h
+    // is not found in ECF_INCLUDE we then look at ECF_HOME
+    cout << "ANode:: ...test_ecf_simple_include_file";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_simple_include_file"));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string header   = "%include <simple_head.h>\n";
+    string body     = "#body\n";
+    string tail     = "%include <simple_tail.h>\n";
+    string ecf_file = header;
+    ecf_file += body;
+    ecf_file += tail;
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Check generation of '.usr' and job files
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+    // Open the job file/
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+
+    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+    BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
+                        "Expected\n"
+                            << expected_job_file_contents << "' but found \n"
+                            << job_file_contents << "'");
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_495) {
+    // This tests for a regression where, *NOT* all the include file were processed.
+    cout << "ANode:: ...test_ECFLOW_495";
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+    Defs theDefs;
+    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_ECFLOW_495"));
+    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+    task_ptr task_t1 = suite->add_task("t1");
+
+    // PrintStyle style(PrintStyle::STATE);
+    // std::cout << theDefs << "\n";
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    // Create the ecf file; *NOTE* <a.h> includes <b.h>
+    string ecf_file = "%include <a.h>\n";
+    ecf_file += "%PAR_EXE:parallel% --gnu --verbose -j $PAR_THR ${run:-0} ::: $(seq %PAR_BEG:0% %PAR_END:50%)\n";
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+    // Open the job file and check job file contents match what we expected
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+
+    std::string expected_job_file_contents =
+        "#a.h\n#b.h\nparallel --gnu --verbose -j $PAR_THR ${run:-0} ::: $(seq 0 50)";
+    BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
+                        "Expected\n'" << expected_job_file_contents << "' but found \n'" << job_file_contents << "'");
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ECF_SCRIPT_CMD_ECFLOW_427) {
+    cout << "ANode:: ...test_ECF_SCRIPT_CMD_ECFLOW_427";
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name("test_ECF_SCRIPT_CMD_ECFLOW_427"));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("body", "body"));
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string header = "%include <simple_head.h>\n";
+    string body   = "#%body%\n";
+    body += "%manual\nThis is a manual\n%end\n";
+    body += "%comment\nThis is a comment\n%end\n";
+    string tail     = "%include <simple_tail.h>\n";
+    string ecf_file = header;
+    ecf_file += body;
+    ecf_file += tail;
+
+    std::string cmd = "cat %ECF_HOME%/%ECF_NAME%.ecf";
+    task_t1->add_variable("ECF_SCRIPT_CMD", cmd);
+
+    /// Now finally the test, use this as this will perform variable expansion on ECF_SCRIPT_CMD
+    EcfFile ecfFile = task_t1->locatedEcfFile();
+
+    // *******************************************************************************************************
+    // CREATE the file after locatedEcfFile() otherwise it will just use script as is, and NOT ECF_SCRIPT_CMD
+    // *******************************************************************************************************
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    /// Check generation of job files
+    JobsParam jobsParam(true); // spawn_jobs = false
+    {
+        task_t1->update_generated_variables();
+
+        try {
+            ecfFile.create_job(jobsParam);
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+        }
+
+        string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+        BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+        // Open the job file and check contents
+        std::string job_file_contents;
+        BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                            "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+        std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+        BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
+                            "Expected\n'" << expected_job_file_contents << "' but found:\n'" << job_file_contents
+                                          << "'");
+    }
+
+    /// Check pre-processing arbitrary file, should return same result as task pre-processing for job generation
+    {
+        task_t1->update_generated_variables();
+
+        string ecf_file_location = ecf_home + task_t1->absNodePath() + ".ecf";
+        std::vector<std::string> user_edit_file;
+        BOOST_CHECK_MESSAGE(File::splitFileIntoLines(ecf_file_location, user_edit_file),
+                            "Could not open file " << ecf_file_location);
+
+        string processed_file;
+        try {
+            ecfFile.pre_process_user_file(user_edit_file, processed_file);
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Expected pre-processing succeed " << e.what());
+        }
+
+        // because we have read file, as a vector of lines, expect extra \n at the end
+        std::string expected_job_file_contents = "#head.h\n#body\n#tail.h\n";
+        BOOST_CHECK_MESSAGE(processed_file == expected_job_file_contents,
+                            "Expected\n'" << expected_job_file_contents << "' but found:\n'" << processed_file << "'");
+    }
+
+    /// Check manual extraction
+    {
+        std::string manual;
+        try {
+            ecfFile.manual(manual);
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Expected manual extraction to succeed " << e.what());
+        }
+
+        std::string expected_manual = "This is a manual\n";
+        BOOST_CHECK_MESSAGE(manual == expected_manual,
+                            "Expected:\n'" << expected_manual << "' but found:\n'" << manual << "'");
+    }
+
+    /// Check script
+    {
+        std::string script;
+        try {
+            ecfFile.script(script);
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Expected script extraction to succeed " << e.what());
+        }
+        string the_ecf_file = ecfFile.ecf_file_origin_dump() + "\n" + ecf_file;
+        BOOST_CHECK_MESSAGE(script == the_ecf_file,
+                            "Expected:\n'" << the_ecf_file << "' but found:\n'" << script << "'");
+    }
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_include_file) {
+    // The specific files are specified in ECF_INCLUDE and common files
+    // are specified in ECF_HOME. This test will ensure that if the file common.h
+    // is not found in ECF_INCLUDE we then look at ECF_HOME
+    cout << "ANode:: ...test_ecf_include_file";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    // edit SLEEPTIME 10
+    // edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_include_file"));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("SLEEPTIME", "1"));
+        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string header   = "%include <head.h>\n\n";
+    string body     = "%include <common.h>\n\n";
+    string tail     = "%include <tail.h>\n# ===================================";
+    string ecf_file = header;
+    ecf_file += body;
+    ecf_file += tail;
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Check generation of '.usr' and job files
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+    // Open the job file/
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_include_multi_paths_ECFLOW_261) {
+    // The specific files are specified in ECF_INCLUDE with multiple paths
+    cout << "ANode:: ...test_ecf_include_multi_paths_ECFLOW_261";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    // edit ECF_INCLUDE "$ECF_HOME/empty_include1:$ECF_HOME/empty_include2:$ECF_HOME/includes:$ECF_HOME/includes2"
+    //    task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_include_multi_paths_ECFLOW_261"));
+    Defs theDefs;
+    {
+        suite->addVariable(
+            Variable(Str::ECF_INCLUDE(),
+                     "$ECF_HOME/empty_include1:$ECF_HOME/empty_include2:$ECF_HOME/includes:$ECF_HOME/includes2"));
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string header   = "%include <head.h>\n\n";
+    string body     = "%include <fred.h>\n\n"; // this is only defined in ANode/test/data/includes2
+    string tail     = "%include <tail.h>\n# ===================================";
+    string ecf_file = header;
+    ecf_file += body;
+    ecf_file += tail;
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Check generation of job files
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+    // Open the job file
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_include_ECFLOW_274) {
+    // Test .ecf scripts with includes like %include "../bill.h"
+    // In this case we expect to find bill.h in the same directory as the script
+    cout << "ANode:: ...test_ecf_include_ECFLOW_274";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    // edit ECF_INCLUDE "$ECF_HOME/includes"
+    //    task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_include_ECFLOW_274"));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string header   = "%include <head.h>\n\n";
+    string body     = "%include \"./t1.h\"\n\n";
+    string tail     = "%include <tail.h>\n# ===================================";
+    string ecf_file = header;
+    ecf_file += body;
+    ecf_file += tail;
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    //   cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // generate bill.h
+    string header_file          = "# in t1.h";
+    string header_file_location = ecf_home + task_t1->absNodePath() + ".h";
+    //   cout << "file_location = " << header_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::create(header_file_location, header_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(header_file_location), "Expected File " << header_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Check generation of job files
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+    // Open the job file
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+
+    /// Remove the directories that were generated. This occasionally fails on ecgb and lxg ???
+    try {
+        fs::remove_all(ecf_home + suite->absNodePath());
+    }
+    catch (const fs::filesystem_error& e) {
+        cout << "Could not remove directory " << ecf_home + suite->absNodePath() << " : " << e.what() << "\n";
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_simple_used_variables) {
+    // Test that used variables are as expected
+    // This should PRUNE the generated variables from the used variables list
+    // Additionally it should NOT affect variables like ESUITE but should ignore generated variable SUITE
+    // See File: ANode/test/data/includes/used_variables.h
+    cout << "ANode:: ...test_ecf_simple_used_variables";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1;
+    suite_ptr suite;
+    Defs theDefs;
+    {
+        suite = theDefs.add_suite(Pid::unique_name("test_ecf_simple_used_variables"));
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->add_variable("ESUITE", "suite");
+        task_t1 = suite->add_family("f1")->add_task("t1");
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string ecf_file          = "%include <used_variables.h>\n";
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    string file_with_used_variables;
+    ecfFile.edit_used_variables(file_with_used_variables);
+    string expected_used_variables =
+        "%comment - ecf user variables\nESUITE = suite\n%end - ecf user variables\n%include <used_variables.h>\n";
+    BOOST_CHECK_MESSAGE(file_with_used_variables == expected_used_variables,
+                        "Expected\n"
+                            << expected_used_variables << "\nBut found:\n"
+                            << file_with_used_variables);
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_simple_used_variables_with_comments) {
+    // Test that used variables are as expected
+    // This should PRUNE the generated variables from the used variables list
+    // Additionally it should NOT affect variables like ETASK but should ignore generated variable TASK
+    // See File: ANode/test/data/includes/used_variables_with_comments.h
+    //
+    // This WILL test that when we have user comment and manuals, we can still extract user variables
+    // Those variable defined within comments and manuals that are not defined should be ignored
+    cout << "ANode:: ...test_ecf_simple_used_variables_with_comments";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1;
+    suite_ptr suite;
+    Defs theDefs;
+    {
+        suite = theDefs.add_suite(Pid::unique_name("test_ecf_simple_used_variables_with_comments"));
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->add_variable("ETASK", "suite");
+        suite->add_variable("FRED", "fred");
+        task_t1 = suite->add_family("f1")->add_task("t1");
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string ecf_file          = "%include <used_variables_with_comments.h>\n";
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    string file_with_used_variables;
+    ecfFile.edit_used_variables(file_with_used_variables);
+    string expected_used_variables = "%comment - ecf user variables\nETASK = suite\nFRED = fred\n%end - ecf user "
+                                     "variables\n%include <used_variables_with_comments.h>\n";
+    BOOST_CHECK_MESSAGE(file_with_used_variables == expected_used_variables,
+                        "Expected\n"
+                            << expected_used_variables << "\nBut found:\n"
+                            << file_with_used_variables);
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_simple_used_variables_errors) {
+    // Test that used variables are as expected
+    // This is similar to test_ecf_simple_used_variables_with_comments
+    // BUT we DO NOT define variable FRED, hence we expect failure
+    cout << "ANode:: ...test_ecf_simple_used_variables_errors";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1;
+    suite_ptr suite;
+    Defs theDefs;
+    {
+        suite = theDefs.add_suite(Pid::unique_name("test_ecf_simple_used_variables_errors"));
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->add_variable("ETASK", "suite");
+        task_t1 = suite->add_family("f1")->add_task("t1");
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string ecf_file          = "%include <used_variables_with_comments.h>\n";
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    // Expect a throw since %FRED% is not defined, on the suite, but exists in used_variables_with_comments.h
+    string file_with_used_variables;
+    BOOST_REQUIRE_THROW(ecfFile.edit_used_variables(file_with_used_variables), std::runtime_error);
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file) {
+    cout << "ANode:: ...test_ecf_file";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // # Test the sms file can be found via ECF_SCRIPT
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // #
+    // suite suite
+    //	edit SLEEPTIME 10
+    //	edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    NameValueMap expected_used_variables;
+    expected_used_variables.insert(std::make_pair(string("VAR1"), string("_val1_")));
+    expected_used_variables.insert(std::make_pair(string("VAR2"), string("_val2_")));
+    expected_used_variables.insert(std::make_pair(string("VAR2_fred"), string("<ignored>")));
+
+    // Create a defs file, where the task name mirrors the sms files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_file"));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("SLEEPTIME", "1"));
+        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
+        for (const NameValueMap::value_type& p : expected_used_variables) {
+            task_t1->addVariable(Variable(p.first, p.second));
+        }
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+
+    // Override ECF_HOME.   ECF_HOME is need to locate to the .ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string header      = "%include <head.h>\n\n";
+    string manual_head = "%manual\n";
+    string manual_body = " manual. The contents of the manual\n";
+    manual_body += " end.\n";
+    string manual_tail  = "%end\n\n";
+    string comment_head = "%comment\n";
+    string comment_body = " comment. The contents of the comment\n";
+    comment_body += " end.\n";
+    string comment_tail = "%end\n\n";
+    string ecf_body;
+    {
+        for (std::pair<std::string, std::string> p : expected_used_variables) {
+            ecf_body += Ecf::MICRO() + p.first + Ecf::MICRO() + "\n";
+        }
+        ecf_body += "%VAR3:substitute_var%\n";
+    }
+    string tail = "\n%include <tail.h>\n# ===================================";
+
+    string ecf_file = header;
+    ecf_file += manual_head;
+    ecf_file += manual_body;
+    ecf_file += manual_tail;
+    ecf_file += comment_head;
+    ecf_file += comment_body;
+    ecf_file += comment_tail;
+    ecf_file += ecf_body;
+    ecf_file += tail;
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    //	cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Test manual extraction
+    /// The manual is manual of all the pre-processed includes
+    /// Test: SUP-762 Lines starting with "manually" are not shown in manual
+    std::string expected_manual = "#This is the manual from the head.h file\n manual. The contents of the manual\n "
+                                  "end.\n#This is the manual from the tail.h file\n";
+
+    string theExtractedManual;
+    try {
+        ecfFile.manual(theExtractedManual);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, e.what());
+    }
+    BOOST_CHECK_MESSAGE(theExtractedManual == expected_manual,
+                        "Expected \n'" << expected_manual << "' but found \n'" << theExtractedManual << "'");
+
+    /// Test script extraction
+    string theExtractedScript;
+    try {
+        ecfFile.script(theExtractedScript);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, e.what());
+    }
+    BOOST_CHECK_MESSAGE(theExtractedScript == ecf_file,
+                        "\nExpected\n"
+                            << ecf_file << "\nsize = " << ecf_file.size() << " but found-----------------\n"
+                            << theExtractedScript << "\nsize = " << theExtractedScript.size());
+
+    /// Test User edit script, this should return all the used variables, between %comment -%end
+    string file_with_used_variables;
+    ecfFile.edit_used_variables(file_with_used_variables);
+    //    std::cout << "file_with_used_variables:----------------------------------------------------------------\n" <<
+    //    file_with_used_variables << "\n";
+    BOOST_CHECK_MESSAGE(file_with_used_variables.find("%comment") == 0,
+                        "Expected to find variable %comment on the very first line: but found at: "
+                            << file_with_used_variables.find("%comment"));
+    for (std::pair<std::string, std::string> p : expected_used_variables) {
+        BOOST_CHECK_MESSAGE(file_with_used_variables.find(p.first) != string::npos,
+                            "Expected to find variable" << p.first);
+    }
+
+    /// Test extraction of all the used variables
+    std::vector<string> script_lines;
+    Str::split(file_with_used_variables, script_lines, "\n"); //  will ignore empty lines, but will do for this case
+    NameValueMap extracted_used_variables;
+    EcfFile::extract_used_variables(extracted_used_variables, script_lines);
+    for (std::pair<std::string, std::string> p : expected_used_variables) {
+        BOOST_CHECK_MESSAGE(extracted_used_variables.find(p.first) != extracted_used_variables.end(),
+                            " expected to find variable " << p.first << " in the extracted variables\n");
+    }
+    //    cout << "Expected:----\n"; for(p:expected_used_variables) { cout << p.first << " " << p.second << "\n";}
+    //    cout << "Actual:------\n"; for(p:extracted_used_variables) { cout << p.first << " " << p.second << "\n";}
+
+    /// Test pre-processing
+    string pre_processed_file;
+    ecfFile.pre_process(pre_processed_file);
+    //	cout << "pre_processed_file\n" << pre_processed_file << "\n";
+    BOOST_CHECK_MESSAGE(!pre_processed_file.empty(), "Expected file not to be empty");
+    BOOST_CHECK_MESSAGE(pre_processed_file.find("%include") == string::npos, "Expected all includes to be removed");
+
+    /// Check generation of '.usr' and job files
+    string man_file_location = ecf_home + task_t1->absNodePath() + File::MAN_EXTN();
+    string usr_file_location = ecf_home + task_t1->absNodePath() + File::USR_EXTN();
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    JobsParam jobsParam(true); // spawn_jobs = false
+    jobsParam.set_user_edit_variables(extracted_used_variables);
+    jobsParam.set_user_edit_file(script_lines);
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+    BOOST_CHECK_MESSAGE(fs::exists(usr_file_location), "Expected File " << usr_file_location << " to exist");
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+    // Open the job file/
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+
+    // Test the contents of the job file.
+    //    cout << "\n" << job_file_contents << "\n";
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PORT%") == string::npos, "Expected variables to be substituted:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_HOST%") == string::npos, "Expected variables to be substituted:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_NAME%") == string::npos, "Expected variables to be substituted:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PASS%") == string::npos, "Expected variables to be substituted");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_TRYNO%") == string::npos, "Expected variables to be substituted");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%include") == string::npos, "Expected all includes to be expanded");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%manual") == string::npos, "%manual should have been removed");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%comment") == string::npos, "%comment should have been removed:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%end") == string::npos, "%end should have been removed:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ecfmicro") == string::npos, "%ecfmicro should have been removed:");
+
+    /// Remove all the generated files
+    fs::remove(man_file_location);
+    fs::remove(ecf_file_location);
+    fs::remove(usr_file_location);
+    fs::remove(job_file_location);
+    fs::remove(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_includenoop) {
+    cout << "ANode:: ...test_ecf_file_includenopp";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // This test is used to check that %includenopp are expanded only.
+    // There should be NO variable substitution, or removal of comments/manual
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name("test_ecf_file_includenoop"));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("SLEEPTIME", "1"));
+        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+    // cout << theDefs << "\n";
+
+    // Override ECF_HOME. ECF_HOME is need to locate to the .ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string header   = "%includenopp <head.h>\n";
+    string tail     = "%includenopp <tail.h>";
+    string ecf_file = header;
+    ecf_file += tail;
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location),
+                        "Could not create missing dir " << ecf_file_location << "\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables. Then EcfFile
+    task_t1->update_generated_variables();
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Check generation of job files
+    string man_file_location = ecf_home + task_t1->absNodePath() + File::MAN_EXTN();
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+
+    // Open the job file and check the contents
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected job File " << job_file_location << " to exist");
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+
+    // Test the contents of the job file. We expect includenopp to be expanded
+    // The contents should be left as is: i.e no pre_processing,hence expect to find %manual %comment, %VARIABLES%
+    // cout << "\n" << job_file_contents << "\n";
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%includenopp") == string::npos, "Expected all includes to be removed");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PORT%") != string::npos, "Expected variables as is:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_HOST%") != string::npos, "Expected variables as is:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_NAME%") != string::npos, "Expected variables as is:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_PASS%") != string::npos, "Expected variables as is:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%ECF_TRYNO%") != string::npos, "Expected variables as is:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%manual") != string::npos,
+                        "%manual should exist inside %nopp/%end pair:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%comment") != string::npos,
+                        "%comment should exist inside %nopp/%end pair:");
+    BOOST_CHECK_MESSAGE(job_file_contents.find("%end") != string::npos,
+                        "%end associated with comment and manual should exist:");
+
+    // Remove all the generated files
+    fs::remove(ecf_file_location);
+    fs::remove(man_file_location);
+    fs::remove(job_file_location);
+    fs::remove(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_override_ECF_JOB) {
+    cout << "ANode:: ...test_ecf_file_override_ECF_JOB";
+
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // This test is used to check that when user has added a variable ECF_JOB
+    // to specify the location of the job file, we use that, in preference
+    // to generated ECF_JOB for the location of the job file.
+    // Note: The directories to the job file should be created by EcfFile
+
+    // SET ECF_HOME
+    std::string ecf_home          = File::test_data("libs/node/test/data", "libs/node");
+    std::string job_file_location = ecf_home + "/a/made/up/path/t1.job";
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    task_t1->addVariable(Variable("ECF_JOB", job_file_location));
+    suite_ptr suite = Suite::create(Pid::unique_name("test_ecf_file_override_ECF_JOB"));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("SLEEPTIME", "1"));
+        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+    // cout << theDefs << "\n";
+
+    // Override ECF_HOME. ECF_HOME is need to locate to the .ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    // generate the dummy ecf file;
+    string header   = "%include <head.h>\n";
+    string tail     = "%include <tail.h>";
+    string ecf_file = header;
+    ecf_file += "# ";
+    ecf_file += tail;
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location),
+                        "Could not create missing dir " << ecf_file_location << "\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables. Then EcfFile
+    task_t1->update_generated_variables();
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Check generation of job files
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+
+    // Open the job file and check the contents
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected job File " << job_file_location << " to exist");
+    std::string job_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                        "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+    BOOST_CHECK_MESSAGE(!job_file_contents.empty(), "Job should not be empty");
+
+    // Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+    fs::remove_all(ecf_home + "/a");
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_manual_files) {
+    // The specific files are specified in ECF_INCLUDE and common files are specified in ECF_HOME.
+    cout << "ANode:: ...test_manual_files\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data/SMSHOME", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    // edit SLEEPTIME 10
+    // edit ECF_INCLUDE $ECF_HOME/includes
+    //  family
+    //     task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    Defs theDefs;
+    suite_ptr suite = theDefs.add_suite("suite"); // ** relies on name of suite, in SMSHOME/suite
+    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/../includes"));
+    family_ptr family = suite->add_family("family");
+    task_ptr task_t1  = family->add_task("t1");
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    // PrintStyle style(PrintStyle::STATE);
+    // std::cout << theDefs << "\n";
+
+    /// Now finally the test
+
+    // Task
+    {
+        std::string manual;
+        EcfFile ecf_file = task_t1->locatedEcfFile(); // will throw std::runtime_error for errors
+        ecf_file.manual(manual);                      // will throw std::runtime_error for errors
+        BOOST_REQUIRE_MESSAGE(!manual.empty(), "Manual not found");
+        BOOST_CHECK_MESSAGE(manual.find("ECF_MICRO=%") != std::string::npos,
+                            "Variable pre-processing failed during manual extraction");
+        BOOST_CHECK_MESSAGE(manual.find("manual-1") != std::string::npos,
+                            "Pre-processing of ecfmicro in manuals failed, expected to find string 'manual-1'\n"
+                                << manual);
+        BOOST_CHECK_MESSAGE(manual.find("end-1") != std::string::npos,
+                            "Pre-processing of ecfmicro in manuals failed, expected to find string 'end-1'\n"
+                                << manual);
+        BOOST_CHECK_MESSAGE(manual.find("Test manual files are pre-processed") != std::string::npos,
+                            "%include <manual.h> pre-processing failed inside manual->end\n"
+                                << manual);
+    }
+
+    {
+        // Family, Check the suite manuals are pre-processed. i.e %includes are expanded
+        // When the node container manual(family or suite) '.man' file, has content but *NO* %manual->%end directives
+        // Just pre-process and return file as is. Since the whole file is a manual.
+        std::string man_file = ecf_home + family->absNodePath() + File::MAN_EXTN();
+        EcfFile ecf_file(family.get(), man_file);
+
+        std::string manual;
+        ecf_file.manual(manual);
+        // cout << manual << "\n";
+        BOOST_CHECK_MESSAGE(!manual.empty(), "Manual not found");
+        BOOST_CHECK_MESSAGE(manual.find("Test manual files are pre-processed") != std::string::npos,
+                            "Pre-processing in manual failed");
+        BOOST_CHECK_MESSAGE(manual.find("Special case where there are no manual directives") != std::string::npos,
+                            "family manual extraction failed");
+    }
+
+    {
+        // Suite, Check the suite manuals are pre-processed. i.e %includes are expanded
+        std::string man_file = ecf_home + suite->absNodePath() + File::MAN_EXTN();
+        EcfFile ecf_file(suite.get(), man_file);
+
+        std::string manual;
+        ecf_file.manual(manual);
+        // cout << manual << "\n";
+        BOOST_CHECK_MESSAGE(!manual.empty(), "Manual not found");
+        BOOST_CHECK_MESSAGE(manual.find("Test manual files are pre-processed") != std::string::npos,
+                            "Pre-processing in manual failed");
+        BOOST_CHECK_MESSAGE(manual.find("suite manual") != std::string::npos, "Suite manual extraction failed");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_672) {
+    // test for recursive includes that are not recursive
+    cout << "ANode:: ...test_ECFLOW_672";
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // Create the defs file corresponding to the text below
+    // suite ECFLOW_672
+    //  edit ECF_INCLUDE $ECF_HOME/ECFLOW_672
+    //  task t
+    // endsuite
+    Defs theDefs;
+    suite_ptr suite = theDefs.add_suite("ECFLOW_672");
+    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/ECFLOW_672"));
+    task_ptr task_t1 = suite->add_task("t");
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    JobsParam jobsParam(true); // spawn_jobs = false
+    try {
+        ecfFile.create_job(jobsParam);
+    }
+    catch (std::exception& e) {
+        BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+    }
+
+    string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+    BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+    /// Remove generate file
+    fs::remove(job_file_location);
+}
+
+static void basic_test_template(const std::string& test_name,
+                                const std::string& ecf_file1,
+                                const std::string& expected_job_file_contents,
+                                const std::string& ecf_micro = "",
+                                bool expect_success          = true) {
+    cout << "ANode:: ..." << test_name;
+    // This test FAIL's randomly on the cray in BATCH mode, but passes in interactive mode.
+    if (getenv("ECFLOW_CRAY_BATCH")) {
+        cout << " **** SKIPPING test, until HPC team can  fix File::createMissingDirectories.(like mkdir -p)  *****\n";
+        return;
+    }
+    cout << "\n";
+
+    // Create the defs file corresponding to the text below
+    // suite suite
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  task t1
+    // endsuite
+
+    // Create a defs file, where the task name mirrors the ecf files in the given directory
+    task_ptr task_t1 = Task::create("t1");
+    suite_ptr suite  = Suite::create(Pid::unique_name(test_name));
+    Defs theDefs;
+    {
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->add_variable("simple", "simple");
+        suite->add_variable("tail", "tail");
+        if (!ecf_micro.empty())
+            suite->add_variable("ECF_MICRO", ecf_micro);
+        suite->addTask(task_t1);
+        theDefs.addSuite(suite);
+    }
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    std::string ecf_home = File::test_data("libs/node/test/data", "libs/node");
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // generate the ecf file;
+    string ecf_file          = ecf_file1;
+    string ecf_file_location = ecf_home + task_t1->absNodePath() + File::ECF_EXTN();
+    // cout << "file_location = " << ecf_file_location << "\n";
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+
+    // Create the generated variables
+    task_t1->update_generated_variables();
+
+    /// Now finally the test
+    EcfFile ecfFile(task_t1.get(), ecf_file_location);
+
+    /// Check generation of '.usr' and job files
+    JobsParam jobsParam(true); // spawn_jobs = false
+    if (expect_success) {
+        std::string file_with_used_variables;
+        try {
+            ecfFile.edit_used_variables(file_with_used_variables);
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Expected edit_used_variables to succeed " << e.what());
+        }
+
+        try {
+            ecfFile.create_job(jobsParam);
+        }
+        catch (std::exception& e) {
+            BOOST_CHECK_MESSAGE(false, "Expected job creation to succeed " << e.what());
+        }
+
+        string job_file_location = ecf_home + task_t1->absNodePath() + File::JOB_EXTN() + task_t1->tryNo();
+        BOOST_CHECK_MESSAGE(fs::exists(job_file_location), "Expected File " << job_file_location << " to exist");
+
+        // Open the job file, make sure it matches our expected file
+        std::string job_file_contents;
+        BOOST_CHECK_MESSAGE(File::open(job_file_location, job_file_contents),
+                            "Could not open job file " << job_file_location << " (" << strerror(errno) << ")");
+        BOOST_CHECK_MESSAGE(job_file_contents == expected_job_file_contents,
+                            "Expected\n"
+                                << expected_job_file_contents << "' but found \n"
+                                << job_file_contents << "'");
+    }
+    else {
+        BOOST_REQUIRE_THROW(ecfFile.create_job(jobsParam), std::runtime_error);
+    }
+
+    /// Remove all the generated files
+    fs::remove_all(ecf_home + suite->absNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_includeonce) {
+    // simplest test of include once, no hierarchy
+    // generate the ecf file;
+    string ecf_file = "%includeonce <simple_head.h>\n";
+    ecf_file += "%includeonce <simple_head.h>\n";
+    ecf_file += "%include <simple_head.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "%includeonce <simple_tail.h>\n";
+    ecf_file += "%include <simple_tail.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#head.h\n#body\n#tail.h\n#tail.h";
+
+    basic_test_template("test_includeonce", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_includeonce_hierarchical) {
+    // Test the pre-processing is done depth first, ( < 4.1.1 it was done breadth first)
+    // generate the ecf file;
+    string ecf_file = "%includeonce <AA.h>\n";
+    ecf_file += "%includeonce <BB.h>\n";
+    ecf_file += "%includeonce <CC.h>\n";
+
+    std::string expected_job_file_contents = "#startAA\n#startBB\n#CC\n#endBB\n#endAA";
+
+    basic_test_template("test_includeonce_hierarchical", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_include_with_variables) {
+    // Test includes with variables %include <%head%.h> ECFLOW-765
+
+    string ecf_file;
+    ecf_file += "%include <%simple%_head.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "%include <simple_%tail%.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+
+    basic_test_template("test_include_with_variables", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_include_with_variable_alternative) {
+    string ecf_file;
+    ecf_file += "%include %FRED:<simple_head.h>%\n";
+    ecf_file += "#body\n";
+    ecf_file += "%include %TAIL:<simple_tail.h>%\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+
+    basic_test_template("test_include_with_variable_alternative", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_include_with_variables_change_micro) {
+    string ecf_file;
+    ecf_file += "%ecfmicro &\n"; // ecf_micro in script OVERRIDES ECF_MICRO variable, but *only* in script
+    ecf_file += "&include <&simple&_head.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "&ecfmicro *\n";
+    ecf_file += "*include <simple_*tail*.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+
+    basic_test_template("test_include_with_variables_change_micro", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_script_override_ecf_micro) {
+    string ecf_file;             // ecf_micro in script OVERRIDES ECF_MICRO variable, but *only* in script
+    ecf_file += "$simple$\n";    // ECF_MICRO is set to $
+    ecf_file += "$ecfmicro &\n"; // ecfmicro change from $ -> &
+    ecf_file += "&include <&simple&_head.h>\n";
+    ecf_file += "#body$fred&simple&\n";
+    ecf_file += "&ecfmicro *\n"; // ecfmicro change from & -> *
+    ecf_file += "*include <simple_*tail*.h>\n";
+
+    std::string expected_job_file_contents = "simple\n#head.h\n#body$fredsimple\n#tail.h";
+
+    basic_test_template("test_script_override_ecf_micro", ecf_file, expected_job_file_contents, "$");
+}
+
+BOOST_AUTO_TEST_CASE(test_mistyped_ecf_micro) {
+    // same test as above, but we have mistyped ecf_micro. Make sure we don't ignore this.
+    string ecf_file;
+    ecf_file += "$simple$\n";
+    ecf_file += "$ecf_micro &\n"; // ecfmicro has been mistyped
+    ecf_file += "&include <&simple&_head.h>\n";
+    ecf_file += "#body$fred&simple&\n";
+    ecf_file += "&ecf_micro *\n";
+    ecf_file += "*include <simple_*tail*.h>\n";
+
+    std::string expected_job_file_contents = "simple\n#head.h\n#body$fredsimple\n#tail.h";
+
+    basic_test_template("test_mistyped_ecf_micro", ecf_file, expected_job_file_contents, "$", false);
+}
+
+BOOST_AUTO_TEST_CASE(test_include_with_variables_mismatched_micros) {
+    // generate the ecf file, where include file has missmatched ecf_micro
+    string ecf_file;
+    ecf_file += "%include <%simple%_head%.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "%include <simple_%tail%.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+
+    basic_test_template("test_include_with_variables_mismatched_micros",
+                        ecf_file,
+                        expected_job_file_contents,
+                        "" /*ecf_micro*/,
+                        false /*expect failure*/);
+}
+
+BOOST_AUTO_TEST_CASE(test_include_with_variable_not_defined) {
+    string ecf_file;
+    ecf_file += "%include %simple_head.h%\n";
+    ecf_file += "#body\n";
+    ecf_file += "%include <simple_%tail%.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+
+    basic_test_template("test_include_with_variable_not_defined",
+                        ecf_file,
+                        expected_job_file_contents,
+                        "" /*ecf_micro*/,
+                        false /*expect failure*/);
+}
+
+BOOST_AUTO_TEST_CASE(test_nopp_preserves_contents) {
+    string ecf_file;
+    ecf_file += "%include <simple_head.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "%nopp\n";
+    ecf_file += "%comment\n";
+    ecf_file += "--comment\n";
+    ecf_file += "%end\n";
+    ecf_file += "%manual\n";
+    ecf_file += "--manual\n";
+    ecf_file += "%end\n";
+    ecf_file += "%end\n";
+    ecf_file += "%include <simple_tail.h>\n";
+
+    std::string expected_job_file_contents =
+        "#head.h\n#body\n%comment\n--comment\n%end\n%manual\n--manual\n%end\n#tail.h";
+
+    basic_test_template("test_nopp_preserves_contents", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_nopp_preserves_contents2) {
+    string ecf_file;
+    ecf_file += "%include <simple_head.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "%nopp\n";
+    ecf_file += "%ecfmicro @\n";
+    ecf_file += "%end\n";
+    ecf_file += "%include <simple_tail.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body\n%ecfmicro @\n#tail.h";
+
+    basic_test_template("test_nopp_preserves_contents2", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_comment_and_manual_removal) {
+    string ecf_file;
+    ecf_file += "%include <simple_head.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "%comment\n";
+    ecf_file += "--comment\n";
+    ecf_file += "%end\n";
+    ecf_file += "%manual\n";
+    ecf_file += "--manual\n";
+    ecf_file += "%end\n";
+    ecf_file += "%include <simple_tail.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body\n#tail.h";
+
+    basic_test_template("test_comment_and_manual_removal", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_unterminated_manual) {
+    string ecf_file;
+    ecf_file += "%include <simple_head.h>\n";
+    ecf_file += "#body\n";
+    ecf_file += "%comment\n";
+    ecf_file += "--comment\n";
+    ecf_file += "%end\n";
+    ecf_file += "%manual\n";
+    ecf_file += "%include <simple_tail.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\n#body%manual\n#tail.h";
+
+    basic_test_template("test_unterminated_manual", ecf_file, expected_job_file_contents, "", false);
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_micro_with_comments_ECFLOW_1686) {
+    string ecf_file;
+    ecf_file += "%include <simple_head.h>\n";
+    ecf_file += "var=%XXXX:2 # fred%\n";
+    ecf_file += "# %comment\n";
+    ecf_file += "var=%X:2 # CC% # comment\n";
+    ecf_file += "%include <simple_tail.h>\n";
+
+    std::string expected_job_file_contents = "#head.h\nvar=2 # fred\n# %comment\nvar=2 # CC # comment\n#tail.h";
+
+    basic_test_template("test_ecf_micro_with_comments_ECFLOW_1686", ecf_file, expected_job_file_contents);
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_resolve_single_ecf_include_with_dollar) {
+    Defs d;
+    suite_ptr s = d.add_suite("suite");                      // suite suite
+    s->add_variable("CORE", "/path/to/core");                //   edit CORE /path/to/core
+    s->add_variable("ECF_INCLUDE", "$CORE/%SUITE%/include"); //   edit ECF_INCLUDE $CORE/include
+    task_ptr t1 = s->add_task("t1");                         //   task t1
+
+    std::string ecf_file_location;
+    EcfFile ecf(t1.get(), ecf_file_location);
+
+    auto ecf_include_paths = EcfFile::get_ecf_include_paths(ecf);
+    BOOST_REQUIRE_EQUAL(ecf_include_paths.size(), 1u);
+    BOOST_REQUIRE_EQUAL(ecf_include_paths[0], "/path/to/core/suite/include");
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_resolve_single_ecf_include) {
+    Defs d;
+    suite_ptr s = d.add_suite("suite");                       // suite suite
+    s->add_variable("CORE", "/path/to/core");                 //   edit CORE /path/to/core
+    s->add_variable("ECF_INCLUDE", "%CORE%/%SUITE%/include"); //   edit ECF_INCLUDE %CORE%/%SUITE%/include
+    task_ptr t1 = s->add_task("t1");                          //   task t1
+
+    std::string ecf_file_location;
+    EcfFile ecf(t1.get(), ecf_file_location);
+
+    auto ecf_include_paths = EcfFile::get_ecf_include_paths(ecf);
+    BOOST_REQUIRE_EQUAL(ecf_include_paths.size(), 1u);
+    BOOST_REQUIRE_EQUAL(ecf_include_paths[0], "/path/to/core/suite/include");
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_resolve_multiple_ecf_include) {
+    Defs d;
+    suite_ptr s = d.add_suite("suite");                                   // suite suite
+    s->add_variable("CORE", "/path/to/core");                             //   edit CORE /path/to/core
+    s->add_variable("ECF_INCLUDE", "%CORE%/%SUITE%/include:%CORE%/more"); //   edit ECF_INCLUDE %CORE%/%SUITE%...
+    task_ptr t1 = s->add_task("t1");                                      //   task t1
+
+    std::string location;
+    EcfFile ecf(t1.get(), location);
+
+    auto ecf_include_paths = EcfFile::get_ecf_include_paths(ecf);
+    BOOST_REQUIRE_EQUAL(ecf_include_paths.size(), 2u);
+    BOOST_REQUIRE_EQUAL(ecf_include_paths[0], "/path/to/core/suite/include");
+    BOOST_REQUIRE_EQUAL(ecf_include_paths[1], "/path/to/core/more");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestEcfFileLocator.cpp 5.13.0-1/libs/node/test/TestEcfFileLocator.cpp
--- 5.12.4-1/libs/node/test/TestEcfFileLocator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestEcfFileLocator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,493 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Pid.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/EcfFile.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_EcfFileLocator)
+
+void located_ecf_file(task_ptr task,
+                      EcfFile::Origin expected_origin,
+                      EcfFile::EcfFileSearchAlgorithm expected_search,
+                      int line) {
+    try {
+        task->update_generated_variables();
+        EcfFile ecf_file = task->locatedEcfFile();
+        // cout << "located_ecf_file task: " << task->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
+        BOOST_REQUIRE_MESSAGE(ecf_file.valid(),
+                              "\nline:" << line << " Expected search to pass with "
+                                        << EcfFile::search_algorithm_str(expected_search));
+        BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == expected_origin,
+                              "\nline:" << line << " Expected ecf_file to be obtained from("
+                                        << EcfFile::origin_str(expected_origin) << ") but found "
+                                        << ecf_file.ecf_file_origin_dump());
+        BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_search_algorithm() == expected_search,
+                              "\nline:" << line << " Expected search " << EcfFile::search_algorithm_str(expected_search)
+                                        << " but found "
+                                        << EcfFile::search_algorithm_str(ecf_file.ecf_file_search_algorithm()));
+    }
+    catch (std::exception& e) {
+        BOOST_REQUIRE_MESSAGE(true, "Expected search to succeed " << e.what());
+    }
+}
+
+void located_ecf_file_fail(task_ptr task, int line) {
+    task->update_generated_variables();
+    try {
+        EcfFile ecf_file = task->locatedEcfFile();
+        BOOST_REQUIRE_MESSAGE(!ecf_file.valid(),
+                              "\nline:" << line << " Expected search to fail with standard look up(i.e PRUNE_ROOT) "
+                                        << ecf_file.ecf_file_origin_dump());
+    }
+    catch (std::exception& e) {
+        BOOST_REQUIRE_MESSAGE(true, "\nline:" << line << "Expected search to fail " << e.what());
+    }
+}
+
+void create_ecf_file(const std::string& ecf_file_location) {
+    // cout << "create file  = " << ecf_file_location << "\n";
+    //  generate the ecf file;
+    string header   = "%include <simple_head.h>\n";
+    string body     = "#body\n";
+    string tail     = "%include <simple_tail.h>\n";
+    string ecf_file = header;
+    ecf_file += body;
+    ecf_file += tail;
+
+    BOOST_CHECK_MESSAGE(File::createMissingDirectories(ecf_file_location), "Could not create missing dir\n");
+    string errormsg;
+    BOOST_CHECK_MESSAGE(File::create(ecf_file_location, ecf_file, errormsg), errormsg);
+    BOOST_CHECK_MESSAGE(fs::exists(ecf_file_location), "Expected File " << ecf_file_location << " to exist");
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_search) {
+    cout << "ANode:: ...test_ecf_file_search\n";
+    // Do test which fails first, i.e does not find the ecf file, then add variable ECF_FILES_LOOKUP(PRUNE_LEAF)
+    // The test should then succeed
+    // Note: Setting ECF_FILES_LOOKUP(PRUNE_LEAF) or ECF_FILES_LOOKUP(PRUNE_ROOT)/default affects the lookup for
+    //       ecf files in BOTH ECF_HOME and ECF_LISTS
+    // PRUNE_ROOT/defaults
+    //    <root>/suite/f1/f2/f3/task.ecf
+    //    <root>/f1/f2/f3/task.ecf
+    //    <root>/f2/f3/task.ecf
+    //    <root>/f3/task.ecf
+    //    <root>/task.ecf
+    // PRUNE_LEAF( new from ecflow 4.12.0)
+    //    <root>/suite/f1/f2/f3/task.ecf
+    //    <root>/suite/f1/f2/task.ecf
+    //    <root>/suite/f1/task.ecf
+    //    <root>/suite/task.ecf
+    //    <root>/task.ecf
+    // IMPORTANT: The first and last lookups are the *SAME* for both search lookups.
+
+    // Create a defs file corresponding to:
+    // suite test_ecf_file_search
+    // edit ECF_INCLUDE $ECF_HOME/includes
+    // family f1
+    //    family f2
+    //       family f3
+    //          task task
+    Defs theDefs;
+    suite_ptr suite = theDefs.add_suite(Pid::unique_name("test_ecf_file_search"));
+    suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+    family_ptr f1 = suite->add_family("f1");
+    family_ptr f2 = f1->add_family("f2");
+    family_ptr f3 = f2->add_family("f3");
+    task_ptr task = f3->add_task("task");
+
+    // Override ECF_HOME. ECF_HOME is as default location for .ecf files, when ECF_INCLUDE not specified
+    // or when file does not exist in ECF_INCLUDE
+    std::string ecf_home  = File::test_data("libs/node/test/data", "libs/node");
+    std::string ecf_lists = File::test_data("libs/node/test/data", "libs/node");
+    suite->add_variable(Str::ECF_HOME(), ecf_home);
+    // cerr << theDefs << "\n";
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    {
+        // cout << "Test ECF_HOME/ECF_LISTS at leaf location this should be using ECF_SCRIPT\n";
+        string ecf_file_location = ecf_home + task->absNodePath() + File::ECF_EXTN();
+        create_ecf_file(ecf_file_location);
+
+        located_ecf_file(task, EcfFile::ECF_SCRIPT, EcfFile::PRUNE_ROOT, __LINE__);
+        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
+        located_ecf_file(task,
+                         EcfFile::ECF_SCRIPT,
+                         EcfFile::PRUNE_ROOT,
+                         __LINE__); // ECF_FILES_LOOKUP make *NO* difference for lookup with EcfFile::ECF_SCRIPT
+
+        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
+
+        suite->add_variable(Str::ECF_FILES(), ecf_lists);
+        located_ecf_file(task,
+                         EcfFile::ECF_SCRIPT,
+                         EcfFile::PRUNE_ROOT,
+                         __LINE__); // ECF_FILES make no difference for lookup with EcfFile::ECF_SCRIPT
+        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
+        located_ecf_file(task,
+                         EcfFile::ECF_SCRIPT,
+                         EcfFile::PRUNE_ROOT,
+                         __LINE__); // ECF_FILES_LOOKUP make *NO* difference for lookup with EcfFile::ECF_SCRIPT
+
+        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
+        suite->deleteVariable("ECF_FILES");        // cleanup
+        fs::remove(ecf_file_location);             // cleanup
+    }
+    {
+        // cout << "Test ECF_HOME/ECF_LISTS at root location\n";
+        string ecf_file_location = ecf_home + "/" + task->name() + File::ECF_EXTN();
+        create_ecf_file(ecf_file_location);
+
+        located_ecf_file(task, EcfFile::ECF_HOME, EcfFile::PRUNE_ROOT, __LINE__);
+        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
+        located_ecf_file(task, EcfFile::ECF_HOME, EcfFile::PRUNE_LEAF, __LINE__);
+
+        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
+
+        suite->add_variable(Str::ECF_FILES(), ecf_lists);
+        located_ecf_file(task, EcfFile::ECF_FILES, EcfFile::PRUNE_ROOT, __LINE__);
+        suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf"); // change look up method
+        located_ecf_file(task, EcfFile::ECF_FILES, EcfFile::PRUNE_LEAF, __LINE__);
+
+        suite->deleteVariable("ECF_FILES_LOOKUP"); // cleanup
+        suite->deleteVariable("ECF_FILES");        // cleanup
+        fs::remove(ecf_file_location);             // cleanup
+    }
+    {
+        // cout << "Test ECF_HOME at intermediate location prune_leaf\n";
+        Node* node = task.get();
+        node       = node->parent();
+        node       = node->parent();
+        while (node) {
+
+            string ecf_file_location = ecf_home + node->absNodePath() + "/" + task->name() + File::ECF_EXTN();
+            create_ecf_file(ecf_file_location);
+
+            // cout << "Node: " << node->absNodePath() << "\n";
+            located_ecf_file_fail(task, __LINE__);
+
+            // change look up method
+            suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf");
+            located_ecf_file(task, EcfFile::ECF_HOME, EcfFile::PRUNE_LEAF, __LINE__);
+
+            // Remove this file, required for the following test
+            fs::remove(ecf_file_location);
+
+            // Remove ECF_FILES_LOOKUP variable
+            suite->deleteVariable("ECF_FILES_LOOKUP");
+
+            node = node->parent();
+        }
+        /// Remove all the generated files
+        fs::remove_all(ecf_home + suite->absNodePath());
+    }
+    {
+        // cout << "Test ECF_FILES at intermediate location, by prune_leaf\n";
+        suite->add_variable(Str::ECF_FILES(), ecf_lists);
+        Node* node = task.get();
+        node       = node->parent();
+        node       = node->parent();
+        while (node) {
+
+            string ecf_file_location = ecf_lists + node->absNodePath() + "/" + task->name() + File::ECF_EXTN();
+            create_ecf_file(ecf_file_location);
+
+            // cout << "Node: " << node->absNodePath() << "\n";
+            located_ecf_file_fail(task, __LINE__);
+
+            // change look up method
+            suite->add_variable("ECF_FILES_LOOKUP", "prune_leaf");
+            located_ecf_file(task, EcfFile::ECF_FILES, EcfFile::PRUNE_LEAF, __LINE__);
+
+            // Remove this file, required for the following test
+            fs::remove(ecf_file_location);
+
+            // Remove ECF_FILES_LOOKUP variable
+            suite->deleteVariable("ECF_FILES_LOOKUP");
+
+            node = node->parent();
+        }
+
+        /// Remove all the generated files
+        fs::remove_all(ecf_home + suite->absNodePath());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_locator) {
+    cout << "ANode:: ...test_ecf_file_locator\n";
+
+    // SET ECF_HOME
+    std::string smshome = File::test_data("libs/node/test/data/SMSHOME", "libs/node");
+
+    // Create a defs file corresponding to:
+    // # Test the sms file can be found via ECF_SCRIPT
+    // #
+    // suite suite
+    //	edit ECF_INCLUDE $ECF_HOME/includes
+    //	edit SLEEPTIME 10
+    //	family family
+    //   		task t1
+    //   		task t2
+    //    		task t3
+    //  	endfamily
+    // endsuite
+    //
+    // #
+    // # This test suite should force a backwards search since the ecf files
+    // # are located in ECF_HOME
+    // suite suite1
+    //  	family family
+    //   		task suite1_task1
+    //   		task suite1_task2
+    //    		task suite1_task3
+    //    endfamily
+    // endsuite
+    //
+    // #
+    // # This suite is used to test command substition with ECF_FETCH command
+    // #
+    // suite suite2
+    //	edit ECF_INCLUDE $ECF_HOME/includes
+    //	edit ECF_FILES   $ECF_HOME
+    //	family family
+    //		edit SMSFETCH "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"
+    //		task t2
+    //	endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("SLEEPTIME", "10"));
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t1");
+        fam->add_task("t2");
+        fam->add_task("t3");
+    }
+    {
+        suite_ptr suite = theDefs.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("suite1_task1");
+        fam->add_task("suite1_task2");
+        fam->add_task("suite1_task3");
+    }
+    {
+        suite_ptr suite2 = theDefs.add_suite("suite2");
+        suite2->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite2->addVariable(Variable(Str::ECF_FILES(), "$ECF_HOME"));
+        family_ptr fam = suite2->add_family("family");
+        fam->addVariable(Variable(Str::ECF_FETCH(), "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"));
+        fam->add_task("t2");
+    }
+    {
+        suite_ptr suite = theDefs.add_suite("suite3");
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable(Str::ECF_FILES(), "$ECF_HOME"));
+        family_ptr fam = suite->add_family("family");
+        fam->addVariable(Variable("ECF_SCRIPT_CMD", "script_cmd -F %ECF_FILES% -I %ECF_INCLUDE%"));
+        fam->add_task("t2");
+    }
+    // 	cerr << theDefs << "\n";
+
+    // get all the task, assume non hierarchical families
+    std::vector<Task*> theTasks;
+    theDefs.getAllTasks(theTasks);
+    BOOST_REQUIRE_MESSAGE(theTasks.size() == 8, "Expected 8 tasks but found, " << theTasks.size());
+
+    // Override ECF_HOME.   ECF_HOME is need to locate to the ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), smshome);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // Test for ECF_ file location
+    for (Task* t : theTasks) {
+        try {
+            EcfFile ecf_file = t->locatedEcfFile();
+            // cout << "Task: " << t->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
+            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task ");
+            Suite* suite = t->suite();
+            if (suite->name() == "suite")
+                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_SCRIPT,
+                                      "Expected ecf_file to be obtained from ECF_SCRIPT "
+                                          << ecf_file.ecf_file_origin_dump());
+            if (suite->name() == "suite1")
+                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_HOME,
+                                      "Expected ecf_file to be obtained from ECF_HOME "
+                                          << ecf_file.ecf_file_origin_dump());
+            if (suite->name() == "suite2")
+                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_FETCH_CMD,
+                                      "Expected ecf_file to be obtained from ECF_FETCH_CMD "
+                                          << ecf_file.ecf_file_origin_dump());
+            if (suite->name() == "suite3")
+                BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_SCRIPT_CMD,
+                                      "Expected ecf_file to be obtained from ECF_SCRIPT_CMD "
+                                          << ecf_file.ecf_file_origin_dump());
+        }
+        catch (std::exception& e) {
+            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task " << e.what());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_locator_using_ECF_FILES) {
+    cout << "ANode:: ...test_ecf_file_locator_using_ECF_FILES\n";
+
+    // This test will check we can locate the ecf files in ECF_FILES directory
+
+    // SET ECF_HOME. *** TO A DIRECTORY WHERE THERE ARE NO .ECF FILES **
+    std::string smshome = File::test_data("libs/node/test/data", "libs/node");
+
+    // set ECF_FILES where we do have some .ecf files
+    std::string ecf_files = File::test_data("libs/node/test/data/SMSHOME/suite/family", "libs/node");
+
+    // Create a defs file corresponding to:
+    // # Test the sms file can be found via ECF_SCRIPT
+    // #
+    // edit ECF_HOME    ANode/test/data
+    // edit ECF_FILES   ANode/test/data/SMSHOME/suite/family
+    // suite suite
+    // edit ECF_INCLUDE $ECF_HOME/includes
+    // edit SLEEPTIME 10
+    // family family
+    //       task t1
+    //       task t2
+    //       task t3
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("SLEEPTIME", "10"));
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t1");
+        fam->add_task("t2");
+        fam->add_task("t3");
+    }
+
+    // get all the task, assume non hierarchical families
+    std::vector<Task*> theTasks;
+    theDefs.getAllTasks(theTasks);
+    BOOST_REQUIRE_MESSAGE(theTasks.size() == 3, "Expected 3 tasks but found, " << theTasks.size());
+
+    // ECF_HOME, a directory with no .ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), smshome);
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_FILES(), ecf_files);
+
+    //    cerr << theDefs << "\n";
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // Test for ECF_ file location
+    for (Task* t : theTasks) {
+        try {
+            EcfFile ecf_file = t->locatedEcfFile();
+            // cout << "Task: " << t->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
+            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task " << t->absNodePath());
+            BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_FILES,
+                                  "Expected ecf_file to be obtained from ECF_FILES "
+                                      << ecf_file.ecf_file_origin_dump());
+        }
+        catch (std::exception& e) {
+            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task\n" << e.what());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ecf_file_locator_using_ECF_FILES_variable_substitution) {
+    cout << "ANode:: ...test_ecf_file_locator_using_ECF_FILES_variable_substitution\n";
+
+    // ECFLOW-788
+    // This test will check we can locate the ecf files in ECF_FILES directory
+    // Will attempt variable substitution, on ECF_FILES is directory does not exist
+
+    // SET ECF_HOME. ***TO A DIRECTORY WHERE THERE ARE NO .ECF FILE **
+    std::string smshome = File::test_data("libs/node/test/data", "libs/node");
+
+    // set ECF_FILES where we do have some .ecf files
+    std::string ecf_files = File::test_data("libs/node/test/data/SMSHOME/suite/%FAMILY%", "libs/node");
+
+    // Create a defs file corresponding to:
+    // # Test the sms file can be found via ECF_SCRIPT
+    // #
+    // edit ECF_HOME    ANode/test/data
+    // edit ECF_FILES   ANode/test/data/SMSHOME/suite/%FAMILY%   # test we variable substitute
+    // suite suite
+    // edit ECF_INCLUDE $ECF_HOME/includes
+    // edit SLEEPTIME 10
+    // family family
+    //       task t1
+    //       task t2
+    //       task t3
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable("SLEEPTIME", "10"));
+        family_ptr fam = suite->add_family("family");
+        fam->addVariable(Variable("FAMILY", "family"));
+        fam->add_task("t1");
+        fam->add_task("t2");
+        fam->add_task("t3");
+    }
+
+    // get all the task, assume non hierarchical families
+    std::vector<Task*> theTasks;
+    theDefs.getAllTasks(theTasks);
+    BOOST_REQUIRE_MESSAGE(theTasks.size() == 3, "Expected 3 tasks but found, " << theTasks.size());
+
+    // ECF_HOME, a directory with no .ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), smshome);
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_FILES(), ecf_files);
+
+    //    cerr << theDefs << "\n";
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // Test for ECF_ file location
+    for (Task* t : theTasks) {
+        try {
+            EcfFile ecf_file = t->locatedEcfFile();
+            // cout << "Task: " << t->absNodePath() << " " << ecf_file.ecf_file_origin_dump() << "\n";
+            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task " << t->absNodePath());
+            BOOST_REQUIRE_MESSAGE(ecf_file.ecf_file_origin() == EcfFile::ECF_FILES,
+                                  "Expected ecf_file to be obtained from ECF_FILES "
+                                      << ecf_file.ecf_file_origin_dump());
+        }
+        catch (std::exception& e) {
+            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task\n" << e.what());
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestEnviromentSubstitution.cpp 5.13.0-1/libs/node/test/TestEnviromentSubstitution.cpp
--- 5.12.4-1/libs/node/test/TestEnviromentSubstitution.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestEnviromentSubstitution.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,97 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_EnvironmentSubstitution)
+
+BOOST_AUTO_TEST_CASE(test_environment_substitution) {
+    std::cout << "ANode:: ...test_environment_substitution\n";
+
+    Defs defs;
+    Suite* s = nullptr;
+    {
+        suite_ptr suite = defs.add_suite("suite");
+        s               = suite.get();
+        suite->addVariable(Variable("AVI", "avi"));
+
+        std::vector<std::pair<std::string, std::string>> env;
+        env.emplace_back(Str::ECF_HOME(), string("/home/smshome"));
+        env.emplace_back(string("FRED"), string("/home/fred"));
+        env.emplace_back(string("BILL"), string("/home/bill"));
+        env.emplace_back(string("JANE"), string("/home/jane"));
+        env.emplace_back(string("REP"), string("$REP/bill"));
+        defs.set_server().add_or_update_user_variables(env);
+    }
+
+    // Check for recursive, in which case we only substitute once
+    string expected = "$REP/bill";
+    std::string cmd = "$REP";
+    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    // See page 31, section 5.1 variable inheritance, of SMS users guide
+    cmd      = "$ECF_HOME";
+    expected = "/home/smshome";
+    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "$ECF_HOME/include";
+    expected = "/home/smshome/include";
+    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "$ECF_HOME$FRED$BILL$JANE";
+    expected = "/home/smshome/home/fred/home/bill/home/jane";
+    BOOST_REQUIRE_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "$ECF_HOME/$FRED/$BILL/$JANE";
+    expected = "/home/smshome//home/fred//home/bill//home/jane";
+    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH";
+    expected = "%PATH";
+    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "$$";
+    expected = "$$";
+    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "$ERROR$";
+    expected = "$ERROR$";
+    BOOST_CHECK_MESSAGE(!s->variable_dollar_substitution(cmd),
+                        " substitution expected to fail since ERROR does not exist");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variable_dollar_substitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestExprParser.cpp 5.13.0-1/libs/node/test/TestExprParser.cpp
--- 5.12.4-1/libs/node/test/TestExprParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestExprParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,756 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <map>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/ExprParser.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_ExprParser)
+
+BOOST_AUTO_TEST_CASE(test_expression_parser_basic) {
+    std::cout << "ANode:: ...test_expression_parser_basic\n";
+
+    using namespace std::string_literals;
+
+    // This must be nicely formatted, i.e. AST is nicely space formatted otherwise it will fail the test
+    // This test ENSURES that the AST matches the expression. (i.e. by getting AST to print the expression)
+    // Note: we can use NOT,eq,ne,le,ge or brackets
+    //       we can't use a:event_name  ==> a:event_name == set
+    std::vector expressions = {
+        "a == complete"s,
+        "a != complete"s,
+        "a:value == 10"s,
+        "a:value != 10"s,
+        "a:value >= 10"s,
+        "a:value <= 10"s,
+        "a:value > 10"s,
+        "a:value < 10"s,
+        "1 == 1"s,
+        "1 == 0"s,
+        "a:event_name == set"s,
+        "a:event_name != set"s,
+        "a:event_name == clear"s,
+        "a:event_name != clear"s,
+        "../a/b:eventname == set"s,
+        "../a/b:eventname == clear"s,
+        "../a/b:eventname != clear"s,
+        "../a:event_name >= 10"s,
+        "a == unknown and b != complete"s,
+        "a == unknown or b != complete"s,
+        "a == complete and b == complete or c == complete"s,
+        "! a == unknown"s,
+        "/mc/main:YMD <= /mc/main/ref:MC_STOP"s,
+        "! ../../../prod2diss/operation_is_late:yes == set or ! a == complete"s,
+        "./a:YMD - ./b:YMD < 5"s,
+        "./a:YMD + ./b:YMD < 5"s,
+        "./a:YMD / ./b:YMD < 5"s,
+        "./a:YMD * ./b:YMD < 5"s,
+        "./a:YMD % ./b:YMD < 5"s,
+        "inigroup:YMD == ! 1"s,
+        "inigroup:YMD == ! 0"s,
+        "comp == complete and notready == complete"s, // ECFLOW-493
+        "comp == complete and not ready == complete"s,
+        "comp == complete and ! ready == complete"s, // we now store the not from the parse, for test comparison
+        "comp == complete and ~ ready == complete"s,
+        ":VAR == 1"s,
+        ":VAR == /mc/main/ref:MC_STOP"s,
+        ":YMD - :YMD < 5"s,
+        ":YMD + :YMD < 5"s,
+        ":YMD / :YMD < 5"s,
+        ":YMD * :YMD < 5"s,
+        ":YMD % :YMD < 5"s,
+        ":VARIABLE == 20230101T000000"s,
+        ":VARIABLE >= 20230101T000000"s,
+        ":VARIABLE <= 20230101T000000"s,
+        ":VARIABLE + 3 <= 19700101T000000"s,
+        ":VARIABLE <= 19700101T000000 + 3"s};
+
+    for (const auto& expression : expressions) {
+
+        PartExpression part(expression);
+        std::string error;
+        auto ast = part.parseExpressions(error);
+        BOOST_REQUIRE_MESSAGE(ast.get(), "Failed to parse\n" << expression << "  " << error);
+
+        std::stringstream s2;
+        ast->print_flat(s2);
+        std::string actual_expression = s2.str();
+        BOOST_CHECK_MESSAGE(expression == actual_expression,
+                            " Failed\n'" << expression << "' != '" << actual_expression << "'");
+
+        std::string why;
+        ast->why(why);
+        if (ast->evaluate()) {
+            BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << expression);
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << expression);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_expression_parser_basic_with_braces) {
+    std::cout << "ANode:: ...test_expression_parser_basic_with_braces\n";
+
+    using namespace std::string_literals;
+
+    // This must be nicely formatted, i.e. AST is nicely space formatted otherwise it will fail the test
+    // This test ENSURES that the AST matches the expression. (i.e. by getting AST to print the expression)
+    // Note: we can use NOT,eq,ne,le,ge,
+    //       we can't use a:event_name  ==> a:event_name == set
+    std::vector expressions = {
+        "((a == complete) and (b == complete))"s,
+        "(((a == complete) or (b == complete)) and (c == complete))"s,
+        "((a == complete) and ((b == complete) or (nodepath:eventname == set)))"s,
+        "((a == complete) and ((b == complete) or ((a == complete) and (b == complete))))"s,
+        "! ((a == unknown))"s,
+        "((t:step + 20) >= (t:step1 - 20))"s,
+        "(((/o/main/12/an/slwet == complete) and ((/o/main/12/an/4dvar/ifstraj:finalwave == set) or (/o/main/12/an/4dvar == complete))) or (/o/main/12/an == complete))"s,
+        "((obs:YMD <= (main:YMD + 1)) and ((../make/setup == complete) and (obs:YMD <= /o/lag:YMD)))"s,
+        "(((stage == complete) or (./stage:YMD > ./retrieve:YMD)) and ((./retrieve:YMD - ./load:YMD) < 5))"s,
+        "((./a:YMD - ./b:YMD) < 5)"s,
+        "((:YMD + :YMD) < 5)"s,
+        "((:YMD + :YMD) < 5)"s,
+        "((:VARIABLE == 19700101T123456) and (b == complete))"s,
+        "((:VARIABLE < 19700101T123456) and (b == complete))"s};
+
+    for (const auto& expression : expressions) {
+
+        PartExpression part(expression);
+        std::string error;
+        std::unique_ptr<AstTop> ast = part.parseExpressions(error);
+        BOOST_REQUIRE_MESSAGE(ast.get(), "Failed to parse " << expression << "  " << error);
+
+        std::stringstream s2;
+        ast->print_flat(s2, true /*add_brackets*/);
+        std::string actual_expression = s2.str();
+        BOOST_CHECK_MESSAGE(expression == actual_expression,
+                            " Failed '" << expression << "' != '" << actual_expression << "'");
+
+        std::string why;
+        ast->why(why);
+        if (ast->evaluate()) {
+            BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << expression);
+        }
+        else {
+            BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << expression);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_parser_good_expressions) {
+    std::cout << "ANode:: ...test_parser_good_expressions\n";
+
+    // The map key  = trigger expression,
+    // value.first  = type of the expected root abstract syntax tree
+    // value.second = result of expected evaluation
+    map<string, std::pair<string, bool>> exprMap;
+
+    exprMap["a:value == 0"]  = std::make_pair(AstEqual::stype(), true);
+    exprMap["a:value == 10"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["a:value eq 10"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["a:value != 10"] = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["a:value ne 10"] = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["a:value > 10"]  = std::make_pair(AstGreaterThan::stype(), false);
+    exprMap["a:value gt 10"] = std::make_pair(AstGreaterThan::stype(), false);
+    exprMap["a:value >= 10"] = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["a:value ge 10"] = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["a:value < 10"]  = std::make_pair(AstLessThan::stype(), true);
+    exprMap["a:value lt 10"] = std::make_pair(AstLessThan::stype(), true);
+    exprMap["a:value <= 10"] = std::make_pair(AstLessEqual::stype(), true);
+    exprMap["a:value le 10"] = std::make_pair(AstLessEqual::stype(), true);
+
+    exprMap["0 == a:value"]  = std::make_pair(AstEqual::stype(), true);
+    exprMap["10 == a:value"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["10 eq a:value"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["10 != a:value"] = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["10 ne a:value"] = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["10 > a:value"]  = std::make_pair(AstGreaterThan::stype(), true);
+    exprMap["10 gt a:value"] = std::make_pair(AstGreaterThan::stype(), true);
+    exprMap["10 >= a:value"] = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["10 < a:value"]  = std::make_pair(AstLessThan::stype(), false);
+    exprMap["10 lt a:value"] = std::make_pair(AstLessThan::stype(), false);
+    exprMap["10 <= a:value"] = std::make_pair(AstLessEqual::stype(), false);
+    exprMap["10 le a:value"] = std::make_pair(AstLessEqual::stype(), false);
+
+    exprMap["a == complete"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["a==complete"]   = std::make_pair(AstEqual::stype(), false);
+    exprMap["a eq complete"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["a ne complete"] = std::make_pair(AstNotEqual::stype(), true);
+
+    exprMap["0 eq 1"]    = std::make_pair(AstEqual::stype(), false);
+    exprMap["1000 eq 9"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["10 eq 10"]  = std::make_pair(AstEqual::stype(), true);
+    exprMap["10 ge 4"]   = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["10 le 4"]   = std::make_pair(AstLessEqual::stype(), false);
+
+    exprMap["0 == 0"]    = std::make_pair(AstEqual::stype(), true);
+    exprMap["0 == 1"]    = std::make_pair(AstEqual::stype(), false);
+    exprMap["0 != 1"]    = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["0 < 1"]     = std::make_pair(AstLessThan::stype(), true);
+    exprMap["10 < 1"]    = std::make_pair(AstLessThan::stype(), false);
+    exprMap["1000 == 9"] = std::make_pair(AstEqual::stype(), false);
+    exprMap["10 == 10"]  = std::make_pair(AstEqual::stype(), true);
+    exprMap["10 >= 4"]   = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["10 <= 4"]   = std::make_pair(AstLessEqual::stype(), false);
+    exprMap["0 > 1"]     = std::make_pair(AstGreaterThan::stype(), false);
+    exprMap["10 > 1"]    = std::make_pair(AstGreaterThan::stype(), true);
+
+    // Integer is distinct from task/family names that are integers, since nodes with integer
+    // names that occur in trigger/complete expression must have path ./0 ./1
+    exprMap["./12:eventname"]             = std::make_pair(AstEqual::stype(), false);
+    exprMap["./12:eventname == 0"]        = std::make_pair(AstEqual::stype(), true);
+    exprMap["./12/b:eventname"]           = std::make_pair(AstEqual::stype(), false);
+    exprMap["/12/b:eventname"]            = std::make_pair(AstEqual::stype(), false);
+    exprMap["../12/b:eventname == set"]   = std::make_pair(AstEqual::stype(), false);
+    exprMap["../12/b:eventname == clear"] = std::make_pair(AstEqual::stype(), true);
+    exprMap["../12/b:eventname != clear"] = std::make_pair(AstNotEqual::stype(), false);
+    exprMap["12:eventname == set"]        = std::make_pair(AstEqual::stype(), false);
+    exprMap["12:eventname != set"]        = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["12:eventname == clear"]      = std::make_pair(AstEqual::stype(), true);
+    exprMap["./12:eventname == set"]      = std::make_pair(AstEqual::stype(), false);
+    exprMap["./12:eventname != set"]      = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["./12:eventname == clear"]    = std::make_pair(AstEqual::stype(), true);
+
+    exprMap["a:eventname"]               = std::make_pair(AstEqual::stype(), false);
+    exprMap["a:eventname == 0"]          = std::make_pair(AstEqual::stype(), true);
+    exprMap["./a/b:eventname"]           = std::make_pair(AstEqual::stype(), false);
+    exprMap["/a/b:eventname"]            = std::make_pair(AstEqual::stype(), false);
+    exprMap["../a/b:eventname == set"]   = std::make_pair(AstEqual::stype(), false);
+    exprMap["../a/b:eventname == clear"] = std::make_pair(AstEqual::stype(), true);
+    exprMap["../a/b:eventname != clear"] = std::make_pair(AstNotEqual::stype(), false);
+    exprMap["a:eventname == set"]        = std::make_pair(AstEqual::stype(), false);
+    exprMap["a:eventname != set"]        = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["a:eventname == clear"]      = std::make_pair(AstEqual::stype(), true);
+
+    exprMap["a:metername >= 100"]        = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["b:metername le 100"]        = std::make_pair(AstLessEqual::stype(), true);
+    exprMap["./b:metername <= 100"]      = std::make_pair(AstLessEqual::stype(), true);
+    exprMap["../a/b:metername ge 100"]   = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["../a/b/c:metername >= 100"] = std::make_pair(AstGreaterEqual::stype(), false);
+
+    exprMap["!a:a  &&   b:b"]          = std::make_pair(AstAnd::stype(), false);
+    exprMap["a:a   && ! b:b"]          = std::make_pair(AstAnd::stype(), false);
+    exprMap["! a:a ||   b:b"]          = std::make_pair(AstOr::stype(), true);
+    exprMap["a:a   || ! b:b"]          = std::make_pair(AstOr::stype(), true);
+    exprMap["! a:a &&   b:b &&   c:c"] = std::make_pair(AstAnd::stype(), false);
+    exprMap["! a:a &&   b:b ||   c:c"] = std::make_pair(AstOr::stype(), false);
+    exprMap["a:a && !   b:b &&   c:c"] = std::make_pair(AstAnd::stype(), false);
+    exprMap["a:a && !   b:b ||   c:c"] = std::make_pair(AstOr::stype(), false);
+    exprMap["a:a ||     b:b && ! c:c"] = std::make_pair(AstOr::stype(), false);
+    exprMap["a:a ||     b:b || ! c:c"] = std::make_pair(AstOr::stype(), true);
+
+    exprMap["a:b && b:c && c:d && ../c:b && ./x:y && z:x"]             = std::make_pair(AstAnd::stype(), false);
+    exprMap["! a:b && b:c && c:d && ../c:b && ./x:y && z:x"]           = std::make_pair(AstAnd::stype(), false);
+    exprMap["! a:b || b:c && c:d && ../c:b && ./x:y && z:x"]           = std::make_pair(AstOr::stype(), true);
+    exprMap["a:b || b:c && ! c:d && ../c:b && ./x:y && z:x"]           = std::make_pair(AstOr::stype(), false);
+    exprMap["a:b && b:c && c:d && ../c:b && ./x:y && ! z:x"]           = std::make_pair(AstAnd::stype(), false);
+    exprMap["x:x || a:b && b:c && c:d && ../c:b && ./x:y && z:x"]      = std::make_pair(AstOr::stype(), false);
+    exprMap["x:x == 0 || a:b && b:c && c:d && ../c:b && ./x:y && z:x"] = std::make_pair(AstOr::stype(), true);
+    exprMap["! a:a && ! b:b && ! c:c && ! d:d "]                       = std::make_pair(AstAnd::stype(), true);
+    exprMap["! a:a || ! b:b || ! c:c || ! d:d "]                       = std::make_pair(AstOr::stype(), true);
+
+    exprMap["./a == unknown"]      = std::make_pair(AstEqual::stype(), true);
+    exprMap["./a/b != queued"]     = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["../a == complete"]    = std::make_pair(AstEqual::stype(), false);
+    exprMap["../a/b == aborted"]   = std::make_pair(AstEqual::stype(), false);
+    exprMap["../a/b/c != aborted"] = std::make_pair(AstNotEqual::stype(), true);
+
+    exprMap["inigroup:YMD == ! 1"]                 = std::make_pair(AstEqual::stype(), true);
+    exprMap["1 != ! 1"]                            = std::make_pair(AstNotEqual::stype(), true);
+    exprMap["b == complete or nodepath:eventname"] = std::make_pair(AstOr::stype(), false);
+
+    exprMap["a eq unknown and b ne complete"]    = std::make_pair(AstAnd::stype(), true);
+    exprMap["a eq complete or b eq complete"]    = std::make_pair(AstOr::stype(), false);
+    exprMap["a eq complete or b eq unknown"]     = std::make_pair(AstOr::stype(), true);
+    exprMap["a eq complete and b eq complete"]   = std::make_pair(AstAnd::stype(), false);
+    exprMap["(a eq complete and b == complete)"] = std::make_pair(AstAnd::stype(), false);
+
+    exprMap["a == unknown && b != complete"]    = std::make_pair(AstAnd::stype(), true);
+    exprMap["a == complete || b == complete"]   = std::make_pair(AstOr::stype(), false);
+    exprMap["a == complete || b == unknown"]    = std::make_pair(AstOr::stype(), true);
+    exprMap["a eq complete && b eq complete"]   = std::make_pair(AstAnd::stype(), false);
+    exprMap["(a == complete && b == complete)"] = std::make_pair(AstAnd::stype(), false);
+
+    // This should be interpreted as '(a == complete and b == complete) or c == complete'
+    // because 'and' has a higher priority than the 'or'. Hence 'OR' must be at the root.
+    exprMap["a == complete and b == complete or c == complete"]             = std::make_pair(AstOr::stype(), false);
+    exprMap["a == complete &&  b == complete || c == complete"]             = std::make_pair(AstOr::stype(), false);
+    exprMap["a == complete and b == complete or c == unknown"]              = std::make_pair(AstOr::stype(), true);
+    exprMap["a == complete and (b == complete or c == complete)"]           = std::make_pair(AstAnd::stype(), false);
+    exprMap["a == complete or b == complete and c == complete"]             = std::make_pair(AstOr::stype(), false);
+    exprMap["((a == complete or b == complete)) and c == complete"]         = std::make_pair(AstAnd::stype(), false);
+    exprMap["a == complete && b == complete and c == complete or x:a == 0"] = std::make_pair(AstOr::stype(), true);
+    exprMap["a == complete || b == complete and c == complete and x:a == 0 || x == complete"] =
+        std::make_pair(AstOr::stype(), false);
+    exprMap["a == complete || b == complete and c == complete and x:a || x == complete"] =
+        std::make_pair(AstOr::stype(), false);
+
+    exprMap["(a != aborted and b == unknown or c != queued)"]          = std::make_pair(AstOr::stype(), true);
+    exprMap["(a == complete and b == complete) or nodepath:eventname"] = std::make_pair(AstOr::stype(), false);
+    exprMap["(a == complete and b == complete) or (a == complete and b == complete)"] =
+        std::make_pair(AstOr::stype(), false);
+    exprMap["a == complete and (b == complete or a == complete) and b == complete"] =
+        std::make_pair(AstAnd::stype(), false);
+
+    // Expression that initially fail to parse for the operational suites
+    exprMap["(/skull/consumer/admin/leader:1 and (0 le /skull/consumer/produce1/produce:STEP)) or (not "
+            "/skull/consumer/admin/leader:1)"] = std::make_pair(AstOr::stype(), true);
+    exprMap["./pdb eq complete and  (  not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)"] =
+        std::make_pair(AstAnd::stype(), false);
+    exprMap["! ../../../prod2diss//operation_is_late:yes"]                    = std::make_pair(AstNot::stype(), true);
+    exprMap["not ../../../prod2diss//operation_is_late:yes"]                  = std::make_pair(AstNot::stype(), true);
+    exprMap["not ../../../prod2diss/operation_is_late:yes"]                   = std::make_pair(AstNot::stype(), true);
+    exprMap["not ../../../prod2diss/operation_is_late:yes or a == complete "] = std::make_pair(AstOr::stype(), true);
+    exprMap["not ../../../prod2diss/operation_is_late:yes or not a == complete "] =
+        std::make_pair(AstOr::stype(), true);
+    exprMap["not ( a == complete )"]                      = std::make_pair(AstNot::stype(), true);
+    exprMap["not ( a == unknown )"]                       = std::make_pair(AstNot::stype(), false);
+    exprMap["~ ( a == unknown )"]                         = std::make_pair(AstNot::stype(), false);
+    exprMap["~ ( a != unknown )"]                         = std::make_pair(AstNot::stype(), true);
+    exprMap["! ( a == unknown )"]                         = std::make_pair(AstNot::stype(), false);
+    exprMap["!( a == unknown )"]                          = std::make_pair(AstNot::stype(), false);
+    exprMap["inigroup:YMD eq ~ 1"]                        = std::make_pair(AstEqual::stype(), true);
+    exprMap["inigroup:YMD eq ~ 0"]                        = std::make_pair(AstEqual::stype(), false);
+    exprMap["inigroup:YMD eq ! 0"]                        = std::make_pair(AstEqual::stype(), false);
+    exprMap["/net/main:YMD le /net/cleanplus1:YMD and 1"] = std::make_pair(AstAnd::stype(), true);
+
+    exprMap["! ../../../operation_is_late:yes == set"]                    = std::make_pair(AstNot::stype(), true);
+    exprMap["2 == (((/seasplots/lag:YMD / 100 ) % 100) % 3)"]             = std::make_pair(AstEqual::stype(), false);
+    exprMap["(((/seasplots/lag:YMD / 100 ) % 100) % 3) ==  2"]            = std::make_pair(AstEqual::stype(), false);
+    exprMap["! ../../../a:yes == set or ! a == complete or y == aborted"] = std::make_pair(AstOr::stype(), true);
+
+    exprMap["bins/wamabs eq complete and links eq complete"] = std::make_pair(AstAnd::stype(), false);
+    exprMap["/mc/main:YMD le /mc/main/ref:MC_STOP"]          = std::make_pair(AstLessEqual::stype(), true);
+    exprMap["/mc//main:YMD le /mc/main//ref:MC_STOP"]        = std::make_pair(AstLessEqual::stype(), true);
+    exprMap["(  ( /o/main/12/an/slwet eq complete and  ( /o/main/12/an/4dvar/ifstraj:finalwave or /o/main/12/an/4dvar "
+            "eq complete)) or /o/main/12/an eq complete)"]   = std::make_pair(AstOr::stype(), false);
+    exprMap["../../sv/getsvs eq complete and  ( getae:1 or getae eq complete)"] =
+        std::make_pair(AstAnd::stype(), false);
+    exprMap["(  ( /o/lag:YMD gt /sync/o/o/lag:YMD) or  ( /o/main:YMD gt /sync/o/o/main:YMD) or 1 eq 0) and /sync/o ne "
+            "active and /sync/o ne submitted"] = std::make_pair(AstAnd::stype(), false);
+
+    exprMap["t:step + 20 le 19"]               = std::make_pair(AstLessEqual::stype(), false);
+    exprMap["(t:step + 20) le 19"]             = std::make_pair(AstLessEqual::stype(), false);
+    exprMap["t:step + 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["t:step - 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["t:step + 20 ge t:step1 - 20"]     = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["(t:step + 20) ge (t:step1 - 20)"] = std::make_pair(AstGreaterEqual::stype(), true);
+
+    // Note: t:step will evaluate to 0,  0 % number  == 0, however 20 % 0 is a runtime error, same as divide by zero
+    exprMap["t:step % 20 < 19"]                = std::make_pair(AstLessThan::stype(), true);
+    exprMap["t:step % 10 == 0"]                = std::make_pair(AstEqual::stype(), true);
+    exprMap["t:step % 20 ge 19"]               = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["(t:step % 20) ge 19"]             = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["t:step % 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["t:step % 20 ge 120"]              = std::make_pair(AstGreaterEqual::stype(), false);
+    exprMap["t:step % 20 ge t:step1 - 20"]     = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["(t:step % 20) ge (t:step1 - 20)"] = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["(t:step % 20) == (t:step1 % 10)"] = std::make_pair(AstEqual::stype(), true);
+
+    exprMap["( obs:YMD le  ( main:YMD + 1)) and ../make/setup eq complete and  ( obs:YMD le /o/lag:YMD)"] =
+        std::make_pair(AstAnd::stype(), false);
+    exprMap["( stage eq complete or ./stage:YMD gt ./retrieve:YMD) and ( ./retrieve:YMD - ./load:YMD lt 5)"] =
+        std::make_pair(AstAnd::stype(), false);
+    exprMap["./a:YMD - ./b:YMD lt 5"] = std::make_pair(AstLessThan::stype(), true);
+
+    exprMap["comp == complete and notready == complete"] = std::make_pair(AstAnd::stype(), false);
+
+    exprMap["/s/f/t<flag>late"]                          = std::make_pair(AstFlag::stype(), false);
+    exprMap["./s<flag>late"]                             = std::make_pair(AstFlag::stype(), false);
+    exprMap["../s/f/t<flag>late"]                        = std::make_pair(AstFlag::stype(), false);
+    exprMap["/s/f/t<flag>late == 0"]                     = std::make_pair(AstEqual::stype(), true);
+    exprMap["0 == /s/f/t<flag>late"]                     = std::make_pair(AstEqual::stype(), true);
+    exprMap["/s/f/t<flag>late and /s/f/t<flag>late"]     = std::make_pair(AstAnd::stype(), false);
+    exprMap["! /s/f/t<flag>late and ! /s/f/t<flag>late"] = std::make_pair(AstAnd::stype(), true);
+    exprMap["! /s/f/t<flag>late"]                        = std::make_pair(AstNot::stype(), true);
+    exprMap["/s/f/t<flag>late + 2 >= 2"]                 = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["(/s/f/t<flag>late or 1)"]                   = std::make_pair(AstOr::stype(), true);
+    exprMap["/<flag>late"]                               = std::make_pair(AstFlag::stype(), false);
+
+    exprMap["/s/f/t<flag>zombie"]                            = std::make_pair(AstFlag::stype(), false);
+    exprMap["./s<flag>zombie"]                               = std::make_pair(AstFlag::stype(), false);
+    exprMap["../s/f/t<flag>zombie"]                          = std::make_pair(AstFlag::stype(), false);
+    exprMap["/s/f/t<flag>zombie == 0"]                       = std::make_pair(AstEqual::stype(), true);
+    exprMap["0 == /s/f/t<flag>zombie"]                       = std::make_pair(AstEqual::stype(), true);
+    exprMap["/s/f/t<flag>zombie and /s/f/t<flag>zombie"]     = std::make_pair(AstAnd::stype(), false);
+    exprMap["/s/f/t<flag>zombie or /s/f/t<flag>zombie"]      = std::make_pair(AstOr::stype(), false);
+    exprMap["! /s/f/t<flag>zombie and ! /s/f/t<flag>zombie"] = std::make_pair(AstAnd::stype(), true);
+    exprMap["! /s/f/t<flag>zombie"]                          = std::make_pair(AstNot::stype(), true);
+    exprMap["/s/f/t<flag>zombie + 2 >= 2"]                   = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["(/s/f/t<flag>zombie or 1)"]                     = std::make_pair(AstOr::stype(), true);
+
+    exprMap["/s/f/t<flag>archived"]                              = std::make_pair(AstFlag::stype(), false);
+    exprMap["./s<flag>archived"]                                 = std::make_pair(AstFlag::stype(), false);
+    exprMap["../s/f/t<flag>archived"]                            = std::make_pair(AstFlag::stype(), false);
+    exprMap["/s/f/t<flag>archived == 0"]                         = std::make_pair(AstEqual::stype(), true);
+    exprMap["0 == /s/f/t<flag>archived"]                         = std::make_pair(AstEqual::stype(), true);
+    exprMap["/s/f/t<flag>archived and /s/f/t<flag>archived"]     = std::make_pair(AstAnd::stype(), false);
+    exprMap["/s/f/t<flag>archived or /s/f/t<flag>archived"]      = std::make_pair(AstOr::stype(), false);
+    exprMap["! /s/f/t<flag>archived and ! /s/f/t<flag>archived"] = std::make_pair(AstAnd::stype(), true);
+    exprMap["! /s/f/t<flag>archived"]                            = std::make_pair(AstNot::stype(), true);
+    exprMap["/s/f/t<flag>archived + 2 >= 2"]                     = std::make_pair(AstGreaterEqual::stype(), true);
+    exprMap["(/s/f/t<flag>archived or 1)"]                       = std::make_pair(AstOr::stype(), true);
+
+    exprMap[":VAR == 0"]                    = std::make_pair(AstEqual::stype(), true);
+    exprMap[":VAR == 1"]                    = std::make_pair(AstEqual::stype(), false);
+    exprMap[":VAR == /mc/main/ref:MC_STOP"] = std::make_pair(AstEqual::stype(), true);
+    exprMap[":YMD - :YMD <= 5"]             = std::make_pair(AstLessEqual::stype(), true);
+    exprMap[":YMD + :YMD <= 5"]             = std::make_pair(AstLessEqual::stype(), true);
+    exprMap[":YMD * :YMD <= 5"]             = std::make_pair(AstLessEqual::stype(), true);
+    exprMap[":YMD + 1 == 1"]                = std::make_pair(AstEqual::stype(), true);
+
+    exprMap[":VAR == 20000101T235959"] = std::make_pair(AstEqual::stype(), false);
+    exprMap[":VAR <= 20000101T235959"] = std::make_pair(AstLessEqual::stype(), true);
+    exprMap[":VAR >= 20000101T235959"] = std::make_pair(AstGreaterEqual::stype(), false);
+
+    int parse_failure = 0;
+    int ast_failure   = 0;
+    // std::pair<string, std::pair<string,bool> > p;
+    for (const auto& p : exprMap) {
+
+        // cout << "parsing: " << p.first << "\n";
+        ExprParser theExprParser(p.first);
+        std::string errorMsg;
+        bool ok = theExprParser.doParse(errorMsg);
+        if (!ok)
+            parse_failure++;
+        BOOST_CHECK_MESSAGE(ok, errorMsg + "failed for " + p.first);
+
+        if (ok) {
+            string expectedRootType       = p.second.first;
+            bool expectedEvaluationResult = p.second.second;
+
+            Ast* top = theExprParser.getAst();
+            if (!top)
+                ast_failure++;
+            BOOST_CHECK_MESSAGE(top, "No abstract syntax tree " + p.first);
+            if (top) {
+                BOOST_CHECK_MESSAGE(top->left(), "No root created " + p.first);
+                BOOST_CHECK_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
+                                    "First child of top should be a root or attribute " + p.first);
+                BOOST_CHECK_MESSAGE(top->left()->is_evaluateable(),
+                                    "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
+                BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
+                                    "expected root type '" << expectedRootType << "' or 'variable' but found '"
+                                                           << top->left()->type() << "' " << p.first);
+                BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(),
+                                    "evaluation not as expected for:\n"
+                                        << p.first << "\n"
+                                        << *top);
+
+                std::string error_msg;
+                BOOST_CHECK_MESSAGE(top->check(error_msg), error_msg << ":  Check failed for " << *top);
+
+                std::string why;
+                top->why(why);
+                // cout << "why: " << p.first << " -> " << why << "\n";
+                if (top->evaluate()) {
+                    BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << p.first);
+                }
+                else {
+                    BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << p.first);
+                }
+            }
+        }
+    }
+    BOOST_REQUIRE_MESSAGE(parse_failure == 0 && ast_failure == 0,
+                          "Found failures parse_failure:" << parse_failure << " ast failure:" << ast_failure);
+}
+
+BOOST_AUTO_TEST_CASE(test_trigger_functions) {
+    std::cout << "ANode:: ...test_trigger_functions\n";
+
+    // The map key  = trigger expression,
+    // value.first  = type of the expected root abstract syntax tree
+    // value.second = result of expected evaluation
+    map<string, std::pair<string, bool>> exprMap;
+
+    exprMap["cal::date_to_julian(A:x) == 0"]                          = std::make_pair(AstEqual::stype(), true);
+    exprMap["cal::date_to_julian( 0 ) == cal::date_to_julian( 0 )"]   = std::make_pair(AstEqual::stype(), true);
+    exprMap["cal::date_to_julian( 0 ) == cal::date_to_julian( A:x )"] = std::make_pair(AstEqual::stype(), true);
+    exprMap["2457620 == cal::date_to_julian( 20160819 )"]             = std::make_pair(AstEqual::stype(), true);
+    exprMap["20160819 == cal::julian_to_date( 2457620 )"]             = std::make_pair(AstEqual::stype(), true);
+
+    // test 10 digit integer, ie yyyymmddhh
+    exprMap["2457620 == cal::date_to_julian( 2016081912 )"] = std::make_pair(AstEqual::stype(), true);
+
+    int parse_failure = 0;
+    int ast_failure   = 0;
+    for (std::pair<string, std::pair<string, bool>> p : exprMap) {
+
+        // cout << "parsing: " << p.first << "\n";
+        ExprParser theExprParser(p.first);
+        std::string errorMsg;
+        bool ok = theExprParser.doParse(errorMsg);
+        if (!ok)
+            parse_failure++;
+        BOOST_CHECK_MESSAGE(ok, errorMsg + "failed for " + p.first);
+
+        if (ok) {
+            string expectedRootType       = p.second.first;
+            bool expectedEvaluationResult = p.second.second;
+
+            Ast* top = theExprParser.getAst();
+            if (!top)
+                ast_failure++;
+            BOOST_CHECK_MESSAGE(top, "No abstract syntax tree " + p.first);
+            if (top) {
+                BOOST_CHECK_MESSAGE(top->left(), "No root created " + p.first);
+                BOOST_CHECK_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
+                                    "First child of top should be a root or attribute " + p.first);
+                BOOST_CHECK_MESSAGE(top->left()->is_evaluateable(),
+                                    "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
+                BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
+                                    "expected root type '" << expectedRootType << "' or 'variable' but found '"
+                                                           << top->left()->type() << "' " << p.first);
+                BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(),
+                                    "evaluation not as expected for:\n"
+                                        << p.first << "\n"
+                                        << *top);
+
+                std::string error_msg;
+                BOOST_CHECK_MESSAGE(top->check(error_msg), error_msg << ":  Check failed for " << *top);
+
+                std::string why;
+                top->why(why);
+                // cout << "why: " << p.first << " -> " << why << "\n";
+                if (top->evaluate()) {
+                    BOOST_CHECK_MESSAGE(why.empty(), "Expected why to be empty when expression evaluates: " << p.first);
+                }
+                else {
+                    BOOST_CHECK_MESSAGE(!why.empty(), "When ast does not evaluate we expect to find why: " << p.first);
+                }
+            }
+        }
+    }
+    BOOST_REQUIRE_MESSAGE(parse_failure == 0 && ast_failure == 0,
+                          "Found failures parse_failure:" << parse_failure << " ast failure:" << ast_failure);
+}
+
+BOOST_AUTO_TEST_CASE(test_date_to_julian_with_repeat_YMD) {
+    std::cout << "ANode:: ...test_date_to_julian_with_repeat_YMD\n";
+
+    Defs theDefs;
+    suite_ptr suite = theDefs.add_suite("s1");
+    suite->addRepeat(RepeatDate("YMD", 20170101, 20180101, 1));
+    task_ptr t1 = suite->add_task("t1");
+    t1->add_trigger("2457755 == cal::date_to_julian( /s1:YMD )");
+    theDefs.beginAll();
+
+    std::string err_msg, warn_msg;
+    theDefs.check(err_msg, warn_msg);
+    BOOST_REQUIRE_MESSAGE(err_msg.empty() && warn_msg.empty(),
+                          "Expected no errors but found " << err_msg
+                                                          << "\nexpected no warnings but found: " << warn_msg);
+
+    // make sure we can resolve /s1:YMD if this the case bottom_up_why should return vector of size 0
+    std::vector<std::string> theReasonWhy;
+    t1->bottom_up_why(theReasonWhy);
+    BOOST_CHECK_MESSAGE(theReasonWhy.empty(), "When all is well expected empty reason vec");
+
+    // be more flexible, of vector is returned we should not get: variable-not-found
+    for (auto& i : theReasonWhy) {
+        cout << i << "\n";
+        BOOST_CHECK_MESSAGE(i.find("variable-not-found") == string::npos, "Variable YMD not found: " << i);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_trigger_functions_with_boost_date) {
+    std::cout << "ANode:: ...test_trigger_functions_with_boost_date\n";
+    // The map key  = trigger expression,
+    // value.first  = type of the expected root abstract syntax tree
+    // value.second = result of expected evaluation
+    map<string, std::pair<string, bool>> exprMap;
+
+    boost::gregorian::date startDate(2017, 1, 1);
+    boost::gregorian::date endDate(2017, 12, 31);
+    while (startDate != endDate) {
+        long julian_day                    = startDate.julian_day();
+        std::string str_julian_day         = ecf::convert_to<std::string>(julian_day);
+        std::string eight_digit_iso_string = to_iso_string(startDate);
+        string expr   = str_julian_day + " ==  cal::date_to_julian(" + eight_digit_iso_string + ")";
+        exprMap[expr] = std::make_pair(AstEqual::stype(), true);
+
+        std::string ten_digit_string = eight_digit_iso_string + "12";
+        expr                         = str_julian_day + " ==  cal::date_to_julian(" + ten_digit_string + ")";
+        exprMap[expr]                = std::make_pair(AstEqual::stype(), true);
+
+        string expr2   = to_iso_string(startDate) + " == cal::julian_to_date(" + str_julian_day + ")";
+        exprMap[expr2] = std::make_pair(AstEqual::stype(), true);
+        startDate += days(1);
+    }
+
+    int parse_failure = 0;
+    int ast_failure   = 0;
+    for (std::pair<string, std::pair<string, bool>> p : exprMap) {
+
+        // cout << "parsing: " << p.first << "\n";
+        ExprParser theExprParser(p.first);
+        std::string errorMsg;
+        bool ok = theExprParser.doParse(errorMsg);
+        if (!ok)
+            parse_failure++;
+        BOOST_CHECK_MESSAGE(ok, errorMsg + "failed for " + p.first);
+
+        if (ok) {
+            string expectedRootType       = p.second.first;
+            bool expectedEvaluationResult = p.second.second;
+
+            Ast* top = theExprParser.getAst();
+            if (!top)
+                ast_failure++;
+            BOOST_CHECK_MESSAGE(top, "No abstract syntax tree " + p.first);
+            if (top) {
+                BOOST_CHECK_MESSAGE(top->left(), "No root created " + p.first);
+                BOOST_CHECK_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
+                                    "First child of top should be a root or attribute " + p.first);
+                BOOST_CHECK_MESSAGE(top->left()->is_evaluateable(),
+                                    "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
+                BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
+                                    "expected root type '" << expectedRootType << "' or 'variable' but found '"
+                                                           << top->left()->type() << "' " << p.first);
+                BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(),
+                                    "evaluation not as expected for:\n"
+                                        << p.first << "\n"
+                                        << *top);
+
+                std::string error_msg;
+                BOOST_CHECK_MESSAGE(top->check(error_msg), error_msg << ":  Check failed for " << *top);
+            }
+        }
+    }
+    BOOST_REQUIRE_MESSAGE(parse_failure == 0 && ast_failure == 0,
+                          "Found failures parse_failure:" << parse_failure << " ast failure:" << ast_failure);
+}
+
+BOOST_AUTO_TEST_CASE(test_trigger_expression_divide_by_zero) {
+    std::cout << "ANode:: ...test_trigger_expression_divide_by_zero\n";
+
+    // The map key  = trigger expression,
+    // value.first  = type of the expected root abstract syntax tree
+    // value.second = result of expected evaluation
+    map<string, std::pair<string, bool>> exprMap;
+
+    // Divide by zero or modulo by zero would lead to run-time crash
+    // However the Ast::evaluate() checks for this, and return zero for the whole expression i.e ./a:YMD % 0 returns 0
+    exprMap["./a:YMD % 0 == 0"] = std::make_pair(AstEqual::stype(), true);
+    exprMap["./a:YMD / 0 == 0"] = std::make_pair(AstEqual::stype(), true);
+    exprMap[":YMD % 0 == 0"]    = std::make_pair(AstEqual::stype(), true);
+    exprMap[":YMD / 0 == 0"]    = std::make_pair(AstEqual::stype(), true);
+
+    // std::pair<string, std::pair<string,bool> > p;
+    for (const auto& p : exprMap) {
+
+        ExprParser theExprParser(p.first);
+        std::string errorMsg;
+        bool ok = theExprParser.doParse(errorMsg);
+        BOOST_REQUIRE_MESSAGE(ok, errorMsg);
+
+        string expectedRootType       = p.second.first;
+        bool expectedEvaluationResult = p.second.second;
+
+        Ast* top = theExprParser.getAst();
+        BOOST_REQUIRE_MESSAGE(top, "No abstract syntax tree");
+        BOOST_CHECK_MESSAGE(top->left(), "No root created");
+        BOOST_CHECK_MESSAGE(top->left()->isRoot(), "First child of top should be a root");
+        BOOST_CHECK_MESSAGE(top->left()->type() == expectedRootType,
+                            "expected root type " << expectedRootType << " but found " << top->left()->type());
+        BOOST_CHECK_MESSAGE(expectedEvaluationResult == top->evaluate(), "evaluation not as expected for " << *top);
+
+        // expect check to fail, due to divide/modulo by zero
+        std::string error_msg;
+        BOOST_CHECK_MESSAGE(!top->check(error_msg), error_msg << ":  Check failed for " << *top);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_parser_bad_expressions) {
+    std::cout << "ANode:: ...test_parser_bad_expressions\n";
+
+    std::vector expressions = {"/s/f/t<flag>restored"s,
+                               "a <= complete"s,
+                               "a >= complete"s,
+                               "a = complete"s,
+                               "a e complete"s,
+                               "a=complete"s,
+                               "a ! complete"s,
+                               "a==complet e"s,
+                               "a eq complet e"s,
+                               "a::eventname"s,
+                               "a:eventname =  set"s,
+                               "a:eventname == "s,
+                               "a:eventname !  set"s,
+                               "a:eventname ! = set"s,
+                               "a:eventname %"s,
+                               "a:event <= set"s,
+                               "a:event >= set"s,
+                               "a:event >= clear"s,
+                               "a:event >= fred"s,
+                               "a:metername  100"s,
+                               ". == complete"s,
+                               "/ == complete"s,
+                               ". == error"s,
+                               "./ == error"s,
+                               ".a == error"s,
+                               ".a == unknown"s,
+                               ".a/. == unknown"s,
+                               ".. == unknown"s,
+                               ".a/b == queued"s,
+                               "./a/b/ == active"s,
+                               "..a == complete"s,
+                               ".../a == complete"s,
+                               "../.../a == complete"s,
+                               ".. /a == complete"s,
+                               "../.. /a == complete"s,
+                               "../../.a == complete"s,
+                               "..a/b == aborted"s,
+                               "..a/b/c == aborted"s,
+                               "a == complete and"s,
+                               "a %"s,
+                               "(a == complete   b == complete)"s,
+                               "a == complete and  b == complete)"s,
+                               "(a == complete and  b == complete"s,
+                               "(a = complete and b = complete or c = complete)"s,
+                               "(a erro complete and b == complete) or nodepath:eventname"s,
+                               "(a == complete and b == complete or (a == complete and b == complete)"s,
+                               // triggers that don't make sense in the operational suites
+                               "../../../legA/fc/pf/01 eq complete eq complete"s,
+                               "/mofc/mon/hind/14/back == complete or %s:DOW ne 5"s, // ECFLOW-888
+                               ":VAR eq 20001332T257890"s};
+
+    for (const auto& expression : expressions) {
+
+        // std::cout << "parsing expression " << expr << "\n";
+        ExprParser theExprParser(expression);
+        std::string error;
+        auto actual = theExprParser.doParse(error);
+        BOOST_CHECK_MESSAGE(!actual, expression << " expected to fail ");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestExprRepeatDateArithmetic.cpp 5.13.0-1/libs/node/test/TestExprRepeatDateArithmetic.cpp
--- 5.12.4-1/libs/node/test/TestExprRepeatDateArithmetic.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestExprRepeatDateArithmetic.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,220 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_ExprRepeatDateArithmetic)
+
+BOOST_AUTO_TEST_CASE(test_repeat_data_arithmetic) {
+    cout << "ANode:: ...test_repeat_data_arithmetic\n";
+
+    Defs theDefs;
+    task_ptr t2, t1;
+    {
+        suite_ptr s1 = theDefs.add_suite("s1");
+        t1           = s1->add_task("t1");
+        t1->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
+        t2 = s1->add_task("t2");
+        t2->add_trigger("t1:YMD ge 20080601");
+    }
+    theDefs.beginAll();
+
+    // Check trigger expressions
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
+
+    // Get the trigger AST
+    AstTop* trigger = t2->triggerAst();
+    BOOST_REQUIRE_MESSAGE(trigger, "Expected trigger");
+
+    // check evaluation
+    BOOST_CHECK_MESSAGE(trigger->evaluate(), "Expected trigger to evaluate i.e 20090101 >= 20080601");
+
+    // Check date arithmetic. Basics, end of months
+    t2->changeTrigger("t1:YMD - 1 eq 20081231"); // 20090101 - 1  == 20081231
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
+
+    t2->changeTrigger("t1:YMD + 1 eq 20090102"); // 20090101 + 1  == 20090102
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_data_arithmetic_add_to_end_of_month) {
+    cout << "ANode:: ...test_repeat_data_arithmetic_add_to_end_of_month\n";
+
+    Defs theDefs;
+    task_ptr t2, t1;
+    {
+        suite_ptr s1 = theDefs.add_suite("s1");
+        t1           = s1->add_task("t1");
+        t1->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
+        t2 = s1->add_task("t2");
+        t2->add_trigger("t1:YMD ge 20080601");
+    }
+    theDefs.beginAll();
+
+    // Check trigger expressions
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
+
+    // Check the end of each month + 1
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090131, 20101231, 1)); // jan
+    t2->changeTrigger("t1:YMD + 1 eq 20090201");             // 20090131 + 1  == 20090201
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090228, 20101231, 1)); // feb
+    t2->changeTrigger("t1:YMD + 1 eq 20090301");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090331, 20101231, 1)); // mar
+    t2->changeTrigger("t1:YMD + 1 eq 20090401");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090430, 20101231, 1)); // apr
+    t2->changeTrigger("t1:YMD + 1 eq 20090501");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090531, 20101231, 1)); // may
+    t2->changeTrigger("t1:YMD + 1 eq 20090601");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090630, 20101231, 1)); // June
+    t2->changeTrigger("t1:YMD + 1 eq 20090701");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090731, 20101231, 1)); // July
+    t2->changeTrigger("t1:YMD + 1 eq 20090801");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090831, 20101231, 1)); // Aug
+    t2->changeTrigger("t1:YMD + 1 eq 20090901");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090930, 20101231, 1)); // Sept
+    t2->changeTrigger("t1:YMD + 1 eq 20091001");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20091031, 20101231, 1)); // Oct
+    t2->changeTrigger("t1:YMD + 1 eq 20091101");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20091130, 20101231, 1)); // Nov
+    t2->changeTrigger("t1:YMD + 1 eq 20091201");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20091231, 20101231, 1)); // Dec
+    t2->changeTrigger("t1:YMD + 1 eq 20100101");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_data_arithmetic_take_from_end_of_month) {
+    cout << "ANode:: ...test_repeat_data_arithmetic_take_from_end_of_month\n";
+
+    Defs theDefs;
+    task_ptr t2, t1;
+    {
+        suite_ptr s1 = theDefs.add_suite("s1");
+        t1           = s1->add_task("t1");
+        t1->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
+        t2 = s1->add_task("t2");
+        t2->add_trigger("t1:YMD ge 20080601");
+    }
+    theDefs.beginAll();
+
+    // Check trigger expressions
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
+
+    // Check the end of each month - 1
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090201, 20101231, 1)); // jan
+    t2->changeTrigger("t1:YMD - 1 eq 20090131");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090301, 20101231, 1)); // feb
+    t2->changeTrigger("t1:YMD - 1 eq 20090228");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090401, 20101231, 1)); // mar
+    t2->changeTrigger("t1:YMD - 1 eq 20090331");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090501, 20101231, 1)); // apr
+    t2->changeTrigger("t1:YMD - 1 eq 20090430");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090601, 20101231, 1)); // may
+    t2->changeTrigger("t1:YMD - 1 eq 20090531");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090701, 20101231, 1)); // June
+    t2->changeTrigger("t1:YMD - 1 eq 20090630");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090801, 20101231, 1)); // July
+    t2->changeTrigger("t1:YMD - 1 eq 20090731");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20090901, 20101231, 1)); // Aug
+    t2->changeTrigger("t1:YMD - 1 eq 20090831");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20091001, 20101231, 1)); // Sept
+    t2->changeTrigger("t1:YMD - 1 eq 20090930");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20091101, 20101231, 1)); // Oct
+    t2->changeTrigger("t1:YMD - 1 eq 20091031");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20091201, 20101231, 1)); // Nov
+    t2->changeTrigger("t1:YMD - 1 eq 20091130");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDate("YMD", 20100101, 20101231, 1)); // Dec
+    t2->changeTrigger("t1:YMD - 1 eq 20091231");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestExprRepeatDateListArithmetic.cpp 5.13.0-1/libs/node/test/TestExprRepeatDateListArithmetic.cpp
--- 5.12.4-1/libs/node/test/TestExprRepeatDateListArithmetic.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestExprRepeatDateListArithmetic.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,220 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_ExprRepeatDateListArithmetic)
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_list_arithmetic) {
+    cout << "ANode:: ... test_repeat_date_list_arithmetic\n";
+
+    Defs theDefs;
+    task_ptr t2, t1;
+    {
+        suite_ptr s1 = theDefs.add_suite("s1");
+        t1           = s1->add_task("t1");
+        t1->addRepeat(RepeatDateList("YMD", {20090101, 20091231}));
+        t2 = s1->add_task("t2");
+        t2->add_trigger("t1:YMD ge 20080601");
+    }
+    theDefs.beginAll();
+
+    // Check trigger expressions
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
+
+    // Get the trigger AST
+    AstTop* trigger = t2->triggerAst();
+    BOOST_REQUIRE_MESSAGE(trigger, "Expected trigger");
+
+    // check evaluation
+    BOOST_CHECK_MESSAGE(trigger->evaluate(), "Expected trigger to evaluate i.e 20090101 >= 20080601");
+
+    // Check date arithmetic. Basics, end of months
+    t2->changeTrigger("t1:YMD - 1 eq 20081231"); // 20090101 - 1  == 20081231
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
+
+    t2->changeTrigger("t1:YMD + 1 eq 20090102"); // 20090101 + 1  == 20090102
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic for evaluation");
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_list_arithmetic_add_to_end_of_month) {
+    cout << "ANode:: ...test_repeat_date_list_arithmetic_add_to_end_of_month \n";
+
+    Defs theDefs;
+    task_ptr t2, t1;
+    {
+        suite_ptr s1 = theDefs.add_suite("s1");
+        t1           = s1->add_task("t1");
+        t1->addRepeat(RepeatDateList("YMD", {20090101, 20091231}));
+        t2 = s1->add_task("t2");
+        t2->add_trigger("t1:YMD ge 20080601");
+    }
+    theDefs.beginAll();
+
+    // Check trigger expressions
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
+
+    // Check the end of each month + 1
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090131, 20101231})); // jan
+    t2->changeTrigger("t1:YMD + 1 eq 20090201");                // 20090131 + 1  == 20090201
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090228, 20101231})); // feb
+    t2->changeTrigger("t1:YMD + 1 eq 20090301");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090331, 20101231})); // mar
+    t2->changeTrigger("t1:YMD + 1 eq 20090401");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090430, 20101231})); // apr
+    t2->changeTrigger("t1:YMD + 1 eq 20090501");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090531, 20101231})); // may
+    t2->changeTrigger("t1:YMD + 1 eq 20090601");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090630, 20101231})); // June
+    t2->changeTrigger("t1:YMD + 1 eq 20090701");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090731, 20101231})); // July
+    t2->changeTrigger("t1:YMD + 1 eq 20090801");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090831, 20101231})); // Aug
+    t2->changeTrigger("t1:YMD + 1 eq 20090901");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090930, 20101231})); // Sept
+    t2->changeTrigger("t1:YMD + 1 eq 20091001");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20091031, 20101231})); // Oct
+    t2->changeTrigger("t1:YMD + 1 eq 20091101");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20091130, 20101231})); // Nov
+    t2->changeTrigger("t1:YMD + 1 eq 20091201");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20091231, 20101231})); // Dec
+    t2->changeTrigger("t1:YMD + 1 eq 20100101");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_list_arithmetic_take_from_end_of_month) {
+    cout << "ANode:: ... test_repeat_date_list_arithmetic_take_from_end_of_month\n";
+
+    Defs theDefs;
+    task_ptr t2, t1;
+    {
+        suite_ptr s1 = theDefs.add_suite("s1");
+        t1           = s1->add_task("t1");
+        t1->addRepeat(RepeatDateList("YMD", {20090101, 20091231}));
+        t2 = s1->add_task("t2");
+        t2->add_trigger("t1:YMD ge 20080601");
+    }
+    theDefs.beginAll();
+
+    // Check trigger expressions
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(theDefs.check(errorMsg, warningMsg), "Expected triggers expressions to parse " << errorMsg);
+
+    // Check the end of each month - 1
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090201, 20101231})); // jan
+    t2->changeTrigger("t1:YMD - 1 eq 20090131");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090301, 20101231})); // feb
+    t2->changeTrigger("t1:YMD - 1 eq 20090228");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090401, 20101231})); // mar
+    t2->changeTrigger("t1:YMD - 1 eq 20090331");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090501, 20101231})); // apr
+    t2->changeTrigger("t1:YMD - 1 eq 20090430");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090601, 20101231})); // may
+    t2->changeTrigger("t1:YMD - 1 eq 20090531");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090701, 20101231})); // June
+    t2->changeTrigger("t1:YMD - 1 eq 20090630");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090801, 20101231})); // July
+    t2->changeTrigger("t1:YMD - 1 eq 20090731");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20090901, 20101231})); // Aug
+    t2->changeTrigger("t1:YMD - 1 eq 20090831");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20091001, 20101231})); // Sept
+    t2->changeTrigger("t1:YMD - 1 eq 20090930");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20091101, 20101231})); // Oct
+    t2->changeTrigger("t1:YMD - 1 eq 20091031");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20091201, 20101231})); // Nov
+    t2->changeTrigger("t1:YMD - 1 eq 20091130");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+
+    t1->deleteRepeat();
+    t1->addRepeat(RepeatDateList("YMD", {20100101, 20101231})); // Dec
+    t2->changeTrigger("t1:YMD - 1 eq 20091231");
+    BOOST_CHECK_MESSAGE(t2->triggerAst()->evaluate(), "Expected trigger to use date arithmetic");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestFindAbsNodePath.cpp 5.13.0-1/libs/node/test/TestFindAbsNodePath.cpp
--- 5.12.4-1/libs/node/test/TestFindAbsNodePath.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestFindAbsNodePath.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_FindAbsNodePath)
+
+BOOST_AUTO_TEST_CASE(test_find_abs_node_path) {
+    cout << "ANode:: ...test_find_abs_node_path\n";
+
+    size_t no_of_nodes = 0;
+    size_t no_of_alias = 0;
+    Defs theDefs;
+    {
+        for (int s = 0; s < 3; s++) {
+            suite_ptr suite = theDefs.add_suite("suite" + ecf::convert_to<std::string>(s));
+            no_of_nodes++;
+            for (int f = 0; f < 3; f++) {
+                family_ptr fam = suite->add_family("family" + ecf::convert_to<std::string>(f));
+                no_of_nodes++;
+                for (int ff = 0; ff < 3; ff++) {
+                    family_ptr hfam = fam->add_family("family" + ecf::convert_to<std::string>(ff));
+                    no_of_nodes++;
+                    for (int t = 0; t < 3; t++) {
+                        task_ptr task = hfam->add_task("t1" + ecf::convert_to<std::string>(t));
+                        no_of_nodes++;
+                        for (int a = 0; a < 3; a++) {
+                            task->add_alias_only();
+                            no_of_nodes++;
+                            no_of_alias++;
+                        }
+                    }
+                }
+            }
+        }
+    }
+
+    // Test Defs::getAllNodes()
+    std::vector<Node*> all_nodes;
+    theDefs.getAllNodes(all_nodes);
+    BOOST_CHECK_MESSAGE(all_nodes.size() == no_of_nodes,
+                        "Expected theDefs.getAllNodes() to return " << no_of_nodes << " node, but found "
+                                                                    << all_nodes.size());
+
+    // Test Defs::get_all_aliases()
+    std::vector<alias_ptr> alias_vec;
+    theDefs.get_all_aliases(alias_vec);
+    BOOST_CHECK_MESSAGE(alias_vec.size() == no_of_alias,
+                        "Expected theDefs.get_all_aliases() to return " << no_of_alias << " node, but found "
+                                                                        << alias_vec.size());
+
+    // Test Defs::findAbsNode()
+    //   PrintStyle style(PrintStyle::STATE); std::cout << theDefs;
+    for (auto node : all_nodes) {
+        node_ptr found_node = theDefs.findAbsNode(node->absNodePath());
+        BOOST_CHECK_MESSAGE(found_node.get(), "Could not find node " << node->debugNodePath());
+        BOOST_CHECK_MESSAGE(found_node.get() == node,
+                            " Expected to find " << node->debugNodePath() << " but found "
+                                                 << found_node->debugNodePath());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestFlag.cpp 5.13.0-1/libs/node/test/TestFlag.cpp
--- 5.12.4-1/libs/node/test/TestFlag.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestFlag.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Flag.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Flag)
+
+BOOST_AUTO_TEST_CASE(test_node_flags) {
+    cout << "ANode:: ...test_node_flags\n";
+
+    Flag flag;
+    std::string expected_flags =
+        "force_aborted,user_edit,task_aborted,edit_failed,ecfcmd_failed,killcmd_failed,statuscmd_failed,no_script,"
+        "killed,status,late,message,by_rule,queue_limit,task_waiting,locked,zombie,no_reque,archived,restored,"
+        "threshold,sigterm,log_error,checkpt_error,remote_error";
+
+    /// Set the flags
+    std::vector<Flag::Type> flag_list = Flag::list();
+    for (auto& i : flag_list) {
+        flag.set(i);
+        BOOST_REQUIRE_MESSAGE(flag.is_set(i), "Expected flag to be set");
+    }
+    BOOST_REQUIRE_MESSAGE(flag.to_string() == expected_flags,
+                          "Expected string '" << expected_flags << "' but found '" << flag.to_string() << "'");
+    for (auto& i : flag_list) {
+        BOOST_REQUIRE_MESSAGE(flag.is_set(i), "Expected flag to be set");
+    }
+
+    /// clears the flags
+    for (auto& i : flag_list) {
+        flag.clear(i);
+        BOOST_REQUIRE_MESSAGE(!flag.is_set(i), "Expected flag to be clear");
+    }
+    for (auto& i : flag_list) {
+        BOOST_REQUIRE_MESSAGE(!flag.is_set(i), "Expected flag to be clear");
+    }
+
+    /// set all flags
+    for (auto& i : flag_list) {
+        flag.set(i);
+    }
+
+    // reset, all flags should be clear
+    flag.reset();
+    for (auto& i : flag_list) {
+        BOOST_REQUIRE_MESSAGE(!flag.is_set(i), "Expected flag to be clear");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_node_flags_parsing) {
+    cout << "ANode:: ...test_node_flags_parsing\n";
+
+    /// Set the flags
+    Flag flag;
+    std::vector<Flag::Type> flag_list = Flag::list();
+    for (auto& i : flag_list)
+        flag.set(i);
+
+    Flag flag2;
+    flag2.set_flag(flag.to_string());
+    BOOST_REQUIRE_MESSAGE(flag == flag2,
+                          "Flags should be equal.\nflag1:" << flag.to_string() << "\nflag2:" << flag2.to_string());
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestHistoryParser.cpp 5.13.0-1/libs/node/test/TestHistoryParser.cpp
--- 5.12.4-1/libs/node/test/TestHistoryParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestHistoryParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,112 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <iterator>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_HistoryParser)
+
+static std::string dump(const std::vector<std::string>& vec) {
+    std::stringstream ss;
+    std::copy(vec.begin(), vec.end(), std::ostream_iterator<std::string>(ss, "\n"));
+    return ss.str();
+}
+
+BOOST_AUTO_TEST_CASE(test_defs_history_parser) {
+    cout << "ANode:: ...test_defs_history_parser\n";
+
+    {
+        string str1("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
+        DefsHistoryParser parser;
+        parser.parse(str1);
+
+        std::vector<std::string> expected_messages;
+        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
+
+        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
+                            "Expected:\n"
+                                << dump(expected_messages) << "but found:\n"
+                                << dump(parser.parsed_messages()));
+    }
+    {
+        string str1("MSG:[12:03:55 21.8.2013] --shutdown=yes :mapMSG:[12:34:08 21.8.2013] --restart :map");
+        DefsHistoryParser parser;
+        parser.parse(str1);
+
+        std::vector<std::string> expected_messages;
+        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
+        expected_messages.emplace_back("MSG:[12:34:08 21.8.2013] --restart :map");
+        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
+                            "Expected:\n"
+                                << dump(expected_messages) << "but found:\n"
+                                << dump(parser.parsed_messages()));
+    }
+    {
+        string str1(
+            "MSG:[12:03:55 21.8.2013] --shutdown=yes :mapMSG:[12:34:08 21.8.2013] --restart :mapMSG:[12:47:22 "
+            "21.8.2013] --alter add variable SMSNODE 0 /  :mapMSG:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 "
+            "/  :mapMSG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :mapMSG:[15:36:14 "
+            "21.8.2013] --shutdown=yes :mapMSG:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
+        DefsHistoryParser parser;
+        parser.parse(str1);
+
+        std::vector<std::string> expected_messages;
+        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
+        expected_messages.emplace_back("MSG:[12:34:08 21.8.2013] --restart :map");
+        expected_messages.emplace_back("MSG:[12:47:22 21.8.2013] --alter add variable SMSNODE 0 /  :map");
+        expected_messages.emplace_back("MSG:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 /  :map");
+        expected_messages.emplace_back(
+            "MSG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :map");
+        expected_messages.emplace_back("MSG:[15:36:14 21.8.2013] --shutdown=yes :map");
+        expected_messages.emplace_back("MSG:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
+        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
+                            "Expected:\n"
+                                << dump(expected_messages) << "but found:\n"
+                                << dump(parser.parsed_messages()));
+    }
+    {
+        string str1(
+            "MSG:[12:03:55 21.8.2013] --shutdown=yes :mapLOG:[12:34:08 21.8.2013] --restart :mapERR:[12:47:22 "
+            "21.8.2013] --alter add variable SMSNODE 0 /  :mapWAR:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 "
+            "/  :mapDBG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :mapOTH:[15:36:14 "
+            "21.8.2013] --shutdown=yes :mapOTH:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
+        DefsHistoryParser parser;
+        parser.parse(str1);
+
+        std::vector<std::string> expected_messages;
+        expected_messages.emplace_back("MSG:[12:03:55 21.8.2013] --shutdown=yes :map");
+        expected_messages.emplace_back("LOG:[12:34:08 21.8.2013] --restart :map");
+        expected_messages.emplace_back("ERR:[12:47:22 21.8.2013] --alter add variable SMSNODE 0 /  :map");
+        expected_messages.emplace_back("WAR:[13:38:45 21.8.2013] --alter add variable SMSTRYNO 0 /  :map");
+        expected_messages.emplace_back(
+            "DBG:[13:44:09 21.8.2013] --alter add variable SMSHOME /vol/emos/output /  :map");
+        expected_messages.emplace_back("OTH:[15:36:14 21.8.2013] --shutdown=yes :map");
+        expected_messages.emplace_back("OTH:[16:04:26 21.8.2013] --alter add variable SMSNODE 0 /  :map");
+        BOOST_CHECK_MESSAGE(parser.parsed_messages() == expected_messages,
+                            "Expected:\n"
+                                << dump(expected_messages) << "but found:\n"
+                                << dump(parser.parsed_messages()));
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestInLimit.cpp 5.13.0-1/libs/node/test/TestInLimit.cpp
--- 5.12.4-1/libs/node/test/TestInLimit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestInLimit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,125 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestSerialisation.hpp"
+#include "ecflow/node/InLimit.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_InLimit)
+
+BOOST_AUTO_TEST_CASE(test_inlimit_basics) {
+    cout << "ANode:: ...test_inlimit_basics \n";
+    {
+        InLimit empty;
+        InLimit empty2;
+        BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
+
+        InLimit l1("name", "path");
+        InLimit l2("name", "path");
+        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
+
+        InLimit a("name", "path", 10);
+        InLimit b("name", "path");
+        BOOST_CHECK_MESSAGE(!(a == b), "Equality passed when should fail");
+    }
+    {
+        InLimit inlim("fred", "/path/to/node", 1, true);
+        {
+            InLimit testCopy = inlim;
+            BOOST_CHECK_MESSAGE(testCopy == inlim, "Copy constructor failed");
+        }
+        {
+            InLimit testCopy;
+            testCopy = inlim;
+            BOOST_CHECK_MESSAGE(testCopy == inlim, "Assignment failed");
+        }
+    }
+    {
+        InLimit inlim("fred", "/path/to/node", 1, false);
+        {
+            InLimit testCopy = inlim;
+            BOOST_CHECK_MESSAGE(testCopy == inlim, "Copy constructor failed");
+        }
+        {
+            InLimit testCopy;
+            testCopy = inlim;
+            BOOST_CHECK_MESSAGE(testCopy == inlim, "Assignment failed");
+        }
+    }
+    {
+        InLimit inlim("fred", "/path/to/node", 1, false, true);
+        {
+            InLimit testCopy = inlim;
+            BOOST_CHECK_MESSAGE(testCopy == inlim, "Copy constructor failed");
+        }
+        {
+            InLimit testCopy;
+            testCopy = inlim;
+            BOOST_CHECK_MESSAGE(testCopy == inlim, "Assignment failed");
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_inlimit_duplicates) {
+    cout << "ANode:: ...test_inlimit_duplicates \n";
+
+    InLimit inlim("fred", "/path/to/node", 1, true);
+
+    task_ptr task = Task::create("task");
+    task->addInLimit(inlim);
+
+    // duplicate should throw
+    BOOST_REQUIRE_THROW(task->addInLimit(inlim), std::runtime_error);
+
+    // still a duplicate
+    InLimit inlim2("fred", "/path/to/node");
+    BOOST_REQUIRE_THROW(task->addInLimit(inlim2), std::runtime_error);
+}
+
+// Globals used throughout the test
+static std::string fileName = "test_InLimit_serialisation.txt";
+BOOST_AUTO_TEST_CASE(test_InLimit_serialisation) {
+    cout << "ANode:: ...test_InLimit_serialisation\n";
+    {
+        // save and restore the default constructor
+        doSaveAndRestore<InLimit>(fileName);
+
+        InLimit saved("limitName", "/path/to/some/node", 20, true);
+        save(fileName, saved);
+
+        InLimit restored;
+        restore(fileName, restored);
+        BOOST_CHECK_MESSAGE(saved == restored, " save and restored don't match");
+        std::remove(fileName.c_str());
+    }
+    {
+        InLimit saved("limitName", "/path/to/some/node", 20, false, true);
+        save(fileName, saved);
+
+        InLimit restored;
+        restore(fileName, restored);
+        BOOST_CHECK_MESSAGE(saved == restored, " save and restored don't match");
+        std::remove(fileName.c_str());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestJobCreator.cpp 5.13.0-1/libs/node/test/TestJobCreator.cpp
--- 5.12.4-1/libs/node/test/TestJobCreator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestJobCreator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,116 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_JobCreator)
+
+BOOST_AUTO_TEST_CASE(test_job_creator) {
+    cout << "ANode:: ...test_job_creator\n";
+
+    // SET SMSHOME
+    std::string ecf_home = File::test_data("libs/node/test/data/SMSHOME", "libs/node");
+
+    // Create the defs file corresponding to the text below
+    // # Test the sms file can be found via ECF_SCRIPT
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // #
+    // suite suite
+    //	edit SLEEPTIME 10
+    //	edit ECF_INCLUDE $ECF_HOME/includes
+    //	family family
+    //   	task t1
+    //   	task t2
+    //    	task t3
+    //  	endfamily
+    // endsuite
+    // #
+    // # This test suite should force a backwards search since the sms files
+    // # are located in SMSHOME
+    // suite suite1
+    //    family family
+    //   		task suite1_task1
+    //   		task suite1_task2
+    //    	    task suite1_task3
+    //    endfamily
+    // endsuite
+    // Create a defs file, where the task name mirrors the sms files in the given directory
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("suite");
+        family_ptr fam  = Family::create("family");
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/../includes"));
+        suite->addVariable(Variable("SLEEPTIME", "1"));
+        suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
+        fam->addTask(Task::create("t1"));
+        fam->addTask(Task::create("t2"));
+        fam->addTask(Task::create("t3"));
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+    {
+        suite_ptr suite1(new Suite("suite1"));
+        family_ptr fam(new Family("family"));
+        fam->addTask(Task::create("suite1_task1"));
+        fam->addTask(Task::create("suite1_task2"));
+        fam->addTask(Task::create("suite1_task3"));
+        suite1->addFamily(fam);
+        theDefs.addSuite(suite1);
+    }
+    // 	cerr << theDefs << "\n";
+
+    // get all the task, assume non hierarchical families
+    std::vector<Task*> theTasks;
+    theDefs.getAllTasks(theTasks);
+    BOOST_REQUIRE_MESSAGE(theTasks.size() == 6, "Expected 6 tasks but found, " << theTasks.size());
+
+    // Override ECF_HOME.   ECF_HOME is need to locate to the .ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    // Test Job creator. The job creation should succeed 3 times only, since
+    // the sms file suite1_task1, suite1_task2,suite1_task3 are empty.
+    JobsParam jobsParam(true /*create jobs*/); // spawn_jobs = false
+    Jobs jobs(&theDefs);
+    jobs.generate(jobsParam);
+    BOOST_REQUIRE_MESSAGE(jobsParam.submitted().size() == 3,
+                          "expected 3 jobs but found " << jobsParam.submitted().size() << "\n"
+                                                       << jobsParam.errorMsg());
+
+    // Expect error message complaining about sms file suite1_task1, suite1_task2,suite1_task3 being empty
+    BOOST_REQUIRE_MESSAGE(!jobsParam.errorMsg().empty(), "expected error message about empty ecf files");
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestJobProfiler.cpp 5.13.0-1/libs/node/test/TestJobProfiler.cpp
--- 5.12.4-1/libs/node/test/TestJobProfiler.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestJobProfiler.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_JobProfiler)
+
+BOOST_AUTO_TEST_CASE(test_job_profiler) {
+    cout << "ANode:: ...test_job_profiler\n";
+
+    // delete the log file if it exists.
+    std::string log_path = File::test_data("libs/node/test/logfile.txt", "libs/node");
+    fs::remove(log_path);
+    BOOST_CHECK_MESSAGE(!fs::exists(log_path), "log file " << log_path << " not deleted ");
+
+    // Create a new log, file, we will look in here to see if job profiling is working
+    // Hence this test relies on output to be flushed
+    TestLog test_log(log_path); // will create log file, and destroy log and remove file at end of scope
+
+    // SET ECF_HOME, re-use exist test of directory and scripts
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), File::test_data("libs/node/test/data/includes", "libs/node")));
+        suite->addVariable(Variable("ECF_HOME", File::test_data("libs/node/test/data/SMSHOME", "libs/node")));
+        suite->addVariable(Variable("SLEEPTIME", "10"));
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t1");
+    }
+    // cerr << theDefs << "\n";
+
+    // begin , will cause creation of generated variables. The generated variables
+    // are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    // By setting submitJobsInterval to -1, we enable the jobs profiling testing
+    // createJobs enables us to ensure job size is profiled
+    // spawn jobs set to false, do not create a separate process to spawn jobs
+    JobsParam jobParam(-1 /*submitJobsInterval*/, true /*createJobs*/, false /* spawn jobs */);
+    Jobs job(&theDefs);
+    bool ok = job.generate(jobParam);
+    BOOST_CHECK_MESSAGE(ok, "generate failed: " << jobParam.getErrorMsg());
+
+    // Check the log file, has the profiling
+    Log::instance()->flush_only();
+    std::string log_file_contents;
+    BOOST_CHECK_MESSAGE(File::open(log_path, log_file_contents),
+                        "Could not open log file at " << log_path << " (" << strerror(errno) << ")");
+    BOOST_CHECK_MESSAGE(!log_file_contents.empty(), "log file is is empty ?");
+    BOOST_CHECK_MESSAGE(log_file_contents.find("Exceeds ECF_TASK_THRESHOLD") != std::string::npos,
+                        "Exceeds ECF_TASK_THRESHOLD  not in profile");
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestLimit.cpp 5.13.0-1/libs/node/test/TestLimit.cpp
--- 5.12.4-1/libs/node/test/TestLimit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestLimit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,216 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestSerialisation.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/node/Limit.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Limit)
+
+BOOST_AUTO_TEST_CASE(test_limit_basics) {
+    cout << "ANode:: ...test_limit_basics \n";
+
+    {
+        Limit empty;
+        Limit empty2;
+        BOOST_CHECK_MESSAGE(empty == empty2, "Equality failed");
+
+        Limit l1("name", 2);
+        Limit l2("name", 2);
+        BOOST_CHECK_MESSAGE(l1 == l2, "Equality failed");
+
+        Limit l3("name", 2);
+        Limit l4("name", 4);
+        BOOST_CHECK_MESSAGE(!(l3 == l4), "Equality failed");
+    }
+
+    std::set<std::string> expected_empty_paths;
+    std::set<std::string> expected_paths;
+
+    Limit l1("name", 100);
+    for (int i = 1; i < 10; i++) {
+        std::string path = ecf::convert_to<std::string>(i);
+        expected_paths.insert(path);
+        l1.increment(1, path);
+        BOOST_CHECK_MESSAGE(l1.paths() == expected_paths, "Expected paths not the same at " << i);
+    }
+
+    for (int i = 9; i >= 1; i--) {
+        std::string path = ecf::convert_to<std::string>(i);
+        l1.decrement(1, path);
+        auto iter = expected_paths.find(path);
+        expected_paths.erase(iter);
+
+        if (l1.paths() != expected_paths) {
+            std::cout << " Expected:";
+            std::copy(expected_paths.begin(), expected_paths.end(), std::ostream_iterator<std::string>(std::cout, " "));
+            std::cout << "    Found:";
+            std::copy(l1.paths().begin(), l1.paths().end(), std::ostream_iterator<std::string>(std::cout, " "));
+        }
+        BOOST_CHECK_MESSAGE(l1.paths() == expected_paths, "Expected paths not the same at " << i);
+    }
+
+    expected_paths.insert("/a/b/c");
+    l1.increment(1, "/a/b/c");
+    BOOST_CHECK_MESSAGE(l1.paths() == expected_paths, "Expected paths not the same");
+
+    l1.decrement(1, "/a/b/c");
+    BOOST_CHECK_MESSAGE(l1.paths() == expected_empty_paths, "Expected paths not the same");
+    BOOST_CHECK_MESSAGE(l1.value() == 0, "Expected value to be 0");
+
+    l1.increment(1, "/a/b/c");
+    l1.increment(1, "/a/b/d");
+    BOOST_CHECK_MESSAGE(l1.paths().size() == 2, "Expected 2 paths but found " << l1.paths().size());
+    BOOST_CHECK_MESSAGE(l1.value() == 2, "Expected value to be 2 but found " << l1.value());
+    l1.reset();
+    BOOST_CHECK_MESSAGE(l1.value() == 0, "Expected value to be 0 after reset, but found " << l1.value());
+    BOOST_CHECK_MESSAGE(l1.paths().size() == 0, "Expected 0 paths after reset but found " << l1.paths().size());
+
+    l1.setValue(10);
+    BOOST_CHECK_MESSAGE(l1.value() == 10, "Expected value to be 10, but found " << l1.value());
+    BOOST_CHECK_MESSAGE(l1.paths().size() == 0, "Expected 0 paths after reset but found " << l1.paths().size());
+}
+
+BOOST_AUTO_TEST_CASE(test_limit_increment) {
+    cout << "ANode:: ...test_limit_increment\n";
+
+    Limit limit("name", 10);    // Limit of 10
+    limit.increment(1, "path"); // consume 1 token
+
+    BOOST_CHECK_MESSAGE(limit.value() == 1,
+                        "Expected increment to consume 1 token but it has consumed " << limit.value());
+    BOOST_CHECK_MESSAGE(limit.paths().size() == 1, "Expected 1 task path but found " << limit.paths().size());
+
+    limit.increment(1, "path"); // Increment with same path, should *NOT* consume a token
+
+    BOOST_CHECK_MESSAGE(limit.value() == 1, "Expected 1 token but it has consumed " << limit.value());
+    BOOST_CHECK_MESSAGE(limit.paths().size() == 1, "Expected 1 task path but found " << limit.paths().size());
+}
+
+BOOST_AUTO_TEST_CASE(test_limit_increment_2) {
+    cout << "ANode:: ...test_limit_increment_2\n";
+
+    Limit limit("name", 10); // Limit of 10
+    for (int i = 0; i < 20; i++) {
+        // increment should keep increasing limit value, *EVEN* if over the limit. See ECFLOW-324
+        std::string path = ecf::convert_to<std::string>(i);
+        limit.increment(1, path);
+        BOOST_CHECK_MESSAGE(limit.value() == i + 1,
+                            "Expected limit value of " << i + 1 << " but found " << limit.value());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_limit_decrement) {
+    cout << "ANode:: ...test_limit_decrement\n";
+
+    Ecf::set_server(true); // needed to test state_change_numbers
+
+    Limit limit("name", 10); // Limit of 10
+    unsigned int expected_state_change_no = limit.state_change_no();
+
+    limit.increment(1, "path");
+    expected_state_change_no++; // consume 1 token, should increment state change no
+    BOOST_CHECK_MESSAGE(limit.value() == 1, "Expected limit of value 1  but found " << limit.value());
+    BOOST_CHECK_MESSAGE(limit.paths().size() == 1, "Expected 1 task path but found " << limit.paths().size());
+    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
+                        "Expected increment to increase state change no, expected "
+                            << expected_state_change_no << " but found " << limit.state_change_no());
+
+    // Since 'path_x' is NOT in the list of paths stored by the limit, there should be NO change to state_change_no
+    limit.decrement(1, "path_x");
+    BOOST_CHECK_MESSAGE(
+        limit.value() == 1,
+        " decrement of path that does not exist, should not affect the Limit: Expected limit of value 1  but found "
+            << limit.value());
+    BOOST_CHECK_MESSAGE(
+        limit.paths().size() == 1,
+        " decrement of path that does not exist, should not affect the Limit : Expected 1 task path but found "
+            << limit.paths().size());
+    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
+                        "Expected no change in state change no, expected " << expected_state_change_no << " but found "
+                                                                           << limit.state_change_no());
+
+    // Multiple decrements should leave Limit of value = 0, and not a negative number
+    limit.decrement(1, "path");
+    expected_state_change_no++;
+    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
+                        "Expected decrement to increase state change no, expected "
+                            << expected_state_change_no << " but found " << limit.state_change_no());
+
+    // Since we have removed 'path' from the limit expect no further state changes
+    limit.decrement(1, "path");
+    limit.decrement(1, "path");
+    limit.decrement(1, "path");
+    BOOST_CHECK_MESSAGE(limit.value() == 0, "Expected limit of value 0  but found " << limit.value());
+    BOOST_CHECK_MESSAGE(limit.paths().size() == 0, "Expected no task paths but found " << limit.paths().size());
+    BOOST_CHECK_MESSAGE(limit.state_change_no() == expected_state_change_no,
+                        "Expected no change to state change no, expected " << expected_state_change_no << " but found "
+                                                                           << limit.state_change_no());
+
+    Ecf::set_server(false); // needed to test state_change_numbers
+    // reset, to avoid effecting downstream tests
+    Ecf::set_state_change_no(0);
+    Ecf::set_modify_change_no(0);
+}
+
+BOOST_AUTO_TEST_CASE(test_limit_set_value) {
+    cout << "ANode:: ...test_limit_set_value\n";
+
+    Limit limit("name", 10);     // Limit of 10
+    limit.increment(1, "path");  // consume 1 token
+    limit.increment(1, "path2"); // consume 1 token
+
+    BOOST_CHECK_MESSAGE(limit.value() == 2,
+                        "Expected increment to consume 2 token but it has consumed " << limit.value());
+    BOOST_CHECK_MESSAGE(limit.paths().size() == 2, "Expected 2 task paths but found " << limit.paths().size());
+
+    limit.setValue(4);
+    BOOST_CHECK_MESSAGE(limit.value() == 4, "Expected setValue(4) but value found is: " << limit.value());
+    BOOST_CHECK_MESSAGE(limit.paths().size() == 2, "Expected 2 task paths but found " << limit.paths().size());
+
+    limit.setValue(0);
+    BOOST_CHECK_MESSAGE(limit.value() == 0, "Expected setValue(0) but found " << limit.value());
+    BOOST_CHECK_MESSAGE(limit.paths().empty(),
+                        "Setting value to zero should clear the paths, but found " << limit.paths().size());
+}
+
+// Globals used throughout the test
+static std::string fileName = "testLimit.txt";
+BOOST_AUTO_TEST_CASE(test_LimitDefaultConstructor_serialisation) {
+    cout << "ANode:: ...test_LimitDefaultConstructor_serialisation \n";
+
+    doSaveAndRestore<Limit>(fileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_Limit_serialisation) {
+    cout << "ANode:: ...test_Limit_serialisation\n";
+    Limit saved1("limitName", 100);
+    doSaveAndRestore(fileName, saved1);
+
+    std::set<std::string> paths;
+    paths.insert("path1");
+    paths.insert("path2");
+    Limit saved2("limitName", 100, 10, paths);
+    doSaveAndRestore(fileName, saved2);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestMigration.cpp 5.13.0-1/libs/node/test/TestMigration.cpp
--- 5.12.4-1/libs/node/test/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestMigration.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "TestSerialisation.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+// #define UPDATE_TESTS 1
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Migration)
+
+BOOST_AUTO_TEST_CASE(test_default_constructor_persistence) {
+    cout << "ANode:: ...test_default_constructor_persistence\n";
+
+    std::string file_name = File::test_data("libs/node/test/data/migration/", "libs/node");
+
+    Defs defs;
+    Suite suite;
+    Family family;
+    Task task;
+
+    // Can't persist server variable are dependent on HOST.i.e ECF_LISTS,ECF_CHECK,etc
+    // Hence is not cross-platform
+    doSave(file_name + "Defs.def", defs);
+
+#ifdef UPDATE_TESTS
+    doSave(file_name + "Suite.def", suite);
+    doSave(file_name + "Family.def", family);
+    doSave(file_name + "Task.def", task);
+    doSave(file_name + "Limit.def", Limit());
+#endif
+
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    do_restore<Defs>(file_name + "Defs.def", defs);
+    do_restore<Suite>(file_name + "Suite.def", suite);
+    do_restore<Family>(file_name + "Family.def", family);
+    do_restore<Task>(file_name + "Task.def", task);
+    do_restore<Limit>(file_name + "Limit.def", Limit());
+
+    fs::remove(file_name + "Defs.def"); // Remove the file. Comment out for debugging
+}
+
+BOOST_AUTO_TEST_CASE(test_compare_cereal_and_defs_checkpt_file) {
+    cout << "ANode:: ...test_compare_cereal_and_defs_checkpt_file\n";
+
+    std::string file_name = File::test_data("libs/node/test/data/migration/", "libs/node");
+
+    // Cannot save these tests since server variable use HOST which is different for each platform
+    MyDefsFixture fixture;
+    doSave(file_name + "cereal.checkpt", fixture.fixtureDefsFile());
+    fixture.fixtureDefsFile().save_as_checkpt(file_name + "defs.checkpt");
+
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    do_restore<Defs>(file_name + "cereal.checkpt", fixture.fixtureDefsFile());
+
+    Defs defs;
+    defs.restore(file_name + "defs.checkpt");
+    BOOST_CHECK_MESSAGE(defs == fixture.fixtureDefsFile(), " ");
+
+    fs::remove(file_name + "defs.checkpt");   // Remove the file. Comment out for debugging
+    fs::remove(file_name + "cereal.checkpt"); // Remove the file. Comment out for debugging
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestMissNextTimeSlot.cpp 5.13.0-1/libs/node/test/TestMissNextTimeSlot.cpp
--- 5.12.4-1/libs/node/test/TestMissNextTimeSlot.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestMissNextTimeSlot.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,121 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_MissNextTimeSlot)
+
+BOOST_AUTO_TEST_CASE(test_miss_next_time_slot) {
+    cout << "ANode:: ...test_miss_next_time_slot\n";
+
+    // Start TIME at 9:30
+    // This test is custom. When the user interactively forces a node to the complete state,
+    // But where the user set of time slots. In this case the node should complete and then
+    // requee and miss the next time. If this is repeated, eventually we should reach the
+    // end of the time slot. In which case the node should *not* re-queue and stay complete
+    //
+    // When the node is then re-queued check that the time has been correctly reset.
+
+    //   suite s1
+    //       task t1
+    //          time 10:00
+    //          time 11:00
+    //          time 12:00
+    //          time 13:00
+    //   endsuite
+    Defs the_defs;
+    suite_ptr suite = the_defs.add_suite("s1");
+    task_ptr t1     = suite->add_task("t1");
+    t1->addTime(TimeAttr(10, 0));
+    t1->addTime(TimeAttr(11, 0));
+    t1->addTime(TimeAttr(12, 0));
+    t1->addTime(TimeAttr(13, 0));
+    ClockAttr clockAttr(15, 12, 2010, false);
+    clockAttr.set_gain(9 /*hour*/, 30 /*minutes*/); // *start* at 9:30
+    suite->addClock(clockAttr);
+
+    suite->begin();
+
+    // get all the time attributes
+    const TimeSeries& ts_10 = t1->timeVec()[0].time_series();
+    const TimeSeries& ts_11 = t1->timeVec()[1].time_series();
+    const TimeSeries& ts_12 = t1->timeVec()[2].time_series();
+    const TimeSeries& ts_13 = t1->timeVec()[3].time_series();
+    BOOST_CHECK_MESSAGE(ts_10.is_valid(), "Expected time 10 to be valid since we started at 9:30 ");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
+
+    const TimeSlot& time_10 = t1->timeVec()[0].time_series().get_next_time_slot();
+    const TimeSlot& time_11 = t1->timeVec()[1].time_series().get_next_time_slot();
+    const TimeSlot& time_12 = t1->timeVec()[2].time_series().get_next_time_slot();
+    const TimeSlot& time_13 = t1->timeVec()[3].time_series().get_next_time_slot();
+    BOOST_CHECK_MESSAGE(time_10 == TimeSlot(10, 0),
+                        "Expected next time slot of 10:00 but found " << time_10.toString());
+    BOOST_CHECK_MESSAGE(time_11 == TimeSlot(11, 0),
+                        "Expected next time slot of 11:00 but found " << time_11.toString());
+    BOOST_CHECK_MESSAGE(time_12 == TimeSlot(12, 0),
+                        "Expected next time slot of 12:00 but found " << time_12.toString());
+    BOOST_CHECK_MESSAGE(time_13 == TimeSlot(13, 0),
+                        "Expected next time slot of 13:00 but found " << time_13.toString());
+
+    // before test flags should be clear
+    BOOST_CHECK_MESSAGE(!t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be clear,before test");
+
+    t1->miss_next_time_slot();
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set,");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
+
+    // Calling miss_next_time_slot again, should have *NO* effect, since its only takes affect when
+    // NO_REQUE_IF_SINGLE_TIME_DEP is clear
+    t1->miss_next_time_slot();
+    BOOST_CHECK_MESSAGE(t1->get_flag().is_set(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP),
+                        "Expected ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP to be set,");
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
+    BOOST_CHECK_MESSAGE(ts_11.is_valid(), "Expected time 11 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
+
+    // Clear the flag and call miss_next_time_slot, this time an additional time slot should have expired
+    t1->flag().clear(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
+    t1->miss_next_time_slot();
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired");
+    BOOST_CHECK_MESSAGE(ts_12.is_valid(), "Expected time 12 to be valid since we started at 9:30");
+    BOOST_CHECK_MESSAGE(ts_13.is_valid(), "Expected time 13 to be valid since we started at 9:30");
+
+    // call twice more, to expire all time slots
+    t1->flag().clear(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
+    t1->miss_next_time_slot();
+    t1->flag().clear(ecf::Flag::NO_REQUE_IF_SINGLE_TIME_DEP);
+    t1->miss_next_time_slot();
+    BOOST_CHECK_MESSAGE(!ts_10.is_valid(), "Expected time 10 to be expired");
+    BOOST_CHECK_MESSAGE(!ts_11.is_valid(), "Expected time 11 to be expired");
+    BOOST_CHECK_MESSAGE(!ts_12.is_valid(), "Expected time 12 to be expired");
+    BOOST_CHECK_MESSAGE(!ts_13.is_valid(), "Expected time 13 to be expired");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestMovePeer.cpp 5.13.0-1/libs/node/test/TestMovePeer.cpp
--- 5.12.4-1/libs/node/test/TestMovePeer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestMovePeer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,104 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_MovePeer)
+
+BOOST_AUTO_TEST_CASE(test_move_peer) {
+    cout << "ANode:: ...test_move_peer\n";
+    Defs defs;
+    {
+        std::vector<string> vec{"3", "2", "1"};
+        for (const auto& str0 : vec) {
+            suite_ptr s = defs.add_suite("s" + str0);
+            for (const auto& str : vec) {
+                family_ptr f1 = s->add_family("f" + str);
+                for (const auto& str2 : vec) {
+                    f1->add_task("t" + str2);
+                }
+            }
+        }
+    }
+    Defs expectedDefs;
+    {
+        std::vector<string> vec{"1", "2", "3"};
+        for (const auto& str0 : vec) {
+            suite_ptr s = expectedDefs.add_suite("s" + str0);
+            for (const auto& str : vec) {
+                family_ptr f1 = s->add_family("f" + str);
+                for (const auto& str2 : vec) {
+                    f1->add_task("t" + str2);
+                }
+            }
+        }
+    }
+    //   std::cout << defs << "\n";
+
+    suite_ptr s3 = defs.findSuite("s3");
+    suite_ptr s2 = defs.findSuite("s2");
+    suite_ptr s1 = defs.findSuite("s1");
+    // order     is s3,s2,s1
+    defs.move_peer(s1.get(), s3.get()); // order now is s1,s3,s2
+    defs.move_peer(s2.get(), s3.get()); // order now is s1,s2,s3
+
+    //   std::cout << defs << "\n";
+
+    node_ptr s1_f1 = defs.findAbsNode("/s1/f1");
+    node_ptr s1_f2 = defs.findAbsNode("/s1/f2");
+    node_ptr s1_f3 = defs.findAbsNode("/s1/f3");
+
+    // order is f3,f2,f1
+    s1->move_peer(s1_f1.get(), s1_f3.get()); // order is f1,f3,f2
+    s1->move_peer(s1_f2.get(), s1_f3.get()); // order is f1,f3,f2
+
+    node_ptr s2_f1 = defs.findAbsNode("/s2/f1");
+    node_ptr s2_f2 = defs.findAbsNode("/s2/f2");
+    node_ptr s2_f3 = defs.findAbsNode("/s2/f3");
+    // order is f3,f2,f1
+    s2->move_peer(s2_f1.get(), s2_f3.get()); // order is f1,f3,f2
+    s2->move_peer(s2_f2.get(), s2_f3.get()); // order is f1,f3,f2
+
+    node_ptr s3_f1 = defs.findAbsNode("/s3/f1");
+    node_ptr s3_f2 = defs.findAbsNode("/s3/f2");
+    node_ptr s3_f3 = defs.findAbsNode("/s3/f3");
+    // order is f3,f2,f1
+    s3->move_peer(s3_f1.get(), s3_f3.get()); // order is f1,f3,f2
+    s3->move_peer(s3_f2.get(), s3_f3.get()); // order is f1,f3,f2
+
+    for (auto suite : defs.suiteVec()) {
+        for (auto family : suite->familyVec()) {
+
+            node_ptr t1 = defs.findAbsNode(family->absNodePath() + "/t1");
+            node_ptr t2 = defs.findAbsNode(family->absNodePath() + "/t2");
+            node_ptr t3 = defs.findAbsNode(family->absNodePath() + "/t3");
+
+            family->move_peer(t1.get(), t3.get());
+            family->move_peer(t2.get(), t3.get());
+        }
+    }
+    //   std::cout << defs << "\n";
+
+    BOOST_CHECK_MESSAGE(defs == expectedDefs, "Defs are not the same");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestNodeBeginRequeue.cpp 5.13.0-1/libs/node/test/TestNodeBeginRequeue.cpp
--- 5.12.4-1/libs/node/test/TestNodeBeginRequeue.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestNodeBeginRequeue.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,80 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_NodeBeginRequeue)
+
+BOOST_AUTO_TEST_CASE(test_node_begin_requeue_hybrid) {
+    cout << "ANode:: ...test_node_begin_reque_hybrid\n";
+
+    // Create a suite with a *HYBRID* clock, and tasks with day,date and cron time attributes
+    defs_ptr the_defs = Defs::create();
+    suite_ptr s1      = the_defs->add_suite("s1");
+    s1->addClock(ClockAttr(true));
+    family_ptr f1 = s1->add_family("f1");
+
+    CronAttr cron;
+    std::vector<int> week_days;
+    week_days.push_back(0);
+    week_days.push_back(1);
+    cron.addWeekDays(week_days);
+    cron.add_time_series(10, 10, true);
+
+    // For task t1 which has day attribute. For this test to succeed the day must not match today day.
+    // So that under the hybrid clock, its is set to complete
+    boost::gregorian::date todays_date = Calendar::second_clock_time().date();
+    int todays_day_as_number           = todays_date.day_of_week().as_number();
+    int tommorrow                      = todays_day_as_number + 1;
+    if (tommorrow > 6)
+        tommorrow = 0;
+
+    task_ptr t1 = f1->add_task("t1");
+    t1->addDay(DayAttr(DayAttr::Day_t(tommorrow)));
+    task_ptr t2 = f1->add_task("t2");
+    t2->addDate(DateAttr(0, 0, 2014));
+    task_ptr t3 = f1->add_task("t3");
+    t3->addCron(cron);
+
+    // begin the suite, Under hybrid clock, nodes with day,date and cron attributes should be marked as complete
+    the_defs->beginAll();
+    BOOST_CHECK_MESSAGE(t1->state() == NState::COMPLETE, "Expected node to be complete");
+    BOOST_CHECK_MESSAGE(t2->state() == NState::COMPLETE, "Expected node to be complete");
+    BOOST_CHECK_MESSAGE(t3->state() == NState::COMPLETE, "Expected node to be complete");
+
+    // Change the node state, so that we can test re-queue
+    t1->set_state(NState::QUEUED);
+    t2->set_state(NState::QUEUED);
+    t3->set_state(NState::QUEUED);
+    BOOST_CHECK_MESSAGE(t1->state() == NState::QUEUED, "Expected node to be QUEUED");
+    BOOST_CHECK_MESSAGE(t2->state() == NState::QUEUED, "Expected node to be QUEUED");
+    BOOST_CHECK_MESSAGE(t3->state() == NState::QUEUED, "Expected node to be QUEUED");
+
+    // Now re-queue all and make sure re-queue also Under hybrid clock, nodes with day,date and cron
+    // attributes should be marked as complete
+    the_defs->requeue();
+    BOOST_CHECK_MESSAGE(t1->state() == NState::COMPLETE, "Expected node to be complete");
+    BOOST_CHECK_MESSAGE(t2->state() == NState::COMPLETE, "Expected node to be complete");
+    BOOST_CHECK_MESSAGE(t3->state() == NState::COMPLETE, "Expected node to be complete");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestNodeState.cpp 5.13.0-1/libs/node/test/TestNodeState.cpp
--- 5.12.4-1/libs/node/test/TestNodeState.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestNodeState.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,139 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_NodeState)
+
+BOOST_AUTO_TEST_CASE(test_state_hierarchy) {
+    cout << "ANode:: ...test_state_hierarchy\n";
+
+    // Create a defs file corresponding to:
+    // suite s1
+    // family f1
+    //    task t1
+    //    task t2
+    //    task t3
+    //    task t4
+    //    task t5
+    //  endfamily
+    // endsuite
+    Defs theDefs;
+    suite_ptr s1  = theDefs.add_suite("suite1");
+    family_ptr f1 = s1->add_family("family");
+    task_ptr t1   = f1->add_task("t1");
+    task_ptr t2   = f1->add_task("t2");
+    task_ptr t3   = f1->add_task("t3");
+    task_ptr t4   = f1->add_task("t4");
+
+    NState::State result = s1->computedState(Node::IMMEDIATE_CHILDREN);
+    BOOST_REQUIRE_MESSAGE(result == NState::UNKNOWN,
+                          "Expected NState::UNKNOWN for suite but found " << NState::toString(result));
+
+    result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+    BOOST_REQUIRE_MESSAGE(result == NState::UNKNOWN,
+                          "Expected NState::UNKNOWN for family but found " << NState::toString(result));
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::QUEUED,
+                              "Expected NState::QUEUED for family but found " << NState::toString(result));
+    }
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        t1->set_state(NState::ABORTED);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::ABORTED,
+                              "Expected NState::ABORTED for family but found " << NState::toString(result));
+    }
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        t2->set_state(NState::SUBMITTED);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::SUBMITTED,
+                              "Expected NState::SUBMITTED for family but found " << NState::toString(result));
+    }
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        t3->set_state(NState::ACTIVE);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::ACTIVE,
+                              "Expected NState::ACTIVE for family but found " << NState::toString(result));
+    }
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        t3->set_state(NState::ACTIVE);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::ACTIVE,
+                              "Expected NState::ACTIVE for family but found " << NState::toString(result));
+    }
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        t1->set_state(NState::COMPLETE);
+        t2->set_state(NState::COMPLETE);
+        t3->set_state(NState::COMPLETE);
+        t4->set_state(NState::COMPLETE);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::COMPLETE,
+                              "Expected NState::COMPLETE for family but found " << NState::toString(result));
+    }
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        t1->set_state(NState::COMPLETE);
+        t2->set_state(NState::ACTIVE);
+        t3->set_state(NState::ACTIVE);
+        t4->set_state(NState::QUEUED);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::ACTIVE,
+                              "Expected NState::ACTIVE for family but found " << NState::toString(result));
+    }
+
+    {
+        f1->setStateOnlyHierarchically(NState::QUEUED);
+        t1->set_state(NState::COMPLETE);
+        t2->set_state(NState::ACTIVE);
+        t3->set_state(NState::ABORTED);
+        t4->set_state(NState::QUEUED);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::ABORTED,
+                              "Expected NState::ABORTED for family but found " << NState::toString(result));
+    }
+
+    { // ECFLOW-347
+        f1->setStateOnlyHierarchically(NState::UNKNOWN);
+        t1->set_state(NState::COMPLETE);
+        result = f1->computedState(Node::IMMEDIATE_CHILDREN);
+        BOOST_REQUIRE_MESSAGE(result == NState::COMPLETE,
+                              "Expected NState::COMPLETE for family but found " << NState::toString(result));
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestNode_main.cpp 5.13.0-1/libs/node/test/TestNode_main.cpp
--- 5.12.4-1/libs/node/test/TestNode_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestNode_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Node
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/node/test/TestOrder.cpp 5.13.0-1/libs/node/test/TestOrder.cpp
--- 5.12.4-1/libs/node/test/TestOrder.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestOrder.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,475 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Order)
+
+static void test_invariants(Defs& the_defs, int line) {
+    std::string errorMsg;
+    bool passed = the_defs.checkInvariants(errorMsg);
+    BOOST_REQUIRE_MESSAGE(passed, "Invariants failed " << errorMsg << " at line " << line);
+}
+
+BOOST_AUTO_TEST_CASE(test_order) {
+    cout << "ANode:: ...test_order\n";
+    std::vector<std::string> vec;
+    vec.reserve(5);
+    vec.emplace_back("a");
+    vec.emplace_back("A");
+    vec.emplace_back("b");
+    vec.emplace_back("B");
+    vec.emplace_back("c");
+    Defs theDefs;
+    {
+        for (size_t s = 0; s < vec.size(); s++) {
+            suite_ptr suite = theDefs.add_suite(vec[s]);
+            for (size_t f = 0; f < vec.size(); f++) {
+                family_ptr fam = suite->add_family(vec[f]);
+                for (const auto& t : vec) {
+                    fam->add_task(t);
+                }
+            }
+        }
+    }
+
+    std::vector<std::string> alpha;
+    alpha.emplace_back("a");
+    alpha.emplace_back("A");
+    alpha.emplace_back("b");
+    alpha.emplace_back("B");
+    alpha.emplace_back("c");
+
+    std::vector<std::string> order;
+    order.emplace_back("c");
+    order.emplace_back("B");
+    order.emplace_back("b");
+    order.emplace_back("A");
+    order.emplace_back("a");
+
+    // Test suite ordering ==========================================================================
+    // In init state all suite should be in alpha order
+    theDefs.order(theDefs.findAbsNode("/A").get(), NOrder::ALPHA);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
+                          "NOrder::ALPHA expected "
+                              << ecf::algorithm::join(alpha) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
+
+    // sort in reverse order
+    theDefs.order(theDefs.findAbsNode("/a").get(), NOrder::ORDER);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == order,
+                          "NOrder::ORDER expected "
+                              << ecf::algorithm::join(order) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
+
+    // Change back to alpha, then move suite 'c' to the top
+    theDefs.order(theDefs.findAbsNode("/A").get(), NOrder::ALPHA);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
+                          "NOrder::ALPHA expected "
+                              << ecf::algorithm::join(alpha) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
+    test_invariants(theDefs, __LINE__);
+
+    std::vector<std::string> expected;
+    expected.emplace_back("c");
+    expected.emplace_back("a");
+    expected.emplace_back("A");
+    expected.emplace_back("b");
+    expected.emplace_back("B");
+    theDefs.order(theDefs.findAbsNode("/c").get(), NOrder::TOP);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == expected,
+                          "NOrder::TOP expected "
+                              << ecf::algorithm::join(expected) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec())));
+
+    // move suite 'c' back to the bottom
+    theDefs.order(theDefs.findAbsNode("/c").get(), NOrder::BOTTOM);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
+                          "NOrder::BOTTOM order not as expected");
+
+    // move suite 'a' up one place. Should be no change, since its already at the top
+    theDefs.order(theDefs.findAbsNode("/a").get(), NOrder::UP);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
+                          "NOrder::UP order not as expected");
+
+    // move suite 'c' down one place. Should be no change, since its already at the bottom
+    theDefs.order(theDefs.findAbsNode("/c").get(), NOrder::DOWN);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == alpha,
+                          "NOrder::DOWN order not as expected");
+
+    // Move suite 'a' down by one place
+    expected.clear();
+    expected.emplace_back("A");
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("B");
+    expected.emplace_back("c");
+    theDefs.order(theDefs.findAbsNode("/a").get(), NOrder::DOWN);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == expected,
+                          "NOrder::DOWN order not as expected");
+
+    // Move suite 'b' up by one place
+    expected.clear();
+    expected.emplace_back("A");
+    expected.emplace_back("b");
+    expected.emplace_back("a");
+    expected.emplace_back("B");
+    expected.emplace_back("c");
+    theDefs.order(theDefs.findAbsNode("/b").get(), NOrder::UP);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(theDefs.suiteVec()) == expected,
+                          "NOrder::UP order not as expected");
+
+    // Test family ordering ==========================================================================
+    // In init state all suite should be in alpha order
+    suite_ptr suite = theDefs.findSuite("a");
+    BOOST_REQUIRE_MESSAGE(suite.get(), "Expected suite /a to exist ");
+
+    theDefs.order(theDefs.findAbsNode("/a/a").get(), NOrder::ALPHA);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
+                          "NOrder::ALPHA Init order "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // sort in reverse order
+    std::sort(expected.begin(), expected.end(), std::greater<std::string>());
+    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::ORDER);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == order,
+                          "NOrder::ORDER order "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(order));
+
+    // Change back to alpha, then move family 'e' to the top
+    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::ALPHA);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
+                          "NOrder::ALPHA expected "
+                              << ecf::algorithm::join(alpha) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec())));
+    test_invariants(theDefs, __LINE__);
+    expected.clear();
+    expected.emplace_back("c");
+    expected.emplace_back("a");
+    expected.emplace_back("A");
+    expected.emplace_back("b");
+    expected.emplace_back("B");
+    suite->order(theDefs.findAbsNode("/a/c").get(), NOrder::TOP);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == expected,
+                          "NOrder::TOP order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(expected));
+
+    //  move family 'c' back to the bottom
+    suite->order(theDefs.findAbsNode("/a/c").get(), NOrder::BOTTOM);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
+                          "NOrder::BOTTOM order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // move family 'a' up one place. Should be no change, since its already at the top
+    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::UP);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
+                          "NOrder::UP order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // move family 'c' down one place. Should be no change, since its already at the bottom
+    suite->order(theDefs.findAbsNode("/a/c").get(), NOrder::DOWN);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == alpha,
+                          "NOrder::DOWN order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // Move family 'a' down by one place
+    expected.clear();
+    expected.emplace_back("A");
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("B");
+    expected.emplace_back("c");
+    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::DOWN);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == expected,
+                          "NOrder::DOWN order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(expected));
+
+    // Move family 'b' up by one place
+    suite->order(theDefs.findAbsNode("/a/a").get(), NOrder::ALPHA); // reset
+    test_invariants(theDefs, __LINE__);
+    expected.clear();
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("A");
+    expected.emplace_back("B");
+    expected.emplace_back("c");
+    suite->order(theDefs.findAbsNode("/a/b").get(), NOrder::UP);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(suite->nodeVec()) == expected,
+                          "NOrder::UP order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(suite->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(expected));
+
+    // Test Task ordering ==========================================================================
+    // In init state all tasks should be in alpha order
+    Family* family = theDefs.findAbsNode("/a/a")->isFamily();
+    BOOST_REQUIRE_MESSAGE(family, "Expected family /a/a to exist ");
+
+    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::ALPHA);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
+                          "NOrder::ALPHA Init state "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // sort in reverse order
+    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::ORDER);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == order,
+                          "NOrder::ORDER  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(order));
+
+    // Change back to alpha, then move task 'c' to the top
+    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::ALPHA); // reset
+    expected.clear();
+    expected.emplace_back("c");
+    expected.emplace_back("a");
+    expected.emplace_back("A");
+    expected.emplace_back("b");
+    expected.emplace_back("B");
+    family->order(theDefs.findAbsNode("/a/a/c").get(), NOrder::TOP);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == expected,
+                          "NOrder::TOP order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(expected));
+
+    //  move task 'c' back to the bottom
+    family->order(theDefs.findAbsNode("/a/a/c").get(), NOrder::BOTTOM);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
+                          "NOrder::BOTTOM order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // move task 'a' up one place. Should be no change, since its already at the top
+    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::UP);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
+                          "NOrder::UP order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // move task 'e' down one place. Should be no change, since its already at the bottom
+    family->order(theDefs.findAbsNode("/a/a/c").get(), NOrder::DOWN);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == alpha,
+                          "NOrder::DOWN order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(alpha));
+
+    // Move task 'a' down by one place
+    expected.clear();
+    expected.emplace_back("A");
+    expected.emplace_back("a");
+    expected.emplace_back("b");
+    expected.emplace_back("B");
+    expected.emplace_back("c");
+    family->order(theDefs.findAbsNode("/a/a/a").get(), NOrder::DOWN);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == expected,
+                          "NOrder::DOWN order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(expected));
+
+    // Move task 'b' up by one place
+    family->order(theDefs.findAbsNode("/a/a/b").get(), NOrder::DOWN);
+    expected.clear();
+    expected.emplace_back("A");
+    expected.emplace_back("a");
+    expected.emplace_back("B");
+    expected.emplace_back("b");
+    expected.emplace_back("c");
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(family->nodeVec()) == expected,
+                          "NOrder::UP order  "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(family->nodeVec()))
+                              << " not as expected " << ecf::algorithm::join(expected));
+}
+
+BOOST_AUTO_TEST_CASE(test_alias_order) {
+    cout << "ANode:: ...test_alias_order\n";
+    task_ptr task;
+    Defs theDefs;
+    {
+        suite_ptr s = theDefs.add_suite("s");
+        task        = s->add_task("t");
+        task->add_alias_only(); // alias0
+        task->add_alias_only(); // alias1
+        task->add_alias_only(); // alias2
+        task->add_alias_only(); // alias3
+    }
+
+    // Test alias ordering ==========================================================================
+    // In init state all suite should be in alpha order
+    alias_ptr alias0 = task->find_alias("alias0");
+    BOOST_REQUIRE_MESSAGE(alias0, "expected to find alias0");
+
+    std::vector<std::string> expected;
+    expected.emplace_back("alias1");
+    expected.emplace_back("alias0");
+    expected.emplace_back("alias2");
+    expected.emplace_back("alias3");
+    task->order(alias0.get(), NOrder::DOWN);
+    test_invariants(theDefs, __LINE__);
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                          "NOrder::DOWN expected "
+                              << ecf::algorithm::join(expected) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+
+    task->order(alias0.get(), NOrder::ALPHA);
+    test_invariants(theDefs, __LINE__);
+    expected.clear();
+    expected.emplace_back("alias0");
+    expected.emplace_back("alias1");
+    expected.emplace_back("alias2");
+    expected.emplace_back("alias3");
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                          "NOrder::ALPHA expectex "
+                              << ecf::algorithm::join(expected) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+
+    task->order(task->find_alias("alias3").get(), NOrder::UP);
+    test_invariants(theDefs, __LINE__);
+    expected.clear();
+    expected.emplace_back("alias0");
+    expected.emplace_back("alias1");
+    expected.emplace_back("alias3");
+    expected.emplace_back("alias2");
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                          "NOrder::UP expected "
+                              << ecf::algorithm::join(expected) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+
+    // sort in reverse order
+    std::sort(expected.begin(), expected.end(), std::greater<std::string>());
+    task->order(alias0.get(), NOrder::ORDER);
+    test_invariants(theDefs, __LINE__);
+    expected.clear();
+    expected.emplace_back("alias3");
+    expected.emplace_back("alias2");
+    expected.emplace_back("alias1");
+    expected.emplace_back("alias0");
+    BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                          "NOrder::ORDER expected "
+                              << ecf::algorithm::join(expected) << " but found "
+                              << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+}
+
+BOOST_AUTO_TEST_CASE(test_order_by_runtime) {
+    cout << "ANode:: ...test_order_by_runtime\n";
+    Defs defs;
+    {
+        std::vector<string> vec{"3", "2", "1"};
+        for (const auto& str0 : vec) {
+            suite_ptr s = defs.add_suite("s" + str0);
+            for (const auto& str : vec) {
+                family_ptr f1 = s->add_family("f" + str);
+                for (const auto& str2 : vec) {
+                    f1->add_task("t" + str2);
+                }
+            }
+        }
+    }
+    Defs expectedDefs;
+    {
+        std::vector<string> vec{"1", "2", "3"};
+        for (const auto& str0 : vec) {
+            suite_ptr s = expectedDefs.add_suite("s" + str0);
+            for (const auto& str : vec) {
+                family_ptr f1 = s->add_family("f" + str);
+                for (const auto& str2 : vec) {
+                    f1->add_task("t" + str2);
+                }
+            }
+        }
+    }
+    // std::cout << defs;
+
+    defs.beginAll();
+    expectedDefs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+
+    Jobs jobs(&defs);
+    JobsParam jobsParam;
+    jobs.generate(jobsParam);
+
+    for (Submittable* s : jobsParam.submitted()) {
+        defs.updateCalendar(calUpdateParams);
+        s->set_state(NState::ACTIVE);
+
+        defs.updateCalendar(calUpdateParams);
+        if (s->name() == "t2" || s->name() == "t1")
+            defs.updateCalendar(calUpdateParams);
+        if (s->name() == "t1")
+            defs.updateCalendar(calUpdateParams);
+        s->set_state(NState::COMPLETE);
+    }
+
+    // PrintStyle style(PrintStyle::MIGRATE);
+    // std::cout << defs;
+
+    defs.order(nullptr, NOrder::RUNTIME); // moot when you only have one suite
+    for (auto suite : defs.suiteVec()) {
+        suite->order(nullptr, NOrder::RUNTIME);
+        for (auto family : suite->familyVec()) {
+            family->order(nullptr, NOrder::RUNTIME);
+        }
+    }
+    // std::cout << defs;
+
+    defs.requeue();
+    expectedDefs.requeue();
+
+    BOOST_CHECK_MESSAGE(defs == expectedDefs, "Defs are not the same");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestPersistence.cpp 5.13.0-1/libs/node/test/TestPersistence.cpp
--- 5.12.4-1/libs/node/test/TestPersistence.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestPersistence.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_FIXTURE_TEST_SUITE(U_Node, MyDefsFixture)
+
+BOOST_AUTO_TEST_SUITE(T_Persistence)
+
+// Allow for multiple archives
+static void testPersistence(const Defs& fixtureDefs) {
+    std::string check_pt_file = "fixture_defs.check";
+    fixtureDefs.cereal_save_as_checkpt(check_pt_file);
+    std::string error_msg;
+    BOOST_CHECK_MESSAGE(fixtureDefs.checkInvariants(error_msg), error_msg);
+
+    Defs restoredDefs;
+    restoredDefs.cereal_restore_from_checkpt(check_pt_file);
+    error_msg.clear();
+    BOOST_CHECK_MESSAGE(restoredDefs.checkInvariants(error_msg), error_msg);
+
+    bool theyCompare = (restoredDefs == fixtureDefs);
+    if (!theyCompare) {
+
+        std::cout << "Dump restored defs\n" << restoredDefs << "\n";
+        std::cout << "Dump fixture defs\n" << fixtureDefs << "\n";
+
+        BOOST_CHECK_MESSAGE(theyCompare, "restored defs file is not same as fixtureDefs defs file");
+    }
+
+    cout << " check pt file_size: " << fs::file_size(check_pt_file) << "\n";
+
+    // Uncomment if you want see what this file looks like
+    fs::remove(check_pt_file);
+}
+
+BOOST_AUTO_TEST_CASE(test_node_tree_persistence_text) {
+    cout << left << setw(54) << "ANode:: ...test_node_tree_persistence_text";
+    BOOST_CHECK_MESSAGE(true, ""); // stop boost complaining about no assertions
+    testPersistence(fixtureDefsFile());
+}
+
+BOOST_AUTO_TEST_CASE(test_node_defs_persistence) {
+    cout << "ANode:: ...test_node_defs_persistence\n";
+
+    const Defs& defs = fixtureDefsFile();
+    std::vector<node_ptr> all_nodes;
+    defs.get_all_nodes(all_nodes);
+    BOOST_REQUIRE_MESSAGE(all_nodes.size() > 0, "Expected nodes");
+    for (auto& all_node : all_nodes) {
+        std::string node_as_defs_string = all_node->print(PrintStyle::MIGRATE);
+        node_ptr the_copy               = Node::create(node_as_defs_string);
+        BOOST_REQUIRE_MESSAGE(the_copy,
+                              "Failed to create node " << all_node->absNodePath() << " from string:\n"
+                                                       << node_as_defs_string);
+        BOOST_REQUIRE_MESSAGE(*the_copy == *all_node, "Nodes not the same");
+    }
+    for (auto& all_node : all_nodes) {
+        std::string node_as_defs_string = all_node->print(PrintStyle::NET);
+        node_ptr the_copy               = Node::create(node_as_defs_string);
+        BOOST_REQUIRE_MESSAGE(the_copy,
+                              "Failed to create node " << all_node->absNodePath() << " from string:\n"
+                                                       << node_as_defs_string);
+        BOOST_REQUIRE_MESSAGE(*the_copy == *all_node, "Nodes not the same");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestPreProcessing.cpp 5.13.0-1/libs/node/test/TestPreProcessing.cpp
--- 5.12.4-1/libs/node/test/TestPreProcessing.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestPreProcessing.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,213 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <set>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+void findVariable(std::string& line, std::set<std::string>& variables) {
+    // scan for variables
+    // edit SMSFETCH "/home/ma/map/sms/smsfectch -F %ECF_FILES% -I %ECF_INCLUDE%"
+    // We can also have
+    //
+    // "%<VAR>:<substitute>% i.e if VAR exist use it, else use substitute
+    //
+    // i.e VAR is defined as BILL
+    //  %VAR:fred --f%  will either be "BILL" or if VAR is not defined "fred --f"
+    while (true) {
+        size_t firstPercentPos = line.find(Ecf::MICRO());
+        if (firstPercentPos == string::npos)
+            break;
+        size_t secondPercentPos = line.find(Ecf::MICRO(), firstPercentPos + 1);
+        if (secondPercentPos == string::npos)
+            break;
+        if (secondPercentPos - firstPercentPos <= 1)
+            break; // handle %% with no characters in between
+
+        string percentVar(line.begin() + firstPercentPos + 1, line.begin() + secondPercentPos);
+
+        size_t firstColon = percentVar.find(':');
+        if (firstColon != string::npos) {
+            string var(percentVar.begin(), percentVar.begin() + firstColon);
+            percentVar = var;
+        }
+
+        // Ignore auto-generated variables
+        if (percentVar.find("ECF_") == string::npos && percentVar != "DATE" && percentVar != "DAY" &&
+            percentVar != "DD" && percentVar != "DOW" && percentVar != "DOY" && percentVar != "MM" &&
+            percentVar != "MONTH" && percentVar != "YYYY" && percentVar != "TASK" && percentVar != "FAMILY" &&
+            percentVar != "FAMILY1" && percentVar != "SUITE") {
+            variables.insert(percentVar);
+        }
+
+        // std::cerr << "line before delete " << line << "\n";
+        line.erase(firstPercentPos, secondPercentPos - firstPercentPos + 1);
+        // std::cerr << "line after delete " << line << "\n";
+    }
+}
+
+void autoDiscoverVariables(const std::string& directory, std::set<std::string>& variables) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+    // std::cout << "\nIn directory: " << full_path << "\n\n";
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (fs::is_directory(dir_itr->status())) {
+                autoDiscoverVariables(relPath.string(), variables);
+                continue;
+            }
+            // std::cout << "......autoDiscoverVariables for file " << relPath.string() << "\n";
+            if (relPath.extension() != ".h")
+                continue; // Only look at .h files
+
+            // open the file, and find variables.
+            std::vector<std::string> lines;
+            if (File::splitFileIntoLines(relPath.string(), lines)) {
+                for (auto& line : lines) {
+                    findVariable(line, variables);
+                }
+            }
+        }
+        catch (const std::exception& ex) {
+            std::cout << "Exception::" << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_PreProcessing)
+
+// *Auto* discover the good/bad sms files
+void test_sms_preprocessing(const std::string& directory, bool pass) {
+    // SET ECF_HOME
+    std::string ecf_home = directory;
+
+    auto full_path = fs::absolute(directory);
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+    // Create a defs file, where the task name mirrors the sms files in the given directory
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/includes"));
+        suite->addVariable(Variable(Str::ECF_OUT(), "$ECF_HOME"));
+        suite->addVariable(Variable("SLEEPTIME", "10"));
+        family_ptr fam = suite->add_family("family");
+
+        // for operations auto discover the variables used in the header files and give
+        // them a dummy value. This would allow the test to pass when doing
+        // variable substitution. hence if variable substitution fails its likely to be
+        // a bug in autoDiscoverVariables
+        std::set<std::string> discoveredVariables;
+        autoDiscoverVariables(ecf_home + "/includes", discoveredVariables);
+        for (const string& var : discoveredVariables) {
+            // 			cerr << "autoDiscoverVariables = " << var << "\n";
+            suite->addVariable(Variable(var, "gobblygook"));
+        }
+
+        // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
+        fs::directory_iterator end_iter;
+        for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+            try {
+                fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+                // Ignore directories were only interested in .ecf files.
+                if (fs::is_directory(relPath))
+                    continue;
+                if (File::getExt(relPath.filename().string()) != "ecf")
+                    continue; // ignore other files
+
+                // std::cout << "......Parsing file " << relPath.string() << "\n";
+                // std::cout << "      adding task name " << relPath.leaf() << "\n";
+                fam->add_task(relPath.stem().string());
+            }
+            catch (const std::exception& ex) {
+                std::cout << "Exception " << dir_itr->path().filename() << " " << ex.what() << std::endl;
+            }
+        }
+        // cerr << "The defs\n" << theDefs << "\n";
+    }
+
+    // get all the task
+    std::vector<Task*> theTasks;
+    theDefs.getAllTasks(theTasks);
+
+    // Override ECF_HOME.   ECF_HOME is need to locate the ecf files
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are used in client scripts(sms) and used to locate the sms files
+    theDefs.beginAll();
+
+    // Test Job creator, this will pre-process and perform variable substitution on ecf files
+    for (Task* t : theTasks) {
+
+        // cout << "  task " << t->absNodePath() << "\n";
+        JobsParam jobsParam; // create jobs =  false, spawn_jobs = false
+        bool ok = t->submitJob(jobsParam);
+
+        if (pass) { // Test expected to pass
+            BOOST_CHECK_MESSAGE(ok, "Failed to create jobs. " << jobsParam.getErrorMsg());
+        }
+        else { // test expected to fail
+            BOOST_CHECK_MESSAGE(!ok, "Expected failure " << jobsParam.getErrorMsg());
+            BOOST_CHECK_MESSAGE(!ok, "expected no passes but found " << t->absNodePath() << " passes");
+            // cerr << "\n" << jobsParam.getErrorMsg() << " \n"; // un-comment to ensure correct error message
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_good_sms) {
+    cout << "ANode:: ...test_good_ecf\n";
+
+    std::string path = File::test_data("libs/node/test/data/SMSHOME2/good", "libs/node");
+
+    // All the sms in this directory are expected to pass
+    test_sms_preprocessing(path, true);
+}
+
+BOOST_AUTO_TEST_CASE(test_bad_sms) {
+    cout << "ANode:: ...test_bad_ecf\n";
+
+    std::string path = File::test_data("libs/node/test/data/SMSHOME2/bad", "libs/node");
+
+    // All the sms in this directory are expected to fail
+    test_sms_preprocessing(path, false);
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestRepeatWithTimeDependencies.cpp 5.13.0-1/libs/node/test/TestRepeatWithTimeDependencies.cpp
--- 5.12.4-1/libs/node/test/TestRepeatWithTimeDependencies.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestRepeatWithTimeDependencies.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,248 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_RepeatWithTimeDependencies)
+
+BOOST_AUTO_TEST_CASE(test_repeat_day_time_combination_in_hierarchy) {
+    cout << "ANode:: ...test_repeat_day_time_combination_in_hierarchy \n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  family f
+    //    repeat integer rep 0 1
+    //    family f1
+    //       day monday
+    //       task t1
+    //         time 10:00  # should run, monday at 10:00 twice, due to repeat
+    //         time 11:00  # should run, monday at 11:00 twice, due to repeat
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    family_ptr f  = suite->add_family("f");
+    family_ptr f1 = f->add_family("f1");
+    f1->addRepeat(RepeatInteger("rep", 0, 1, 1));
+    f1->addDay(DayAttr(DayAttr::MONDAY));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(11, 0)));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time1 =
+        boost::posix_time::ptime(date(2019, 8, 5), time_duration(10, 0, 0)); // Monday & 10
+    boost::posix_time::ptime expected_time2 =
+        boost::posix_time::ptime(date(2019, 8, 5), time_duration(11, 0, 0)); // Monday & 11
+    boost::posix_time::ptime expected_time3 =
+        boost::posix_time::ptime(date(2019, 8, 12), time_duration(10, 0, 0)); // Monday & 10
+    boost::posix_time::ptime expected_time4 =
+        boost::posix_time::ptime(date(2019, 8, 12), time_duration(11, 0, 0)); // Monday & 11
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 212; m++) { // run for 9 days
+
+        // const std::vector<DayAttr>& days = f1->days();
+        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // " " << days[0].dump() << " " << times[0].dump() << " rep: " << f1->repeat().value() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n";
+
+            // 1st Run: Monday at 10:00 am
+            if (submitted == 1)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
+                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            // 2nd Run: Monday at 11:00 am
+            if (submitted == 2)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time2,
+                                    "\nExpected to submit at " << expected_time2 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            // 3rd Run: Monday at 10:00 am
+            if (submitted == 3)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time3,
+                                    "\nExpected to submit at " << expected_time3 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            // 4th Run: Monday at 11:00 am
+            if (submitted == 4)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time4,
+                                    "\nExpected to submit at " << expected_time4 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            t1->set_state(NState::COMPLETE); // cause repeat to loop
+            // cout << "   set_complete t1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n";
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 4, "Expected four submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_time_day_combination_in_hierarchy) {
+    cout << "ANode:: ...test_repeat_time_day_combination_in_hierarchy \n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  family f
+    //    repeat integer rep 0 1
+    //    family f1
+    //       time 10:00  # should run, 2 on monday at midnight, the time has NO effect
+    //       task t1
+    //          day monday
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    family_ptr f  = suite->add_family("f");
+    family_ptr f1 = f->add_family("f1");
+    f1->addRepeat(RepeatInteger("rep", 0, 3, 1)); // four iteration
+    f1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addDay(DayAttr(DayAttr::MONDAY));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time1 =
+        boost::posix_time::ptime(date(2019, 8, 5), time_duration(0, 0, 0)); // Monday & 00:00
+    boost::posix_time::ptime expected_time3 =
+        boost::posix_time::ptime(date(2019, 8, 12), time_duration(0, 0, 0)); // Monday & 00:00
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 212; m++) { // run for 9 days
+
+        // const std::vector<DayAttr>& days = t1->days();
+        // const std::vector<ecf::TimeAttr>& times = f1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // " " << days[0].dump() << " " << times[0].dump() << " rep: " << f1->repeat().value() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n";
+
+            // 1st Run: Monday at 00:00 am
+            if (submitted == 1)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
+                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            // 1st Run: Monday at 00:00 am
+            if (submitted == 2)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time3,
+                                    "\nExpected to submit at " << expected_time3 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            t1->set_state(NState::COMPLETE); // cause repeat to loop
+            // cout << "   set_complete t1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n"; PrintStyle style(PrintStyle::MIGRATE); cout << defs << "\n";
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 2, "Expected two submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_with_impossible_day_combination_in_hierarchy) {
+    cout << "ANode:: ...test_repeat_with_impossible_day_combination_in_hierarchy\n";
+    // Create the suite, starting on a sunday
+    //   suite s1
+    //     clock real 04.08.2019            # Sunday
+    //     family f
+    //       repeat integer rep 0 1
+    //       family f1
+    //          day monday
+    //          task t1
+    //               day tuesday            # cant be free on Monday and Tuesday,
+    //               time 10:00
+    //               verify complete:1
+    Defs defs;
+    suite_ptr suite = defs.add_suite("s1");
+    suite->addClock(ClockAttr(boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)))); // sunday
+    family_ptr f  = suite->add_family("f");
+    family_ptr f1 = f->add_family("f1");
+    f1->addRepeat(RepeatInteger("rep", 0, 1, 1)); // 2 iteration
+    f1->addDay(DayAttr(DayAttr::MONDAY));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addDay(DayAttr(DayAttr::TUESDAY));
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 212; m++) { // run for 9 days
+
+        // const std::vector<DayAttr>& fdays = f1->days();
+        // const std::vector<DayAttr>& days = t1->days();
+        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // "\n   "
+        //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
+        //          f1->repeat().value() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << " submitted at " << suite->calendar().suiteTime() << " dayChanged:" <<
+            // suite->calendar().dayChanged() << "\n   "
+            //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
+            //          f1->repeat().value() << "\n";
+
+            t1->set_state(NState::COMPLETE); // cause repeat to loop
+                                             // PrintStyle style(PrintStyle::MIGRATE);
+            // cout << defs << "\n";
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 0, "Expected 0 submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestReplace.cpp 5.13.0-1/libs/node/test/TestReplace.cpp
--- 5.12.4-1/libs/node/test/TestReplace.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestReplace.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1052 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+class ExpectStateChange {
+public:
+    ExpectStateChange() : state_change_no_(Ecf::state_change_no()) { Ecf::set_server(true); }
+    ~ExpectStateChange() {
+        BOOST_CHECK_MESSAGE(state_change_no_ != Ecf::state_change_no(), "Expected state change");
+        Ecf::set_server(false);
+    }
+
+private:
+    unsigned int state_change_no_;
+};
+
+class ExpectModifyChange {
+public:
+    ExpectModifyChange() : modify_change_no_(Ecf::modify_change_no()) { Ecf::set_server(true); }
+    ~ExpectModifyChange() {
+        BOOST_CHECK_MESSAGE(modify_change_no_ != Ecf::modify_change_no(), "Expected Modify change");
+        Ecf::set_server(false);
+    }
+
+private:
+    unsigned int modify_change_no_;
+};
+
+class ExpectNoChange {
+public:
+    ExpectNoChange() : state_change_no_(Ecf::state_change_no()), modify_change_no_(Ecf::modify_change_no()) {
+        Ecf::set_server(true);
+    }
+    ~ExpectNoChange() {
+        BOOST_CHECK_MESSAGE(state_change_no_ == Ecf::state_change_no() && modify_change_no_ == Ecf::modify_change_no(),
+                            "Expected no change");
+        Ecf::set_server(false);
+    }
+
+private:
+    unsigned int state_change_no_;
+    unsigned int modify_change_no_;
+};
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Replace)
+
+BOOST_AUTO_TEST_CASE(test_replace_add_task) {
+    cout << "ANode:: ...test_replace_add_task\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t2");
+        clientDef->addSuite(suite);
+    }
+
+    // add Child t2 to the server defs
+    Defs serverDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+        serverDefs.addSuite(suite);
+    }
+
+    Defs expectedDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t2"); // notice we preserve client position, and not server position
+        fam->add_task("t1");
+        expectedDefs.addSuite(suite);
+    }
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs.replaceChild(
+            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_add_suite) {
+    cout << "ANode:: ...test_replace_add_suite\n";
+    // In this test the server defs is *EMPTY* hence we should copy/move over the whole suite
+    // provided the a/ Path to node exists in the client def, b/ create nodes as needed is TRUE
+    Defs expectedDefs;
+    {
+        suite_ptr suite = expectedDefs.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+        fam->add_task("t2");
+    }
+
+    {
+        // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
+        defs_ptr clientDef = Defs::create();
+        {
+            suite_ptr suite = clientDef->add_suite("suite1");
+            family_ptr fam  = suite->add_family("family");
+            fam->add_task("t1");
+            fam->add_task("t2");
+        }
+
+        ExpectModifyChange expect_state_change;
+        Defs serverDefs; // Server defs is empty
+
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild(
+                "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+
+    {
+        // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
+        defs_ptr clientDef = Defs::create();
+        {
+            suite_ptr suite = clientDef->add_suite("suite1");
+            family_ptr fam  = suite->add_family("family");
+            fam->add_task("t1");
+            fam->add_task("t2");
+        }
+
+        ExpectModifyChange expect_state_change;
+        Defs serverDefs; // Server defs is empty
+
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild(
+                "/suite1/family", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+
+    {
+        // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
+        defs_ptr clientDef = Defs::create();
+        {
+            suite_ptr suite = clientDef->add_suite("suite1");
+            family_ptr fam  = suite->add_family("family");
+            fam->add_task("t1");
+            fam->add_task("t2");
+        }
+
+        ExpectModifyChange expect_state_change;
+        Defs serverDefs; // Server defs is empty
+
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_child) {
+    cout << "ANode:: ...test_replace_child\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        clientDef->addSuite(suite);
+    }
+    Defs comparisonDef;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        comparisonDef.addSuite(suite);
+    }
+    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
+
+    ExpectModifyChange expect_state_change;
+    std::string errorMsg;
+    Defs serverDefs;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs.replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_CHECK_MESSAGE(comparisonDef == serverDefs, "comparisonDef and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_add_preserves_states) {
+    cout << "ANode:: ...test_replace_add_preserves_states\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+        fam->add_task("t2");
+        fam->add_task("t3");
+        fam->add_task("t4");
+    }
+
+    // add Child t4 to the server defs, the states on t1->t3 should be preserved
+    // The abort should be progagated up the node tree
+    family_ptr fam;
+    suite_ptr suite;
+    Defs serverDefs;
+    {
+        suite       = serverDefs.add_suite("suite1");
+        fam         = suite->add_family("family");
+        task_ptr t1 = fam->add_task("t1");
+        task_ptr t2 = fam->add_task("t2");
+        task_ptr t3 = fam->add_task("t3");
+        serverDefs.beginAll();
+        t1->set_state(NState::COMPLETE);
+        t2->set_state(NState::ABORTED);
+        t3->set_state(NState::ACTIVE);
+    }
+
+    // cout << serverDefs;
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs.replaceChild(
+            "/suite1/family/t4", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+
+    /// The Nodes t1,t2,t3 may have been replaced hence we must get Nodes again
+    node_ptr st1 = serverDefs.findAbsNode("/suite1/family/t1");
+    node_ptr st2 = serverDefs.findAbsNode("/suite1/family/t2");
+    node_ptr st3 = serverDefs.findAbsNode("/suite1/family/t3");
+    node_ptr st4 = serverDefs.findAbsNode("/suite1/family/t4");
+    BOOST_REQUIRE_MESSAGE(st1, "Expected to find task t1");
+    BOOST_REQUIRE_MESSAGE(st2, "Expected to find task t2");
+    BOOST_REQUIRE_MESSAGE(st3, "Expected to find task t3");
+    BOOST_REQUIRE_MESSAGE(st4, "Expected to find task t4");
+    BOOST_REQUIRE_MESSAGE(st1->state() == NState::COMPLETE, " state on task t1 not preserved after replace");
+    BOOST_REQUIRE_MESSAGE(st2->state() == NState::ABORTED, " state on task t2 not preserved after replace");
+    BOOST_REQUIRE_MESSAGE(st3->state() == NState::ACTIVE, " state on task t3 not preserved after replace");
+    BOOST_REQUIRE_MESSAGE(st4->state() == NState::QUEUED, " state on task t4 to be queued");
+    BOOST_REQUIRE_MESSAGE(fam->state() == NState::ABORTED, "Aborted should have propagated to family");
+    BOOST_REQUIRE_MESSAGE(suite->state() == NState::ABORTED, "Aborted should have propagated to suite");
+    BOOST_REQUIRE_MESSAGE(serverDefs.state() == NState::ABORTED, "Aborted should have propagated to Defs");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_preserves_suspend) {
+    cout << "ANode:: ...test_replace_preserves_suspend\n"; // ECFLOW-1520
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+        fam->add_task("t2");
+        fam->add_task("t3");
+        fam->add_task("t4");
+    }
+
+    Defs comparisonDef;
+    {
+        suite_ptr suite = comparisonDef.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        task_ptr t1     = fam->add_task("t1");
+        task_ptr t2     = fam->add_task("t2");
+        task_ptr t3     = fam->add_task("t3");
+        task_ptr t4     = fam->add_task("t4");
+        BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
+        comparisonDef.beginAll();
+
+        fam->suspend();
+        t1->suspend();
+        t2->suspend();
+        t3->suspend();
+        t4->suspend();
+    }
+
+    defs_ptr serverDefs = Defs::create();
+    {
+        suite_ptr suite = serverDefs->add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        task_ptr t1     = fam->add_task("t1");
+        task_ptr t2     = fam->add_task("t2");
+        task_ptr t3     = fam->add_task("t3");
+        task_ptr t4     = fam->add_task("t4");
+        serverDefs->beginAll();
+        fam->suspend();
+        t1->suspend();
+        t2->suspend();
+        t3->suspend();
+        t4->suspend();
+    }
+
+    //   PrintStyle style(PrintStyle::MIGRATE);
+    //   cout << serverDefs;
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs->replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1"), "Can't find suite1");
+    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1")->begun(), "Expected replaced suite to preserve begun status");
+    DebugEquality debug_equality; // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(comparisonDef == *serverDefs, "comparisonDef and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_preserves_suspend2) {
+    cout << "ANode:: ...test_replace_preserves_suspend2\n"; // ECFLOW-1520
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        family_ptr f1   = suite->add_family("f1");
+        family_ptr fam  = f1->add_family("fam");
+        fam->add_task("t1");
+    }
+
+    Defs comparisonDef;
+    {
+        suite_ptr suite = comparisonDef.add_suite("suite1");
+        family_ptr f1   = suite->add_family("f1");
+        family_ptr fam  = f1->add_family("fam");
+        task_ptr t1     = fam->add_task("t1");
+
+        BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
+        comparisonDef.beginAll();
+
+        f1->suspend();
+        fam->suspend();
+    }
+
+    defs_ptr serverDefs = Defs::create();
+    {
+        suite_ptr suite = serverDefs->add_suite("suite1");
+        family_ptr f1   = suite->add_family("f1");
+        family_ptr fam  = f1->add_family("fam");
+        serverDefs->beginAll();
+        f1->suspend();
+        fam->suspend();
+    }
+
+    //   PrintStyle style(PrintStyle::MIGRATE);
+    //   cout << serverDefs;
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs->replaceChild(
+            "/suite1/f1/fam/t1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1"), "Can't find suite1");
+    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1")->begun(), "Expected replaced suite to preserve begun status");
+    DebugEquality debug_equality; // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(comparisonDef == *serverDefs, "comparisonDef and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_preserves_sibling_states) {
+    cout << "ANode:: ...test_replace_preserves_sibling_states\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t4");
+        clientDef->addSuite(suite);
+    }
+
+    // add Child t4 to the server defs, the states on t1->t4 should be preserved
+    task_ptr t1, t2, t3;
+    Defs serverDefs;
+    {
+        suite_ptr suite = serverDefs.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        t1              = fam->add_task("t1");
+        t1->set_state(NState::COMPLETE);
+        t2 = fam->add_task("t2");
+        t2->set_state(NState::ABORTED);
+        t3 = fam->add_task("t3");
+        t3->set_state(NState::ACTIVE);
+        fam->add_task("t4");
+    }
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs.replaceChild(
+            "/suite1/family/t4", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_REQUIRE_MESSAGE(t1->state() == NState::COMPLETE, " state on task t1 not preserved after replace");
+    BOOST_REQUIRE_MESSAGE(t2->state() == NState::ABORTED, " state on task t2 not preserved after replace");
+    BOOST_REQUIRE_MESSAGE(t3->state() == NState::ACTIVE, " state on task t3 not preserved after replace");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_preserves_begun_status) {
+    cout << "ANode:: ...test_replace_preserves_begun_status\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->addTask(Task::create("t1"));
+    }
+    Defs comparisonDef;
+    {
+        suite_ptr suite = comparisonDef.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->addTask(Task::create("t1"));
+    }
+    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
+    comparisonDef.beginAll();
+
+    defs_ptr serverDefs = Defs::create();
+    {
+        suite_ptr suite = serverDefs->add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->addTask(Task::create("t1"));
+    }
+    serverDefs->beginAll();
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs->replaceChild("/suite1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1"), "Can't find suite1");
+    BOOST_REQUIRE_MESSAGE(serverDefs->findSuite("suite1")->begun(), "Expected replaced suite to preserve begun status");
+    DebugEquality debug_equality; // only has affect in DEBUG build
+    BOOST_CHECK_MESSAGE(comparisonDef == *serverDefs, "comparisonDef and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_preserves_begun_where_client_not_begun) {
+    cout << "ANode:: ...test_replace_preserves_begun_where_client_not_begun\n"; // ECFLOW-1612
+    // In this test we will end up calling begin on the time attribute.
+    // However we had called begin on the client defs side, where the calendar/suite had not been begun
+    // Thus causing an assert failure. The fix is to call begin on the server side, after the replace.
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = suite->add_family("family");
+        task_ptr t2     = fam->add_task("t2");
+        t2->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), false));
+        clientDef->addSuite(suite);
+    }
+
+    // add Child t2 to the server defs
+    Defs serverDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+        serverDefs.addSuite(suite);
+        serverDefs.beginAll();
+    }
+
+    Defs expectedDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = suite->add_family("family");
+        task_ptr t2     = fam->add_task("t2"); // notice we preserve client position, and not server position
+        t2->addTime(ecf::TimeAttr(ecf::TimeSlot(0, 0), ecf::TimeSlot(10, 1), ecf::TimeSlot(0, 1), false));
+        fam->add_task("t1");
+        expectedDefs.addSuite(suite);
+        expectedDefs.beginAll();
+    }
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs.replaceChild(
+            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_add_node) {
+    cout << "ANode:: ...test_replace_add_node\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        suite->addTask(Task::create("t2"));
+        clientDef->addSuite(suite);
+    }
+    Defs comparisonDef;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        suite->addTask(Task::create("t2"));
+        comparisonDef.addSuite(suite);
+    }
+    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
+
+    // Here /suite1/t2 does not exist in the server. Moved from client defs to server
+    Defs serverDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        serverDefs.addSuite(suite);
+    }
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs.replaceChild("/suite1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_CHECK_MESSAGE(comparisonDef == serverDefs, "comparisonDef and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_add_hierarchy) {
+    cout << "ANode:: ...test_replace_add_hierarchy\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fa   = Family::create("fa");
+        family_ptr fb   = Family::create("fb");
+        family_ptr fc   = Family::create("fc");
+        family_ptr fd   = Family::create("fd");
+        fa->addFamily(fb);
+        fb->addFamily(fc);
+        fc->addFamily(fd);
+        fd->addTask(Task::create("t1"));
+        suite->addFamily(fa);
+        clientDef->addSuite(suite);
+    }
+    Defs comparisonDef;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fa   = Family::create("fa");
+        family_ptr fb   = Family::create("fb");
+        family_ptr fc   = Family::create("fc");
+        family_ptr fd   = Family::create("fd");
+        fa->addFamily(fb);
+        fb->addFamily(fc);
+        fc->addFamily(fd);
+        fd->addTask(Task::create("t1"));
+        suite->addFamily(fa);
+        comparisonDef.addSuite(suite);
+    }
+    BOOST_CHECK_MESSAGE(comparisonDef == *clientDef, "client and comparisonDef should be the same");
+
+    // Here /suite1/fa/fb/fc/fd/t1 does not exist in the server.  These should be created.
+    // by adding family "fa" as a child of suite1
+    Defs serverDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        serverDefs.addSuite(suite);
+    }
+
+    ExpectStateChange expect_state_change;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        serverDefs.replaceChild(
+            "/suite1/fa/fb/fc/fd/t1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        errorMsg);
+    BOOST_CHECK_MESSAGE(comparisonDef == serverDefs, "comparisonDef and servers defs should be the same");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_order_preserved_for_suite) {
+    cout << "ANode:: ...test_replace_order_preserved_for_suite\n";
+    // Test that when we replace a suite, its order is preserved,
+    // See  ECFLOW-23 - When replacing a node the order is changed.
+    defs_ptr clientDef = Defs::create();
+    {
+        clientDef->add_suite("s1");
+        clientDef->add_suite("s2");
+        clientDef->add_suite("s3");
+    }
+
+    // Replace suite s1 with another suite s1 check order is preserved
+    Defs serverDefs;
+    {
+        serverDefs.add_suite("s1");
+        serverDefs.add_suite("s2");
+        serverDefs.add_suite("s3");
+    }
+
+    Defs expectedDefs;
+    {
+        expectedDefs.add_suite("s1");
+        expectedDefs.add_suite("s2");
+        expectedDefs.add_suite("s3");
+    }
+
+    std::string errorMsg;
+    {
+        ExpectModifyChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild("/s1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+    {
+        ExpectModifyChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild("/s2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+    {
+        ExpectModifyChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild("/s3", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_order_preserved_for_family) {
+    cout << "ANode:: ...test_replace_order_preserved_for_family\n";
+    // Test that when we replace a family, its order is preserved,
+    // See  ECFLOW-23 - When replacing a node the order is changed.
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        suite->add_family("f1");
+        suite->add_family("f2");
+        suite->add_family("f3");
+    }
+
+    // Replace family f1 with another family f1 check order is preserved
+    Defs serverDefs;
+    {
+        suite_ptr suite = serverDefs.add_suite("suite1");
+        suite->add_family("f1");
+        suite->add_family("f2");
+        suite->add_family("f3");
+    }
+
+    Defs expectedDefs;
+    {
+        suite_ptr suite = expectedDefs.add_suite("suite1");
+        suite->add_family("f1");
+        suite->add_family("f2");
+        suite->add_family("f3");
+    }
+
+    std::string errorMsg;
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    {
+        ExpectStateChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
+                                  "/suite1/f1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+                              errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+    {
+        ExpectStateChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
+                                  "/suite1/f2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+                              errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+    {
+        ExpectStateChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
+                                  "/suite1/f3", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+                              errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_order_preserved_for_task) {
+    cout << "ANode:: ...test_replace_order_preserved_for_task\n";
+    // Test that when we replace a family, its order is preserved,
+    // See  ECFLOW-23 - When replacing a node the order is changed.
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        family_ptr f1   = suite->add_family("f1");
+        f1->add_task("t1");
+        f1->add_task("t2");
+        f1->add_task("t3");
+    }
+
+    // Replace task t1 with another task t1, check order is preserved
+    Defs serverDefs;
+    {
+        suite_ptr suite = serverDefs.add_suite("suite1");
+        family_ptr f1   = suite->add_family("f1");
+        f1->add_task("t1");
+        f1->add_task("t2");
+        f1->add_task("t3");
+    }
+
+    Defs expectedDefs;
+    {
+        suite_ptr suite = expectedDefs.add_suite("suite1");
+        family_ptr f1   = suite->add_family("f1");
+        f1->add_task("t1");
+        f1->add_task("t2");
+        f1->add_task("t3");
+    }
+
+    std::string errorMsg;
+    DebugEquality debug_equality; // only as affect in DEBUG build
+    {
+        ExpectStateChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild(
+                "/suite1/f1/t1", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+    {
+        ExpectStateChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild(
+                "/suite1/f1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+    {
+        ExpectStateChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild(
+                "/suite1/f1/t3", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+            errorMsg);
+        BOOST_CHECK_MESSAGE(expectedDefs == serverDefs, "expectedDefs and servers defs should be the same");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_child_errors) {
+    cout << "ANode:: ...test_replace_child_errors\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        suite->addTask(Task::create("t2"));
+        clientDef->addSuite(suite);
+    }
+
+    ExpectNoChange expect_no_change;
+    Defs serverDefs;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(
+        !serverDefs.replaceChild(
+            "/suite1/i/dont/exist", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+        "Expected failure");
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_child_errors_2) {
+    cout << "ANode:: ...test_replace_child_errors_2\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        suite->addTask(Task::create("t2"));
+        clientDef->addSuite(suite);
+    }
+    Defs serverDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        serverDefs.addSuite(suite);
+    }
+
+    std::string errorMsg;
+    {
+        ExpectNoChange expect_no_change;
+        // because createNodesAsNeeded is false, child adoption should fail since /suite1/t2
+        // does not exist on the server
+        BOOST_REQUIRE_MESSAGE(
+            !serverDefs.replaceChild("/suite1/t2", clientDef, false /*create nodes as needed*/, false, errorMsg),
+            "Expected failure");
+    }
+    {
+        // With flag now set, we will create any missing nodes even if they dont exist in the server
+        ExpectStateChange expect_state_change;
+        errorMsg.clear();
+        BOOST_REQUIRE_MESSAGE(serverDefs.replaceChild(
+                                  "/suite1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+                              "Expected success " << errorMsg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_child_errors_3) {
+    // test force option
+    cout << "ANode:: ...test_replace_child_errors_3\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        suite->addTask(Task::create("t2"));
+        clientDef->addSuite(suite);
+    }
+
+    Defs serverDefs;
+    {
+        suite_ptr suite = Suite::create("suite1");
+        family_ptr fam  = Family::create("family");
+        fam->addTask(Task::create("t1"));
+        suite->addFamily(fam);
+        task_ptr t2 = Task::create("t2");
+        suite->addTask(t2);
+        serverDefs.addSuite(suite);
+
+        t2->set_state(NState::ACTIVE); // Must be done after parent has been setup
+    }
+
+    std::string errorMsg;
+    {
+        ExpectNoChange expect_no_change;
+        BOOST_REQUIRE_MESSAGE(!serverDefs.replaceChild(
+                                  "/suite1/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg),
+                              "Expected failure since server task t2 is active, and force not used");
+    }
+    {
+        errorMsg.clear();
+        ExpectStateChange expect_state_change;
+        BOOST_REQUIRE_MESSAGE(
+            serverDefs.replaceChild("/suite1/t2", clientDef, true /*create nodes as needed*/, true /*force*/, errorMsg),
+            errorMsg);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_add_task_with_bad_trigger) {
+    cout << "ANode:: ...test_replace_add_task_with_bad_trigger\n";
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        task_ptr task   = fam->add_task("t2");
+        task->add_trigger("txx eq complete");
+    }
+
+    // add Child t2 to the server defs
+    Defs serverDefs;
+    {
+        suite_ptr suite = serverDefs.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+    }
+
+    // Expect to pass, since the replace part is ok.
+    std::string errorMsg;
+    node_ptr replaced_node;
+    {
+        ExpectStateChange expect_state_change;
+        replaced_node = serverDefs.replaceChild(
+            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
+        BOOST_REQUIRE_MESSAGE(replaced_node, "Expected replaced to succeed, even though triggers are dodgy");
+    }
+
+    // Although we have change the data model, Check if the trigger expressions are still valid. Should fail
+    std::string warning_msg;
+    BOOST_REQUIRE_MESSAGE(!replaced_node->suite()->check(errorMsg, warning_msg), "Expected failure " << errorMsg);
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_add_suite_with_bad_triggers) {
+    cout << "ANode:: ...test_replace_add_suite_with_bad_triggers\n";
+
+    // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
+    defs_ptr clientDef = Defs::create();
+    {
+        suite_ptr suite = clientDef->add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_task("t1");
+        fam->add_task("t2");
+        task_ptr t3 = fam->add_task("t3");
+        t3->add_trigger("txxxxx eq complete");
+    }
+
+    // Server defs is empty
+    Defs serverDefs;
+
+    // Expect to pass, since the replace part is ok.
+    std::string errorMsg;
+    node_ptr replaced_node;
+    {
+        ExpectModifyChange expect_state_change;
+        replaced_node = serverDefs.replaceChild(
+            "/suite1/family/t2", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
+        BOOST_REQUIRE_MESSAGE(replaced_node, "Expected replaced to succeed, even though triggers are dodgy");
+    }
+
+    // Although we have changed the data model, Check if the trigger expressions are still valid. Should fail.
+    std::string warning_msg;
+    BOOST_REQUIRE_MESSAGE(!replaced_node->suite()->check(errorMsg, warning_msg), "Expected failure " << errorMsg);
+
+    // reset, to avoid effecting downstream tests
+    Ecf::set_state_change_no(0);
+    Ecf::set_modify_change_no(0);
+}
+
+BOOST_AUTO_TEST_CASE(test_replace_task_ECFLOW_1135) {
+    cout << "ANode:: ...test_replace_task_ECFLOW_1135\n";
+
+    // The whole suite should get *MOVED* from clientDef to the *EMPTY* server def. i.e add
+    defs_ptr clientDef = Defs::create();
+    {
+        clientDef->add_suite("o")
+            ->add_family("main")
+            ->add_family("00")
+            ->add_family("an")
+            ->add_family("4dvar")
+            ->add_task("vardata");
+    }
+
+    // Server
+    Defs serverDefs;
+    { serverDefs.add_suite("o")->add_family("main")->add_family("00")->add_family("an")->add_task("4dvar"); }
+
+    // Expect to fail *IF*  irrespective of 'create nodes as needed' flag, since path in the server is a *TASK*
+    {
+        std::string errorMsg;
+        ExpectNoChange expect_no_change;
+        node_ptr replaced_node = serverDefs.replaceChild(
+            "/o/main/00/an/4dvar/vardata", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
+        BOOST_REQUIRE_MESSAGE(!replaced_node, "Expected replace to fail");
+        BOOST_REQUIRE_MESSAGE(!errorMsg.empty(), "Expected error message");
+    }
+    {
+        std::string errorMsg;
+        ExpectNoChange expect_no_change;
+        node_ptr replaced_node = serverDefs.replaceChild(
+            "/o/main/00/an/4dvar/vardata", clientDef, false /*create nodes as needed*/, false /*force*/, errorMsg);
+        BOOST_REQUIRE_MESSAGE(!replaced_node, "Expected replace to fail");
+        BOOST_REQUIRE_MESSAGE(!errorMsg.empty(), "Expected error message");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_trigger_references_during_replace) {
+    cout << "ANode:: ...test_trigger_references_during_replace\n"; // ECFLOW-1319
+
+    // This is used to check that the trigger references in AST, are invalidated after replace.
+
+    Defs serverDefs;
+    suite_ptr server_suite;
+    {
+        server_suite = serverDefs.add_suite("suite");
+        server_suite->addVariable(Variable(Str::ECF_INCLUDE(), "$ECF_HOME/../includes"));
+        server_suite->addVariable(Variable("SLEEPTIME", "1"));
+        server_suite->addVariable(Variable("ECF_CLIENT_EXE_PATH", "a/made/up/path"));
+        family_ptr fam = server_suite->add_family("family");
+        fam->add_task("t1")->add_trigger("/suite1/family/suite1_task1 == complete");
+        fam->add_task("t2")->add_trigger("/suite1/family/suite1_task2 == complete");
+        fam->add_task("t3")->add_trigger("/suite1/family/suite1_task3 == complete");
+    }
+    task_ptr suite1_task1, suite1_task2, suite1_task3;
+    {
+        suite_ptr suite = serverDefs.add_suite("suite1");
+        family_ptr fam  = suite->add_family("family");
+        suite1_task1    = fam->add_task("suite1_task1");
+        suite1_task2    = fam->add_task("suite1_task2");
+        suite1_task3    = fam->add_task("suite1_task3");
+    }
+
+    // Override ECF_HOME. ECF_HOME is need to locate to the .ecf files
+    std::string ecf_home = File::test_data("libs/node/test/data/SMSHOME", "libs/node");
+    serverDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(), ecf_home);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    serverDefs.beginAll();
+
+    suite1_task1->set_state(NState::COMPLETE);
+    suite1_task2->set_state(NState::COMPLETE);
+    suite1_task3->set_state(NState::COMPLETE);
+
+    // We need JOB generation to *FORCE* the creation of the trigger AST, and hence references
+    {
+        JobsParam jobsParam(true /*create jobs*/); // spawn_jobs = false
+        Jobs jobs(&serverDefs);
+        jobs.generate(jobsParam);
+        BOOST_REQUIRE_MESSAGE(jobsParam.submitted().size() == 3,
+                              "expected 3 jobs but found " << jobsParam.submitted().size() << "\n"
+                                                           << jobsParam.errorMsg());
+    }
+
+    {
+        // Now replace the suite1/family thereby, invalidating the trigger reference on suite/family/t1,t2,t3
+        defs_ptr clientDef = Defs::create();
+        suite_ptr suite    = clientDef->add_suite("suite1");
+        family_ptr fam     = suite->add_family("family");
+        fam->add_task("suite1_task1");
+        fam->add_task("suite1_task2");
+        fam->add_task("suite1_task3");
+        fam->add_task("dummy");
+
+        std::string errorMsg;
+        serverDefs.replaceChild(
+            "/suite1/family", clientDef, true /*create nodes as needed*/, false /*force*/, errorMsg);
+        BOOST_REQUIRE_MESSAGE(errorMsg.empty(), "Expected no message " << errorMsg);
+    }
+    {
+        std::vector<Node*> all_server_nodes;
+        serverDefs.getAllNodes(all_server_nodes);
+
+        // Now check the Trigger reference. The old reference to nodes in the trigger expressions should have been
+        // removed
+        std::vector<Task*> theTasks;
+        server_suite->getAllTasks(theTasks);
+        BOOST_REQUIRE_MESSAGE(theTasks.size() == 3, "Expected 3 tasks but found, " << theTasks.size());
+        for (auto& theTask : theTasks) {
+
+            std::set<Node*> referenced_nodes;
+            theTask->getAllAstNodes(referenced_nodes);
+            BOOST_REQUIRE_MESSAGE(referenced_nodes.size() == 1, " expected 1 referenced node");
+
+            // The reference nodes must exist in the server. Otherwise replace has still kept references to old nodes in
+            // the triggers
+            bool found_reference = false;
+            for (auto& all_server_node : all_server_nodes) {
+                if (all_server_node == (*referenced_nodes.begin())) {
+                    found_reference = true;
+                    break;
+                }
+            }
+            BOOST_CHECK_MESSAGE(found_reference,
+                                "Could not find trigger reference " << (*referenced_nodes.begin())->absNodePath()
+                                                                    << " in the server");
+        }
+    }
+
+    // reset, to avoid effecting downstream tests
+    Ecf::set_state_change_no(0);
+    Ecf::set_modify_change_no(0);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestSetState.cpp 5.13.0-1/libs/node/test/TestSetState.cpp
--- 5.12.4-1/libs/node/test/TestSetState.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestSetState.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,145 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_SetState)
+
+static void set_state(node_ptr n, NState::State set, NState::State expected) {
+    n->set_state(set);
+    BOOST_REQUIRE_MESSAGE(n->state() == expected,
+                          "Expected state " << NState::toString(expected) << " but found "
+                                            << NState::toString(n->state()) << " for " << n->debugNodePath());
+}
+
+static void test_state(node_ptr n, NState::State expected) {
+    BOOST_REQUIRE_MESSAGE(n->state() == expected,
+                          "Expected state " << NState::toString(expected) << " but found "
+                                            << NState::toString(n->state()) << " for " << n->debugNodePath());
+}
+
+BOOST_AUTO_TEST_CASE(test_set_state) {
+    cout << "ANode:: ...test_set_state\n";
+    std::vector<NState::State> stateVec = NState::states();
+
+    // 	cout << "Defs setState\n";
+    Defs theDefs;
+    for (NState::State state : stateVec) {
+        theDefs.set_state(state);
+        BOOST_REQUIRE_MESSAGE(theDefs.state() == state,
+                              "Expected defs state " << NState::toString(state) << " but found "
+                                                     << NState::toString(theDefs.state()));
+    }
+    //  	theDefs.resume();                   // unset the suspended state. Start with default, for next set of
+    //  test
+    theDefs.set_state(NState::UNKNOWN); // Start with default, for next set of test
+
+    // 	cout << "Suite setState\n";
+    suite_ptr s = Suite::create("s");
+    theDefs.addSuite(s);
+    for (NState::State state : stateVec) {
+        set_state(s, state, state); // suite with no children, state should be what was set
+    }
+    s->resume();                   // unset the suspended state. Start with default, for next set of test
+    s->set_state(NState::UNKNOWN); // Start with default, for next set of test
+
+    // 	cout << "family setState\n";
+    family_ptr f = Family::create("f");
+    s->addFamily(f);
+    for (NState::State state : stateVec) {
+        set_state(f, state, state); // family with no children, state should be what was set
+    }
+    f->resume();                   // unset the suspended state. Start with default, for next set of test
+    f->set_state(NState::UNKNOWN); // Start with default, for next set of test
+
+    // 	cout << "task setState\n";
+    task_ptr t = Task::create("t");
+    f->addTask(t);
+
+    for (NState::State state : stateVec) {
+        f->setStateOnly(NState::UNKNOWN); // reset family state
+        s->setStateOnly(NState::UNKNOWN); // reset suite state
+        set_state(t, state, state);       // task state should be what was set
+
+        test_state(f, state); // family state should be computed state
+        test_state(s, state); // suite state should be computed state
+    }
+
+    /// Everytime we set the state on a nodecontainer, we call handleStateChange
+    /// This by default works out the most significant state of the children
+    /// ie. the computed state. Hence setting the state on Suite/Family is really
+    /// meaningless, since it will always be the computed state.
+}
+
+BOOST_AUTO_TEST_CASE(test_set_aborted) {
+    // see ECFLOW-344
+    cout << "ANode:: ...test_set_aborted\n";
+
+    Defs defs;
+    suite_ptr suite = defs.add_suite("s1");
+    task_ptr t1     = suite->add_task("t1");
+    t1->addDefStatus(DState::COMPLETE);
+    defs.beginAll();
+
+    {
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "No jobs should be submitted when task is complete but found "
+                                << jobsParam.submitted().size() << " submitted");
+    }
+
+    t1->setStateOnly(NState::ABORTED, true /*force*/);
+    {
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 0,
+                            "No jobs should be submitted when task is forcibly aborted but found "
+                                << jobsParam.submitted().size() << " submitted");
+    }
+
+    Node::Requeue_args args;
+    t1->requeue(args);
+
+    t1->set_state(NState::ABORTED); // mimic non forced, i.e like job aborted
+    {
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+        BOOST_CHECK_MESSAGE(jobsParam.submitted().size() == 1,
+                            "Expected 1 job, when job aborts and ECF_TRIES > 1 but found "
+                                << jobsParam.submitted().size() << " submitted");
+        BOOST_CHECK_MESSAGE(t1->try_no() == 1, " expected try_no to be 1 but found " << t1->try_no());
+    }
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestSingleExprParse.cpp 5.13.0-1/libs/node/test/TestSingleExprParse.cpp
--- 5.12.4-1/libs/node/test/TestSingleExprParse.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestSingleExprParse.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,126 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+#include <map>
+#include <string>
+
+#include <boost/date_time/posix_time/conversion.hpp>
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/ExprDuplicate.hpp"
+#include "ecflow/node/ExprParser.hpp"
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+// DEBUG AID: to see the expression tree, invert the expected evaluation
+//            so that test fail's
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_SingleExprParse)
+
+BOOST_AUTO_TEST_CASE(test_single_expression) {
+    std::cout << "ANode:: ...test_single_expression\n";
+
+    // Duplicate AST are held in a static map. Delete them, to avoid ASAN complaining
+    ExprDuplicate reclaim_cloned_ast_memory;
+
+    // The map key = trigger expression,
+    // value.first  = type of expected root abstract syntax tree
+    // value.second = result of expected evaluation
+    map<string, std::pair<string, bool>> exprMap;
+
+    exprMap[":var == 0"] = std::make_pair(AstEqual::stype(), true);
+    exprMap[":var != 1"] = std::make_pair(AstNotEqual::stype(), true);
+
+    for (std::pair<string, std::pair<string, bool>> p : exprMap) {
+
+        ExprParser theExprParser(p.first);
+        std::string errorMsg;
+        bool ok = theExprParser.doParse(errorMsg);
+        BOOST_REQUIRE_MESSAGE(ok, errorMsg);
+
+        string expectedRootType       = p.second.first;
+        bool expectedEvaluationResult = p.second.second;
+
+        Ast* top = theExprParser.getAst();
+        BOOST_REQUIRE_MESSAGE(top, "No abstract syntax tree");
+        BOOST_REQUIRE_MESSAGE(top->left(), "No root created");
+        BOOST_REQUIRE_MESSAGE(top->left()->isRoot() || top->left()->is_attribute(),
+                              "First child of top should be a root or attribute " + p.first);
+        BOOST_REQUIRE_MESSAGE(top->left()->is_evaluateable(),
+                              "expected ast to be evaluatable. found: " << top->left()->type() << " " << p.first);
+        BOOST_REQUIRE_MESSAGE(top->left()->type() == expectedRootType || top->left()->type() == "variable",
+                              "expected root type " << expectedRootType << " or 'variable' but found "
+                                                    << top->left()->type() << " " << p.first);
+        {
+            std::stringstream ss;
+            top->print_flat(ss);
+            std::string print_flat = ss.str();
+            cout << print_flat << "\n";
+            BOOST_REQUIRE_MESSAGE(expectedEvaluationResult == top->evaluate(),
+                                  "evaluation not as expected for:\n"
+                                      << p.first << "\n"
+                                      << print_flat << "\n"
+                                      << *top);
+        }
+        {
+            std::stringstream ss;
+            top->print(ss);
+            cout << ss.str() << "\n";
+        }
+
+        std::string why;
+        top->why(why);
+        cout << "why: " << why << "\n";
+    }
+}
+
+// BOOST_AUTO_TEST_CASE( test_expression_read_from_file )
+//{
+//    std::cout <<  "ANode:: ...test_expression_read_from_file\n";
+//
+//    std::string filename = "${ECF_TEST_DEFS_DIR}/triggers.list";
+//    std::ifstream the_file(filename.c_str(),std::ios_base::in);
+//    BOOST_REQUIRE_MESSAGE(the_file,"file " << filename << "not found");
+//
+//    int  i = 0;
+//    string line;
+//    while ( std::getline(the_file,line) ) {
+//       i++;
+//       // cout << i << ": " << line << "\n";
+//       ExprParser theExprParser(line);
+//       std::string errorMsg;
+//       bool ok = theExprParser.doParse(errorMsg);
+//       BOOST_CHECK_MESSAGE(ok,errorMsg << " line: " << i );
+//
+//       if (ok) {
+//          Ast* top = theExprParser.getAst();
+//          BOOST_REQUIRE_MESSAGE( top ,"No abstract syntax tree " + line);
+//          BOOST_REQUIRE_MESSAGE( top->left() ,"No root created " + line);
+//          BOOST_REQUIRE_MESSAGE( top->left()->isRoot() || top->left()->is_attribute() ,"First child of top should be a
+//          root or variable " + line);
+//          //top->print_flat(ss);
+//       }
+//    }
+//
+//    ExprDuplicate reclaim_cloned_ast_memory;
+//    cout << " read " << i << " expressions\n";
+// }
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestSingleExprParse_main.cpp 5.13.0-1/libs/node/test/TestSingleExprParse_main.cpp
--- 5.12.4-1/libs/node/test/TestSingleExprParse_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestSingleExprParse_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_SingleExprParse
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/node/test/TestSpecificIssues.cpp 5.13.0-1/libs/node/test/TestSpecificIssues.cpp
--- 5.12.4-1/libs/node/test/TestSpecificIssues.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestSpecificIssues.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,314 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_SpecificIssues)
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_195) {
+    cout << "ANode:: ...test_ECFLOW_195 re-queue on task should retain label value\n";
+
+    defs_ptr defs = Defs::create();
+    suite_ptr s1  = defs->add_suite("s1");
+    family_ptr f1 = s1->add_family("f1");
+    task_ptr t1   = f1->add_task("t1");
+
+    s1->addLabel(Label("s1", "s1"));
+    f1->addLabel(Label("f1", "f1"));
+    t1->addLabel(Label("t1", "t1"));
+
+    defs->beginAll();
+
+    // Set the labels, with new values
+    s1->changeLabel("s1", "xx");
+    f1->changeLabel("f1", "xx");
+    t1->changeLabel("t1", "xx");
+
+    { // Check new values have not changed
+        Label s1_label = s1->find_label("s1");
+        BOOST_CHECK_MESSAGE(!s1_label.empty(), "expected to find label 's1'");
+        BOOST_CHECK_MESSAGE(s1_label.new_value() == "xx", "expected xx but found " << s1_label.new_value());
+
+        Label f1_label = f1->find_label("f1");
+        BOOST_CHECK_MESSAGE(!f1_label.empty(), "expected to find label 'f1'");
+        BOOST_CHECK_MESSAGE(f1_label.new_value() == "xx", "expected xx but found " << f1_label.new_value());
+
+        Label t1_label = t1->find_label("t1");
+        BOOST_CHECK_MESSAGE(!t1_label.empty(), "expected to find label 't1'");
+        BOOST_CHECK_MESSAGE(t1_label.new_value() == "xx", "expected xx but found " << t1_label.new_value());
+    }
+
+    // Now requee. the suite and family should be cleared and task label should remain.
+    defs->requeue();
+
+    { // Suite and Family labels should be reset, and task labels should retain their values
+        Label s1_label = s1->find_label("s1");
+        BOOST_CHECK_MESSAGE(!s1_label.empty(), "expected to find label 's1'");
+        BOOST_CHECK_MESSAGE(s1_label.new_value().empty(),
+                            "expected empty string for suite label value after re-queue, but found "
+                                << s1_label.new_value());
+
+        Label f1_label = f1->find_label("f1");
+        BOOST_CHECK_MESSAGE(!f1_label.empty(), "expected to find label 'f1'");
+        BOOST_CHECK_MESSAGE(f1_label.new_value().empty(),
+                            "expected empty string for family label value after re-queue, but found "
+                                << f1_label.new_value());
+
+        Label t1_label = t1->find_label("t1");
+        BOOST_CHECK_MESSAGE(!t1_label.empty(), "expected to find label 't1'");
+        BOOST_CHECK_MESSAGE(t1_label.new_value() == "xx",
+                            "Expected task label to remain unchanged after re-queue but found "
+                                << t1_label.new_value());
+    }
+
+    // After explicit re-queue expect new labels to be empty
+    s1->requeue_labels();
+    f1->requeue_labels();
+    t1->requeue_labels();
+    {
+        Label s1_label = s1->find_label("s1");
+        BOOST_CHECK_MESSAGE(!s1_label.empty(), "expected to find label 's1'");
+        BOOST_CHECK_MESSAGE(s1_label.new_value().empty(),
+                            "expected empty string for suite label value after explicit re-queue, but found "
+                                << s1_label.new_value());
+
+        Label f1_label = f1->find_label("f1");
+        BOOST_CHECK_MESSAGE(!f1_label.empty(), "expected to find label 'f1'");
+        BOOST_CHECK_MESSAGE(f1_label.new_value().empty(),
+                            "expected empty string for family label value after explicit re-queue, but found "
+                                << f1_label.new_value());
+
+        Label t1_label = t1->find_label("t1");
+        BOOST_CHECK_MESSAGE(!t1_label.empty(), "expected to find label 't1'");
+        BOOST_CHECK_MESSAGE(t1_label.new_value().empty(),
+                            "expected empty string for task label value after explicit re-queue, but found "
+                                << t1_label.new_value());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_247) {
+    cout << "ANode:: ...test_ECFLOW_247  \n";
+
+    defs_ptr defs = Defs::create();
+    suite_ptr s1  = defs->add_suite("s1");
+    family_ptr f1 = s1->add_family("f1");
+    f1->add_complete("f1/t1 == complete");
+    task_ptr t1 = f1->add_task("t1");
+    task_ptr t2 = f1->add_task("t2");
+    task_ptr t3 = f1->add_task("t3");
+    task_ptr t4 = f1->add_task("t4");
+
+    PrintStyle style(PrintStyle::MIGRATE);
+    {
+        defs->beginAll();
+        t1->set_state(NState::COMPLETE);
+        // cout << defs;
+
+        t4->set_state(NState::ABORTED);
+        t4->flag().set(ecf::Flag::FORCE_ABORT); // stopped bu user mimic, otherwise it be be queued
+
+        Jobs jobs(defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+        // cout << defs;
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ABORTED,
+                            "The complete for family should not evaluate if child is aborted");
+    }
+    {
+        defs->requeue();
+        t1->set_state(NState::COMPLETE);
+        // cout << defs;
+
+        t4->set_state(NState::ACTIVE);
+
+        Jobs jobs(defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        // cout << defs;
+        BOOST_CHECK_MESSAGE(f1->state() == NState::ACTIVE,
+                            "The complete for family should not evaluate if child is active");
+    }
+
+    {
+        defs->requeue();
+        t1->set_state(NState::COMPLETE);
+
+        Jobs jobs(defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        t4->set_state(NState::SUBMITTED);
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::SUBMITTED,
+                            "The complete for family should not evaluate if child is submitted");
+        // cout << defs;
+    }
+
+    {
+        defs->requeue();
+        t1->set_state(NState::COMPLETE);
+        // cout << defs;
+
+        Jobs jobs(defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        BOOST_CHECK_MESSAGE(f1->state() == NState::COMPLETE,
+                            "The complete for family should not evaluate if child is submitted");
+        // cout << defs;
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_417_real_clock) {
+    // Make sure reque resets calendar according to the clock attribute *FOR* a real clock
+    cout << "ANode:: ...test_ECFLOW_417_real_clock  \n";
+
+    defs_ptr defs = Defs::create();
+    suite_ptr s1  = defs->add_suite("s1");
+    s1->addRepeat(RepeatDay(1));
+    s1->addClock(ClockAttr(1, 10, 2015, false /*real clock*/));
+    task_ptr t1 = s1->add_task("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(16, 0), false));
+
+    defs->beginAll();
+
+    // ECF_DATE = year/month/day of month
+    {
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151001", "expected 20151001 but found " << ecf_date.theValue());
+    }
+
+    // now requeue and date should be reset
+    {
+        defs->requeue();
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151001", "expected 20151001 but found " << ecf_date.theValue());
+    }
+
+    // Now change the clock date to 10.10.2015.
+    {
+        s1->changeClockDate("10.10.2015");
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151010", "expected 20151010 but found " << ecf_date.theValue());
+    }
+
+    // now requeue
+    {
+        defs->requeue();
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151010", "expected 20151010 but found " << ecf_date.theValue());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_417_hybrid_clock) {
+    // ECFLOW-417
+    // For a suite with a hybrid clock *AND* repeat day. requue should update calendar date, by the repeat day interval
+    cout << "ANode:: ...test_ECFLOW_417_hybrid_clock  \n";
+
+    defs_ptr defs = Defs::create();
+    suite_ptr s1  = defs->add_suite("s1");
+    s1->addRepeat(RepeatDay(1));
+    s1->addClock(ClockAttr(1, 10, 2015, true /*hybrid*/));
+    task_ptr t1 = s1->add_task("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(16, 0), false));
+
+    defs->beginAll();
+
+    // ECF_DATE = year/month/day of month
+    {
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151001", "expected 20151001 but found " << ecf_date.theValue());
+    }
+
+    // now requeue and date should be incremented
+    {
+        defs->requeue();
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151002", "expected 20151002 but found " << ecf_date.theValue());
+    }
+
+    // now requeue again and date should be incremented
+    {
+        defs->requeue();
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151003", "expected 20151003 but found " << ecf_date.theValue());
+    }
+
+    // Now change the clock date to 10.10.2015. We expect date to decremented to 09.10.2015,
+    // Since user should always re-queue after changing suite clock attributes.
+    // This will get us back to the original date set by the user.
+    {
+        s1->changeClockDate("10.10.2015");
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151009", "expected 20151009 but found " << ecf_date.theValue());
+    }
+
+    // now requeue and date should be incremented
+    {
+        defs->requeue();
+        const Variable& ecf_date = s1->findGenVariable("ECF_DATE");
+        BOOST_CHECK_MESSAGE(!ecf_date.empty(), "Did not find ECF_DATE");
+        BOOST_CHECK_MESSAGE(ecf_date.theValue() == "20151010", "expected 20151010 but found " << ecf_date.theValue());
+    }
+
+    // Now update calendar for more than 24 hours, and calendar date should *NOT* change for hybrid
+    {
+        using namespace boost::posix_time;
+        using namespace boost::gregorian;
+
+        boost::posix_time::ptime time_now                 = s1->calendar().suiteTime();
+        boost::posix_time::time_duration serverPollPeriod = boost::posix_time::time_duration(0, 1, 0, 0);
+        std::string expectedDate                          = "2015-Oct-10";
+
+        for (int hour = 1; hour <= 60; hour++) {
+
+            // Update calendar every hour, for 60 hours
+            time_now += hours(1);
+            CalendarUpdateParams param(time_now, serverPollPeriod, true, /* serverRunning */ false /* forTest */);
+
+            defs->updateCalendar(param);
+
+            // cout << "hour = " << hour << " timeAfterUpdate " << to_simple_string(s1->calendar().suiteTime()) << "\n";
+
+            std::string actualDate = to_simple_string(s1->calendar().suiteTime().date());
+            BOOST_CHECK_MESSAGE(actualDate == expectedDate,
+                                "Expected '" << expectedDate << "' but found " << actualDate << " at hour " << hour);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestSystem.cpp 5.13.0-1/libs/node/test/TestSystem.cpp
--- 5.12.4-1/libs/node/test/TestSystem.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestSystem.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Signal.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_System)
+
+BOOST_AUTO_TEST_CASE(test_system) {
+    cout << "ANode:: ...test_system \n";
+
+    std::string file = "test_system.log";
+    std::string cmd  = "echo sat siri akal dunyia > " + file;
+
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(System::instance()->spawn(System::ECF_STATUS_CMD, cmd, "", errorMsg),
+                          "System::instance()->spawn() failed: " << errorMsg);
+    while (System::instance()->process() != 0) {
+        // Capture child process termination. Child sends SIGNAl SIGCHLD, caught by parent
+        Signal unblock_on_desctruction_then_reblock;
+        // sleep(1); // Need to wait for child termination()
+        System::instance()->processTerminatedChildren();
+    }
+
+    BOOST_CHECK_MESSAGE(fs::exists(file), "Expected cmd(" << cmd << ") to produce a file " << file);
+
+    fs::remove(file); // Remove the file. Comment out for debugging
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestSystemStandalone.cpp 5.13.0-1/libs/node/test/TestSystemStandalone.cpp
--- 5.12.4-1/libs/node/test/TestSystemStandalone.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestSystemStandalone.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+#include <stdexcept>
+#include <string>
+#include <unistd.h>
+
+#include "ecflow/node/Signal.hpp"
+#include "ecflow/node/System.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// leap42 boost_1_64_0 gcc-5.3.0 release mode
+//    time bin/gcc-5.3.0/release/perf_aparser_only ${ECF_TEST_DEFS_DIR}/vsms2.31415.def
+//    real    0m2.79s
+//    user    0m2.59s
+//    sys     0m0.18s
+
+int main(int argc, char* argv[]) {
+    cout << "argc = " << argc << "\n";
+    for (int i = 0; i < argc; i++) {
+        cout << "arg " << i << ":" << argv[i] << "\n";
+    }
+
+    if (argc != 2) {
+        cout << "Expect single argument \n";
+        return 1;
+    }
+
+    cout << "Invoke command: " << argv[1] << "\n";
+    std::string errorMsg;
+    if (!System::instance()->spawn(System::ECF_STATUS_CMD, argv[1], "", errorMsg)) {
+        throw std::runtime_error(errorMsg);
+    }
+
+    while (System::instance()->process() != 0) {
+        // cout << "no of System::instance()->process() " << System::instance()->process() << "\n";
+
+        // Capture child process termination. Child sends SIGNAl SIGCHLD, caught by parent
+        Signal unblock_on_desctruction_then_reblock;
+        sleep(1); // Need to wait for child termination()
+        System::instance()->processTerminatedChildren();
+    }
+
+    return 0;
+}
diff -pruN 5.12.4-1/libs/node/test/TestTaskScriptGenerator.cpp 5.13.0-1/libs/node/test/TestTaskScriptGenerator.cpp
--- 5.12.4-1/libs/node/test/TestTaskScriptGenerator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestTaskScriptGenerator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,247 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/EcfFile.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/JobCreationCtrl.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_TaskScriptGenerator)
+
+BOOST_AUTO_TEST_CASE(test_reset_after_job_generation_checking) {
+    cout << "ANode:: ...test_reset_after_job_generation_checking\n";
+    {
+        Defs defs   = Defs();
+        suite_ptr s = defs.add_suite("s");
+        task_ptr t  = s->add_task("t");
+        t->addTime(TimeAttr("+00:00 23:00 00:30"));
+
+        Defs defs_copy = Defs(defs);
+        BOOST_REQUIRE_MESSAGE(defs_copy == defs, "Expected defs to be equal");
+
+        // After check_job_creation, the defs SHOULD be reset. see ECFLOW-1203
+        job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
+        defs.check_job_creation(jobCtrl);
+        BOOST_REQUIRE_MESSAGE(!jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
+
+        DebugEquality debug_equality; // only as affect in DEBUG build
+        BOOST_REQUIRE_MESSAGE(defs_copy == defs, "reset failed - Expected defs to be equal");
+    }
+
+    {
+        // test reset with a full definition
+        MyDefsFixture theDefsFixture;
+        Defs copy = Defs(theDefsFixture.defsfile_);
+
+        BOOST_REQUIRE_MESSAGE(copy == theDefsFixture.defsfile_, "Expected defs to be equal");
+
+        // After check_job_creation, the defs SHOULD be reset. see ECFLOW-1203
+        job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
+        theDefsFixture.defsfile_.check_job_creation(jobCtrl);
+
+        DebugEquality debug_equality; // only as affect in DEBUG build
+        BOOST_REQUIRE_MESSAGE(copy == theDefsFixture.defsfile_, "reset failed - Expected defs to be equal");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_task_script_generator) {
+    cout << "ANode:: ...test_task_script_generator\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data/TaskScriptGenerator", "libs/node");
+
+    std::string head = ecf_home + "/head.h";
+    std::string tail = ecf_home + "/tail.h";
+    fs::remove_all(ecf_home);
+    BOOST_REQUIRE_MESSAGE(!fs::exists(head), "Remove of head file failed");
+    BOOST_REQUIRE_MESSAGE(!fs::exists(tail), "Remove of tail file failed");
+
+    // Create a defs file corresponding to:
+    // suite suite
+    // edit ECF_INCLUDE $ECF_HOME/includes
+    // edit SLEEP 10
+    // task t1
+    //    family f1
+    //       task t1
+    //       task t2
+    //    endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->add_variable(Str::ECF_INCLUDE(), ecf_home);
+        suite->add_variable(Str::ECF_HOME(), ecf_home);
+        suite->add_variable("SLEEP", "10");
+        task_ptr t1 = suite->add_task("t1");
+        t1->addEvent(Event("event1"));
+        t1->addEvent(Event("event2"));
+        t1->addEvent(Event("event4"));
+        t1->addMeter(Meter("meter1", 1, 100, 90));
+        t1->addMeter(Meter("meter2", 1, 100, 90));
+        t1->addLabel(Label("label", "label value"));
+        family_ptr fam = suite->add_family("f1");
+        fam->add_task("t1");
+        fam->add_task("t2");
+        //    cerr << theDefs << "\n";
+    }
+
+    /// generate the scripts and head.h and tail.h
+    theDefs.generate_scripts();
+
+    /// Test the ecf file were created, by doing job creation
+    /// JobCreationCtrl is used control what node we generate the jobs for:
+    /// Since we have not set the node on it, we force job generation for all tasks
+    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
+    theDefs.check_job_creation(jobCtrl);
+    BOOST_REQUIRE_MESSAGE(jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
+    BOOST_REQUIRE_MESSAGE(jobCtrl->fail_submittables().empty(), "Expected no failing tasks");
+
+    /// Additional sanity tests #######################################################
+
+    /// test that header and tail file were created
+    BOOST_REQUIRE_MESSAGE(fs::exists(head), "Head file " << head << " not created");
+    BOOST_REQUIRE_MESSAGE(fs::exists(tail), "Tail file " << tail << " not created");
+
+    // get all the task, assume non hierarchical families
+    std::vector<Task*> theTasks;
+    theDefs.getAllTasks(theTasks);
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the sms files
+    theDefs.beginAll();
+
+    // Test for ECF_ file location
+    for (Task* t : theTasks) {
+        try {
+            EcfFile ecf_file = t->locatedEcfFile();
+            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task ");
+        }
+        catch (std::exception& e) {
+            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task " << e.what());
+        }
+    }
+
+    // Remove the directories that were generated. This occasionally fails on ecgb and lxg ?
+    try {
+        fs::remove_all(ecf_home);
+    }
+    catch (const fs::filesystem_error& e) {
+        cout << "Could not remove directory " << ecf_home << " : " << e.what() << "\n";
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_task_script_generator_with_dummy_tasks) {
+    cout << "ANode:: ...test_task_script_generator_with_dummy_tasks\n";
+
+    // SET ECF_HOME
+    std::string ecf_home = File::test_data("libs/node/test/data/TaskScriptGenerator", "libs/node");
+
+    std::string head = ecf_home + "/head.h";
+    std::string tail = ecf_home + "/tail.h";
+    fs::remove_all(ecf_home);
+    BOOST_REQUIRE_MESSAGE(!fs::exists(head), "Remove of head file failed");
+    BOOST_REQUIRE_MESSAGE(!fs::exists(tail), "Remove of tail file failed");
+
+    // Create a defs file corresponding to:
+    // suite suite
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   edit ECF_HOME $ECF_HOME/includes
+    //   edit SLEEP 10
+    //   family f1
+    //       task t1
+    //       task t2
+    //   endfamily
+    //   family f2
+    //       edit ECF_DUMMY_TASK ''
+    //       task t1
+    //       task t2
+    //   endfamily
+    // endsuite
+    std::vector<task_ptr> tasks_with_scripts, tasks_without_scripts;
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->add_variable(Str::ECF_INCLUDE(), ecf_home);
+        suite->add_variable(Str::ECF_HOME(), ecf_home);
+        suite->add_variable("SLEEP", "10");
+        family_ptr f1 = suite->add_family("f1");
+        tasks_with_scripts.push_back(f1->add_task("t1"));
+        family_ptr f2 = suite->add_family("f2");
+        f2->add_variable("ECF_DUMMY_TASK", "");
+        tasks_without_scripts.push_back(f2->add_task("t1"));
+        tasks_without_scripts.push_back(f2->add_task("t2"));
+        //      cout << theDefs << "\n";
+    }
+
+    /// generate the scripts and head.h and tail.h
+    theDefs.generate_scripts();
+
+    /// Test the ecf file were created, by doing job creation
+    /// JobCreationCtrl is used control what node we generate the jobs for:
+    /// Since we have *NOT* set the node on it, we force job generation for all tasks
+    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
+    theDefs.check_job_creation(jobCtrl);
+    BOOST_REQUIRE_MESSAGE(jobCtrl->get_error_msg().empty(), jobCtrl->get_error_msg());
+    BOOST_REQUIRE_MESSAGE(jobCtrl->fail_submittables().empty(), "Expected no failing tasks");
+
+    /// Additional sanity tests #######################################################
+
+    /// test that header and tail file were created
+    BOOST_REQUIRE_MESSAGE(fs::exists(head), "Head file " << head << " not created");
+    BOOST_REQUIRE_MESSAGE(fs::exists(tail), "Tail file " << tail << " not created");
+
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files
+    theDefs.beginAll();
+
+    // Test for script generation
+    for (task_ptr t : tasks_with_scripts) {
+        try {
+            EcfFile ecf_file = t->locatedEcfFile();
+            BOOST_REQUIRE_MESSAGE(ecf_file.valid(), "Could not locate ecf file for task ");
+        }
+        catch (std::exception& e) {
+            BOOST_REQUIRE_MESSAGE(false, "Could not locate ecf file for task " << e.what());
+        }
+    }
+
+    // Test  that no scripts are generated when ECF_DUMMY_TASK is used
+    for (task_ptr t : tasks_without_scripts) {
+        BOOST_REQUIRE_THROW(t->locatedEcfFile(), std::runtime_error);
+    }
+
+    // Remove the directories that were generated. This occasionally fails on ecgb and lxg ?
+    try {
+        fs::remove_all(ecf_home);
+    }
+    catch (const fs::filesystem_error& e) {
+        cout << "Could not remove directory " << ecf_home << " : " << e.what() << "\n";
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestTimeDependencies.cpp 5.13.0-1/libs/node/test/TestTimeDependencies.cpp
--- 5.12.4-1/libs/node/test/TestTimeDependencies.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestTimeDependencies.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,479 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+using namespace boost::gregorian;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_TimeDependencies)
+
+// See ECFLOW-337
+// See ECFLOW-833. Also See Note: ACore/doc/TimeDependencies.ddoc
+
+BOOST_AUTO_TEST_CASE(test_day_time_combination) {
+    cout << "ANode:: ...test_day_time_combination\n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  clock real 7.6.2015  # sunday
+    //  task t1              # run task monday at 10, Day acts like a guard, time if ignored until day is free
+    //      day monday
+    //      time 10:00
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    task_ptr t1 = suite->add_task("t1");
+    t1->addDay(DayAttr(DayAttr::MONDAY));
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time =
+        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
+    // cout << "expected_time =  " << expected_time << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 120; m++) { // run for 5 days
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "submitted at " << suite->calendar().suiteTime() << "\n";
+            BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
+                                "\nExpected to submit at " << expected_time << " only, but also found "
+                                                           << suite->calendar().suiteTime());
+        }
+
+        defs.updateCalendar(calUpdateParams);
+        if (suite->calendar().dayChanged()) {
+            Node::Requeue_args args(Node::Requeue_args::TIME);
+            t1->requeue(args);
+        }
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged: " <<   suite->calendar().dayChanged()
+        // << "\n";
+    }
+    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_date_time_combination) {
+    cout << "ANode:: ...test_date_time_combination\n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  clock real 7.6.2015  # sunday
+    //  task t1              # run task monday at 10, Date acts like a guard, time if ignored until date is free
+    //      date 8.6.2015
+    //      time 10:00
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    task_ptr t1 = suite->add_task("t1");
+    t1->addDate(DateAttr(8, 6, 2015)); // Monday
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time =
+        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 100; m++) {
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "submitted at " << suite->calendar().suiteTime() << "\n";
+            BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
+                                "\nExpected to submit at " << expected_time << " only, but also found "
+                                                           << suite->calendar().suiteTime());
+        }
+
+        defs.updateCalendar(calUpdateParams);
+        if (suite->calendar().dayChanged()) {
+            Node::Requeue_args args;
+            t1->requeue(args);
+        }
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged: " <<   suite->calendar().dayChanged()
+        // << "\n";
+    }
+    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_day_time_combination_in_hierarchy) {
+    cout << "ANode:: ...test_day_time_combination_in_hierarchy\n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  clock real 7.6.2015 # sunday
+    //  family f1
+    //    day monday     # day attribute prevents time from being free
+    //    task t1
+    //      time 10:00   # should run ONCE, monday at 10:00
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    family_ptr f1 = suite->add_family("f1");
+    f1->addDay(DayAttr(DayAttr::MONDAY));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time =
+        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 120; m++) { // run for 5 days
+
+        // const std::vector<DayAttr>& days = f1->days();
+        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // " " << days[0].dump() << " " << times[0].dump() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n";
+
+            // 1st Run: Monday at 10:00 am
+            if (submitted == 1)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
+                                    "\nExpected to submit at " << expected_time << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            Node::Requeue_args args;
+            f1->requeue(args);
+            // cout << "   requeue f1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n";
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_time_day_combination_in_hierarchy) {
+    cout << "ANode:: ...test_time_day_combination_in_hierarchy\n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  clock real 7.6.2015 # sunday
+    //  family f1
+    //    time 10:00
+    //    task t1      # task should run *TWICE*, Monday morning @00:00 and, at 10:00
+    //      day monday
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    family_ptr f1 = suite->add_family("f1");
+    f1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addDay(DayAttr(DayAttr::MONDAY));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time1 =
+        boost::posix_time::ptime(date(2015, 6, 8), time_duration(0, 0, 0)); // Monday & 00:00
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 120; m++) { // run for 5 days
+        // const std::vector<DayAttr>& days = t1->days();
+        // const std::vector<ecf::TimeAttr>& times = f1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // " " << days[0].dump() << " " << times[0].dump() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "   submitted at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n";
+
+            // 1st Run: Monday at 00:00 am
+            if (submitted == 1)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
+                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            Node::Requeue_args args;
+            f1->requeue(args);
+            // cout << "   requeue f1 at " << suite->calendar().suiteTime() << " " << days[0].dump() << " " <<
+            // times[0].dump() << "\n";
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 2, "Expected two submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_date_time_combination_in_hierarchy) {
+    cout << "ANode:: ...test_date_time_combination_in_hierarchy\n";
+
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  clock real 7.6.2015 # sunday
+    //  family f1
+    //    date 8.6.15  # monday date now guards the time
+    //    task t1
+    //      time 10:00
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    family_ptr f1 = suite->add_family("f1");
+    f1->addDate(DateAttr(8, 6, 2015)); // Monday
+    task_ptr t1 = f1->add_task("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time =
+        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 100; m++) {
+
+        // const std::vector<DateAttr>& dates = f1->dates();
+        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // " " << dates[0].dump() << " " << times[0].dump() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "  submitted at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
+            // times[0].dump() << "\n";
+
+            // New to ecflow 5.0, parent date will guard the time. i.e will not let time be free until date is
+            // satisfied.
+            if (submitted == 1)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time,
+                                    "\nExpected to submit at " << expected_time << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            Node::Requeue_args args;
+            f1->requeue(args);
+            // cout << "  requeue at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
+            // times[0].dump() << "\n";
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 1, "Expected one submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_time_date_combination_in_hierarchy) {
+    cout << "ANode:: ...test_time_date_combination_in_hierarchy \n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  clock real 7.6.2015 # sunday
+    //  family f1
+    //    time 10:00
+    //    task t1
+    //       date 8.6.15  # monday, run once at Monday morning, and gain Monday at 10:00
+    //
+    Defs defs;
+    suite_ptr suite                   = defs.add_suite("s1");
+    boost::posix_time::ptime the_time = boost::posix_time::ptime(date(2015, 6, 7), time_duration(0, 0, 0)); // sunday
+    suite->addClock(ClockAttr(the_time));
+    family_ptr f1 = suite->add_family("f1");
+    f1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addDate(DateAttr(8, 6, 2015)); // Monday
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    boost::posix_time::ptime expected_time1 =
+        boost::posix_time::ptime(date(2015, 6, 8), time_duration(0, 0, 0)); // Monday & 00:00
+    boost::posix_time::ptime expected_time2 =
+        boost::posix_time::ptime(date(2015, 6, 8), time_duration(10, 0, 0)); // Monday & 10
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 100; m++) {
+
+        // const std::vector<DateAttr>& dates = t1->dates();
+        // const std::vector<ecf::TimeAttr>& times = f1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // " " << dates[0].dump() << " " << times[0].dump() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << "  submitted at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
+            // times[0].dump() << "\n";
+
+            // 1st Run: MONDAY Morning 00:00 time was free from sunday
+            if (submitted == 1)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time1,
+                                    "\nExpected to submit at " << expected_time1 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            // 2nd Run: Monday at 10:00
+            if (submitted == 2)
+                BOOST_CHECK_MESSAGE(suite->calendar().suiteTime() == expected_time2,
+                                    "\nExpected to submit at " << expected_time2 << " only, but also found "
+                                                               << suite->calendar().suiteTime());
+
+            Node::Requeue_args args;
+            f1->requeue(args);
+            // cout << "  requeue at " << suite->calendar().suiteTime() << " " << dates[0].dump() << " " <<
+            // times[0].dump() << "\n";
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 2, "Expected two submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_impossible_day_combination) {
+    cout << "ANode:: ...test_impossible_day_combination\n";
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  clock real 4.8.2019 # sunday
+    //  family f1
+    //    day monday
+    //    task t1        # task should never run, can't be Sunday/Monday at same time.
+    //      day tuesday
+    //      time 10:00
+    Defs defs;
+    suite_ptr suite = defs.add_suite("s1");
+    suite->addClock(ClockAttr(boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)))); // sunday
+    family_ptr f1 = suite->add_family("f1");
+    f1->addDay(DayAttr(DayAttr::MONDAY));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    t1->addDay(DayAttr(DayAttr::TUESDAY));
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 100; m++) {
+        // const std::vector<DateAttr>& fdates = f1->dates();
+        // const std::vector<DateAttr>& dates = t1->dates();
+        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // "\n   "
+        //          << fdates[0].dump() << " " << dates[0].dump() << " " << times[0].dump() << " rep: " <<
+        //          f1->repeat().value() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << " submitted " << suite->calendar().suiteTime() << " dayChanged:" <<
+            // suite->calendar().dayChanged() << "\n   "
+            //          << fdates[0].dump() << " " << dates[0].dump() << " " << times[0].dump() << " rep: " <<
+            //          f1->repeat().value() << "\n";
+            Node::Requeue_args args;
+            t1->requeue(args);
+        }
+
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 0, "Expected zero submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_CASE(test_impossible_date_combination) {
+    cout << "ANode:: ...test_impossible_date_combination\n";
+
+    // Create the suite, starting on a sunday
+    // suite s1
+    //  family f1
+    //    date 5.8.2019   # monday
+    //    task t1         # task should never run, can't be Sunday/Monday at same time.
+    //      date 6.8.2019 # tuesday
+    //      time 10:00
+    Defs defs;
+    suite_ptr suite = defs.add_suite("s1");
+    suite->addClock(ClockAttr(boost::posix_time::ptime(date(2019, 8, 4), time_duration(0, 0, 0)))); // sunday
+    family_ptr f1 = suite->add_family("f1");
+    f1->addDate(DateAttr(5, 8, 2019)); // Monday
+    task_ptr t1 = f1->add_task("t1");
+    t1->addTime(ecf::TimeAttr(ecf::TimeSlot(10, 0)));
+    t1->addDate(DateAttr(6, 8, 2019)); // Tuesday
+    defs.beginAll();
+
+    CalendarUpdateParams calUpdateParams(hours(1));
+    // cout << defs << "\n";
+
+    int submitted = 0;
+    for (int m = 1; m < 100; m++) {
+        // const std::vector<DayAttr>& fdays = f1->days();
+        // const std::vector<DayAttr>& days = t1->days();
+        // const std::vector<ecf::TimeAttr>& times = t1->timeVec();
+        // cout << "Suite time " << suite->calendar().suiteTime() << " dayChanged:" << suite->calendar().dayChanged() <<
+        // "\n   "
+        //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
+        //          f1->repeat().value() << "\n";
+
+        Jobs jobs(&defs);
+        JobsParam jobsParam;
+        jobs.generate(jobsParam);
+
+        if (jobsParam.submitted().size()) {
+            submitted++;
+            // cout << " submitted at " << suite->calendar().suiteTime() << " dayChanged:" <<
+            // suite->calendar().dayChanged() << "\n   "
+            //          << fdays[0].dump() << " " << days[0].dump() << " " << times[0].dump() << " rep: " <<
+            //          f1->repeat().value() << "\n";
+            Node::Requeue_args args;
+            t1->requeue(args);
+        }
+        defs.updateCalendar(calUpdateParams);
+    }
+    BOOST_CHECK_MESSAGE(submitted == 0, "Expected zero submission but found " << submitted);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestVariableGeneration.cpp 5.13.0-1/libs/node/test/TestVariableGeneration.cpp
--- 5.12.4-1/libs/node/test/TestVariableGeneration.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestVariableGeneration.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,109 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Cal.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_VariableGeneration)
+
+static void findParentVariableValue(task_ptr t, const std::string& name, const std::string& expected) {
+    std::string value;
+    BOOST_CHECK_MESSAGE(t->findParentVariableValue(name, value),
+                        "Task " << t->debugNodePath() << " could not find variable of name " << name);
+    //   if (expected.empty()) std::cout << name  << " = " << value << "\n";
+    if (!expected.empty())
+        BOOST_CHECK_MESSAGE(value == expected,
+                            "From task " << t->debugNodePath() << " for variable " << name << " expected value "
+                                         << expected << " but found " << value);
+}
+
+BOOST_AUTO_TEST_CASE(test_generated_variables) {
+    std::cout << "ANode:: ...test_generated_variables\n";
+
+    task_ptr t;
+
+    Defs defs;
+    {
+
+        suite_ptr suite = defs.add_suite("suite");
+        suite->addRepeat(RepeatInteger("RepeatInteger", 10, 20, 1));
+
+        family_ptr fam = suite->add_family("f");
+        fam->addRepeat(RepeatDate("YMD", 20090101, 20091231, 1));
+
+        t = fam->add_family("f2")->add_task("t");
+        std::vector<std::string> stringList;
+        stringList.reserve(3);
+        stringList.emplace_back("AA");
+        stringList.emplace_back("BB");
+        stringList.emplace_back("CC");
+        t->addRepeat(RepeatEnumerated("AEnum", stringList));
+    }
+
+    // Generate variables, needed since,findParentVariableValue also serach's the generated variables
+    defs.beginAll();
+
+    // Check Submittable generated variables
+    findParentVariableValue(t, "TASK", "t");
+    findParentVariableValue(t, Str::ECF_RID(), "");
+    findParentVariableValue(t, Str::ECF_TRYNO(), "0");
+    findParentVariableValue(t, Str::ECF_NAME(), "/suite/f/f2/t");
+    findParentVariableValue(t, Str::ECF_PASS(), "");
+    findParentVariableValue(t, Str::ECF_JOB(), "./suite/f/f2/t.job0");
+    findParentVariableValue(t, Str::ECF_JOBOUT(), "./suite/f/f2/t.0");
+    findParentVariableValue(t, Str::ECF_SCRIPT(), "./suite/f/f2/t.ecf");
+
+    // Check Family generated variables
+    findParentVariableValue(t, "FAMILY", "f/f2");
+    findParentVariableValue(t, "FAMILY1", "f2");
+
+    // Check Suite generated variables
+    findParentVariableValue(t, "SUITE", "suite");
+    findParentVariableValue(t, "YYYY", "");
+    findParentVariableValue(t, "DOW", "");
+    findParentVariableValue(t, "DOY", "");
+    findParentVariableValue(t, "DATE", "");
+    findParentVariableValue(t, "DAY", "");
+    findParentVariableValue(t, "DD", "");
+    findParentVariableValue(t, "MM", "");
+    findParentVariableValue(t, "MONTH", "");
+    findParentVariableValue(t, "ECF_DATE", "");
+    findParentVariableValue(t, "ECF_CLOCK", "");
+    findParentVariableValue(t, "ECF_TIME", "");
+    findParentVariableValue(t, "ECF_JULIAN", "");
+
+    // Test repeat generated variables
+    findParentVariableValue(t, "AEnum", "AA");
+    findParentVariableValue(t, "YMD", "20090101");
+    findParentVariableValue(t, "YMD_YYYY", "2009");
+    findParentVariableValue(t, "YMD_MM", "1");
+    findParentVariableValue(t, "YMD_DD", "1");
+    findParentVariableValue(t, "YMD_DOW", "4");
+    findParentVariableValue(t, "YMD_JULIAN", ecf::convert_to<std::string>(Cal::date_to_julian(20090101)));
+    findParentVariableValue(t, "RepeatInteger", "10");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestVariableInheritance.cpp 5.13.0-1/libs/node/test/TestVariableInheritance.cpp
--- 5.12.4-1/libs/node/test/TestVariableInheritance.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestVariableInheritance.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,80 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_VariableInheritance)
+
+static void findParentVariableValue(task_ptr t, const std::string& name, const std::string& expected) {
+    std::string value;
+    BOOST_CHECK_MESSAGE(t->findParentVariableValue(name, value),
+                        "Task " << t->debugNodePath() << " could not find variable of name " << name);
+    BOOST_CHECK_MESSAGE(value == expected,
+                        "From task " << t->debugNodePath() << " for variable " << name << " expected value " << expected
+                                     << " but found " << value);
+}
+
+BOOST_AUTO_TEST_CASE(test_variable_inheritance) {
+    std::cout << "ANode:: ...test_variable_inheritance\n";
+
+    // See page 31, section 5.1 variable inheritance, of SMS users guide
+    task_ptr t;
+    task_ptr t2;
+    task_ptr z;
+
+    Defs defs;
+    {
+        suite_ptr suite = defs.add_suite("suite");
+        suite->addVariable(Variable("TOPLEVEL", "10"));
+        suite->addVariable(Variable("MIDDLE", "10"));
+        suite->addVariable(Variable("LOWER", "10"));
+
+        family_ptr fam = suite->add_family("f");
+        fam->addVariable(Variable("MIDDLE", "20"));
+        t = fam->add_task("t");
+        t->addVariable(Variable("LOWER", "abc"));
+        t2 = fam->add_task("t2");
+
+        family_ptr fam2 = suite->add_family("f2");
+        fam2->addVariable(Variable("TOPLEVEL", "40"));
+        z = fam2->add_task("z");
+    }
+
+    // Generate variables, needed since,findParentVariableValue also serach's the generated variables
+    defs.beginAll();
+
+    // See page 31, section 5.1 variable inheritance, of SMS users guide
+    findParentVariableValue(t, "TOPLEVEL", "10");
+    findParentVariableValue(t2, "TOPLEVEL", "10");
+    findParentVariableValue(z, "TOPLEVEL", "40");
+
+    findParentVariableValue(t, "MIDDLE", "20");
+    findParentVariableValue(t2, "MIDDLE", "20");
+    findParentVariableValue(z, "MIDDLE", "10");
+
+    findParentVariableValue(t, "LOWER", "abc");
+    findParentVariableValue(t2, "LOWER", "10");
+    findParentVariableValue(z, "LOWER", "10");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestVariableSubstitution.cpp 5.13.0-1/libs/node/test/TestVariableSubstitution.cpp
--- 5.12.4-1/libs/node/test/TestVariableSubstitution.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestVariableSubstitution.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,494 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_VariableSubstitution)
+
+BOOST_AUTO_TEST_CASE(test_variable_substitution) {
+    std::cout << "ANode:: ...test_variable_substitution\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    {
+        s->addVariable(Variable("AVI", "avi"));
+        s->addVariable(Variable("BAHRA", "bahra"));
+        s->addVariable(Variable("LOWER", "10"));
+        s->addVariable(Variable("PATH", "/fred/bill/joe"));
+        s->addVariable(Variable("EMPTY_VARIABLE", ""));
+        s->addVariable(Variable("fred", "%bill%"));
+        s->addVariable(Variable("bill", "%fred%"));
+        s->addVariable(Variable("hello", "%hello%"));
+        s->addVariable(Variable("mary", "%jane%"));
+        s->addVariable(Variable("jane", "10"));
+    }
+
+    // See page 31, section 5.1 variable inheritance, of SMS users guide
+    std::string cmd = "%AVI%-%BAHRA%-%LOWER%-%AVI%";
+    string expected = "avi-bahra-10-avi";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%ECF_VERSION%";
+    expected = Version::raw();
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH%";
+    expected = "/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "/%AVI%/%BAHRA%/%LOWER%%PATH%";
+    expected = "/avi/bahra/10/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%EMPTY_VARIABLE%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%mary%";
+    expected = "10"; // double substitution
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%fred%";
+    expected = "%fred%"; // infinite substitution
+    BOOST_CHECK_MESSAGE(!s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%hello%";
+    expected = "%hello%"; // infinite substitution
+    BOOST_CHECK_MESSAGE(!s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = Ecf::MICRO();
+    expected = Ecf::MICRO();
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH";
+    expected = "%PATH";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%";
+    expected = "%";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%ERROR%";
+    expected = "%ERROR%";
+    BOOST_CHECK_MESSAGE(!s->variableSubstitution(cmd), " substitution expected to fail since ERROR does not exist");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    // new rules
+    // %<VAR>:substitute %
+    // If we find VAR, then use it, else use substitute
+    cmd      = "%AVI:goblly gook%";
+    expected = "avi";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH:goblly::: gook%";
+    expected = "/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%LOWER:fred% %AVI:fred2%";
+    expected = "10 avi";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%LOWER:fred% %AVI:fred2";
+    expected = "10 %AVI:fred2";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%EMPTY_VARIABLE::goblly gook%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL:goblly gook%";
+    expected = "goblly gook";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL::goblly gook%";
+    expected = ":goblly gook";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL:%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%:%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+}
+
+BOOST_AUTO_TEST_CASE(test_variable_substitution_double_micro) {
+    std::cout << "ANode:: ...test_variable_substitution_double_micro\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+
+    std::string cmd      = "%%";
+    std::string expected = "%";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%%";
+    expected = "%%";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%%%";
+    expected = "%%";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%%%%";
+    expected = "%%%";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "date +%%Y.%%m.%%d";
+    expected = "date +%Y.%m.%d";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "printf %%02d %HOUR:00%";
+    expected = "printf %02d 00";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    s->addVariable(Variable("HOUR", "hammer time"));
+    cmd      = "printf %%02d %HOUR:00%";
+    expected = "printf %02d hammer time";
+    BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+}
+
+BOOST_AUTO_TEST_CASE(test_user_variable_substitution) {
+    std::cout << "ANode:: ...test_user_variable_substitution\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    {
+        s->addVariable(Variable("AVI", "avi"));
+        s->addVariable(Variable("BAHRA", "bahra"));
+        s->addVariable(Variable("LOWER", "10"));
+        s->addVariable(Variable("PATH", "/fred/bill/joe"));
+        s->addVariable(Variable("EMPTY_VARIABLE", ""));
+        s->addVariable(Variable("fred", "%bill%"));
+        s->addVariable(Variable("bill", "%fred%"));
+        s->addVariable(Variable("hello", "%hello%"));
+        s->addVariable(Variable("mary", "%jane%"));
+        s->addVariable(Variable("jane", "10"));
+    }
+
+    NameValueMap user_variables;
+    user_variables.insert(std::make_pair(string("AVI"), string("_avi")));
+    user_variables.insert(std::make_pair(string("BAHRA"), string("_bahra")));
+    user_variables.insert(std::make_pair(string("LOWER"), string("_10")));
+    user_variables.insert(std::make_pair(string("PATH"), string("_/fred/bill/joe")));
+    user_variables.insert(std::make_pair(string("EMPTY_VARIABLE"), string("_")));
+    user_variables.insert(std::make_pair(string("fred"), string("%bill%")));
+    user_variables.insert(std::make_pair(string("bill"), string("%fred%")));
+    user_variables.insert(std::make_pair(string("hello"), string("%hello%")));
+    user_variables.insert(std::make_pair(string("mary"), string("%jane%")));
+    user_variables.insert(std::make_pair(string("jane"), string("_10")));
+
+    // See page 31, section 5.1 variable inheritance, of SMS users guide
+    std::string cmd = "%AVI%-%BAHRA%-%LOWER%-%AVI%";
+    string expected = "_avi-_bahra-_10-_avi";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH%";
+    expected = "_/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "/%AVI%/%BAHRA%/%LOWER%%PATH%";
+    expected = "/_avi/_bahra/_10_/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%EMPTY_VARIABLE%";
+    expected = "_";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%mary%";
+    expected = "_10"; // double substitution
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%fred%";
+    expected = "%fred%"; // infinite substitution
+    BOOST_CHECK_MESSAGE(!s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%hello%";
+    expected = "%hello%"; // infinite substitution
+    BOOST_CHECK_MESSAGE(!s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = Ecf::MICRO();
+    expected = Ecf::MICRO();
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH";
+    expected = "%PATH";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%";
+    expected = "%";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%ERROR%";
+    expected = "%ERROR%";
+    BOOST_CHECK_MESSAGE(!s->variable_substitution(cmd, user_variables),
+                        " substitution expected to fail since ERROR does not exist");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    // new rules
+    // %<VAR>:substitute %
+    // If we find VAR, then use it, else use substitute
+    cmd      = "%AVI:goblly gook%";
+    expected = "_avi";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH:goblly::: gook%";
+    expected = "_/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%LOWER:fred% %AVI:fred2%";
+    expected = "_10 _avi";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%LOWER:fred% %AVI:fred2";
+    expected = "_10 %AVI:fred2";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%EMPTY_VARIABLE::goblly gook%";
+    expected = "_";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL:goblly gook%";
+    expected = "goblly gook";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL::goblly gook%";
+    expected = ":goblly gook";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL:%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%:%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+}
+
+BOOST_AUTO_TEST_CASE(test_user_variable_substitution_1) {
+    std::cout << "ANode:: ...test_user_variable_substitution_1\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    s->addVariable(Variable("AVI", "avi"));
+
+    NameValueMap user_variables;
+    user_variables.insert(std::make_pair(string("AVI:goblly gook"), string("avtar")));
+
+    // new rules
+    // %<VAR>:substitute %
+    // If we find VAR, then use it, else use substitute
+    // However when we have user_variables if we find the complete string
+    // in the user variable list, we use user veriable value:
+    // cmd = %FRED:BILL%"   and   user_variable = "FRED:BILL","Joe90"   ===> cmd = "Joe90"
+    std::string cmd      = "%AVI:goblly gook%";
+    std::string expected = "avtar";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%AVI:goblly%";
+    expected = "avi";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%FRED:goblly%";
+    expected = "goblly";
+    BOOST_CHECK_MESSAGE(s->variable_substitution(cmd, user_variables), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+}
+
+static std::vector<std::string> required_server_variables() {
+    std::vector<std::string> required_server_variables;
+    required_server_variables.push_back(Str::ECF_PORT());
+    required_server_variables.push_back(Str::ECF_HOST());
+
+    required_server_variables.push_back(Str::ECF_HOME());
+    required_server_variables.emplace_back("ECF_LOG");
+    required_server_variables.emplace_back("ECF_CHECK");
+    required_server_variables.emplace_back("ECF_CHECKOLD");
+
+    // These variable are read in from the environment, but are not exposed
+    // since they only affect the server
+    // ECF_CHECKINTERVAL
+    // ECF_LISTS
+
+    // variables that can be overridden, in the suite definition
+    required_server_variables.emplace_back("ECF_JOB_CMD");
+    required_server_variables.emplace_back("ECF_KILL_CMD");
+    required_server_variables.emplace_back("ECF_STATUS_CMD");
+    required_server_variables.emplace_back("ECF_URL_CMD");
+    required_server_variables.emplace_back("ECF_URL_BASE");
+    required_server_variables.emplace_back("ECF_URL");
+    required_server_variables.emplace_back("ECF_MICRO");
+
+    // Reference variable, these should be read only
+    required_server_variables.emplace_back("ECF_PID");     // server PID
+    required_server_variables.emplace_back("ECF_VERSION"); // server version
+    return required_server_variables;
+}
+
+BOOST_AUTO_TEST_CASE(test_server_variable_substitution) {
+    std::cout << "ANode:: ...test_server_variable_substitution\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+
+    std::vector<std::string> vec = required_server_variables();
+    for (const auto& i : vec) {
+        if (i == "ECF_PID")
+            continue; // CANT test since, this is process ID of server
+        std::string value;
+        BOOST_CHECK_MESSAGE(s->findParentVariableValue(i, value), "Could not find Server variable " << i);
+        BOOST_CHECK_MESSAGE(!value.empty(), "Empty server variable value for " << i);
+    }
+
+    for (const auto& i : vec) {
+        if (i == "ECF_JOB_CMD")
+            continue; // CANT test since it requires %ECF_JOB% and %ECF_JOBOUT%
+        if (i == "ECF_KILL_CMD")
+            continue; // CANT test since it requires %ECF_PID%
+        if (i == "ECF_STATUS_CMD")
+            continue; // CANT test since it requires %ECF_RID%
+        if (i == "ECF_PID")
+            continue; // CANT test since, this is process ID of server
+        std::string cmd = "%";
+        cmd += i;
+        cmd += "%";
+        BOOST_CHECK_MESSAGE(s->variableSubstitution(cmd), " substitution failed for " << i << " : " << cmd);
+        if (i == "ECF_VERSION") {
+            BOOST_CHECK_MESSAGE(cmd == Version::raw(), "expected '" << Version::raw() << "' but found '" << cmd << "'");
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_generated_variable_substitution) {
+    // test that if ECF_OUT is defined using %, then we perform variable substitution
+    // test that if ECF_JOBOUT or ECF_JOB are specified, they take priority over the generated variables
+    std::cout << "ANode:: ...test_generated_variable_substitution\n";
+
+    Defs defs;
+    suite_ptr s = defs.add_suite("suite");
+    s->addVariable(Variable("PATH", "/fred/bill/joe"));
+    s->addVariable(Variable("ECF_HOME", "/ecf_home"));
+    family_ptr f = s->add_family("f");
+    task_ptr t   = f->add_task("t");
+    t->addVariable(Variable("ECF_OUT", "%PATH%"));
+    family_ptr f1 = s->add_family("f1");
+    f1->addVariable(Variable("PATH2", "/fred/bill/joe2"));
+    task_ptr t1 = f1->add_task("t1");
+    t1->addVariable(Variable("ECF_OUT", "%PATH2%"));
+    task_ptr t2 = f1->add_task("t2");
+    t2->addVariable(Variable("ECF_JOBOUT", "ECFLOW-999"));
+    t2->addVariable(Variable("ECF_JOB", "ECFLOW-999"));
+
+    // begin_all
+    defs.beginAll();
+    t->update_generated_variables();
+    t1->update_generated_variables();
+    t2->update_generated_variables();
+
+    // cout << defs;
+
+    string value;
+    value.clear();
+    t->findParentVariableValue(Str::ECF_JOBOUT(), value);
+    BOOST_CHECK_MESSAGE(value == "/fred/bill/joe/suite/f/t.0",
+                        "ECF_JOBOUT expected /fred/bill/joe/suite/f/t.0, but found " << value);
+
+    value.clear();
+    t1->findParentVariableValue(Str::ECF_JOBOUT(), value);
+    BOOST_CHECK_MESSAGE(value == "/fred/bill/joe2/suite/f1/t1.0",
+                        "ECF_JOBOUT expected /fred/bill/joe/suite/f/t.0, but found " << value);
+
+    // ECFLOW-999  make sure that if ECF_JOBOUT or ECF_JOB are overridden, they take priority over
+    // the generated variables of the same name
+    std::string cmd = Ecf::JOB_CMD();
+    BOOST_CHECK_MESSAGE(t2->variableSubstitution(cmd), " variableSubstitution failed for " << Ecf::JOB_CMD());
+
+    std::string expected = "ECFLOW-999 1> ECFLOW-999 2>&1";
+    BOOST_CHECK_MESSAGE(cmd == expected, "variable substitution failed expected " << expected << " but found " << cmd);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestVariableSubstitutionDefs.cpp 5.13.0-1/libs/node/test/TestVariableSubstitutionDefs.cpp
--- 5.12.4-1/libs/node/test/TestVariableSubstitutionDefs.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestVariableSubstitutionDefs.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,194 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_VariableSubstitutionDefs)
+
+BOOST_AUTO_TEST_CASE(test_defs_variable_substitution) {
+    std::cout << "ANode:: ...test_defs_variable_substitution\n";
+
+    Defs defs;
+    {
+        std::vector<Variable> vec;
+        vec.emplace_back("AVI", "avi");
+        vec.emplace_back("BAHRA", "bahra");
+        vec.emplace_back("LOWER", "10");
+        vec.emplace_back("PATH", "/fred/bill/joe");
+        vec.emplace_back("fred", "%bill%");
+        vec.emplace_back("bill", "%fred%");
+        vec.emplace_back("hello", "%hello%");
+        vec.emplace_back("mary", "%jane%");
+        vec.emplace_back("jane", "10");
+        defs.set_server().add_or_update_user_variables(vec);
+    }
+
+    // See page 31, section 5.1 variable inheritance, of SMS users guide
+    std::string cmd = "%AVI%-%BAHRA%-%LOWER%-%AVI%";
+    string expected = "avi-bahra-10-avi";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%ECF_VERSION%";
+    expected = Version::raw();
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH%";
+    expected = "/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "/%AVI%/%BAHRA%/%LOWER%%PATH%";
+    expected = "/avi/bahra/10/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%mary%";
+    expected = "10"; // double substitution
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%fred%";
+    expected = "%fred%"; // infinite substitution
+    BOOST_CHECK_MESSAGE(!defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%hello%";
+    expected = "%hello%"; // infinite substitution
+    BOOST_CHECK_MESSAGE(!defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = Ecf::MICRO();
+    expected = Ecf::MICRO();
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH";
+    expected = "%PATH";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%";
+    expected = "%";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%ERROR%";
+    expected = "%ERROR%";
+    BOOST_CHECK_MESSAGE(!defs.variableSubsitution(cmd), " substitution expected to fail since ERROR does not exist");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "";
+    expected = "";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    // new rules
+    // %<VAR>:substitute %
+    // If we find VAR, then use it, else use substitute
+    cmd      = "%AVI:goblly gook%";
+    expected = "avi";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%PATH:goblly::: gook%";
+    expected = "/fred/bill/joe";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%LOWER:fred% %AVI:fred2%";
+    expected = "10 avi";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%LOWER:fred% %AVI:fred2";
+    expected = "10 %AVI:fred2";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL:goblly gook%";
+    expected = "goblly gook";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL::goblly gook%";
+    expected = ":goblly gook";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%NULL:%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%:%";
+    expected = "";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed ");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+}
+
+BOOST_AUTO_TEST_CASE(test_defs_variable_substitution_double_micro) {
+    std::cout << "ANode:: ...test_defs_variable_substitution_double_micro\n";
+
+    Defs defs;
+
+    std::string cmd      = "%%";
+    std::string expected = "%";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%%";
+    expected = "%%";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%%%";
+    expected = "%%";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "%%%%%";
+    expected = "%%%";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), " substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "date +%%Y.%%m.%%d";
+    expected = "date +%Y.%m.%d";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    cmd      = "printf %%02d %HOUR:00%";
+    expected = "printf %02d 00";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+
+    defs.set_server().add_or_update_user_variables("HOUR", "hammer time");
+    cmd      = "printf %%02d %HOUR:00%";
+    expected = "printf %02d hammer time";
+    BOOST_CHECK_MESSAGE(defs.variableSubsitution(cmd), "substitution failed");
+    BOOST_CHECK_MESSAGE(cmd == expected, "expected '" << expected << "' but found '" << cmd << "'");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/TestZombies.cpp 5.13.0-1/libs/node/test/TestZombies.cpp
--- 5.12.4-1/libs/node/test/TestZombies.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/TestZombies.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Node)
+
+BOOST_AUTO_TEST_SUITE(T_Zombies)
+
+BOOST_AUTO_TEST_CASE(test_zombies) {
+    cout << "ANode:: ...test_zombies\n";
+    Defs theDefs;
+    suite_ptr s = theDefs.add_suite("s");
+    task_ptr t  = s->add_family("f")->add_task("t");
+
+    // SANITY
+    {
+        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 0, "Expected 0 zombies but found " << s->zombies().size());
+        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::USER).empty(), "Expected no zombies");
+        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF).empty(), "Expected no zombies");
+        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF_PID).empty(), "Expected no zombies");
+        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF_PASSWD).empty(), "Expected no zombies");
+        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::ECF_PID_PASSWD).empty(), "Expected no zombies");
+        BOOST_REQUIRE_MESSAGE(s->findZombie(ecf::Child::PATH).empty(), "Expected no zombies");
+        ZombieAttr attr;
+        BOOST_REQUIRE_MESSAGE(!t->findParentZombie(ecf::Child::PATH, attr) && attr.empty(),
+                              "Expected to NOT find PATH zombies on parent");
+    }
+
+    // ADD
+    std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
+    {
+        s->addZombie(ZombieAttr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10));
+        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 1, "Expected 1 zombie but found " << s->zombies().size());
+        s->addZombie(ZombieAttr(ecf::Child::ECF, child_cmds, ecf::User::FAIL, 100));
+        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 2, "Expected 2 zombie but found " << s->zombies().size());
+        s->addZombie(ZombieAttr(ecf::Child::ECF_PID, child_cmds, ecf::User::FAIL, 100));
+        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 3, "Expected 3 zombie but found " << s->zombies().size());
+        s->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, child_cmds, ecf::User::FAIL, 100));
+        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 4, "Expected 4 zombie but found " << s->zombies().size());
+        s->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, child_cmds, ecf::User::FAIL, 100));
+        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 5, "Expected 5 zombie but found " << s->zombies().size());
+        s->addZombie(ZombieAttr(ecf::Child::PATH, child_cmds, ecf::User::BLOCK, 100));
+        BOOST_REQUIRE_MESSAGE(s->zombies().size() == 6, "Expected 6 zombie but found " << s->zombies().size());
+    }
+
+    // FIND
+    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::USER).empty(), "Expected to find USER zombies");
+    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF).empty(), "Expected to find ECF zombies");
+    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF_PID).empty(), "Expected to find ECF_PID zombies");
+    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF_PID_PASSWD).empty(),
+                          "Expected to find ECF_PID_PASSWD zombies");
+    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::ECF_PASSWD).empty(), "Expected to find ECF_PASSWD zombies");
+    BOOST_REQUIRE_MESSAGE(!s->findZombie(ecf::Child::PATH).empty(), "Expected to find PATH zombies");
+
+    // FIND on parent
+    {
+        ZombieAttr path_z, ecf_z, ecf_pid_z, ecf_pid_passwd_z, ecf_passwd_z, user_z;
+        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::PATH, path_z) && !path_z.empty(),
+                              "Expected to find PATH zombies on parent");
+        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF, ecf_z) && !ecf_z.empty(),
+                              "Expected to find ECF zombies on parent");
+        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF_PID, ecf_pid_z) && !ecf_pid_z.empty(),
+                              "Expected to find ECF_PID zombies on parent");
+        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF_PID_PASSWD, ecf_pid_passwd_z) &&
+                                  !ecf_pid_passwd_z.empty(),
+                              "Expected to find ECF_PID_PASSWD zombies on parent");
+        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::ECF_PASSWD, ecf_passwd_z) && !ecf_passwd_z.empty(),
+                              "Expected to find ECF_PASSWD zombies on parent");
+        BOOST_REQUIRE_MESSAGE(t->findParentZombie(ecf::Child::USER, user_z) && !user_z.empty(),
+                              "Expected to find USER zombies on parent");
+    }
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/base_date.h 5.13.0-1/libs/node/test/data/ECFLOW_672/base_date.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/base_date.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/base_date.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#base_date.h
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/base_ic.h 5.13.0-1/libs/node/test/data/ECFLOW_672/base_ic.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/base_ic.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/base_ic.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+#base_ic.h
+%include <suite.h>
+%include <date.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/base_se.h 5.13.0-1/libs/node/test/data/ECFLOW_672/base_se.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/base_se.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/base_se.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+#base_se.h
+%include <suite.h>
+%include <lib.h>
+%include <date.h>
+%include <ic.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/date.h 5.13.0-1/libs/node/test/data/ECFLOW_672/date.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/date.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/date.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+#date.h
+%include <base_date.h>
+%include <hc_date.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/hc_date.h 5.13.0-1/libs/node/test/data/ECFLOW_672/hc_date.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/hc_date.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/hc_date.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#hc_date.h
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/ic.h 5.13.0-1/libs/node/test/data/ECFLOW_672/ic.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/ic.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/ic.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+#ic.h
+%include <suite.h>
+%include <base_ic.h>
+%include <hc_date.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/lib.h 5.13.0-1/libs/node/test/data/ECFLOW_672/lib.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/lib.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/lib.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#lib.h
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/ms.h 5.13.0-1/libs/node/test/data/ECFLOW_672/ms.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/ms.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/ms.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+#ms.h
+%include <suite.h>
+%include <ic.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/ms_mem.h 5.13.0-1/libs/node/test/data/ECFLOW_672/ms_mem.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/ms_mem.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/ms_mem.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+#ms_mem.h
+%include <ms.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/se.h 5.13.0-1/libs/node/test/data/ECFLOW_672/se.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/se.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/se.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+#se.h
+%include <base_se.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/se_mem.h 5.13.0-1/libs/node/test/data/ECFLOW_672/se_mem.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/se_mem.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/se_mem.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+#se_mem.h
+%include <se.h>
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/suite.h 5.13.0-1/libs/node/test/data/ECFLOW_672/suite.h
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/suite.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/suite.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#suite.h
diff -pruN 5.12.4-1/libs/node/test/data/ECFLOW_672/t.ecf 5.13.0-1/libs/node/test/data/ECFLOW_672/t.ecf
--- 5.12.4-1/libs/node/test/data/ECFLOW_672/t.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/ECFLOW_672/t.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+%include <se_mem.h>
+%include <ms_mem.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/head.h 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/head.h
--- 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,47 @@
+#!/bin/ksh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+
+# Defines the three variables that are needed for any
+# communication with ECF_
+
+export ECF_PORT=%ECF_PORT%    # ECF_ port numner
+export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%
+fi
+
+# Tell ECF_ we have stated
+# The ECF_ variable ECF_RID will be set to parameter of smsinit
+# Here we give the current PID.
+
+#smsinit $$
+
+# Defined a error hanlder
+
+ERROR() {
+	set +e        # Clear -e flag, so we don't fail
+	#smsabort      # Notify ECF_ that something went wrong
+	trap 0        # Remove the trap
+	exit 0        # End the script
+}
+
+# Trap any calls to exit and errors caught by the -e flag
+
+trap ERROR 0
+
+# Trap any signal that may cause the script to fail
+
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/t1.ecf 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/t1.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/t1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/t1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,81 @@
+%manual
+	OPERATORS: This is an example of using a manual
+	
+	This is used to also test variable subsitution of 
+	generated variables
+	SUITE     = %SUITE%
+	DATE      = %DATE%
+	DAY       = %DAY%
+	DD        = %DD%
+	DOW       = %DOW%
+	DOY       = %DOY%
+	MM        = %MM%
+	MONTH     = %MONTH%
+	YYYY      = %YYYY%
+	ECF_DATE   = %ECF_DATE%
+	ECF_TIME   = %ECF_TIME%
+	ECF_CLOCK  = %ECF_CLOCK%
+
+	FAMILY    = %FAMILY%
+	FAMILY1   = %FAMILY1%
+
+	TASK      = %TASK%
+	ECF_RID    = %ECF_RID:<not defined yet, since empty string in task>%
+	ECF_TRYNO  = %ECF_TRYNO%
+	ECF_NAME   = %ECF_NAME%
+	ECF_PASS   = %ECF_PASS%
+	ECF_SCRIPT = %ECF_SCRIPT%
+	ECF_JOB    = %ECF_JOB%
+	ECF_JOBOUT = %ECF_JOBOUT%
+    
+    Other ECF_ variables
+   ECF_KILL_CMD    = %ECF_KILL_CMD:<not defined yet>%
+   ECF_STATUS_CMD  = %ECF_STATUS_CMD:<not defined yet>%
+	ECF_JOB_CMD     = %ECF_JOB_CMD%
+	ECF_HOME      = %ECF_HOME%
+	ECF_TRIES     = %ECF_TRIES:<Error>%
+	SMFILES       = %SMFILES:<not defined yet>%
+	ECF_INCLUDE   = %ECF_INCLUDE:<not defined yet>%
+	ECF_FETCH     = %ECF_FETCH:<not defined yet>%
+	ECF_OUT       = %ECF_OUT:<not defined yet>%
+	ECF_MICRO=%ECF_MICRO%
+%end
+
+#============================================================
+# Using angle brackets should use ECF_INCLUDES
+#=========================================================
+%include <head.h>
+
+
+echo do some work
+# SLEEPTIME is defined thedefs.def file. Test variable substituition
+sleep %SLEEPTIME%
+echo end of job
+
+
+%include <tail.h>
+
+# This is used in TestEcfFile.cpp
+# o check we handle ecfmicro when extracting manuals
+# o ensure we only handle manual/end if preceded with current ecfmicro char
+# o Pre-process %includes in manual, treat contents as manual contents
+%ecfmicro *
+*manual
+*include <manual.h>
+ manual-1
+ end-1
+*end
+*ecfmicro %
+
+%manual
+Rest of the manual page is placed here, closer to the code
+%end
+%comment
+  Comment start
+%end
+%comment
+  Comment end
+%end
+%nopp
+  ignore everything in here
+%end
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/t2.ecf 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/t2.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/t2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/t2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+ 
+# using %include "filename"
+# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
+#
+# since we are using quotes we expect to find 'head.h' and 'tail.h'
+# in the same directory as the sms files.
+#======================================================================
+%include "head.h"
+
+
+echo do some work
+# SLEEPTIME is defined thedefs.def file. Test variable substituition
+sleep 10
+echo end of job
+
+
+%include "tail.h"
+
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/t3.ecf 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/t3.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/t3.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/t3.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,39 @@
+# using %include "filename"
+# include the contents of the file %ECF_HOME%/%SUITE%/%FAMILY%/filename
+#
+# since we are using quotes we expect to find 'head.h' and 'tail.h'
+# in the same directory as the sms files.
+#======================================================================
+%include "head.h"
+
+
+echo do some work
+sleep 10
+echo end of job
+
+#=====================================================
+# change the ecfmicro character
+%ecfmicro &
+
+&manual
+	START Rest of the manual page is placed here, closer to the code
+&end
+&comment
+  Comment start
+  &SUITE&
+&end
+&comment
+  Comment end
+&end
+&nopp
+  ignore everything in here
+&end
+&manual
+	END of the manual
+&end
+#=====================================================
+# change the ecfmicro character back
+&ecfmicro %
+
+
+%include "tail.h"
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/tail.h 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/tail.h
--- 5.12.4-1/libs/node/test/data/SMSHOME/suite/family/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME/suite/family/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+#smscomplete  # Notify SMS of a normal end
+trap 0       # Remove all traps
+exit 0       # End the shell
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME/suite/family.man 5.13.0-1/libs/node/test/data/SMSHOME/suite/family.man
--- 5.12.4-1/libs/node/test/data/SMSHOME/suite/family.man	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME/suite/family.man	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+Special case where there are no manual directives.
+Just include contents of file as is:
+
+no directives in here either
+%include <manual.h> 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME/suite.man 5.13.0-1/libs/node/test/data/SMSHOME/suite.man
--- 5.12.4-1/libs/node/test/data/SMSHOME/suite.man	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME/suite.man	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+%manual
+%include <manual.h>
+suite manual
+%end
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+
+# test for unterminated manual
+
+%manual
+	OPERATORS: This is an example of using a manual
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad1.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad1.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+# test for unterminated comment
+
+%comment
+	OPERATORS: This is an example of using a manual
+  
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad10.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad10.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad10.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad10.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+
+ 
+# test for uneven number for microcharacter's
+ 
+%ecfmicro £
+sleep £SLEEPTIME
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad11.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad11.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad11.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad11.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+
+ 
+# test for uneven number for microcharacter's
+ 
+%ecfmicro £
+sleep £SLEEPTIME££
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad12.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad12.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad12.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad12.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+sleep %SLEEPTIME # test for uneven number for microcharacter's with comments, start of line
+                 # this is different to bad9.ecf
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad13.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad13.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad13.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad13.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+# test missnamed include
+%includeblahblah <good_head.h>
+%includeblah <good_tail.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad14.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad14.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad14.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad14.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+# unknow directive
+%fred
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad15.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad15.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad15.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad15.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+# test unrecognized pre-processing directive
+%ecfmicro * 
+*VAR
+*ecfmicro %
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad2.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad2.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+
+# test for missing nopp, manual, comment
+
+%end
+	 
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad3.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad3.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad3.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad3.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+
+# test for unterminate nopp
+
+%nopp
+  ignore everything in here
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad4.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad4.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad4.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad4.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+
+#
+# test for embedded manual
+%manual
+	OPERATORS: This is an example of usinh a manual
+	First include head.h
+	
+%manual
+    Illegal we can't have embedded manuals
+%end
+
+%end
+ 
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad5.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad5.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad5.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad5.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+
+#
+# test for embedded comments
+#
+
+%comment
+	OPERATORS: This is an example of using a manual
+	First include head.h
+	
+%comment
+    Illegal we can't have embedded comments
+%end
+
+%end
+ 
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad6.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad6.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad6.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad6.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+
+#
+# test for embedded  manual/comment
+#
+
+%comment
+	OPERATORS: This is an example of usinh a manual
+	First include head.h
+	
+%manual
+    Illegal we cannt have embedded manuals in a comment
+%end
+
+%end
+ 
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad7.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad7.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad7.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad7.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+ 
+ 
+# test for uneven number for microcharacter's
+ 
+sleep %SLEEPTIME%%
+
+ 
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad8.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad8.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad8.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad8.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+# test for uneven number for microcharacter's
+sleep %SLEEPTIME
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad9.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad9.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad9.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad9.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+
+sleep %SLEEPTIME # test for uneven number for microcharacter's with comments
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+
+
+# Test that a replacement character should be specified for ecfmicro
+ 
+%ecfmicro
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/bad_ecfmicro_1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+# Test that a replacement character for ecfmicro must be single character
+# Note: a single £ is multi-character of size 2
+ 
+%ecfmicro ££
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/a.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/a.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/a.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/a.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+# a.h
+%include <b.h>
+%include <c.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/b.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/b.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/b.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/b.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+# b.h
+%include <d.h>
+%include <e.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/c.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/c.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/c.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/c.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+# c.h
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/d.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/d.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/d.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/d.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+# d.h
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/e.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/e.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/e.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/e.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+%include <b.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/good_head.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/good_head.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/good_head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/good_head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+# just need empty file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/good_tail.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/good_tail.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/good_tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/good_tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+# just need empty file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/ok.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/ok.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/ok.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/ok.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+# file ok.h
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/recursive_head.h 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/recursive_head.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/includes/recursive_head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/includes/recursive_head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+#!/bin/ksh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+#
+# test recursive include
+#
+%include <recursive_head.h>
+
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/recursive_include1.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/recursive_include1.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/recursive_include1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/recursive_include1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+#======================================================================
+# test recursive include
+#======================================================================
+%include <recursive_head.h>
+
+
+echo do some work
+sleep 10
+echo end of job
+
+
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/bad/recursive_include2.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/bad/recursive_include2.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/bad/recursive_include2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/bad/recursive_include2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+# test for recursive includes
+%include <a.h>
+
+# a.h -> b.h -> d.h
+#               e.h -> b.h
+#        c.h
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/.gitignore 5.13.0-1/libs/node/test/data/SMSHOME2/good/.gitignore
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/.gitignore	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+/suite
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/ecf_micro_2.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/ecf_micro_2.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/ecf_micro_2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/ecf_micro_2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+
+%ecfmicro ^
+exe_time=`date +%s -r ACore/bin/^COMPILER_TEST_PATH:gcc^/u_acore`
+^ecfmicro %
+
+%manual
+  Rest of the manual page is placed here, closer to the code
+%end
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/ecfmicro.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/ecfmicro.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/ecfmicro.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/ecfmicro.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+
+# test exfmicro with a pound sign, this is multi-character
+%ecfmicro £  
+
+£VAR:sub£
+
+£ecfmicro %
+
+%VAR1:sub%
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/good.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/good.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/good.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/good.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,21 @@
+%manual
+	OPERATORS: This is an example of usinh a manual
+	First include head.h
+%end
+
+echo do some work
+echo end of job
+
+%manual
+  Rest of the manual page is placed here, closer to the code
+%end
+%comment
+  Comment start
+%end
+%comment
+  Comment end
+%end
+
+%nopp
+  ignore everything in here
+%end
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/good1.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/good1.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/good1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/good1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+ #============================================================
+# test for include included twice. 
+# This is not a recursive include
+#=========================================================
+%include <head.h>
+%include <head.h>
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/good2.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/good2.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/good2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/good2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+# sleep %SLEEPTIME test for uneven number for microcharacter's
+sleep %SLEEPTIME%
+# sleep %SLEEPTIME test for uneven number for microcharacter's
+# %fred
+# fred%
+        # %%fred%
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includeonce.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/includeonce.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includeonce.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includeonce.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+%includeonce <head.h>
+%includeonce <head.h>
+%include <head.h>
+%includeonce <tail.h>
+%include <tail.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includeonce_recursive.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/includeonce_recursive.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includeonce_recursive.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includeonce_recursive.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+%includeonce <recursive_include.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/config.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/config.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/config.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/config.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1527 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+#=======================================================================
+#  config.h
+#=======================================================================
+banner config.h
+
+if [[ "$ARCH" != "linux" ]] ;then
+  typeset -l ARCH
+fi
+
+export SCRATCHDIR=${SCRATCHDIR:-UNDEFINED}
+export ARCH=${ARCH:-sgimips}
+export TMPDIR=${TMPDIR:-UNDEFINED}
+export HOST=${HOST:-`hostname`}
+export NPES=${NPES:-0}
+
+if [[ $ARCH = linux ]] ; then
+  export EMOS_TMPDIR=/var/tmp/tmpdir/%TASK%_%ECF_TRYNO%.$$
+  export TMPDIR=$EMOS_TMPDIR
+  [[ -d $TMPDIR ]] || mkdir -p $TMPDIR
+  export USE_EMOS_TMP="true"
+  cd $TMPDIR
+else
+  EMOS_TMPDIR=""
+fi
+
+if [[ "$TMPDIR" = "UNDEFINED" ]] ; then
+   TMPDIR="$TEMP/NQS_tmpdir.$$"  export TMPDIR
+   export USE_EMOS_TMP="true"
+   [[ -d $TMPDIR ]] || mkdir $TMPDIR
+   if [[ $? -ne 0 ]] ; then
+      echo "####### CANNOT CREATE TMPDIR #######" >&2
+      exit 1
+   fi
+fi
+
+PS4="+ "
+
+echo "\
+  This is the config.h file and\n\
+  System variables used were:\n\
+  USER     $USER\n\
+  TMPDIR   $TMPDIR\n\
+  HOME     $HOME\n\
+  HOST     $HOST\n\
+  ARCH     $ARCH\n\
+  PATH     $PATH\n\
+"
+set -xa
+
+#=======================================================================
+#  Experiment version and initial data origin (default values)
+#=======================================================================
+
+EXPVER=%VERSION:0001%
+GRIBCLASS=1
+BASEVER=0001
+BASETIME=1996072200
+
+#=======================================================================
+#  Software configuration (library cycles etc)
+#=======================================================================
+
+IFSMASTER=ifsMASTER
+#####################################
+IFS_CYCLE=35r3
+#####################################
+
+
+SUITE_TYPE=%SUITE_TYPE:"undef"%
+NEWSTREAM=none
+EMOS_CYCLE=000370
+VIEW_IFS=
+VIEW_IFSAUX=
+VIEW_OBSPROC=
+VIEW_OBSORT=
+VIEW_TOVSCODE=
+VIEW_SSMICODE=
+VIEW_BL=
+VIEW_SSA=
+VIEW_SST=
+VIEW_WAM=
+MAKE_LIBS=yes
+
+GRIB_API_VERSION=1.8.0
+GRIB_API_INCLUDE="-I/usr/local/lib/metaps/lib/grib_api/jasper/include -I/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/include"
+GRIB_API_LIB="-L/usr/local/lib/metaps/lib/grib_api/jasper/lib -ljasper -L/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/lib -lgrib_api_f90 -lgrib_api"
+export GRIB_API=/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/bin   # change to fixed version
+export PATH=$GRIB_API:$PATH
+
+#=======================================================================
+#  Model configuration
+#=======================================================================
+
+RESOL=799
+LEVELS=91
+GTYPE=l_2
+FCLENGTH=%FCLENGTH:6%
+FCLENGTH0N=$FCLENGTH
+RUN_GFC=no
+
+#=======================================================================
+#  Analysis parameters
+#=======================================================================
+
+IFSMODE=early_delivery
+PERIOD=6
+TSTEP=720
+
+if [[ "%STREAM%" = SCDA ]] && [[ %MXUP_TRAJ:3% = 1 ]] ; then
+  RESOLINC_0=255 # HR:255, LR:159
+  TSTEP_INC_0=1800
+else
+  RESOLINC_0=95
+  TSTEP_INC_0=3600
+fi
+
+RESOLINC_1=159     # 255 32r1
+RESOLINC_2=255     # 159 32r1
+TSTEP_INC_1=1800
+TSTEP_INC_2=1800
+
+LFG=.false.
+
+ITER_MIN_0=70
+ITER_MIN_1=50
+ITER_MIN_2=50
+MXUP_TRAJ=%MXUP_TRAJ:3%
+NMINSIMPHY=1
+LINCNMI=false
+LVERIFY_SCREEN=true
+SCRANA=active
+
+RESOLFCE=42
+ITER_FCE=150
+NWRIEVEC=25
+
+OBPATH=ops
+BLACK_DS=ops
+BLACK_MM=ops
+BLACK_EX=ops
+
+LOZONE=true
+LOZONECH=true
+ANEMOM_HT=true
+LISENTRPP=true
+LESUITE=false
+
+OBNLAT=90.00
+OBSLAT=-90.00
+OBWLON=-180.00
+OBELON=180.00
+
+MPLARGS="check=0"
+
+#================================
+# New for 25r3
+
+LINRADEX=true
+LREDUCOB=false
+TSLOTSEC=1800
+UPTRAJ_FCE=0
+LAMV_REASSIGN=false
+
+#================================
+# New for 25r4
+
+BRANCH=""
+BRF=0
+LAIRS=true
+PARALLEL=4
+PROJECTS="none"
+
+#================================
+# New for 26r3
+
+if [[ "%SUITE%" = o || "%SUITE%" = e_* ]] ; then
+  LARCHINCR=true
+else
+  LARCHINCR=false
+fi
+
+#================================
+# New for 28r1
+
+FPOSCLD=%FPOSCLD:false%  # should be true for 4dvar, false for 3d_fgat
+PROFILE=%PROFILE:0%  # for diagnostic purposes
+LANOBSENS=false
+
+#================================
+# New for 28r2
+#==========================================================
+# Variables configuring testOfAnalysis
+#==========================================================
+LTESTVAR=false
+NTESTVAR=0
+LCVTEST=false
+LTLTEST=false
+LADTEST=false
+LGRTEST=false
+LTESTINC=false    # should be set to false and will turn off other testing
+
+#==========================================================
+# New for 28r3
+#==========================================================
+REINIHOUR=%REINIHOUR:0%
+ED_PERIOD=%ED_PERIOD:12%
+ED_ONLY=%ED_ONLY:false%
+REINICLASS=%REINICLASS:od%
+REINI_NOT_ED=%REINI_NOT_ED:false%
+OBSTREAM=%STREAM%
+
+#==========================================================
+# New for 29r1
+#==========================================================
+set -a
+LOBREALTIME=%OBREALTIME:false% ; # false in catchup mode, true in rt
+LCALC_PSBIAS=%CALC_PSBIAS:true%
+LUSE_PSBIAS=%USE_PSBIAS:true%
+INIPSBIAS=%INIPSBIAS:true%
+INIVARBC=%INIVARBC:false%
+
+NTYPE_MODERR=2
+NCOMP_MODERR=1
+LFGMODERR=true
+ALPHAQ=0.3         # 31r2
+NSERR=-1
+LINITCV=true
+LMODERRFC=false
+LBGMODERR=false
+
+LPROPTL=false
+LINTEST=false
+
+SAVINI=false
+
+EPSROTPATH=""
+
+#==========================================================
+# New for 29r2
+#==========================================================
+set -a
+LTWINTRUTH=false
+LTWINEXP=false
+TRUTHEXP="none"
+LCO2=false
+LCO2ANER=false
+INICO2=false
+LERA40_PREODB=false
+Q2CREATE_NEWSTREAM=false
+Q2USE=false
+Q2CHANGELIST=0
+
+# EPS
+NSVET=50
+NITERLET=120
+EPSBASIS=50 # number of tropical singular vectors used in
+            # Gaussian sampling
+EPSBASIST=5 # number of tropical singular vectors used in
+
+            # in order to startup emc suite this might be set to 25
+            # for the first 2 way. Then make_sv would not be used.
+
+EPSEVO_NORMALIZE=true
+ICPEXPVER=%ICPEXPVER:0001%
+EPSGAMMA_TC2INI=1.5
+EPSGAMMA_EVO2INI=1.0 # 1.5 for 29r2
+EPSGAMMA=0.014
+EPSSIMPL=5     # Gaussian sampling for all singular vectors
+#==========================================================
+# New for 29r3
+#==========================================================
+
+LGPINNER=true
+NFRDHP=3
+
+#==========================================================
+# New for 30r1
+#==========================================================
+FILTERRESOL=255
+FILTERFACTOR=5
+FILTEREXPONENT=4
+EC_FILL_NANS=false
+USE_SMT=%USE_SMT:true%
+
+if [[ "%EC_SMT:yes%" = yes ]] ; then
+  USE_SMT=true
+else
+  USE_SMT=false
+fi
+
+#==========================================================
+# New for 30r2
+#==========================================================
+LUSE_RSTBIAS=%USE_RSTBIAS:true%
+ERA_MODE=false
+
+#==========================================================
+# New for 31r1
+#==========================================================
+DOFDBK=true # ie true
+LCALC_RSTBIAS=%CALC_RSTBIAS:false%
+VARBC_PATH=%VARBC_PATH:standard%
+NCS_CONFIG=2  # 31r2
+USE_SMT=%USE_SMT:true%
+LPML=%PRODUCE_EPS_ML:0%
+
+if [[ %EC_SMT:yes% = yes ]] && [[ %USE_SMT:true% = false ]] ; then
+  echo "ECF_ variable EC_SMT and USE_SMT are not compatible"
+  exit 1
+elif [[ %EC_SMT:yes% = no ]] && [[ %USE_SMT:true% = true ]] ; then
+  echo "ECF_ variable EC_SMT and USE_SMT are not compatible"
+  exit 1
+fi
+#==========================================================
+# New for 31r2
+#==========================================================
+LRAIN4D=true
+LNMPHYS=true   #32r1
+ENDANENS=0
+ENDANENSODB=0
+
+P4CLIENT=0     #32r1 not used in operations
+
+#==========================================================
+# New for 32r1
+#==========================================================
+LCONSTANT_VARBC=false
+
+#==========================================================
+# New for 32r2
+#==========================================================
+LIASI=true
+
+INIMODISALB=true # if intial data was run with 32r1 or later
+VARBC_ARCHIVE_EVOLVE=false
+
+#==========================================================
+# New for 32r3
+#==========================================================
+LFULL_IASI=%LFULL_IASI:true%   # true = use full iasi data and screen: false use screened data
+LGEMS=false                    # run with gems parameters
+GHGVAR=
+GRGVAR=
+AEROVAR=
+TRACVAR=
+INIGHG=false
+INIGRG=false
+INIAERO=false
+INITRAC=false
+LEVGEN=true          # Use van Genuchten hydrology
+INIHTESSEL=true      # if starteding from experiment where LEVGEN=true
+LCALC_RSTRHBIAS=%CALC_RSTRHBIAS:true%
+LUSE_RSTRHBIAS=%LUSE_RSTRHBIAS:true%
+LSSMI1D=true
+LSSMIS1D=true
+LAMSRE1D=true
+LTMI1D=true
+LAMSRE1D=true
+ODB_IO_OPENMP=1
+
+#==========================================================
+# New for 33r2
+#==========================================================
+LOBSCOR=false
+
+#==========================================================
+# New for 35r2
+#==========================================================
+
+LECURR=false
+INIECURR=false
+LSCATT_NEUTRAL=false
+D3GGFIELDSSTEND="0"
+LFSOBS=false
+LSEKF=false
+
+#==========================================================
+# New for 35r3
+#==========================================================
+# if EPS or associated then LEMISKF & LWEAK4DVAR=false
+INIOZONE=true
+
+WEAK4D_INTERV=0.0
+LMODERR_PERIODIC=false
+NSPLIT4DWIN=0
+LBALSTRATO=false
+AMSU_LAND=Dynamic_emis
+EMISKF_PATH=standard
+INIEMISKF=true
+INIMODERR=true
+LDUCTDIA=false
+LASCATSM=true
+if [[ %SUITE% = "e_*" ]] ; then LANOBSENS=true; fi
+
+#==========================================================
+# Variables configuring ifs_ctm
+#==========================================================
+LCOUPLO4=false
+CTM_MODEL=mozart
+NFRCOUPLO4=1
+NFRCOUPLO4_FB=1
+LGLOBALGP=true
+LGLOBALSP=true
+MPROCGPG=1
+MPROCSPG=1
+LOUT_SPC=false
+LOUT_FLUX=true
+LOUT_COOR=false
+LIN_GRG=true
+LIN_COOR=false
+LCOUPLO4_CTM=true
+LOUT_GRG=false
+LOUT_CO=false
+LOUT_SO2=false
+LOUT_NOX=false
+LOUT_NO2=false
+LOUT_GO3=false
+LOUT_HCHO=false
+LNOX2NO2=false
+INTERP2D=bilinear
+PARA_SEARCH=global
+IF_MASKED=novalue
+LGRG_CYCLE=true
+LDIFF_GRG=false
+LCONV_GRG=false
+LDIA_GRG=false
+NPROC_CTM=8
+NPROC_CTM_AN=8
+NPROC_DRV=1
+CTM_THREADS=4
+CTM_THREADS_AN=4
+DRV_THREADS=1
+DRV_THREADS_AN=1
+IFS_THREADS_AN=6
+LSTATS=true
+
+#==========================================================
+# Variables configuring Gems
+#==========================================================
+LGEMS=false
+GHGVAR=""
+INIGHG=false
+GRGVAR=""
+INIGRG=false
+AEROVAR=""
+INIAERO=false
+TRACVAR=""
+INITRAC=false
+
+#=======================================================================
+# DR_HOOK
+#=======================================================================
+DR_HOOK=true # 30r1 was false
+DR_HOOK_OPT="none" # 30r1 was "prof"
+DR_HOOK_PROFILE_LIMIT=-10
+DR_HOOK_HASHBITS=15
+DR_HOOK_CATCH_SIGNALS=false
+DR_HOOK_IGNORE_SIGNALS=false
+
+LIBHPM=""
+if [[ $DR_HOOK = true ]] ; then
+  DR_HOOK_OPT=`echo $DR_HOOK_OPT | sed -e 's/\// /g'`
+  if [[ $ARCH = ibm_power4 ]] ; then
+    LIBHPM="-L/usr/pmapi/lib -lpmapi"
+  fi
+fi
+
+#=======================================================================
+#  BC project setup for analysis (only those that are different)
+#=======================================================================
+
+if [[ "%STREAM%" = SCDA ]] ; then
+  PERIOD_4D=6 ;
+  WINDOW_LENGTH_4D=%WINDOW_LENGTH_4D:12%
+  WINDOW_OFFSET_4D=%WINDOW_OFFSET_4D:9%
+
+  if [[ %MXUP_TRAJ:3% = 3 ]] ; then
+
+  IFSMODE=4d_inc
+
+  else
+
+  IFSMODE=3d_fgat
+  ITER_MIN=70
+  ITER_MIN_1=0
+  SIMUL_MIN=80
+  SIMUL_MIN_1=0
+  LISENTRPP=false
+  LVERIFY_SCREEN=false
+
+  fi
+else
+  # PERIOD_4D=6 ; # 20040423 should stay 12 by default (for SCDA reinit), then SMS variable is set to 12, this variable is considered for reinit = false (vardata.sms)
+if [[ `echo %FAMILY:NOT_DEF% | cut -d / -f 1` = "main" ]] ; then
+  ## RD behaviour : default is constant 12,
+  ## if SMS variable is changed, task should consider it specifically
+  ## some tasks (vardata, fetcherr) may want this default and not SMS
+  ## variable for REINITIALIZE state
+  PERIOD_4D=12
+  WINDOW_LENGTH_4D=12
+  WINDOW_OFFSET_4D=3
+
+else  # SMS variable IS the environment variable for other families
+  PERIOD_4D=%PERIOD_4D:12%
+  WINDOW_LENGTH_4D=%WINDOW_LENGTH_4D:12%
+  WINDOW_OFFSET_4D=%WINDOW_OFFSET_4D:3%
+fi
+fi
+
+#=================================================
+#  Simplified Kalman filter parameters
+#=================================================
+
+TSTEP_SV=1200
+RESOLSV=42
+NLANTYPE=6
+NJDSTOP=48
+NITERL=60
+NINNER=30
+NEIGEVO=60
+HESSTYPE=3d
+SVPPFRQ=6
+
+
+################### New for 23r1 #############
+LATE4DSTART=true
+FPOSINC=false
+INICLOUDAN=true
+
+
+#=======================================================================
+#  Satellite parameters
+#=======================================================================
+
+LTOVS=.false.
+LATOVS=true
+LAIRS=true # 31r1
+LSSMI=true # 33r1
+LSCAT=.true.
+LGEOS=true
+LRAIN1D=false    # 35r2
+LSSMIRAIN=true   # 33r2
+LSSMISRAIN=true  # 35r3
+LTMIRAIN=true    # 35r3
+LAMSRERAIN=true  # 33r2
+LPRERAD1C=false
+LREO3=true
+LAEOLUS=false # 31r1
+LSSMIS=true   # 31r2
+LAMSRE=true   # 31r2
+LMERIS=true # 20080714 until which was false  # 33r2
+LTMI=true     # 31r2
+LGPSRO=true   # 31r2
+
+BIAS_PATH_AMV=none
+BIAS_PATH_REO3=none
+LREO3_BCOR=false
+
+BIASCOLD=yes
+BIASDAYS=14
+BIASMISS=7
+BIAS_ARCHIVE=1
+
+if [[ "%SUITE%" = o || "%SUITE%" = e_* ]] ; then
+  export FDB_NOF_BUFF=4
+  export FDB_BUF_SECT_SIZE=25165824
+elif [[ "%SUITE%" = bc || "%SUITE%" = ebc_* ]] ; then
+  export FDB_NOF_BUFF=3
+  export FDB_BUF_SECT_SIZE=33554432
+else
+  export FDB_NOF_BUFF=4
+  export FDB_BUF_SECT_SIZE=4194304
+fi
+
+# 23r4
+RSTBIAS=true
+
+# 24r2
+ERAFS=false
+
+#  SATMON parameters
+SMON_OPT_DIR=""
+SMON_OPT_GEOS=ops
+SMON_OPT_NOAA=ops
+SMON_OPT_DMSP=ops
+SMON_OPT_O3=ops
+SMON_OPT_O3KNMI=ops
+SMON_OPT_O3MSG=ops
+SMON_OPT_TEMP=ops
+SMON_OPT_PWC=ops
+SMON_OPT_AMV=ops
+SMON_OPT_DBAMV=ops       # 33r1
+SMON_OPT_AIRS=ops
+SMON_OPT_IASI=ops        # 32r3
+SMON_OPT_EARS=ops
+SMON_OPT_PACRARS=ops     # 33r1
+SMON_OPT_MERIS=ops       # 33r2
+SMON_OPT_SSMIS=ops       # 31r2
+SMON_OPT_AMSRE=ops       # 31r2
+SMON_OPT_TMI=ops         # 31r2
+SMON_OPT_GPSRO=ops       # 31r2
+SMON_OPT_SCATT=ops       # 35r3
+SMON_OPT_SLMOIST=ops     # 35r3
+
+
+SATROOT=/od_archive/data/satmon
+
+#==========================================================
+# Variables configuring Reanalysis
+#==========================================================
+MEANS=true
+MOMENTS=true
+INTEGRALS=true
+INCREMENTS=true
+PLOTS=true
+RSTBIAS_TS=false
+RSTBIAS_SE=true
+ERAPRODUCTS="/era/intprod/data/monitor"
+
+#=======================================================================
+#  Coupled wave model parameters
+#=======================================================================
+
+WAVE=yes
+WAM2WAY=yes
+WAMNSTPW=1
+  if [[ "%FSFAMILY%" = @(mc|refc|assim) ]] ; then
+WAMRESOL=global100
+else
+WAMRESOL=global36 # HR global50
+fi
+WAMALT=yes
+WAMSAR=yes
+WAMSARASS=true
+
+if [[ "%FSFAMILY%" = "euroshelf" || $SUITE_TYPE = "law" ]] ; then  # law suites
+  WAMNFRE=30  # 36 future 0044
+  WAMNANG=24  # 36 future 0044
+else
+  WAMNFRE=30
+  WAMNANG=24
+fi
+
+date_ers1_wave=1994010100
+
+if [[ $BASETIME -lt $date_ers1_wave || $WAMALT != yes ]] ; then
+  WAMANPARAM_DYN="215/216/220/221/222/223/224/225/226/227/228/229/230/231/232/233/234/235/236/237/238/239/244/245/249"
+else
+  WAMANPARAM_DYN="215/216/217/218/220/221/222/223/224/225/226/227/228/229/230/231/232/233/234/235/236/237/238/239/244/245/246/247/248/249/252/253/254"
+fi
+
+WAMANPARAM_STAT="219"
+WAMANPARAM=$WAMANPARAM_STAT/$WAMANPARAM_DYN
+
+WAMFCPARAM_STAT="219"
+WAMFCPARAM_DYN="215/216/217/218/220/221/222/223/224/225/226/227/228/229/230/231/232/233/234/235/236/237/238/239/244/245/249/252/253/254"
+WAMFCPARAM=$WAMFCPARAM_STAT/$WAMFCPARAM_DYN
+
+INIWAVE=yes
+WAMCOLDLENGTH=240
+WAMSTREAM=0
+# Many of these values are overridden for
+# local area model in law.h
+
+if [[ "%STREAM%" = SCDA ]] ; then
+  WAMSTREAM=1027
+elif  [[ "%STREAM%" = DCDA ]] ; then
+  WAMSTREAM=1029
+fi
+
+#=======================================================================
+#  Initial data parameters
+#=======================================================================
+
+
+INITIME=%INITIME:2001042900%
+INICLASS=%INICLASS:od%
+INISTREAM=%INISTREAM:da%
+# da : early delivery suite initialised from standard suite
+# dcda : early delivery suite initialised from another delayed cutoff suite
+INITYPE=4v
+INIEXPVER=%INIEXPVER:0001%
+INILEVELS=%INILEVELS:60%
+INISTEP=%INISTEP:0%
+# size of the 4dvar window
+
+# offset from the beginning of the 4V for FC
+INIOFFSET_4D=%INIOFFSET_4D:3%
+# 9 : early delivery suite initialised from standard suite
+# 3 : early delivery suite initialised from another ealry delivery suite
+INITILES=true
+INIRESOL=799 # was 511
+INICI=true
+FORCE_FP=no
+
+if [[ "%FAMILY1:NOT_DEF%" = sv || "%FAMILY1:NOT_DEF%" = m2_12 || "%FAMILY1:NOT_DEF%" = m2_00 || "%FAMILY1:NOT_DEF%" = m1_12 || "%FAMILY1:NOT_DEF%" = m1_00 ]] ; then
+  INITYPE=fc
+#  ------- vv
+#  INISTEP=12   # for 00,12 UTC forecasts
+#  ------- ^^
+  INISTEP=6     # for 06,18 UTC forecasts
+  INISTREAM=dcda
+  INISUFFIX="_sv"
+else
+  INISUFFIX=
+fi
+
+if [[ "$ARCH" != "linux" ]];then
+  typeset -l REINITIALIZE
+fi
+REINITIALIZE=%REINITIALIZE:false%
+REINIEXPVER=%REINIEXPVER:0001%
+REINISTREAM=%REINISTREAM:da%
+REINIPERIOD_4D=%REINIPERIOD_4D:12%
+REINIOFFSET=%REINIOFFSET:12%
+ED_CUTOFF=%ED_CUTOFF:4%
+
+#=================================================
+# PE settings
+#=================================================
+NPES_MKCMA=%MKCMANPES:1%
+NPES_AN=%ANNPES:1%
+NPES_FC=%FCNPES:1%
+NPES_SV=%FCNPES:1%
+#=================================================
+#  PREPAN parameters
+#=================================================
+
+OWNER=emos
+AMASTER=/ws/home/ma/emos/amaster/xxxx
+RUN_PARALLEL=true
+
+#=======================================================================
+#  Sami's variables + ODB
+#=======================================================================
+
+CONCAT=1
+PMETHOD=2
+FSODB=/emos_backup
+
+ODB_CTX_DEBUG=0
+ODB_MAXHANDLE=5
+ODB_STATIC_LINKING=1
+ODB_UNDEF=2146959359
+ODB_CCMA_CREATE_DIRECT=1
+ODBSAVE_ODBCMP=true     #31r2
+ODB_FROM_FB=false
+if [[ "%STREAM%" = SCDA ]] ; then
+  ODBSAVE_CCMA=false
+  ODBSAVE_ECMA=false
+else
+  ODBSAVE_CCMA=true
+  ODBSAVE_ECMA=true
+fi
+ODB_CATCH_SIGNALS=0
+ODB_CCMA_IGNORE_TSLOTS=0
+ODB_CCMA_OBS_RANDOMIZE=0
+ODB_CCMA_WTMETHOD=107
+ODB_ERRTRA=1
+ODB_FLPCHECK=0
+ODB_INTCHECK=0
+ODB_IO_METHOD=4
+ODB_IO_FILESIZE=128
+ODB_PACKING=-1
+ODB_REPRODUCIBLE_SEQNO=4
+ODB_TEST_INDEX_RANGE=0
+ODB_WRITE_EMPTY_FILES=0
+
+MANPATH=""
+#=======================================================================
+#  Coupled wave variables
+#=======================================================================
+
+WGRIBIN=yes
+
+#================================
+# New for 19r1, should be put in correct place.
+
+HESS3D=3d
+PPFRQ=12
+LINCNMI=false
+NEIGEVO=60
+#================================
+# New for 24r4
+
+LMAPSOP=false
+MPP_TYPE=1
+if [[ "%STREAM%" = SCDA ]] && [[ %MXUP_TRAJ:3% = 1 ]] ; then
+  LTRAJHR=false
+else
+  LTRAJHR=true
+fi
+
+#================================
+# New for 26r3
+
+LMODERR=false
+
+#=======================================================================
+#  Plot control
+#=======================================================================
+
+PLOT_RMS=true
+
+#=======================================================================
+#  Standard libraries
+#=======================================================================
+
+SCHOST=%SCHOST%
+SCHOST_BKUP=%SCHOST_BKUP:not_set%
+# storage host
+STHOST=%STHOST:%
+STHOST_BKUP=%STHOST_BKUP%
+WSHOST=%WSHOST%
+
+LIBRESOL=.R64.D64.I32
+ELIB=/usr/local/lib/metaps/lib/${EMOS_CYCLE}
+
+if [[ $ARCH = ibm_power* ]] ; then
+  SLIB=/usr/local/lib
+###########################################
+#temporary setting: A.Hofstadler, 200200821
+  EMOSLIB="-lemos.R64.D64.I32"
+  ECLIB="-L $SLIB "
+  FDBLIB="-L $SLIB -lfdb"
+#temporary setting:
+###########################################
+  EMOSLIB="-L $ELIB $EMOSLIB"
+  OBJECT_MODE=64
+  XLFRTEOPTS=err_recovery=no
+else
+###########################################
+#temporary setting: A.Hofstadler, 200200821
+#  EMOSLIB="-lemos.R64.D64.I32"
+  EMOSLIB="-lemos.R32.D64.I32" # or single???
+#temporary setting:
+###########################################
+  SLIB=/usr/local/lib
+  EMOSLIB="-L $ELIB $EMOSLIB"
+fi
+
+emosbin=/home/ma/emos/bin/${EMOS_CYCLE}/$ARCH
+#=======================================================================
+#  Singular vector configuration
+#  NSVHEM=1 for SVs over NH only
+#         2      "       SH only
+#         3      "       NH+SH
+#=======================================================================
+
+EPSSVPATH=
+EPSSVROTPATH=
+EPSFCRES=%EPSFCRES:399% # HR 255
+
+# VAREPS 30r2
+EPSFCRES_A=%EPSFCRES_A:399% # HR 255
+EPSFCRES_B=%EPSFCRES_B:255% # HR 255
+EPSFCRES_C=%EPSFCRES_C:255% # HR 255
+
+EPSFCLENGTH_A=%EPSFCLENGTH_A:240%
+EPSFCLENGTH_B=%EPSFCLENGTH_B:144%
+EPSFCLENGTH_C=%EPSFCLENGTH_C:408%
+
+EPSINISTEP_B=%EPSINISTEP_B:216%
+EPSINISTEP_C=%EPSINISTEP_C:360%
+
+EPSFCGTYPE=%EPSFCGTYPE:l_2%
+EPSFCGTYPE_A=%EPSFCGTYPE_A:l_2%
+EPSFCGTYPE_B=%EPSFCGTYPE_B:l_2%
+EPSFCGTYPE_C=%EPSFCGTYPE_C:l_2%
+
+EPSVARHDIF=false
+EPSVARHDIFT=24
+
+EPS_USE_ICP=0
+# /VAREPS
+
+EPSFCLEV=%EPSFCLEV:62%  # HR 40
+EPSSVRES=%EPSSVRES:42%
+EPSSVGTYPE=_full
+EPSSVLEV=%EPSSVLEV:62%  # HR 40
+EPSMEMBERS=`echo "%ENSEMBLES:50% + 1" | bc`
+EPSNENS=%ENSEMBLES:50%
+EPSEVO=1
+EPSHEM=%EPSHEM:3%
+EPSEVOTIME=48
+
+EPSWAMRESOL=%EPSWAMRESOL:global100%
+EPSWAMNSTPW=%EPSWAMSTPW:1%
+EPSTSTEP=%TSTEP:1800% # HR 2700
+EPSSVTSTEP=%EPSSVTSTEP:900%
+
+if [[ %STREAM% = MAED ]] ; then
+  INIMODISALB=false
+TSTEP=$EPSTSTEP
+fi
+
+EPSTSTEP_SV=900 # HR 1200
+EPSWAMALT=no
+EPSTYPE=%EPSTYPE%
+EPSMEMBER=%MEMBER%
+FCTOTAL=$EPSMEMBERS
+NTOTAL=$EPSNENS
+EPSSVDIAB=%EPSSVDIAB:false%
+EPSSVNUM=%EPSSVNUM:0%
+
+# 28r3
+DELTAHH_TC_TRACKS=12 # 12h lag from previous TC used in targets task
+EPSSV_TOPT=48        # optimization time for the tropical singular vectors
+                     # targets
+
+TC_TRACKS_EXPVER=%VERSION:0001%    # ???TDB
+
+if [[ %VERSION:0001% = 0020 ]] ; then
+  TC_TRACKS_EXPVER=0001
+fi
+
+OD_PROJ=%OD_PROJ:od%
+
+if [[ "%SUITE%" = emc* ]] && [[ %IS_REAL_TIME:false% = false ]] ; then
+  TC_TRACKS_PATH=/emos/tc/0001
+elif [[ $REINITIALIZE = true ]] ; then
+  TC_TRACKS_PATH=/emos/tc/$REINIEXPVER
+elif [[ %FIRST_DAY% = 1 ]] ; then
+  TC_TRACKS_PATH=/emos/tc/$INIEXPVER
+  TC_TRACKS_EXPVER=0001
+elif [[ ! "$OD_PROJ" = "od" ]] ; then
+# || [[ %IS_REAL_TIME:false% = false ]] ; then
+  ## MC_NO and other MS suites
+  ## and catchup mode running 12 cycle only
+  TC_TRACKS_PATH=/emos/tc/0001
+else
+  TC_TRACKS_PATH=/emos/tc/%VERSION%
+fi
+
+TC_TRACKS_FROM_MARS=true
+TC_TRACKS_CLASS=od
+
+EPSSVTCSUB=%EPSSVTCSUB:0%
+EPSTCBB=%EPSTCBB:1%       # use TC tracks to define optimization regions
+EPSSVOP=%EPSSVOP:0%       # not required to set sms variable in OD
+EPSSVTC_ORTHONORM=1       # ortho-normalize tropical SVs
+
+RUNHINDCAST=%RUNHINDCAST:0% # 1 for back loop and 0 for realtime
+
+#=======================================================================
+# EFI PATHS:
+#=======================================================================
+EFI_WS_CACHE=/efi_clim/data/cache
+EFI_WS_SCRATCH=/efi_clim/data/scratch
+EFI_ECFS_PATH=ec:/emos/efi_clim
+EFI_HPCF_PATH=/home/ma/emos/data/efi_clim
+#=======================================================================
+#  Ocean model configuration
+#=======================================================================
+
+OCVER=h2e2
+ASVER=cy2r3
+
+#=======================================================================
+#  Configuration for sensitivity suite
+#=======================================================================
+
+SENSFCRES=255
+SENSFCLEV=60
+SENSADJRES=63
+SENSADJLEV=60
+SENSADJGTYPE=_2
+SENSFCGTYPE=l_2
+SENSADJSTEP=48
+SENSADJTSTEP=600.0
+SENSRUNFC=yes
+INISPQ=no
+
+#new for 25r1
+SENSADJADVEC=euler
+SENSFORCE=false
+SENSDIAB=true
+SENSITER=6
+
+#=======================================================================
+#  The disk configuration
+#  Look at e-suite configuration below also
+#=======================================================================
+
+if [[ $ARCH = ibm_power* ]] ; then
+  if [[ "%SUITE%" = mc_no ]] ; then
+    TROOT=$STHOST/ms_crit/teps
+    WROOT=$STHOST/ms_crit/teps
+    OROOT=$STHOST/emos_data
+    FDB_ROOT=$STHOST/ms_crit/fdb
+    FDB_IROOT=$STHOST/ms_crit/fdb
+    WAVEEPS_ROOT=$FDB_ROOT
+    WAVEEPS_IROOT=$FDB_IROOT
+  elif [[ "%SUITE%" = e*35r3* || "%SUITE%" = "e_sync" || "%SUITE%" = "emc_no*" ]] ; then
+    TROOT=$STHOST/emos_esuite/emos_data
+    WROOT=$STHOST/emos_esuite/emos_data
+    OROOT=$STHOST/emos_data
+    WBASE=/
+    FDB_ROOT=$STHOST/emos_esuite/ma_fdb
+    FDB_ROOT_BKUP=$STHOST_BKUP/emos_esuite/ma_fdb
+    FDB_IROOT=$STHOST/emos_esuite/ma_fdb
+    WAVEEPS_ROOT=$FDB_ROOT
+    WAVEEPS_IROOT=$FDB_IROOT
+  else
+    TROOT=$STHOST/emos_data
+    WROOT=$STHOST/emos_data
+    OROOT=$STHOST/emos_data
+    FDB_ROOT=$STHOST/ma_fdb
+    FDB_ROOT_BKUP=$STHOST_BKUP/ma_fdb
+    FDB_IROOT=$STHOST/ma_fdb
+    WAVEEPS_ROOT=$STHOST$FDB_ROOT
+    WAVEEPS_IROOT=$STHOST$FDB_IROOT
+  fi
+  if [[ "%FSFAMILY%" = mars  ]] ; then
+    WROOT=/od_archive/data
+  fi
+elif [[ $ARCH = linux ]] ; then
+  TROOT=/var/tmp/tmpdir/emos
+  WROOT=/var/tmp/tmpdir/emos
+  OROOT=/var/tmp/tmpdir/emos
+  FDB_ROOT=""
+  FDB_IROOT=""
+else
+  TROOT=/var/tmp/emos
+  WROOT=/var/tmp/emos
+  OROOT=/var/tmp/emos
+  FDB_ROOT=""
+  FDB_IROOT=""
+fi
+
+WBASE=${WROOT}/${EXPVER}
+
+XROOT=/home/ma/emos
+XLIB=$XROOT/lib/${IFS_CYCLE}
+XDATA=$XROOT/data
+XBINS=$XROOT/bin
+XMOD=/cc/rd/module/frt
+XSRC=$XROOT/src
+ODATA=/home/ma/emos/data
+SCRATCH=/ws/scratch/ma/emos
+
+FSROOT=/$USER
+FSOROOT=/emos
+FSFAMILY=""
+FSXDATA=/emos/data
+FSXBINS=/emos/$ARCH/bin
+
+#=======================================================================
+#
+#  The following is the configuration filled in by the SMS
+#
+#=======================================================================
+
+#EXPVER=%VERSION% # done further up...
+
+if [[ "%USE_YMD:false%" = true ]] ; then
+  BASETIME=%YMD%%EMOS_BASE%
+else
+  BASETIME=%YYYY%%MM%%DD%%EMOS_BASE%
+fi
+
+FSFAMILY=%FSFAMILY%
+
+ECF_PASS=%ECF_PASS%
+ECF_HOST=%ECF_HOST%
+ECF_NAME=%ECF_NAME%
+ECF_TRYNO=%ECF_TRYNO%
+
+ECF_HOSTFILE=$HOME/.smshostfile
+ECF_PORT=%ECF_PORT%
+ECF_JOBOUT=%ECF_JOBOUT%
+
+
+SUITE=%SUITE%
+FAMILY=%FAMILY:NOT_DEF%
+TASK=%TASK%
+
+DEBUG=0
+DISPLAY=0
+
+# INFORM_EMOS_AUTORESOL=1
+
+#
+#  For e-suites only
+#
+if [[ $EXPVER -eq 2 ]] ; then
+  BASEVER=0002
+fi
+
+#Multianalysis
+INIMA="%INIMA:ecmwf%"
+INIMACONS=%INIMACONS:0%
+INIORIG=mars
+MANNCEP=0
+MANMFR=0
+MANDWD=0
+MANUKM=0
+
+INIORIGIN=OFF
+MAORIGINS="CONS"
+MAMISSING="%MAMISSING:%"
+
+if [[ %STREAM% = "MAED" || %STREAM% = MAWV ]] ; then
+  WAMRESOL=global100
+  WAMNFRE=30
+  WAMNANG=24
+  INIOZONE=false
+  LOZONE=false
+  LOZONECH=false
+  RESOL=399
+  LEVELS=62
+
+  for xxx in $INIMA ; do
+  if [[ "$xxx" = ncep ]] ; then
+    MANNCEP=1
+    MAORIGINS="$MAORIGINS KWBC"
+  elif [[ "$xxx" = mfr ]] ; then
+    MANMFR=1
+    MAORIGINS="$MAORIGINS LFPW"
+  elif [[ "$xxx" = ukm ]] ; then
+    MANUKM=1
+    MAORIGINS="$MAORIGINS EGRR"
+  elif [[ "$xxx" = dwd ]] ; then
+    MANDWD=1
+    MAORIGINS="$MAORIGINS EDZW"
+  fi
+  done
+
+
+  # Find WMO centre number. Do this more cleverly
+  if [[ $INIMACONS -eq 1 ]] ; then
+    INIORIGIN=CONS
+  elif [[ $INIMA = mfr ]] ; then
+   INIORIGIN=LFPW
+  elif [[ $INIMA = ncep ]] ; then
+   INIORIGIN=KWBC
+  elif [[ $INIMA = ukm ]] ; then
+   INIORIGIN=EGRR
+  elif [[ $INIMA = dwd ]] ; then
+   INIORIGIN=EDZW
+  fi
+
+fi
+
+#=================================================
+# For mars compute. This will use model number found.
+# If not set, model number will be 255.
+export MARS_COMPUTE_FLAG=0
+
+# User for e-suite plots
+EPLOT_USER=mos
+
+set +a
+
+if [[ %DELTA_DAY% -ne 0 ]] ; then
+  delta=`expr %DELTA_DAY% \* 24`
+  BASETIME=`newdate $BASETIME $delta`
+fi
+
+if [[ $FSFAMILY = "refc" ]] ; then
+  HC_REFDATE=`echo $BASETIME | cut -c 1-8`
+  EPSTYPE=fc
+
+  export HC_REFDATE EPSTYPE
+
+  if [[ %YEAR:0% -ne 0 ]] ; then
+    YEAR=%YEAR:0%
+    YYYY=`echo $BASETIME | cut -c 1-4`
+    MM=`echo $BASETIME | cut -c 5-6`
+    DDHH=`echo $BASETIME | cut -c 7-10`
+    if [[ $MM$DDHH = 0229* ]] ; then
+      BASETIME=`newdate $(( $YEAR$MM$DDHH - 100 )) 24 `
+    else
+      BASETIME=$YEAR$MM$DDHH
+    fi
+  fi
+fi
+
+DELTA_YEAR=%DELTA_YEAR:0%
+YYYY=`echo $BASETIME | cut -c 1-4`
+YYYY=$(( $DELTA_YEAR + $YYYY ))
+if [[ $DELTA_YEAR -ne 0 ]] ; then
+  YYYY=`echo $BASETIME | cut -c 1-4`
+  DELTA_YEAR=%DELTA_YEAR:0%
+  MMDDHH=`echo $BASETIME | cut -c 5-10`
+  YYYY=$(( $DELTA_YEAR + $YYYY ))
+  BASETIME=$YYYY$MMDDHH
+  YMD=$(substring $BASETIME 1 8)
+fi
+
+DELTA_HOUR=%DELTA_HOUR:0%
+if [[ $DELTA_HOUR -ne 0 ]] ; then
+  BASETIME=`newdate $BASETIME $DELTA_HOUR`
+fi
+
+# remove when hpcf gone
+if [[ $HOST = hpc* ]] ; then
+  EMOSLIB="-qextname $EMOSLIB"
+fi
+
+if [[ $ARCH = linux ]] ; then
+  export LINK_C="pgf90 -tp k8-32 -g"
+  export LINK_F="pgf90 -tp k8-32 -g"
+fi
+
+if [[ "%OD_PROJ:od%" = no ]] ; then
+  ### TEPS project
+  EPSHEM=1
+  EPSGAMMA=0.016
+  EPSBASIS=10
+  EPSMEMBERS=21
+  EPSNENS=20
+  GRIBCLASS=113 # from http://www.ecmwf.int/publications/manuals/libraries/gribex/gribClass.html
+fi
+
+#=====================================================================
+# ocean model configuration
+#======================================================================
+export RUNVARFC=%RUNVARFC:0%
+export EPSLEG=%EPSLEG:1%
+if [[ $RUNHINDCAST = 1 ]] ; then
+  # export HC_REFDATE=%YMD%
+  export HC_REFDATE=$((YYYY -(DELTA_YEAR)))`echo $BASETIME | cut -c 5-8`
+
+INIMODISALB=false # if intial data was run with 32r1 or later
+
+#==========================================================
+# Variables configuring inidata
+#==========================================================
+INIPATH="/net/fujitsu/ifs/initial/t95r/ic_19r1_%YMD%"
+INISTREAM=DA
+INITYPE=an
+INISTEP=0
+INISPQ=no
+LFG=.true.
+INIOFFSET=0
+INISCHEME=lslag
+SAVINI=""
+SVRF=no
+IFRF=no
+FORCE_FP=no
+
+INICLASS=`oper_model -b $BASETIME -c`
+INIRESOL=`oper_model -b $BASETIME -r`
+INILEVELS=`oper_model -b $BASETIME -l`
+INIGTYPE=`oper_model -b $BASETIME -t`
+INIEXPVER=`oper_model -b $BASETIME -e`
+INITILES=`oper_model -b $BASETIME -T`
+INICLOUDAN=`oper_model -b $BASETIME -C`
+
+if [[ %RUNHINDCAST:0% = 0 ]] ; then
+  INILEVELS=91
+  INIRESOL=799
+
+if [[ $BASETIME -le %ERA40END:2002073100% ]] ; then
+  INICLASS=e4
+  INILEVELS=60
+  INIEXPVER=0001
+  INITILES=true
+  INICLOUDAN=true
+  INIMODISALB=false
+  EPSGAMMA=0.018
+fi
+
+else # HINDCAST mode
+  INICLASS=ei
+  INILEVELS=60
+
+  if [[ $BASETIME -lt 2008010100 ]] ; then
+    INIEXPVER=0001
+  else
+    INIEXPVER=1112 # temporary while Manuel is changing 1112 to 0001
+  fi
+  EPSGAMMA=0.016 # to be updated according to Martin Leutbecher
+  INIRESOL=255
+  INIMODISALB=true
+  INIHTESSEL=false
+  INITILES=true
+fi
+
+fi
+
+export MARS_CMD='mars'
+
+if [[ %RUNHINDCAST:0% = 1 ]] ; then
+  INIHTESSEL=`oper_model -b $BASETIME -I ${CLASSORIG:="er_ops"} -H`
+fi
+
+### check if MOFC-VarEps is to run
+  sim=`newdate -d -D $BASETIME`
+  real=`date +'%%Y%%m%%d'`
+  real=`newdate -d -D $real`
+  dow=`date +'%%u'`
+  res=$((($sim - $real + $dow) %% 7))
+
+  if [[ $((res)) -lt 0 ]] ; then res=$((res+7)); fi
+
+  RUN_VAREPS=0
+  if [[ $res = 4 ]] ; then # Thursday MOFC
+    RUN_VAREPS=1
+  fi
+  export EPSNLEGS=$((2+$RUN_VAREPS)) # do not refer to sms variables while this changes
+  # 35r2
+  export EPSCOUPL_A=no                    # 35r2
+  export EPSCOUPLE_A=0                    # 35r2
+  CC=`substring $BASETIME 9 10`           # later EMOS_BASE
+  export EPSCOUPLE_B=$((CC == 00))        # 35r2
+  export EPSCOUPLE_C=$RUN_VAREPS          # 35r2
+
+
+export RUN_VAREPS
+###########
+export OCNINDAT=$(substring $BASETIME 1 8) # 19900101
+
+if [[ $EPSLEG != 1 ]] || [[ $RUNVARFC = 1 ]] ; then
+set -a
+
+
+ENAMELIST=general
+FULL_POS=yes
+LPPL=1
+LPSU=1
+LPPV=0
+LPTH=0
+LPGZ=0
+PPSTEPS="0"
+ERF=408
+FRQRF=-1
+DATE_BRANCH=2005112409
+USEDATE_BRANCH=no
+VIEW=""
+VIEW_HOPE="hope_h2e20"
+OCEPS=no
+OCUSESV=no
+EPSLROT=no
+OCPATM=yes
+OCFCRESOL=255
+OCFCLEVELS=62
+OCFCGTYPE=l_2
+OCFCTSTEP=%TSTEP:1800%.0
+FCCHUNKTOT=1
+NEWSTREAMLIB=none
+SAVLIB=false
+OCEAN_BRANCH="neh_h2e20_enfo"
+OCEAN_CYCLE="h2e20"
+OCIAUFR=2
+if [[ $RUNHINDCAST = 1 ]] ; then
+
+GRIB_API_VERSION=1.7.0
+GRIB_API_INCLUDE="-I/usr/local/lib/metaps/lib/grib_api/jasper/include -I/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/include"
+GRIB_API_LIB="-L/usr/local/lib/metaps/lib/grib_api/jasper/lib -ljasper -L/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/lib -lgrib_api_f90 -lgrib_api"
+export GRIB_API=/usr/local/lib/metaps/lib/grib_api/$GRIB_API_VERSION/bin   # change to fixed version
+export PATH=$GRIB_API:$PATH
+
+  if [[ $HC_REFDATE -lt 20080605 ]] ; then
+    OCINI="seas_0001_01_NN_${OCNINDAT}_od_02"
+  else
+    OCINI="ocea_0001_01_NN_$(substring $BASETIME 1 8)_od_03"
+  fi
+else
+  OCINI="ocea_0001_01_NN_$(substring $BASETIME 1 8)_od_03"
+fi
+OCNEWREST=false
+OCNMINI="00"
+CLASSORIG=e4_ops
+
+OCRUNCTRLAN=no
+OCRUNCTRLAC=no
+OCRUNCTRLFC=no
+OCRUNASSIMAN=no
+OCRUNASSIMAC=yes
+OCRUNASSIMFC=yes
+MEMBERSTATE=no
+%include <config.oc.h>
+
+ OCINPUT=mars
+ OCSUITE=vareps
+ if [[ -n $OCINI ]] ;then
+    OCINPUT=$(substring $OCINI 1 4)
+ fi
+
+ if [[ $OCINPUT != 'ecfs' ]] ; then
+   OCSTREAM_INI=$OCINPUT
+    if [[ $OCINPUT = 'mars' ]];then
+      OCSTREAM_INI='ocea' # 'seas'
+    fi
+    if [[ $OCINPUT = 'seas' ]];then
+      OCINPUT='mars'
+    fi
+    if [[ $OCINPUT = 'mofc' ]];then
+     OCINPUT='mars'
+    fi
+   OCEXPVER_INI=0001 # $(substring $OCINI 6 9 )
+   OCMETHOD_INI=$(substring $OCINI 11 12 )
+   OCNUMBER_INI=$(substring $OCINI 14 15 )
+   OCDATE_INI=$(substring $OCINI 17 24 )
+   OCCLASS_INI=$(substring $OCINI 26 27 )
+   OCSYST_INI=$(substring $OCINI 29 30 )
+ fi
+
+# For EPS runs only. Change of EPSNORM
+#
+   LASTERA40=%ERA40END:2000070100%
+
+  if [[ $OCEPS = "yes" ]] ; then
+     if [[ $BASETIME  -le 2001031400 ]] || [[ $BASETIME  -le $LASTERA40 ]] ;
+     then
+        EPSNORM=2.0
+        EPSNORMT=2.0
+     fi
+     EPSTROP=%EPSTROP:$EPSTROP%
+     EPSSVDIAB=%EPSSVDIAB:$EPSSVDIAB%
+     EPSSVNUM=%EPSSVNUM:$EPSSVNUM%
+  fi
+
+#=======================================================================
+#  special mofc variables
+#=======================================================================
+
+# pop/web/mofc
+
+MOFC_PROCESS=$WROOT/data/%SUITE%_process
+MOFC_PROCESS=`echo $MOFC_PROCESS | sed -e 's/var\/tmp\/tmpdir\/emos\/data/emos_data/'`
+Y=`echo $BASETIME | cut -c 1-4`
+STREAM=EF
+CLIMYEAR1=$((Y + - %NH_YEARS:18%))
+CLIMYEAR2=$((Y - 1))
+OCUTILS=$XBINS/$STREAM/$EXPVER
+
+export NH_ENSEMBLES=%NH_ENSEMBLES:4%
+export MOFC_PROCESS
+
+if [[ %RUNHINDCAST:0% = 1 ]] ; then
+  MOFCCLIM_VERIF=$WROOT/data/%SUITE%_clim
+  [[ -d $MOFCCLIM_VERIF ]] || mkdir -p $MOFCCLIM_VERIF
+  MOFC_VERIFY=/gpfs1/emos_verify/data/%SUITE%_verify
+  export PATH=$PATH:$HOME/bin/EF/verify
+  [[ -d $MOFC_VERIFY ]] || mkdir -p $MOFC_VERIFY
+
+  INIHTESSEL=`oper_model -b $BASETIME -I ${CLASSORIG:="er_ops"} -H`
+fi
+
+fi
+
+set -a
+
+if [[ %EPSTYPE:cf% = sv ]] ; then
+   INIMODISALB=false
+fi
+
+if [[ "%STREAM%" = EF ]] ; then
+  INIPERIOD_4D=%INIPERIOD_4D:12%
+else
+  INIPERIOD_4D=12
+fi
+
+if [[ "%FSFAMILY:0%" != refc ]] && [[ %RUNHINDCAST:0% != 1 ]] ; then
+  LVARBC=true
+else
+  LVARBC=false
+  INIMODISALB=false # if intial data was run with 32r1 or later
+
+  date4v12h=2000091200
+  # CHANGE date_dcda=2004062900
+  date_dcda=2004062912
+  if [ $BASETIME -ge $date4v12h ] ; then
+     INIPERIOD_4D=12
+  fi
+  if [ $BASETIME -ge $date_dcda ] ; then
+    INIPERIOD_4D=6
+  fi
+fi
+
+inidate=`echo $BASETIME | cut -c 1-8`
+if [ ${inidate} -ge 19971125 ] && [ $INICLASS = od ] && [ $INIPERIOD_4D = 6 ] ; then
+    INIOFFSET_4D=3
+elif [ $INICLASS = ei ] ; then
+    INIOFFSET_4D=9
+elif [ $INICLASS = e4 ] ; then
+    INIOFFSET_4D=3
+elif [ $INIPERIOD_4D = 12 ] ; then
+  if [[ %RUNHINDCAST:0% = 1 ]] || [[ %STREAM:UNDEF% = EF ]] ; then
+    INIOFFSET_4D=9
+  else
+    INIOFFSET_4D=3
+  fi
+elif [ $INIPERIOD_4D = 6 ] ; then
+    INIOFFSET_4D=3
+else
+    INIOFFSET_4D=0
+fi
+
+### SST ###
+CLMSST=no
+PERSST=%PERSST:false%
+FORCE_SST=no
+SSTLEN=%SSTLEN:240%
+SSTINT=%SSTINT:1%
+LOSTIA=%LOSTIA:true%              # 33r2
+
+NUMBER=%FCTOTAL:NOT_SET%
+VAR=%VAR:NOT_SET%
+CNUMBER=5
+
+if [[ "%SUITE%" = @(mc*|emc*|mofc*|emofc*|ma|tparc*|dts*) || $SUITE_TYPE = "eps" ]] ; then
+  LWEAK4DVAR=false
+  LEMISKF=false
+  LOZONE=false
+  INIOZONE=false
+  LOZONECH=false
+  LVARBC=false
+else
+  LWEAK4DVAR=true
+  LEMISKF=true
+fi
+
+
+set +a
+
+
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/config.oc.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/config.oc.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/config.oc.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/config.oc.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,197 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+# EXPVER=et34
+#==========================================================
+# Variables configuring emptyNamelist
+#==========================================================
+ENAMELIST=general
+#
+#==========================================================
+# Variables configuring wsconfig
+#==========================================================
+
+# WSHOST=metis
+# SCRATCH="/scratch/rd/rdx"
+#
+#==========================================================
+# Variables configuring ppgeneral
+#==========================================================
+
+IFSMODE=fc
+#PERIOD=6
+#PERIOD_4D=12
+
+FULL_POS=yes
+LPPL=1
+LPSU=1
+LPML=0
+LPPV=0
+LPTH=0
+LPGZ=0
+#PPFRQ=24
+PPSTEPS="0"
+#BRF=0
+ERF=408
+FRQRF=-1
+#
+#==========================================================
+# Variables configuring Ozone
+#==========================================================
+LOZONE=false
+LOZONECH=false
+#
+#==========================================================
+# Variables configuring clearcase
+#==========================================================
+#PROJECTS="none"
+DATE_BRANCH=2005112409
+USEDATE_BRANCH=no
+VIEW=""
+VIEW_HOPE="hope_h2e20"
+#
+#==========================================================
+# Variables configuring eps_svect
+#==========================================================
+OCEPS=no
+OCUSESV=no
+EPSLROT=no
+EPSNLEGS=%EPSNLEGS:3%
+EPSFCLEV_A=40
+EPSTSTEP_A=1800
+EPSFCLEV_B=40
+EPSTSTEP_B=%TSTEP:2700% # 2700
+EPSFCLEV_C=40
+EPSTSTEP_C=%TSTEP:2700% # 2700
+
+#
+#==========================================================
+# Variables configuring Dr_Hook
+#==========================================================
+#DR_HOOK=true
+#DR_HOOK_OPT="none"
+#DR_HOOK_PROFILE_LIMIT=-10
+#DR_HOOK_HASHBITS=15
+#DR_HOOK_CATCH_SIGNALS=0
+#DR_HOOK_IGNORE_SIGNALS=0
+#
+#==========================================================
+# Variables configuring wavgeneral
+#==========================================================
+#WAVE=yes
+#INIWAVE=yes
+#WAM2WAY=yes
+#WAMALT=no
+#WAMSAR=no
+#WAMSARASS=false
+#WGRIBIN=yes
+#WAMNSTPW=1
+#WAMRESOL=global100
+#WAMCOLDLENGTH=240
+WAMNFRE=%EPSWAMNFRE:25%
+WAMNANG=%EPSWAMNANG:12%
+#WAMFCPARAM="229/230/231/232/220/221/244/233/245"
+#
+#==========================================================
+# Variables configuring compile
+#==========================================================
+OCPATM=yes
+#LD="mpxlf90_r"
+#LDCC="xlc_r"
+#USE=standard
+#USECC=vac_6000
+#PARALLEL=4
+#NATIVE=true
+#F90_DEBUG=0
+#RUN_PARALLEL=true
+#EC_FILL_NANS=false
+#
+#==========================================================
+# Variables configuring system
+#==========================================================
+# ABO all comments
+#FSROOT="/RDX/prepIFS"
+#FSOROOT="/emos"
+#ABO FSXDATA="/ocx/data"
+#ABO FSXBINS="/ocx/$ARCH/bin"
+#ACCOUNT=ecrmoc
+#USER=ocx
+#GROUP=rd
+#FDB_GROUP=ecmwf
+#BASEVER=0001
+#CLASS=rd
+#GRIBCLASS=2
+#NOW=2005112409
+#MEMBERSTATE=no
+#
+#==========================================================
+# Variables configuring submit
+#==========================================================
+#SMS_NAME=ocx-prod
+#
+#==========================================================
+# Variables configuring general
+#==========================================================
+OCFCRESOL=255
+OCFCLEVELS=62
+OCFCGTYPE=l_2
+OCFCTSTEP=%TSTEP:1800%.0
+FCCHUNKTOT=1
+VERSION="fc"
+LESUITE=false
+#
+#==========================================================
+# Variables configuring libraries
+#==========================================================
+# IFS_CYCLE="31r1"
+# Q2USE=true
+# EMOS_CYCLE="000281"
+# Q2CREATE_NEWSTREAM=false
+# NEWSTREAM=none
+NEWSTREAMLIB=none
+# LIBRESOL=".R64.D64.I32"
+SAVLIB=false
+#GETLIB=false
+# MAKE_LIBS=yes
+# Q2CHANGELIST=0
+OCEAN_BRANCH="neh_h2e20_enfo"
+OCEAN_CYCLE="h2e20"
+#
+#==========================================================
+# Variables configuring inidata
+#==========================================================
+#OCNINDAT=$(substring $BASETIME 1 8) # 19900101
+#OCIAUFR=2
+#if [[ $RUNHINDCAST = 1 ]] ; then
+#OCINI="seas_0001_01_NN_${OCNINDAT}_od_02"
+#else
+#OCINI="ocea_0001_01_NN_$(substring $BASETIME 1 8)_od_03"
+## "seas_0001_01_NN_${OCNINDAT}_od_02"
+#fi
+#OCNEWREST=false
+#OCNMINI="00"
+#INIORIG=mars
+#CLASSORIG=e4_ops
+#INISCHEME=lslag
+SVRF=no
+IFRF=no
+#
+#==========================================================
+# Variables configuring ocgeneral
+#==========================================================
+OCRUNCTRLAN=no
+OCRUNCTRLAC=no
+OCRUNCTRLFC=no
+OCRUNASSIMAN=no
+OCRUNASSIMAC=yes
+OCRUNASSIMFC=yes
+#
+MEMBERSTATE=no
+#if [ $RUNVARFC -eq 1 ] ; then
+#  OCSUITE=vareps
+#fi
+
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/endt.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/endt.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/endt.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/endt.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+#==========================================================================
+#  End task (complete -> SMS)
+#  Clean up and exit
+#==========================================================================
+
+smscomplete ; trap 0 ; exit
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/head.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/head.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+#!/bin/ksh
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+
+# Defines the three variables that are needed for any
+# communication with ECF_
+
+export ECF_PORT=%ECF_PORT%    # The port on the ecflow server
+export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%
+fi
+
+# Tell ECF_ we have stated
+# The ECF_ variable ECF_RID will be set to parameter of smsinit
+# Here we give the current PID.
+
+#smsinit $$
+
+# Defined a error hanlder
+
+ERROR() {
+	set +e        # Clear -e flag, so we don't fail
+	#smsabort      # Notify ECF_ that something went wrong
+	trap 0        # Remove the trap
+	exit 0        # End the script
+}
+
+# Trap any calls to exit and errors caught by the -e flag
+
+trap ERROR 0
+
+# Trap any signal that may cause the script to fail
+
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/law.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/law.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/law.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/law.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,43 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+### start of law.h, normally included from config.h ####################
+
+# Override for local area wave model
+if [[ "%FSFAMILY%" = "euroshelf" ]] ; then
+  set -a
+  PPFRQ=6
+  WAMRESOL=medite10
+  WAMANLEN=12
+  WAMFCLEN=120
+  WAMSAR=yes
+  WAMIDELRES=6
+  INIWDEXPVER=%INIWDEXPVER:0001%     # expver for wind forcing
+  INIWDCLASS=%INIWDCLASS:od%
+  INIWDSTREAM=DA
+  WGRIBIN=yes
+  gflag=T
+  nsysnb=-1
+  nmetnb=-1
+
+  ALTIMETER=ers2
+  SAR=ers2
+  ERS=`echo $SAR | cut -c4`
+
+  model=medite
+  FSALT=$FSBASE/${ALTIMETER}/alt/$model
+  FSALT_B=$FSBASE/${ALTIMETER}_b/alt/$model
+  FSALT_S=$FSBASE/${ALTIMETER}_s/alt/$model
+  FSSAR=$FSBASE/${SAR}/sar/$model
+  FSSAR_B=$FSBASE/${SAR}_b/sar/$model
+  FSSAR_S=$FSBASE/${SAR}_s/sar/$model
+
+  WAVE_ROOT=$FDB_ROOT
+  WAVE_IROOT=$FDB_IROOT
+
+fi
+# end of law.h #################################
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/qsub.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/qsub.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/qsub.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/qsub.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+:
+# QSUB -q %QUEUE%
+# QSUB -u %USER%
+# QSUB -eo
+# QSUB -ro
+# QSUB -ko
+# QSUB -nr
+# QSUB -A %ACCOUNT%
+# QSUB -s /bin/ksh
+# QSUB -r %TASK%-%FAMILY1%
+# QSUB -o %LOGDIR%%SMSNAME%.%SMSTRYNO%
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/rcp.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/rcp.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/rcp.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/rcp.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+#  rcp.h
+
+SMSRCP() {
+  set -x
+  set +e
+  if [[ "${ARCH:=UNDEF}" = hppa || "${ARCH:=UNDEF}" = hpia64 ]] ; then
+    if [[ $PBS_JOBID = NOT_SET ]] ; then
+      rcp %LOGDIR%%SMSNAME%.%SMSTRYNO% \
+          emos@%SMSNODE%:%SMSOUT%%SMSNAME%.%SMSTRYNO%
+    else
+      rm -f %SMSJOBOUT% || : # remove link
+
+      # hardcoded to hanfs2 then mordred to release load on ablamor
+      rcp /var/spool/PBS/spool/${PBS_JOBID}.OU \
+        emos@hanfs2:/hanfs%SMSHOME%%SMSNAME%.%SMSTRYNO% || \
+      rcp /var/spool/PBS/spool/${PBS_JOBID}.OU \
+        emos@mordred:%SMSHOME%%SMSNAME%.%SMSTRYNO% || \
+      rcp /var/spool/PBS/spool/${PBS_JOBID}.OU \
+        emos@%SMSNODE%:%SMSHOME%%SMSNAME%.%SMSTRYNO%
+
+      link_name=`~emos/bin/subs_path.pl -f %SMSOUT% -t $TOPATH -n %SMSJOBOUT%`
+      rm -f $link_name || :
+
+    fi
+  fi
+
+  if [[ ${ARCH:=UNDEF} = ibm_power* ]] ; then
+    rcp %LOGDIR%%SMSNAME%.%SMSTRYNO% %SMSNODE%:%SMSHOME%%SMSNAME%.%SMSTRYNO%
+  fi
+
+}
+typeset -fx SMSRCP
+
+#  end of rcp.h
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/recursive_include.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/recursive_include.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/recursive_include.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/recursive_include.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+# test includeonce with a recursive include
+%includeonce <recursive_include.h>
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/set_traps.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/set_traps.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/set_traps.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/set_traps.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/setup.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/setup.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/setup.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/setup.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,535 @@
+banner setup.h
+#=======================================================================
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+USER=${USER:=$LOGNAME}
+
+set -a
+
+#=======================================================================
+#  Get the prompt PS4 to be ok with -u option
+#=======================================================================
+
+typeset -Z2 _h _m _s
+if [[ $ARCH != linux ]] ; then
+SECONDS="$(date '+3600*%%H+60*%%M+%%S')"
+_x=""
+_time='${_x[(_h=(SECONDS/3600)%%24)==(_m=SECONDS/60%%60)==(_s=SECONDS%%60)]}$_h:$_m:$_s'
+PS4="$_time + "
+elif [[ $ARCH = linux ]] ; then
+  set +e
+  LKSH93=`isksh93 && echo "true" || echo "false"`
+  set -e
+  if [[ $ARCH = linux ]] && [[ "$LKSH93" = "true" ]] ; then
+# ksh93 syntax
+    _time='$((_h=(SECONDS/3600)%%24)):$((_m=(SECONDS/60)%%60)):$((_s=SECONDS%%60))'
+    PS4="$_time + "
+  fi
+fi
+
+unset _hh _mm || true
+#=======================================================================
+#
+#  Distinguish between OD and RD
+#
+#=======================================================================
+
+STREAM=%STREAM:DA%
+if [[ $STREAM = DA ]] ; then
+  stream=""
+else
+  stream="/${STREAM}"
+fi
+
+  # OD_MODE is set to false (default) for rd, e4 projects
+  #                   true for od and all od projects
+  OD_MODE=true
+  CLASS=%OD_PROJ:od%
+  OD_PROJ=%OD_PROJ:od%
+
+  #---------------------------------------------------------------------
+  #  EMOS specific setup
+  #---------------------------------------------------------------------
+
+  EMOS_YEAR=`substring $BASETIME 1 4`
+  EMOS_MONTH=`substring $BASETIME 5 6`
+  EMOS_DAY=`substring $BASETIME 7 8`
+  EMOS_BASE=`substring $BASETIME 9 10`
+  EMOS_VERSION=$EXPVER
+  EMOS_TIME_STEP_H=%EMOS_TIME_STEP_H%
+  EMOS_STREAM=$STREAM
+
+  if [[ $EXPVER -ne 1 && $EXPVER -ne 2 ]] ; then
+    alias -x gksplot="gksplot -u $EPLOT_USER"
+    alias -x magplot="magplot -u $EPLOT_USER"
+  fi
+
+#=======================================================================
+#
+#  Derive the disk variables
+#
+#=======================================================================
+
+export FWROOT=$FSROOT/${EXPVER} # this variable for similar path WITHOUT stream
+export FWBASE=$FSROOT/${EXPVER} # this variable for similar path WITHOUT stream
+
+if [[ %OD_PROJ:od% != od ]] ; then
+  BASE=$TROOT/$CLASS/$EXPVER
+  WORK=$WROOT/$CLASS/$EXPVER
+  LIBS=$BASE/lib
+  BINS=$BASE/bin
+  DATA=$BASE/data
+
+elif [[ $STREAM = MAED ]] ; then
+  TROOT=${TROOT}/${STREAM}
+  WROOT=${WROOT}/${STREAM}
+  FSROOT=${FSROOT}/${STREAM}
+  BASE=$TROOT/$EXPVER
+  WORK=$WROOT/$EXPVER
+  LIBS=$BASE/lib
+  BINS=$BASE/bin
+  DATA=$BASE/data
+
+elif [[ $STREAM = DCDA ]] ; then
+  # TBD TBD TBD ODIR configuration for operational mode
+
+  BASE=$TROOT/$EXPVER
+  LIBS=$BASE/lib
+  BINS=$BASE/bin
+  DATA=$BASE/data
+  TROOT=${TROOT}/${STREAM}
+  BASE=$TROOT/$EXPVER
+  WROOT=${WROOT}/${STREAM}
+  WORK=$WROOT/$EXPVER
+  FSROOT=${FSROOT}/${STREAM}
+  FSODB=${FSODB}/${STREAM}
+
+else
+  BASE=$TROOT/$EXPVER
+  WORK=$WROOT/$EXPVER
+  LIBS=$BASE/lib
+  BINS=$BASE/bin
+  DATA=$BASE/data
+fi
+
+
+if [[ $OD_MODE = true ]] ; then
+  LOGS=%LOGDIR%/$SUITE/$FAMILY
+else
+  LOGS=$TROOT/log/$SUITE/$FAMILY
+fi
+
+if [ "$FSFAMILY" != "" ] ; then
+  PATH=${XBINS}/${ARCH}/${IFS_CYCLE}/${FSFAMILY}:${XBINS}/${ARCH}/${IFS_CYCLE}:${XBINS}/${ARCH}/${IFS_CYCLE}/an:/${BINS}/${FSFAMILY}:${HOME}/bin/${FSFAMILY}:${XBINS}/${IFS_CYCLE}:${XBINS}/an:$PATH:$emosbin:${HOME}/bin/${ARCH}
+  FSFAMILY=/$FSFAMILY
+fi
+
+SUBFSFAMILY=%SUBFSFAMILY:""%
+
+XDIR=$XROOT/bin
+ADIR=$BASE/${BASETIME}${FSFAMILY}$SUBFSFAMILY
+WDIR=$WORK/${BASETIME}${FSFAMILY}$SUBFSFAMILY
+ODIR=$OROOT/0001/${BASETIME}
+
+
+if [[ "$STREAM" = MAED ]] ; then
+ if [[ "$FSFAMILY" = "/fc" ]] ; then
+   if [[ $INIMACONS -eq 1 ]] ; then
+    ADIR="${ADIR}_cons"
+    WDIR="${WDIR}_cons"
+   elif [[ "$INIMA" != "" ]] ; then
+     ADIR="${ADIR}_$INIMA"
+     WDIR="${WDIR}_$INIMA"
+   fi
+ fi
+fi
+
+PATH=$HOME/bin/ppdi:$TMPDIR:$BINS:$BINS/$WAMRESOL:$XROOT/bin/$EMOS_CYCLE:$PATH
+
+if [[ "$FSFAMILY" = /mc ]] && [[ $RUNHINDCAST != 1 ]] ; then
+  EMOS_STREAM=EF
+  STREAM=EF
+fi
+
+#=======================================================================
+#
+#  Suite specific fdb settings
+#
+#=======================================================================
+#=======================================================================
+#
+#  Derive the FileServer variables
+#
+#=======================================================================
+
+if [[ %OD_PROJ:od% = od ]] ; then
+  FSBASE=${FSROOT}${FSFAMILY}/${EXPVER}
+else
+  FSBASE=${FSROOT}${FSFAMILY}/${CLASS}/${EXPVER}
+fi
+
+FDBASE=$FSBASE
+
+FSHOST=${FSBASE}/${ARCH}
+
+FSLIBS=${FSHOST}/lib
+FSBINS=${FSHOST}/bin
+FSDATA=${FSHOST}/data
+FSODIR=${FSROOT}/0001/$(substring $BASETIME 1 6)/$(substring $BASETIME 7 10)
+
+DHSWAVE=${FSROOT}/${EXPVER}/wave
+
+if [[ "$FSFAMILY" = /euroshelf ]] ; then
+ DHSWAVE=${FSROOT}/${EXPVER}/euroshelf
+fi
+
+if [[ $OD_MODE = true ]] ; then
+  FSDIR=${FSBASE}/${BASETIME}
+  FSLOG=${FSBASE}/log
+
+  DHSTIME=$(substring $BASETIME 1 6)/$(substring $BASETIME 7 10)
+
+  FSBDIR=$FSOROOT/$EXPVER/$DHSTIME
+else
+  FSDIR=$FSROOT/${EXPVER}/${BASETIME}
+  FSLOG=$FSROOT/${EXPVER}/log
+
+  DHSTIME=${BASETIME}
+fi
+FODBDIR=${FSODB}${FSFAMILY}/${EXPVER}${stream}/${BASETIME}
+
+PSDIR=/ws/scratch/ma/emos/ps
+
+#=======================================================================
+# Set variable to run metview macros on a different fs from normal users
+# Please see comments in web.h if you want to change it.
+#
+# On linux cluster we use the default one
+#=======================================================================
+
+
+
+#=======================================================================
+#  Model variables that depend on configuration
+#=======================================================================
+
+VPP_MBX_SIZE=1000000
+MBX_SIZE=1000000
+MPP_TYPE=2
+if [[ $ARCH = @(ibm_power*) ]] ; then
+  MBX_SIZE=64000000
+fi
+
+[[ $RESOL = 213 || $RESOL = 319 ]] && NRESOL=160
+[[ $RESOL = 106 || $RESOL = 159 ]] && NRESOL=80
+[[ $RESOL = 511 ]] && NRESOL=256
+[[ $RESOL = 799 ]] && NRESOL=400
+[[ $RESOL = 255 ]] && NRESOL=160
+[[ $RESOL = 399 ]] && NRESOL=200
+
+
+if [[ $ARCH = @(ibm_power*) ]] ; then
+  CC=xlc_r
+  FRT=xlf90
+  FRT77=xlf
+  LD=mpxlf90_r
+  LDCC=xlc_r
+  BUILDWS=true
+  WSUSE=xlf_7112
+  PARALLEL=4
+  NATIVE=true
+  F90_DEBUG=0
+  RUN_PARALLEL=true
+fi
+#==========================================================
+# New for 33r1
+#==========================================================
+
+if [[ $ARCH = ibm_power4 ]] ; then
+  USE=xlf_11102
+elif [[ $ARCH = @(ibm_power6) ]] ; then
+  USE=standard
+fi
+
+if [[ $TASK != exp_setup ]] ; then
+  USE=${USE:-standard}
+
+  if [[ $USE != standard ]] && [[ $ARCH = ibm_power* ]] ; then
+    use $USE
+#    addon1=`echo $PATH | cut -d: -f1`
+#    addon2=`echo $PATH | cut -d: -f2`
+#    REDUCED_PATH=$addon1:$addon2:$REDUCED_PATH
+  fi
+fi
+
+set +a
+
+#=======================================================================
+#
+#  Functions to manipulate the variables
+#
+#=======================================================================
+
+NEWADIR() {
+  set -xe
+  if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi
+    echo $BASE/$(newdate $BASETIME $1)/$(basename $ADIR)
+}
+
+NEWWDIR() {
+  set -xe
+  if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi
+    # echo $WORK/$(newdate $BASETIME $1)/$(basename $WDIR) # 29r2 TBD
+    echo `echo $WDIR | sed -e "s/$BASETIME/$(newdate $BASETIME $1)/g"`
+}
+
+NEWFSBDIR() {
+  set -x
+    if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi;
+    XX=`newdate ${BASETIME} $1`;
+    # used to define the location for PS_BIAS file
+    # shall contain DCDA stream within the path _but_ this would mean
+    # modifying FSBDIR variable. However, too many script use already
+    # this variable.
+      echo $FSOROOT/$EXPVER/$(substring $XX 1 6)/$(substring $XX 7 10);
+# ${FSBASE}/$STREAM/$(substring $XX 1 6)/$(substring $XX 7 10)
+}
+
+NEWFDIR() {
+  set -xe
+    if [ $# -lt 1 ] ; then echo $0: error; return 1 ; fi;
+    XX=`newdate ${BASETIME} $1`;
+    echo $FSBASE/$(substring $XX 1 6)/$(substring $XX 7 10)
+}
+
+CHECK_DIR(){
+  if [[ $ARCH = ibm_power* ]]  ; then
+    trap '{ echo "Error in function"; exit 1; }' 0 $SMS_SIGNAL_LIST
+  fi
+  set -xeu
+  if [[ ! "$ARCH" = "linux" ]] ; then
+    trap '{ echo "Error in function"; exit 1; }' 0 $SMS_SIGNAL_LIST
+  fi
+  if [[ $# -eq 0 ]]; then
+    return 1
+  fi
+
+ if [[ $ARCH = ibm_power* ]] then
+   (umask 022;pmkdir $1 || exit )
+ else
+    mkdir -p -m 755 $1 || exit
+ fi
+  if [[ ! "$ARCH" = "linux" ]] ; then
+    trap 0
+  fi
+
+  return 0
+}
+
+
+PUT() {
+  set -xe
+  Ecp -o $1 ec:$FSDIR/$1 || return 1
+}
+
+GET() {
+  set -xe
+  Ecp ec:$FSDIR/$1 $1 || return 1
+}
+
+if [[ $OD_MODE = true ]] ; then
+
+  GETSV() {
+    set -xe
+    file=$(basename $2)
+    Ecp ec:$1/$file $2 || return 1
+  }
+
+else
+  GETSV() {
+       set -xe
+       Ecp ec:$1/$2 $2 || return 1
+  }
+
+fi
+
+typeset -fx NEWADIR NEWWDIR NEWFDIR CHECK_DIR PUT GET GETSV NEWFSBDIR
+
+if [[ $ARCH != fujitsu ]] ; then
+  function libselect { echo WARNING - dummy command : libselect $1 ;}
+  typeset -fx libselect
+fi
+
+export OLDADIR=`NEWADIR -$PERIOD`
+export OLDWDIR=`NEWWDIR -$PERIOD`
+export YESTERDIR=`NEWWDIR -24`
+
+#==========================================================================
+#  Copy postscript file into a scratch directory;
+#
+#  PSFILE [filename [countem [rename]]]
+#
+#  Default filename is "ps"
+#
+#  countem (set but can contain anything) means that there is more than
+#  one file from this task in which case the files are numbered.
+#
+#  If only one file is produced it is copied as
+#    ${_PSDIR}/${SUITE}${EMOS_BASE}${TASK}.ps
+#  otherwise it is copied as
+#    ${_PSDIR}/${SUITE}${EMOS_BASE}${TASK}.fileno.ps
+#  where fileno is counted automatically
+#
+#  If the third parameter is given the naming convention is not followed
+#  except that the file numbering is still being done (stupid if there's
+#  only one file, but what the hell...)
+#
+#  Old file is not saved
+#==========================================================================
+
+PSFILE() {
+  set +exv
+  if [ $# -ge 1 ] ; then _psfile="$1" ; else _psfile="ps" ; fi
+  if [ ! -f $_psfile ] ; then return 1; fi
+  if [ $# -ge 2 ] ; then _fileno=`expr ${_fileno:-0} + 1`; else _fileno=0; fi
+  if [ $# -ge 3 ] ; then _name=$3; else _name=${SUITE}${EMOS_BASE}${TASK}; fi
+
+  if [ ${_fileno} -gt 0 ] ; then
+    /bin/rm -f ${PSDIR}/${_name}.${_fileno}.ps
+    cp $_psfile ${PSDIR}/${_name}.${_fileno}.ps
+  else
+    /bin/rm -f ${PSDIR}/${_name}.ps
+    cp $_psfile ${PSDIR}/${_name}.ps
+  fi
+
+  set -ex
+}
+
+typeset -fx PSFILE
+
+#=======================================================================
+#  For FDB we need a different stream. Oh why can they not be the same?
+#=======================================================================
+
+set -a
+[[ $STREAM = DA   ]] && { WSTREAM=WV;   FDB_STREAM=oper; FDB_WSTREAM=wave; }
+[[ $STREAM = EF   ]] && { WSTREAM=WAEF; FDB_STREAM=enfo; FDB_WSTREAM=waef; }
+[[ $STREAM = SCDA ]] && { WSTREAM=SCWV; FDB_STREAM=scda; FDB_WSTREAM=scwv; }
+[[ $STREAM = MAED ]] && { WSTREAM=MAWV; FDB_STREAM=maed; FDB_WSTREAM=mawv; }
+[[ $STREAM = sens ]] && { WSTREAM=sens; FDB_STREAM=sens; FDB_WSTREAM=sens; }
+[[ $STREAM = SCDA ]] && unset FDB_SERVER_HOST || true
+[[ $STREAM = DCDA ]] && { WSTREAM=DCWV ; FDB_STREAM=dcda ;  FDB_WSTREAM=dcwv; }
+[[ $STREAM = EFHC ]] && { WSTREAM=EWHC ; FDB_STREAM=efhc ;  FDB_WSTREAM=ewhc; } # MC HINDCAST
+[[ $STREAM = ENFH ]] && { WSTREAM=ENWH; FDB_STREAM=enfh ;  FDB_WSTREAM=enwh; } # MC HINDCAST
+[[ $STREAM = DAHC ]] && { WSTREAM=WVHC ; FDB_STREAM=dahc ;  FDB_WSTREAM=wvhc; } # MC HINDCAST
+
+set +a
+
+#=======================================================================
+#  Check for day and date mask
+#=======================================================================
+
+echo checking for date mask
+
+datemask=$(echo '%DATEMASK%' | cut -f1 -d.)
+day=$(substring $BASETIME 7 8)
+weekday=%WEEKDAY:none%
+
+if [[ $weekday != "none" ]] ; then
+  jday=$(newdate -d $BASETIME)
+  jday=$(expr $jday %% 7) || true
+  if [[ $jday -eq 0 ]] ; then
+    dow=monday
+  elif [[ $jday -eq 1 ]] ; then
+    dow=tuesday
+  elif [[ $jday -eq 2 ]] ; then
+    dow=wednesday
+  elif [[ $jday -eq 3 ]] ; then
+    dow=thursday
+  elif [[ $jday -eq 4 ]] ; then
+    dow=friday
+  elif [[ $jday -eq 5 ]] ; then
+    dow=saturday
+  elif [[ $jday -eq 6 ]] ; then
+    dow=sunday
+  fi
+fi
+
+if [[ $datemask != "*" && $day -ne $datemask ]] || [[ $weekday != "none" && $weekday != $dow ]] ; then
+echo job should not run today ... setting it complete
+%include <endt.h>
+fi
+
+#=======================================================================
+#
+#  Check the directories
+#
+#=======================================================================
+
+CHECK_DIR $ADIR
+CHECK_DIR $WDIR
+
+if [[ $ARCH = ibm_power* ]];then
+  export PBIO_BUFSIZE=1048576
+fi
+
+#=======================================================================
+#
+#  Suite stopper
+#
+#=======================================================================
+
+if [[ %SUITE% = "e_35r3" && $BASETIME = "2012120500" ]] ; then
+  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
+  echo "Suite e_35r3 has been set up to stop now"
+  echo "Operators  You can suspend this suite and requeue failed tasks if you like!"
+  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
+  exit 1
+elif [[ %SUITE% = "emc_35r3" && $BASETIME = "2012022600" ]] ; then
+  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
+  echo "Suite emc_35r3 has been set up to stop now"
+  echo "Operators  You can suspend this suite and requeue failed tasks if you like!"
+  echo "ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR ERROR"
+  exit 1
+fi
+
+#=======================================================================
+# We use an operation only Magics version to be on the safe side.
+# This is of course only on the servers
+#=======================================================================
+MAGICS=%MAGICS:magics_emos%
+
+#=======================================================================
+# We use an operation only Metview version to be on the safe side.
+#=======================================================================
+
+if [[ $ARCH = linux ]] ; then
+  metview_cmd=%METVIEW:metview_emos%
+
+elif [[ $ARCH = ibm_power4 ]] ; then
+  METVIEW_TMPDIR=/home/ma/emos/metview/metview_tmpdir
+  metview_cmd=%METVIEW:/home/ma/emos/metview/MvRun_3.9.3%
+elif [[ $ARCH = ibm_power6 ]] ; then
+  METVIEW_TMPDIR=/home/ma/emos/metview/metview_tmpdir
+  metview_cmd=%METVIEW:/home/ma/emos/metview/MvRun_3.10%
+fi
+
+#=======================================================================
+# We use an operation only metpy version to be on the safe side.
+#=======================================================================
+metpy_cmd=%METPY:metpy_emos%
+
+echo setup complete
+
+# 20040720 add /home/rd/rdx/bin/filter/bufr_filter from hpcd
+#
+%include <law.h>
+
+export LEDFAMILY=%EDFAMILY:false%
+
+banner end setup.h
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/sms.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/sms.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/sms.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/sms.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+#==========================================================================
+#  Define environment variables and export them.
+#==========================================================================
+
+set -a
+
+ECF_PASS=%ECF_PASS%
+ECF_HOST=%ECF_HOST%
+ECF_NAME=%ECF_NAME%
+ECF_TRYNO=%ECF_TRYNO%
+ECF_RID=$(echo $QSUB_REQID | cut -f1 -d.)
+ECF_HOSTFILE=$HOME/.smshostfile
+ECF_PORT=%ECF_PORT%
+ECF_JOBOUT=%ECF_JOBOUT%
+
+SUITE=%SUITE%
+FAMILY=%FAMILY%
+TASK=%TASK%
+
+DEBUG=0
+DISPLAY=0
+
+#==========================================================================
+#  Initialize sms.
+#  Trap handling.
+#  Modify the ERROR function what to do in case of any error.
+#==========================================================================
+
+#if [[ $ARCH = sgimips && -f /usr/local/ecfs/prodn/.ecfs_k_env ]] ; then
+if [[ -f /usr/local/ecfs/prodn/.ecfs_k_env ]] ; then
+  . /usr/local/ecfs/prodn/.ecfs_k_env
+fi
+
+smsinit $ECF_RID &
+
+ERROR() {
+  smsabort; printenv; trap 0; exit
+}
+
+trap ERROR 0
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
+
+set -ex
+
+if [[ $ARCH = sgimips && -f /usr/local/ecfs/prodn/.ecfs_k_env ]] ; then
+  . /usr/local/ecfs/prodn/.ecfs_k_env
+fi
+
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/tail.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/tail.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+#smscomplete  # Notify SMS of a normal end
+trap 0       # Remove all traps
+exit 0       # End the shell
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/trap.h 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/trap.h
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/includes/trap.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/includes/trap.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,137 @@
+banner trap.h
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+
+#==========================================================================
+#  Trap handling and ECF_ initialisation
+#
+#  Write into the ERROR function what to do in case of any error.
+#==========================================================================
+
+typeset -l ARCH
+
+if [[ "$ARCH" = hpia64 ]] ; then
+  rcp /home/ma/emos/data/dummy.output emos@%ECF_HOST%:%ECF_JOBOUT% || true
+fi
+
+set -a
+LOADL_STEP_ID=${LOADL_STEP_ID:=NOT_SET}
+QSUB_REQID=${QSUB_REQID:=NOT_SET}
+PBS_JOBID=${PBS_JOBID:=NOT_SET}
+
+if [[ $LOADL_STEP_ID != NOT_SET ]] ; then
+  ECF_RID=$(echo $LOADL_STEP_ID | cut -f1 -d.)
+  ECF_RID=$(substring $ECF_RID 6 8  )
+  ECF_RID=$(echo $LOADL_STEP_ID | cut -f2 -d.)${ECF_RID}
+  JOB_ID=$LOADL_STEP_ID
+elif [[ $QSUB_REQID != NOT_SET ]] ; then
+  ECF_RID=$(echo $QSUB_REQID | cut -f1 -d.)
+  JOB_ID=$QSUB_REQID
+elif [[ $PBS_JOBID != NOT_SET ]] ; then
+  ECF_RID=$(echo $PBS_JOBID | cut -f1 -d.)
+  JOB_ID=$PBS_JOBID
+
+  TOPATH=%TOPATH:/tmp/output%
+  link_name=`~emos/bin/subs_path.pl -f %ECF_OUT% -t $TOPATH -n %ECF_JOBOUT%`
+  mkdir -p `dirname $link_name` || :
+  ln -sf /var/spool/PBS/spool/${PBS_JOBID}.OU $link_name || :
+  rm -f %ECF_JOBOUT% || :
+  ln -sf /var/spool/PBS/spool/${PBS_JOBID}.OU %ECF_JOBOUT%
+else
+  ECF_RID=$$
+  JOB_ID=$ECF_RID
+fi
+
+ECF_PASS=%ECF_PASS%
+ECF_HOST=%ECF_HOST%
+ECF_NAME=%ECF_NAME%
+ECF_TRYNO=%ECF_TRYNO%
+ECF_HOSTFILE=$HOME/.smshostfile
+ECF_JOBOUT=%ECF_JOBOUT%
+
+set +a
+ARCHWDIR=${ARCHWDIR:=""}
+
+SMSCLEAN() {
+  set -x
+  set +e
+  STREAM=${STREAM:=""}
+  if [[ "$STREAM" = @(SEAS|MOFC|OCEA|mnfc|mnfh) ]] ; then
+    if [[ "%TASK%" = logfiles ]] ; then
+      n=0
+      while [[ -d $WDIR ]] ; do
+        # Forked processes could still be around, and 'rm -rf' fails
+        rm -rf $WDIR || true
+        ls -l $WDIR && sleep 2 || true
+        n=$((n+1))
+        [[ $n -gt 5 ]] && break
+      done || true
+    fi
+  fi
+  FSFAMILY=${FSFAMILY:=""}
+  if [[ "$FSFAMILY" = /mars || "%FAMILY1%" = archive ]] ; then
+    cd $TMPDIR
+    n=0
+    while [[ -d ${WDIR}$ECF_NAME ]] ; do
+      # Forked processes could still be around, and 'rm -rf' fails
+      rm -rf ${WDIR}$ECF_NAME || true
+      ls -l ${WDIR}$ECF_NAME && sleep 2 || true
+      n=$((n+1))
+      [[ $n -gt 5 ]] && break
+    done || true
+  fi
+
+  if [[ $ARCH = linux ]] ; then
+    . /usr/local/share/ecmwf/share/.epilog
+  fi
+}
+typeset -fx SMSCLEAN
+
+%include <rcp.h>
+
+ERROR() {
+  set -x
+  set +e
+  wait
+  smsabort
+  trap 0
+  date
+  times
+  echo "environment was:"
+  printenv | sort
+
+  SMSCLEAN
+
+  if [[ $$ARCH != "ibm_power*" ]] ; then
+    SMSRCP || :
+  fi
+  exit 1
+}
+
+if [[ $ARCH == hpia64 ]]; then
+  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 10 12 13 15 24 30 33'
+elif [[ $ARCH == ibm_power* ]]; then
+  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 10 12 13 15 24 30'
+elif [[ $ARCH == linux ]]; then
+  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
+else
+  export SMS_SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
+fi
+
+%include <set_traps.h>
+trap
+set -exu
+
+[[ -d $TMPDIR ]] && cd $TMPDIR
+
+smsinit $ECF_RID &
+smsmsg "#ID ECF_NAME=%ECF_NAME%;ECF_JOBOUT=%ECF_JOBOUT%;ECF_HOME=%ECF_HOME%;JOB_ID=${JOB_ID:-}"
+
+date
+
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/micro_in_comment.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/micro_in_comment.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/micro_in_comment.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/micro_in_comment.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+echo do %% some work
+
+# mismatched micro characters staring with a # are not reported as errors
+#BSUB -o /u/Carolyn.Pasti/ecf/out/test500/sleep2.o%J
+#BSUB -e /u/Carolyn.Pasti/ecf/out/test500/sleep2.o%J
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/SMSHOME2/good/operations.ecf 5.13.0-1/libs/node/test/data/SMSHOME2/good/operations.ecf
--- 5.12.4-1/libs/node/test/data/SMSHOME2/good/operations.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/SMSHOME2/good/operations.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+
+# Since we have comment out, this should not appear in the jobs file
+#%include <qsub.h>
+# QSUB -lT 3500
+# QSUB -lt 3500
+# QSUB -lM 50mb
+
+%include <config.h>
+
+%include <trap.h>
+%include <setup.h>
+ 
+%include <endt.h>
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/common.h 5.13.0-1/libs/node/test/data/common.h
--- 5.12.4-1/libs/node/test/data/common.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/common.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+#
+# Used to test inclusion with angle brackets  <filename>
+# First look in %ECF_INCLUDE%/filename
+# If file not there then look at ECF_HOME/filename
+#
+# THIS ALLOWS USE TO PUT SPECIFIC FILES IN ECF_INCLUDE
+# AND COMMON FILE IN ECF_HOME
diff -pruN 5.12.4-1/libs/node/test/data/includes/AA.h 5.13.0-1/libs/node/test/data/includes/AA.h
--- 5.12.4-1/libs/node/test/data/includes/AA.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/AA.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+#startAA
+%includeonce <BB.h>
+#endAA
diff -pruN 5.12.4-1/libs/node/test/data/includes/BB.h 5.13.0-1/libs/node/test/data/includes/BB.h
--- 5.12.4-1/libs/node/test/data/includes/BB.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/BB.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+#startBB
+%includeonce <CC.h>
+#endBB
diff -pruN 5.12.4-1/libs/node/test/data/includes/CC.h 5.13.0-1/libs/node/test/data/includes/CC.h
--- 5.12.4-1/libs/node/test/data/includes/CC.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/CC.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#CC
diff -pruN 5.12.4-1/libs/node/test/data/includes/a.h 5.13.0-1/libs/node/test/data/includes/a.h
--- 5.12.4-1/libs/node/test/data/includes/a.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/a.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+#a.h
+%include <b.h>
diff -pruN 5.12.4-1/libs/node/test/data/includes/b.h 5.13.0-1/libs/node/test/data/includes/b.h
--- 5.12.4-1/libs/node/test/data/includes/b.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/b.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#b.h
diff -pruN 5.12.4-1/libs/node/test/data/includes/head.h 5.13.0-1/libs/node/test/data/includes/head.h
--- 5.12.4-1/libs/node/test/data/includes/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,75 @@
+#!/bin/ksh
+# ================================== start of head.h ================================
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+%manual
+#This is the manual from the head.h file
+%end
+
+%comment
+#This is the comment from the head.h file
+%end
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+set -o pipefail # fail if last(rightmost) command exits with a non-zero status
+
+# Defines the three variables that are needed for any
+# communication with ECF
+
+export ECF_PORT=%ECF_PORT%    # The port number on the server
+export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%
+fi
+
+# to debug client communication with the server, enable this environment
+#export ECF_DEBUG_CLIENT=
+
+# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
+os_name=$(uname -s)
+if [[ $os_name = Linux ]] ; then
+   host %ECF_HOST%
+fi
+
+# Typically we dont set this, however the zombie automated test require this.
+# it allows us to disambiguate a zomie from a real job.
+export ECF_RID=$$
+
+# Tell ECF_ we have stated
+# The ECF_ variable ECF_RID will be set to parameter of smsinit
+# Here we give the current PID.
+
+
+# Defined a error hanlder
+ERROR() {
+	echo "ERROR() called"
+	set +e        # Clear -e flag, so we don't fail
+	wait          # wait for background process to stop
+	%ECF_CLIENT_EXE_PATH:ecflow_client% --abort # Notify ECF_ that something went wrong
+	trap 0        # Remove the trap
+	exit 0        # End the script
+}
+
+# Trap any calls to exit and errors caught by the -e flag
+
+trap ERROR 0
+
+# Trap any signal that may cause the script to fail
+
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
+
+
+#smsinit $$
+%ECF_CLIENT_EXE_PATH:ecflow_client% --init=$$
+echo $?
+# ================================== end of head.h ================================
diff -pruN 5.12.4-1/libs/node/test/data/includes/manual.h 5.13.0-1/libs/node/test/data/includes/manual.h
--- 5.12.4-1/libs/node/test/data/includes/manual.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/manual.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+Test manual files are pre-processed
diff -pruN 5.12.4-1/libs/node/test/data/includes/simple_head.h 5.13.0-1/libs/node/test/data/includes/simple_head.h
--- 5.12.4-1/libs/node/test/data/includes/simple_head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/simple_head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#head.h
diff -pruN 5.12.4-1/libs/node/test/data/includes/simple_tail.h 5.13.0-1/libs/node/test/data/includes/simple_tail.h
--- 5.12.4-1/libs/node/test/data/includes/simple_tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/simple_tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+#tail.h
diff -pruN 5.12.4-1/libs/node/test/data/includes/tail.h 5.13.0-1/libs/node/test/data/includes/tail.h
--- 5.12.4-1/libs/node/test/data/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+# ================================== start of tail.h ================================
+#smscomplete  # Notify ECF of a normal end
+%ECF_CLIENT_EXE_PATH:ecflow_client% --complete
+trap 0       # Remove all traps
+exit 0       # End the shell
+%manual
+#This is the manual from the tail.h file
+%end
+%comment
+#This is the comment from the tail.h file
+%end
+# ================================== end of tail.h ================================
diff -pruN 5.12.4-1/libs/node/test/data/includes/used_variables.h 5.13.0-1/libs/node/test/data/includes/used_variables.h
--- 5.12.4-1/libs/node/test/data/includes/used_variables.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/used_variables.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite=%SUITE%
+suite=%FAMILY%
+suite=%FAMILY1%
+suite=%TASK%
+suite=%ECF_TRYNO%
+suite=%ECF_JOB%
+suite=%ECF_JOBOUT%
+suite=%ECF_PASS%
+suite=%ECF_PORT%
+suite=%ECF_HOST%
+suite=%ECF_NAME%
+suite=%ESUITE%
diff -pruN 5.12.4-1/libs/node/test/data/includes/used_variables_with_comments.h 5.13.0-1/libs/node/test/data/includes/used_variables_with_comments.h
--- 5.12.4-1/libs/node/test/data/includes/used_variables_with_comments.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes/used_variables_with_comments.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+%comment
+suite = %ETASK%
+%end
+
+%manual
+suite = %ETASK%
+%end
+
+suite=%FRED%
diff -pruN 5.12.4-1/libs/node/test/data/includes2/fred.h 5.13.0-1/libs/node/test/data/includes2/fred.h
--- 5.12.4-1/libs/node/test/data/includes2/fred.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/includes2/fred.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+#
+# Used to test inclusion with angle brackets  <filename>
+# First look in *ALL* the paths specfied in %ECF_INCLUDE%
+# If file not there then look at ECF_HOME/filename
+#
+# THIS ALLOWS USE TO PUT SPECIFIC FILES IN ECF_INCLUDE
+# AND COMMON FILE IN ECF_HOME
diff -pruN 5.12.4-1/libs/node/test/data/migration/Family.def 5.13.0-1/libs/node/test/data/migration/Family.def
--- 5.12.4-1/libs/node/test/data/migration/Family.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/migration/Family.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"6Family":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"n_":""},"nodes_":[]}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/migration/Limit.def 5.13.0-1/libs/node/test/data/migration/Limit.def
--- 5.12.4-1/libs/node/test/data/migration/Limit.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/migration/Limit.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Limit":{"n_":"","lim_":0}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/migration/Suite.def 5.13.0-1/libs/node/test/data/migration/Suite.def
--- 5.12.4-1/libs/node/test/data/migration/Suite.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/migration/Suite.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"5Suite":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"n_":""},"nodes_":[]},"cal_":{"cereal_class_version":0,"initTime_":{"ptime":"2018-Aug-21 08:38:58"}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/data/migration/Task.def 5.13.0-1/libs/node/test/data/migration/Task.def
--- 5.12.4-1/libs/node/test/data/migration/Task.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/data/migration/Task.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+{"4Task":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"value0":{"cereal_class_version":0,"n_":""}}}}
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/ParseOnly.cpp 5.13.0-1/libs/node/test/parser/ParseOnly.cpp
--- 5.12.4-1/libs/node/test/parser/ParseOnly.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/ParseOnly.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+#include <string>
+
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// leap42 boost_1_64_0 gcc-5.3.0 release mode
+//    time bin/gcc-5.3.0/release/perf_aparser_only ${ECF_TEST_DEFS_DIR}/vsms2.31415.def
+//    real    0m2.79s
+//    user    0m2.59s
+//    sys     0m0.18s
+
+int main(int argc, char* argv[]) {
+    //   cout << "argc = " << argc << "\n";
+    //   for(int i = 0; i < argc; i++) {
+    //      cout << "arg " << i << ":" << argv[i] << "\n";
+    //   }
+
+    if (argc != 2) {
+        cout << "Expect single argument which is path to a defs file\n";
+        return 1;
+    }
+
+    std::string path = argv[1];
+
+    Defs defs;
+    std::string errorMsg, warningMsg;
+    if (!defs.restore(path, errorMsg, warningMsg)) {
+        cout << errorMsg << "\n";
+        cout << warningMsg << "\n";
+        return 1;
+    }
+
+    //   // Determine average number of variables for nodes with variables
+    //   vector<Node*> nodes;
+    //   defs.getAllNodes(nodes);
+    //   cout << "Total number of nodes: " << nodes.size() << "\n";
+    //   size_t number_of_variables = 0;
+    //   size_t nodes_with_variables = 0;
+    //   for(const auto& n : nodes) {
+    //      // cout << n->variables().size() << "\n";
+    //      if (n->variables().size() > 0) {
+    //         number_of_variables +=  n->variables().size();
+    //         nodes_with_variables++;
+    //      }
+    //   }
+    //   cout << "number_of_variables " << number_of_variables << "\n";
+    //   cout << "nodes_with_variables  " <<  nodes_with_variables << "\n";
+    //   cout <<"Average number of variables per node " <<  (double)number_of_variables/nodes_with_variables  << "\n";
+
+    //   PrintStyle style(PrintStyle::MIGRATE);
+    //   cout << defs;
+    return 0;
+}
diff -pruN 5.12.4-1/libs/node/test/parser/ParseTimer.cpp 5.13.0-1/libs/node/test/parser/ParseTimer.cpp
--- 5.12.4-1/libs/node/test/parser/ParseTimer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/ParseTimer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,249 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+#include <string>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/timer/timer.hpp>
+
+#include "PersistHelper.hpp"
+#include "TemporaryFile.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/NodeContainer.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::timer;
+
+// This test is used to find a task given a path of the form:
+//      suite/family/task
+//    suite/family/family/task
+void test_find_task_using_path(NodeContainer* f, const Defs& defs) {
+    if (f != defs.findAbsNode(f->absNodePath()).get())
+        cout << "Could not find path " << f->absNodePath() << "\n";
+
+    for (node_ptr t : f->nodeVec()) {
+        if (t.get() != defs.findAbsNode(t->absNodePath()).get())
+            cout << "Could not find path " << t->absNodePath() << "\n";
+        Family* family = t->isFamily();
+        if (family) {
+            test_find_task_using_path(family, defs);
+        }
+    }
+}
+
+// Create derived class, so that we can time the parse only
+// i.e ignore expression build/checking and limit checking
+class TestDefsStructureParser : public DefsStructureParser {
+public:
+    TestDefsStructureParser(Defs* defsfile, const std::string& file_name) : DefsStructureParser(defsfile, file_name) {}
+    bool do_parse_file(std::string& errorMsg) { return DefsStructureParser::do_parse_file(errorMsg); }
+};
+
+int main(int argc, char* argv[]) {
+    //   cout << "argc = " << argc << "\n";
+    //   for(int i = 0; i < argc; i++) {
+    //      cout << "arg " << i << ":" << argv[i] << "\n";
+    //   }
+
+    if (argc != 2) {
+        cout << "Expect single argument which is path to a defs file\n";
+        return 1;
+    }
+
+    std::string path = argv[1];
+
+    auto_cpu_timer t;
+    cpu_timer timer;
+
+    /// If this is moved below, we get some caching affect, with the persist and reload timing
+    Defs defs;
+    {
+        timer.start();
+        std::string errorMsg, warningMsg;
+        bool result = defs.restore(path, errorMsg, warningMsg);
+        cout << " Parsing Node tree & AST creation time parse(" << result
+             << ") = " << timer.format(3, Str::cpu_timer_format()) << endl;
+    }
+    {
+        Defs local_defs;
+        timer.start();
+        TestDefsStructureParser checkPtParser(&local_defs, path);
+        std::string errorMsg;
+        bool result = checkPtParser.do_parse_file(errorMsg);
+        cout << " Parsing Node tree *only* time         parse(" << result
+             << ") = " << timer.format(3, Str::cpu_timer_format()) << endl;
+    }
+    {
+        timer.start();
+        std::string defs_as_string;
+        defs.save_as_string(defs_as_string, PrintStyle::DEFS);
+        Defs newDefs;
+        std::string error_msg, warning_msg; // ignore error since some input defs have invalid triggers
+        newDefs.restore_from_string(defs_as_string, error_msg, warning_msg);
+        cout << " Save and restore as string(DEFS)               = " << timer.format(3, Str::cpu_timer_format())
+             << " -> string size(" << defs_as_string.size() << ")" << endl;
+    }
+    {
+        timer.start();
+        std::string defs_as_string;
+        defs.save_as_string(defs_as_string, PrintStyle::NET);
+        Defs newDefs;
+        std::string error_msg, warning_msg; // ignore error since some input defs have invalid triggers
+        newDefs.restore_from_string(defs_as_string, error_msg, warning_msg);
+        cout << " Save and restore as string(NET)                = " << timer.format(3, Str::cpu_timer_format())
+             << " -> string size(" << defs_as_string.size() << ") checks relaxed" << endl;
+    }
+    {
+        timer.start();
+        std::string defs_as_string;
+        defs.save_as_string(defs_as_string, PrintStyle::MIGRATE);
+        Defs newDefs;
+        std::string error_msg, warning_msg; // ignore error since some input defs have invalid triggers
+        newDefs.restore_from_string(defs_as_string, error_msg, warning_msg);
+        cout << " Save and restore as string(MIGRATE)            = " << timer.format(3, Str::cpu_timer_format())
+             << " -> string size(" << defs_as_string.size() << ")" << endl;
+    }
+    {
+        // Test time for persisting to defs file only
+        TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
+
+        timer.start();
+        defs.save_as_checkpt(temporary.path());
+        cout << " Save as DEFS checkpoint, time taken            = " << timer.format(3, Str::cpu_timer_format())
+             << endl;
+    }
+
+    {
+        // Test time for persisting to CEREAL checkpoint file only
+        fs::path fs_path(path);
+        //   std::cout << "parent path " << fs_path.parent_path() << "\n";
+        //   std::cout << "root path " << fs_path.root_path()  << "\n";
+        //   std::cout << "root name " << fs_path.root_name()  << "\n";
+        //   std::cout << "root directory " << fs_path.root_directory()  << "\n";
+        //   std::cout << "relative_path " << fs_path.relative_path()  << "\n";
+        //   std::cout << "filename " << fs_path.filename()  << "\n";
+        //   std::cout << "stem " << fs_path.stem()  << "\n";
+        //   std::cout << "extension " << fs_path.extension()  << "\n";
+
+        std::stringstream ss;
+#ifdef DEBUG
+        ss << "/var/tmp/ma0/JSON/debug_" << fs_path.stem() << ".json";
+#else
+        ss << "/var/tmp/ma0/JSON/" << fs_path.stem() << ".json";
+#endif
+
+        std::string json_filepath = ss.str();
+        Str::replaceall(json_filepath, "\"", ""); // fs_path.stem() seems to add ", so remove them
+        // cout << "  json_filepath: " << json_filepath << endl;
+
+        std::remove(json_filepath.c_str());
+        timer.start();
+        defs.cereal_save_as_checkpt(json_filepath);
+        cout << " Save as CEREAL checkpoint, time taken          = " << timer.format(3, Str::cpu_timer_format())
+             << endl;
+    }
+
+    {
+        // may need to comment out output for large differences. Will double the time.
+        bool do_compare = false;
+        timer.start();
+        PersistHelper helper;
+        bool result = helper.test_defs_checkpt_and_reload(defs, do_compare);
+        cout << " Checkpt(DEFS) and reload, time taken           = " << timer.format(3, Str::cpu_timer_format())
+             << " file_size(" << helper.file_size() << ")  result(" << result << ") msg(" << helper.errorMsg() << ")"
+             << endl;
+    }
+
+    {
+        bool do_compare = false;
+        timer.start();
+        PersistHelper helper;
+        bool result = helper.test_cereal_checkpt_and_reload(defs, do_compare);
+        cout << " Checkpt(CEREAL) and reload , time taken        = ";
+        cout << timer.format(3, Str::cpu_timer_format()) << " file_size(" << helper.file_size() << ")  result("
+             << result << ") msg(" << helper.errorMsg() << ")" << endl;
+    }
+
+    {
+        timer.start();
+        for (suite_ptr s : defs.suiteVec()) {
+            test_find_task_using_path(s.get(), defs);
+        }
+        cout << " Test all paths can be found. time taken        = " << timer.format(3, Str::cpu_timer_format())
+             << endl;
+    }
+    {
+        // Time how long it takes for job submission. Must call begin on all suites first.
+        timer.start();
+        defs.beginAll();
+        int count = 10;
+        JobsParam jobsParam; // default is not to create jobs, hence only used in testing
+        Jobs jobs(&defs);
+        for (int i = 0; i < count; i++) {
+            jobs.generate(jobsParam);
+        }
+        cout << " time for 10 jobSubmissions                     = " << timer.format(3, Str::cpu_timer_format())
+             << " jobs:" << jobsParam.submitted().size() << endl;
+    }
+    {
+        // Time how long it takes for post process
+        timer.start();
+        string errorMsg, warningMsg;
+        bool result = defs.check(errorMsg, warningMsg);
+        cout << " Time for Defs::check(inlimit resolution)       = " << timer.format(3, Str::cpu_timer_format())
+             << " result(" << result << ")" << endl;
+    }
+    {
+        // Time how long it takes to delete all nodes/ references. Delete all tasks and then suites/families.
+        timer.start();
+        std::vector<Task*> tasks;
+        defs.getAllTasks(tasks);
+        for (Task* ta : tasks) {
+            if (!defs.deleteChild(ta))
+                cout << "Failed to delete task\n";
+        }
+        tasks.clear();
+        defs.getAllTasks(tasks);
+        if (!tasks.empty())
+            cout << "Expected all tasks to be deleted but found " << tasks.size() << "\n";
+
+        std::vector<suite_ptr> vec = defs.suiteVec(); // make a copy, to avoid invalidating iterators
+        for (suite_ptr s : vec) {
+            std::vector<node_ptr> familyVec = s->nodeVec(); // make a copy, to avoid invalidating iterators
+            for (node_ptr f : familyVec) {
+                if (!defs.deleteChild(f.get()))
+                    cout << "Failed to delete family\n";
+            }
+            if (!s->nodeVec().empty())
+                cout << "Expected all Families to be deleted but found " << s->nodeVec().size() << "\n";
+            if (!defs.deleteChild(s.get()))
+                cout << "Failed to delete suite\n";
+        }
+        if (!defs.suiteVec().empty())
+            cout << "Expected all Suites to be deleted but found " << defs.suiteVec().size() << "\n";
+
+        cout << " time for deleting all nodes                    = " << timer.format(3, Str::cpu_timer_format())
+             << endl;
+    }
+}
diff -pruN 5.12.4-1/libs/node/test/parser/PersistHelper.cpp 5.13.0-1/libs/node/test/parser/PersistHelper.cpp
--- 5.12.4-1/libs/node/test/parser/PersistHelper.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/PersistHelper.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,309 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "PersistHelper.hpp"
+
+#include <sstream>
+
+#include "TemporaryFile.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+
+bool PersistHelper::test_persist_and_reload(const Defs& theInMemoryDefs,
+                                            PrintStyle::Type_t file_type_on_disk,
+                                            bool do_compare) {
+    // Write parsed file to disk, and reload, then compare defs, they should be the same
+    errorMsg_.clear();
+    file_size_ = 0;
+
+    TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
+
+    {
+        // The file MUST be written in the *SAME* form that it was read, Otherwise they will not compare:
+        theInMemoryDefs.save_as_filename(temporary.path(), file_type_on_disk);
+    }
+
+    // Reload the file we just persisted and compare with in memory defs
+    Defs savedDef;
+    return reload_from_defs_file(theInMemoryDefs, savedDef, temporary.path(), do_compare);
+}
+
+bool PersistHelper::test_defs_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare) {
+    // Write parsed file to disk, and reload, then compare defs, they should be the same
+    errorMsg_.clear();
+    file_size_ = 0;
+
+    TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
+
+    {
+        // The file MUST be written in the *SAME* form that it was read, Otherwise they will not compare:
+        theInMemoryDefs.save_as_checkpt(temporary.path());
+    }
+
+    // Reload the file we just persisted and compare with in memory defs
+    Defs savedDef;
+    bool reload_result = reload_from_defs_file(theInMemoryDefs, savedDef, temporary.path(), do_compare);
+    if (reload_result)
+        return savedDef.checkInvariants(errorMsg_);
+    return false;
+}
+
+bool PersistHelper::test_cereal_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare) {
+    errorMsg_.clear();
+    file_size_ = 0;
+    if (!theInMemoryDefs.checkInvariants(errorMsg_)) {
+        return false;
+    }
+
+    // Save in memory defs as a check pt file, then restore and compare
+    Defs reloaded_defs;
+    bool reload_result = reload_from_cereal_checkpt_file(theInMemoryDefs, reloaded_defs, do_compare);
+    if (reload_result)
+        return reloaded_defs.checkInvariants(errorMsg_);
+    return false;
+}
+
+bool PersistHelper::test_state_persist_and_reload_with_checkpt(const Defs& theInMemoryDefs) {
+    // Write Defs to disk, and reload, then compare defs reloaded checkpt file, they should be the same
+    errorMsg_.clear();
+    file_size_ = 0;
+    if (!theInMemoryDefs.checkInvariants(errorMsg_)) {
+        return false;
+    }
+
+    DebugEquality debug_equality; // only as affect in DEBUG build
+
+    TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
+
+    {
+        // The file MUST be written in the *SAME* form that it was read, Otherwise they will not compare:
+        theInMemoryDefs.save_as_checkpt(temporary.path()); // will save edit history
+    }
+
+    Defs reload_strings_def;
+    {
+        // Open file, and parse as a string.
+        std::string defs_as_string;
+        if (!File::open(temporary.path(), defs_as_string)) {
+            errorMsg_ += "Could not file file: " + temporary.path();
+            return false;
+        }
+        std::string error_msg, warning;
+        if (!reload_strings_def.restore_from_string(defs_as_string, error_msg, warning)) {
+            errorMsg_ += error_msg;
+            return false;
+        }
+        if (!reload_strings_def.checkInvariants(errorMsg_)) {
+            return false;
+        }
+    }
+
+    // Reload the file we just persisted and compare with in memory defs
+    Defs reloaded_defs;
+    if (!reload_from_defs_file(theInMemoryDefs, reloaded_defs, temporary.path())) {
+        return false;
+    }
+    if (!reloaded_defs.checkInvariants(errorMsg_)) {
+        return false;
+    }
+
+    // Save in memory defs as a check pt file, then restore and compare
+    Defs reloaded_cereal_checkPt_defs;
+    if (!reload_from_cereal_checkpt_file(theInMemoryDefs, reloaded_cereal_checkPt_defs, true)) {
+        return false;
+    }
+    if (!reloaded_cereal_checkPt_defs.checkInvariants(errorMsg_)) {
+        return false;
+    }
+
+    // Make sure reloading def's file with state is same as the checkpt file
+    bool match = reloaded_defs == reloaded_cereal_checkPt_defs;
+
+    if (!match) {
+        std::stringstream ss;
+        ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt\n";
+        ss << "In reloaded_defs_file and reloaded_checkPt_defs don't match\n";
+        ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
+        PrintStyle style(PrintStyle::MIGRATE); // will save edit history
+        ss << theInMemoryDefs;
+        ss << "+++++++++++++ reloaded_defs  ++++++++++++++++++++++++++++\n";
+        ss << reloaded_defs;
+        ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
+        ss << reloaded_cereal_checkPt_defs;
+        errorMsg_ += ss.str();
+    }
+    else {
+        if (compare_edit_history_ && !reloaded_defs.compare_edit_history(reloaded_cereal_checkPt_defs)) {
+            std::stringstream ss;
+            ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt  compare_edit_history_\n";
+            ss << "In reloaded_defs_file and reloaded_checkPt_defs edit history don't match\n";
+            ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
+            PrintStyle style(PrintStyle::MIGRATE); // will save edit history
+            ss << theInMemoryDefs;
+            ss << "+++++++++++++ reloaded_defs  ++++++++++++++++++++++++++++\n";
+            ss << reloaded_defs;
+            ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
+            ss << reloaded_cereal_checkPt_defs;
+            errorMsg_ += ss.str();
+        }
+    }
+    if (!reloaded_defs.compare_change_no(reloaded_cereal_checkPt_defs)) {
+        errorMsg_ += "\nPersistHelper::test_state_persist_and_reload_with_checkpt: Change numbers don't compare "
+                     "between reloaded_defs and reloaded_cereal_checkPt_defs \n";
+    }
+
+    // Make sure reloading def's file with state is same as the checkpt file
+    match = reload_strings_def == reloaded_cereal_checkPt_defs;
+    if (!match) {
+        std::stringstream ss;
+        ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt\n";
+        ss << "In reloaded_defs file AS STRING and reloaded_checkPt_defs don't match\n";
+        ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
+        PrintStyle style(PrintStyle::MIGRATE); // will save edit history
+        ss << theInMemoryDefs;
+        ss << "+++++++++++++  reload_strings_def  ++++++++++++++++++++++++++++\n";
+        ss << reload_strings_def;
+        ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
+        ss << reloaded_cereal_checkPt_defs;
+        errorMsg_ += ss.str();
+    }
+    else {
+        if (compare_edit_history_ && !reload_strings_def.compare_edit_history(reloaded_cereal_checkPt_defs)) {
+            std::stringstream ss;
+            ss << "\nPersistHelper::test_state_persist_and_reload_with_checkpt  compare_edit_history_\n";
+            ss << "In reloaded_defs_file and reloaded_checkPt_defs edit history don't match\n";
+            ss << "+++++++++++++ in memory defs  ++++++++++++++++++++++++++++\n";
+            PrintStyle style(PrintStyle::MIGRATE); // will save edit history
+            ss << theInMemoryDefs;
+            ss << "+++++++++++++ reload_strings_def ++++++++++++++++++++++++++++\n";
+            ss << reload_strings_def;
+            ss << "++++++++++++++ reloaded_checkPt_defs  ++++++++++++++++++++++++++++\n";
+            ss << reloaded_cereal_checkPt_defs;
+            errorMsg_ += ss.str();
+        }
+    }
+    if (!reload_strings_def.compare_change_no(reloaded_cereal_checkPt_defs)) {
+        errorMsg_ += "\nPersistHelper::test_state_persist_and_reload_with_checkpt: Change numbers don't compare "
+                     "between reload_strings_def and reloaded_cereal_checkPt_defs\n";
+    }
+
+    return errorMsg_.empty();
+}
+
+bool PersistHelper::reload_from_defs_file(const Defs& theInMemoryDefs,
+                                          Defs& reloaded_defs,
+                                          const std::string& tmpFilename,
+                                          bool do_compare) {
+    DebugEquality debug_equality; // only as affect in DEBUG build
+
+    std::string warningMsg;
+    if (!reloaded_defs.restore(tmpFilename, errorMsg_, warningMsg)) {
+        std::stringstream ss;
+        ss << "RE-PARSE failed for " << tmpFilename << "\n";
+        errorMsg_ += ss.str();
+        return false;
+    }
+
+    if (do_compare) {
+        // Make sure the file we just parsed match's the one we persisted
+        bool match = reloaded_defs == theInMemoryDefs;
+
+        if (!match) {
+            std::stringstream ss;
+            ss << "\nPersistHelper::reload_from_defs_file\n";
+            ss << "In memory and reloaded def's don't match\n";
+            ss << "+++++++++++++ Saved/reloaded_defs  ++++++++++++++++++++++++++++\n";
+            PrintStyle style(PrintStyle::STATE);
+            ss << reloaded_defs;
+            ss << "++++++++++++++ In memory def ++++++++++++++++++++++++++++\n";
+            ss << theInMemoryDefs;
+            errorMsg_ += ss.str();
+        }
+        else {
+            if (compare_edit_history_ && !reloaded_defs.compare_edit_history(theInMemoryDefs)) {
+                std::stringstream ss;
+                ss << "\nPersistHelper::reload_from_defs_file compare_edit_history_\n";
+                ss << "In memory and reloaded def's don't match\n";
+                ss << "+++++++++++++ Saved/reloaded_defs  ++++++++++++++++++++++++++++\n";
+                PrintStyle style(PrintStyle::MIGRATE);
+                ss << reloaded_defs;
+                ss << "++++++++++++++ In memory def ++++++++++++++++++++++++++++\n";
+                ss << theInMemoryDefs;
+                errorMsg_ += ss.str();
+            }
+        }
+        if (!reloaded_defs.compare_change_no(theInMemoryDefs)) {
+            errorMsg_ += "\nPersistHelper::reload_from_defs_file: Change numbers don't compare between reloaded_defs  "
+                         "and theInMemoryDefs  \n";
+        }
+    }
+
+    file_size_ = fs::file_size(tmpFilename);
+    std::remove(tmpFilename.c_str());
+    return errorMsg_.empty();
+}
+
+bool PersistHelper::reload_from_cereal_checkpt_file(const Defs& theInMemoryDefs, Defs& reloaded_defs, bool do_compare) {
+    // make sure edit history is stored
+    TemporaryFile temporary("tmp.check_%%%%-%%%%-%%%%-%%%%");
+
+    theInMemoryDefs.cereal_save_as_checkpt(temporary.path());
+
+    DebugEquality debug_equality; // only as effect in DEBUG build
+
+    try {
+        // Parse the file we just persisted and load the defs file into memory.
+        reloaded_defs.cereal_restore_from_checkpt(temporary.path());
+
+        if (do_compare) {
+            // Make sure the checkpoint the file we just parsed corresponds to the one we stored
+            bool match = reloaded_defs == theInMemoryDefs;
+            if (!match) {
+                std::stringstream ss;
+                ss << "\nPersistHelper::reload_from_cereal_checkpt_file\n";
+                ss << "In memory and reloaded def's don't match\n";
+                ss << "+++++++++++++ Saved/reloaded check pt file ++++++++++++++++++++++++++++\n";
+                PrintStyle style(PrintStyle::STATE);
+                ss << reloaded_defs;
+                ss << "++++++++++++++ In memory def ++++++++++++++++++++++++++++\n";
+                ss << theInMemoryDefs;
+                errorMsg_ += ss.str();
+            }
+            else {
+                if (compare_edit_history_ && !reloaded_defs.compare_edit_history(theInMemoryDefs)) {
+                    std::stringstream ss;
+                    ss << "\nPersistHelper::reload_from_cereal_checkpt_file  compare_edit_history_\n";
+                    ss << "In reloaded_defs_file and reloaded_checkPt_defs edit history don't match\n";
+                    ss << "+++++++++++++ Saved/reloaded check pt file ++++++++++++++++++++++++++++\n";
+                    PrintStyle style(PrintStyle::MIGRATE);
+                    ss << reloaded_defs;
+                    ss << "++++++++++++++ theInMemoryDefs  ++++++++++++++++++++++++++++\n";
+                    ss << theInMemoryDefs;
+                    errorMsg_ += ss.str();
+                }
+            }
+            if (!reloaded_defs.compare_change_no(theInMemoryDefs)) {
+                errorMsg_ += "\nPersistHelper::reload_from_cereal_checkpt_file: Change numbers don't compare between "
+                             "reloaded_defs and theInMemoryDefs  \n";
+            }
+        }
+    }
+    catch (std::exception& e) {
+        errorMsg_ = "PersistHelper::reload_from_cereal_checkpt_file: " + string(e.what());
+    }
+
+    file_size_ = temporary.size();
+
+    return errorMsg_.empty();
+}
diff -pruN 5.12.4-1/libs/node/test/parser/PersistHelper.hpp 5.13.0-1/libs/node/test/parser/PersistHelper.hpp
--- 5.12.4-1/libs/node/test/parser/PersistHelper.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/PersistHelper.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_test_PersistHelper_HPP
+#define ecflow_node_parser_test_PersistHelper_HPP
+
+#include <string>
+
+#include "ecflow/core/PrintStyle.hpp"
+
+class Defs;
+
+/// Given a in memory defs file, this class will write it to disk
+/// and reload the definition file structure and will then make a comparison
+/// to ensure they are the same
+class PersistHelper {
+public:
+    explicit PersistHelper(bool compare_edit_history = false) : compare_edit_history_(compare_edit_history) {}
+
+    bool
+    test_persist_and_reload(const Defs& theInMemoryDefs, PrintStyle::Type_t file_type_on_disk, bool do_compare = true);
+    bool test_defs_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare = true);
+    bool test_cereal_checkpt_and_reload(const Defs& theInMemoryDefs, bool do_compare = true);
+    bool test_state_persist_and_reload_with_checkpt(const Defs& theInMemoryDefs);
+    const std::string& errorMsg() const { return errorMsg_; }
+
+    /// returns the file size of the temporary file created by:
+    ///   test_persist_and_reload(..) or test_cereal_checkpt_and_reload(..)
+    size_t file_size() const { return file_size_; }
+
+private:
+    bool reload_from_defs_file(const Defs& theInMemoryDefs,
+                               Defs& reloaded_defs,
+                               const std::string& filename,
+                               bool do_compare = true);
+    bool reload_from_cereal_checkpt_file(const Defs& theInMemoryDefs, Defs& reloaded_defs, bool do_compare = true);
+
+private:
+    PersistHelper(const PersistHelper&)                  = delete;
+    const PersistHelper& operator=(const PersistHelper&) = delete;
+
+private:
+    std::string errorMsg_;
+    size_t file_size_{0};
+    bool compare_edit_history_;
+};
+
+#endif /* ecflow_node_parser_test_PersistHelper_HPP */
diff -pruN 5.12.4-1/libs/node/test/parser/TemporaryFile.cpp 5.13.0-1/libs/node/test/parser/TemporaryFile.cpp
--- 5.12.4-1/libs/node/test/parser/TemporaryFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TemporaryFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,26 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "TemporaryFile.hpp"
+
+TemporaryFile::TemporaryFile() : path_{fs::unique_path("tmp_%%%%-%%%%-%%%%-%%%%")} {
+}
+
+TemporaryFile::TemporaryFile(const std::string& pattern) : path_{fs::unique_path(pattern)} {
+}
+
+TemporaryFile::~TemporaryFile() {
+    try {
+        fs::remove(path_);
+    }
+    catch (...) {
+        // Nothing to do...
+    }
+}
diff -pruN 5.12.4-1/libs/node/test/parser/TemporaryFile.hpp 5.13.0-1/libs/node/test/parser/TemporaryFile.hpp
--- 5.12.4-1/libs/node/test/parser/TemporaryFile.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TemporaryFile.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_node_parser_test_TemporaryFile_HPP
+#define ecflow_node_parser_test_TemporaryFile_HPP
+
+#include <string>
+
+#include "ecflow/core/Filesystem.hpp"
+
+class TemporaryFile {
+public:
+    TemporaryFile();
+    explicit TemporaryFile(const std::string& pattern);
+
+    ~TemporaryFile();
+
+    [[nodiscard]] inline std::string path() const { return path_.string(); }
+    [[nodiscard]] inline size_t size() const { return fs::file_size(path_); }
+
+private:
+    fs::path path_;
+};
+
+#endif /* ecflow_node_parser_test_TemporaryFile_HPP */
diff -pruN 5.12.4-1/libs/node/test/parser/TestAutoAddExterns.cpp 5.13.0-1/libs/node/test/parser/TestAutoAddExterns.cpp
--- 5.12.4-1/libs/node/test/parser/TestAutoAddExterns.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestAutoAddExterns.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,60 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_AutoAddExterns)
+
+// Test that automatic add of externs
+BOOST_AUTO_TEST_CASE(test_auto_add_externs) {
+    std::string path = File::test_data("libs/node/test/parser/data/single_defs/test_auto_add_extern.def", "parser");
+
+    size_t mega_file_size = fs::file_size(path);
+    cout << "AParser:: ...test_auto_add_externs " << path << " file_size(" << mega_file_size << ")\n";
+
+    Defs defs;
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(defs.restore(path, errorMsg, warningMsg), "Expected no errors, but found " << errorMsg);
+    BOOST_REQUIRE_MESSAGE(warningMsg.empty(), "Expected no warnings but found:\n" << warningMsg);
+
+    // Check number of extrens read in: Duplicate should be ignore
+    BOOST_REQUIRE_MESSAGE(defs.externs().size() == 11,
+                          "Expected 11 externs as starting point but found " << defs.externs().size() << "\n"
+                                                                             << defs << "\n");
+
+    // Test auto extern generation. Don't remove existing extern's
+    defs.auto_add_externs(false /* remove_existing_externs_first*/);
+    BOOST_REQUIRE_MESSAGE(defs.externs().size() == 11,
+                          "Expected 11, auto_add_extern(false) gave: " << defs.externs().size() << "\n"
+                                                                       << defs << "\n");
+
+    // By removing the externs read, in we can determine the real number of extern;s from
+    // parsing all the trigger expressions, and inlimit references
+    defs.auto_add_externs(true /* remove_existing_externs_first*/);
+    BOOST_REQUIRE_MESSAGE(defs.externs().size() == 10,
+                          "Expected 10 externs, since redundant externs removed, auto_add_extern(true) gave: "
+                              << defs.externs().size() << "\n"
+                              << defs << "\n");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestAvisoAttr.cpp 5.13.0-1/libs/node/test/parser/TestAvisoAttr.cpp
--- 5.12.4-1/libs/node/test/parser/TestAvisoAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestAvisoAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,110 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_AvisoAttr)
+
+BOOST_AUTO_TEST_CASE(can_parse_aviso_attribute_on_task_with_default_parameters) {
+    std::cout << "..." << boost::unit_test::framework::current_test_unit().full_name() << std::endl;
+
+    using namespace ecf;
+
+    std::string definition = R"(
+        suite s1
+          family f1
+            task t1
+              aviso --name A --listener '{ "event": "mars", "request": { "class": "od"} }'
+          endfamily
+    )";
+
+    Defs defs;
+    DefsStructureParser parser(&defs, definition, true);
+
+    std::string errorMsg, warningMsg;
+    bool parsedOK = parser.doParse(errorMsg, warningMsg);
+    BOOST_CHECK_MESSAGE(parsedOK, "Failed to parse definition: " << errorMsg);
+
+    const auto& suites = defs.suiteVec();
+    BOOST_CHECK_EQUAL(suites.size(), static_cast<size_t>(1));
+
+    const auto& families = suites[0]->familyVec();
+    BOOST_CHECK_EQUAL(families.size(), static_cast<size_t>(1));
+
+    const auto& tasks = families[0]->taskVec();
+    BOOST_CHECK_EQUAL(tasks.size(), static_cast<size_t>(1));
+
+    const auto& avisos = tasks[0]->avisos();
+    BOOST_CHECK_EQUAL(avisos.size(), static_cast<size_t>(1));
+
+    const auto& aviso = avisos[0];
+    BOOST_CHECK_EQUAL(aviso.name(), "A");
+    BOOST_CHECK_EQUAL(aviso.listener(), R"('{ "event": "mars", "request": { "class": "od"} }')");
+    BOOST_CHECK_EQUAL(aviso.url(), "%ECF_AVISO_URL%");
+    BOOST_CHECK_EQUAL(aviso.schema(), "%ECF_AVISO_SCHEMA%");
+    BOOST_CHECK_EQUAL(aviso.auth(), "%ECF_AVISO_AUTH%");
+    BOOST_CHECK_EQUAL(aviso.polling(), "%ECF_AVISO_POLLING%");
+}
+
+BOOST_AUTO_TEST_CASE(can_parse_aviso_attribute_on_task_with_all_parameters) {
+    std::cout << "..." << boost::unit_test::framework::current_test_unit().full_name() << std::endl;
+
+    using namespace ecf;
+
+    std::string definition = R"(
+        suite s1
+          family f1
+            task t1
+              aviso --name A --listener '{ "event": "mars", "request": { "class": "od"} }' --url http://host:port --schema /path/to/schema --auth /path/to/auth --polling 60
+          endfamily
+    )";
+
+    Defs defs;
+    DefsStructureParser parser(&defs, definition, true);
+
+    std::string errorMsg, warningMsg;
+    bool parsedOK = parser.doParse(errorMsg, warningMsg);
+    BOOST_CHECK_MESSAGE(parsedOK, "Failed to parse definition: " << errorMsg);
+
+    const auto& suites = defs.suiteVec();
+    BOOST_CHECK_EQUAL(suites.size(), static_cast<size_t>(1));
+
+    const auto& families = suites[0]->familyVec();
+    BOOST_CHECK_EQUAL(families.size(), static_cast<size_t>(1));
+
+    const auto& tasks = families[0]->taskVec();
+    BOOST_CHECK_EQUAL(tasks.size(), static_cast<size_t>(1));
+
+    const auto& avisos = tasks[0]->avisos();
+    BOOST_CHECK_EQUAL(avisos.size(), static_cast<size_t>(1));
+
+    const auto& aviso = avisos[0];
+    BOOST_CHECK_EQUAL(aviso.name(), "A");
+    BOOST_CHECK_EQUAL(aviso.listener(), R"('{ "event": "mars", "request": { "class": "od"} }')");
+    BOOST_CHECK_EQUAL(aviso.url(), "http://host:port");
+    BOOST_CHECK_EQUAL(aviso.schema(), "/path/to/schema");
+    BOOST_CHECK_EQUAL(aviso.auth(), "/path/to/auth");
+    BOOST_CHECK_EQUAL(aviso.polling(), "60");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestDefsStructurePersistAndReload.cpp 5.13.0-1/libs/node/test/parser/TestDefsStructurePersistAndReload.cpp
--- 5.12.4-1/libs/node/test/parser/TestDefsStructurePersistAndReload.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestDefsStructurePersistAndReload.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,91 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "PersistHelper.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_DefsStructurePersisteAndReload)
+
+//=============================================================================
+// This test case will save the defs file in old style format
+// and the parse it back in. As we add different types to our defs fixture
+// we can automatically check that what we save can be parsed back in.
+// Specifically written to test the parser.
+// Note: Aliases are *NOT* written in the defs file BUT are when in MIGRATE
+BOOST_AUTO_TEST_CASE(test_defs_structure_persistence_and_reload) {
+    cout << "AParser:: ...test_defs_structure_persistence_and_reload\n";
+
+    MyDefsFixture theDefsFixture;
+    PersistHelper helper;
+    BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(theDefsFixture.defsfile_), helper.errorMsg());
+
+    // Note: Aliases are *NOT* written in PrintStyle::DEFS file
+    // Hence in order for this test to pass, we must delete the alias first & reset task alias_no
+    std::vector<alias_ptr> alias_vec;
+    theDefsFixture.defsfile_.get_all_aliases(alias_vec);
+    for (alias_ptr al : alias_vec) {
+        al->parent()->isTask()->reset_alias_number();
+        al->remove();
+    }
+    BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(theDefsFixture.defsfile_, PrintStyle::DEFS), helper.errorMsg());
+}
+
+BOOST_AUTO_TEST_CASE(test_defs_checkpt_persistence_and_reload) {
+    cout << "AParser:: ...test_defs_checkpt_persistence_and_reload\n";
+
+    MyDefsFixture theDefsFixture;
+    PersistHelper helper;
+    BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(theDefsFixture.defsfile_), helper.errorMsg());
+    BOOST_CHECK_MESSAGE(helper.test_defs_checkpt_and_reload(theDefsFixture.defsfile_), helper.errorMsg());
+}
+
+// This test is used to find a task given a path of the form:
+// 	  suite/family/task
+//    suite/family/family/task
+//
+void test_find_task_using_path(NodeContainer* f, const Defs& defs) {
+    BOOST_CHECK_MESSAGE(f == defs.findAbsNode(f->absNodePath()).get(),
+                        "Could not find path " << f->absNodePath() << "\n");
+
+    for (node_ptr t : f->nodeVec()) {
+        BOOST_CHECK_MESSAGE(t.get() == defs.findAbsNode(t->absNodePath()).get(),
+                            "Could not find path " << t->absNodePath() << "\n");
+        Family* family = t->isFamily();
+        if (family) {
+            test_find_task_using_path(family, defs);
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_find_task_using_paths) {
+    cout << "AParser:: ...test_find_task_using_paths\n";
+
+    MyDefsFixture theDefsFixture;
+
+    const std::vector<suite_ptr>& suiteVec = theDefsFixture.defsfile_.suiteVec();
+    for (suite_ptr s : suiteVec) {
+        test_find_task_using_path(s.get(), theDefsFixture.defsfile_);
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestMementoPersistAndReload.cpp 5.13.0-1/libs/node/test/parser/TestMementoPersistAndReload.cpp
--- 5.12.4-1/libs/node/test/parser/TestMementoPersistAndReload.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestMementoPersistAndReload.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,472 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "PersistHelper.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Memento.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// ********************************************************************
+// These test are used to check that MIGRATE is equivalent to check pt
+// MIGRATE will be used for migration from old to new release
+// MIGRATE is essentially the defs structure with state.
+// The state is written out as comments
+// It is loaded like a normal Defs, the parser detects MIGRATE
+// and loads the state in.
+//
+// By default  persistence/MIGRATE *ONLY* writes the state when it not the default.
+// Hence the defaults should *NOT* change. These test will change the state
+// to a non default value.
+//
+// Write the Defs with state and the compare with in memory defs
+// Write the Defs as check pt an then compare with in memory defs
+// Finally compare the two *RELOADED* defs file.
+// ********************************************************************
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_MementoPersistAndReload)
+
+BOOST_AUTO_TEST_CASE(test_memento_persist_and_reload) {
+    std::vector<ecf::Aspect::Type> aspects;
+    bool aspect_only = false;
+    cout << "AParser:: ...test_memento_persist_and_reload\n";
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        StateMemento memento2(NState::ABORTED);
+        defs.set_memento(&memento2, aspects, aspect_only);
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "StateMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        std::pair<NState::State, boost::posix_time::time_duration> state;
+        state.first  = NState::ABORTED;
+        state.second = boost::posix_time::time_duration(1, 1, 1, 0);
+        NodeStateMemento memento(state);
+        t->set_memento(&memento, aspects, aspect_only);
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeStateMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        NodeDefStatusDeltaMemento memento(DState::ABORTED);
+        t->set_memento(&memento, aspects, aspect_only);
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeDefStatusDeltaMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        SuspendedMemento memento(true);
+        t->set_memento(&memento, aspects, aspect_only);
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "SuspendedMemento failed: " << helper.errorMsg());
+
+        SuspendedMemento memento1;
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "SuspendedMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Event event(1);
+        NodeEventMemento memento(event);
+        t->set_memento(&memento, aspects, aspect_only); // add event
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeEventMemento failed: " << helper.errorMsg());
+
+        event.set_value(true);
+        NodeEventMemento memento1(event); // set event
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeEventMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Meter meter("meter", 0, 100);
+
+        NodeMeterMemento memento(meter);
+        t->set_memento(&memento, aspects, aspect_only); // add meter
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeMeterMemento failed: " << helper.errorMsg());
+
+        meter.set_value(100);
+        NodeMeterMemento memento1(meter); // change meter
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeMeterMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Label label("label", "xxx");
+
+        NodeLabelMemento memento(label);
+        t->set_memento(&memento, aspects, aspect_only); // add label;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeLabelMemento failed: " << helper.errorMsg());
+
+        label.set_new_value("yyy");
+        NodeLabelMemento memento1(label); // change label
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeLabelMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Expression exp("1 == 0");
+
+        NodeTriggerMemento memento(exp);
+        t->set_memento(&memento, aspects, aspect_only); // add trigger;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeTriggerMemento failed: " << helper.errorMsg());
+
+        exp.setFree();
+        NodeTriggerMemento memento1(exp); // free trigger
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeTriggerMemento failed: " << helper.errorMsg());
+
+        exp.clearFree();
+        NodeTriggerMemento memento2(exp); // clear trigger
+        t->set_memento(&memento2, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeTriggerMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Expression exp("1 == 0");
+
+        NodeCompleteMemento memento(exp);
+        t->set_memento(&memento, aspects, aspect_only); // add trigger;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeCompleteMemento failed: " << helper.errorMsg());
+
+        exp.setFree();
+        NodeCompleteMemento memento1(exp); // free trigger
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeCompleteMemento failed: " << helper.errorMsg());
+
+        exp.clearFree();
+        NodeCompleteMemento memento2(exp); // clear trigger
+        t->set_memento(&memento2, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeCompleteMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Repeat repeat(RepeatDate("YMD", 20090916, 20090916, 1));
+
+        NodeRepeatMemento memento(repeat);
+        t->set_memento(&memento, aspects, aspect_only); // add repeat;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeRepeatMemento failed: " << helper.errorMsg());
+
+        repeat.increment();
+        NodeRepeatMemento memento1(repeat); // change repeat
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeRepeatMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Repeat repeat(RepeatDateList("YMD", {20090916, 20090916}));
+
+        NodeRepeatMemento memento(repeat);
+        t->set_memento(&memento, aspects, aspect_only); // add repeat;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeRepeatMemento failed: " << helper.errorMsg());
+
+        repeat.increment();
+        NodeRepeatMemento memento1(repeat); // change repeat
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeRepeatMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Limit limit("suiteLimit", 10);
+
+        NodeLimitMemento memento(limit);
+        t->set_memento(&memento, aspects, aspect_only); // add limit;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeLimitMemento failed: " << helper.errorMsg());
+
+        std::set<std::string> paths;
+        paths.insert("/s1/t1");
+
+        limit.set_state(20, 2, paths);
+        NodeLimitMemento memento1(limit); // change limit
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeLimitMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        InLimit inlimit("suiteLimit", "/path/to/node", 2);
+
+        NodeInLimitMemento memento(inlimit);
+        t->set_memento(&memento, aspects, aspect_only); // add inlimit only, no state
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeInLimitMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        Variable variable("name", "value");
+
+        NodeVariableMemento memento(variable);
+        t->set_memento(&memento, aspects, aspect_only); // add variable;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeVariableMemento failed: " << helper.errorMsg());
+
+        variable.set_value("new value");
+        NodeVariableMemento memento1(variable); // change variable
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeVariableMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        ecf::LateAttr lateAttr;
+        lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
+        lateAttr.addActive(ecf::TimeSlot(3, 12));
+        lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
+
+        NodeLateMemento memento(lateAttr);
+        t->set_memento(&memento, aspects, aspect_only); // add late;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeLateMemento failed: " << helper.errorMsg());
+
+        lateAttr.setLate(true);
+        NodeLateMemento memento1(lateAttr); // change late
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeLateMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        ecf::TodayAttr attr(ecf::TimeSlot(10, 12));
+
+        NodeTodayMemento memento(attr);
+        t->set_memento(&memento, aspects, aspect_only); // add today;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeTodayMemento failed: " << helper.errorMsg());
+
+        attr.setFree();
+        NodeTodayMemento memento1(attr); // change today
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeTodayMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        ecf::TimeAttr attr(ecf::TimeSlot(10, 12));
+
+        NodeTimeMemento memento(attr);
+        t->set_memento(&memento, aspects, aspect_only); // add time;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeTimeMemento failed: " << helper.errorMsg());
+
+        attr.setFree();
+        NodeTimeMemento memento1(attr); // change time
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeTimeMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        DayAttr attr(DayAttr::MONDAY);
+
+        NodeDayMemento memento(attr);
+        t->set_memento(&memento, aspects, aspect_only); // add day;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeDayMemento failed: " << helper.errorMsg());
+
+        attr.setFree();
+        NodeDayMemento memento1(attr); // change day
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeDayMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        DateAttr attr(1, 2, 2009);
+
+        NodeDateMemento memento(attr);
+        t->set_memento(&memento, aspects, aspect_only); // add date;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeDateMemento failed: " << helper.errorMsg());
+
+        attr.setFree();
+        NodeDateMemento memento1(attr); // change date
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeDateMemento failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        ecf::CronAttr attr;
+        ecf::TimeSlot start(0, 0);
+        ecf::TimeSlot finish(10, 0);
+        ecf::TimeSlot incr(0, 5);
+        std::vector<int> weekdays;
+        for (int i = 0; i < 7; ++i)
+            weekdays.push_back(i);
+        std::vector<int> daysOfMonth;
+        for (int i = 1; i < 32; ++i)
+            daysOfMonth.push_back(i);
+        std::vector<int> months;
+        for (int i = 1; i < 13; ++i)
+            months.push_back(i);
+        attr.addTimeSeries(start, finish, incr);
+        attr.addWeekDays(weekdays);
+        attr.addDaysOfMonth(daysOfMonth);
+        attr.addMonths(months);
+
+        NodeCronMemento memento(attr);
+        t->set_memento(&memento, aspects, aspect_only); // add cron;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeCronMemento failed: " << helper.errorMsg());
+
+        attr.setFree();
+        NodeCronMemento memento1(attr); // change cron
+        t->set_memento(&memento1, aspects, aspect_only);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeCronMemento failed: " << helper.errorMsg());
+    }
+
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        node_ptr t      = suite->add_task("t1");
+
+        std::vector<ecf::Child::CmdType> child_cmds = ecf::Child::list();
+
+        ZombieAttr attr(ecf::Child::USER, child_cmds, ecf::User::FOB, 10);
+
+        NodeZombieMemento memento(attr);
+        t->set_memento(&memento, aspects, aspect_only); // add zombie;
+
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "NodeZombieMemento failed: " << helper.errorMsg());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestMigration.cpp 5.13.0-1/libs/node/test/parser/TestMigration.cpp
--- 5.12.4-1/libs/node/test/parser/TestMigration.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestMigration.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,619 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "MyDefsFixture.hpp"
+#include "PersistHelper.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/Memento.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+
+// ********************************************************************
+// These test are used to check that MIGRATE is equivalent to check pt
+// MIGRATE will be used for migration from old to new release
+// MIGRATE is essentially the defs structure with state.
+// The state is written out as comments
+// It is loaded like a normal Defs, the parser detects MIGRATE
+// and loads the state in.
+//
+// By default  persistence/MIGRATE *ONLY* writes the state when it not the default.
+// Hence the defaults should *NOT* change. These test will change the state
+// to a non default value.
+//
+// Write the Defs with state and the compare with in memory defs
+// Write the Defs as check pt an then compare with in memory defs
+// Finally compare the two *RELOADED* defs file.
+// ********************************************************************
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_Migration)
+
+BOOST_AUTO_TEST_CASE(test_state_parser) {
+    cout << "AParser:: ...test_state_parser\n";
+    // **** The persistence will NOT write the defaults, hence we need to change the states
+    // **** to test the persistence
+    PersistHelper helper;
+    std::vector<Flag::Type> flag_list = Flag::list();
+    {
+        Defs defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Empty Defs failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+
+        // Change state other the default
+        defs.beginAll();
+        suite->set_state(NState::ABORTED);
+        for (auto& i : flag_list)
+            suite->flag().set(i);
+        suite->suspend();
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Add one suite failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        family_ptr f1   = suite->add_family("f1");
+
+        // Change state other the default
+        f1->set_state(NState::COMPLETE);
+        for (auto& i : flag_list)
+            f1->flag().set(i);
+        f1->suspend();
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Add one family failed: " << helper.errorMsg());
+
+        // Test multiple
+        suite->add_family("f2");
+        suite->add_family("f3");
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Add one family failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        family_ptr f1 = defs.add_suite("s1")->add_family("f1");
+        task_ptr t1   = f1->add_task("t1");
+
+        for (auto& i : flag_list)
+            t1->flag().set(i);
+        t1->suspend();
+        t1->set_state(NState::COMPLETE);
+
+        // Use memento to modify task state
+        SubmittableMemento memento("Jobs_password", "the_rid", "the abort  reason with spaces", 12);
+        std::vector<ecf::Aspect::Type> aspects;
+        t1->set_memento(&memento, aspects, false);
+
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Add one task failed: " << helper.errorMsg());
+
+        // Test multiple
+        f1->add_task("t2");
+        f1->add_task("t3");
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Add one task failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        task_ptr task = defs.add_suite("s1")->add_family("f1")->add_task("t1");
+        alias_ptr t1  = task->add_alias_only();
+        for (auto& i : flag_list)
+            t1->flag().set(i);
+        t1->suspend();
+        t1->set_state(NState::COMPLETE);
+        // Use memento to modify alias state
+        SubmittableMemento memento("Jobs_password", "the_rid", "the abort  reason with spaces", 12);
+        std::vector<ecf::Aspect::Type> aspects;
+        t1->set_memento(&memento, aspects, false);
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Add one alias failed: " << helper.errorMsg());
+
+        // Test multiple
+        task->add_alias_only();
+        task->add_alias_only();
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Add multiple alias failed: " << helper.errorMsg());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_state_node_attributes) {
+    cout << "AParser:: ...test_state_node_attributes\n";
+    PersistHelper helper;
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        task_ptr task   = suite->add_task("t1");
+        ecf::LateAttr lateAttr;
+        lateAttr.addSubmitted(ecf::TimeSlot(3, 12));
+        lateAttr.addActive(ecf::TimeSlot(3, 12));
+        lateAttr.addComplete(ecf::TimeSlot(4, 12), true);
+        lateAttr.setLate(true);
+        task->addLate(lateAttr);
+
+        ecf::LateAttr lateAttr1;
+        lateAttr1.addSubmitted(ecf::TimeSlot(3, 12));
+        lateAttr1.addActive(ecf::TimeSlot(3, 12));
+        lateAttr1.addComplete(ecf::TimeSlot(4, 12), false);
+        lateAttr1.setLate(true);
+        task_ptr task1 = suite->add_task("t2");
+        task1->addLate(lateAttr1);
+
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Late state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        task_ptr task = defs.add_suite("s1")->add_task("t1");
+        Meter meter("meter", 0, 100, 100);
+        meter.set_value(10);
+        task->addMeter(meter);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Meter state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        task_ptr task = defs.add_suite("s1")->add_task("t1");
+        Event event("event");
+        event.set_value(true);
+        Event event2(10, "event");
+        event2.set_value(true);
+        Event event3(10);
+        event3.set_value(true);
+        Event event4(10, "event4", true /*init value*/, true /*value*/);
+        Event event5(10, "event5", true /*init value*/, false /*value*/);
+        task->addEvent(event);
+        task->addEvent(event2);
+        task->addEvent(event3);
+        task->addEvent(event4);
+        task->addEvent(event5);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Event state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        family_ptr fam  = suite->add_family("f1");
+        task_ptr t      = fam->add_task("t");
+        std::vector<std::string> queue_items;
+        queue_items.emplace_back("001");
+        queue_items.emplace_back("002");
+        queue_items.emplace_back("003");
+        QueueAttr queue("queue", queue_items);
+        queue.active();
+        queue.active();
+        QueueAttr queue1("queue1", queue_items);
+        queue1.active();
+        suite->add_queue(queue);
+        suite->add_queue(queue1);
+        fam->add_queue(queue);
+        fam->add_queue(queue1);
+        t->add_queue(queue);
+        t->add_queue(queue1);
+        // PrintStyle::setStyle(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Queue state: failed: " << helper.errorMsg());
+    }
+    {
+        {
+            Defs defs;
+            task_ptr task = defs.add_suite("s1")->add_task("t1");
+            Label label("name", "value");
+            label.set_new_value("new  value");
+            task->addLabel(label);
+            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                                "Label state: failed: " << helper.errorMsg());
+        }
+        {
+            Defs defs;
+            suite_ptr suite = defs.add_suite("s1");
+            Label label("name", "value");
+            label.set_new_value("new  value");
+            suite->addLabel(label);
+            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                                "Label state: failed: " << helper.errorMsg());
+        }
+        {
+            Defs defs;
+            suite_ptr suite = defs.add_suite("s1");
+            Label label("name", "value\nvalue");
+            suite->addLabel(label);
+            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                                "Label state: failed: " << helper.errorMsg());
+        }
+        {
+            Defs defs;
+            suite_ptr suite = defs.add_suite("s1");
+            Label label("name", "value\nvalue");
+            label.set_new_value("value\nwith\nmany\nnewlines");
+            suite->addLabel(label);
+            //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+            BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                                "Label state: failed: " << helper.errorMsg());
+        }
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        task_ptr t1     = suite->add_task("t1");
+        task_ptr t2     = suite->add_task("t2");
+        task_ptr t3     = suite->add_task("t3");
+        task_ptr t4     = suite->add_task("t4");
+        Limit limit("limit", 10);
+        limit.increment(1, t1->absNodePath());
+        limit.increment(1, t2->absNodePath());
+        limit.increment(1, t3->absNodePath());
+        limit.increment(1, t4->absNodePath());
+        suite->addLimit(limit);
+        //       PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Limit state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        task_ptr t1     = suite->add_task("t1");
+        InLimit inlimit1("limit", "/s1", 10, true); // limit has state when 'limit this node only' is set
+        inlimit1.set_incremented(true);             // the state
+        InLimit inlimit2("limit2", "/s1", 10);
+        t1->addInLimit(inlimit1);
+        t1->addInLimit(inlimit2);
+
+        //       PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "InLimit state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        task_ptr t1     = suite->add_task("t1");
+        task_ptr t2     = suite->add_task("t2");
+        task_ptr t3     = suite->add_task("t3");
+        task_ptr t4     = suite->add_task("t4");
+        task_ptr t5     = suite->add_task("t5");
+        task_ptr t6     = suite->add_task("t6");
+
+        std::vector<std::string> stringList;
+        stringList.reserve(3);
+        stringList.emplace_back("20130101");
+        stringList.emplace_back("20130201");
+        stringList.emplace_back("20130301");
+
+        RepeatEnumerated rep("AEnum", stringList);
+        rep.increment();
+        t1->addRepeat(rep);
+
+        RepeatString rep2("AEnum", stringList);
+        rep2.increment();
+        t2->addRepeat(rep2);
+
+        RepeatDate rep3("YMD", 20090916, 20090916, 1);
+        rep3.increment();
+        t3->addRepeat(rep3);
+
+        RepeatInteger rep4("rep", 0, 100, 1);
+        rep4.increment();
+        t4->addRepeat(rep4);
+        t4->increment_repeat();
+
+        RepeatDay rep5(2);
+        rep5.increment();
+        t5->addRepeat(rep5);
+
+        RepeatDateList rep6("YMD", {20090916, 20090916});
+        rep6.increment();
+        t6->addRepeat(rep6);
+
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Repeat state: failed: " << helper.errorMsg());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_state_time_attributes) {
+    cout << "AParser:: ...test_state_time_attributes\n";
+    PersistHelper helper;
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        suite->begin();
+        task_ptr task = suite->add_task("t1");
+        TimeAttr time(10, 10);
+        time.setFree();
+        time.miss_next_time_slot();
+        TimeAttr time2(10, 10, true);
+        time2.calendarChanged(suite->calendar());
+        time2.setFree();
+        time2.miss_next_time_slot();
+        TimeAttr time3(TimeSlot(10, 10), TimeSlot(12, 10), TimeSlot(0, 10), true);
+        time3.calendarChanged(suite->calendar());
+        time3.setFree();
+        time3.miss_next_time_slot();
+
+        task->addTime(time);
+        task->addTime(time2);
+        task->addTime(time3);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Time state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        suite->begin();
+        task_ptr task = suite->add_task("t1");
+        TodayAttr time(10, 10);
+        time.setFree();
+        time.miss_next_time_slot();
+        TodayAttr time2(10, 10, true);
+        time2.calendarChanged(suite->calendar());
+        time2.setFree();
+        time2.miss_next_time_slot();
+        TodayAttr time3(TimeSlot(10, 10), TimeSlot(12, 10), TimeSlot(0, 10), true);
+        time3.calendarChanged(suite->calendar());
+        time3.setFree();
+        time3.miss_next_time_slot();
+        task->addToday(time);
+        task->addToday(time2);
+        task->addToday(time3);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Today state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        task_ptr task = defs.add_suite("s1")->add_task("t1");
+        DayAttr day;
+        DayAttr day1;
+        day1.setFree();
+        DayAttr day2(DayAttr::FRIDAY);
+        day2.setFree();
+        task->addDay(day);
+        task->addDay(day1);
+        task->addDay(day2);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Day state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        task_ptr task = defs.add_suite("s1")->add_task("t1");
+        DateAttr d;
+        DateAttr d1;
+        d1.setFree();
+        DateAttr d2(1, 1, 2012);
+        d2.setFree();
+        DateAttr d3(0, 0, 2012);
+        d3.setFree();
+        task->addDate(d);
+        task->addDate(d1);
+        task->addDate(d2);
+        task->addDate(d3);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Date state: failed: " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        suite_ptr suite = defs.add_suite("s1");
+        suite->begin();
+        task_ptr task  = suite->add_task("t1");
+        task_ptr task2 = suite->add_task("t2");
+
+        ecf::CronAttr cronAttr;
+        ecf::TimeSlot start(0, 0);
+        ecf::TimeSlot finish(10, 0);
+        ecf::TimeSlot incr(0, 5);
+        std::vector<int> weekdays;
+        for (int i = 0; i < 7; ++i)
+            weekdays.push_back(i);
+        std::vector<int> daysOfMonth;
+        for (int i = 1; i < 32; ++i)
+            daysOfMonth.push_back(i);
+        std::vector<int> months;
+        for (int i = 1; i < 13; ++i)
+            months.push_back(i);
+        cronAttr.addTimeSeries(start, finish, incr);
+        cronAttr.addWeekDays(weekdays);
+        cronAttr.addDaysOfMonth(daysOfMonth);
+        cronAttr.addMonths(months);
+        cronAttr.setFree();
+        task->addCron(cronAttr);
+
+        // Change TimeSeries state
+        TimeSeries ts(start, finish, incr, true);
+        ts.calendarChanged(suite->calendar());
+        ts.miss_next_time_slot();
+        cronAttr.addTimeSeries(ts);
+        task2->addCron(cronAttr);
+
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Date state: failed: " << helper.errorMsg());
+    }
+
+    // ZombieAttr do not have any changeable state
+}
+
+BOOST_AUTO_TEST_CASE(test_state_edit_history) {
+    cout << "AParser:: ...test_state_edit_history\n";
+    PersistHelper helper(true /* compare edit History */);
+    Defs defs;
+    suite_ptr suite = defs.add_suite("s1");
+    defs.add_edit_history(suite->absNodePath(), "request1 with single spaces");
+    defs.add_edit_history(suite->absNodePath(), "request2 with double  spaces");
+    defs.add_edit_history(suite->absNodePath(), "request3_with_no_spaces!|?<>$%^&*()_{}:@<>?");
+    suite_ptr suite2 = defs.add_suite("s2");
+    defs.add_edit_history(suite2->absNodePath(), "request1 with single spaces");
+    defs.add_edit_history(suite2->absNodePath(), "request2 with double  spaces");
+    defs.add_edit_history(suite2->absNodePath(), "request3_with_no_spaces!|?<>$%^&*()_{}:@<>?");
+    //   PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+    BOOST_REQUIRE_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                          "Edit history failed: " << helper.errorMsg());
+}
+
+static std::string dump_edit_history(const std::unordered_map<std::string, std::vector<std::string>>& edit_history) {
+    std::stringstream ss;
+    for (const auto& i : edit_history) {
+        ss << "node: " << i.first << "\n";
+        for (const auto& h : i.second) {
+            ss << "  " << h << "\n";
+        }
+    }
+    return ss.str();
+}
+
+BOOST_AUTO_TEST_CASE(test_state_edit_history_pruning) {
+    cout << "AParser:: ...test_state_edit_history_pruning\n";
+    Defs defs;
+    suite_ptr suite = defs.add_suite("s1");
+    defs.add_edit_history(suite->absNodePath(), "MSG:[07:36:05 10.3.2016] --requeue force /s1  :maj");
+    defs.add_edit_history(suite->absNodePath(), "MSG:[09:15:33 26.8.2016] --run /s1  :mab");
+    defs.add_edit_history(suite->absNodePath(), "MSG:[06:45:18 26.8.2017] --force=queued /s1  :ma0");
+    suite_ptr suite2 = defs.add_suite("s2");
+    defs.add_edit_history(suite2->absNodePath(), "MSG:[19:13:44 21.6.2016] --suspend /s2  :ma");
+    defs.add_edit_history(suite2->absNodePath(), "MSG:[11:28:12 6.10.2016] --requeue abort /s2  :ma");
+    defs.add_edit_history(suite2->absNodePath(), "MSG:[09:15:33 26.8.2016] --run /s2  :mab");
+    //   PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+    //   cout << dump_edit_history(defs.get_edit_history()) << "\n";
+
+    std::string tmpFilename = "test_state_edit_history_pruning.def";
+    defs.save_as_checkpt(tmpFilename);
+
+    {
+        // If any edit history is older than 1 day, then prune
+        Defs reloaded_defs;
+        reloaded_defs.ecf_prune_node_log(1);
+
+        std::string errorMsg, warningMsg;
+        BOOST_REQUIRE_MESSAGE(reloaded_defs.restore(tmpFilename, errorMsg, warningMsg),
+                              "RE-PARSE failed for " << tmpFilename);
+
+        const std::unordered_map<std::string, std::vector<std::string>>& edit_history =
+            reloaded_defs.get_edit_history();
+        BOOST_REQUIRE_MESSAGE(edit_history.empty(),
+                              "Expected no edit history after pruning, but found:\n"
+                                  << dump_edit_history(edit_history));
+    }
+
+    std::remove(tmpFilename.c_str());
+}
+
+BOOST_AUTO_TEST_CASE(test_state_edit_history_pruning2) {
+    cout << "AParser:: ...test_state_edit_history_pruning2\n";
+
+    // Create edit history for today, this should not be affected by pruning
+    date todays_date_in_utc = day_clock::universal_day();
+    std::string history     = "MSG:[07:36:05 ";
+    history += ecf::convert_to<std::string>(todays_date_in_utc.day());
+    history += ".";
+    history += ecf::convert_to<std::string>(todays_date_in_utc.month());
+    history += ".";
+    history += ecf::convert_to<std::string>(todays_date_in_utc.year());
+    history += "] --requeue force /s1  :maj";
+
+    Defs defs;
+    suite_ptr suite = defs.add_suite("s1");
+    defs.add_edit_history(suite->absNodePath(), history);
+    defs.add_edit_history(suite->absNodePath(), history);
+    defs.add_edit_history(suite->absNodePath(), history);
+    //   PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+    //   cout << dump_edit_history(defs.get_edit_history()) << "\n";
+
+    std::string tmpFilename = "test_state_edit_history_pruning2.def";
+    defs.save_as_checkpt(tmpFilename);
+
+    {
+        // Since the history is todays it should be preserved, and not affected by pruning
+        Defs reloaded_defs;
+        reloaded_defs.ecf_prune_node_log(1);
+
+        std::string errorMsg, warningMsg;
+        BOOST_REQUIRE_MESSAGE(reloaded_defs.restore(tmpFilename, errorMsg, warningMsg),
+                              "RE-PARSE failed for " << tmpFilename);
+
+        const std::unordered_map<std::string, std::vector<std::string>>& edit_history =
+            reloaded_defs.get_edit_history();
+        //      cout << dump_edit_history(defs.get_edit_history()) << "\n";
+
+        BOOST_REQUIRE_MESSAGE(!edit_history.empty(), "Expected edit history but found none");
+    }
+
+    std::remove(tmpFilename.c_str());
+}
+
+BOOST_AUTO_TEST_CASE(test_server_state) {
+    cout << "AParser:: ...test_server_state\n";
+    PersistHelper helper(true /* compare edit History */);
+    {
+        Defs defs;
+        defs.set_server().set_state(SState::HALTED);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Set server state failed " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        defs.set_server().set_state(SState::RUNNING);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Set server state failed " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        defs.set_server().set_state(SState::SHUTDOWN);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Set server state failed " << helper.errorMsg());
+    }
+    {
+        Defs defs;
+        std::vector<Variable> vec;
+        vec.emplace_back("name", "value1");
+        vec.emplace_back("name2", "val with 'spaces' ");
+        vec.emplace_back("name3", "");
+        defs.set_server().set_user_variables(vec);
+        //      PrintStyle style(PrintStyle::MIGRATE); std::cout << defs;
+        BOOST_CHECK_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(defs),
+                            "Set server variables failed " << helper.errorMsg());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_state_fixture_defs) {
+    cout << "AParser:: ...test_state_fixture_defs\n";
+    PersistHelper helper;
+    MyDefsFixture theDefsFixture;
+    BOOST_REQUIRE_MESSAGE(helper.test_state_persist_and_reload_with_checkpt(theDefsFixture.defsfile_),
+                          "Fixture failed: " << helper.errorMsg());
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestMirrorAttr.cpp 5.13.0-1/libs/node/test/parser/TestMirrorAttr.cpp
--- 5.12.4-1/libs/node/test/parser/TestMirrorAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestMirrorAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,110 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_MirrorAttr)
+
+BOOST_AUTO_TEST_CASE(can_parse_mirror_attribute_on_task_with_default_parameters) {
+    std::cout << "..." << boost::unit_test::framework::current_test_unit().full_name() << std::endl;
+
+    using namespace ecf;
+
+    std::string definition = R"(
+        suite s1
+          family f1
+            task t1
+              mirror --name A --remote_path /s1/f1/t2
+          endfamily
+    )";
+
+    Defs defs;
+    DefsStructureParser parser(&defs, definition, true);
+
+    std::string errorMsg, warningMsg;
+    bool parsedOK = parser.doParse(errorMsg, warningMsg);
+    BOOST_CHECK_MESSAGE(parsedOK, "Failed to parse definition: " << errorMsg);
+
+    const auto& suites = defs.suiteVec();
+    BOOST_CHECK_EQUAL(suites.size(), static_cast<size_t>(1));
+
+    const auto& families = suites[0]->familyVec();
+    BOOST_CHECK_EQUAL(families.size(), static_cast<size_t>(1));
+
+    const auto& tasks = families[0]->taskVec();
+    BOOST_CHECK_EQUAL(tasks.size(), static_cast<size_t>(1));
+
+    const auto& mirrors = tasks[0]->mirrors();
+    BOOST_CHECK_EQUAL(mirrors.size(), static_cast<size_t>(1));
+
+    const auto& mirror = mirrors[0];
+    BOOST_CHECK_EQUAL(mirror.name(), "A");
+    BOOST_CHECK_EQUAL(mirror.remote_path(), "/s1/f1/t2");
+    BOOST_CHECK_EQUAL(mirror.remote_host(), "%ECF_MIRROR_REMOTE_HOST%");
+    BOOST_CHECK_EQUAL(mirror.remote_port(), "%ECF_MIRROR_REMOTE_PORT%");
+    BOOST_CHECK_EQUAL(mirror.polling(), "%ECF_MIRROR_REMOTE_POLLING%");
+    BOOST_CHECK_EQUAL(mirror.ssl(), false);
+}
+
+BOOST_AUTO_TEST_CASE(can_parse_mirror_attribute_on_task_with_all_attributes) {
+    std::cout << "..." << boost::unit_test::framework::current_test_unit().full_name() << std::endl;
+
+    using namespace ecf;
+
+    std::string definition = R"(
+        suite s1
+          family f1
+            task t1
+              mirror --name A --remote_path /s1/f1/t2 --remote_host hostname --remote_port 1234 --polling 20 --ssl
+          endfamily
+    )";
+
+    Defs defs;
+    DefsStructureParser parser(&defs, definition, true);
+
+    std::string errorMsg, warningMsg;
+    bool parsedOK = parser.doParse(errorMsg, warningMsg);
+    BOOST_CHECK_MESSAGE(parsedOK, "Failed to parse definition: " << errorMsg);
+
+    const auto& suites = defs.suiteVec();
+    BOOST_CHECK_EQUAL(suites.size(), static_cast<size_t>(1));
+
+    const auto& families = suites[0]->familyVec();
+    BOOST_CHECK_EQUAL(families.size(), static_cast<size_t>(1));
+
+    const auto& tasks = families[0]->taskVec();
+    BOOST_CHECK_EQUAL(tasks.size(), static_cast<size_t>(1));
+
+    const auto& mirrors = tasks[0]->mirrors();
+    BOOST_CHECK_EQUAL(mirrors.size(), static_cast<size_t>(1));
+
+    const auto& mirror = mirrors[0];
+    BOOST_CHECK_EQUAL(mirror.name(), "A");
+    BOOST_CHECK_EQUAL(mirror.remote_path(), "/s1/f1/t2");
+    BOOST_CHECK_EQUAL(mirror.remote_host(), "hostname");
+    BOOST_CHECK_EQUAL(mirror.remote_port(), "1234");
+    BOOST_CHECK_EQUAL(mirror.polling(), "20");
+    BOOST_CHECK_EQUAL(mirror.ssl(), true);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestParser.cpp 5.13.0-1/libs/node/test/parser/TestParser.cpp
--- 5.12.4-1/libs/node/test/parser/TestParser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestParser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,233 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "PersistHelper.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+using namespace ecf;
+
+std::vector<std::string> defs_with_expected_warnings() {
+    return {"limit/limit3.def"};
+}
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_Parser)
+
+void test_defs(const std::string& directory, bool pass) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+    DebugEquality debug_equality; // only as affect in DEBUG build
+
+    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (fs::is_directory(dir_itr->status())) {
+                test_defs(relPath.string(), pass);
+                continue;
+            }
+
+            // std::cout << "......Parsing file " << relPath.string() << "\n";
+
+            Defs defs;
+            DefsStructureParser parser(&defs, relPath.string());
+
+            std::string errorMsg, warningMsg;
+            bool parsedOk = parser.doParse(errorMsg, warningMsg);
+            if (pass) {
+                // Test expected to pass
+                BOOST_CHECK_MESSAGE(parsedOk, "Failed to parse file " << relPath << "\n" << errorMsg);
+
+                if (parsedOk) {
+                    // Check triggers and limits
+                    std::string err_msg, warn_msg;
+                    defs.check(err_msg, warn_msg);
+                    BOOST_CHECK_MESSAGE(err_msg.empty(),
+                                        "Expected no errors but found:" << err_msg << "File: " << relPath.string());
+
+                    // expect warnings for some file:
+                    bool ignore = false;
+                    for (auto path : defs_with_expected_warnings()) {
+                        if (relPath.string().find(path) != std::string::npos) {
+                            ignore = true;
+                            break;
+                        }
+                    }
+                    if (!ignore)
+                        BOOST_CHECK_MESSAGE(warn_msg.empty(),
+                                            "Expected no warnings but found:" << warn_msg
+                                                                              << "File: " << relPath.string());
+
+                    // Write parsed file to a temporary file on disk, and reload, then compare defs, should be the same
+                    PersistHelper helper;
+                    BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, parser.get_file_type()),
+                                        relPath.string() << " " << helper.errorMsg());
+                    BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(defs),
+                                        relPath.string() << " " << helper.errorMsg());
+
+                    // test copy constructor
+                    Defs copy_of_defs = Defs(defs);
+                    BOOST_CHECK_MESSAGE(copy_of_defs == defs, "Error copy constructor failed " << relPath);
+
+                    // Test parse by string is same as parsing by file:
+                    {
+                        std::string contents;
+                        BOOST_CHECK_MESSAGE(File::open(relPath.string(), contents),
+                                            "Error could not open file " << relPath);
+                        // cout << "parsing file " << relPath << " by string\n";
+
+                        Defs defs2;
+                        std::string errorMsg2, warningMsg2;
+                        BOOST_CHECK_MESSAGE(defs2.restore_from_string(contents, errorMsg2, warningMsg2),
+                                            "restore from string failed for file " << relPath << "\n"
+                                                                                   << errorMsg2);
+                        BOOST_CHECK_MESSAGE(defs2 == defs,
+                                            "Parse by string != parse by filename for file:\n"
+                                                << relPath);
+                    }
+
+                    // Make sure all nodes can be found
+                    std::vector<Node*> all_nodes;
+                    defs.getAllNodes(all_nodes);
+                    for (auto node : all_nodes) {
+                        node_ptr found_node = defs.findAbsNode(node->absNodePath());
+                        BOOST_CHECK_MESSAGE(found_node.get(), "Could not find node " << node->debugNodePath());
+                        BOOST_CHECK_MESSAGE(found_node.get() == node,
+                                            " Expected to find " << node->debugNodePath() << " but found "
+                                                                 << found_node->debugNodePath());
+                    }
+                }
+            }
+            else {
+                // test expected to fail
+                if (parsedOk) {
+                    // Check triggers and limits
+                    std::string err_msg, warn_msg;
+                    defs.check(err_msg, warn_msg);
+                    BOOST_CHECK_MESSAGE(!err_msg.empty() || !warn_msg.empty(),
+                                        "Expected problems with trigger/limits but found none for file" << relPath
+                                                                                                        << "\n");
+                }
+                else {
+                    BOOST_CHECK_MESSAGE(!parsedOk, "Parse expected to fail for " << relPath << "\n" << errorMsg);
+                }
+            }
+        }
+        catch (const std::exception& ex) {
+            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_for_good_defs) {
+    cout << "AParser:: ...test_parsing_for_good_defs\n";
+
+    std::string path = File::test_data("libs/node/test/parser/data/good_defs", "parser");
+
+    // All the defs in this directory are expected to pass
+    test_defs(path, true);
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_for_bad_defs) {
+    cout << "AParser:: ...test_parsing_for_bad_defs\n";
+
+    std::string path = File::test_data("libs/node/test/parser/data/bad_defs", "parser");
+
+    // All the defs in this directory are expected to fail
+    test_defs(path, false);
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_for_good_defs_state) {
+    cout << "AParser:: ...test_parsing_for_good_defs_state\n";
+
+    std::string path = File::test_data("libs/node/test/parser/data/good_defs_state", "parser");
+
+    // All the defs in this directory are expected to pass
+    test_defs(path, true);
+}
+
+void test_node_defs(const std::string& directory, bool pass) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (fs::is_directory(dir_itr->status())) {
+                test_node_defs(relPath.string(), pass);
+                continue;
+            }
+
+            // std::cout << "......Parsing file " << relPath.string() << "\n";
+            std::string file_contents;
+            if (!ecf::File::open(relPath.string(), file_contents)) {
+                std::cout << "......Could not open file" << relPath.string() << "\n";
+                continue;
+            }
+
+            // Parse string as a standalone node.
+            DefsStructureParser parser(file_contents);
+            std::string errorMsg, warningMsg;
+            bool parsedOk = parser.doParse(errorMsg, warningMsg);
+            if (pass) {
+                // Test expected to pass
+                BOOST_CHECK_MESSAGE(parsedOk, "Failed to parse file " << relPath << "\n" << errorMsg);
+                BOOST_CHECK_MESSAGE(parser.the_node_ptr(), "Failed to parse file " << relPath << "\n" << errorMsg);
+                // PrintStyle print_style(PrintStyle::MIGRATE);
+                // parser.the_node_ptr()->print(cout);
+            }
+            else {
+                // test expected to fail
+                // std::cout << errorMsg << "\n";
+                BOOST_CHECK_MESSAGE(!parser.the_node_ptr(),
+                                    "Parse expected to fail for " << relPath << "\n"
+                                                                  << errorMsg);
+            }
+        }
+        catch (const std::exception& ex) {
+            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_parsing_node) {
+    cout << "AParser:: ...test_parsing_node\n";
+
+    std::string path = File::test_data("libs/node/test/parser/data/good_node_defs", "parser");
+
+    // All the defs in this directory are expected to pass
+    test_node_defs(path, true);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestParserPerformance_main.cpp 5.13.0-1/libs/node/test/parser/TestParserPerformance_main.cpp
--- 5.12.4-1/libs/node/test/parser/TestParserPerformance_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestParserPerformance_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_ParserPerformance
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/node/test/parser/TestParser_main.cpp 5.13.0-1/libs/node/test/parser/TestParser_main.cpp
--- 5.12.4-1/libs/node/test/parser/TestParser_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestParser_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Parser
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/node/test/parser/TestSingleDefsFile.cpp 5.13.0-1/libs/node/test/parser/TestSingleDefsFile.cpp
--- 5.12.4-1/libs/node/test/parser/TestSingleDefsFile.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestSingleDefsFile.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,325 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+#include <string>
+
+#include <boost/chrono.hpp>
+#include <boost/test/unit_test.hpp>
+#include <boost/timer/timer.hpp>
+
+#include "PersistHelper.hpp"
+#include "TemporaryFile.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/NodeContainer.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_SingleDefsFile)
+
+// This test is used to find a task given a path of the form:
+//     suite/family/task
+//     suite/family/family/task
+void test_find_task_using_path(NodeContainer* f, const Defs& defs) {
+    BOOST_CHECK_MESSAGE(f == defs.findAbsNode(f->absNodePath()).get(),
+                        "Could not find path " << f->absNodePath() << "\n");
+
+    for (node_ptr t : f->nodeVec()) {
+        BOOST_CHECK_MESSAGE(t.get() == defs.findAbsNode(t->absNodePath()).get(),
+                            "Could not find path " << t->absNodePath() << "\n");
+        Family* family = t->isFamily();
+        if (family) {
+            test_find_task_using_path(family, defs);
+        }
+    }
+}
+
+// Create derived class, so that we can time the parse only
+// i.e ignore expression build/checking and limit checking
+class TestDefsStructureParser : public DefsStructureParser {
+public:
+    TestDefsStructureParser(Defs* defsfile, const std::string& file_name) : DefsStructureParser(defsfile, file_name) {}
+    bool do_parse_file(std::string& errorMsg) { return DefsStructureParser::do_parse_file(errorMsg); }
+};
+
+double get_seconds(const boost::timer::nanosecond_type& elapsed) {
+    return static_cast<double>(boost::chrono::nanoseconds(elapsed).count()) * boost::chrono::nanoseconds::period::num /
+           boost::chrono::nanoseconds::period::den;
+}
+
+BOOST_AUTO_TEST_CASE(test_single_defs) {
+    boost::timer::auto_cpu_timer auto_cpu_timer;
+
+    std::string path      = File::test_data("libs/node/test/parser/data/single_defs/mega.def", "parser");
+    size_t mega_file_size = fs::file_size(path);
+    cout << "AParser:: ...test_single_defs " << path << " file_size(" << mega_file_size << ")\n";
+
+    // Time parse/resolve dependencies: This will need to be #defined depending on the platform
+    // Change for file_iterator to plain string halved the time taken to load operation suite
+    boost::timer::cpu_timer timer;
+
+#ifdef DEBUG
+    #if defined(HPUX) || defined(_AIX)
+    double expectedTimeForParse                   = 15.0;
+    double expectedTimeForParseOnly               = 10.0;
+    double expectedTimeForResolveDependencies     = 3.5; // this is time for 10 job submissions
+    double checkExprAndLimits                     = 1.0;
+    double expectedTimeForFindAllPaths            = 7.2;
+    double expectedTimeForDefsPersistOnly         = 6;
+    double expectedTimeForDefsPersistAndReload    = 24;
+    double expectedTimeForCheckPtPersistAndReload = 27;
+    #else
+    double expectedTimeForParse                   = 4.5;
+    double expectedTimeForParseOnly               = 2.0;
+    double expectedTimeForResolveDependencies     = 0.5; // this is time for 10 job submissions
+    double checkExprAndLimits                     = 0.5;
+    double expectedTimeForFindAllPaths            = 1.2;
+    double expectedTimeForDefsPersistOnly         = 2;
+    double expectedTimeForDefsPersistAndReload    = 4.5;
+    double expectedTimeForCheckPtPersistAndReload = 8.0;
+    #endif
+#else
+    #if defined(HPUX) || defined(_AIX)
+    double expectedTimeForParse                   = 7.8;
+    double expectedTimeForParseOnly               = 5.0;
+    double expectedTimeForResolveDependencies     = 3.5; // this is time for 10 job submissions
+    double checkExprAndLimits                     = 1.0;
+    double expectedTimeForFindAllPaths            = 4.5;
+    double expectedTimeForDefsPersistOnly         = 3.5;
+    double expectedTimeForDefsPersistAndReload    = 9.5;
+    double expectedTimeForCheckPtPersistAndReload = 11.5;
+    #else
+    double expectedTimeForParse                   = 1.2;
+    double expectedTimeForParseOnly               = 0.6;
+    double expectedTimeForResolveDependencies     = 0.2; // this is time for 10 job submissions
+    double checkExprAndLimits                     = 0.1;
+    double expectedTimeForFindAllPaths            = 0.58;
+    double expectedTimeForDefsPersistOnly         = 0.4;
+    double expectedTimeForDefsPersistAndReload    = 1.4;
+    double expectedTimeForCheckPtPersistAndReload = 1.6;
+    #endif
+#endif
+    // ****************************************************************************************
+    // Please note: that for Parsing: that the predominate time is taken in creating the AST/ and checking
+
+    /// If this is moved below, we get some caching affect, with the persist and reload timing
+    Defs defs;
+    {
+        timer.start();
+        std::string errorMsg, warningMsg;
+        BOOST_REQUIRE_MESSAGE(defs.restore(path, errorMsg, warningMsg), errorMsg);
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForParse,
+                            "Performance regression, expected < " << expectedTimeForParse
+                                                                  << " seconds for parse/node tree creation but found "
+                                                                  << timer.format(3, Str::cpu_timer_format()));
+        cout << " Parsing Node tree and AST creation time                = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << expectedTimeForParse << ")" << endl;
+    }
+    {
+        Defs local_defs;
+        timer.start();
+        TestDefsStructureParser checkPtParser(&local_defs, path);
+        std::string errorMsg;
+        BOOST_REQUIRE_MESSAGE(checkPtParser.do_parse_file(errorMsg), errorMsg);
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForParse,
+                            "Performance regression, expected < " << expectedTimeForParseOnly
+                                                                  << " seconds for parse/node tree creation but found "
+                                                                  << timer.format(3, Str::cpu_timer_format()));
+        cout << " Parsing Node tree *only* time                          = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << expectedTimeForParseOnly << ")" << endl;
+    }
+    {
+        timer.start();
+        for (suite_ptr s : defs.suiteVec()) {
+            test_find_task_using_path(s.get(), defs);
+        }
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForFindAllPaths,
+                            "Performance regression, expected < " << expectedTimeForFindAllPaths
+                                                                  << " seconds to find all paths, but found "
+                                                                  << timer.format(3, Str::cpu_timer_format()));
+        cout << " Test all paths can be found. time taken                = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << expectedTimeForFindAllPaths << ")" << endl;
+    }
+
+    {
+        // Test time for persisting to defs file only
+        TemporaryFile temporary("tmp_%%%%-%%%%-%%%%-%%%%.def");
+
+        timer.start();
+        PrintStyle style(PrintStyle::DEFS);
+        std::ofstream ofs(temporary.path());
+        ofs << defs;
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistOnly,
+                            "Performance regression, expected < " << expectedTimeForDefsPersistOnly
+                                                                  << " to persist defs file, but found "
+                                                                  << timer.format(3, Str::cpu_timer_format()));
+        cout << " Persist only, time taken                               = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << expectedTimeForDefsPersistOnly << ")" << endl;
+    }
+
+    {
+        // may need to comment out output for large differences. Will double the time.
+        timer.start();
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::DEFS), helper.errorMsg());
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistAndReload,
+                            "Performance regression, expected < " << expectedTimeForDefsPersistAndReload
+                                                                  << " seconds to persist and reload, but found "
+                                                                  << timer.format(3, Str::cpu_timer_format()));
+        cout << " Persist and reload(DEFS) and compare, time taken       = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << expectedTimeForDefsPersistAndReload << ")"
+             << " file_size(" << helper.file_size() << ")" << endl;
+    }
+    {
+        timer.start();
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::STATE), helper.errorMsg());
+        cout << " Persist and reload(STATE) and compare, time taken      = " << timer.format(3, Str::cpu_timer_format())
+             << " file_size(" << helper.file_size() << ")" << endl;
+    }
+    {
+        timer.start();
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::MIGRATE), helper.errorMsg());
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistAndReload,
+                            "Performance regression, expected < "
+                                << expectedTimeForDefsPersistAndReload
+                                << " seconds to persist and reload *state*, but found "
+                                << timer.format(3, Str::cpu_timer_format()));
+        cout << " Persist and reload(MIGRATE) and compare, time taken    = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << expectedTimeForDefsPersistAndReload << ")"
+             << " file_size(" << helper.file_size() << ")" << endl;
+
+        // each platform will have a slightly different size, since the server environment variables
+        // will be different, i.e host, pid, i.e check point etc, encompasses the host name, which will be different
+        BOOST_CHECK_MESSAGE(helper.file_size() <= 6679000,
+                            "File size regression expected <= 6679000 but found " << helper.file_size());
+    }
+    {
+        timer.start();
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_persist_and_reload(defs, PrintStyle::NET), helper.errorMsg());
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForDefsPersistAndReload,
+                            "Performance regression, expected < "
+                                << expectedTimeForDefsPersistAndReload
+                                << " seconds to persist and reload *state*, but found "
+                                << timer.format(3, Str::cpu_timer_format()));
+        cout << " Persist and reload(NET) and compare, time taken        = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << expectedTimeForDefsPersistAndReload << ")"
+             << " file_size(" << helper.file_size() << ")" << endl;
+
+        // each platform will have a slightly different size, since the server environment variables
+        // will be different, i.e host, pid, i.e check point etc, encompasses the host name, which will be different
+        BOOST_CHECK_MESSAGE(helper.file_size() <= 6679000,
+                            "File size regression expected <= 6679000 but found " << helper.file_size());
+    }
+
+    {
+        timer.start();
+        PersistHelper helper;
+        BOOST_CHECK_MESSAGE(helper.test_cereal_checkpt_and_reload(defs, true), helper.errorMsg());
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForCheckPtPersistAndReload,
+                            "Performance regression, expected < " << expectedTimeForCheckPtPersistAndReload
+                                                                  << " seconds to persist and reload, but found "
+                                                                  << timer.format(3, Str::cpu_timer_format()));
+        cout << " Checkpt(CEREAL) and reload and compare, time taken     = ";
+        cout << timer.format(3, Str::cpu_timer_format()) << " < limit(" << expectedTimeForCheckPtPersistAndReload << ")"
+             << " file_size(" << helper.file_size() << ")" << endl;
+    }
+
+    {
+        // Time how long it takes for job submission. Must call begin on all suites first.
+        timer.start();
+        defs.beginAll();
+        int count = 10;
+        JobsParam jobsParam; // default is *not* to create jobs, and *not* to spawn jobs, hence only used in testing
+        Jobs jobs(&defs);
+        for (int i = 0; i < count; i++) {
+            jobs.generate(jobsParam);
+        }
+        cout << " " << count
+             << " jobSubmissions                                      = " << timer.format(3, Str::cpu_timer_format())
+             << "s jobs:" << jobsParam.submitted().size() << " < limit(" << expectedTimeForResolveDependencies << ")"
+             << endl;
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < expectedTimeForResolveDependencies,
+                            "jobSubmission Performance regression, expected < "
+                                << expectedTimeForResolveDependencies
+                                << " seconds for resolving dependencies but found "
+                                << timer.format(3, Str::cpu_timer_format()));
+    }
+
+    {
+        // Time how long it takes for post process
+        timer.start();
+        string errorMsg, warningMsg;
+        BOOST_CHECK(defs.check(errorMsg, warningMsg));
+        cout << " Defs::check (inlimit resolution)                       = " << timer.format(3, Str::cpu_timer_format())
+             << " < limit(" << checkExprAndLimits << ")" << endl;
+        BOOST_CHECK_MESSAGE(get_seconds(timer.elapsed().user) < checkExprAndLimits,
+                            "Defs::check Performance regression, expected < "
+                                << checkExprAndLimits << " seconds for resolving dependencies but found "
+                                << timer.format(3, Str::cpu_timer_format()));
+    }
+
+    {
+        // Time how long it takes to delete all nodes/ references. Delete all tasks and then suites/families.
+        timer.start();
+        std::vector<Task*> tasks;
+        defs.getAllTasks(tasks);
+        BOOST_CHECK_MESSAGE(tasks.size() > 0, "Expected > 0 tasks but found " << tasks.size());
+        for (Task* t : tasks) {
+            BOOST_REQUIRE_MESSAGE(defs.deleteChild(t), " Failed to delete task");
+        }
+        tasks.clear();
+        defs.getAllTasks(tasks);
+        BOOST_REQUIRE_MESSAGE(tasks.empty(), "Expected all tasks to be deleted but found " << tasks.size());
+
+        std::vector<suite_ptr> vec = defs.suiteVec(); // make a copy, to avoid invalidating iterators
+        BOOST_CHECK_MESSAGE(vec.size() > 0, "Expected > 0 Suites but found " << vec.size());
+        for (suite_ptr s : vec) {
+            std::vector<node_ptr> familyVec = s->nodeVec(); // make a copy, to avoid invalidating iterators
+            for (node_ptr f : familyVec) {
+                BOOST_REQUIRE_MESSAGE(defs.deleteChild(f.get()), " Failed to delete family");
+            }
+            BOOST_REQUIRE_MESSAGE(s->nodeVec().empty(),
+                                  "Expected all Families to be deleted but found " << s->nodeVec().size());
+            BOOST_REQUIRE_MESSAGE(defs.deleteChild(s.get()), " Failed to delete suite");
+        }
+        BOOST_REQUIRE_MESSAGE(defs.suiteVec().empty(),
+                              "Expected all Suites to be deleted but found " << defs.suiteVec().size());
+
+        cout << " time for deleting all nodes                            = " << timer.format(3, Str::cpu_timer_format())
+             << endl;
+    }
+
+    // Explicitly destroy, To keep valgrind happy
+    Log::destroy();
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/TestVariableParsing.cpp 5.13.0-1/libs/node/test/parser/TestVariableParsing.cpp
--- 5.12.4-1/libs/node/test/parser/TestVariableParsing.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/TestVariableParsing.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,75 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Parser)
+
+BOOST_AUTO_TEST_SUITE(T_VariableParsing)
+
+BOOST_AUTO_TEST_CASE(test_single_defs) {
+
+    cout << "AParser:: ...test_variable  \n";
+
+    std::string path = File::test_data("libs/node/test/parser/data/good_defs/edit/edit.def", "parser");
+
+    Defs defs;
+    std::string errorMsg, warningMsg;
+    BOOST_REQUIRE_MESSAGE(defs.restore(path, errorMsg, warningMsg), errorMsg);
+
+    // suite edit
+    //     edit ECF_INCLUDE /home/ma/map/sms/example/x                  # comment line
+    //     edit ECF_FILES   /home/ma/map/sms/example/x                  #comment line
+    //     edit EXPVER 'f8na'                                          #
+    //     edit USER 'ecgems'                                          #comment
+    //     edit USER2 "ecgems"                                         # comment
+    //     edit INT1 "10"                                             # comment
+    //     edit INT2 '11'                                             # comment
+    //     edit YMD  '20091012'                                        # comment
+    //     family family
+    //         edit var  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # comment line
+    //         edit var2 'smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%'  #comment line
+    //         task t2
+    //     endfamily
+    // endsuite
+    suite_ptr editSuite = defs.findSuite("edit");
+    BOOST_REQUIRE_MESSAGE(editSuite, "Could not find the edit suite");
+
+    const Variable& int1 = editSuite->findVariable("INT1");
+    BOOST_REQUIRE_MESSAGE(!int1.empty(), "Could not find variable INT1");
+    BOOST_REQUIRE_MESSAGE(int1.value() == 10, "Expected INT1 to have a value of 10, but found " << int1.value());
+
+    const Variable& int2 = editSuite->findVariable("INT2");
+    BOOST_REQUIRE_MESSAGE(!int2.empty(), "Could not find variable INT2");
+    BOOST_REQUIRE_MESSAGE(int2.value() == 11, "Expected INT2 to have a value of 11, but found " << int2.value());
+
+    const Variable& ymd = editSuite->findVariable("YMD");
+    BOOST_REQUIRE_MESSAGE(!ymd.empty(), "Could not find variable YMD");
+    BOOST_REQUIRE_MESSAGE(ymd.value() == 20091012,
+                          "Expected YMD to have a value of 20091012, but found " << ymd.value());
+
+    const Variable& user = editSuite->findVariable("USER");
+    BOOST_REQUIRE_MESSAGE(!user.empty(), "Could not find variable USER");
+    BOOST_REQUIRE_MESSAGE(user.value() == 0, "Expected user to have a value of 0, but found " << user.value());
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/autoarchive/autoarchive.def 5.13.0-1/libs/node/test/parser/data/bad_defs/autoarchive/autoarchive.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/autoarchive/autoarchive.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/autoarchive/autoarchive.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite s
+ family f1
+    autoarchive +01:00 # archive one hour after complete
+    autocancel +01:00  # cancel one hour after complete
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/autocancel/autocancel.def 5.13.0-1/libs/node/test/parser/data/bad_defs/autocancel/autocancel.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/autocancel/autocancel.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/autocancel/autocancel.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite s
+ family f1
+    autocancel +01:00  # cancel one hour after complete
+    autoarchive +01:00 # archive one hour after complete
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/autorestore.def 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/autorestore.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/autorestore.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/autorestore.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite s
+ family f1
+    autorestore ./f2  # autorestore
+    autorestore ./f2  # can only have one
+ endfamily
+ family f2
+    task t1
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/bad_ref.def 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/bad_ref.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/bad_ref.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/bad_ref.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite s
+ family f1
+    autorestore /s/f4   # reference to non existing node
+ endfamily
+ family f2
+    task t1
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref.def 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite s
+ family f1
+    autorestore /s/f2 /s/f2   # multiple reference to same node
+ endfamily
+ family f2
+    task t1
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/multiple_ref2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite s
+ family f1
+    autorestore ./f2 /s/f2   # multiple reference to same node
+ endfamily
+ family f2
+    task t1
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/ref_to_task.def 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/ref_to_task.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/autorestore/ref_to_task.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/autorestore/ref_to_task.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite s
+ family f1
+    autorestore /s/f2/t1   # restore can only restore suite/family and not task
+ endfamily
+ family f2
+    task t1
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite s1
+ clock real 0.1.2006 # clock date should not have wild carding
+endsuite
+
+suite s2
+ clock real 1.0.2006 # clock date should not have wild carding
+endsuite
+
+suite s3
+ clock real 1.12.0  # clock date should not have wild carding
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite s1
+ clock real 99.1.2006   # day out of range
+endsuite
+suite s2
+ clock real 1.15.2006   # month out of range
+endsuite
+suite s3
+ clock real 1.15.0000   # 0 year out of range
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite suiteName
+  clock real 20.1.2006
+  endclock  19.1.2006    # endclock should be greater than clock start
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite s1
+ clock real 400  #  
+ endclock  300  #  # endclock should be greater than clock start
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock5.def 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock5.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite s1
+ clock real 400  #  
+ endclock  real 300  #   should not have real, clock end same type as clock start, or default to real
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock6.def 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock6.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock6.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock6.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite suiteName
+  endclock   19.1.2006  # endclock should be greater than clock start
+  clock real 19.1.2017
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock7.def 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock7.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/clock/clock7.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/clock/clock7.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite s1
+ endclock  300  # endclock should be greater than clock start
+ clock real 400  #  
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+	cron 36:00                              #  error should between hour 0-23
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+	cron 00:60                              #  error should   min 0-59
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+ 	cron -w 0,1,3,4,5,6,7,8 10:00           # Error should be range [0-6] where 0=sunday,1=monday,etc
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+	cron -d 10,11,12,35,36 12:00            # errors days of month should have range 1-31
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron5.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron5.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+	cron -m 1,2,3,13,14 12:00   #  Error month should have range 1-12
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron5_1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron5_1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron5_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron5_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+    cron -m 0,1,2,3 12:00   #  Error month should have range 1-12
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron6.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron6.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron6.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron6.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+	cron -w -1,0,6 10:00                     #  weekdays should have range [0-6]
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron7.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron7.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron7.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron7.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+	cron -w 0 -m 5,6,7,8 10:00 20:00 25:00  # error in increment
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron8.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron8.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/cron8.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/cron8.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite cron
+    cron 10:00 27:00 01:00  #  max end time is 23:59
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/repeat_with_cron.def 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/repeat_with_cron.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/cron/repeat_with_cron.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/cron/repeat_with_cron.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite suiteName
+    family f
+        cron 23:00                          # cant have repeat  & cron at same level
+        repeat date YMD 20090331 20121212 1 # status 0
+        task t
+        task t2
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date.def 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite suiteName
+   task a
+      date 100.*.2009   # day should be in range 1-31
+   endtask
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date0.def 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date0.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date0.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date0.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite a
+   date 10.10.2009   # date should not be allowed on a suite, see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node 
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   task a
+      date 1.14.2009         # month should be in range 1-12
+   endtask
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite suiteName
+   task a
+      date 0.14.2009       # day is invalid, month is invalid
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite suiteName
+   task a
+      date 1.0.2009
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite suiteName
+   task b
+      date 1.1.200
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date5.def 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date5.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/date/date5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/date/date5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite suiteName
+   task b
+      date 2.29.2002
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/day/day.def 5.13.0-1/libs/node/test/parser/data/bad_defs/day/day.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/day/day.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/day/day.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite a
+  day wednesday  # do not allow day at suite level, see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node 
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/defstatus/defstatus.def 5.13.0-1/libs/node/test/parser/data/bad_defs/defstatus/defstatus.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/defstatus/defstatus.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/defstatus/defstatus.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite suiteName
+   defstatus suspended
+   family familyName0
+      defstatus complete
+      task taskName0
+      	 defstatus complete  
+      	 defstatus complete  
+  		 edit VAR2 value2
+   endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suiteName
+   family familyName0
+      task taskName0
+         event name_1
+         event name_1
+     endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suiteName
+   family familyName0
+      task taskName0
+         event 0 
+         event 0
+     endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suiteName
+   family familyName0
+      task taskName0
+           event 1 eventName
+           event 1 eventName
+      endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suiteName
+   family familyName0
+      task taskName0
+           event 1  
+           event "1"
+      endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_state.def 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_state.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_state.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_state.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite s
+   family f
+      task t
+         event name_1 set
+         event name_1
+     endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_state2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_state2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/event/event_state2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/event/event_state2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite s
+   family f
+      task t
+         event 0 name_1 set
+         event 0 name_1
+     endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/event/simple_event.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/event/simple_event.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/event/simple_event.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/event/simple_event.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   family familyName0
+      task taskName0
+         event //
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/bad.def 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/bad.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/bad.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/bad.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+extern                    #extern without anything
+extern                    # extern without anything
+extern /limits:c1a
+extern /limits:linux_cluster;
+extern /limits:pdb
+ 
+suite suiteName
+    limit sg1  10
+    limit mars 10
+endsuite
+
+ 
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/complete.def 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/complete.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/complete.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/complete.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+#
+# complete references to node path, not in externs is an error
+#
+suite suiteName
+   family familyName
+      task q
+            complete /a/b/c/d/e:event == set       # extern event path
+      task r
+            complete /a/b/c/d/e:meter le 30        # extern meter path   
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/trigger1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/trigger1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/trigger1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/trigger1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+#
+# Trigger references to node path, not in externs is an error
+#
+suite suiteName
+   family familyName
+      task q
+            trigger /a/b/c/d/e:event == set       # extern event path
+      task r
+            trigger /a/b/c/d/e:meter le 30        # extern meter path   
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/trigger2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/trigger2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/extern/trigger2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/extern/trigger2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+#
+# Trigger references to node path, not in externs is an error
+#
+suite bad_extern
+   family f1
+      task p
+            trigger /a/b/c/d == complete          # extern path
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/family/family.def 5.13.0-1/libs/node/test/parser/data/bad_defs/family/family.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/family/family.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/family/family.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   family familyName0
+   endfamily
+   family familyName0             # duplicate family names
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/family/family_1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/family/family_1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/family/family_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/family/family_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+    suite suiteName
+       family familyName0
+          task taskName0
+          family heir_familyName0
+          endfamily
+          family heir_familyName0     # duplicate hierarchical familys
+          endfamily
+      endfamily
+      family familyName1
+      endfamily
+      family familyName2
+      endfamily
+   endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/family/missing_ends.def 5.13.0-1/libs/node/test/parser/data/bad_defs/family/missing_ends.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/family/missing_ends.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/family/missing_ends.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   family familyName0    # missing endfamily and endsuite, should parse ok if its last family and suite
+
+suite suiteName
+   family familyName0    
+   endfamily
+endsuite 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/family/simple_family.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/family/simple_family.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/family/simple_family.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/family/simple_family.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite suiteName
+   family  
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/generic/generic.def 5.13.0-1/libs/node/test/parser/data/bad_defs/generic/generic.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/generic/generic.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/generic/generic.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite a
+	generic a b c
+	generic a
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit.def 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,26 @@
+
+extern /limits:c1a
+extern /limits:linux_cluster
+extern /limits:pdb
+extern /limits:q2diss
+
+suite suiteName
+	limit sg1  10
+	limit mars 10
+endsuite
+
+suite obs
+    inlimit /limits:c1a
+    family limits
+    	limit hpcd 20
+    endfamily
+    
+    family anon    
+            inlimit /suiteName:sg1        #  
+    	task t1
+            inlimit /suiteName:sg1        #  
+            inlimit /suiteName:sg1        # duplicate inlimit
+   		task t2
+   		task t3
+     endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+extern /limits:c1a
+extern /limits:linux_cluster
+extern /limits:pdb
+extern /limits:q2diss
+
+suite obs
+    limit sg1
+    inlimit /limits:c1a
+    family limits
+    	limit hpcd 20
+    endfamily
+    
+    family anon    
+        inlimit -n -s sg1 # cant have -n(limit node only) and -s(limit submission) together       
+    	task t1
+   		task t2
+   		task t3
+     endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check.def 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite s
+ family anon    
+   task t1
+    inlimit disk   # no path, find limit name up the tree, not found, should be warning
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite s
+ family anon    
+   task t1
+     inlimit /s:disk        # absolute path to node defining the limit, limit missing
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite s
+ family anon    
+   task t3
+     #limit rel_limit 1
+   task t4
+     inlimit t3:rel_limit   # relative limit (sibling) missing
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limit_check4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite s
+ family anon    
+   task t6
+     inlimit ../anon:anon   # relative limit (parent)
+   task t7
+     inlimit ../../s:disk   # relative limit (parents/parent)
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limt2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limt2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/inlimit/limt2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/inlimit/limt2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,22 @@
+
+extern /limits:c1a
+extern /limits:linux_cluster
+extern /limits:pdb
+extern /limits:q2diss
+
+suite obs
+    limit sg1
+    inlimit /limits:c1a
+    family limits
+    	limit hpcd 20
+    endfamily
+    
+    family anon    
+            inlimit  sg1       
+    	task t1
+            inlimit  sg1        #  
+            inlimit  sg1        # duplicate inlimit
+   		task t2
+   		task t3
+     endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late.def 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   family familyName
+      task t1
+      	  late -s +00:15 -s 20:00 -c +02:00  # how to cope with duplivates ????????????
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   family familyName
+      task t1
+      		late -c +00:15 -s 20:00 -c +02:00  # how to cope with duplivates ????????????
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   family familyName
+      task t1
+      	  late  # oops no -s -a -c specified
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/late/late4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/late/late4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suiteName
+   family familyName
+      task t1
+      	  late -s +00:15 -c +02:00  #  Con only have one late per node
+      	  late -a 00:15 -c +02:00   #  Con only have one late per node
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/meter/meter.def 5.13.0-1/libs/node/test/parser/data/bad_defs/meter/meter.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/meter/meter.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/meter/meter.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName
+      task taskName
+          meter myMeter  200 100 100  #  min val(200)  > max value(100)
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/meter/meter2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/meter/meter2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/meter/meter2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/meter/meter2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName
+      task taskName
+          meter myMeter  0 100 200  #  color change must be between min(0) and max(100)
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/meter/meter3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/meter/meter3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/meter/meter3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/meter/meter3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   family familyName
+      task taskName
+          meter myMeter  0 100 100  
+          meter myMeter  0 100 100  #  duplicate meters are not allowed
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/queue/bad_name.def 5.13.0-1/libs/node/test/parser/data/bad_defs/queue/bad_name.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/queue/bad_name.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/queue/bad_name.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+  queue .name 001 002 003 # status 0
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/queue/duplicate_name.def 5.13.0-1/libs/node/test/parser/data/bad_defs/queue/duplicate_name.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/queue/duplicate_name.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/queue/duplicate_name.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite s1
+  queue name 001 002 003 # status 0
+  queue name 001 002 003 # status 0
+endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/queue/empty_queue.def 5.13.0-1/libs/node/test/parser/data/bad_defs/queue/empty_queue.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/queue/empty_queue.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/queue/empty_queue.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite s1
+  queue name  # status 0
+endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/date_missing_name.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/date_missing_name.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/date_missing_name.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/date_missing_name.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+ repeat date 20090331 20121212 1  
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/duplicate_repeats_per_node.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite s1
+ repeat date YMD 20090331 20121212 1 # status 0
+ repeat date YMD1 20090331 20121212 1 # status 0
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+ repeat date YMD 20091901 20091501   # should have format yyyymmdd  19 and 15 ar not valid months
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates_2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates_2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates_2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/invalid_dates_2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+ repeat date YMD 20091099 20091501  # should have format yyyymmdd  invalid day of month
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+ repeat date YMD 20091001 20090901 1  #  start date is > end date, when delta > 0
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+repeat date YMD 20090901 20091001 -1 # start date is < end date, when delta < 0
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+repeat date YMD 20090901 20091010  0  # 0 is an invalid delta
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list.ecf 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list.ecf
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+ repeat datelist YMD 20091901 20091501   # should have format yyyymmdd  19 and 15 ar not valid months
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_date_list1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s1
+ repeat datelist YMD  # empty list
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_integer.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_integer.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_integer.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_integer.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite s
+ repeat integer VARIABLE 0 10 2 # comment
+ repeat integer VARIABLE 0 10 # duplicate variable name
+ repeat integer VARIABLE 0 10 # duplicate variable name
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_month.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_month.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_month.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_month.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite s
+ repeat month 2   #111
+endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_with_cron.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_with_cron.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_with_cron.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_with_cron.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite s
+ repeat date YMD 20090331 20121212 1 # status 0
+ cron 10:00 23:00 00:10              # cant have repeat  & cron time series at same level
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_year.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_year.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/repeat_year.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/repeat_year.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s
+ repeat year 3 20090331 20121212 1 # status 0
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/string_missing_name.def 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/string_missing_name.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/repeat/string_missing_name.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/repeat/string_missing_name.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite s
+    repeat string  
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/clock.def 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/clock.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/clock.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/clock.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+    # only suites are allowed to have clocks
+    suite suiteName
+       family familyName0
+		 	clock real 20.1.2006
+      endfamily
+   endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/clock1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/clock1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/clock1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/clock1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+    # only suites are allowed to have clocks
+    suite suiteName
+       family familyName0
+       		task t1
+		 		clock real 20.1.2006
+      endfamily
+   endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/family_and_task_same_name.def 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/family_and_task_same_name.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/family_and_task_same_name.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/family_and_task_same_name.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite  s1
+   task t1
+   family t1
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/simple_suite.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/simple_suite.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/suite/simple_suite.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/suite/simple_suite.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+suite  
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/task/simple_task.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/task/simple_task.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/task/simple_task.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/task/simple_task.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName0
+      task  
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/task/task.def 5.13.0-1/libs/node/test/parser/data/bad_defs/task/task.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/task/task.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/task/task.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suiteName
+   family familyName0
+      task fred             # duplicate task names
+      task fred
+      endtask
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/task/task_1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/task/task_1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/task/task_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/task/task_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+   suite suiteName
+       family familyName0
+          family heir_familyName0      
+          		task fred                      # duplicate tasks within hier family
+          		task fred
+          endfamily
+      endfamily
+      family familyName1
+      endfamily
+      family familyName2
+      endfamily
+   endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite suiteName
+   family familyName0
+   		time 15:00 20:00   # ERROR should  time <start> <finish> <increment>
+   		time 19:00
+   		time +15:00
+   		time 10:00 20:00 01:00
+   		time +10:00 20:00 01:00
+		task t
+   			time 15:00
+   			time 19:00
+   			time +15:00
+   			time 10:00 20:00 01:00
+   			time +10:00 20:00 01:00		   		
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite a
+   time 19:00  # suites don't have a time, See see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite suiteName
+   family familyName0
+    	time 19:00
+   		time -15:00                  # minus not allowed
+   		time 10:00 20:00 01:00
+   		time +10:00 20:00 01:00
+		task t
+   			time 15:00
+   			time 19:00
+   			time +15:00
+   			time 10:00 20:00 01:00
+   			time +10:00 20:00 01:00		   		
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite suiteName
+   family familyName0
+   		time 15:000   # ERROR minutes should be limited to 2 digits
+   		time 19:00
+   		time +15:00
+   		time 10:00 20:00 01:00
+   		time +10:00 20:00 01:00
+		task t
+   			time 15:00
+   			time 19:00
+   			time +15:00
+   			time 10:00 20:00 01:00
+   			time +10:00 20:00 01:00		   		
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName0
+   		time 99:00        # bad hour range should be 00-23
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_5.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_5.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite suiteName
+   family familyName0
+   		time 23:76        # bad minutes range should be 00-59
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_6.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_6.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_6.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_6.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName0
+   		time  20:00 10:00 01:00          # invalid range start time > end time
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_7.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_7.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_7.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_7.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite suiteName
+   family familyName0
+   		time 15:00 20:00 00:00  # ERROR  increment cant be NULL
+   		time 19:00
+   		time +15:00
+   		time 10:00 20:00 01:00
+   		time +10:00 20:00 01:00
+		task t
+   			time 15:00
+   			time 19:00
+   			time +15:00
+   			time 10:00 20:00 01:00
+   			time +10:00 20:00 01:00		   		
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_8.def 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_8.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/time/time_8.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/time/time_8.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName0
+        time 00:00 01:00 10:00  # ERROR  increment duration is greater than duration between start/finish
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/today/today.def 5.13.0-1/libs/node/test/parser/data/bad_defs/today/today.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/today/today.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/today/today.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName0
+   		today 15:00
+   		today 23:59 00:00  00:30     # start should be less than finish
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/today/today1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/today/today1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/today/today1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/today/today1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite a
+   today 19:00  # suites dont have a today, See  see SUP-1198, ECFLOW-106 Times/Dates attributes attached to suite node
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_relative.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_relative.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_relative.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_relative.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+# test node referencing in triggers
+#      o/ <node> == complete    i.e   a == complete   sibling    
+#      o/ ./<node> == complete  i.e  ./a == complete  sibling
+#      o/ ../<node> == complete i.e  ../a == complete means trigger nodes parent
+suite s1
+  family f1
+     family f2
+        family f3
+           family f4
+              task a
+                 trigger ../f4 == complete or ../f3 == complete  # cant have ../f4 and ../f3 at same level, should be ../../f3
+            endfamily   
+         endfamily
+      endfamily
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger2.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger2.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger2.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger2.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+    family familyName1
+		task a
+    	task b
+   			trigger z == complete   # reference to non existing sibling
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger3.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger3.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger3.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger3.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+    family familyName1
+		task a
+    	task b
+   			trigger /suiteName/ == complete   # incomplete absolute path
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger4.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger4.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger4.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger4.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+suite suite
+    family family
+    	task t1
+    	task t2
+    	task t3
+    	task t4
+    	task t5
+    	task t6
+    	task t7
+    	task t8
+    	task t9
+    	task t10
+		task a             
+         	event eventName 
+    	task b             
+   			trigger -a t2  == complete     # option -a and -o should be last
+   			trigger -o t3  == complete     # option -a and -o should be last
+   			trigger t1  == complete        # trigger with out options should be first
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger5.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger5.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger5.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/bad_trigger5.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+# here we have a trigger expression that references a meter and a node.
+# We should only except a string which is 'set' or 'clear'
+# i.e
+#    trigger /suite/family/m:var gt  0 or /suite/family/m:var eq set
+# here var could be an event
+
+suite suite
+    family family
+      task a             
+         trigger /suite/family/m:meter gt  0 or /suite/family/m:meter eq complete
+      task m
+         meter meter  0 100 100  # meter <name> <min> <max> [optional color change]
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/complex.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/complex.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/complex.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/complex.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite main
+  family dc00
+     task obs
+     task ref
+     family an
+         task forceinv
+     endfamily
+     family fc
+         # this should fail to find the referenced node, since .. means parents  i.e dc00
+         # since there is no family 'an' under main this should fail.
+         trigger ../an/forceinv == complete # this should really be ./an/forceinv == complete
+     endfamily    
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/divide_by_zero.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/divide_by_zero.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/divide_by_zero.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/divide_by_zero.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite suiteName
+    family f1
+      task a
+      event event
+      task b
+            trigger ((/suiteName/f1/a:event / 0) == 0)   # divide by zero
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/ecflow_969.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/ecflow_969.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/ecflow_969.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/ecflow_969.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite suite
+    task pertinic
+        event 1
+    task eda_pert
+    task rot
+    family pert_ic
+             complete pertinic:1
+             trigger eda_pert
+             trigger -a rot==complete
+             trigger -a pertinic==complete and not pertinic:1
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/extern_trigger.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/extern_trigger.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/extern_trigger.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/extern_trigger.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+extern /a/b/c/d         
+extern /a/b/c/d/e:event        
+extern /a/b/c/d/e:meter        
+
+suite suiteName
+  family familyName
+  		task a
+   			trigger /a/b/c/d/e/f == complete  		   # non existing path, not even extern
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/modulo_by_zero.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/modulo_by_zero.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/modulo_by_zero.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/modulo_by_zero.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+      task a
+         meter meter 0 100 100
+      task b
+            trigger /suiteName/a:meter % 0 >= 0   # modulo by zero, should failed check
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite s1
+  family f1
+    task a
+    task b
+   	   trigger f1 == complete   # f1 is not a sibling but a parent, expect error
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/parent_trigger2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite s1
+  family f1
+    task a
+    task b
+   	   trigger ./f1 == complete   # f1 is not a sibling but a parent, expect error
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/simple_trigger_bad_expression.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite suiteName
+  family familyNamea
+   		task a
+   		task b
+       endfamily
+   family familyName
+   		task a
+   		task b
+    			trigger ..//familyNamea\b == complete                      
+     endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/suite_with_trigger.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/suite_with_trigger.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/suite_with_trigger.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/suite_with_trigger.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suite_with_trigger_should_fail
+  trigger 1 == 0
+endsuite
+suite suite_with_complete_should_fail
+  complete 1 == 0
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/trigger.txt 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/trigger.txt
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/trigger.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/trigger.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite suiteName
+   family familyName
+   		task a
+   		task b
+   			trigger a == complete                       
+   			trigger b == complete               # duplicate task trigger        
+     endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/trigger_1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/trigger_1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/trigger/trigger_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/trigger/trigger_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite suiteName
+   family familyName
+   		trigger familyName1 == complete                
+   		trigger familyName1 == complete    # duplicate family trigger
+   		task a
+   		task b
+   			trigger a == complete                       
+      endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad1.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad1.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit var
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit var # a comment
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit #comment
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit #var value
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad5.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad5.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/bad5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/bad5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit var#bad value
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/comment.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/comment.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/comment.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/comment.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit # comment
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/comment2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/comment2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/variable/comment2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/variable/comment2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite suiteName
+   edit comment # start of a comment,  this is an error since value starts with #
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verfiy3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verfiy3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verfiy3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verfiy3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite  
+	verify complete:int        # correct format is <state>:int, ie verify complete:3
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verify.def 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verify.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verify.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verify.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite  
+	verify complete        # correct format is <state>:int
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verify2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verify2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verify2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verify2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite  
+	verify complete:        # correct format is <state>:int
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verify4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verify4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/verify/verify4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/verify/verify4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite  
+	verify complete:3        # cant have 2 verify completes, must be of different states
+	verify complete:4        #  
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad.def 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite suiteName
+   zombie ecf               # should be ecf:::0
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad2.def 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad2.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   zombie ecf:fob:init:100
+   zombie path:fail:event:100
+   zombie user:adopt:meter:100
+   zombie ecf:fob:init:100       # can only have one ecf
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad3.def 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad3.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite suiteName
+    zombie fred:adopt:meter:100    # fred is not a valid zombie type
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad4.def 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad4.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite suiteName
+    zombie user:fred:event,meter:100    # fred is not a valid user action
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad5.def 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad5.def
--- 5.12.4-1/libs/node/test/parser/data/bad_defs/zombie/bad5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/bad_defs/zombie/bad5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite suiteName
+    zombie user:fob:fred:100    # fred is not a valid child cmd
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_1550.def 5.13.0-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_1550.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_1550.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_1550.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,101 @@
+suite ecflow_1550
+  defstatus suspended
+  edit SLEEP 120
+  family barrier
+    repeat enumerated YMD 1 2 3 4 5 6 7 8 #sdsdsd
+    family start
+      complete start/0 == complete and start/1 == complete and start/2 == complete and start/3 == complete and start/4 == complete and start/5 == complete and start/6 == complete
+      family 0
+        time 23:59
+        day monday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 1
+        time 23:59
+        day tuesday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 2
+        time 23:59
+        day wednesday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 3
+        time 23:59
+        day thursday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 4
+        time 23:59
+        day friday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 5
+        time 23:59
+        day saturday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 6
+        time 23:59
+        day sunday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+    endfamily
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337.def 5.13.0-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,43 @@
+suite ecflow_337
+  defstatus suspended
+  family barrier
+    repeat enumerated YMD "20150521" "20150525" "20150528" "20150601" "20150604" "20150608" "20150611" "20150615" "20150618" "20150622" "20150625" "20150629" "20150702" "20150706" "20150709" "20150713" "20150716" "20150720" "20150723" "20150727" "20150730" "20150803" "20150806" "20150810" "20150813" "20150817" "20150820" "20150824" "20150827" "20150831" "20150903" "20150907" "20150910" "20150914" "20150917" "20150921" "20150924" "20150928" "20151001" "20151005" "20151008" "20151012" "20151015" "20151019" "20151022" "20151026" "20151029" "20151102" "20151105" "20151109" "20151112" "20151116" "20151119" "20151123" "20151126" "20151130" "20151203" "20151207" "20151210" "20151214" "20151217" "20151221" "20151224" "20151228" "20151231" "20160104" "20160107" "20160111" "20160114" "20160118" "20160121" "20160125" "20160128" "20160201" "20160204" "20160208" "20160211" "20160215" "20160218" "20160222" "20160225" "20160229" "20160303" "20160307" "20160310" "20160314" "20160317" "20160321" "20160324" "20160328" "20160331" "20160404" "20160407" "20160411" "20160414" "20160418" "20160421" "20160425" "20160428" "20160502" "20160505" "20160509" "20160512" "20160516" "20160519" "20160523" "20160526" "20160530" "20160602" "20160606" "20160609" "20160613" "20160616" "20160620" "20160623" "20160627" "20160630" "20160704" "20160707" "20160711" "20160714" "20160718" "20160721" "20160725" "20160728" "20160801" "20160804" "20160808" "20160811" "20160815" "20160818" "20160822" "20160825" "20160829" "20160901" "20160905" "20160908" "20160912" "20160915" "20160919" "20160922" "20160926" "20160929" "20161003" "20161006" "20161010" "20161013" "20161017" "20161020" "20161024" "20161027" "20161031" "20161103" "20161107" "20161110" "20161114" "20161117" "20161121" "20161124" "20161128" "20161201" "20161205" "20161208" "20161212" "20161215" "20161219" "20161222" "20161226" "20161229" "20170102" "20170105" "20170109" "20170112" "20170116" "20170119" "20170123" "20170126" "20170130" "20170202" "20170206" "20170209" "20170213" "20170216" "20170220" "20170223" "20170227" "20170302" "20170306" "20170309" "20170313" "20170316" "20170320" "20170323" "20170327" "20170330" "20170403" "20170406" "20170410" "20170413" "20170417" "20170420" "20170424" "20170427" "20170501" "20170504" "20170508" "20170511" "20170515" "20170518" "20170522" "20170525" "20170529" "20170601" "20170605" "20170608" "20170612" "20170615" "20170619" "20170622" "20170626" "20170629" "20170703" "20170706" "20170710" "20170713" "20170717" "20170720" "20170724" "20170727" "20170731" "20170803" "20170807" "20170810" "20170814" "20170817" "20170821" "20170824" "20170828" "20170831" "20170904" "20170907" "20170911" "20170914" "20170918" "20170921" "20170925" "20170928" "20171002" "20171005" "20171009" "20171012" "20171016" "20171019" "20171023" "20171026" "20171030" "20171102" "20171106" "20171109" "20171113" "20171116" "20171120" "20171123" "20171127" "20171130" "20171204" "20171207" "20171211" "20171214" "20171218" "20171221" "20171225" "20171228" "20180101" "20180104" "20180108" "20180111" "20180115" "20180118" "20180122" "20180125" "20180129" "20180201" "20180205" "20180208" "20180212" "20180215" "20180219" "20180222" "20180226" "20180301" "20180305" "20180308" "20180312" "20180315" "20180319" "20180322" "20180326" "20180329" "20180402" "20180405" "20180409" "20180412" "20180416" "20180419" "20180423" "20180426" "20180430" "20180503" "20180507" "20180510" "20180514" "20180517" "20180521" "20180524" "20180528" "20180531" "20180604" "20180607" "20180611" "20180614" "20180618" "20180621" "20180625" "20180628" "20180702" "20180705" "20180709" "20180712" "20180716" "20180719" "20180723" "20180726" "20180730" "20180802" "20180806" "20180809" "20180813" "20180816" "20180820" "20180823" "20180827" "20180830" "20180903" "20180906" "20180910" "20180913" "20180917" "20180920" "20180924" "20180927" "20181001" "20181004" "20181008" "20181011" "20181015" "20181018" "20181022" "20181025" "20181029" "20181101" "20181105" "20181108" "20181112" "20181115" "20181119" "20181122" "20181126" "20181129" "20181203" "20181206" "20181210" "20181213" "20181217" "20181220" "20181224" "20181227" "20181231" "20190103" "20190107" "20190110" "20190114" "20190117" "20190121" "20190124" "20190128" "20190131" "20190204" "20190207" "20190211" "20190214" "20190218" "20190221" "20190225" "20190228" "20190304" "20190307" "20190311" "20190314" "20190318" "20190321" "20190325" "20190328" "20190401" "20190404" "20190408" "20190411" "20190415" "20190418" "20190422" "20190425" "20190429" "20190502" "20190506" "20190509" "20190513" "20190516" "20190520" "20190523" "20190527" "20190530" "20190603" "20190606" "20190610" "20190613" "20190617" "20190620" "20190624" "20190627" "20190701" "20190704" "20190708" "20190711" "20190715" "20190718" "20190722" "20190725" "20190729" "20190801" "20190805" "20190808" "20190812" "20190815" "20190819" "20190822" "20190826" "20190829" "20190902" "20190905" "20190909" "20190912" "20190916" "20190919" "20190923" "20190926" "20190930" "20191003" "20191007" "20191010" "20191014" "20191017" "20191021" "20191024" "20191028" "20191031" "20191104" "20191107" "20191111" "20191114" "20191118" "20191121" "20191125" "20191128" "20191202" "20191205" "20191209" "20191212" "20191216" "20191219" "20191223" "20191226" "20191230" "20200102" "20200106" "20200109" "20200113" "20200116" "20200120" "20200123" "20200127" "20200130" "20200203" "20200206" "20200210" "20200213" "20200217" "20200220" "20200224" "20200227" "20200302" "20200305" "20200309" "20200312" "20200316" "20200319" "20200323" "20200326" "20200330" "20200402" "20200406" "20200409" "20200413" "20200416" "20200420" "20200423" "20200427" "20200430" "20200504" "20200507" "20200511" "20200514" "20200518" "20200521" "20200525" "20200528" "20200601" "20200604" "20200608" "20200611" "20200615" "20200618" "20200622" "20200625" "20200629" "20200702" "20200706" "20200709" "20200713" "20200716" "20200720" "20200723" "20200727" "20200730" "20200803" "20200806" "20200810" "20200813" "20200817" "20200820" "20200824" "20200827" "20200831" "20200903" "20200907" "20200910" "20200914" "20200917" "20200921" "20200924" "20200928" "20201001" "20201005" "20201008" "20201012" "20201015" "20201019" "20201022" "20201026" "20201029" "20201102" "20201105" "20201109" "20201112" "20201116" "20201119" "20201123" "20201126" "20201130" "20201203" "20201207" "20201210" "20201214" "20201217" "20201221" "20201224" "20201228" "20201231" "20210104" "20210107" "20210111" "20210114" "20210118" "20210121" "20210125" "20210128" "20210201" "20210204" "20210208" "20210211" "20210215" "20210218" "20210222" "20210225" "20210301" "20210304" "20210308" "20210311" "20210315" "20210318" "20210322" "20210325" "20210329" "20210401" "20210405" "20210408" "20210412" "20210415" "20210419" "20210422" "20210426" "20210429" "20210503" "20210506" "20210510" "20210513" "20210517" "20210520" "20210524" "20210527" "20210531" "20210603" "20210607" "20210610" "20210614" "20210617" "20210621" "20210624" "20210628" "20210701" "20210705" "20210708" "20210712" "20210715" "20210719" "20210722" "20210726" "20210729" "20210802" "20210805" "20210809" "20210812" "20210816" "20210819" "20210823" "20210826" "20210830" "20210902" "20210906" "20210909" "20210913" "20210916" "20210920" "20210923" "20210927" "20210930" "20211004" "20211007" "20211011" "20211014" "20211018" "20211021" "20211025" "20211028" "20211101" "20211104" "20211108" "20211111" "20211115" "20211118" "20211122" "20211125" "20211129" "20211202" "20211206" "20211209" "20211213" "20211216" "20211220" "20211223" "20211227" "20211230"
+    family start
+      complete start/0 == complete or start/1 == complete
+      family 0
+        time 10:00
+        day monday
+        task dummy
+          complete 1==1
+          trigger 0==1
+      endfamily
+      family 1
+        time 10:00
+        day thursday
+        task dummy
+          complete 1==1
+          trigger 0==1
+      endfamily
+    endfamily
+    family last
+      trigger start == complete
+      family done
+        complete done/0 == complete or done/1 == complete
+        family 0
+          time 14:00
+          day monday
+          task dummy
+            complete 1==1
+            trigger 0==1
+        endfamily
+        family 1
+          time 14:00
+          day thursday
+          task dummy
+            complete 1==1
+            trigger 0==1
+        endfamily
+      endfamily
+    endfamily
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337_.def 5.13.0-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337_.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337_.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/JIRA/ecflow_337_.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+suite ecflow_337
+  defstatus suspended
+  family barrier
+    repeat enumerated YMD 1 2 3 4
+    family monday
+        time 10:00
+        day monday
+        task dummy
+          complete 1==1
+          trigger 0==1
+    endfamily
+    family tuesday
+        time 10:00
+        day tuesday
+        task dummy
+          complete 1==1
+          trigger 0==1
+    endfamily
+    family wednesday
+        time 10:00
+        day wednesday
+        task dummy
+          complete 1==1
+          trigger 0==1
+    endfamily
+    family thursday
+        time 10:00
+        day thursday
+        task dummy
+          complete 1==1
+          trigger 0==1
+    endfamily
+    family friday
+        time 10:00
+        day friday
+        task dummy
+          complete 1==1
+          trigger 0==1
+    endfamily
+    family saturday
+        time 10:00
+        day saturday
+        task dummy
+          complete 1==1
+          trigger 0==1
+    endfamily
+    family sunday
+        time 10:00
+        day sunday
+        task dummy
+          complete 1==1
+          trigger 0==1
+    endfamily
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive.def 5.13.0-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,69 @@
+suite autoarchive
+ family f1
+    autoarchive +00:02  
+    task t1
+ endfamily
+ family f2
+     autoarchive 01:00 # archive at 1 am in morning after complete
+    task t1
+ endfamily
+ family f3
+    autoarchive 1     # archive 1 days after complete
+    task t1
+ endfamily
+ family f4
+    autoarchive 0      # archive immediately after complete
+    task t1
+ endfamily
+ family f5
+    autoarchive +00:01  #  archive after 1 minute, same as archive 0
+    task t1
+ endfamily
+ family f5_1
+    defstatus aborted
+    autoarchive +00:01  
+    task t1
+ endfamily
+ family f5_2
+    autoarchive 0  
+    task t1
+      trigger 1== 0
+ endfamily
+  family f6
+    autoarchive +00:02 -i  
+    task t1
+ endfamily
+ family f7
+     autoarchive 01:00 -i  
+    task t1
+ endfamily
+ family f8
+    autoarchive 1 -i     
+    task t1
+ endfamily
+ family f9
+    autoarchive 0 -i     # archive immediately after complete,queued,abort
+    task t1
+ endfamily
+ family f10
+    autoarchive +00:01 -i #  archive after 1 minute, same as archive 0  ,queued,abort
+    task t1
+ endfamily
+ family f11
+    autoarchive +00:01 -i # archive after 1 minute, same as archive 0  ,queued,abort
+    task t1
+      trigger 1 == 0
+ endfamily
+ family f12
+    defstatus aborted
+    autoarchive 0 -i  
+    task t1
+       trigger 1 == 0
+ endfamily
+ family f13
+    defstatus aborted
+    autoarchive +00:01 -i 
+    task t1
+      trigger 1 == 0
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive2.def 5.13.0-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/autoarchive/autoarchive2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,39 @@
+suite autoarchive_with_family_limit
+ limit fam 1
+ family f1
+     inlimit -n fam 
+     autoarchive 0      # archive immediately after complete
+     task t1
+     task t2
+ endfamily
+ family f2
+     inlimit -n fam 
+     autoarchive 0      # archive immediately after complete
+     task t1
+     task t2
+ endfamily
+ family f3
+     inlimit -n fam 
+     autoarchive 0      # archive immediately after complete
+     task t1
+     task t2
+ endfamily
+ family f4
+     inlimit -n fam 
+     autoarchive 0      # archive immediately after complete
+     task t1
+     task t2
+ endfamily
+ family f5
+     inlimit -n fam 
+     autoarchive 0      # archive immediately after complete
+     task t1
+     task t2
+ endfamily
+endsuite
+
+#suite test2
+#  task t1
+#     trigger /test/f1<flag>late and /test/f2<flag>late
+#     autorestore /test/f1 /test/f2
+#endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/autocancel/autocancel.def 5.13.0-1/libs/node/test/parser/data/good_defs/autocancel/autocancel.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/autocancel/autocancel.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/autocancel/autocancel.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,18 @@
+suite autocancel
+ family f1
+    autocancel +01:00 # cancel one hour after complete
+    task t1
+ endfamily
+ family f2
+     autocancel 01:00 # cancel at 1 am in morning after complete
+    task t1
+ endfamily
+ family f3
+    autocancel 10     # cancel 10 days after complete
+    task t1
+ endfamily
+ family f4
+    autocancel 0      # cancel immediately after complete
+    task t1
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/autorestore/autorestore.def 5.13.0-1/libs/node/test/parser/data/good_defs/autorestore/autorestore.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/autorestore/autorestore.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/autorestore/autorestore.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,26 @@
+extern /s4
+extern /s4/f1
+extern /s4/f2
+
+suite autorestore
+ family f1
+    autorestore ./f2 ./f3 ./f4 # autorestore
+    task t1
+ endfamily
+ family f2
+     autorestore /autorestore/f1 /autorestore/f3 /autorestore/f4 # autorestore
+     task t1
+ endfamily
+ family f3
+    autorestore /autorestore/f1  # autorestore
+    task t1
+ endfamily
+ family f4
+    autorestore /autorestore 
+    task t1
+ endfamily
+ family f5
+    autorestore /s4 /s4/f1 /s4/f2 # this is an extern so allow
+    task t1
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/autorestore/autorestore2.def 5.13.0-1/libs/node/test/parser/data/good_defs/autorestore/autorestore2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/autorestore/autorestore2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/autorestore/autorestore2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite autorestore2
+ family f1
+    trigger ./f2<flag>archived and ./f3<flag>archived
+    task t1
+        autorestore ../f2 ../f3  # autorestore
+ endfamily
+ family f2
+    autoarchive 0
+    task t1   
+ endfamily
+ family f3
+    autoarchive 0   
+    task t1   
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/autorestore/autorestore_test.def 5.13.0-1/libs/node/test/parser/data/good_defs/autorestore/autorestore_test.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/autorestore/autorestore_test.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/autorestore/autorestore_test.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,22 @@
+suite autorestore_test
+ family farchive_now
+    autoarchive 0      # archive immediately after complete, may have to wait 60 seconds
+    task t1
+ endfamily
+ family farchive2_now
+    autoarchive 0      # archive immediately after complete, may have to wait 60 seconds
+    task t1
+ endfamily
+ family frestore_from_family_now
+    trigger ./farchive_now<flag>archived
+    autorestore ./farchive_now       
+    task t1
+       edit SLEEP 60
+ endfamily
+ family frestore_from_task_now
+    trigger ./frestore_from_family_now<flag>archived
+    task t1
+       edit SLEEP 60
+       autorestore ../farchive2_now       
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/aviso/aviso.def 5.13.0-1/libs/node/test/parser/data/good_defs/aviso/aviso.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/aviso/aviso.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/aviso/aviso.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+suite aviso
+  edit ECF_HOME '/Users/mamb/w/sandbox.aviso/.'
+  edit ECF_INCLUDE '/Users/mamb/w/sandbox.aviso/core/included'
+  edit ECF_FILES '/Users/mamb/w/sandbox.aviso/scripts'
+  edit ECF_AVISO_URL 'http://localhost:2379'
+  edit ECF_AVISO_SCHEMA '/Users/mamb/w/sandbox.aviso/client/service_configuration/event_listener_schema.json'
+  edit ECF_AVISO_POLLING '40'
+  edit ECF_AVISO_AUTH '/Users/mamb/w/sandbox.aviso/aviso.auth'
+  family f1
+    task t1
+      aviso --name A --listener '{ "event": "mars", "request": { "class": "od", "expver": "0001", "domain": "g", "stream": "enfo", "step": [0, 6, 12, 18] } }' --url %ECF_AVISO_URL% --schema %ECF_AVISO_SCHEMA% --auth %ECF_AVISO_AUTH% --polling %ECF_AVISO_POLLING%
+    task t2
+      aviso --name B --listener '{ "event": "mars", "request": { "class": "od", "expver": "0001", "domain": "g", "stream": "enfo", "step": [0, 6] } }' --url %ECF_AVISO_URL% --schema %ECF_AVISO_SCHEMA% --polling %ECF_AVISO_POLLING%
+    task t3
+      aviso --name D --listener '{ "event": "mars", "request": { "class": "od", "expver": "0001", "domain": "g", "stream": "enfo", "step": [0, 12] } }' --url %ECF_AVISO_URL% --schema %ECF_AVISO_SCHEMA% --polling %ECF_AVISO_POLLING%
+    task t4
+      aviso --name E --listener '{ "event": "dissemination", "request": { "destination": "COM" } }' --url %ECF_AVISO_URL% --schema %ECF_AVISO_SCHEMA% --polling 20
+    task t5
+      aviso --name F --listener '{ "event": "dissemination", "request": { "destination": "ABC" } }' --url %ECF_AVISO_URL% --schema %ECF_AVISO_SCHEMA% --polling 20
+    task tX
+      edit ECF_AVISO_URL 'http://wrong:2379'
+      aviso --name X --listener '{ "event": "mars", "request": { "class": "od", "expver": "0001", "domain": "g", "stream": "enfo", "step": [0, 6, 12, 18] } }' --url %ECF_AVISO_URL% --schema %ECF_AVISO_SCHEMA% --polling %ECF_AVISO_POLLING%
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock.def 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite clock
+ clock real 300
+ endclock 400
+ task t1
+endsuite
+
+suite clock_s1
+ clock real 300
+ task t1
+endsuite
+
+suite clock_s2; clock real 300; endclock 400; task t1 ; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock1.def 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock1.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite clock1
+ clock real +01:00
+ endclock   +02:00
+ task t1
+endsuite
+
+suite clock1_s1; clock real +01:00; endclock +01:00; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock2.def 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite clock2
+ clock real 01:00
+ endclock  02:00
+ task t1
+endsuite
+
+suite clock2_s1; clock real 01:00; endclock 10:00; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock3.def 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock3.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite clock3
+ clock real 20.1.2006
+ endclock  24.1.2006
+ task t1;
+endsuite
+
+suite clock3_s1;clock real 20.1.2006;endclock 20.1.2017; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock4.def 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock4.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite clock4
+ clock real 20.1.2006 +02:00
+ endclock   23.1.2006 +04:14
+ task t1
+endsuite
+ 
+suite clock4_s1; clock real 20.1.2006 +02:00; endclock 23.1.2006 +02:00; task t1; endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock5.def 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock5.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/clock/clock5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/clock/clock5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite clock5
+ clock real 01.01.2006 +02:00
+ task t1
+endsuite
+
+suite clock5_s1;clock real 01.01.2006 +02:00; task t1; endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/comment/comment.txt 5.13.0-1/libs/node/test/parser/data/good_defs/comment/comment.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/comment/comment.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/comment/comment.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,33 @@
+# # comment 
+# This is defs file that show use of comments
+# # comment 
+
+suite comment                       # comment 
+   family familyName0                # comment 
+      task taskName0                 # comment 
+         event 0                     # comment 
+         event 1 eventName           # comment 
+         meter myMeter 0 100         # comment 
+      family heir_familyName0        # comment 
+         task taskName0              # comment 
+            event 0                  # comment 
+            event 1 eventName        # comment 
+            meter myMeter 0 100      # comment 
+      endfamily                      # comment 
+   endfamily                         # comment 
+   family familyName1                # comment 
+      task taskName1                 # comment 
+         event 1                     # comment 
+         event 2 eventName           # comment 
+         meter myMeter 0 100         # comment 
+   endfamily                         # comment 
+   family familyName2                # comment 
+      task taskName2                 # comment 
+         event 2                     # comment 
+         event 3 eventName           # comment 
+         meter myMeter 0 100         # comment 
+   endfamily                         # comment 
+endsuite                             # comment 
+
+# Final comment  # comment 
+            
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/complete/complete.def 5.13.0-1/libs/node/test/parser/data/good_defs/complete/complete.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/complete/complete.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/complete/complete.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite complete
+ family f
+   task t
+   	meter step 0 5 4
+   task tt
+   	complete t:step ge 2
+   	trigger t == complete
+ endfamily
+endsuite
+
+suite complete_s1; family f; task t;meter step 0 6 3;task tt;complete t:step ge 1;trigger t == complete
+endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/complete/complex.def 5.13.0-1/libs/node/test/parser/data/good_defs/complete/complex.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/complete/complex.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/complete/complex.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+suite complete1
+    family f
+    	task t1
+    	task t2
+    	task t3
+    	task t4
+    	task t5
+    	task t6
+    	task t7
+    	task t8
+    	task t9
+    	task t10
+		task a             
+         	event eventName 
+    	task b  
+    	    trigger 1 == 0                  # impossible trigger, keeps task queued           
+   			complete t1  == complete        # a comment at end of trigger
+   			complete -a t2  == complete     # a comment at end of trigger
+   			complete -a t3  == complete     # a comment at end of trigger
+   			complete -a t4  == complete     # a comment at end of trigger
+   			complete -a t5  == complete     # a comment at end of trigger
+   			complete -o t6  == complete      # a comment at end of trigger
+   			complete -o t7  == complete      # a comment at end of trigger
+   			complete -o t8  == complete      # a comment at end of trigger
+   			complete -o t9  == complete      # a comment at end of trigger
+   			complete -o t10  == complete      # a comment at end of trigger
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/complete/why.def 5.13.0-1/libs/node/test/parser/data/good_defs/complete/why.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/complete/why.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/complete/why.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite complete_why  
+ family hold
+  defstatus queued
+  time 07:20
+  day tuesday
+  task dummy
+    trigger 1==0
+    complete 1==1 # ECFLOW-1629, why should not report on trigger since complete expression is true
+ endfamily 
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron.def 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite cron
+ task t1
+	cron 23:00                              # run every day at 23:00
+	cron 10:00 20:00 01:00                  # run every hour between 10am and 8pm
+	cron -w 0,1 10:00                       # run every sunday and monday at 10am
+	cron -d 10,11,12 12:00                  # run 10th, 11th and 12th of each month at noon
+	cron -m 1,2,3 12:00                     # run on Jan,Feb and March every day at noon.
+	cron -w 0,6 12:00
+	cron -w 0,1,2,3,4,5,6 12:00
+   cron -w 0 -m 5,6,7,8 10:00 20:00 01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
+   cron +00:00 23:59 00:01                 # relative cron
+   cron -w 0L,1L,2L,3L,4L,5L,6L -d 1,L 23:00  # run first and last day of month or last week of month
+endsuite
+
+suite cron_s1;cron 23:00 ;cron 10:00 20:00 01:00 ;cron -w 0,1 10:00 ;cron -d 10,11,12 12:00 ;cron -m 1,2,3 12:00 ; cron -w 0,6 12:00;cron -w 0,1,2,3,4,5,6 12:00;cron -w 0 -m 5,6,7,8 10:00 20:00 01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron1.def 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron1.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite cron1
+ cron -w 0 , 1, 2 -m 5, 6, 7 , 8,9,10      10:00  20:00  01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
+ task t
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron2.def 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite cron2
+ cron -w 0,1,2 -d 1,20,24 -m 5,6,7,8 10:00 20:00 01:00  #  
+ task t
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron_simple.def 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron_simple.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/cron/cron_simple.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/cron/cron_simple.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite cron_simple
+ task t1
+      cron 00:00 17:59 00:01   
+ task t2
+      cron 17:40               
+ task t3
+      cron 17:55    
+ task t4
+      cron 21:45    
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/cron/last.def 5.13.0-1/libs/node/test/parser/data/good_defs/cron/last.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/cron/last.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/cron/last.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite cron3
+ task t
+   cron -w 0L,1,2L,3L,4L,5L,6L 23:00  
+   cron -w 0L,1,2L,3L,4L,5L,6  23:00  
+   cron -w 0L,1,2L,3L,4L,5L,6L -d 25,L 23:00  
+   cron -w 1,3 -d 28,L 23:00  
+   cron -w 1,3 -d 28,L -m 1 23:00  
+   cron -d 1,L 23:00 
+   cron -d 1,L -m 2,3 23:00 
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/date/date.def 5.13.0-1/libs/node/test/parser/data/good_defs/date/date.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/date/date.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/date/date.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,25 @@
+suite date
+   task a
+      date *.*.2009
+   endtask
+   family familyName0
+   	  date 1.*.2009
+      task taskName0
+   	  		date 1.12.2009
+      task fred
+   	  		date 01.*.*
+      endtask
+   endfamily
+endsuite
+
+suite date_s1;
+   family familyName0
+   	  date 1.*.2009
+      task taskName0
+   	  		date 1.12.2009
+      task fred
+   	  		date 01.*.*
+      endtask
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/day/day.def 5.13.0-1/libs/node/test/parser/data/good_defs/day/day.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/day/day.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/day/day.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+suite day
+   family f
+      task t1
+   	  		day wednesday
+      task f2
+            day monday
+            day tuesday
+            day wednesday
+            day thursday
+   	  		day friday
+   	  		day saturday
+   	  		day sunday
+       endtask
+   endfamily
+   family f2
+      repeat datelist YMD 20090331 20121212 20121212 20121213 20121214 20121215 
+      task t
+         day tuesday
+         time 13:00
+   endfamily
+   family f3
+      repeat date YMD 20090331 20121212 1  
+      task t
+         day wednesday
+         time 13:00
+         time 14:00
+   endfamily
+   family f4
+      repeat enumerated quotes "first" "second" "third" 
+      task t
+         day tuesday
+         time 00:00 23:59 00:30
+   endfamily
+   family f5
+      repeat integer VARIABLE_XX 0 10 2  
+      task t
+         day tuesday
+         today 09:00
+   endfamily
+   family f6
+      repeat string VARIABLE str1 str2 str3 str4 str5 str6 str7
+      task t
+         day tuesday
+         today 09:00
+   endfamily
+endsuite
+
+suite day_s1; family f ; day tuesday
+      task t1
+   	  		day wednesday
+      task t2
+   	  		day thursday
+   	  		day friday
+   	  		day saturday
+   	  		day sunday
+      endtask
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/defstatus/defstatus.txt 5.13.0-1/libs/node/test/parser/data/good_defs/defstatus/defstatus.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/defstatus/defstatus.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/defstatus/defstatus.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+suite defstatus
+   defstatus suspended
+   family f
+      defstatus complete
+      task t
+  		  edit VAR2 value2
+        defstatus complete  # TODO defstatus ordering, if edit,event,meter first it wont parse
+   endfamily
+endsuite
+
+suite defstatus_s1;
+   defstatus suspended
+   family f
+      defstatus complete
+      task t
+  		  edit VAR2 value2
+        defstatus complete  # TODO defstatus ordering, if edit,event,meter first it wont parse
+   endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/edit/edit.def 5.13.0-1/libs/node/test/parser/data/good_defs/edit/edit.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/edit/edit.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/edit/edit.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+ suite edit
+	edit ECF_INCLUDE /home/ma/map/sms/example/x                  # comment line
+	edit ECF_FILES   /home/ma/map/sms/example/x                  #comment line
+    edit EXPVER 'f8na'                                          #
+    edit USER 'ecgems'                                          #comment
+    edit USER2 "ecgems"                                         # comment
+    edit INT1 "10"                                             # comment
+    edit INT2 '11'                                             # comment
+    edit YMD  '20091012'                                        # comment
+ 	family f
+		edit ECF_FETCH  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%"  # comment line
+		edit ECF_FETCH2 'smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%'  #comment line
+		task t2
+	endfamily
+endsuite
+	
+suite edi1; edit ECF_INCLUDE /home/ma/map/sms/example/x ; edit INT2 '11'                                             # comment
+    edit YMD  '20091012'                                        # comment
+ 	family f
+		edit ECF_FETCH  "smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%" ; edit ECF_FETCH2 'smsfetch -F %ECF_FILES% -I %ECF_INCLUDE%'  #comment line
+		task t2 ; endfamily
+endsuite
+	
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/event/event_1.def 5.13.0-1/libs/node/test/parser/data/good_defs/event/event_1.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/event/event_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/event/event_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite event_1
+   family f
+      task t
+         event 0 
+         event name
+         event 1 eventName
+         event 2 eventNamea
+     endfamily
+endsuite
+
+suite event_1s1;family f ; task t ; event 0  ;event name ;event 1 eventName
+   event 2 eventNamea ; endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/event/event_2.def 5.13.0-1/libs/node/test/parser/data/good_defs/event/event_2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/event/event_2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/event/event_2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite event_2
+   family f
+      task t
+         event 0 
+         event 1
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/event/event_set.def 5.13.0-1/libs/node/test/parser/data/good_defs/event/event_set.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/event/event_set.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/event/event_set.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite event_set
+   family f1
+      task t
+         event 0 set
+         event name set
+         event 1 eventName set
+         event 2 eventNamea set
+     endfamily
+endsuite
+
+suite event_set_s2;family f ; task t ; event 0 set ;event name set;event 1 eventName set
+         event 2 eventNamea set; endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/event/family_event.def 5.13.0-1/libs/node/test/parser/data/good_defs/event/family_event.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/event/family_event.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/event/family_event.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite event_family_1
+   family f
+      # Events added to suite/family cannot be signaled by child commands
+      # However alter/force should allow events to set/cleared on Family/suite
+      event 0 
+      event name
+      event 1 eventName
+      event 2 eventNamea
+      task t
+   endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/event/spaces.def 5.13.0-1/libs/node/test/parser/data/good_defs/event/spaces.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/event/spaces.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/event/spaces.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite event_spaces
+   family f
+      task t
+      
+         event 0 
+         
+         event name
+         
+         event 1 eventName
+         
+         event 2 eventNamea
+         
+     endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/event/suite_event.def 5.13.0-1/libs/node/test/parser/data/good_defs/event/suite_event.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/event/suite_event.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/event/suite_event.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite event_suite
+   # Events added to suite/family cannot be signaled by child commands
+   # However alter/force should allow events to set/cleared on Family/suite
+   event 0 
+   event name
+   event 1 eventName
+   event 2 eventNamea
+   task t
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/extern/extern.def 5.13.0-1/libs/node/test/parser/data/good_defs/extern/extern.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/extern/extern.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/extern/extern.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,52 @@
+extern /o/main/12/an;extern /limits:c1a
+extern /limits:linux_cluster;extern /limits:pdb
+extern /limits:q2diss;extern /o/main:YMD
+extern /o/main/12/an/slwet
+extern /o/main/12/an/4dvar/ifstraj:finalwave
+extern /o/main/12/an/4dvar
+extern /o/main/12/an
+extern /o/main/12/fc/model
+extern /o/main/12/fc/model
+extern /o/main/12/an/4dvar/uptraj_0
+extern /o/main/12/an/4dvar/uptraj_0
+extern /o/main/12/fc/model
+extern /o/main/00dc/fc/model:step
+extern /o/main/00dc/fc/model
+extern /o/main/12/obs/get/get_stor
+extern /limits:prod
+extern /o/main/12/prod/240/prod_wparam
+extern /o/main:YMD
+extern /o/main/00/an
+extern /o/main/00/an/slwet
+extern /o/main/00/an/4dvar/ifstraj:finalwave
+extern /o/main/00/an/4dvar
+extern /o/main/00/an
+extern /o/main/00/fc/model
+extern /o/main/00/fc/model
+extern /o/main/00/an/4dvar/uptraj_0
+extern /o/main/00/an/4dvar/uptraj_0
+extern /o/main/00/fc/model
+extern /o/main/12dc/fc/model:step
+extern /o/main/12dc/fc/model
+extern /o/main/00/obs/get/get_stor
+extern /o/main/00/prod/240/prod_wparam
+extern /limits:mars
+extern /mofc/00/efi/swarm/sync_climate
+
+suite extern
+	limit sg1  10
+	limit mars 10
+endsuite
+
+suite extern_obs
+    family limits
+    	limit hpcd 20
+    endfamily
+    
+    family anon
+    	task t1
+    		inlimit /extern:sg1
+   		task t2
+   			inlimit /extern_obs/limits:hpcd         
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/extern/first.def 5.13.0-1/libs/node/test/parser/data/good_defs/extern/first.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/extern/first.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/extern/first.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+#
+# This defines extern which are defined in second.def
+#
+extern /a/b/c/d         
+extern /a/b/c/d/e:event        
+extern /a/b/c/d/e:meter       
+
+extern /a/b/c/d/e/f/g/h/j     # this does not exist in second.def
+
+suite extern_first
+   family familyName
+   	task p
+   			trigger /a/b/c/d == complete  		  # extern path
+  		task q
+   			trigger /a/b/c/d/e:event == set  	  # extern event path
+ 		task r
+   			trigger /a/b/c/d/e:meter le 30		  # extern meter path	
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/extern/plain.def 5.13.0-1/libs/node/test/parser/data/good_defs/extern/plain.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/extern/plain.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/extern/plain.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+extern fred                             # allow non absolute paths
+extern /mofc/00/efi/swarm/sync_climate
+
+suite extern_plain
+    limit sg1  10
+    limit mars 10
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/extern/second.def 5.13.0-1/libs/node/test/parser/data/good_defs/extern/second.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/extern/second.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/extern/second.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+#
+# The defs is used conjunction with first.def to test resolution of externs
+#
+suite event_second
+   family b
+   		family c
+   			family d
+   				task e
+   					event event
+           	    	meter meter  0 100 100  # meter <name> <min> <max> [optional color change]
+           	endfamily
+    	endfamily
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/extern/simple_extern.def 5.13.0-1/libs/node/test/parser/data/good_defs/extern/simple_extern.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/extern/simple_extern.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/extern/simple_extern.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+extern /o/main/12/an
+extern /limits:c1a
+extern /limits:linux_cluster
+extern /limits:pdb
+extern /limits:q2diss
+extern /o/main:YMD
+extern /o/main/12/an/slwet
+extern /o/main/12/an/4dvar/ifstraj:finalwave
+extern /o/main/12/an/4dvar
+extern /o/main/12/an
+extern /o/main/12/fc/model
+extern /o/main/12/fc/model
+extern /o/main/12/an/4dvar/uptraj_0
+extern /o/main/12/an/4dvar/uptraj_0
+extern /o/main/12/fc/model
+extern /o/main/00dc/fc/model:step
+extern /o/main/00dc/fc/model
+extern /o/main/12/obs/get/get_stor
+extern /limits:prod
+extern /o/main/12/prod/240/prod_wparam
+extern /o/main:YMD
+extern /o/main/00/an
+extern /o/main/00/an/slwet
+extern /o/main/00/an/4dvar/ifstraj:finalwave
+extern /o/main/00/an/4dvar
+extern /o/main/00/an
+extern /o/main/00/fc/model
+extern /o/main/00/fc/model
+extern /o/main/00/an/4dvar/uptraj_0
+extern /o/main/00/an/4dvar/uptraj_0
+extern /o/main/00/fc/model
+extern /o/main/12dc/fc/model:step
+extern /o/main/12dc/fc/model
+extern /o/main/00/obs/get/get_stor
+extern /o/main/00/prod/240/prod_wparam
+extern /limits:mars
+extern /mofc/00/efi/swarm/sync_climate
+
+suite extern_simple1
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/family/hierarchical_family.txt 5.13.0-1/libs/node/test/parser/data/good_defs/family/hierarchical_family.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/family/hierarchical_family.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/family/hierarchical_family.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+suite family_hier
+   edit VAR value
+   edit VAR1 "value"
+   family f
+      edit VAR value
+      task t
+         edit VAR1 "value"
+         event 0 
+         event 1 eventName
+         meter myMeter 0 100
+      family heir_f
+         edit VAR1 value
+         task taskName0
+            edit VAR1 value
+            event 0 
+            event 1 eventName
+            meter myMeter 0 100
+      endfamily
+   endfamily
+   family f1
+      edit VAR value
+      task t
+         edit VAR1 "value"
+         event 1 
+         event 2 eventName
+         meter myMeter 0 100
+   endfamily
+   family f2
+      edit VAR value
+      task t
+         trigger ../f1/t == complete
+         edit VAR1 "value"
+         event 2 
+         event 3 eventName
+         meter myMeter 0 100
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/family/missingEnds.txt 5.13.0-1/libs/node/test/parser/data/good_defs/family/missingEnds.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/family/missingEnds.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/family/missingEnds.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+suite family_missing_ends
+   family f    # missing endfamily and endsuite, should parse ok if its last family and suite
+ 
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/family/simple_family.txt 5.13.0-1/libs/node/test/parser/data/good_defs/family/simple_family.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/family/simple_family.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/family/simple_family.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,18 @@
+suite family_simple
+   family 3
+     task 3
+     task 1
+     task 2
+   endfamily
+   family 2
+     task 3
+     task 1
+     task 2
+   endfamily
+   family 1
+     task 3
+     task 1
+     task 2
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/generic/generic.def 5.13.0-1/libs/node/test/parser/data/good_defs/generic/generic.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/generic/generic.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/generic/generic.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite generic
+  generic a #dddd
+  generic b c f #
+  family b
+    generic a #dddd
+    generic b c f #
+    task c
+    	generic a #dddd
+    	generic b c f #
+    	generic x #
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/label/label.txt 5.13.0-1/libs/node/test/parser/data/good_defs/label/label.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/label/label.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/label/label.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+suite label
+   family f
+      task t
+      	label foo ""
+    endfamily
+endsuite
+
+suite label_s1
+   family f
+      task t ; label foo ""
+    endfamily
+endsuite
+
+suite label_s3
+   label foo ""
+   task t
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/label/multi_line_lables.def 5.13.0-1/libs/node/test/parser/data/good_defs/label/multi_line_lables.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/label/multi_line_lables.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/label/multi_line_lables.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite label_multi_line
+   label error "This is an error"
+   label warning "This is an warning"
+   label Note "This is an note"
+   label Critical "This is an critical"
+   label info "This is an info"
+   label warning2 "value"
+   label note2 "value\\nvalue" #\\n should be converted to new line
+   label info2 "value\\nvalue  \\nfred fred2\\n" # \\n should be converted to new line
+   task t
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/label/semicolon.def 5.13.0-1/libs/node/test/parser/data/good_defs/label/semicolon.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/label/semicolon.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/label/semicolon.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite label_semicolon
+  family f
+    label foo "a; b"
+    task t1
+       label label1 "fred ;  bill;  joe;  kate b"
+       label label2 ";;;;;;;;;;;"
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/label/spaces.def 5.13.0-1/libs/node/test/parser/data/good_defs/label/spaces.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/label/spaces.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/label/spaces.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite label_spaces
+   family f
+      task t
+      
+      	label foo ""
+      	
+      	label fred ""
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/late/late.def 5.13.0-1/libs/node/test/parser/data/good_defs/late/late.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/late/late.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/late/late.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite late
+   family f
+      task t1
+      		late -s +00:15 -a 20:00 -c +02:00
+      task t2
+      		late -a 20:00 -c +02:00 -s +00:15
+      task t3
+      		late -c +02:00 -a 20:00  -s +00:15
+      task t4
+            late  -s 00:02 -c +00:05
+      task t5
+            late  -s 00:01 -a 14:30 -c +00:01
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/lifecycle.txt 5.13.0-1/libs/node/test/parser/data/good_defs/lifecycle.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/lifecycle.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/lifecycle.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite zombie_lifecycle
+  family family1
+   	task a
+        event 1 myEvent
+        meter myMeter 0 10
+   	task b
+   		trigger a == complete
+   endfamily
+   family family2
+   		task aa
+   			trigger ../family1/a:myMeter >= 3 and ../family1/a:myEvent 
+   		task bb
+   			trigger ../family1/a:myMeter >= 4  or  ../family1/a:myEvent
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/basic.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/basic.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/basic.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/basic.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite limit_basic
+ limit disk 1
+ family anon    
+   inlimit disk  
+   task t1
+   task t2
+   task t3
+   task t4
+   task t5
+   task t6
+   task t7
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/inlimit_all_types.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/inlimit_all_types.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/inlimit_all_types.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/inlimit_all_types.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+suite limit_all_inlimit_types
+ limit fam 2
+ limit task 4
+ inlimit task         
+ family f1
+     limit sub 1
+     inlimit -n fam 
+     inlimit -s sub         
+     task t1
+     task t2
+     task t3
+     task t4
+     task t5
+     task t6
+ endfamily
+ family f2
+     limit sub 3
+     inlimit -s sub         
+     inlimit -n fam 
+     task t1
+     task t2
+     task t3
+     task t4
+     task t5
+     task t6
+ endfamily
+ family f3
+     inlimit -n fam 
+     task t1
+     task t2
+     task t3
+     task t4
+     task t5
+     task t6
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/inlimit_family.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/inlimit_family.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/inlimit_family.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/inlimit_family.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+suite limit_family
+ limit fam 1
+ family f1
+     inlimit -n fam 
+     task t1
+     task t2
+ endfamily
+ family f2
+     inlimit -n fam 
+     task t1
+     task t2
+ endfamily
+ family f3
+     inlimit -n fam 
+     task t1
+     task t2
+ endfamily
+ family f4
+     inlimit -n fam 
+     task t1
+     task t2
+ endfamily
+ family f5
+     inlimit -n fam 
+     task t1
+     task t2
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/inlimit_only.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/inlimit_only.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/inlimit_only.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/inlimit_only.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,37 @@
+extern /limits:c1a
+extern /limits:linux_cluster
+extern /limits:pdb
+extern /limits:q2diss
+
+suite limit
+    limit sg1  10
+    limit mars 10
+endsuite
+
+suite limit_with_node_inlimit
+    limit fred 1000
+    inlimit -n /limits:c1a
+    
+    family limits
+        limit hpcd 20
+    endfamily
+    
+    family X
+        inlimit -n fred 3
+        task t1
+    endfamily
+    
+    family anon    
+        inlimit -n fred      
+        task t1
+            inlimit -n /limit:sg1 3          # another suite limit
+            inlimit -n /limit_with_node_inlimit/limits:hpcd      # This suite limit
+            inlimit -n /limits:c1a           # extern suite limit
+        task t2
+            inlimit -n /limit_with_node_inlimit/limits:hpcd      # This suite limit
+        task t3
+            inlimit -n /limits:c1a           # extern suite limit
+        task t4
+            inlimit -n /limits:c1a  10       # extern suite limit
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,33 @@
+extern /limits:c1a
+extern /limits:linux_cluster
+extern /limits:pdb
+extern /limits:q2diss
+suite suiteName
+	limit sg1  10
+	limit mars 10
+endsuite
+
+suite limit_s1
+	limit mars 10
+	limit sg1  10
+endsuite
+
+suite limit_with_externs
+    inlimit /limits:c1a
+    family limits
+    	limit hpcd 20
+    endfamily
+    
+    family anon    
+   		inlimit limits:hpcd       
+    	task t1
+    		inlimit /suiteName:sg1        # another suite limit
+    		inlimit /suiteName:mars       # another suite limit
+    		inlimit /limit_s1:mars              # another suite limit
+    		inlimit /limit_s1:sg1               # another suite limit
+   		task t2
+   			inlimit /limit_with_externs/limits:hpcd      # This suite limit
+  		task t3
+   			inlimit /limits:c1a           # extern suite limit
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit2.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+suite limit2
+  clock hybrid 0 # 24.02.2006 14:47
+  inlimit pop
+  limit pop 10
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit3.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit3.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+# ECFLOW-713, moved from bad_defs/limit to good_defs/limit
+# Allow Limit value of zero, i.e inlimit greater than limit, as a way of controlling job submission.
+suite limit_with_higher_inlimit
+    limit disk 50
+    family anon    
+    	inlimit /limit_with_higher_inlimit:disk 100    # inlimit value is greater than the LIMIT
+    	task t1
+    	task t2
+    endfamily
+endsuite
+
+suite limit_with_value_zero
+    limit disk 0
+    family anon    
+        inlimit /limit_with_value_zero:disk 100    # inlimit value is greater than the LIMIT
+        task t1
+        task t2
+    endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit_check.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit_check.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/limit_check.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/limit_check.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,21 @@
+suite limit_check_relative_paths_on_inlimits
+ limit disk 1
+ family anon    
+   inlimit disk             # no path, find limit name up the tree
+   limit anon 1
+   task t1
+     inlimit /limit_check_relative_paths_on_inlimits/anon:anon   # absolute path to node defining the limit
+   task t2
+     inlimit /limit_check_relative_paths_on_inlimits:disk        # absolute path to node defining the limit
+   task t3
+     limit rel_limit 1
+   task t4
+     inlimit t3:rel_limit   # relative limit (sibling)
+   task t5
+     inlimit ./t3:rel_limit # relative limit (sibling)
+   task t6
+     inlimit ../anon:anon   # relative limit (parent)
+   task t7
+     inlimit ../../limit_check_relative_paths_on_inlimits:disk   # relative limit (parents/parent)
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/sub_only.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/sub_only.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/sub_only.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/sub_only.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,33 @@
+extern /limits:c1a
+extern /limits:linux_cluster
+extern /limits:pdb
+extern /limits:q2diss
+suite limit_suiteName
+	limit sg1  10
+	limit mars 10
+endsuite
+
+suite limit_s1
+	limit mars 10
+	limit sg1  10
+endsuite
+
+suite limit_extern_and_submission_limits
+    inlimit -s /limits:c1a
+    family limits
+    	limit hpcd 20
+    endfamily
+    
+    family anon    
+   		inlimit -s limits:hpcd       
+    	task t1
+    		inlimit -s /limit_suiteName:sg1        # another suite limit
+    		inlimit -s /limit_suiteName:mars       # another suite limit
+    		inlimit -s /limit_s1:mars              # another suite limit
+    		inlimit -s /limit_s1:sg1               # another suite limit
+   		task t2
+   			inlimit -s /limit_extern_and_submission_limits/limits:hpcd      # This suite limit
+  		task t3
+   			inlimit -s /limits:c1a           # extern suite limit
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/limit/sub_only1.def 5.13.0-1/libs/node/test/parser/data/good_defs/limit/sub_only1.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/limit/sub_only1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/limit/sub_only1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,18 @@
+suite limit_with_submission_limits
+    limit disk 2
+    family anon    
+    	inlimit -s disk   # Inlimit submission
+    	task t1
+    	task t2
+    	task t3
+    	task t4
+    	task t5
+    	task t6
+    	task t7
+    	task t8
+    	task t9
+    	task t10
+    	task t11
+    	task t12
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/meter/negative.def 5.13.0-1/libs/node/test/parser/data/good_defs/meter/negative.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/meter/negative.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/meter/negative.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite meter_negative
+   family f
+      task t
+          meter myMeter  -1 10 10  # meter <name> <min> <max> [optional color change]
+     endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/meter/simple_meter.txt 5.13.0-1/libs/node/test/parser/data/good_defs/meter/simple_meter.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/meter/simple_meter.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/meter/simple_meter.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite meter_simple
+   family f
+      task t
+          meter myMeter  0 10 10  # meter <name> <min> <max> [optional color change]
+          meter myMeter2 0 5      
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/meter/spaces.def 5.13.0-1/libs/node/test/parser/data/good_defs/meter/spaces.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/meter/spaces.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/meter/spaces.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite meter_spaces
+   family f
+      task t
+      
+          meter myMeter  0 4 4  # meter <name> <min> <max> [optional color change]
+          
+          meter myMeter1 0 5      
+          
+          meter myMeter2 0 4      
+          
+          meter myMeter3 0 3     
+          
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/mirror/mirror.def 5.13.0-1/libs/node/test/parser/data/good_defs/mirror/mirror.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/mirror/mirror.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/mirror/mirror.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+suite mirror
+  edit ECF_HOME '/Users/mamb/w/sandbox.aviso/.'
+  edit ECF_INCLUDE '/Users/mamb/w/sandbox.aviso/core/included'
+  edit ECF_FILES '/Users/mamb/w/sandbox.aviso/scripts'
+  family f1
+    edit ECF_MIRROR_REMOTE_HOST 'localhost'
+    edit ECF_MIRROR_REMOTE_PORT '1234'
+    edit ECF_MIRROR_REMOTE_POLLING '21'
+    edit ECF_MIRROR_REMOTE_AUTH '/Users/mamb/w/sandbox.aviso/mirror.auth'
+    task t1
+      mirror --name operationsX --remote_path /s1/f1/t1 --ssl
+    task t2
+      mirror --name operationsY --remote_path /s1/f1/t2 --remote_host %ECF_MIRROR_REMOTE_HOST% --polling 20 --remote_port %ECF_MIRROR_REMOTE_PORT% --ssl
+    task t3
+      mirror --name operationsZ --remote_path /s1/f1/t3 --polling 20 --remote_host %ECF_MIRROR_REMOTE_HOST% --remote_port %ECF_MIRROR_REMOTE_PORT% --ssl
+    task t4
+      trigger t1 == complete and t2 == complete and t3 == complete
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/queue/queue.def 5.13.0-1/libs/node/test/parser/data/good_defs/queue/queue.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/queue/queue.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/queue/queue.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite queue
+  queue name 001 002 003 # status 0
+  queue name1 001 002 003 # status 0
+  family f1
+    queue name 001 002 003 # status 0
+    queue name1 001 002 003 # status 0
+    task t
+       queue name 001   # status 0
+       queue name1 001  # status 0    
+  endfamily
+endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/queue/queue2.def 5.13.0-1/libs/node/test/parser/data/good_defs/queue/queue2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/queue/queue2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/queue/queue2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite queue2
+  queue name 001 002 003 # status 0
+  queue name1 001 002 003 # status 0
+  family f1
+    task t
+  endfamily
+endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/queue/queue_string.def 5.13.0-1/libs/node/test/parser/data/good_defs/queue/queue_string.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/queue/queue_string.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/queue/queue_string.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite queue_string
+  queue name red orange 002 003 blue green indigo  
+  family f1
+    task t
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_date.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_date.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_date.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_date.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite repeat_date
+  repeat date YMD 20090331 20121212 1 # status 0
+  task t1
+endsuite
+
+suite repeat_date_s2
+  repeat date YMD 20121212 20090331  -1 # status 0
+  task t1
+endsuite
+
+suite repeat_date_s3; repeat date YMD 20090331 20121212 1 # status 0
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_date_list.ecf 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_date_list.ecf
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_date_list.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_date_list.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite repeat_datelist_s1
+  repeat datelist YMD 20090331 20121212 20121212 # status 0
+  task t1
+endsuite
+
+suite repeat_datelist_s2
+  repeat datelist YMD 20121212 20090331 20090331 # status 0
+  task t1
+endsuite
+
+suite repeat_datelist_s3; repeat datelist YMD 20090331 20121212 20090331 # status 0
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_day.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_day.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_day.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_day.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite repeat_day
+  repeat day 1                             #status 0
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerate_quotes.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite repeat_enumerated1
+   
+  repeat enumerated quotes "first" "second" "third"  # sdsdsd 
+  task t1
+
+endsuite
+
+suite repeat_enumerated2
+   
+ repeat enumerated quotes 'first' 'second' "third"  # sdsdsd 
+  task t1
+   
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerated.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerated.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerated.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_enumerated.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite repeat_enumnerate_s1
+   
+    repeat enumerated VARIABLE first second third #sdsdsd
+  task t1
+   
+endsuite
+
+suite repeat_enumnerate_s1s2
+   
+    repeat enumerated VARIABLE 20130101 20130102 20130103 #sdsdsd
+  task t1
+   
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_file.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_file.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_file.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_file.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite repeat_file
+  repeat file filename fred.txt   # comment
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite repeate_integer3
+  repeat integer VARIABLE3_XZ 0 10 #comment
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_1.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_1.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite repeate_integer
+  repeat integer VARIABLE_XX 0 10 2 # comment
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_2.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_integer_2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite repeat_integer2
+  repeat integer VARIABLE_XY 0 10 # comment
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_string.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_string.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_string.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_string.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite repeat_string
+  repeat string VARIABLE str1 str2              #comment
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_string_quotes.def 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_string_quotes.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/repeat/repeat_string_quotes.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/repeat/repeat_string_quotes.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite repeat_string_quotes
+  repeat string quotes "str1" "str2"  "str2" # comment
+  task t1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/suite/multi_statements_per_line.def 5.13.0-1/libs/node/test/parser/data/good_defs/suite/multi_statements_per_line.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/suite/multi_statements_per_line.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/suite/multi_statements_per_line.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite suite_ml_empty_x;endsuite
+suite suite_ml_obs; endsuite
+
+suite suite_ml_fred; task a; task b; endsuite # a comment suite fred; task a; task b; endsuite
+
+suite suite_ml_s1; task t1; task t2;task t3;family f1;task f1_t1;task f1_t2;endfamily;task t4
+endsuite
+
+suite suite_ml_s2;task t1;task t2;task t3;family f1;task f1_t1;task f1_t2;endfamily; task t4 # comment,
+endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/suite/multi_suite.def 5.13.0-1/libs/node/test/parser/data/good_defs/suite/multi_suite.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/suite/multi_suite.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/suite/multi_suite.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+
+suite suite_ml_empty
+ 
+endsuite
+
+suite suite_ml_empty_obs
+ 
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/suite/simple_suite.txt 5.13.0-1/libs/node/test/parser/data/good_defs/suite/simple_suite.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/suite/simple_suite.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/suite/simple_suite.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,5 @@
+
+# this is comment
+  # this is another comment line
+suite suite_empty_1
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/suite/suite_with_hierarchy.def 5.13.0-1/libs/node/test/parser/data/good_defs/suite/suite_with_hierarchy.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/suite/suite_with_hierarchy.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/suite/suite_with_hierarchy.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+suite suite_hier
+	task 4
+	task 1
+	task 2
+	task 3
+	family f1
+		task 1
+		task 2
+	endfamily
+endsuite
+suite suite_hier_s1
+	task 4
+	task 1
+	task 2
+	task 3
+	family f1
+		task f1_t1
+		task f1_t2
+	endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/suite/suite_with_task.def 5.13.0-1/libs/node/test/parser/data/good_defs/suite/suite_with_task.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/suite/suite_with_task.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/suite/suite_with_task.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+suite suite_with_task
+   task a
+   task b
+   task c
+   task 1
+   task 2
+   task 3
+   task 4
+   task 5
+   task 6
+   task 7
+   task 9
+   task 10
+   task 11
+   task 20
+   task 21
+   task 30
+   task 100
+   task 101
+   task 200
+   task 400
+   task 1001
+   task 2001
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/task/simple_task.txt 5.13.0-1/libs/node/test/parser/data/good_defs/task/simple_task.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/task/simple_task.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/task/simple_task.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+suite task1
+   family f
+      task t1
+      task t2
+      task t4
+      task t5
+      endtask
+   endfamily
+endsuite
+
+suite task1_s1
+   family f
+      task t1 ; task t2 ;task t4 ; task t5
+      endtask
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/task/spaces.def 5.13.0-1/libs/node/test/parser/data/good_defs/task/spaces.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/task/spaces.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/task/spaces.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite task_spaces
+   family f
+   
+      task t
+      task 001
+      
+      task fred
+      
+      endtask
+      
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/task/task.def 5.13.0-1/libs/node/test/parser/data/good_defs/task/task.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/task/task.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/task/task.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite task2
+   family f
+      task t1
+      endtask
+      task t2
+      endtask
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/time/time.def 5.13.0-1/libs/node/test/parser/data/good_defs/time/time.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/time/time.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/time/time.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite time_time
+   family f
+		time 15:00
+		time 19:00
+		time +15:00
+		time 10:00 20:00 01:00
+		time +10:00 20:00 01:00
+	task t
+		time 15:00
+		time 19:00
+		time +15:00
+		time 10:00 20:00 01:00
+		time +10:00 20:00 01:00		   		
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/time/time_1.def 5.13.0-1/libs/node/test/parser/data/good_defs/time/time_1.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/time/time_1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/time/time_1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,21 @@
+suite time_1
+   family f1
+      task t1
+   		time 15:00
+   		time 00:00 23:59 00:30
+         time 00:00 06:59 00:30
+      task t2
+         time 17:00
+      task t3
+         time 18:00
+         time 19:00
+         time 20:00
+   endfamily
+endsuite
+
+suite time_1s1 
+   family f
+   	time 15:00 ; time 00:00 23:59 00:30 ;time 00:00 06:59 00:30
+   task t
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/time/time_2.def 5.13.0-1/libs/node/test/parser/data/good_defs/time/time_2.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/time/time_2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/time/time_2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite time_2
+   family f
+		task t
+			time 15:00
+			time 19:00
+			time +15:00
+			time 10:00 20:00 01:00
+			time +10:00 20:00 01:00		   		
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/today/today.def 5.13.0-1/libs/node/test/parser/data/good_defs/today/today.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/today/today.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/today/today.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite today
+   family f
+   	today 15:00
+   	today 00:00 23:59 00:30
+      today 00:00 06:59 00:30
+      task t
+   endfamily
+endsuite
+
+suite today_s1
+   family f
+   	today 15:00 ; today 00:00 23:59 00:30
+      today 00:00 06:59 00:30
+      task t
+   endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/today/today1.def 5.13.0-1/libs/node/test/parser/data/good_defs/today/today1.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/today/today1.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/today/today1.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite today1
+   family familyName0
+   		today 15:00            #comment
+   		today 19:00
+   		today 10:00 20:00 01:00
+   		today 11:00 20:00 01:00
+		task t
+   			today 15:00
+   			today 19:00
+   			today 10:00 20:00 01:00
+   			today 11:00 20:00 01:00		   		
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_1442.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_1442.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_1442.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_1442.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+# 4.11.1
+suite trigger_ecflow_1442
+  defstatus suspended
+  edit FIRE_YMD '19000101'
+  family setup
+    family build
+      task build_geff
+      task install_scripts
+    endfamily
+  endfamily
+  family timers
+    family start
+      task ymd
+        edit YMD '19781229'
+    endfamily
+  endfamily
+  family monthly
+    repeat enumerated YMD "19790101" "19790201" "19790301" "19790401" "19790501" "19790601" "19790701" "19790801" "19790901" "19791001" "19791101" "19791201" "19800101" "19800201" "19800301" "19800401" "19800501" "19800601" "19800701" "19800801" "19800901" "19801001" "19801101" "19801201" "19810101" "19810201" "19810301" "19810401" "19810501" "19810601" "19810701" "19810801" "19810901" "19811001" "19811101" "19811201" "19820101" "19820201" "19820301" "19820401" "19820501" "19820601" "19820701" "19820801" "19820901" "19821001" "19821101" "19821201" "19830101" "19830201" "19830301" "19830401" "19830501" "19830601" "19830701" "19830801" "19830901" "19831001" "19831101" "19831201" "19840101" "19840201" "19840301" "19840401" "19840501" "19840601" "19840701" "19840801" "19840901" "19841001" "19841101" "19841201" "19850101" "19850201" "19850301" "19850401" "19850501" "19850601" "19850701" "19850801" "19850901" "19851001" "19851101" "19851201" "19860101" "19860201" "19860301" "19860401" "19860501" "19860601" "19860701" "19860801" "19860901" "19861001" "19861101" "19861201" "19870101" "19870201" "19870301" "19870401" "19870501" "19870601" "19870701" "19870801" "19870901" "19871001" "19871101" "19871201" "19880101" "19880201" "19880301" "19880401" "19880501" "19880601" "19880701" "19880801" "19880901" "19881001" "19881101" "19881201" "19890101" "19890201" "19890301" "19890401" "19890501" "19890601" "19890701" "19890801" "19890901" "19891001" "19891101" "19891201" "19900101" "19900201" "19900301" "19900401" "19900501" "19900601" "19900701" "19900801" "19900901" "19901001" "19901101" "19901201" "19910101" "19910201" "19910301" "19910401" "19910501" "19910601" "19910701" "19910801" "19910901" "19911001" "19911101" "19911201" "19920101" "19920201" "19920301" "19920401" "19920501" "19920601" "19920701" "19920801" "19920901" "19921001" "19921101" "19921201" "19930101" "19930201" "19930301" "19930401" "19930501" "19930601" "19930701" "19930801" "19930901" "19931001" "19931101" "19931201" "19940101" "19940201" "19940301" "19940401" "19940501" "19940601" "19940701" "19940801" "19940901" "19941001" "19941101" "19941201" "19950101" "19950201" "19950301" "19950401" "19950501" "19950601" "19950701" "19950801" "19950901" "19951001" "19951101" "19951201" "19960101" "19960201" "19960301" "19960401" "19960501" "19960601" "19960701" "19960801" "19960901" "19961001" "19961101" "19961201" "19970101" "19970201" "19970301" "19970401" "19970501" "19970601" "19970701" "19970801" "19970901" "19971001" "19971101" "19971201" "19980101" "19980201" "19980301" "19980401" "19980501" "19980601" "19980701" "19980801" "19980901" "19981001" "19981101" "19981201" "19990101" "19990201" "19990301" "19990401" "19990501" "19990601" "19990701" "19990801" "19990901" "19991001" "19991101" "19991201" "20000101" "20000201" "20000301" "20000401" "20000501" "20000601" "20000701" "20000801" "20000901" "20001001" "20001101" "20001201" "20010101" "20010201" "20010301" "20010401" "20010501" "20010601" "20010701" "20010801" "20010901" "20011001" "20011101" "20011201" "20020101" "20020201" "20020301" "20020401" "20020501" "20020601" "20020701" "20020801" "20020901" "20021001" "20021101" "20021201" "20030101" "20030201" "20030301" "20030401" "20030501" "20030601" "20030701" "20030801" "20030901" "20031001" "20031101" "20031201" "20040101" "20040201" "20040301" "20040401" "20040501" "20040601" "20040701" "20040801" "20040901" "20041001" "20041101" "20041201" "20050101" "20050201" "20050301" "20050401" "20050501" "20050601" "20050701" "20050801" "20050901" "20051001" "20051101" "20051201" "20060101" "20060201" "20060301" "20060401" "20060501" "20060601" "20060701" "20060801" "20060901" "20061001" "20061101" "20061201" "20070101" "20070201" "20070301" "20070401" "20070501" "20070601" "20070701" "20070801" "20070901" "20071001" "20071101" "20071201" "20080101" "20080201" "20080301" "20080401" "20080501" "20080601" "20080701" "20080801" "20080901" "20081001" "20081101" "20081201" "20090101" "20090201" "20090301" "20090401" "20090501" "20090601" "20090701" "20090801" "20090901" "20091001" "20091101" "20091201" "20100101" "20100201" "20100301" "20100401" "20100501" "20100601" "20100701" "20100801" "20100901" "20101001" "20101101" "20101201" "20110101" "20110201" "20110301" "20110401" "20110501" "20110601" "20110701" "20110801" "20110901" "20111001" "20111101" "20111201" "20120101" "20120201" "20120301" "20120401" "20120501" "20120601" "20120701" "20120801" "20120901" "20121001" "20121101" "20121201" "20130101" "20130201" "20130301" "20130401" "20130501" "20130601" "20130701" "20130801" "20130901" "20131001" "20131101" "20131201" "20140101" "20140201" "20140301" "20140401" "20140501" "20140601" "20140701" "20140801" "20140901" "20141001" "20141101" "20141201" "20150101" "20150201" "20150301" "20150401" "20150501" "20150601" "20150701" "20150801" "20150901" "20151001" "20151101" "20151201" "20160101" "20160201" "20160301" "20160401" "20160501" "20160601" "20160701" "20160801" "20160901" "20161001" "20161101" "20161201" "20170101" "20170201" "20170301" "20170401" "20170501" "20170601" "20170701" "20170801" "20170901" "20171001" "20171101" "20171201" "20180101" "20180201" "20180301" "20180401" "20180501" "20180601" "20180701" "20180801" "20180901" "20181001" "20181101" "20181201" "20190101" "20190201" "20190301" "20190401" "20190501" "20190601" "20190701" "20190801" "20190901" "20191001" "20191101" "20191201" "20200101" "20200201" "20200301" "20200401" "20200501" "20200601" "20200701" "20200801" "20200901" "20201001" "20201101" "20201201" "20210101" "20210201" "20210301" "20210401" "20210501" "20210601" "20210701" "20210801" "20210901" "20211001" "20211101" "20211201" "20220101"
+    task ei_get_nwp
+      trigger ../timers/start/ymd:YMD >= ../monthly:YMD
+    family last
+      trigger ../timers/start/ymd:YMD > ../monthly:YMD and ../monthly:YMD <= ../daily:YMD + 2 and ei_get_nwp == complete
+    endfamily
+  endfamily
+  family daily
+    repeat date YMD 19790101 20220101 1
+    family init
+      trigger ../../trigger_ecflow_1442:FIRE_YMD >= ../daily:YMD
+      task const_prep
+    endfamily
+    task ic
+    family forcings
+      trigger init == complete and ic == complete
+      task ws
+      task rh
+      task tt
+      task pr
+      task sc
+      task cc
+    endfamily
+    task ecfire
+      trigger init == complete and forcings == complete
+    task update_latest
+      trigger ecfire == complete
+    task ei_tar
+      trigger ecfire == complete
+    task ei_arch
+      trigger ei_tar == complete
+    task ei_clean
+      trigger ei_arch == complete
+    family last
+      trigger ../../trigger_ecflow_1442:FIRE_YMD > ../daily:YMD and init == complete and ic == complete and forcings == complete and ecfire == complete and update_latest == complete and ei_tar == complete and ei_arch == complete and ei_clean == complete
+    endfamily
+  endfamily
+endsuite
+# enddef
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_867.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_867.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_867.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/ECFLOW_867.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite trigger_ecflow_867
+  family f1.1
+    task t1
+  endfamily
+  family f2
+    task t1
+      trigger ../f1.1/t1 eq complete
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/all_trigger_examples.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/all_trigger_examples.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/all_trigger_examples.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/all_trigger_examples.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+suite trigger_examples_all
+   limit top_level_limit 20
+   task a
+      event EVENT
+      meter METER 1 9 5
+      edit  VAR_DATE 20170701
+      edit  VAR_STRING "captain scarlett"      # This is not convertible to an integer, if referenced will use '0'
+      late -c +02:00                           # add late flag if task takes longer than 2 hours to complete
+  family f1
+      edit SLEEP 2
+      repeat string NAME a b c d e f              # This has values: a(0),b(1), c(3), d(4), e(5), f(6) i.e. index
+      family f2
+         repeat integer VALUE 5 10                # This has values: 5,6,7,8,9,10
+         family f3
+            repeat enumerated red green blue      # red(0), green(1), blue(2)
+            task t1
+               repeat date DATE 19991230 20000102  # This has values: 19991230,19991231,20000101,20000102
+               trigger :VALUE == 5 and :NAME == 0 and :SLEEP == 2 # references f2:VALUE,f1:NAME,f1:SLEEP new for 4.7.0 release
+         endfamily
+      endfamily
+   endfamily
+   family f2
+      inlimit /trigger_examples_all:top_level_limit
+      task event_meter
+          trigger /trigger_examples_all/a:EVENT == set and /trigger_examples_all/a:METER >= 6
+      task variable
+          trigger /trigger_examples_all/a:VAR_DATE >= 20170801 and /trigger_examples_all/a:VAR_STRING == 0
+      task repeat_string
+          trigger /trigger_examples_all/f1:NAME >= 4
+      task repeat_integer
+          trigger /trigger_examples_all/f1/f2:VALUE >= 7
+      task repeat_date
+          trigger /trigger_examples_all/f1/f2/f3/t1:DATE >= 19991231
+      task repeat_date_arithmitic
+          # Using plus/minus on a repeat DATE will use date arithmetic
+          # Since the starting value of DATE is 19991230, this task will run
+          # straight away
+          trigger /trigger_examples_all/f1/f2/f3/t1:DATE - 1 == 19991229
+      task use_repeat_date_yyyy
+          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_YYYY == 2000    # DATE_YYYY(year)is a generated variable for repeat date DATE 19991230 20000102
+      task use_repeat_date_generated_mm
+          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_MM == 2         # DATE_MM(month) is a generated variable for repeat date DATE 19991230 20000102
+      task use_repeat_date_generated_dd
+          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_DD == 30        # DATE_DD(day of the month) is a generated variable for repeat date DATE 19991230 20000102
+      task use_repeat_date_generated_dow
+          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_DOW == 0        # DATE_MM(day of week, 0-sunday,1-monday,etc) is a generated variable for repeat date DATE 19991230 20000102
+      task use_repeat_date_generated_julian
+          trigger /trigger_examples_all/f1/f2/f3/t1:DATE_JULIAN > cal::date_to_julian(/trigger_examples_all/a:VAR_DATE)  # DATE_JULIAN(the julian of the date) is a generated variable for repeat date DATE 19991230 20000102
+      task with_trigger_that_ref_a_limit
+          trigger /trigger_examples_all:top_level_limit < 5        # low priority task, only valid when system is not loaded
+      task trigger_with_ref_to_late_flag
+          trigger /trigger_examples_all/a<flag>late                # Only triggers if task /trigger_examples_all/a is late
+      task trigger_with_ref_to_zombie_flag
+          trigger /trigger_examples_all/a<flag>zombie              # Only triggers if task /trigger_examples_all/a is a zombie
+      task trigger_with_ref_to_archived_flag
+          trigger /trigger_examples_all<flag>archived              # Only triggers if family /trigger_examples_all is archived -> only family/suite can be archived
+   endfamily
+   family time_trigger
+      trigger /trigger_examples_all:DOW == 0  or /trigger_examples_all:DOW == 1   # DOW is a generated variable on the suite representing DAY of the week. i.e Sundày and Monday in this case
+      task with_time
+         trigger /trigger_examples_all:TIME > 1330                 # TIME is a generated variable on the suite , same as time > 13:30
+   endfamily
+ endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/anded_ored.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/anded_ored.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/anded_ored.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/anded_ored.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite trigger_anded
+ family f
+ 	task t1
+ 	task t2
+	task a             
+      	event eventName 
+ 	task b             
+			trigger t1  == complete       # a comment at end of trigger
+			trigger -a t2  == complete    # a comment at end of trigger
+			trigger -o a  == complete     # a comment at end of trigger
+ endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/complex_hier.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/complex_hier.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/complex_hier.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/complex_hier.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+# test node referencing in triggers
+#      o/ <node> == complete    i.e   a == complete   sibling    
+#      o/ ./<node> == complete  i.e  ./a == complete  sibling
+#      o/ ../<node> == complete i.e  ../a == complete means trigger nodes parent
+suite trigger_s0
+  edit FIRE_YMD '19000101'
+  task t1
+endsuite
+suite trigger_s1
+  family f1
+     trigger f2/f3/f4/a == complete or ../trigger_s0:FIRE_YMD == 19000101  # allow relative suite access
+     family f2
+        family f3
+           family f4
+              task a
+                 event 1 theEventName
+                 meter myMeter 0 100
+                 trigger ./b == complete or c == complete or ../f4 == complete or ../../f3 == complete or ../../../f2 == aborted 
+               task b
+                  trigger ../../../../../trigger_s0 == complete or  ../../../../../trigger_s0/t1<flag>late
+               task c
+                  trigger ../../../../../trigger_s0:FIRE_YMD == 10 
+            endfamily   
+         endfamily
+      endfamily
+   endfamily
+   family f0
+      task c
+         # The initial .. means parents parent( i.e /trigger_s1 in this case)
+         # i.e task 'c' parents parent is suite 'trigger_s1'
+         trigger  ../f1/f2/f3/f4/a == complete
+         complete ../f1/f2/f3/f4/a:myMeter >= 10
+      family f1
+         family f2
+            family f3
+               family f4
+                  # ..             -> f3 level
+                  # ../..          -> f2 level
+                  # ../../..       -> f1 level
+                  # ../../../..    -> f0 level
+                  # ../../../../.. -> suite level
+                  trigger ../../../../f1/f2/f3/f4/a == complete or ../../../../../trigger_s1/f1/f2/f3/f4/a == complete or ../../../../../trigger_s0 == complete
+            endfamily
+         endfamily
+      endfamily
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/complex_trigger.txt 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/complex_trigger.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/complex_trigger.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/complex_trigger.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,68 @@
+extern /a/b/c/d         
+extern /a/b/c/d/e:event        
+extern /a/b/c/d/e:meter        
+
+suite trigger_complex
+  edit int_var 20
+  family familyName
+   		task a
+        	event 1 theEventName
+         	meter myMeter 0 100
+   		task b
+     	family heir_familyName
+         	task taskName0
+            	event 0 
+            	event 1 eventName
+            	meter myMeter 0 100
+      	endfamily
+   endfamily
+   family familyName1
+   		trigger familyName == complete                      # this is a comment
+        repeat date YMD 20090331 20121212 1 # status 0
+        task ref_parent_var_without_path
+        	trigger :YMD < 20121212 and :int_var < 40
+   		task a
+         	event 1 theEventName
+         	event aEvent
+         	meter myMeter 0 100
+   		task b
+   			trigger ./a == unknown
+   		task c
+   			trigger ../familyName/a == complete
+   		task d
+   			trigger ../familyName/b != aborted
+   		task e
+   			trigger (a == complete and b == complete)
+        task ee
+            trigger (a == complete AND b == complete)
+   		task f
+   			trigger (a == complete and b == complete OR ../familyName/a == complete)
+   		task g
+   			trigger a:theEventName and a:aEvent
+   		task h
+   			trigger a:myMeter >= 10
+   		task i
+   			trigger ../familyName/a:myMeter <= 30
+   		task j
+   			trigger a == complete                      # this is a comment
+   		task k
+   		    trigger (a == complete AND b == complete) or (c == complete && d == complete)
+   		task l
+   			trigger (a == complete and b == complete) OR ../familyName/a:theEventName == set
+        task ll
+            trigger (a == complete and b == complete) || ../familyName/a:theEventName == set
+   		task m
+   			trigger ../familyName/heir_familyName/taskName0 == complete
+   		task n
+   			trigger ../familyName/heir_familyName/taskName0:myMeter >= 10  	     # relative path
+  		task o
+   			trigger /trigger_complex/familyName/heir_familyName/taskName0:myMeter >= 10  # absolute path
+  		task p
+   			trigger /a/b/c/d == complete  		                                   # extern path
+  		task q
+   			trigger /a/b/c/d/e:event == set  		                                # extern event path
+ 		task r
+   			trigger /a/b/c/d/e:meter le 30		                                   # extern meter path
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/extension.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/extension.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/extension.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/extension.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+ suite trigger_extension
+  family f
+  	    task b
+  	    task c
+   		task a
+   			trigger a == complete and \
+   			        b == complete and\
+   			        c == complete
+   endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/late.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/late.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/late.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/late.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite trigger_late_flag
+    family f1
+        task t
+        task t1
+            event event
+    endfamily
+    family anon    
+        task t1
+           trigger /trigger_late_flag/f1/t<flag>late
+        task t2
+           trigger /trigger_late_flag/f1/t1:event
+         task t3
+           trigger /<flag>late  # late flag set on Defs. Since defs is alawys there, does not need extern
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/limit.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/limit.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/limit.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/limit.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,27 @@
+extern /limits:c1a
+extern /limits:linux_cluster
+
+suite trigger_limit
+    limit sg1  100
+    limit mars 100
+endsuite
+
+suite trigger_limit_obs
+    inlimit /limits:c1a
+    family limits
+        limit hpcd 20
+    endfamily
+    
+    family anon    
+        inlimit limits:hpcd       
+        task t1
+            inlimit /trigger_limit:sg1        # another suite limit
+            trigger /trigger_limit:sg1 < 30
+        task t2
+            inlimit /trigger_limit_obs/limits:hpcd      # This suite limit
+            trigger /trigger_limit_obs/limits:hpcd > 10
+        task t3
+            inlimit /limits:c1a           # extern suite limit
+            trigger /limits:c1a > 10
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/relative.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/relative.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/relative.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/relative.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+# test node referencing in triggers
+#      o/ <node> == complete    i.e   a == complete   means sibling
+#      o/ ./<node> == complete  i.e  ./a == complete  means sibling
+#      o/ ../<node> == complete i.e  ../a == complete means trigger nodes parent
+suite trigger_relative_s
+endsuite
+suite trigger_relative
+  family f1
+     trigger f2/f3/f4/a == complete
+     family f2
+        trigger ../f1 == complete
+        family f3
+           trigger f4/a == complete
+           family f4
+              task a
+           endfamily   
+        endfamily
+     endfamily
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/simple_trigger.txt 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/simple_trigger.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/simple_trigger.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/simple_trigger.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite trigger_simple
+    family f
+		task a             
+         	event eventName 
+    	task b             
+   			trigger a  == complete                  # a comment at end of trigger
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/trigger_references.def 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/trigger_references.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/trigger/trigger_references.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/trigger/trigger_references.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite trigger_reference
+  family acq
+    task data
+      trigger wait/wait:data
+    family wait
+      task wait
+        event data
+    endfamily
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/variable/alias.def 5.13.0-1/libs/node/test/parser/data/good_defs/variable/alias.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/variable/alias.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/variable/alias.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+#  
+defs_state MIGRATE
+
+# The file can be of different styles:
+#    DEFS: This is the structure only (default), 
+#          when we write out defs to disk, this will exclude aliases.
+#          Hence we use 
+#             defs_state MIGRATE
+#          So that when *testing*, we write out the defs in the state state in meant to be loaded
+#   STATE: structure + state
+#   MIGRATE: structure + state (No checking, and no externs )
+    
+# ===============================================================================
+# This will test that for alias we allow _variables_ names *without* checking
+# i.e for tasks EDACLASS:"od" would be an illegal variable name
+# ===============================================================================
+suite alias
+  task t1
+    alias alias0
+    
+         edit VAR  "value !£$%^&*() ~@: ?><,."   #comment
+   
+         edit VAR1 '123'
+   
+         edit VAR2 value2
+   
+         edit VAR3 ""
+         edit VAR55 ''
+         edit VAR56 '#'
+         edit VAR57 "#"
+         
+         # alias show allow variable names with invalid names
+         edit name:1 '1'
+         edit namx$1 '1'
+         
+         
+        edit DO_PUSH_TO_WEB:yes 'yes'
+        edit ECF_HOME:0 '/vol/emos_nc/output'
+        edit ECF_OUT:0 '/vol/emos_nc/output'
+        edit EDACLASS:"od" 'od'
+        edit EDACLASS:undef 'od'
+        edit EDAEXPVER:"0001" '0001'
+        
+    endalias
+endsuite
+ 
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/variable/duplicate.def 5.13.0-1/libs/node/test/parser/data/good_defs/variable/duplicate.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/variable/duplicate.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/variable/duplicate.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+suite edit_duplicate
+   edit VAR2 value2
+   edit VAR2 value3     # allow duplicates to update the last value
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/variable/variable.txt 5.13.0-1/libs/node/test/parser/data/good_defs/variable/variable.txt
--- 5.12.4-1/libs/node/test/parser/data/good_defs/variable/variable.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/variable/variable.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+suite edit_variable
+ 
+   edit SMSURLCMD '${BROWSER:=firefox} -new-tab %SMSURLBASE%/%SMSURL%'
+   
+   edit VAR  "value !£$%^&*() ~@: ?><,."
+   
+   edit VAR1 '123'
+   
+   edit VAR2 value2
+   
+   edit VAR3 ""
+   edit VAR55 ''
+   edit VAR56 '#'
+   edit VAR57 "#"
+
+endsuite
+
+suite edit_variable_s1
+ 
+   edit SMSURLCMD '${BROWSER:=firefox} -new-tab %SMSURLBASE%/%SMSURL%'; edit VAR  "value !£$%^&*() ~@: ?><,."
+   
+   edit VAR1 '123'; edit VAR2 value2
+   
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/verify/verify.def 5.13.0-1/libs/node/test/parser/data/good_defs/verify/verify.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/verify/verify.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/verify/verify.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,31 @@
+suite verify
+   verify complete:3 
+   verify unknown:3 
+   verify queued:3 
+   verify aborted:3 
+   verify submitted:3 
+    verify active:3 
+   family f
+    	verify complete:3 
+   		verify unknown:3 
+   		verify queued:3 
+   		verify aborted:3 
+   		verify submitted:3 
+   		verify active:3 
+      task t1
+    		verify complete:3 
+   			verify unknown:3 
+   			verify queued:3 
+   			verify aborted:3 
+   			verify submitted:3 
+    			verify active:3 
+      task t2
+    		verify complete:3 
+   			verify unknown:3 
+   			verify queued:3 
+   			verify aborted:3 
+   			verify submitted:3 
+   			verify active:3 
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs/zombie/zombie.def 5.13.0-1/libs/node/test/parser/data/good_defs/zombie/zombie.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs/zombie/zombie.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs/zombie/zombie.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,33 @@
+suite zombie
+   zombie ecf:fob:init:100
+   zombie ecf_pid:fob:init:100
+   zombie ecf_pid_passwd:fob:init:100
+   zombie ecf_passwd:fob:init:100
+   zombie path:fail:init:100
+   zombie user:adopt:meter:100
+
+   task t1
+     zombie ecf:remove::
+     zombie ecf_pid:remove::
+     zombie ecf_pid_passwd:remove::
+     zombie ecf_passwd:remove::
+     zombie path:block:wait:
+     zombie user:fob:complete:
+
+   task t2
+     zombie ecf:fob::
+     zombie ecf_pid:kill::
+     zombie ecf_pid_passwd:block::
+     zombie ecf_passwd:adopt::
+     zombie path:fail::
+     zombie user:adopt::
+    
+   task t3
+     zombie ecf:remove:init,event,meter,label,wait,queue,complete:2000     # comment
+     zombie ecf_pid:remove:init,event,meter,label,wait,queue,complete:2000     # comment
+     zombie ecf_pid_passwd:remove:init,event,meter,label,wait,queue,complete:2000     # comment
+     zombie ecf_passwd:remove:init,event,meter,label,wait,queue,complete:2000     # comment
+     zombie path:::0
+     zombie user:::0
+endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_defs_state/defs/defs_state.def 5.13.0-1/libs/node/test/parser/data/good_defs_state/defs/defs_state.def
--- 5.12.4-1/libs/node/test/parser/data/good_defs_state/defs/defs_state.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_defs_state/defs/defs_state.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+# 2.0.31 
+defs_state STATE state:unknown flag: state_change:17 modify_change:0 server_state:SHUTDOWN
+  edit ECF_MICRO '%'
+  edit ECF_HOME '/var/tmp/ma0/workspace'
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_node_defs/family/family.def 5.13.0-1/libs/node/test/parser/data/good_node_defs/family/family.def
--- 5.12.4-1/libs/node/test/parser/data/good_node_defs/family/family.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_node_defs/family/family.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+family test_local_actions # state:queued suspended:1
+   defstatus suspended
+   edit REMOTE_HOST 'eurydice'
+   edit WORKDIR ''
+   task action1 # state:queued suspended:1
+	  defstatus suspended
+   family f1 # state:queued suspended:1
+	  task a # state:queued suspended:1
+	  task b # state:queued suspended:1
+   endfamily
+endfamily
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_node_defs/suite/suite.def 5.13.0-1/libs/node/test/parser/data/good_node_defs/suite/suite.def
--- 5.12.4-1/libs/node/test/parser/data/good_node_defs/suite/suite.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_node_defs/suite/suite.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+# 
+suite suite #  begun:1 state:queued suspended:1
+	defstatus suspended
+	edit ECF_HOME '/scratch/ma/ma0/nightly'
+	task exp # state:queued
+		edit ECF_JOB_CMD 'python %ECF_JOB% 1> %ECF_JOBOUT% 2>&1'
+		label label_name "value"
+		meter meter 0 100 100
+		event event_fred
+	family test_local_actions # state:queued suspended:1
+		defstatus suspended
+		edit REMOTE_HOST 'eurydice'
+		edit WORKDIR ''
+		task action1 # state:queued suspended:1
+			defstatus suspended
+	endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/good_node_defs/task/task.def 5.13.0-1/libs/node/test/parser/data/good_node_defs/task/task.def
--- 5.12.4-1/libs/node/test/parser/data/good_node_defs/task/task.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/good_node_defs/task/task.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+task exp # state:queued
+  edit ECF_JOB_CMD 'python %ECF_JOB% 1> %ECF_JOBOUT% 2>&1'
+  label label_name "value"
+  meter meter 0 100 100
+  event event_fred
+  trigger 1 == 1
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/ECFLOW-417.def 5.13.0-1/libs/node/test/parser/data/single_defs/ECFLOW-417.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/ECFLOW-417.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/ECFLOW-417.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite s1
+   repeat day 1
+   clock hybrid  
+   task t1
+      time 15:42
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/ealadin.def 5.13.0-1/libs/node/test/parser/data/single_defs/ealadin.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/ealadin.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/ealadin.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3671 @@
+extern /limits:mars
+extern /limits:localhost
+extern /limits:c1b
+extern /limits:linux_cluster
+extern /limits:swarm
+extern /limits:ha_pp
+extern /limits:ecfs
+extern /limits:obs_get
+extern /limits:pdb
+extern /limits:q2diss
+extern /limits:pdb_bc
+extern /limits:q2diss_bc
+extern /limits:rebuild
+extern /o/main/12/fc
+extern /o/main/12/fc/model:step
+extern /o/main:YMD
+extern /o/main/18/fc
+extern /o/main/18/fc/model:step
+extern /o/main/00/fc
+extern /o/main/00/fc/model:step
+extern /o/main/06/fc
+extern /o/main/06/fc/model:step
+extern /o/main/12bc/fc
+extern /o/main/12bc/fc/model:step
+extern /o/main/18bc/fc
+extern /o/main/18bc/fc/model:step
+extern /o/main/00bc/fc
+extern /o/main/00bc/fc/model:step
+extern /o/main/06bc/fc
+extern /o/main/06bc/fc/model:step
+
+suite ealadin
+  #defstatus suspended
+  edit QUEUE 'ts'
+  edit QUEUE_EPILOG 'SC_QUEUE_EPILOG'
+  edit ECFCMD 'smssubmit %USER% %SCHOST% %ECFJOB% %ECFJOBOUT%'
+  edit ECFKILL 'smskill %USER% %SCHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
+  edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %ECFRID% %ECFJOB%'
+  edit LOGDIR '/s1a/emos_esuite/emos_data/0047/log'
+  edit ECFOUT '/s1a/emos_esuite/emos_data/0047/log'
+  edit THREADS_FRA '6'
+  edit THREADS_LBC '6'
+  edit EMOS_TIME_STEP_H 'undef'
+  edit STREAM 'undef'
+  edit ECF_URLBASE 'http://www.ecmwf.int'
+  edit NB_TASKS_FRA '38'
+  edit SCLOGDIR '/s1a/emos_esuite/emos_data/0047/log'
+  edit USER 'emos'
+  edit STHOST_BKUP '/s1b'
+  edit DATEMASK '*.*.*'
+  edit CALL_ECPDS 'false'
+  edit EXPVER '0047'
+  edit MEMBER '-1'
+  edit ECF_OUT '/vol/emos_nc/output'
+  edit FSFAMILY 'undef'
+  edit USE_YMD 'true'
+  edit ECF_URLCMD '${BROWSER:=firefox} -new-tab %ECF_URLBASE%/%ECF_URL%'
+  edit NB_TASKS_LBC '32'
+  edit DELTA_DAY '0'
+  edit STHOST '/s1a'
+  edit VERSION '%EXPVER%'
+  edit SCHOST_BKUP 'c1b'
+  edit ACCOUNT_FRA 'oesu'
+  edit MEM '2500'
+  edit EPSTYPE 'undef'
+  edit ACCOUNT_LBC 'oesu'
+  edit ALADIN_STEP '-1'
+  edit ECF_LOGHOST 'localhost'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit INIEXPVER '0001'
+  edit WSHOST 'localhost'
+  edit ECF_URL 'index.html'
+  edit THREADS '1'
+  edit SCHOST 'localhost'
+  edit ECF_LOGPORT '9316'
+  edit REAL_TIME '1'
+  edit FIRST_DAY '0'
+  inlimit /limits:localhost
+  family limits
+    defstatus complete
+    limit limiter 1
+    limit oper 7
+    limit bkup 7
+    limit clst 7
+    limit lbc 26
+    limit main 84
+    limit 927 21
+    limit subd 21
+    limit init 7
+  endfamily
+  family main
+    repeat date YMD 20100607 20201212 1
+    edit LOGTASK 'main'
+    edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+    edit ECPDS_STREAM 'JSN2'
+    edit DESTINATION 'FRA'
+    family 12
+      edit ACCOUNT '%ACCOUNT_FRA%'
+      edit NB_TASKS '%NB_TASKS_FRA%'
+      edit STREAM 'oper'
+      edit EMOS_BASE '1'
+      edit ECF_URL 'FRA/ALADIN/12'
+      inlimit /ealadin/limits:main
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/main:YMD
+        edit EMOS_BASE '1'
+        task external
+          defstatus complete
+          complete /o/main/12/fc eq complete or /o/main/12/fc/model:step gt 42
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 17:58
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 42 42
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 42 42
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 42 42
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../00/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 42 42
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 42 42
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 42 42
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../00/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../03/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 42 42
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 42 42
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 42 42
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../03/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 42 42
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '17:58'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '17:58'
+        limit mutex 1
+        inlimit prod:mutex
+        family fra
+          edit DESTINATION 'FRA'
+          edit ECF_URL 'FRA/ALADIN/12'
+          task ecpds
+            edit ECPDS_STREAM 'JSN2'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    family 18
+      edit ACCOUNT '%ACCOUNT_FRA%'
+      edit NB_TASKS '%NB_TASKS_FRA%'
+      edit STREAM 'scda'
+      edit EMOS_BASE '1'
+      edit ECF_URL 'FRA/ALADIN/18'
+      inlimit /ealadin/limits:main
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/main:YMD
+        edit EMOS_BASE '1'
+        task external
+          defstatus complete
+          complete /o/main/18/fc eq complete or /o/main/18/fc/model:step gt 60
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 00:00
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 60 60
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../00/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 60 60
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../00/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../03/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 60 60
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../03/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 42
+          edit ALADIN_STEP '42'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 45
+          edit ALADIN_STEP '45'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 48
+          edit ALADIN_STEP '48'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 51
+          edit ALADIN_STEP '51'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 54
+          edit ALADIN_STEP '54'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 57
+          edit ALADIN_STEP '57'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '00:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '00:00'
+        limit mutex 1
+        inlimit prod:mutex
+        family fra
+          edit DESTINATION 'FRA'
+          edit ECF_URL 'FRA/ALADIN/18'
+          task ecpds
+            edit ECPDS_STREAM 'JSN2'
+            edit ECPDS_OPER 'false'
+            edit CALL_ECPDS 'false'
+            edit TO_ECPDS 'false'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    family 00
+      edit ACCOUNT '%ACCOUNT_FRA%'
+      edit NB_TASKS '%NB_TASKS_FRA%'
+      edit DELTA_DAY '1'
+      edit STREAM 'oper'
+      edit EMOS_BASE '0'
+      edit ECF_URL 'FRA/ALADIN/00'
+      inlimit /ealadin/limits:main
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/main:YMD
+        edit EMOS_BASE '0'
+        task external
+          defstatus complete
+          complete /o/main/00/fc eq complete or /o/main/00/fc/model:step gt 54
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 06:01
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 54 54
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 54 54
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 54 54
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../00/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 54 54
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 54 54
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 54 54
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../00/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../03/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 54 54
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 54 54
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 54 54
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../03/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 42
+          edit ALADIN_STEP '42'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 45
+          edit ALADIN_STEP '45'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 48
+          edit ALADIN_STEP '48'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 51
+          edit ALADIN_STEP '51'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 54 54
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '06:01'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '06:01'
+        limit mutex 1
+        inlimit prod:mutex
+        family fra
+          edit DESTINATION 'FRA'
+          edit ECF_URL 'FRA/ALADIN/00'
+          task ecpds
+            edit ECPDS_STREAM 'JSN2'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    family 06
+      edit ACCOUNT '%ACCOUNT_FRA%'
+      edit NB_TASKS '%NB_TASKS_FRA%'
+      edit DELTA_DAY '1'
+      edit STREAM 'scda'
+      edit EMOS_BASE '0'
+      edit ECF_URL 'FRA/ALADIN/06'
+      inlimit /ealadin/limits:main
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/main:YMD
+        edit EMOS_BASE '0'
+        task external
+          defstatus complete
+          complete /o/main/06/fc eq complete or /o/main/06/fc/model:step gt 60
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 12:00
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 60 60
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../00/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 60 60
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../00/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../03/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+          family subd
+            trigger ./927 eq active or ./927 eq complete
+            inlimit /ealadin/limits:subd
+            family poly
+              edit DOM 'polyf'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family antg
+              edit DOM 'antig'
+              task 927
+                meter step -1 60 60
+            endfamily
+            family ncal
+              edit DOM 'ncal'
+              task 927
+                meter step -1 60 60
+            endfamily
+            task ecpds
+              defstatus complete
+              trigger ./poly==complete and ./antg==complete and ./ncal==complete
+              trigger -a ../../03/subd/ecpds eq complete
+              edit DOM 'polyf antig ncal'
+              label scheduled ""
+          endfamily
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 42
+          edit ALADIN_STEP '42'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 45
+          edit ALADIN_STEP '45'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 48
+          edit ALADIN_STEP '48'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 51
+          edit ALADIN_STEP '51'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 54
+          edit ALADIN_STEP '54'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+        family 57
+          edit ALADIN_STEP '57'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_FRA%'
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            inlimit /ealadin/limits:927
+            meter step -1 60 60
+          task ecpds
+            defstatus complete
+            trigger ./927 eq complete
+            trigger -a ../06/ecpds eq complete
+            edit ECPDS_AT '12:00'
+            edit DOM 'francecep'
+            label scheduled ""
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '12:00'
+        limit mutex 1
+        inlimit prod:mutex
+        family fra
+          edit DESTINATION 'FRA'
+          edit ECF_URL 'FRA/ALADIN/06'
+          task ecpds
+            edit ECPDS_STREAM 'JSN2'
+            edit ECPDS_OPER 'false'
+            edit CALL_ECPDS 'false'
+            edit TO_ECPDS 'false'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    task logfilestore
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit KEEPLOGS 'no'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
+      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
+      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit ECFOUT '/vol/emos_nc/output'
+    task logfiles
+      trigger ./12==complete and ./18==complete and ./00==complete and ./06==complete and ./logfilestore==complete
+      edit MOVE_TO_ECFS 'no'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
+      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
+      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit ECFOUT '/vol/emos_nc/output'
+      edit ACCOUNT 'oesu'
+      time 12:30
+  endfamily
+  family lbc
+    repeat date YMD 20100607 20201212 1
+    edit LOGTASK 'lbc'
+    family 12bc
+      task clean
+        edit ACCOUNT '%ACCOUNT_LBC%'
+        edit NB_TASKS '%NB_TASKS_LBC%'
+        edit STREAM 'oper'
+        edit EMOS_BASE '1'
+        inlimit /ealadin/limits:lbc
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/lbc:YMD
+        edit EMOS_BASE '1'
+        task external
+          defstatus complete
+          complete /o/main/12bc/fc eq complete or /o/main/12bc/fc/model:step gt 72
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 18:06
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 42
+          edit ALADIN_STEP '42'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 45
+          edit ALADIN_STEP '45'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 48
+          edit ALADIN_STEP '48'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 51
+          edit ALADIN_STEP '51'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 54
+          edit ALADIN_STEP '54'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 57
+          edit ALADIN_STEP '57'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 60
+          edit ALADIN_STEP '60'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 63
+          edit ALADIN_STEP '63'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 66
+          edit ALADIN_STEP '66'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 69
+          edit ALADIN_STEP '69'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '18:06'
+        limit mutex 1
+        inlimit prod:mutex
+        family hun
+          edit DESTINATION 'HUN'
+          edit ECF_URL 'HUN/ALADIN/1'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family czm
+          edit DESTINATION 'CZM'
+          edit ECF_URL 'CZM/ALADIN/1'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family sli
+          edit DESTINATION 'SLI'
+          edit ECF_URL 'SLI/ALADIN/1'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family aus
+          edit DESTINATION 'AUS'
+          edit ECF_URL 'AUS/ALADIN/1'
+          task ecpds
+            edit ECPDS_OPER 'false'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    family 18bc
+      task clean
+        edit ACCOUNT '%ACCOUNT_LBC%'
+        edit NB_TASKS '%NB_TASKS_LBC%'
+        edit STREAM 'SCDA'
+        edit EMOS_BASE '1'
+        inlimit /ealadin/limits:lbc
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/lbc:YMD
+        edit EMOS_BASE '1'
+        task external
+          defstatus complete
+          complete /o/main/18bc/fc eq complete or /o/main/18bc/fc/model:step gt 72
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 00:06
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 42
+          edit ALADIN_STEP '42'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 45
+          edit ALADIN_STEP '45'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 48
+          edit ALADIN_STEP '48'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 51
+          edit ALADIN_STEP '51'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 54
+          edit ALADIN_STEP '54'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 57
+          edit ALADIN_STEP '57'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 60
+          edit ALADIN_STEP '60'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 63
+          edit ALADIN_STEP '63'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 66
+          edit ALADIN_STEP '66'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 69
+          edit ALADIN_STEP '69'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '00:06'
+        limit mutex 1
+        inlimit prod:mutex
+        family hun
+          edit DESTINATION 'HUN'
+          edit ECF_URL 'HUN/ALADIN/1'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family czm
+          edit DESTINATION 'CZM'
+          edit ECF_URL 'CZM/ALADIN/1'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family sli
+          edit DESTINATION 'SLI'
+          edit ECF_URL 'SLI/ALADIN/1'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family aus
+          edit DESTINATION 'AUS'
+          edit ECF_URL 'AUS/ALADIN/1'
+          task ecpds
+            edit ECPDS_OPER 'false'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    family 00bc
+      task clean
+        edit ACCOUNT '%ACCOUNT_LBC%'
+        edit NB_TASKS '%NB_TASKS_LBC%'
+        edit DELTA_DAY '1'
+        edit STREAM 'oper'
+        edit EMOS_BASE '0'
+        inlimit /ealadin/limits:lbc
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/lbc:YMD
+        edit EMOS_BASE '0'
+        task external
+          defstatus complete
+          complete /o/main/00bc/fc eq complete or /o/main/00bc/fc/model:step gt 72
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 06:06
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 42
+          edit ALADIN_STEP '42'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 45
+          edit ALADIN_STEP '45'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 48
+          edit ALADIN_STEP '48'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 51
+          edit ALADIN_STEP '51'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 54
+          edit ALADIN_STEP '54'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 57
+          edit ALADIN_STEP '57'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 60
+          edit ALADIN_STEP '60'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 63
+          edit ALADIN_STEP '63'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 66
+          edit ALADIN_STEP '66'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 69
+          edit ALADIN_STEP '69'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '06:06'
+        limit mutex 1
+        inlimit prod:mutex
+        family hun
+          edit DESTINATION 'HUN'
+          edit ECF_URL 'HUN/ALADIN/0'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family czm
+          edit DESTINATION 'CZM'
+          edit ECF_URL 'CZM/ALADIN/0'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family sli
+          edit DESTINATION 'SLI'
+          edit ECF_URL 'SLI/ALADIN/0'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family aus
+          edit DESTINATION 'AUS'
+          edit ECF_URL 'AUS/ALADIN/0'
+          task ecpds
+            edit ECPDS_OPER 'false'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    family 06bc
+      task clean
+        edit ACCOUNT '%ACCOUNT_LBC%'
+        edit NB_TASKS '%NB_TASKS_LBC%'
+        edit DELTA_DAY '1'
+        edit STREAM 'SCDA'
+        edit EMOS_BASE '0'
+        inlimit /ealadin/limits:lbc
+      family ref
+        defstatus complete
+        complete /o/main:YMD gt /ealadin/lbc:YMD
+        edit EMOS_BASE '0'
+        task external
+          defstatus complete
+          complete /o/main/06bc/fc eq complete or /o/main/06bc/fc/model:step gt 72
+          trigger 0==1
+        family timed
+          complete /ealadin:REAL_TIME eq 0
+          time 12:06
+          task dummy
+            complete 1==1
+        endfamily
+      endfamily
+      family prl
+        trigger ref eq complete
+        family 00
+          edit ALADIN_STEP '00'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 03
+          edit ALADIN_STEP '03'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 06
+          edit ALADIN_STEP '06'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 09
+          edit ALADIN_STEP '09'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 12
+          edit ALADIN_STEP '12'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 15
+          edit ALADIN_STEP '15'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 18
+          edit ALADIN_STEP '18'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 21
+          edit ALADIN_STEP '21'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 24
+          edit ALADIN_STEP '24'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 27
+          edit ALADIN_STEP '27'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 30
+          edit ALADIN_STEP '30'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 33
+          edit ALADIN_STEP '33'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 36
+          edit ALADIN_STEP '36'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 39
+          edit ALADIN_STEP '39'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 42
+          edit ALADIN_STEP '42'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 45
+          edit ALADIN_STEP '45'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 48
+          edit ALADIN_STEP '48'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 51
+          edit ALADIN_STEP '51'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 54
+          edit ALADIN_STEP '54'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 57
+          edit ALADIN_STEP '57'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 60
+          edit ALADIN_STEP '60'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 63
+          edit ALADIN_STEP '63'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 66
+          edit ALADIN_STEP '66'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+        family 69
+          edit ALADIN_STEP '69'
+          task init
+            inlimit /ealadin/limits:init
+          task 901
+            trigger init ==complete
+            edit THREADS '%THREADS_LBC%'
+            meter step -1 72 72
+          task 927
+            trigger ./901==complete
+            edit DOM 'francecep'
+            meter step -1 72 72
+        endfamily
+      endfamily
+      family prod
+        defstatus complete
+        trigger prl eq complete
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit TO_ECFS 'false'
+        edit ECPDS_AT '12:06'
+        limit mutex 1
+        inlimit prod:mutex
+        family hun
+          edit DESTINATION 'HUN'
+          edit ECF_URL 'HUN/ALADIN/0'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family czm
+          edit DESTINATION 'CZM'
+          edit ECF_URL 'CZM/ALADIN/0'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family sli
+          edit DESTINATION 'SLI'
+          edit ECF_URL 'SLI/ALADIN/0'
+          task ecpds
+            label scheduled ""
+        endfamily
+        family aus
+          edit DESTINATION 'AUS'
+          edit ECF_URL 'AUS/ALADIN/0'
+          task ecpds
+            edit ECPDS_OPER 'false'
+            label scheduled ""
+        endfamily
+      endfamily
+    endfamily
+    task logfilestore
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit KEEPLOGS 'no'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
+      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
+      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit ECFOUT '/vol/emos_nc/output'
+    task logfiles
+      trigger ./12bc==complete and ./18bc==complete and ./00bc==complete and ./06bc==complete and ./logfilestore==complete
+      edit MOVE_TO_ECFS 'no'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
+      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
+      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit ECFOUT '/vol/emos_nc/output'
+      edit ACCOUNT 'oesu'
+      time 12:30
+  endfamily
+  family lag
+    repeat date YMD 20100607 20201212 1
+    edit LOGTASK 'lag'
+    family 12
+      task clean
+      task ecpds
+        trigger /ealadin/main/12 eq complete
+        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
+        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit ECPDS_STREAM 'JSN2'
+        edit DESTINATION 'FRA'
+        edit CALL_ECPDS 'false'
+        edit ECPDS_AT '12:06'
+        edit ECPDS_OPER 'false'
+        edit TO_ECFS 'true'
+        edit ECF_URL ' FRA/ALADIN/12'
+        edit TO_ECPDS 'false'
+        edit ACCOUNT '%ACCOUNT_FRA%'
+        edit NB_TASKS '%NB_TASKS_FRA%'
+        edit STREAM 'oper'
+        edit EMOS_BASE '1'
+        inlimit /ealadin/limits:main
+        label scheduled ""
+    endfamily
+    family 18
+      task clean
+      task ecpds
+        trigger /ealadin/main/18 eq complete
+        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
+        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit ECPDS_STREAM 'JSN2'
+        edit DESTINATION 'FRA'
+        edit CALL_ECPDS 'false'
+        edit ECPDS_AT '17:58'
+        edit ECPDS_OPER 'false'
+        edit TO_ECFS 'true'
+        edit ECF_URL ' FRA/ALADIN/18'
+        edit TO_ECPDS 'false'
+        edit ACCOUNT '%ACCOUNT_FRA%'
+        edit NB_TASKS '%NB_TASKS_FRA%'
+        edit STREAM 'scda'
+        edit EMOS_BASE '1'
+        inlimit /ealadin/limits:main
+        label scheduled ""
+    endfamily
+    family 00
+      task clean
+      task ecpds
+        trigger /ealadin/main/00 eq complete
+        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
+        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit ECPDS_STREAM 'JSN2'
+        edit DESTINATION 'FRA'
+        edit CALL_ECPDS 'false'
+        edit ECPDS_AT '00:00'
+        edit ECPDS_OPER 'false'
+        edit TO_ECFS 'true'
+        edit ECF_URL ' FRA/ALADIN/00'
+        edit TO_ECPDS 'false'
+        edit ACCOUNT '%ACCOUNT_FRA%'
+        edit NB_TASKS '%NB_TASKS_FRA%'
+        edit DELTA_DAY '1'
+        edit STREAM 'oper'
+        edit EMOS_BASE '0'
+        inlimit /ealadin/limits:main
+        label scheduled ""
+    endfamily
+    family 06
+      task clean
+      task ecpds
+        trigger /ealadin/main/06 eq complete
+        trigger -a /ealadin/main:YMD eq /ealadin/lag:YMD
+        trigger -a /ealadin/main:YMD gt /ealadin/lag:YMD
+        edit ECF_URLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+        edit ECPDS_STREAM 'JSN2'
+        edit DESTINATION 'FRA'
+        edit CALL_ECPDS 'false'
+        edit ECPDS_AT '06:01'
+        edit ECPDS_OPER 'false'
+        edit TO_ECFS 'true'
+        edit ECF_URL ' FRA/ALADIN/06'
+        edit TO_ECPDS 'false'
+        edit ACCOUNT '%ACCOUNT_FRA%'
+        edit NB_TASKS '%NB_TASKS_FRA%'
+        edit DELTA_DAY '1'
+        edit STREAM 'scda'
+        edit EMOS_BASE '0'
+        inlimit /ealadin/limits:main
+        label scheduled ""
+    endfamily
+    task logfilestore
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit KEEPLOGS 'no'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
+      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
+      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit ECFOUT '/vol/emos_nc/output'
+    task logfiles
+      trigger ./12==complete and ./18==complete and ./00==complete and ./06==complete and ./logfilestore==complete
+      edit MOVE_TO_ECFS 'no'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit ECFCMD 'smssubmit %USER% %WSHOST% %ECFJOB% %ECFJOBOUT%'
+      edit ECFKILL 'smskill %USER% %WSHOST% %ECFRID% %ECFJOB% %ECFJOBOUT%'
+      edit ECFSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %ECFRID% %ECFJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit ECFOUT '/vol/emos_nc/output'
+      edit ACCOUNT 'oesu'
+      time 12:30
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/error.def 5.13.0-1/libs/node/test/parser/data/single_defs/error.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/error.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/error.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,284 @@
+
+suite ecflow_1182
+ repeat day 1
+ family hc00
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc01
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc02
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+ family hc03
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc04
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc05
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+ family hc06
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc07
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc08
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc09
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc10
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc11
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc12
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc13
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc14
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc15
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc16
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc17
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc18
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc19
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc20
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc21
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc22
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc23
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc24
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc25
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc26
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+   family hc27
+   defstatus queued
+   repeat integer HYEAR 1993 2015 1
+   time +00:01
+   task uk2fdb
+      defstatus queued
+   task extrafields_uk
+      defstatus complete
+      trigger uk2fdb==complete
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/mega.def 5.13.0-1/libs/node/test/parser/data/single_defs/mega.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/mega.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/mega.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,194064 @@
+# 4.0.6
+extern /e_36r1/main/00/an
+extern /e_36r1/main/00/an/4dvar
+extern /e_36r1/main/00/an/4dvar/ifstraj:finalwave
+extern /e_36r1/main/00/an/4dvar/uptraj_0
+extern /e_36r1/main/00/an/surf_anal/slwet
+extern /e_36r1/main/00/an/surf_anal/sst
+extern /e_36r1/main/00/fc/model
+extern /e_36r1/main/00/getreq
+extern /e_36r1/main/00/obs/get/get_stor
+extern /e_36r1/main/00/prod/240/prod_wparam
+extern /e_36r1/main/00dc/fc/model
+extern /e_36r1/main/00dc/fc/model:step
+extern /e_36r1/main/12/an
+extern /e_36r1/main/12/an/4dvar
+extern /e_36r1/main/12/an/4dvar/ifstraj:finalwave
+extern /e_36r1/main/12/an/4dvar/uptraj_0
+extern /e_36r1/main/12/an/surf_anal/slwet
+extern /e_36r1/main/12/an/surf_anal/sst
+extern /e_36r1/main/12/fc/model
+extern /e_36r1/main/12/getreq
+extern /e_36r1/main/12/obs/get/get_stor
+extern /e_36r1/main/12/prod/240/prod_wparam
+extern /e_36r1/main/12dc/fc/model
+extern /e_36r1/main/12dc/fc/model:step
+extern /e_36r1/main:YMD
+extern /ecgems/f93i/an/lag/00/archive
+extern /ecgems/f93i/an/lag:YMD
+extern /emc_36r1/main/00/legB/prod
+extern /emc_36r1/main/12/legB/prod
+extern /limits:c1a
+extern /limits:c1b
+extern /limits:hpce
+extern /limits:hpcf
+extern /limits:linux_cluster
+extern /limits:mars
+extern /limits:obs_get
+extern /limits:pdb
+extern /limits:pdb_bc
+extern /limits:prod
+extern /limits:q2diss
+extern /limits:q2diss_bc
+extern /limits:swarm
+extern /mc/main/00
+extern /mc/main/00/legA/fc
+extern /mc/main/00/legB/fc
+extern /mc/main/00/legB/postproc
+extern /mc/main/12/legA/fc
+extern /mc/main/12/legB/fc
+extern /mc/main/12/legB/postproc
+extern /mc/main:YMD
+extern /o/lag/00/archive/anml
+extern /o/lag/00/archive/anpl
+extern /o/lag/00/archive/ansfc
+extern /o/lag/00/archive/fc048
+extern /o/lag/00/archive/fc240
+extern /o/lag/00/archive/obs
+extern /o/lag/00/archive/sst
+extern /o/lag/00/fb/feedback/matchup
+extern /o/lag/00/satim
+extern /o/lag/00/verif
+extern /o/lag/00dc/archive
+extern /o/lag/00dc/fb/feedback/matchup
+extern /o/lag/06/archive
+extern /o/lag/06/fb/feedback/matchup
+extern /o/lag/06bc/archive
+extern /o/lag/06bc/fb/feedback/matchup
+extern /o/lag/12/archive/fc240
+extern /o/lag/12/archive/obs
+extern /o/lag/12/fb/feedback/matchup
+extern /o/lag/12/satim
+extern /o/lag/12/verif
+extern /o/lag/12dc/archive
+extern /o/lag/12dc/fb/feedback/matchup
+extern /o/lag/18/archive
+extern /o/lag/18/fb/feedback/matchup
+extern /o/lag/18bc/archive
+extern /o/lag/18bc/fb/feedback/matchup
+extern /o/lag:YMD
+extern /o/main/00/an
+extern /o/main/00/an/4dvar
+extern /o/main/00/an/surf_anal
+extern /o/main/00/fc
+extern /o/main/00/fc/clean
+extern /o/main/00/fc/model
+extern /o/main/00/fc/model:step
+extern /o/main/00/prod/18an/derived_param
+extern /o/main/00/prod2diss/oper
+extern /o/main/00/prod2diss/sched/240
+extern /o/main/00/prod2diss/wave
+extern /o/main/00dc/an/4dvar
+extern /o/main/00dc/an/surf_anal
+extern /o/main/00dc/fc/clean
+extern /o/main/00dc/fc/model
+extern /o/main/06bc/an/4dvar
+extern /o/main/06bc/an/surf_anal
+extern /o/main/06bc/fc/model
+extern /o/main/06bc/prod2diss/oper
+extern /o/main/06bc/prod2diss/sched/72
+extern /o/main/12/an
+extern /o/main/12/an/4dvar
+extern /o/main/12/an/surf_anal
+extern /o/main/12/fc
+extern /o/main/12/fc/model
+extern /o/main/12/fc/model:step
+extern /o/main/12/obs/get/get_stor
+extern /o/main/12/prod/06an/derived_param
+extern /o/main/12/prod2diss/oper
+extern /o/main/12/prod2diss/sched/240
+extern /o/main/12/prod2diss/wave
+extern /o/main/12dc/an/4dvar
+extern /o/main/12dc/an/surf_anal
+extern /o/main/12dc/fc/model
+extern /o/main/12dc/obs/get/get_stor
+extern /o/main/18bc/an/4dvar
+extern /o/main/18bc/an/surf_anal
+extern /o/main/18bc/fc/model
+extern /o/main/18bc/prod2diss/oper
+extern /o/main/18bc/prod2diss/sched/72
+extern /o/main:YMD
+extern /pp1/main/extractions/dc00/airs
+extern /pp1/main/extractions/dc00/amsr
+extern /pp1/main/extractions/dc00/atap
+extern /pp1/main/extractions/dc00/ateu
+extern /pp1/main/extractions/dc00/atov
+extern /pp1/main/extractions/dc00/bice
+extern /pp1/main/extractions/dc00/eas1
+extern /pp1/main/extractions/dc00/emer
+extern /pp1/main/extractions/dc00/ers1_ra
+extern /pp1/main/extractions/dc00/ers1_wa
+extern /pp1/main/extractions/dc00/ers1_wi
+extern /pp1/main/extractions/dc00/grad
+extern /pp1/main/extractions/dc00/grst
+extern /pp1/main/extractions/dc00/ice/ice_fdb_c1b
+extern /pp1/main/extractions/dc00/nonbin
+extern /pp1/main/extractions/dc00/qsca
+extern /pp1/main/extractions/dc00/rado
+extern /pp1/main/extractions/dc00/rtovs
+extern /pp1/main/extractions/dc00/sbuv
+extern /pp1/main/extractions/dc00/smin
+extern /pp1/main/extractions/dc00/snow
+extern /pp1/main/extractions/dc00/ssbt
+extern /pp1/main/extractions/dc00/sst/sst_fdb_c1b
+extern /pp1/main/extractions/dc00/stor
+extern /pp1/main/extractions/dc00/trmm
+extern /pp1/main/extractions/dc06/airs
+extern /pp1/main/extractions/dc06/amsr
+extern /pp1/main/extractions/dc06/atap
+extern /pp1/main/extractions/dc06/ateu
+extern /pp1/main/extractions/dc06/atov
+extern /pp1/main/extractions/dc06/bice
+extern /pp1/main/extractions/dc06/eas1
+extern /pp1/main/extractions/dc06/emer
+extern /pp1/main/extractions/dc06/ers1_ra
+extern /pp1/main/extractions/dc06/ers1_wa
+extern /pp1/main/extractions/dc06/ers1_wi
+extern /pp1/main/extractions/dc06/grad
+extern /pp1/main/extractions/dc06/grst
+extern /pp1/main/extractions/dc06/ice/ice_fdb_c1b
+extern /pp1/main/extractions/dc06/nonbin
+extern /pp1/main/extractions/dc06/qsca
+extern /pp1/main/extractions/dc06/rado
+extern /pp1/main/extractions/dc06/rtovs
+extern /pp1/main/extractions/dc06/sbuv
+extern /pp1/main/extractions/dc06/smin
+extern /pp1/main/extractions/dc06/snow
+extern /pp1/main/extractions/dc06/ssbt
+extern /pp1/main/extractions/dc06/sst/sst_fdb_c1b
+extern /pp1/main/extractions/dc06/stor
+extern /pp1/main/extractions/dc06/trmm
+extern /pp1/main/extractions/dc12/airs
+extern /pp1/main/extractions/dc12/amsr
+extern /pp1/main/extractions/dc12/atap
+extern /pp1/main/extractions/dc12/ateu
+extern /pp1/main/extractions/dc12/atov
+extern /pp1/main/extractions/dc12/bice
+extern /pp1/main/extractions/dc12/eas1
+extern /pp1/main/extractions/dc12/emer
+extern /pp1/main/extractions/dc12/ers1_ra
+extern /pp1/main/extractions/dc12/ers1_wa
+extern /pp1/main/extractions/dc12/ers1_wi
+extern /pp1/main/extractions/dc12/grad
+extern /pp1/main/extractions/dc12/grst
+extern /pp1/main/extractions/dc12/ice/ice_fdb_c1b
+extern /pp1/main/extractions/dc12/nonbin
+extern /pp1/main/extractions/dc12/qsca
+extern /pp1/main/extractions/dc12/rado
+extern /pp1/main/extractions/dc12/rtovs
+extern /pp1/main/extractions/dc12/sbuv
+extern /pp1/main/extractions/dc12/smin
+extern /pp1/main/extractions/dc12/snow
+extern /pp1/main/extractions/dc12/ssbt
+extern /pp1/main/extractions/dc12/sst/sst_fdb_c1b
+extern /pp1/main/extractions/dc12/stor
+extern /pp1/main/extractions/dc12/trmm
+extern /pp1/main/extractions/dc18/airs
+extern /pp1/main/extractions/dc18/amsr
+extern /pp1/main/extractions/dc18/atap
+extern /pp1/main/extractions/dc18/ateu
+extern /pp1/main/extractions/dc18/atov
+extern /pp1/main/extractions/dc18/bice
+extern /pp1/main/extractions/dc18/eas1
+extern /pp1/main/extractions/dc18/emer
+extern /pp1/main/extractions/dc18/ers1_ra
+extern /pp1/main/extractions/dc18/ers1_wa
+extern /pp1/main/extractions/dc18/ers1_wi
+extern /pp1/main/extractions/dc18/grad
+extern /pp1/main/extractions/dc18/grst
+extern /pp1/main/extractions/dc18/ice/ice_fdb_c1b
+extern /pp1/main/extractions/dc18/nonbin
+extern /pp1/main/extractions/dc18/qsca
+extern /pp1/main/extractions/dc18/rado
+extern /pp1/main/extractions/dc18/rtovs
+extern /pp1/main/extractions/dc18/sbuv
+extern /pp1/main/extractions/dc18/smin
+extern /pp1/main/extractions/dc18/snow
+extern /pp1/main/extractions/dc18/ssbt
+extern /pp1/main/extractions/dc18/sst/sst_fdb_c1b
+extern /pp1/main/extractions/dc18/stor
+extern /pp1/main/extractions/dc18/trmm
+extern /pp1/main/extractions/ex00/airs
+extern /pp1/main/extractions/ex00/amsr
+extern /pp1/main/extractions/ex00/atap
+extern /pp1/main/extractions/ex00/ateu
+extern /pp1/main/extractions/ex00/atov
+extern /pp1/main/extractions/ex00/bice
+extern /pp1/main/extractions/ex00/eas1
+extern /pp1/main/extractions/ex00/emer
+extern /pp1/main/extractions/ex00/ers1_ra
+extern /pp1/main/extractions/ex00/ers1_wa
+extern /pp1/main/extractions/ex00/ers1_wi
+extern /pp1/main/extractions/ex00/grad
+extern /pp1/main/extractions/ex00/grst
+extern /pp1/main/extractions/ex00/ice/ice_fdb_c1b
+extern /pp1/main/extractions/ex00/nonbin
+extern /pp1/main/extractions/ex00/qsca
+extern /pp1/main/extractions/ex00/rado
+extern /pp1/main/extractions/ex00/rtovs
+extern /pp1/main/extractions/ex00/sbuv
+extern /pp1/main/extractions/ex00/smin
+extern /pp1/main/extractions/ex00/snow
+extern /pp1/main/extractions/ex00/ssbt
+extern /pp1/main/extractions/ex00/sst/sst_fdb_c1b
+extern /pp1/main/extractions/ex00/stor
+extern /pp1/main/extractions/ex00/trmm
+extern /pp1/main/extractions/ex06/airs
+extern /pp1/main/extractions/ex06/amsr
+extern /pp1/main/extractions/ex06/atap
+extern /pp1/main/extractions/ex06/ateu
+extern /pp1/main/extractions/ex06/atov
+extern /pp1/main/extractions/ex06/bice
+extern /pp1/main/extractions/ex06/eas1
+extern /pp1/main/extractions/ex06/emer
+extern /pp1/main/extractions/ex06/ers1_ra
+extern /pp1/main/extractions/ex06/ers1_wa
+extern /pp1/main/extractions/ex06/ers1_wi
+extern /pp1/main/extractions/ex06/grad
+extern /pp1/main/extractions/ex06/grst
+extern /pp1/main/extractions/ex06/ice/ice_fdb_c1b
+extern /pp1/main/extractions/ex06/nonbin
+extern /pp1/main/extractions/ex06/qsca
+extern /pp1/main/extractions/ex06/rado
+extern /pp1/main/extractions/ex06/rtovs
+extern /pp1/main/extractions/ex06/sbuv
+extern /pp1/main/extractions/ex06/smin
+extern /pp1/main/extractions/ex06/snow
+extern /pp1/main/extractions/ex06/ssbt
+extern /pp1/main/extractions/ex06/sst/sst_fdb_c1b
+extern /pp1/main/extractions/ex06/stor
+extern /pp1/main/extractions/ex06/trmm
+extern /pp1/main/extractions/ex12/airs
+extern /pp1/main/extractions/ex12/amsr
+extern /pp1/main/extractions/ex12/atap
+extern /pp1/main/extractions/ex12/ateu
+extern /pp1/main/extractions/ex12/atov
+extern /pp1/main/extractions/ex12/bice
+extern /pp1/main/extractions/ex12/eas1
+extern /pp1/main/extractions/ex12/emer
+extern /pp1/main/extractions/ex12/ers1_ra
+extern /pp1/main/extractions/ex12/ers1_wa
+extern /pp1/main/extractions/ex12/ers1_wi
+extern /pp1/main/extractions/ex12/grad
+extern /pp1/main/extractions/ex12/grst
+extern /pp1/main/extractions/ex12/ice/ice_fdb_c1b
+extern /pp1/main/extractions/ex12/nonbin
+extern /pp1/main/extractions/ex12/qsca
+extern /pp1/main/extractions/ex12/rado
+extern /pp1/main/extractions/ex12/rtovs
+extern /pp1/main/extractions/ex12/sbuv
+extern /pp1/main/extractions/ex12/smin
+extern /pp1/main/extractions/ex12/snow
+extern /pp1/main/extractions/ex12/ssbt
+extern /pp1/main/extractions/ex12/sst/sst_fdb_c1b
+extern /pp1/main/extractions/ex12/stor
+extern /pp1/main/extractions/ex12/trmm
+extern /pp1/main/extractions/ex18/airs
+extern /pp1/main/extractions/ex18/amsr
+extern /pp1/main/extractions/ex18/atap
+extern /pp1/main/extractions/ex18/ateu
+extern /pp1/main/extractions/ex18/atov
+extern /pp1/main/extractions/ex18/bice
+extern /pp1/main/extractions/ex18/eas1
+extern /pp1/main/extractions/ex18/emer
+extern /pp1/main/extractions/ex18/ers1_ra
+extern /pp1/main/extractions/ex18/ers1_wa
+extern /pp1/main/extractions/ex18/ers1_wi
+extern /pp1/main/extractions/ex18/grad
+extern /pp1/main/extractions/ex18/grst
+extern /pp1/main/extractions/ex18/ice/ice_fdb_c1b
+extern /pp1/main/extractions/ex18/nonbin
+extern /pp1/main/extractions/ex18/qsca
+extern /pp1/main/extractions/ex18/rado
+extern /pp1/main/extractions/ex18/rtovs
+extern /pp1/main/extractions/ex18/sbuv
+extern /pp1/main/extractions/ex18/smin
+extern /pp1/main/extractions/ex18/snow
+extern /pp1/main/extractions/ex18/ssbt
+extern /pp1/main/extractions/ex18/sst/sst_fdb_c1b
+extern /pp1/main/extractions/ex18/stor
+extern /pp1/main/extractions/ex18/trmm
+extern /pp1/main/extractions/ma
+extern /pp2/main/extractions/dc00/amsa
+extern /pp2/main/extractions/dc00/asc2
+extern /pp2/main/extractions/dc00/ascs
+extern /pp2/main/extractions/dc00/asel
+extern /pp2/main/extractions/dc00/avhn
+extern /pp2/main/extractions/dc00/g2to
+extern /pp2/main/extractions/dc00/gras
+extern /pp2/main/extractions/dc00/hirs
+extern /pp2/main/extractions/dc00/iasi
+extern /pp2/main/extractions/dc00/j2eo
+extern /pp2/main/extractions/dc00/j2nb
+extern /pp2/main/extractions/dc00/mhsa
+extern /pp2/main/extractions/dc00/modw
+extern /pp2/main/extractions/dc06/amsa
+extern /pp2/main/extractions/dc06/asc2
+extern /pp2/main/extractions/dc06/ascs
+extern /pp2/main/extractions/dc06/asel
+extern /pp2/main/extractions/dc06/avhn
+extern /pp2/main/extractions/dc06/g2to
+extern /pp2/main/extractions/dc06/gras
+extern /pp2/main/extractions/dc06/hirs
+extern /pp2/main/extractions/dc06/iasi
+extern /pp2/main/extractions/dc06/j2eo
+extern /pp2/main/extractions/dc06/j2nb
+extern /pp2/main/extractions/dc06/mhsa
+extern /pp2/main/extractions/dc06/modw
+extern /pp2/main/extractions/dc12/amsa
+extern /pp2/main/extractions/dc12/asc2
+extern /pp2/main/extractions/dc12/ascs
+extern /pp2/main/extractions/dc12/asel
+extern /pp2/main/extractions/dc12/avhn
+extern /pp2/main/extractions/dc12/g2to
+extern /pp2/main/extractions/dc12/gras
+extern /pp2/main/extractions/dc12/hirs
+extern /pp2/main/extractions/dc12/iasi
+extern /pp2/main/extractions/dc12/j2eo
+extern /pp2/main/extractions/dc12/j2nb
+extern /pp2/main/extractions/dc12/mhsa
+extern /pp2/main/extractions/dc12/modw
+extern /pp2/main/extractions/dc18/amsa
+extern /pp2/main/extractions/dc18/asc2
+extern /pp2/main/extractions/dc18/ascs
+extern /pp2/main/extractions/dc18/asel
+extern /pp2/main/extractions/dc18/avhn
+extern /pp2/main/extractions/dc18/g2to
+extern /pp2/main/extractions/dc18/gras
+extern /pp2/main/extractions/dc18/hirs
+extern /pp2/main/extractions/dc18/iasi
+extern /pp2/main/extractions/dc18/j2eo
+extern /pp2/main/extractions/dc18/j2nb
+extern /pp2/main/extractions/dc18/mhsa
+extern /pp2/main/extractions/dc18/modw
+extern /pp2/main/extractions/ex00/amsa
+extern /pp2/main/extractions/ex00/asc2
+extern /pp2/main/extractions/ex00/ascs
+extern /pp2/main/extractions/ex00/asel
+extern /pp2/main/extractions/ex00/avhn
+extern /pp2/main/extractions/ex00/g2to
+extern /pp2/main/extractions/ex00/gras
+extern /pp2/main/extractions/ex00/hirs
+extern /pp2/main/extractions/ex00/iasi
+extern /pp2/main/extractions/ex00/j2eo
+extern /pp2/main/extractions/ex00/j2nb
+extern /pp2/main/extractions/ex00/mhsa
+extern /pp2/main/extractions/ex00/modw
+extern /pp2/main/extractions/ex06/amsa
+extern /pp2/main/extractions/ex06/asc2
+extern /pp2/main/extractions/ex06/ascs
+extern /pp2/main/extractions/ex06/asel
+extern /pp2/main/extractions/ex06/avhn
+extern /pp2/main/extractions/ex06/g2to
+extern /pp2/main/extractions/ex06/gras
+extern /pp2/main/extractions/ex06/hirs
+extern /pp2/main/extractions/ex06/iasi
+extern /pp2/main/extractions/ex06/j2eo
+extern /pp2/main/extractions/ex06/j2nb
+extern /pp2/main/extractions/ex06/mhsa
+extern /pp2/main/extractions/ex06/modw
+extern /pp2/main/extractions/ex12/amsa
+extern /pp2/main/extractions/ex12/asc2
+extern /pp2/main/extractions/ex12/ascs
+extern /pp2/main/extractions/ex12/asel
+extern /pp2/main/extractions/ex12/avhn
+extern /pp2/main/extractions/ex12/g2to
+extern /pp2/main/extractions/ex12/gras
+extern /pp2/main/extractions/ex12/hirs
+extern /pp2/main/extractions/ex12/iasi
+extern /pp2/main/extractions/ex12/j2eo
+extern /pp2/main/extractions/ex12/j2nb
+extern /pp2/main/extractions/ex12/mhsa
+extern /pp2/main/extractions/ex12/modw
+extern /pp2/main/extractions/ex18/amsa
+extern /pp2/main/extractions/ex18/asc2
+extern /pp2/main/extractions/ex18/ascs
+extern /pp2/main/extractions/ex18/asel
+extern /pp2/main/extractions/ex18/avhn
+extern /pp2/main/extractions/ex18/g2to
+extern /pp2/main/extractions/ex18/gras
+extern /pp2/main/extractions/ex18/hirs
+extern /pp2/main/extractions/ex18/iasi
+extern /pp2/main/extractions/ex18/j2eo
+extern /pp2/main/extractions/ex18/j2nb
+extern /pp2/main/extractions/ex18/mhsa
+extern /pp2/main/extractions/ex18/modw
+suite limits
+  defstatus complete
+  edit SLEEPTIME '1'
+  limit mars 16
+  limit ha_pp 10
+  limit ha_pp2 10
+  limit swarm 40
+  limit linux_cluster 40
+  limit obs_get 20
+  limit hpcf 150
+  limit c1a 150
+  limit c1b 150
+  limit prod 25
+  limit prod2diss 6
+  limit prod2ecpds 6
+  limit pdb 10
+  limit q2diss 10
+  limit pdb_bc 6
+  limit q2diss_bc 6
+  clock hybrid 
+endsuite
+suite pp1
+  edit ECF_DATE '20080711'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family main
+    edit YMD '20100114'
+    family extractions
+      family ex00
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task buoy
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task smiu
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task cmwn
+        task ap19
+      endfamily
+      family ex06
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task mtsat
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task smiu
+        task cmwn
+        task ap19
+      endfamily
+      family ex12
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task mtsat
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task smiu
+        task cmwn
+        task ap19
+      endfamily
+      family ex18
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task mtsat
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task smiu
+        task cmwn
+        task ap19
+      endfamily
+      family dc00
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task mtsat
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task smiu
+        task cmwn
+        task ap19
+      endfamily
+      family dc06
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task mtsat
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task smiu
+        task cmwn
+        task ap19
+      endfamily
+      family dc12
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task mtsat
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task smiu
+        task cmwn
+        task ap19
+      endfamily
+      family dc18
+        task nonbin
+        task airs
+        task amsr
+        task at18
+        task at19
+        task atap
+        task ateu
+        task atov
+        task avhr
+        task bice
+        task bssh
+        task btem
+        task cmwi
+        task csrj
+        task eas1
+        task eas2
+        task emer
+        task erad
+        task ers1_at
+        task ers1_ra
+        task ers1_wa
+        task ers1_wi
+        task esck
+        task goes
+        task gomw
+        task grad
+        task grst
+        family ice
+          task ice_ex
+          task ice_fdb_hpcf
+          task ice_fdb_c1a
+          task ice_fdb_c1b
+        endfamily
+        task jaso
+        task masr
+        family metop_a
+          task amsa
+          task asca
+          task hirs
+          task iasi
+          task mhsa
+        endfamily
+        task mtsat
+        task nomi
+        task qsca
+        task rado
+        task rtovs
+        task sb19
+        task sbuv
+        task smin
+        task smis
+        task snow
+        task ssbt
+        family sst
+          task sst_ex
+          task sst_fdb_hpcf
+          task sst_fdb_c1a
+          task sst_fdb_c1b
+        endfamily
+        task stor
+        task tozo
+        task trmm
+        task trmr
+        task wavb
+        task smiu
+        task cmwn
+        task ap19
+      endfamily
+      family ma
+        family egrr
+          task extract
+          task fdb_c1a
+          task fdb_c1b
+          task fdb_hpcf
+        endfamily
+        family edzw
+          task extract
+          task fdb_c1a
+          task fdb_c1b
+          task fdb_hpcf
+        endfamily
+        family lfpw
+          task extract
+          task fdb_c1a
+          task fdb_c1b
+          task fdb_hpcf
+        endfamily
+        family kwbc
+          task extract
+          task fdb_c1a
+          task fdb_c1b
+          task fdb_hpcf
+        endfamily
+      endfamily
+    endfamily
+  endfamily
+endsuite
+suite o
+  edit SMSFILES '/home/ma/emos/def/sync'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family main
+    edit YMD '20100114'
+    family 00
+      family an
+        task 4dvar
+        task surf_anal
+      endfamily
+      family prod
+        family 18an
+          task derived_param
+        endfamily
+      endfamily
+      family prod2diss
+        task oper
+        task wave
+        family sched
+          task 240
+        endfamily
+      endfamily
+      family fc
+        task model
+        task clean
+      endfamily
+    endfamily
+    family 12
+      family an
+        task 4dvar
+        task surf_anal
+      endfamily
+      family prod
+        family 06an
+          task derived_param
+        endfamily
+      endfamily
+      family prod2diss
+        task oper
+        task wave
+        family sched
+          task 240
+        endfamily
+      endfamily
+      family fc
+        task model
+      endfamily
+      family obs
+        family get
+          task get_stor
+        endfamily
+      endfamily
+    endfamily
+    family 00dc
+      family an
+        task 4dvar
+        task surf_anal
+      endfamily
+      family fc
+        task model
+        task clean
+      endfamily
+    endfamily
+    family 12dc
+      family an
+        task 4dvar
+        task surf_anal
+      endfamily
+      family fc
+        task model
+      endfamily
+      family obs
+        family get
+          task get_stor
+        endfamily
+      endfamily
+    endfamily
+    family 06bc
+      family an
+        task 4dvar
+        task surf_anal
+      endfamily
+      family prod2diss
+        task oper
+        family sched
+          task 72
+        endfamily
+      endfamily
+      family fc
+        task model
+      endfamily
+    endfamily
+    family 18bc
+      family an
+        task 4dvar
+        task surf_anal
+      endfamily
+      family prod2diss
+        task oper
+        family sched
+          task 72
+        endfamily
+      endfamily
+      family fc
+        task model
+      endfamily
+    endfamily
+  endfamily
+  family lag
+    edit YMD '20100114'
+    family 00dc
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task archive
+    endfamily
+    family 06
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task archive
+    endfamily
+    family 12
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task satim
+      task verif
+      family archive
+        task obs
+        task fc240
+      endfamily
+    endfamily
+    family 12dc
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task archive
+    endfamily
+    family 18
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task archive
+    endfamily
+    family 00
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task satim
+      task verif
+      family archive
+        task obs
+        task anml
+        task anpl
+        task ansfc
+        task sst
+        task fc048
+        task fc240
+      endfamily
+    endfamily
+    family 18bc
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task archive
+    endfamily
+    family 06bc
+      family fb
+        family feedback
+          task matchup
+        endfamily
+      endfamily
+      task archive
+    endfamily
+  endfamily
+endsuite
+suite pp2
+  edit ECF_DATE '20091117'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family main
+    edit YMD '20100114'
+    family extractions
+      family ex00
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+      family ex06
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+      family ex12
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+      family ex18
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+      family dc00
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+      family dc06
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+      family dc12
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+      family dc18
+        task amsa
+        task amse
+        task asc2
+        task asca
+        task ascs
+        task asch
+        task aseh
+        task asel
+        task ashs
+        task avhn
+        task cori
+        task earn
+        task emsg
+        task er19
+        task g2to
+        task gras
+        task hirs
+        task iasi
+        task ias1
+        task ias2
+        task ias3
+        task ias4
+        task itwt
+        task j2eo
+        task j2nb
+        task mhsa
+        task mhse
+        task mloz
+        task modw
+      endfamily
+    endfamily
+  endfamily
+endsuite
+suite pp3
+  edit ECF_DATE '20121212'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family limits
+  endfamily
+  family first
+    task log
+      event tar
+    task clean
+    task clean_stat
+    task clean_err_db
+    task pp_src
+    task chktasks
+  endfamily
+  family meb
+    task restore
+    task clean
+    task stat
+    task feed
+  endfamily
+  family reb
+    task restore
+    task clean
+      event deqc
+    task stat
+  endfamily
+  family bkup
+    family meb
+      task strhandle
+      task MAER
+    endfamily
+    family reb
+      task strhandle
+      task MAER
+    endfamily
+  endfamily
+  family deqc
+    task MAER
+  endfamily
+  family ex00
+    task maer
+      event 1 
+  endfamily
+  family ex06
+    task maer
+      event 1 
+  endfamily
+  family ex12
+    task maer
+      event 1 
+  endfamily
+  family ex18
+    task maer
+      event 1 
+  endfamily
+  family dc00
+    task maer
+      event 1 
+  endfamily
+  family dc06
+    task maer
+      event 1 
+  endfamily
+  family dc12
+    task maer
+      event 1 
+  endfamily
+  family dc18
+    task maer
+      event 1 
+  endfamily
+  family last
+    task stop
+    task chksuite
+  endfamily
+endsuite
+suite mc
+  edit SMSFILES '/home/ma/emos/def/sync'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family main
+    edit YMD '20100114'
+    family 00
+      family sv
+        task svsh
+        task svnh
+        task sv1
+        task sv2
+        task sv3
+        task sv4
+        task sv5
+        task sv6
+      endfamily
+      family legA
+        family fc
+          task pert_ic
+          task pf
+          task cf
+        endfamily
+        task postproc
+      endfamily
+      family legB
+        task postproc
+      endfamily
+    endfamily
+    family 12
+      family legA
+        family fc
+          task pf
+          task cf
+        endfamily
+        task postproc
+      endfamily
+      family legB
+        task postproc
+      endfamily
+    endfamily
+  endfamily
+endsuite
+suite esync
+  edit USER 'emos'
+  edit QUEUE 'emos-exp'
+  edit ACCOUNT 'oosu'
+  edit WSHOST 'localhost'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+  edit SMSOUT '/vol/emos/output'
+  edit LOGDIR '/vol/emos/output'
+  edit SMSHOME '/vol/emos/output'
+  edit SMSFILES '/home/ma/emos/def/esync'
+  edit SMSINCLUDE '/home/ma/emos/def/esync/include'
+  edit SMSTRIES '1'
+  edit SYNC_HOSTS 'marhaus percard marhaus percard ibis'
+  edit SYNC_PORTS ' 314122 314111 314288 314155 314159 314159'
+  edit SYNC_SUITES 'o pp1'
+  edit SLEEPTIME '1'
+  inlimit /esync/limits:sync
+  clock hybrid 
+  family limits
+    limit sync 3
+  endfamily
+  family o
+    family o
+      edit SMSFILES '/home/ma/emos/def/sync'
+      family main
+        edit YMD '20100114'
+        family 00
+          family an
+            family 4dvar
+              task sync
+                trigger /o/main/00/an/4dvar eq complete
+                edit SYNC_NODE '/o/main/00/an/4dvar'
+            endfamily
+            family surf_anal
+              task sync
+                trigger /o/main/00/an/surf_anal eq complete
+                edit SYNC_NODE '/o/main/00/an/surf_anal'
+            endfamily
+          endfamily
+          family prod
+            family 18an
+              family derived_param
+                task sync
+                  trigger /o/main/00/prod/18an/derived_param eq complete
+                  edit SYNC_NODE '/o/main/00/prod/18an/derived_param'
+              endfamily
+            endfamily
+          endfamily
+          family prod2diss
+            family oper
+              task sync
+                trigger /o/main/00/prod2diss/oper eq complete
+                edit SYNC_NODE '/o/main/00/prod2diss/oper'
+            endfamily
+            family wave
+              task sync
+                trigger /o/main/00/prod2diss/wave eq complete
+                edit SYNC_NODE '/o/main/00/prod2diss/wave'
+            endfamily
+            family sched
+              family 240
+                task sync
+                  trigger /o/main/00/prod2diss/sched/240 eq complete
+                  edit SYNC_NODE '/o/main/00/prod2diss/sched/240'
+              endfamily
+            endfamily
+          endfamily
+          family fc
+            family model
+              task sync
+                trigger /o/main/00/fc/model eq complete
+                edit SYNC_NODE '/o/main/00/fc/model'
+            endfamily
+            family clean
+              task sync
+                trigger /o/main/00/fc/clean eq complete
+                edit SYNC_NODE '/o/main/00/fc/clean'
+            endfamily
+          endfamily
+        endfamily
+        family 12
+          family an
+            family 4dvar
+              task sync
+                trigger /o/main/12/an/4dvar eq complete
+                edit SYNC_NODE '/o/main/12/an/4dvar'
+            endfamily
+            family surf_anal
+              task sync
+                trigger /o/main/12/an/surf_anal eq complete
+                edit SYNC_NODE '/o/main/12/an/surf_anal'
+            endfamily
+          endfamily
+          family prod
+            family 06an
+              family derived_param
+                task sync
+                  trigger /o/main/12/prod/06an/derived_param eq complete
+                  edit SYNC_NODE '/o/main/12/prod/06an/derived_param'
+              endfamily
+            endfamily
+          endfamily
+          family prod2diss
+            family oper
+              task sync
+                trigger /o/main/12/prod2diss/oper eq complete
+                edit SYNC_NODE '/o/main/12/prod2diss/oper'
+            endfamily
+            family wave
+              task sync
+                trigger /o/main/12/prod2diss/wave eq complete
+                edit SYNC_NODE '/o/main/12/prod2diss/wave'
+            endfamily
+            family sched
+              family 240
+                task sync
+                  trigger /o/main/12/prod2diss/sched/240 eq complete
+                  edit SYNC_NODE '/o/main/12/prod2diss/sched/240'
+              endfamily
+            endfamily
+          endfamily
+          family fc
+            family model
+              task sync
+                trigger /o/main/12/fc/model eq complete
+                edit SYNC_NODE '/o/main/12/fc/model'
+            endfamily
+          endfamily
+          family obs
+            family get
+              family get_stor
+                task sync
+                  trigger /o/main/12/obs/get/get_stor eq complete
+                  edit SYNC_NODE '/o/main/12/obs/get/get_stor'
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family 00dc
+          family an
+            family 4dvar
+              task sync
+                trigger /o/main/00dc/an/4dvar eq complete
+                edit SYNC_NODE '/o/main/00dc/an/4dvar'
+            endfamily
+            family surf_anal
+              task sync
+                trigger /o/main/00dc/an/surf_anal eq complete
+                edit SYNC_NODE '/o/main/00dc/an/surf_anal'
+            endfamily
+          endfamily
+          family fc
+            family model
+              task sync
+                trigger /o/main/00dc/fc/model eq complete
+                edit SYNC_NODE '/o/main/00dc/fc/model'
+            endfamily
+            family clean
+              task sync
+                trigger /o/main/00dc/fc/clean eq complete
+                edit SYNC_NODE '/o/main/00dc/fc/clean'
+            endfamily
+          endfamily
+        endfamily
+        family 12dc
+          family an
+            family 4dvar
+              task sync
+                trigger /o/main/12dc/an/4dvar eq complete
+                edit SYNC_NODE '/o/main/12dc/an/4dvar'
+            endfamily
+            family surf_anal
+              task sync
+                trigger /o/main/12dc/an/surf_anal eq complete
+                edit SYNC_NODE '/o/main/12dc/an/surf_anal'
+            endfamily
+          endfamily
+          family fc
+            family model
+              task sync
+                trigger /o/main/12dc/fc/model eq complete
+                edit SYNC_NODE '/o/main/12dc/fc/model'
+            endfamily
+          endfamily
+          family obs
+            family get
+              family get_stor
+                task sync
+                  trigger /o/main/12dc/obs/get/get_stor eq complete
+                  edit SYNC_NODE '/o/main/12dc/obs/get/get_stor'
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family 06bc
+          family an
+            family 4dvar
+              task sync
+                trigger /o/main/06bc/an/4dvar eq complete
+                edit SYNC_NODE '/o/main/06bc/an/4dvar'
+            endfamily
+            family surf_anal
+              task sync
+                trigger /o/main/06bc/an/surf_anal eq complete
+                edit SYNC_NODE '/o/main/06bc/an/surf_anal'
+            endfamily
+          endfamily
+          family prod2diss
+            family oper
+              task sync
+                trigger /o/main/06bc/prod2diss/oper eq complete
+                edit SYNC_NODE '/o/main/06bc/prod2diss/oper'
+            endfamily
+            family sched
+              family 72
+                task sync
+                  trigger /o/main/06bc/prod2diss/sched/72 eq complete
+                  edit SYNC_NODE '/o/main/06bc/prod2diss/sched/72'
+              endfamily
+            endfamily
+          endfamily
+          family fc
+            family model
+              task sync
+                trigger /o/main/06bc/fc/model eq complete
+                edit SYNC_NODE '/o/main/06bc/fc/model'
+            endfamily
+          endfamily
+        endfamily
+        family 18bc
+          family an
+            family 4dvar
+              task sync
+                trigger /o/main/18bc/an/4dvar eq complete
+                edit SYNC_NODE '/o/main/18bc/an/4dvar'
+            endfamily
+            family surf_anal
+              task sync
+                trigger /o/main/18bc/an/surf_anal eq complete
+                edit SYNC_NODE '/o/main/18bc/an/surf_anal'
+            endfamily
+          endfamily
+          family prod2diss
+            family oper
+              task sync
+                trigger /o/main/18bc/prod2diss/oper eq complete
+                edit SYNC_NODE '/o/main/18bc/prod2diss/oper'
+            endfamily
+            family sched
+              family 72
+                task sync
+                  trigger /o/main/18bc/prod2diss/sched/72 eq complete
+                  edit SYNC_NODE '/o/main/18bc/prod2diss/sched/72'
+              endfamily
+            endfamily
+          endfamily
+          family fc
+            family model
+              task sync
+                trigger /o/main/18bc/fc/model eq complete
+                edit SYNC_NODE '/o/main/18bc/fc/model'
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family lag
+        edit YMD '20100114'
+        family 00dc
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/00dc/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/00dc/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family archive
+            task sync
+              trigger /o/lag/00dc/archive eq complete
+              edit SYNC_NODE '/o/lag/00dc/archive'
+          endfamily
+        endfamily
+        family 06
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/06/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/06/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family archive
+            task sync
+              trigger /o/lag/06/archive eq complete
+              edit SYNC_NODE '/o/lag/06/archive'
+          endfamily
+        endfamily
+        family 12
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/12/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/12/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family satim
+            task sync
+              trigger /o/lag/12/satim eq complete
+              edit SYNC_NODE '/o/lag/12/satim'
+          endfamily
+          family verif
+            task sync
+              trigger /o/lag/12/verif eq complete
+              edit SYNC_NODE '/o/lag/12/verif'
+          endfamily
+          family archive
+            family obs
+              task sync
+                trigger /o/lag/12/archive/obs eq complete
+                edit SYNC_NODE '/o/lag/12/archive/obs'
+            endfamily
+            family fc240
+              task sync
+                trigger /o/lag/12/archive/fc240 eq complete
+                edit SYNC_NODE '/o/lag/12/archive/fc240'
+            endfamily
+          endfamily
+        endfamily
+        family 12dc
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/12dc/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/12dc/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family archive
+            task sync
+              trigger /o/lag/12dc/archive eq complete
+              edit SYNC_NODE '/o/lag/12dc/archive'
+          endfamily
+        endfamily
+        family 18
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/18/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/18/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family archive
+            task sync
+              trigger /o/lag/18/archive eq complete
+              edit SYNC_NODE '/o/lag/18/archive'
+          endfamily
+        endfamily
+        family 00
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/00/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/00/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family satim
+            task sync
+              trigger /o/lag/00/satim eq complete
+              edit SYNC_NODE '/o/lag/00/satim'
+          endfamily
+          family verif
+            task sync
+              trigger /o/lag/00/verif eq complete
+              edit SYNC_NODE '/o/lag/00/verif'
+          endfamily
+          family archive
+            family obs
+              task sync
+                trigger /o/lag/00/archive/obs eq complete
+                edit SYNC_NODE '/o/lag/00/archive/obs'
+            endfamily
+            family anml
+              task sync
+                trigger /o/lag/00/archive/anml eq complete
+                edit SYNC_NODE '/o/lag/00/archive/anml'
+            endfamily
+            family anpl
+              task sync
+                trigger /o/lag/00/archive/anpl eq complete
+                edit SYNC_NODE '/o/lag/00/archive/anpl'
+            endfamily
+            family ansfc
+              task sync
+                trigger /o/lag/00/archive/ansfc eq complete
+                edit SYNC_NODE '/o/lag/00/archive/ansfc'
+            endfamily
+            family sst
+              task sync
+                trigger /o/lag/00/archive/sst eq complete
+                edit SYNC_NODE '/o/lag/00/archive/sst'
+            endfamily
+            family fc048
+              task sync
+                trigger /o/lag/00/archive/fc048 eq complete
+                edit SYNC_NODE '/o/lag/00/archive/fc048'
+            endfamily
+            family fc240
+              task sync
+                trigger /o/lag/00/archive/fc240 eq complete
+                edit SYNC_NODE '/o/lag/00/archive/fc240'
+            endfamily
+          endfamily
+        endfamily
+        family 18bc
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/18bc/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/18bc/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family archive
+            task sync
+              trigger /o/lag/18bc/archive eq complete
+              edit SYNC_NODE '/o/lag/18bc/archive'
+          endfamily
+        endfamily
+        family 06bc
+          family fb
+            family feedback
+              family matchup
+                task sync
+                  trigger /o/lag/06bc/fb/feedback/matchup eq complete
+                  edit SYNC_NODE '/o/lag/06bc/fb/feedback/matchup'
+              endfamily
+            endfamily
+          endfamily
+          family archive
+            task sync
+              trigger /o/lag/06bc/archive eq complete
+              edit SYNC_NODE '/o/lag/06bc/archive'
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+    task restart
+      trigger ( ( /o/lag:YMD gt /esync/o/o/lag:YMD) or ( /o/main:YMD gt /esync/o/o/main:YMD) or 1 eq 0) and /esync/o ne active and /esync/o ne submitted
+      edit SMSPASS 'stripped'
+  endfamily
+endsuite
+suite admin3
+  repeat day 1
+  edit USER 'emos'
+  edit ACCOUNT 'oosu'
+  edit SCHOST 'hpce'
+  edit VERSION '0011'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '12'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY ''
+  edit STREAM 'TMP'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit INIMA ''
+  edit INIMACONS '0'
+  edit WSHOST 'swarm'
+  edit QUEUE 'emos-e'
+  edit QUEUE_EPILOG 'emos-exp'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+  edit LOGDIR '/vol/emos/output'
+  edit SMSOUT '/vol/emos/output'
+  edit SMSHOME '/vol/emos/output'
+  edit SMSINCLUDE '/home/ma/emos/def/o/include'
+  edit SMSFILES '/home/ma/emos/def/o/admin'
+  edit SERVER_HOME '/var/tmp/emos/sms'
+  edit CLASS 'od'
+  edit DATEMASK '*.*.*'
+  edit SLEEPTIME '1'
+  inlimit /limits:swarm
+  clock hybrid 
+  family daily
+    repeat date YMD 20070115 20121212 1
+    edit USE_YMD 'true'
+    edit LOGTASK 'daily'
+    family check
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      task rcp
+        time 00:00 23:59 00:10
+        time 00:00 06:59 00:10
+      task ecfs
+        edit SMSTRIES '3'
+        time 00:00 23:59 00:30
+        time 00:00 06:59 00:30
+    endfamily
+    family files
+      task usr_edt
+      task smslog
+        trigger usr_edt eq complete or usr_edt eq aborted
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+        edit LOGDIR '/vol/emos/output'
+        edit SMSOUT '/vol/emos/output'
+      task no_jobs
+        trigger smslog eq complete or smslog eq aborted
+      task tar
+        trigger no_jobs eq complete or no_jobs eq aborted
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      edit SMSFILES '/home/ma/emos/def/admin'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'daily'
+    task logfiles
+      trigger ( check eq complete and files eq complete)
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      edit KEEPLOGS 'no'
+      edit MOVE_TO_ECFS 'no'
+      edit SMSFILES '/home/ma/emos/def/o'
+      time 06:45
+  endfamily
+endsuite
+suite new_monitor
+  edit SMSOUT '/vol/emos_nc/output'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/new_monitor'
+  edit SMSINCLUDE '/home/ma/emos/def/new_monitor/include'
+  edit WSHOST 'bilbo'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/vol/emos_nc/output'
+  edit EMPDIR '/usr/local/apps/empress/v8.60'
+  edit EMPTMPDIR '/acq/tmp/empress'
+  edit EDBPATH 'not_used'
+  edit EPSTYPE 'not_used'
+  edit MEMBER '0'
+  edit FIRST_DAY '0'
+  edit VERSION '0001'
+  edit YMD 'not_used'
+  edit DELTA_DAY '0'
+  edit WDIR 'not_used'
+  edit PACKAGE 'not_used'
+  edit SCHOST 'not_used'
+  edit HAACQ 'not_used'
+  edit AN_TIME 'not_used'
+  edit EDBNAME 'not_used'
+  edit PP_BASE 'not_used'
+  edit EXPVER 'not_used'
+  edit STREAM 'not_used'
+  edit USEEXTRACTED 'not_used'
+  edit SMSHOST 'not_used'
+  edit USER 'emos'
+  edit QUEUE 'emos'
+  edit ACCOUNT 'not_used'
+  edit FSFAMILY 'disk_space'
+  edit EMOS_BASE '00'
+  edit EMOS_TIME_STEP_H '0000'
+  edit DATEMASK '*.*.*'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family admin
+    task display_seaice
+      edit WSHOST 'swarm'
+      edit SMSLOG '/vol/emos/output/monitor'
+      edit MCSLOG '/vol/emos/output'
+      edit FSFAMILY 'undef'
+      edit EMOS_BASE '12'
+      edit SMSURLBASE 'http://w3ec2.ecmwf.int/metapps/preprocessing/Monitoring'
+      edit SMSURL 'seaice.html'
+      edit YMD '20071025'
+      edit METVIEW 'metview'
+      edit EMOS_TYPE 'undef'
+      edit MARS_DB 'mars_od'
+  endfamily
+  family disk_space
+    edit SMSOUT '/vol/emos_nc/output'
+    edit SMSHOME '/vol/emos_nc/output'
+    edit SMSLOG '/vol/emos_nc/output'
+    edit LOGDIR '/vol/emos_nc/output'
+    task chkspace
+      edit WSHOST 'swarm'
+      edit SMSPASS 'stripped'
+      cron 00:00 23:00 00:30
+    task chkspace_img
+      edit WSHOST 'bilbo'
+      edit SMSCMD '/home/ma/emos/bin/smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      cron 00:05 23:05 00:30
+    task chkspace_img_copy
+      edit WSHOST 'localhost'
+      cron 00:10 23:10 00:30
+    task rd_chkspace
+      edit WSHOST 'swarm'
+      cron 00:15 23:15 00:30
+    task rd_chkspace_img
+      edit WSHOST 'bilbo'
+      cron 00:20 23:20 00:30
+    task rd_chkspace_img_copy
+      edit WSHOST 'localhost'
+      cron 00:25 23:25 00:30
+    task chkfeed
+      cron 00:00 23:00 00:30
+  endfamily
+  family stats
+    edit FSFAMILY 'stats'
+    edit ODBCINIFILE '/home/ma/emos/maw/stats2/odbc.ini'
+    task chk_stats_meb
+      label info ""
+      cron 07:00
+    task chk_stats_reb
+      label info ""
+      cron 07:30
+    task chk_stats_reb2
+      label info ""
+      cron 07:35
+    task chk_grib_meb
+      cron 09:30
+    task chk_grib_reb
+      cron 09:30
+    task copy_stats_to_intra
+      edit WSHOST 'localhost'
+      cron 09:45
+  endfamily
+  family acq2
+    edit WSHOST 'localhost'
+    edit WARNINGMAIL 'true'
+    family emc1
+      task amsua
+        edit WARNINGMAIL 'true'
+        cron 00:05 23:05 00:30
+      task mhs
+        edit WARNINGMAIL 'false'
+        cron 00:05 23:05 00:30
+      task hirs
+        edit WARNINGMAIL 'false'
+        cron 00:05 23:05 00:30
+    endfamily
+    family emc2
+      task amsua
+        edit WARNINGMAIL 'false'
+        cron 00:08 23:08 00:30
+      task mhs
+        edit WARNINGMAIL 'false'
+        cron 00:08 23:08 00:30
+      task hirs
+        edit WARNINGMAIL 'false'
+        cron 00:08 23:08 00:30
+    endfamily
+  endfamily
+  family radar
+    task get_radar
+      edit WSHOST 'localhost'
+      edit SMSLOG '/vol/emos/output/monitor'
+      edit MCSLOG '/vol/emos/output'
+      edit FSFAMILY 'radar'
+      cron 00:00 23:00 00:15
+    task get_img
+      edit WSHOST 'bilbo'
+      edit SMSLOG '/vol/emos/output/monitor'
+      edit MCSLOG '/vol/emos/output'
+      edit FSFAMILY 'radar'
+      cron 00:05 23:05 00:15
+  endfamily
+  family db_locks
+    edit SMSOUT '/vol/emos_nc/output'
+    edit SMSHOME '/vol/emos_nc/output'
+    edit SMSLOG '/vol/emos_nc/output'
+    edit LOGDIR '/vol/emos_nc/output'
+    task lockinfo_meb
+      edit WSHOST 'pp1'
+      cron 09:00 15:00 00:02
+    task lockinfo_reb
+      edit WSHOST 'pp1'
+      cron 09:01 15:01 00:02
+    task lockinfo_graph
+      edit WSHOST 'bilbo'
+      cron 09:05 15:05 00:02
+    task lockinfo_img_copy
+      edit WSHOST 'localhost'
+      cron 09:06 15:06 00:02
+  endfamily
+endsuite
+suite preview
+  edit USER 'emos'
+  edit SCHOST 'c1a'
+  edit SCHOST_BKUP 'c1b'
+  edit WSHOST 'swarm'
+  edit WSLOGDIR '/vol/emos/output'
+  edit SCLOGDIR '/emos_dir/0001/log'
+  edit USE_YMD 'true'
+  edit YMD '20070712'
+  edit DATEMASK '*.*.*'
+  edit VERSION '0001'
+  edit INIEXPVER '0001'
+  edit TCINIEXPVER '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '00'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'tc'
+  edit USER_PRIORITY '70'
+  edit REINITIALIZE 'false'
+  edit SMSHOME '/vol/emos/output'
+  edit SMSFILES '/home/ma/emos/def/preview/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/preview/include'
+  edit ACCOUNT 'oosu'
+  edit STREAM 'DA'
+  edit EMOS_STREAM 'EF'
+  edit ENSEMBLES '50'
+  edit ENS_SIZE '50'
+  edit MARS_DB 'marsod'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit SMSLOGHOST 'c1a'
+  edit SMSLOGPORT '9316'
+  edit OD_PROJ 'od'
+  edit SUITE_START '20070602'
+  edit QUEUE 'emos-e'
+  edit QUEUE_EPILOG 'emos-exp'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/vol/emos/output'
+  edit SMSOUT '/vol/emos/output'
+  edit METPY 'metpy_new'
+  edit SLEEPTIME '1'
+  inlimit /limits:swarm
+  clock hybrid 
+  family pop
+    repeat date YMD 20070712 20201215 1
+    limit plots 3
+    family 00
+      edit PLOT_AREAS 'Preview'
+      edit EMOS_BASE '00'
+      edit UPDATE_WEB_NOW 'yes'
+      inlimit plots
+      family deterministic
+        edit SMSFILES '/home/ma/emos/def/preview/pop/web'
+        edit PLOT_STEPS '60,72,84,96,108,120'
+        edit STREAM 'DA'
+        task delay
+          time 07:20
+        family data
+          trigger delay eq complete
+          edit SMSFILES '/home/ma/emos/def/preview/pop/data/fields'
+          edit STEP_LIST '60/to/120/by/12'
+          task mslp
+          task rain
+          task rh
+          task t2m
+          task t850
+          task z500
+          task w30m
+          task wind
+          task wr
+          task wbpt
+        endfamily
+        family web
+          trigger data eq complete
+          task w_msl_uv200
+          task w_mslrain
+          task w_t2m30mw
+          task w_uv_rh
+          task w_z500t850
+          task w_wr850_700
+          task w_wbpt_msl
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/preview/pop'
+      endfamily
+      family eps
+        edit SMSFILES '/home/ma/emos/def/preview/pop/web'
+        edit STREAM 'EF'
+        edit PLOT_STEPS '60/72/84/96/108/120'
+        task delay
+          time 08:50
+        family data
+          trigger delay eq complete
+          edit SMSFILES '/home/ma/emos/def/preview/pop/data/fields'
+          task efi
+          task lsmoro
+            edit STEP_LIST '0/to/48/by/12'
+          task proba
+            edit PLOT_STEPS_RANGE '48-72/60-84/72-96/84-108/96-120/108-132'
+            edit PLOT_STEPS '60/72/84/96/108/120'
+            edit RANGE 'legA'
+        endfamily
+        family web
+          trigger data eq complete
+          edit SMSFILES '/home/ma/emos/def/preview/pop/web'
+          edit STEP_RANGE 'legA'
+          family probabilities
+            task pb_2t
+            task pb_ff
+            task pb_tp
+              edit PLOT_STEPS '48-72/60-84/72-96/84-108/96-120/108-132'
+            task w_proba_gusts
+              edit PLOT_STEPS '48-72/60-84/72-96/84-108/96-120/108-132'
+          endfamily
+          family efi
+            family efi_tpi
+              task w_efi
+                edit PARAMETER 'tpi'
+            endfamily
+            family efi_10wsi
+              task w_efi
+                edit PARAMETER '10wsi'
+            endfamily
+            family efi_2ti
+              task w_efi
+                edit PARAMETER '2ti'
+            endfamily
+            family efi_10fgi
+              task w_efi
+                edit PARAMETER '10fgi'
+            endfamily
+          endfamily
+          family others
+            edit PLOT_STEPS '60,72,84,96,108,120'
+            task w_msl_mean_spread
+            task w_z500_mean_spread
+            task w_z200_mean_spread
+            task w_t850_mean_spread
+          endfamily
+          family quartiles
+            edit AREA_TO_PLOT '-5/-50/60/80'
+            edit MAP_VERT_LONG '0'
+            edit MAP_PROJECTION 'POLAR_STEREOGRAPHIC'
+            edit STEP_LIST '54/TO/126/by/12'
+            edit STEP_PLOT '60/TO/120/by/12'
+            task w_tp_quartiles
+            task w_wind_quartiles
+            task w_wgust_quartiles
+            task w_wind925_quartiles
+            task w_cape_quartiles
+          endfamily
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/preview/pop'
+      endfamily
+    endfamily
+    family ukmo
+      edit SMSFILES '/home/ma/emos/def/preview/pop/mogreps'
+      edit PLOT_AREAS 'Preview'
+      edit EMOS_BASE '00'
+      edit STREAM 'EF'
+      edit UPDATE_WEB_NOW 'yes'
+      inlimit plots
+      task delay
+        time 08:55
+      family mogreps
+        trigger delay eq complete
+        edit PLOT_STEPS '60,72,84,96,108,120'
+        family web
+          family en_mean_spread
+            task m_msl_mean_spread
+            task m_z500_mean_spread
+            task m_z200_mean_spread
+            task m_t850_mean_spread
+          endfamily
+          family quartiles
+            edit AREA_TO_PLOT '-5/-50/60/80'
+            edit MAP_VERT_LONG '0'
+            edit MAP_PROJECTION 'POLAR_STEREOGRAPHIC'
+            edit STEP_LIST '54/TO/126/by/12'
+            task m_tp_quartiles
+            task m_wind_quartiles
+            task m_wind925_quartiles
+          endfamily
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/preview/pop'
+      endfamily
+    endfamily
+    task restart
+      trigger ./00 eq complete
+      time 15:00
+  endfamily
+endsuite
+suite gems
+  edit USER 'emos'
+  edit SCHOST 'hpce'
+  edit SCHOST_BKUP 'hpcf'
+  edit WSHOST 'swarm'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/emos_dir/evnj/log'
+  edit USE_YMD 'true'
+  edit YMD '20071217'
+  edit DATEMASK '*.*.*'
+  edit VERSION 'evnj'
+  edit INIEXPVER '0001'
+  edit TCINIEXPVER '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '1'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '00'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'tc'
+  edit USER_PRIORITY '70'
+  edit REINITIALIZE 'false'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/gems/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/gems/include'
+  edit ACCOUNT 'oosu'
+  edit STREAM 'EF'
+  edit EMOS_STREAM 'EF'
+  edit ENSEMBLES '50'
+  edit ENS_SIZE '50'
+  edit MARS_DB 'marsod'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit SMSLOGHOST 'c1a'
+  edit SMSLOGPORT '9316'
+  edit OD_PROJ 'od'
+  edit SUITE_START '20061126'
+  edit QUEUE 'emos-e'
+  edit QUEUE_EPILOG 'emos-exp'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/vol/emos_nc/output'
+  edit SMSOUT '/vol/emos_nc/output'
+  edit SLEEPTIME '1'
+  inlimit /limits:swarm
+  clock hybrid 
+  family limits
+    limit linux_cluster 8
+    limit raq_ensemble 3
+    limit calchas 4
+  endfamily
+  family grg
+    inlimit /gems/limits:linux_cluster
+    family plot
+      edit METPY 'metpy_dev'
+      edit UPDATE_WEB_NOW 'yes'
+      edit DO_PUSH_TO_WEB 'yes'
+      family realtime
+        repeat date YMD 20081223 20120924 1
+        edit VERSION 'f7kn'
+        edit METPY 'metpy_new'
+        edit PARAMETERS 'co,go3'
+        edit LEVELS '850,500,300,50'
+        family deps
+          task dummy
+            time 01:00
+        endfamily
+        task daily_fields
+          trigger deps eq complete
+        task daily_totalcolumns
+          trigger daily_fields eq complete
+          edit PARAMETERS 'tcco,gtco3'
+        task daily_zonalmean
+          trigger daily_totalcolumns eq complete
+        task daily_crosssection
+          trigger daily_zonalmean eq complete
+      endfamily
+      family realtime_da
+        repeat date YMD 20081223 20120924 1
+        edit METPY 'metpy_new'
+        edit VERSION 'f8na'
+        edit PARAMETERS 'co,go3'
+        edit LEVELS '850,500,300,50'
+        family deps
+          task dummy
+            time 12:00
+        endfamily
+        task daily_fields_da
+          trigger deps eq complete
+        task daily_totalcolumns_da
+          trigger daily_fields_da eq complete
+          edit PARAMETERS 'tcco,gtco3'
+        task daily_zonalmean_da
+          trigger daily_totalcolumns_da eq complete
+        task daily_crosssection_da
+          trigger daily_zonalmean_da eq complete
+      endfamily
+      family uv
+        repeat date YMD 20081223 20090924 1
+        edit VERSION 'ewsf'
+        edit PARAMETERS '82'
+        family deps
+          task dummy
+            time 16:00
+        endfamily
+        task uv_dose
+          trigger deps eq complete
+          edit METPY 'metpy_new'
+      endfamily
+      family reanalysis
+        repeat integer month 200301 200312
+        edit VERSION 'eyih'
+        edit LEVELS '850,500,300,50'
+        edit PARAMETERS 'co,go3,hcho,nox'
+        task monthly_fields
+        task monthly_totalcolumns
+          edit PARAMETERS 'tcco,gtco3,tchcho'
+        task monthly_zonalmean
+          trigger monthly_totalcolumns eq complete
+        task monthly_crosssection
+          trigger monthly_zonalmean eq complete
+      endfamily
+      task logfilestore
+        trigger realtime eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit KEEPLOGS 'no'
+        edit LOGSTOECFS 'no'
+        edit MOVE_TO_ECFS 'yes'
+      task logfiles
+        trigger logfilestore eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit MOVE_TO_ECFS 'no'
+      family polarcat
+        repeat date YMD 20081223 20120924 1
+        edit VERSION 'f7kn'
+        edit OWNER 'nal'
+        family deps
+          task dummy
+            time 11:00
+        endfamily
+        task polarcat_retrieve_and_process
+          trigger deps eq complete
+        task polarcat_make_latlon_plots
+          trigger polarcat_retrieve_and_process eq complete
+        task polarcat_make_polar_plots
+          trigger polarcat_make_latlon_plots eq complete
+        task polarcat_make_xs_plots
+          trigger polarcat_make_polar_plots eq complete
+        task polarcat_cleanup
+          trigger polarcat_make_xs_plots eq complete
+      endfamily
+    endfamily
+  endfamily
+  family ghg
+    inlimit /gems/limits:linux_cluster
+    family plot
+      edit METPY 'metpy_new'
+      edit UPDATE_WEB_NOW 'yes'
+      edit DO_PUSH_TO_WEB 'yes'
+      family reanalysis
+        edit PARAMETERS 'tcco2'
+        task tcco2_mean
+      endfamily
+      family ch4_reanalysis
+        repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712"
+        edit VERSION 'f46b'
+        edit PARAMETERS 'tcch4'
+        task ch4_monthly_totalcolumns
+      endfamily
+      family iasi_plots
+        repeat enumerated month "200801" "200802" "200803" "200804" "200805" "200806" "200807" "200808" "200809" "200810" "200811" "200812"
+        task iasi
+      endfamily
+      family ch4_flux_inversion
+        repeat enumerated month "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412"
+        task plot_ch4_flux
+      endfamily
+    endfamily
+  endfamily
+  family aer
+    edit UPDATE_WEB_NOW 'yes'
+    edit DO_PUSH_TO_WEB 'yes'
+    edit METPY 'metpy_dev'
+    inlimit /gems/limits:linux_cluster
+    family realtime
+      repeat date YMD 20080507 20081224 1
+      edit VERSION 'f0dm'
+      edit AERTYPES 'total,natural,anthropogenic'
+      edit METPY 'metpy_new'
+      family deps
+        task dummy
+          time 08:30
+      endfamily
+      task optical_depth
+        trigger deps eq complete
+    endfamily
+    family realtime_da
+      repeat date YMD 20080506 20091224 1
+      edit VERSION 'f8na'
+      edit AERTYPES 'total,natural,anthropogenic'
+      edit METPY 'metpy_new'
+      family deps
+        task dummy
+          time 12:00
+      endfamily
+      task optical_depth_da
+        trigger deps eq complete
+    endfamily
+    family verif
+      repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412"
+      task aer_station_plots_exlz_ezub
+      task aer_stat_plots_exlz_ezub
+        trigger aer_station_plots_exlz_ezub eq complete
+    endfamily
+    family fire_products
+      repeat date YMD 20080506 20091224 1
+      edit METPY 'metpy_new'
+      family deps
+        task dummy
+          time 07:00
+      endfamily
+      task fire_radiative_power
+        trigger deps eq complete
+    endfamily
+    family verif_f1kd
+      repeat enumerated month "200807" "200808" "200809" "200810" "200811" "200812" "200901" "200902" "200903" "200904" "200905" "200906" "200907" "200908" "200909" "200910" "200911" "200912"
+      task aer_station_plots_f1kd
+      task aer_stat_plots_f1kd
+        trigger aer_station_plots_f1kd eq complete
+    endfamily
+  endfamily
+  family raq
+    edit SMSTRIES '5'
+    edit UPDATE_WEB_NOW 'yes'
+    edit DO_PUSH_TO_WEB 'yes'
+    edit METPY 'metpy_new'
+    edit VERSION 'gems'
+    inlimit /gems/limits:linux_cluster
+    family obs
+      repeat date YMD 20081223 20111001 1
+      edit METPY 'metpy_new'
+      edit FIRST_HOUR '0'
+      edit FINAL_HOUR '23'
+      edit STEP '1'
+      edit PARAMETERS 'o3,no2,so2,co,pm10'
+      edit COUNTRIES 'pl,fi,se,nl,fr'
+      edit ARCHIVED_COUNTRIES 'uk,es,de'
+      family deps
+        task dummy
+          time 11:35
+      endfamily
+      task plot_obs
+        trigger deps eq complete
+    endfamily
+    family ensemble
+      repeat date YMD 20081223 20111001 1
+      edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
+      family deps
+        task dummy
+          time 10:00
+      endfamily
+      task regrid_models
+        trigger deps eq complete
+        edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
+      family plot_ensemble
+        inlimit /gems/limits:raq_ensemble
+        task plot_ensemble_o3
+          trigger ../regrid_models eq complete
+          edit PARAMETER 'o3'
+          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH'
+        task plot_ensemble_no2
+          trigger ../regrid_models eq complete
+          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
+          edit PARAMETER 'no2'
+        task plot_ensemble_so2
+          trigger ../regrid_models eq complete
+          edit PARAMETER 'so2'
+          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
+        task plot_ensemble_co
+          trigger ../regrid_models eq complete
+          edit PARAMETER 'co'
+          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
+        task plot_ensemble_pm10
+          trigger ../regrid_models eq complete
+          edit PARAMETER 'pm10'
+          edit MODELS 'CHI,EMP,FMI,NKU,RIU,SMH,UKN'
+        task plot_epsgram
+          trigger ../regrid_models eq complete
+        task plot_ensemble_aqi
+          trigger ./plot_ensemble_o3 eq complete and ./plot_ensemble_no2 eq complete and ./plot_ensemble_so2 eq complete and ./plot_ensemble_pm10 eq complete
+          edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,NKU,RIU,SMH'
+      endfamily
+      task compute_hourly_ensemble
+        trigger plot_ensemble eq complete
+        edit PARAMETERS 'o3,no2,so2,co,pm10'
+      task cleanup_models
+        trigger compute_hourly_ensemble eq complete
+        time 15:30
+    endfamily
+    family verif
+      edit METPY 'metpy_new'
+      family scores
+        repeat date YMD 20080731 20100716 1
+        family deps
+          task dummy
+            time 11:35
+        endfamily
+        family compute_scores
+          edit PARAMETERS 'o3,no2,so2,pm10'
+          task verify_RAQ
+            trigger ../deps eq complete
+            label status ""
+        endfamily
+        family plot_scores
+          edit PARAMETERS 'o3,no2,so2,co,pm10'
+          edit COUNTRIES 'pl,fi,se,nl,fr'
+          edit ARCHIVED_COUNTRIES 'uk,es,de'
+          task plot_RAQ_mean_scores
+            trigger ../compute_scores eq complete
+          task plot_RAQ_ts_scores
+            trigger ../compute_scores eq complete
+          task plot_RAQ_taylor_plots
+            trigger ../compute_scores eq complete
+        endfamily
+      endfamily
+      family obs_model
+        family values
+          repeat date YMD 20080731 20100716 1
+          edit COUNTRIES 'pl,fi,se,nl,fr'
+          edit ARCHIVED_COUNTRIES 'uk,es,de'
+          task plot_obs_model_o3
+            trigger ( /gems/raq/verif/scores:YMD gt /gems/raq/verif/obs_model/values:YMD) or ../../scores eq complete
+            edit PARAMETER 'o3'
+            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH'
+          task plot_obs_model_no2
+            trigger plot_obs_model_o3 eq complete
+            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH,UKN'
+            edit PARAMETER 'no2'
+          task plot_obs_model_so2
+            trigger plot_obs_model_no2 eq complete
+            edit PARAMETER 'so2'
+            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,NKU,RIU,SMH,UKN'
+          task plot_obs_model_co
+            trigger plot_obs_model_so2 eq complete
+            edit PARAMETER 'co'
+            edit MODELS 'CHI,CNR,DMI,EMP,FMI,MFM,MOZ,NKU,RIU,SMH'
+          task plot_obs_model_pm10
+            trigger plot_obs_model_co eq complete
+            edit PARAMETER 'pm10'
+            edit MODELS 'CHI,EMP,FMI,NKU,RIU,SMH,UKN'
+        endfamily
+      endfamily
+      family plot_OMI
+        repeat date YMD 20080731 20100716 1
+        family deps
+          task dummy
+            time 11:00
+        endfamily
+        task plot_OMI_tc
+          trigger deps eq complete
+          edit MODELS 'CHI,CNR,DMI,EMP,FMI,NKU,RIU,SMH'
+      endfamily
+      family rescore_fam
+        family rescore_1
+          repeat date YMD 20080601 20081031 1
+          task rescore_RAQ_1
+            label status ""
+        endfamily
+        family rescore_2
+          repeat date YMD 20080601 20081031 1
+          task rescore_RAQ_2
+            label status ""
+        endfamily
+        family rescore_3
+          repeat date YMD 20080601 20081031 1
+          task rescore_RAQ_3
+            label status ""
+        endfamily
+        family rescore_4
+          repeat date YMD 20080601 20081031 1
+          task rescore_RAQ_4
+            label status ""
+        endfamily
+        family rescore_5
+          repeat date YMD 20080601 20081031 1
+          task rescore_RAQ_5
+            label status ""
+        endfamily
+      endfamily
+    endfamily
+    family models
+      edit FIRST_STEP '0'
+      edit FINAL_STEP '72'
+      edit STEP '1'
+      edit DEADLINE '1500'
+      edit LEVELS '500,1000,3000'
+      edit PARAMETERS 'o3,no,no2'
+      family CHI
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'CHI'
+        family plot
+          complete plot/finish eq complete
+          task plot_CHI
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_CHI:done or plot_CHI eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family CNR
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'CNR'
+        family plot
+          complete plot/finish eq complete
+          task plot_CNR
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_CNR:done or plot_CNR eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family DMI
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'DMI'
+        family plot
+          complete plot/finish eq complete
+          task plot_DMI
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_DMI:done or plot_DMI eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family EMP
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'EMP'
+        family plot
+          complete plot/finish eq complete
+          task plot_EMP
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_EMP:done or plot_EMP eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family FMI
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'FMI'
+        edit PARAMETERS 'o3,no,no2'
+        family plot
+          complete plot/finish eq complete
+          task plot_FMI
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_FMI:done or plot_FMI eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family KNM
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'KNM'
+        family plot
+          complete plot/finish eq complete
+          task plot_KNM
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_KNM:done or plot_KNM eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family MFM
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'MFM'
+        family plot
+          complete plot/finish eq complete
+          task plot_MFM
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_MFM:done or plot_MFM eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family MOZ
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'MOZ'
+        edit FIRST_STEP '1'
+        family plot
+          complete plot/finish eq complete
+          task plot_MOZ
+            label status "nothing yet"
+            event done
+            cron 10:00 16:00 00:30
+          task finish
+            complete plot_MOZ:done or plot_MOZ eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 16:15
+      endfamily
+      family NKU
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'NKU'
+        family plot
+          complete plot/finish eq complete
+          task plot_NKU
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_NKU:done or plot_NKU eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family RIU
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'RIU'
+        family plot
+          complete plot/finish eq complete
+          task plot_RIU
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_RIU:done or plot_RIU eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family SMH
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'SMH'
+        family plot
+          complete plot/finish eq complete
+          task plot_SMH
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_SMH:done or plot_SMH eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+      family UKN
+        repeat date YMD 20081223 20111001 1
+        edit MODEL 'UKN'
+        edit FINAL_STEP '71'
+        edit PARAMETERS 'no,no2'
+        family plot
+          complete plot/finish eq complete
+          task plot_UKN
+            label status "nothing yet"
+            event done
+            cron 00:00 15:00 00:30
+          task finish
+            complete plot_UKN:done or plot_UKN eq complete
+            trigger 1 eq 0
+        endfamily
+        task dummy
+          trigger plot eq complete
+          time 15:15
+      endfamily
+    endfamily
+    family etc
+      task cleanup_ftp
+        cron 23:55
+    endfamily
+  endfamily
+  family combined
+    inlimit /gems/limits:linux_cluster
+    family reanalysis
+      repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712" "200801"
+      edit VERSION 'f026'
+      edit LEVELS '850,500,300,50'
+      edit PARAMETERS 'co,go3,hcho,ch4,nox'
+      task gems_monthly_fields
+      task gems_monthly_zonalmean
+      task gems_monthly_totalcolumns
+        edit PARAMETERS 'tcco2,tcco,gtco3,tchcho,tcch4'
+    endfamily
+    family reanalysis_update
+      repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712" "200801"
+      edit VERSION 'ey2o'
+      task gems_monthly_totalcolumns
+        edit PARAMETERS 'tcco2'
+    endfamily
+  endfamily
+endsuite
+suite tparc
+  edit USER 'emos'
+  edit SCHOST 'hpce'
+  edit SCHOST_BKUP 'hpcf'
+  edit WSHOST 'swarm'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/emos_dir/0001/log'
+  edit USE_YMD 'true'
+  edit YMD '20100105'
+  edit DATEMASK '*.*.*'
+  edit VERSION '0001'
+  edit INIEXPVER '0015'
+  edit TCINIEXPVER '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '00'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'tc'
+  edit USER_PRIORITY '70'
+  edit REINITIALIZE 'false'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/tparc/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/tparc/include'
+  edit ACCOUNT 'oosu'
+  edit STREAM 'DA'
+  edit EMOS_STREAM 'EF'
+  edit ENSEMBLES '50'
+  edit ENS_SIZE '50'
+  edit MARS_DB 'marsod'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit SMSLOGHOST 'hpce'
+  edit SMSLOGPORT '9316'
+  edit OD_PROJ 'od'
+  edit SUITE_START '20080611'
+  edit QUEUE 'emos-e'
+  edit QUEUE_EPILOG 'emos-exp'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/vol/emos_nc/output'
+  edit SMSOUT '/vol/emos_nc/output'
+  edit METPY 'metpy_new'
+  edit SLEEPTIME '1'
+  inlimit /limits:swarm
+  clock hybrid 
+  family pop
+    repeat date YMD 20100105 20120410 1
+    limit plots 5
+    family 00
+      edit DELTA_DAY '1'
+      edit PLOT_AREAS 'Tparc_winter'
+      edit EMOS_BASE '00'
+      edit UPDATE_WEB_NOW 'yes'
+      inlimit plots
+      family deterministic
+        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
+        edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
+        edit STREAM 'DA'
+        task delay
+          time 07:30
+        family data
+          trigger delay eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
+          edit STEP_LIST '12/to/144/by/12'
+          task mslp
+          task rain
+          task rh
+          task t2m
+          task t850
+          task z500
+          task w30m
+          task wind
+          task wr
+          task wbpt
+        endfamily
+        family web
+          trigger data eq complete
+          task w_msl_uv200
+          task w_mslrain
+          task w_t2m30mw
+          task w_uv_rh
+          task w_z500t850
+          task w_wr850_700
+          task w_wbpt_msl
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop'
+      endfamily
+      family interactive_chart
+        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
+        family interactive_ghost
+          time 00:01
+          task w_msl_mean_spread_ghost
+            edit PLOT_STEPS '36,48,60,72,84,96,108,120,132,144'
+            edit DELTA_VALUE '-1'
+        endfamily
+        family interactive_real
+          time 08:55
+          task w_msl_mean_spread_ghost
+            edit PLOT_STEPS '36,48,60,72,84,96,108,120,132,144'
+            edit DELTA_VALUE '0'
+        endfamily
+      endfamily
+      family eps
+        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
+        edit STREAM 'EF'
+        edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
+        task delay
+          time 08:55
+        family data
+          trigger delay eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
+          task efi
+          task lsmoro
+            edit STEP_LIST '0/to/48/by/12'
+          task proba
+            edit PLOT_STEPS_RANGE '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
+            edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
+            edit RANGE 'legA'
+        endfamily
+        family web
+          trigger data eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
+          edit STEP_RANGE 'legA'
+          family probabilities
+            task pb_2t
+            task pb_ff
+            task pb_tp
+              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
+            task w_proba_gusts
+              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
+          endfamily
+          family efi
+            family efi_tpi
+              task w_efi
+                edit PARAMETER 'tpi'
+            endfamily
+            family efi_10wsi
+              task w_efi
+                edit PARAMETER '10wsi'
+            endfamily
+            family efi_2ti
+              task w_efi
+                edit PARAMETER '2ti'
+            endfamily
+            family efi_10fgi
+              task w_efi
+                edit PARAMETER '10fgi'
+            endfamily
+          endfamily
+          family others
+            edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
+            task w_msl_mean_spread
+            task w_z500_mean_spread
+            task w_z200_mean_spread
+            task w_t850_mean_spread
+          endfamily
+          family quartiles
+            edit AREA_TO_PLOT '-10/100/90/300'
+            edit AREA_TO_PLOT_ZOOM '20/140/90/280'
+            edit MAP_VERT_LONG '160'
+            edit MAP_VERT_LONG_ZOOM '160'
+            edit MAP_PROJECTION 'CYLINDRICAL'
+            edit STEP_LIST '6/TO/150/by/12'
+            edit STEP_PLOT '12/TO/144/by/12'
+            task w_tp_quartiles
+            task w_wind_quartiles
+            task w_wgust_quartiles
+            task w_wind925_quartiles
+            task w_cape_quartiles
+          endfamily
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop'
+      endfamily
+    endfamily
+    family 12
+      edit PLOT_AREAS 'Tparc_winter'
+      edit EMOS_BASE '12'
+      edit UPDATE_WEB_NOW 'yes'
+      inlimit plots
+      family deterministic
+        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
+        edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
+        edit STREAM 'DA'
+        task delay
+          time 19:20
+        family data
+          trigger delay eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
+          edit STEP_LIST '12/to/144/by/12'
+          task mslp
+          task rain
+          task rh
+          task t2m
+          task t850
+          task z500
+          task w30m
+          task wind
+          task wr
+          task wbpt
+        endfamily
+        family web
+          trigger data eq complete
+          task w_msl_uv200
+          task w_mslrain
+          task w_t2m30mw
+          task w_uv_rh
+          task w_z500t850
+          task w_wr850_700
+          task w_wbpt_msl
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop'
+      endfamily
+      family eps
+        edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
+        edit STREAM 'EF'
+        edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
+        task delay
+          time 20:50
+        family data
+          trigger delay eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop/data/fields'
+          task efi
+          task lsmoro
+            edit STEP_LIST '0/to/48/by/12'
+          task proba
+            edit PLOT_STEPS_RANGE '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
+            edit PLOT_STEPS '12/24/36/48/60/72/84/96/108/120/132/144'
+            edit RANGE 'legA'
+        endfamily
+        family web
+          trigger data eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop/web'
+          edit STEP_RANGE 'legA'
+          family probabilities
+            task pb_2t
+            task pb_ff
+            task pb_tp
+              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
+            task w_proba_gusts
+              edit PLOT_STEPS '0-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156'
+          endfamily
+          family efi
+            family efi_tpi
+              task w_efi
+                edit PARAMETER 'tpi'
+            endfamily
+            family efi_10wsi
+              task w_efi
+                edit PARAMETER '10wsi'
+            endfamily
+            family efi_2ti
+              task w_efi
+                edit PARAMETER '2ti'
+            endfamily
+            family efi_10fgi
+              task w_efi
+                edit PARAMETER '10fgi'
+            endfamily
+          endfamily
+          family others
+            edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
+            task w_msl_mean_spread
+            task w_z500_mean_spread
+            task w_z200_mean_spread
+            task w_t850_mean_spread
+          endfamily
+          family quartiles
+            edit AREA_TO_PLOT '-10/100/90/300'
+            edit AREA_TO_PLOT_ZOOM '20/140/90/280'
+            edit MAP_VERT_LONG '160'
+            edit MAP_VERT_LONG_ZOOM '160'
+            edit MAP_PROJECTION 'CYLINDRICAL'
+            edit STEP_LIST '6/TO/150/by/12'
+            edit STEP_PLOT '12/TO/144/by/12'
+            task w_tp_quartiles
+            task w_wind_quartiles
+            task w_wgust_quartiles
+            task w_wind925_quartiles
+            task w_cape_quartiles
+          endfamily
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop'
+      endfamily
+    endfamily
+    family ukmo
+      edit DELTA_DAY '1'
+      edit SMSFILES '/home/ma/emos/def/tparc/pop/mogreps'
+      edit PLOT_AREAS 'Tparc_winter'
+      edit EMOS_BASE '00'
+      edit STREAM 'EF'
+      edit UPDATE_WEB_NOW 'yes'
+      inlimit plots
+      task delay
+        time 09:00
+      family mogreps
+        trigger delay eq complete
+        edit PLOT_STEPS '12,24,36,48,60,72,84,96,108,120,132,144'
+        family web
+          family en_mean_spread
+            task m_msl_mean_spread
+            task m_z500_mean_spread
+            task m_z200_mean_spread
+            task m_t850_mean_spread
+          endfamily
+          family quartiles
+            edit AREA_TO_PLOT '-10/100/90/300'
+            edit AREA_TO_PLOT_ZOOM '20/140/90/280'
+            edit MAP_VERT_LONG '160'
+            edit MAP_VERT_LONG_ZOOM '160'
+            edit MAP_PROJECTION 'CYLINDRICAL'
+            edit STEP_LIST '6/TO/150/by/12'
+            edit STEP_PLOT '12/TO/144/by/12'
+            task m_tp_quartiles
+            task m_wind_quartiles
+            task m_wind925_quartiles
+          endfamily
+        endfamily
+        task cleanup
+          trigger web eq complete
+          edit SMSFILES '/home/ma/emos/def/tparc/pop'
+      endfamily
+    endfamily
+    task restart
+      trigger ./00 eq complete and ukmo eq complete and ./12 eq complete
+      time 11:00
+  endfamily
+endsuite
+suite tparc_dts
+  edit USER 'emos'
+  edit SCHOST 'hpcf'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/emos_esuite/emos_data/0015/log'
+  edit EMOS_TYPE '1'
+  edit DTS '1'
+  edit USE_YMD 'true'
+  edit YMD '20090327'
+  edit DATEMASK '*.*.*'
+  edit VERSION '0015'
+  edit INIEXPVER '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'mc'
+  edit USER_PRIORITY '70'
+  edit PRIORITY '70'
+  edit ININPES '16'
+  edit NPROCA '16'
+  edit NPROCB '1'
+  edit SVMODE 'dts'
+  edit SVPROJVERT 'lower_troposphere'
+  edit REINITIALIZE 'false'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
+  edit SMSINCLUDE '/home/ma/emos/def/tparc_33r1/include'
+  edit ACCOUNT 'oodts'
+  edit STREAM 'EF'
+  edit EMOS_STREAM 'EF'
+  edit MARS_DB 'marser'
+  edit EPSTYPE 'sv'
+  edit MEMBER '0'
+  edit INILEVELS '91'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit FCGROUP 'fc0'
+  edit SMSLOGHOST 'hpcf'
+  edit SMSLOGPORT '9316'
+  edit SVTHREADS '2'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/emos_esuite/emos_data/0015/log'
+  edit SMSOUT '/emos_esuite/emos_data/0015/log'
+  edit SLEEPTIME '1'
+  inlimit /limits:hpcf
+  clock hybrid 
+  family limits
+    limit hpce 5
+    limit hpcf 5
+    limit mars 3
+    limit webplots 3
+    limit linux_cluster 3
+  endfamily
+  family main
+    repeat date YMD 20090327 20190101 1
+    family make
+      edit EMOS_BASE '00'
+      task setup
+      task links
+        trigger setup eq complete
+      task datalinks
+        trigger links eq complete and setup eq complete
+      family bins
+        trigger datalinks eq complete
+        task ifs
+        task prepdata
+        task mc_tools
+      endfamily
+    endfamily
+    family 00
+      edit EMOS_BASE '00'
+      task concordiasi_control
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        time 10:00
+      family case1
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '1'
+        edit INISTEP '42'
+        edit FCLENGTH '30'
+        edit FSFAMILY 'mc/case1'
+        edit ALAT1 '20'
+        edit ALON1 '0'
+        edit ALAT3 '-20'
+        edit ALON3 '359'
+        edit DELTA_HOUR '42'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case2
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '2'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case2'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case3
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '3'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case3'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case4
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '4'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case4'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case5
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '5'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case5'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case6
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '6'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case6'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case7
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '7'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case7'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case8
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '8'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case8'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case9
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '9'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case9'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case10
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_control eq complete
+        edit REGIONNR '10'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit FSFAMILY 'mc/case10'
+        inlimit /tparc_dts/limits:hpcf
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '4'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit EMOS_BASE '00'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'main'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'main'
+      time 19:00
+  endfamily
+  family lag
+    trigger ( main:YMD ge lag:YMD)
+    repeat date YMD 20090327 20190101 1
+    inlimit /tparc_dts/limits:mars
+    family 00
+      edit EMOS_BASE '00'
+      edit SUBFSFAMILY ''
+      task concordiasi_archivecontrol
+        trigger /tparc_dts/main/00/concordiasi_control eq complete
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+      family case1
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case1 eq complete
+        edit FSFAMILY 'mc/case1'
+        edit REGIONNR '1'
+        edit INISTEP '42'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '42'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case2
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case2 eq complete
+        edit FSFAMILY 'mc/case2'
+        edit REGIONNR '2'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case3
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case3 eq complete
+        edit FSFAMILY 'mc/case3'
+        edit REGIONNR '3'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case4
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case4 eq complete
+        edit FSFAMILY 'mc/case4'
+        edit REGIONNR '4'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case5
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case5 eq complete
+        edit FSFAMILY 'mc/case5'
+        edit REGIONNR '5'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case6
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case6 eq complete
+        edit FSFAMILY 'mc/case6'
+        edit REGIONNR '6'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case7
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case7 eq complete
+        edit FSFAMILY 'mc/case7'
+        edit REGIONNR '7'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case8
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case8 eq complete
+        edit FSFAMILY 'mc/case8'
+        edit REGIONNR '8'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case9
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case9 eq complete
+        edit FSFAMILY 'mc/case9'
+        edit REGIONNR '9'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+      family case10
+        trigger ./concordiasi_archivecontrol eq complete and /tparc_dts/main/00/case10 eq complete
+        edit FSFAMILY 'mc/case10'
+        edit REGIONNR '10'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave_concordiasi
+        task svsave
+        task archive_sv
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGTASK 'lag'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'lag'
+      time 19:00
+  endfamily
+  family pop
+    trigger ( main:YMD ge pop:YMD)
+    repeat date YMD 20090327 20190101 1
+    edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
+    edit EMOS_BASE '00'
+    inlimit /tparc_dts/limits:webplots
+    family 00
+      edit SUBFSFAMILY ''
+      edit HOUR '0'
+      task concordiasi_plotcontrol
+        trigger /tparc_dts/main/00/concordiasi_control eq complete
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+      task getobslist
+        trigger concordiasi_plotcontrol eq complete
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+      family case1
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case1 eq complete
+        edit FSFAMILY 'mc/case1'
+        edit INISTEP '42'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '42'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case2
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case2 eq complete
+        edit FSFAMILY 'mc/case2'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case3
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case3 eq complete
+        edit FSFAMILY 'mc/case3'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case4
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case4 eq complete
+        edit FSFAMILY 'mc/case4'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case5
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case5 eq complete
+        edit FSFAMILY 'mc/case5'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case6
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case6 eq complete
+        edit FSFAMILY 'mc/case6'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case7
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case7 eq complete
+        edit FSFAMILY 'mc/case7'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case8
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case8 eq complete
+        edit FSFAMILY 'mc/case8'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case9
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case9 eq complete
+        edit FSFAMILY 'mc/case9'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+      family case10
+        trigger /tparc_dts/main/make eq complete and ./concordiasi_plotcontrol eq complete and /tparc_dts/main/00/case10 eq complete
+        edit FSFAMILY 'mc/case10'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /tparc_dts/limits:linux_cluster
+      endfamily
+    endfamily
+    task cases2ftp
+      trigger /tparc_dts/main/00/concordiasi_control eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      inlimit /tparc_dts/limits:linux_cluster
+    task cases2web
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      inlimit /tparc_dts/limits:linux_cluster
+    task clean
+      trigger ./00 eq complete and cases2web eq complete
+    task clean_ws
+      trigger ./00 eq complete and cases2web eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      inlimit /tparc_dts/limits:linux_cluster
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'pop'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete and ./clean eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/tparc_33r1/dts'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'pop'
+      time 22:00
+  endfamily
+  family sap_other_centres
+    trigger ( main:YMD ge pop:YMD)
+    repeat date YMD 20090327 20190101 1
+    edit EMOS_BASE '00'
+    family 00
+      family ukmo
+        edit CENTRE 'metoffice'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'egrr'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task getdata
+          time 17:00
+        task plotftg_other
+          trigger getdata eq complete
+        task sap_other2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_other2web eq complete
+      endfamily
+      family ncep
+        edit CENTRE 'ncep'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'kwbc'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task getdata
+          time 17:00
+        task getfields
+          trigger getdata eq complete
+        task plotftg_other
+          trigger getfields eq complete
+        task sap_ncep2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task others2cfs
+          trigger sap_ncep2web eq complete
+        task archive_other
+          trigger others2cfs eq complete
+      endfamily
+      family nrl
+        edit CENTRE 'nrl'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'fnmoc'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'sv'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task get_some_data
+          time 18:20
+        task get_some_fields
+          trigger get_some_data eq complete
+        task plotftg_other
+          trigger get_some_fields eq complete
+        task sap_nrl2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task others2cfs
+          trigger sap_nrl2web eq complete
+        task archive_other
+          trigger others2cfs eq complete
+      endfamily
+      family jma
+        edit CENTRE 'jma'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'jma'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task get_some_data
+          time 12:00
+        task get_some_fields
+          trigger get_some_data eq complete
+        task grib_mod_jma
+          trigger get_some_fields eq complete
+        task plotftg_other
+          trigger grib_mod_jma eq complete
+        task sap_jma2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task others2cfs
+          trigger sap_jma2web eq complete
+        task archive_other
+          trigger sap_jma2web eq complete
+      endfamily
+      family ntu
+        edit CENTRE 'ntu'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'ntu'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task getdata
+          time 10:00
+        task getfields
+          trigger getdata eq complete
+        task plotftg_other
+          trigger getfields eq complete
+        task sap_ntu2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_ntu2web eq complete
+      endfamily
+      family UYonsei
+        edit CENTRE 'UYonsei'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'UYonsei'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task get_some_data
+          time 15:45
+        task get_some_fields
+          trigger get_some_data eq complete
+        task plotftg_other
+          trigger get_some_fields eq complete
+        task sap_UYonsei2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task others2cfs
+          trigger sap_UYonsei2web eq complete
+        task archive_other
+          trigger others2cfs eq complete
+      endfamily
+      family UWash
+        edit CENTRE 'UWash'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'UWash'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task get_some_data
+          time 10:00
+        task get_some_fields
+          trigger get_some_data eq complete
+        task plotftg_other
+          trigger get_some_fields eq complete
+        task sap_UWash2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_UWash2web eq complete
+      endfamily
+      family noaa_hrd
+        edit CENTRE 'noaa_hrd'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'noaa_hrd'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /tparc_dts/limits:linux_cluster
+        task getdata
+          time 10:00
+        task getfields
+          trigger getdata eq complete
+        task plotftg_other
+          trigger getfields eq complete
+        task sap_noaa_hrd2web
+          trigger plotftg_other eq complete and /tparc_dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_noaa_hrd2web eq complete
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'sap_other_centres'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'sap_other_centres'
+      time 22:00
+  endfamily
+  family post_process
+    trigger ( main:YMD ge pop:YMD)
+    repeat date YMD 20090327 20190101 1
+    edit EMOS_BASE '00'
+    edit QUEUE 'emos'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit SMSOUT '/vol/emos_nc/output'
+    inlimit /tparc_dts/limits:linux_cluster
+    task fixed_cases
+      time 10:00
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'post_process'
+    task logfiles
+      late -s +00:05 -c +00:15
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'post_process'
+      time 19:00
+  endfamily
+endsuite
+suite dts
+  edit USER 'emos'
+  edit SCHOST 'c1b'
+  edit WSHOST 'swarm'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0014/log'
+  edit EMOS_TYPE '1'
+  edit USE_YMD 'true'
+  edit YMD '20080901'
+  edit DATEMASK '*.*.*'
+  edit VERSION '0014'
+  edit INIEXPVER '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'mc'
+  edit USER_PRIORITY '70'
+  edit PRIORITY '70'
+  edit ININPES '16'
+  edit NPROCA '16'
+  edit NPROCB '1'
+  edit SVMODE 'tg'
+  edit REINITIALIZE 'false'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/dts/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/dts/include'
+  edit ACCOUNT 'oodts'
+  edit STREAM 'EF'
+  edit EMOS_STREAM 'EF'
+  edit MARS_DB 'marser'
+  edit EPSTYPE 'sv'
+  edit MEMBER '0'
+  edit INILEVELS '91'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit FCGROUP 'fc0'
+  edit SMSLOGHOST 'c1b'
+  edit SMSLOGPORT '9316'
+  edit SVTHREADS '2'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/s1b/emos_esuite/emos_data/0014/log'
+  edit SMSOUT '/s1b/emos_esuite/emos_data/0014/log'
+  edit SLEEPTIME '1'
+  inlimit /limits:c1b
+  clock hybrid 
+  family limits
+    limit c1b 5
+    limit mars 3
+    limit webplots 3
+    limit swarm 3
+  endfamily
+  family main
+    repeat date YMD 20080901 20121212 1
+    family make
+      edit EMOS_BASE '00'
+      task setup
+      task links
+        trigger setup eq complete
+      task datalinks
+        trigger links eq complete and setup eq complete
+      family bins
+        trigger datalinks eq complete
+        task ifs
+        task prepdata
+        task mc_tools
+      endfamily
+    endfamily
+    family 00
+      edit EMOS_BASE '00'
+      task control
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+        time 10:35
+      family case1
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case1'
+        edit REGIONNR '1'
+        edit INISTEP '42'
+        edit FCLENGTH '30'
+        edit ALAT1 '47.3'
+        edit ALON1 '13.5'
+        edit ALAT3 '27.8'
+        edit ALON3 '37.7'
+        edit DELTA_HOUR '42'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case2
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case2'
+        edit REGIONNR '2'
+        edit INISTEP '54'
+        edit FCLENGTH '30'
+        edit ALAT1 '46.3'
+        edit ALON1 '342.9'
+        edit ALAT3 '26.9'
+        edit ALON3 '7.2'
+        edit DELTA_HOUR '54'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case3
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case3'
+        edit REGIONNR '3'
+        edit INISTEP '66'
+        edit FCLENGTH '30'
+        edit ALAT1 '49.5'
+        edit ALON1 '353.7'
+        edit ALAT3 '30.1'
+        edit ALON3 '18'
+        edit DELTA_HOUR '66'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case4
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case4'
+        edit REGIONNR '4'
+        edit INISTEP '42'
+        edit FCLENGTH '42'
+        edit ALAT1 '48.1'
+        edit ALON1 '353.6'
+        edit ALAT3 '28.6'
+        edit ALON3 '17.8'
+        edit DELTA_HOUR '42'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case5
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case5'
+        edit REGIONNR '5'
+        edit INISTEP '54'
+        edit FCLENGTH '30'
+        edit ALAT1 '48.9'
+        edit ALON1 '356.5'
+        edit ALAT3 '29.4'
+        edit ALON3 '20.8'
+        edit DELTA_HOUR '54'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case6
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case6'
+        edit REGIONNR '6'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case7
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case7'
+        edit REGIONNR '7'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case8
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case8'
+        edit REGIONNR '8'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case9
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case9'
+        edit REGIONNR '9'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+      family case10
+        trigger /dts/main/make eq complete and ./control eq complete
+        edit FSFAMILY 'mc/case10'
+        edit REGIONNR '10'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        inlimit /dts/limits:c1b
+        task getini
+        task inidata_sv
+          trigger getini eq complete
+          edit NPES '16'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit CPUTIME '1000'
+          edit STACK '450'
+        task sv
+          trigger inidata_sv eq complete
+          edit MEM '890'
+          edit NPES '42'
+          edit THREADS '2'
+          edit CPUTIME '20000'
+        task sv2gg
+          trigger sv eq complete
+          edit EMOS_TYPE '0'
+        task sv_te
+          trigger sv2gg eq complete
+        task sv2fdb
+          trigger sv_te eq complete
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit EMOS_BASE '00'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'main'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'main'
+      time 15:00
+  endfamily
+  family lag
+    trigger ( main:YMD ge lag:YMD)
+    repeat date YMD 20080901 20121212 1
+    inlimit /dts/limits:mars
+    family 00
+      edit EMOS_BASE '00'
+      edit SUBFSFAMILY ''
+      task archivecontrol
+        trigger /dts/main/00/control eq complete
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+      family case1
+        trigger ./archivecontrol eq complete and /dts/main/00/case1 eq complete
+        edit FSFAMILY 'mc/case1'
+        edit REGIONNR '1'
+        edit INISTEP '42'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '42'
+        task svsave
+        task archive_sv
+      endfamily
+      family case2
+        trigger ./archivecontrol eq complete and /dts/main/00/case2 eq complete
+        edit FSFAMILY 'mc/case2'
+        edit REGIONNR '2'
+        edit INISTEP '54'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '54'
+        task svsave
+        task archive_sv
+      endfamily
+      family case3
+        trigger ./archivecontrol eq complete and /dts/main/00/case3 eq complete
+        edit FSFAMILY 'mc/case3'
+        edit REGIONNR '3'
+        edit INISTEP '66'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '66'
+        task svsave
+        task archive_sv
+      endfamily
+      family case4
+        trigger ./archivecontrol eq complete and /dts/main/00/case4 eq complete
+        edit FSFAMILY 'mc/case4'
+        edit REGIONNR '4'
+        edit INISTEP '42'
+        edit FCLENGTH '42'
+        edit DELTA_HOUR '42'
+        task svsave
+        task archive_sv
+      endfamily
+      family case5
+        trigger ./archivecontrol eq complete and /dts/main/00/case5 eq complete
+        edit FSFAMILY 'mc/case5'
+        edit REGIONNR '5'
+        edit INISTEP '54'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '54'
+        task svsave
+        task archive_sv
+      endfamily
+      family case6
+        trigger ./archivecontrol eq complete and /dts/main/00/case6 eq complete
+        edit FSFAMILY 'mc/case6'
+        edit REGIONNR '6'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave
+        task archive_sv
+      endfamily
+      family case7
+        trigger ./archivecontrol eq complete and /dts/main/00/case7 eq complete
+        edit FSFAMILY 'mc/case7'
+        edit REGIONNR '7'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave
+        task archive_sv
+      endfamily
+      family case8
+        trigger ./archivecontrol eq complete and /dts/main/00/case8 eq complete
+        edit FSFAMILY 'mc/case8'
+        edit REGIONNR '8'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave
+        task archive_sv
+      endfamily
+      family case9
+        trigger ./archivecontrol eq complete and /dts/main/00/case9 eq complete
+        edit FSFAMILY 'mc/case9'
+        edit REGIONNR '9'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave
+        task archive_sv
+      endfamily
+      family case10
+        trigger ./archivecontrol eq complete and /dts/main/00/case10 eq complete
+        edit FSFAMILY 'mc/case10'
+        edit REGIONNR '10'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task svsave
+        task archive_sv
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGTASK 'lag'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'lag'
+      time 13:00
+  endfamily
+  family pop
+    trigger ( main:YMD ge pop:YMD)
+    repeat date YMD 20080901 20121212 1
+    edit EMOS_BASE '00'
+    inlimit /dts/limits:webplots
+    family 00
+      edit SUBFSFAMILY ''
+      edit HOUR '0'
+      task plotcontrol
+        trigger /dts/main/00/control eq complete
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+      task getobslist
+        trigger plotcontrol eq complete
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+      family case1
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case1 eq complete
+        edit FSFAMILY 'mc/case1'
+        edit INISTEP '42'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '42'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case2
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case2 eq complete
+        edit FSFAMILY 'mc/case2'
+        edit INISTEP '54'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '54'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case3
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case3 eq complete
+        edit FSFAMILY 'mc/case3'
+        edit INISTEP '66'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '66'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case4
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case4 eq complete
+        edit FSFAMILY 'mc/case4'
+        edit INISTEP '42'
+        edit FCLENGTH '42'
+        edit DELTA_HOUR '42'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case5
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case5 eq complete
+        edit FSFAMILY 'mc/case5'
+        edit INISTEP '54'
+        edit FCLENGTH '30'
+        edit DELTA_HOUR '54'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case6
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case6 eq complete
+        edit FSFAMILY 'mc/case6'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case7
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case7 eq complete
+        edit FSFAMILY 'mc/case7'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case8
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case8 eq complete
+        edit FSFAMILY 'mc/case8'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case9
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case9 eq complete
+        edit FSFAMILY 'mc/case9'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+      family case10
+        trigger /dts/main/make eq complete and ./plotcontrol eq complete and /dts/main/00/case10 eq complete
+        edit FSFAMILY 'mc/case10'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        task plotftg
+          edit QUEUE 'emos'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /dts/limits:swarm
+      endfamily
+    endfamily
+    task cases2ftp
+      trigger /dts/main/00/control eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      inlimit /dts/limits:swarm
+    task cases2web
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      inlimit /dts/limits:swarm
+    task clean
+      trigger ./00 eq complete and cases2web eq complete
+    task clean_ws
+      trigger ./00 eq complete and cases2web eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      inlimit /dts/limits:swarm
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'pop'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete and ./clean eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'pop'
+      time 15:00
+  endfamily
+  family sap_other_centres
+    trigger ( main:YMD ge pop:YMD)
+    repeat date YMD 20080901 20121212 1
+    edit EMOS_BASE '00'
+    family 00
+      family ukmo
+        edit CENTRE 'metoffice'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'egrr'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+        task getdata
+          time 11:00
+        task plotftg_other
+          trigger getdata eq complete
+        task sap_other2web
+          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_other2web eq complete
+      endfamily
+      family meteofrance
+        edit CENTRE 'meteofrance'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'lfpw'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+        task getdata
+          time 11:00
+        task getfields
+          trigger getdata eq complete
+        task plotftg_other
+          trigger getfields eq complete
+        task sap_meteofrance2web
+          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_meteofrance2web eq complete
+      endfamily
+      family uib
+        edit CENTRE 'uib'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'uib'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+        task getdata
+          time 11:00
+        task getfields
+          trigger getdata eq complete
+        task plotftg_other
+          trigger getfields eq complete
+          edit SMSPASS 'stripped'
+        task sap_uib2web
+          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_uib2web eq complete
+      endfamily
+      family cnrm
+        edit CENTRE 'cnrm'
+        edit SUBFSFAMILY ''
+        edit FSFAMILY 'mc/%CENTRE%'
+        edit HOUR '0'
+        edit INISTEP '48'
+        edit FCLENGTH '24'
+        edit CENTRE_ORIGIN 'cnrm'
+        edit SAP_METHOD '0'
+        edit SAP_TYPE 'svar'
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /dts/limits:swarm
+        task getdata
+          time 11:00
+        task getfields
+          trigger getdata eq complete
+        task plotftg_other
+          trigger getfields eq complete
+        task sap_cnrm2web
+          trigger plotftg_other eq complete and /dts/pop/cases2web eq complete
+        task archive_other
+          trigger sap_cnrm2web eq complete
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'sap_other_centres'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'sap_other_centres'
+      time 15:00
+  endfamily
+  family post_process
+    trigger ( main:YMD ge pop:YMD)
+    repeat date YMD 20080901 20121212 1
+    edit EMOS_BASE '00'
+    edit QUEUE 'emos'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit SMSOUT '/vol/emos_nc/output'
+    inlimit /dts/limits:swarm
+    task monitor
+      time 07:00
+    task extraobs
+      time 14:05
+    task sendrequest
+      trigger extraobs eq complete
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'post_process'
+    task logfiles
+      late -s +00:05 -c +00:15
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'post_process'
+      time 15:00
+  endfamily
+endsuite
+suite seas_fr3_back
+  edit VERSION '0001'
+  edit EXPVER '0001'
+  edit SCHOST 'hpce'
+  edit WSHOST 'swarm'
+  edit WSLOGDIR '/vol/emos/output'
+  edit SCLOGDIR '/hpce/emos_dir/0001/log'
+  edit STREAM 'MMSF'
+  edit REINITIALIZE 'false'
+  edit EPSTYPE 'fc'
+  edit EMOS_BASE '00'
+  edit DATEMASK '*.*.*'
+  edit START_DAY '19781101'
+  edit END_DAY '20071201'
+  edit YMD '19781101'
+  edit USE_YMD 'true'
+  edit FCLENGTH '5160'
+  edit FCTOTAL '11'
+  edit OCTOTAL '1'
+  edit OCGROUP 'an0'
+  edit RUNCOUPLE '1'
+  edit OCSYSTEM '0'
+  edit OCMETHOD '1'
+  edit ORIGIN 'LFPW'
+  edit FDB_ROOT_FR '/fdb'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit USER_PRIORITY '50'
+  edit FIRST_DAY '0'
+  edit EMOS_TYPE 'fc'
+  edit EMOS_TIME_STEP_H '0000'
+  edit EMOS_STREAM 'DA'
+  edit MARS_DB 'marsod'
+  edit FCNPES '1'
+  edit ANNPES '1'
+  edit SMSHOME '/vol/emos/output'
+  edit SMSFILES '/home/ma/emos/def/seas_fr3_back/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/seas_fr3_back/include'
+  edit ACCOUNT 'oosu'
+  edit USER 'emos'
+  edit MEMBER '0'
+  edit RUNBACK '1'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/hpce/emos_dir/0001/log'
+  edit SMSOUT '/hpce/emos_dir/0001/log'
+  edit SMSLOGHOST 'hpce-batch'
+  edit SMSLOGPORT '9316'
+  edit HOUR '00'
+  edit FSFAMILY 'seas'
+  edit SLEEPTIME '1'
+  inlimit /limits:hpce
+  clock hybrid 
+  family limits
+    limit retrieve 2
+    limit mars 2
+    limit ws 6
+  endfamily
+  family make
+    task setup
+    task mmsf_tools
+      trigger setup eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      inlimit /limits:swarm
+      inlimit /seas_fr3_back/limits:ws
+    task sc_tools
+      trigger setup eq complete
+    task logfiles
+      trigger setup eq complete and sc_tools eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      edit LOGTASK 'make'
+  endfamily
+  family main
+    trigger make eq complete
+    repeat enumerated YMD "19790101" "19800101" "19810101" "19820101" "19830101" "19840101" "19850101" "19860101" "19870101" "19880101" "19890101" "19900101" "19910101" "19920101" "19930101" "19940101" "19950101" "19960101" "19970101" "19980101" "19990101" "20000101" "20010101" "20020101" "20030101" "20040101" "20050101" "20060101" "20070101" "19790201" "19800201" "19810201" "19820201" "19830201" "19840201" "19850201" "19860201" "19870201" "19880201" "19890201" "19900201" "19910201" "19920201" "19930201" "19940201" "19950201" "19960201" "19970201" "19980201" "19990201" "20000201" "20010201" "20020201" "20030201" "20040201" "20050201" "20060201" "20070201" "19790301" "19800301" "19810301" "19820301" "19830301" "19840301" "19850301" "19860301" "19870301" "19880301" "19890301" "19900301" "19910301" "19920301" "19930301" "19940301" "19950301" "19960301" "19970301" "19980301" "19990301" "20000301" "20010301" "20020301" "20030301" "20040301" "20050301" "20060301" "20070301" "19790401" "19800401" "19810401" "19820401" "19830401" "19840401" "19850401" "19860401" "19870401" "19880401" "19890401" "19900401" "19910401" "19920401" "19930401" "19940401" "19950401" "19960401" "19970401" "19980401" "19990401" "20000401" "20010401" "20020401" "20030401" "20040401" "20050401" "20060401" "20070401" "19790501" "19800501" "19810501" "19820501" "19830501" "19840501" "19850501" "19860501" "19870501" "19880501" "19890501" "19900501" "19910501" "19920501" "19930501" "19940501" "19950501" "19960501" "19970501" "19980501" "19990501" "20000501" "20010501" "20020501" "20030501" "20040501" "20050501" "20060501" "20070501" "19790601" "19800601" "19810601" "19820601" "19830601" "19840601" "19850601" "19860601" "19870601" "19880601" "19890601" "19900601" "19910601" "19920601" "19930601" "19940601" "19950601" "19960601" "19970601" "19980601" "19990601" "20000601" "20010601" "20020601" "20030601" "20040601" "20050601" "20060601" "20070601" "19790701" "19800701" "19810701" "19820701" "19830701" "19840701" "19850701" "19860701" "19870701" "19880701" "19890701" "19900701" "19910701" "19920701" "19930701" "19940701" "19950701" "19960701" "19970701" "19980701" "19990701" "20000701" "20010701" "20020701" "20030701" "20040701" "20050701" "20060701" "20070701" "19790801" "19800801" "19810801" "19820801" "19830801" "19840801" "19850801" "19860801" "19870801" "19880801" "19890801" "19900801" "19910801" "19920801" "19930801" "19940801" "19950801" "19960801" "19970801" "19980801" "19990801" "20000801" "20010801" "20020801" "20030801" "20040801" "20050801" "20060801" "20070801" "19790901" "19800901" "19810901" "19820901" "19830901" "19840901" "19850901" "19860901" "19870901" "19880901" "19890901" "19900901" "19910901" "19920901" "19930901" "19940901" "19950901" "19960901" "19970901" "19980901" "19990901" "20000901" "20010901" "20020901" "20030901" "20040901" "20050901" "20060901" "20070901" "19791001" "19801001" "19811001" "19821001" "19831001" "19841001" "19851001" "19861001" "19871001" "19881001" "19891001" "19901001" "19911001" "19921001" "19931001" "19941001" "19951001" "19961001" "19971001" "19981001" "19991001" "20001001" "20011001" "20021001" "20031001" "20041001" "20051001" "20061001" "20071001" "19781101" "19791101" "19801101" "19811101" "19821101" "19831101" "19841101" "19851101" "19861101" "19871101" "19881101" "19891101" "19901101" "19911101" "19921101" "19931101" "19941101" "19951101" "19961101" "19971101" "19981101" "19991101" "20001101" "20011101" "20021101" "20031101" "20041101" "20051101" "20061101" "20071101" "19781201" "19791201" "19801201" "19811201" "19821201" "19831201" "19841201" "19851201" "19861201" "19871201" "19881201" "19891201" "19901201" "19911201" "19921201" "19931201" "19941201" "19951201" "19961201" "19971201" "19981201" "19991201" "20001201" "20011201" "20021201" "20031201" "20041201" "20051201" "20061201" "20071201"
+    edit LOGTASK 'main'
+    family fc
+      family fc0
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc0'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc1
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc1'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc2
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc2'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc3
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc3'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc4
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc4'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc5
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc5'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc6
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc6'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc7
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc7'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc8
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc8'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc9
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc9'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+      family fc10
+        edit FCNUM 'fcnum'
+        edit FCGROUP 'fc10'
+        task fr2fdb
+          inlimit /seas_fr3_back/limits:retrieve
+        task extrafields_fr
+          trigger fr2fdb eq complete
+        task mm_sfc_fr
+          trigger fr2fdb eq complete and extrafields_fr eq complete
+        task mm_ua_fr
+          trigger fr2fdb eq complete and mm_sfc_fr eq complete
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      trigger fc eq complete and logfilestore eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+  family lag
+    trigger make eq complete
+    repeat enumerated YMD "19790101" "19800101" "19810101" "19820101" "19830101" "19840101" "19850101" "19860101" "19870101" "19880101" "19890101" "19900101" "19910101" "19920101" "19930101" "19940101" "19950101" "19960101" "19970101" "19980101" "19990101" "20000101" "20010101" "20020101" "20030101" "20040101" "20050101" "20060101" "20070101" "19790201" "19800201" "19810201" "19820201" "19830201" "19840201" "19850201" "19860201" "19870201" "19880201" "19890201" "19900201" "19910201" "19920201" "19930201" "19940201" "19950201" "19960201" "19970201" "19980201" "19990201" "20000201" "20010201" "20020201" "20030201" "20040201" "20050201" "20060201" "20070201" "19790301" "19800301" "19810301" "19820301" "19830301" "19840301" "19850301" "19860301" "19870301" "19880301" "19890301" "19900301" "19910301" "19920301" "19930301" "19940301" "19950301" "19960301" "19970301" "19980301" "19990301" "20000301" "20010301" "20020301" "20030301" "20040301" "20050301" "20060301" "20070301" "19790401" "19800401" "19810401" "19820401" "19830401" "19840401" "19850401" "19860401" "19870401" "19880401" "19890401" "19900401" "19910401" "19920401" "19930401" "19940401" "19950401" "19960401" "19970401" "19980401" "19990401" "20000401" "20010401" "20020401" "20030401" "20040401" "20050401" "20060401" "20070401" "19790501" "19800501" "19810501" "19820501" "19830501" "19840501" "19850501" "19860501" "19870501" "19880501" "19890501" "19900501" "19910501" "19920501" "19930501" "19940501" "19950501" "19960501" "19970501" "19980501" "19990501" "20000501" "20010501" "20020501" "20030501" "20040501" "20050501" "20060501" "20070501" "19790601" "19800601" "19810601" "19820601" "19830601" "19840601" "19850601" "19860601" "19870601" "19880601" "19890601" "19900601" "19910601" "19920601" "19930601" "19940601" "19950601" "19960601" "19970601" "19980601" "19990601" "20000601" "20010601" "20020601" "20030601" "20040601" "20050601" "20060601" "20070601" "19790701" "19800701" "19810701" "19820701" "19830701" "19840701" "19850701" "19860701" "19870701" "19880701" "19890701" "19900701" "19910701" "19920701" "19930701" "19940701" "19950701" "19960701" "19970701" "19980701" "19990701" "20000701" "20010701" "20020701" "20030701" "20040701" "20050701" "20060701" "20070701" "19790801" "19800801" "19810801" "19820801" "19830801" "19840801" "19850801" "19860801" "19870801" "19880801" "19890801" "19900801" "19910801" "19920801" "19930801" "19940801" "19950801" "19960801" "19970801" "19980801" "19990801" "20000801" "20010801" "20020801" "20030801" "20040801" "20050801" "20060801" "20070801" "19790901" "19800901" "19810901" "19820901" "19830901" "19840901" "19850901" "19860901" "19870901" "19880901" "19890901" "19900901" "19910901" "19920901" "19930901" "19940901" "19950901" "19960901" "19970901" "19980901" "19990901" "20000901" "20010901" "20020901" "20030901" "20040901" "20050901" "20060901" "20070901" "19791001" "19801001" "19811001" "19821001" "19831001" "19841001" "19851001" "19861001" "19871001" "19881001" "19891001" "19901001" "19911001" "19921001" "19931001" "19941001" "19951001" "19961001" "19971001" "19981001" "19991001" "20001001" "20011001" "20021001" "20031001" "20041001" "20051001" "20061001" "20071001" "19781101" "19791101" "19801101" "19811101" "19821101" "19831101" "19841101" "19851101" "19861101" "19871101" "19881101" "19891101" "19901101" "19911101" "19921101" "19931101" "19941101" "19951101" "19961101" "19971101" "19981101" "19991101" "20001101" "20011101" "20021101" "20031101" "20041101" "20051101" "20061101" "20071101" "19781201" "19791201" "19801201" "19811201" "19821201" "19831201" "19841201" "19851201" "19861201" "19871201" "19881201" "19891201" "19901201" "19911201" "19921201" "19931201" "19941201" "19951201" "19961201" "19971201" "19981201" "19991201" "20001201" "20011201" "20021201" "20031201" "20041201" "20051201" "20061201" "20071201"
+    edit LOGTASK 'lag'
+    family archive
+      trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc eq complete)
+      edit SMSFILES '/home/ma/emos/def/seas_fr3_back/smsfiles/archive'
+      inlimit /limits:mars
+      inlimit /seas_fr3_back/limits:mars
+      task daily_sfc_fr
+        label files ""
+        event fdb
+      task daily_ua_fr
+        trigger daily_sfc_fr eq complete
+        label files ""
+        event fdb
+      task mm_sfc_fr
+        label files ""
+        event fdb
+      task mm_ua_fr
+        label files ""
+        event fdb
+    endfamily
+    family process
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      inlimit /limits:swarm
+      inlimit /seas_fr3_back/limits:ws
+      family fc0
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc0 eq complete)
+        edit FCGROUP 'fc0'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc1
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc1 eq complete)
+        edit FCGROUP 'fc1'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc2
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc2 eq complete)
+        edit FCGROUP 'fc2'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc3
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc3 eq complete)
+        edit FCGROUP 'fc3'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc4
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc4 eq complete)
+        edit FCGROUP 'fc4'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc5
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc5 eq complete)
+        edit FCGROUP 'fc5'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc6
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc6 eq complete)
+        edit FCGROUP 'fc6'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc7
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc7 eq complete)
+        edit FCGROUP 'fc7'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc8
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc8 eq complete)
+        edit FCGROUP 'fc8'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc9
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc9 eq complete)
+        edit FCGROUP 'fc9'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+      family fc10
+        trigger ( /seas_fr3_back/main:YMD gt /seas_fr3_back/lag:YMD) or ( /seas_fr3_back/main:YMD eq /seas_fr3_back/lag:YMD and /seas_fr3_back/main/fc/fc10 eq complete)
+        edit FCGROUP 'fc10'
+        edit FCNUM 'fcnum'
+        task nino_sst_fr
+        task nino_atmos_fr
+          trigger nino_sst_fr eq complete
+        task tcyc_fr
+          trigger nino_atmos_fr eq complete
+      endfamily
+    endfamily
+    family clean
+      trigger archive eq complete and process eq complete
+      task postclean_fdb
+      task clean_sc
+      task clean_ws
+        edit QUEUE 'emos'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+        edit LOGDIR '/vol/emos/output'
+        edit SMSOUT '/vol/emos/output'
+        inlimit /limits:swarm
+        inlimit /seas_fr3_back/limits:ws
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      trigger archive eq complete and process eq complete and clean eq complete and logfilestore eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID%'
+      edit LOGDIR '/vol/emos/output'
+      edit SMSOUT '/vol/emos/output'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+endsuite
+suite cweb
+  edit USER 'emos'
+  edit SCHOST 'c1a'
+  edit SCHOST_BKUP 'c1b'
+  edit STHOST '/s1a'
+  edit STHOST_BKUP '/s1b'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/s1a/emos_esuite/emos_data/9001/log'
+  edit DATEMASK '*.*.*'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSLOGHOST 'c1a'
+  edit SMSLOGPORT '9316'
+  edit ACCOUNT 'oocweb'
+  edit VERSION '9001'
+  edit EPSVERSION '0001'
+  edit RFVERSION '0001'
+  edit SMSTRIES '1'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '00'
+  edit FIRST_DAY '0'
+  edit USE_YMD 'true'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/cweb'
+  edit SMSINCLUDE '/home/ma/emos/def/cweb/include'
+  edit FSFAMILY '/'
+  edit XBINS '/home/ma/emos/bin'
+  edit STREAM 'undef'
+  edit EPSTYPE 'undef'
+  edit MEMBER '0'
+  edit EMOS_TIME_STEP_H '00'
+  edit SUITE_START '20091001'
+  edit LOW_RESOLUTION '1.5'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family limits
+    limit retrieve 10
+    limit purge 1
+  endfamily
+  family o
+    repeat date YMD 20091001 20121212 1
+    edit STREAM 'oper'
+    family 00
+      trigger ( /cweb/o:YMD lt /o/main:YMD) or ( /cweb/o:YMD eq /o/main:YMD and /o/main/00/fc eq complete)
+      edit QUEUE 'ns'
+      edit QUEUE_EPILOG 'ns'
+      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
+      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
+      edit DELTA_DAY '1'
+      edit EMOS_BASE '00'
+      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
+      inlimit /limits:c1a
+      task purge
+        inlimit /cweb/limits:purge
+        label info ""
+      family feed
+        trigger purge eq complete
+        inlimit /cweb/limits:retrieve
+        task an_sfc
+          label info ""
+          label grid ""
+        task an_pl
+          label info ""
+          label grid ""
+        task an_ml
+          label info ""
+          label grid ""
+        task fc_sfc
+          label info ""
+          label grid ""
+        task fc_pl
+          label info ""
+          label grid ""
+        task fc_ml
+          label info ""
+          label grid ""
+        task fc_wave
+          label info ""
+          label grid ""
+        task sim
+          trigger ( /o/lag:YMD gt /cweb/o:YMD) or ( /o/lag:YMD eq /cweb/o:YMD and /o/lag/00/satim eq complete)
+          label info ""
+          label grid ""
+      endfamily
+      task check
+        trigger feed eq complete
+        label info ""
+      task ready
+        trigger check eq complete
+        label info ""
+    endfamily
+    family 12
+      trigger ( /cweb/o:YMD lt /o/main:YMD) or ( /cweb/o:YMD eq /o/main:YMD and /o/main/12/fc eq complete)
+      edit QUEUE 'ns'
+      edit QUEUE_EPILOG 'ns'
+      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
+      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
+      edit DELTA_DAY '0'
+      edit EMOS_BASE '12'
+      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
+      inlimit /limits:c1a
+      task purge
+        inlimit /cweb/limits:purge
+        label info ""
+      family feed
+        trigger purge eq complete
+        inlimit /cweb/limits:retrieve
+        task an_sfc
+          label info ""
+          label grid ""
+        task an_pl
+          label info ""
+          label grid ""
+        task an_ml
+          label info ""
+          label grid ""
+        task fc_sfc
+          label info ""
+          label grid ""
+        task fc_pl
+          label info ""
+          label grid ""
+        task fc_ml
+          label info ""
+          label grid ""
+        task fc_wave
+          label info ""
+          label grid ""
+        task sim
+          trigger ( /o/lag:YMD gt /cweb/o:YMD) or ( /o/lag:YMD eq /cweb/o:YMD and /o/lag/12/satim eq complete)
+          label info ""
+          label grid ""
+      endfamily
+      task check
+        trigger feed eq complete
+        label info ""
+      task ready
+        trigger check eq complete
+        label info ""
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/cweb'
+      edit LOGTASK 'o'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete and ./12 eq complete and logfilestore eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/cweb'
+      edit LOGTASK 'o'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+  family mc
+    repeat date YMD 20091001 20121212 1
+    edit STREAM 'enfo'
+    family 00
+      trigger ( /cweb/mc:YMD lt /mc/main:YMD) or ( /cweb/mc:YMD eq /mc/main:YMD and /mc/main/00/legB/postproc eq complete)
+      edit QUEUE 'ns'
+      edit QUEUE_EPILOG 'ns'
+      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
+      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
+      edit DELTA_DAY '1'
+      edit EMOS_BASE '00'
+      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
+      inlimit /limits:c1a
+      task purge
+        inlimit /cweb/limits:purge
+        label info ""
+      family feed
+        trigger purge eq complete
+        inlimit /cweb/limits:retrieve
+        family leg_A
+          edit LEG 'A'
+          task cf_sfc
+            label info ""
+            label grid ""
+          task cf_pl
+            label info ""
+            label grid ""
+          task cf_wave_sfc
+            label info ""
+            label grid ""
+          task pf_sfc
+            label info ""
+            label grid ""
+          task pf_pl
+            label info ""
+            label grid ""
+          task pf_wave_sfc
+            label info ""
+            label grid ""
+          task efi_sfc
+            label info ""
+            label grid ""
+        endfamily
+        family leg_B
+          edit LEG 'B'
+          task cf_sfc
+            label info ""
+            label grid ""
+          task cf_pl
+            label info ""
+            label grid ""
+          task cf_wave_sfc
+            label info ""
+            label grid ""
+          task pf_sfc
+            label info ""
+            label grid ""
+          task pf_pl
+            label info ""
+            label grid ""
+          task pf_wave_sfc
+            label info ""
+            label grid ""
+        endfamily
+        family leg_C
+          edit LEG 'C'
+          task cf_sfc
+            label info ""
+            label grid ""
+          task cf_pl
+            label info ""
+            label grid ""
+          task cf_wave_sfc
+            label info ""
+            label grid ""
+          task pf_sfc
+            label info ""
+            label grid ""
+          task pf_pl
+            label info ""
+            label grid ""
+          task pf_wave_sfc
+            label info ""
+            label grid ""
+        endfamily
+      endfamily
+      task check
+        trigger feed eq complete
+        label info ""
+      task ready
+        trigger check eq complete
+        label info ""
+    endfamily
+    family 12
+      trigger ( /cweb/mc:YMD lt /mc/main:YMD) or ( /cweb/mc:YMD eq /mc/main:YMD and /mc/main/12/legB/postproc eq complete)
+      edit QUEUE 'ns'
+      edit QUEUE_EPILOG 'ns'
+      edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/s1a/emos_esuite/emos_data/9001/log'
+      edit SMSOUT '/s1a/emos_esuite/emos_data/9001/log'
+      edit DELTA_DAY '0'
+      edit EMOS_BASE '12'
+      edit SMSFILES '/home/ma/emos/def/cweb/cweb'
+      inlimit /limits:c1a
+      task purge
+        inlimit /cweb/limits:purge
+        label info ""
+      family feed
+        trigger purge eq complete
+        inlimit /cweb/limits:retrieve
+        family leg_A
+          edit LEG 'A'
+          task cf_sfc
+            label info ""
+            label grid ""
+          task cf_pl
+            label info ""
+            label grid ""
+          task cf_wave_sfc
+            label info ""
+            label grid ""
+          task pf_sfc
+            label info ""
+            label grid ""
+          task pf_pl
+            label info ""
+            label grid ""
+          task pf_wave_sfc
+            label info ""
+            label grid ""
+          task efi_sfc
+            label info ""
+            label grid ""
+        endfamily
+        family leg_B
+          edit LEG 'B'
+          task cf_sfc
+            label info ""
+            label grid ""
+          task cf_pl
+            label info ""
+            label grid ""
+          task cf_wave_sfc
+            label info ""
+            label grid ""
+          task pf_sfc
+            label info ""
+            label grid ""
+          task pf_pl
+            label info ""
+            label grid ""
+          task pf_wave_sfc
+            label info ""
+            label grid ""
+        endfamily
+        family leg_C
+          edit LEG 'C'
+          task cf_sfc
+            label info ""
+            label grid ""
+          task cf_pl
+            label info ""
+            label grid ""
+          task cf_wave_sfc
+            label info ""
+            label grid ""
+          task pf_sfc
+            label info ""
+            label grid ""
+          task pf_pl
+            label info ""
+            label grid ""
+          task pf_wave_sfc
+            label info ""
+            label grid ""
+        endfamily
+      endfamily
+      task check
+        trigger feed eq complete
+        label info ""
+      task ready
+        trigger check eq complete
+        label info ""
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/cweb'
+      edit LOGTASK 'mc'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete and ./12 eq complete and logfilestore eq complete
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/cweb'
+      edit LOGTASK 'mc'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+endsuite
+suite emc_33r1
+  edit USER 'emos'
+  edit SCHOST 'c1a'
+  edit SCHOST_BKUP 'hpcf'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/emos_esuite/emos_data/0039/log'
+  edit USE_YMD 'true'
+  edit YMD '20080203'
+  edit DATEMASK '*.*.*'
+  edit VERSION '0039'
+  edit INIEXPVER '0039'
+  edit TCINIEXPVER '0039'
+  edit FIRST_DAY '1'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '12'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'mc'
+  edit IMPL_DATE '2012123112'
+  edit EVERSION '0001'
+  edit USER_PRIORITY '70'
+  edit ININPES '16'
+  edit FCNPES '16'
+  edit PGNPES '32'
+  edit ANNPES '4'
+  edit REINITIALIZE 'false'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/emc_33r1'
+  edit SMSINCLUDE '/home/ma/emos/def/emc_33r1/include'
+  edit ACCOUNT 'oeenfo'
+  edit STREAM 'EF'
+  edit EMOS_STREAM 'EF'
+  edit ENSEMBLES '50'
+  edit ENS_SIZE '50'
+  edit MARS_DB 'marsod'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit INILEVELS '91'
+  edit INIPERIOD_4D '6'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit RUNHINDCAST '0'
+  edit ERA40END '2002073100'
+  edit NH_YEARS '18'
+  edit NH_WEEKS '2'
+  edit DELTA_DAY_M '-15'
+  edit DELTA_DAY_P '25'
+  edit FCGTYPE 'l_2'
+  edit EPSFCGTYPE 'l_2'
+  edit LUSE_RSTRHBIAS 'true'
+  edit FCGROUP 'fc0'
+  edit SMSLOGHOST 'c1a'
+  edit SMSLOGPORT '9316'
+  edit OCNPES_OC '4'
+  edit OCNPES_IFS '28'
+  edit OD_PROJ 'od'
+  edit SMSURLBASE 'http://datasvc.ecmwf.int/twiki/bin/view/Main'
+  edit SMSURL 'CurrentAndOldESuites'
+  edit SUITE_START '20080204'
+  edit PRODUCE_EPS_ML '0'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit.35r3 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/s1a/emos_esuite/emos_data/0039/log'
+  edit SMSOUT '/s1a/emos_esuite/emos_data/0039/log'
+  edit STHOST '/s1a'
+  edit COURTESY '0'
+  edit SLEEPTIME '1'
+  inlimit /limits:hpce
+  clock hybrid 
+  family efi_curop
+    edit SMSFILES '/home/ma/emos/def/o/mc/efi_hdc'
+    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+    edit SMSURL 'GENFO/00'
+    limit ext 30
+    inlimit ext
+    family hind
+      repeat date YMD 20080403 20121212 1
+      edit EMOS_BASE '00'
+      family op
+        family stage
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit ACC '24'
+          edit EFI_STEP1 '00'
+          edit EFI_STEP2 '24'
+          edit RETRIEVE 'stage'
+          inlimit /limits:linux_cluster
+          family all
+            edit RF_NAME 'all'
+            task prep
+          endfamily
+        endfamily
+        family d0105_24
+          edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
+          edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
+          edit ACC '24'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+        endfamily
+        family d0610_24
+          edit EFI_STEP1 '108 120 132 144 168 192 216'
+          edit EFI_STEP2 '132 144 156 168 192 216 240'
+          edit ACC '24'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+        endfamily
+      endfamily
+      family nop
+        family stage
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit ACC '24'
+          edit EFI_STEP1 '00'
+          edit EFI_STEP2 '24'
+          edit RETRIEVE 'stage'
+          inlimit /limits:linux_cluster
+          family all
+            edit RF_NAME 'all'
+            task prep
+          endfamily
+        endfamily
+        family d0105_24
+          edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
+          edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
+          edit ACC '24'
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+        family d0610_24
+          edit EFI_STEP1 '108 120 132 144 168 192 216'
+          edit EFI_STEP2 '132 144 156 168 192 216 240'
+          edit ACC '24'
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+        family d1115_24
+          edit EFI_STEP1 '240 264 288 312 336'
+          edit EFI_STEP2 '264 288 312 336 360'
+          edit ACC '24'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+        family d0102_06
+          edit EFI_STEP1 '006 012 018 024 030 036 042 048'
+          edit EFI_STEP2 '006 012 018 024 030 036 042 048'
+          edit ACC '0'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+        family d0304_06
+          edit EFI_STEP1 '054 060 066 072 078 084 090 096'
+          edit EFI_STEP2 '054 060 066 072 078 084 090 096'
+          edit ACC '0'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+        family d0506_06
+          edit EFI_STEP1 '102 108 114 120 126 132 138 144'
+          edit EFI_STEP2 '102 108 114 120 126 132 138 144'
+          edit ACC '0'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+        family d0708_06
+          edit EFI_STEP1 '150 156 162 168 174 180 186 192'
+          edit EFI_STEP2 '150 156 162 168 174 180 186 192'
+          edit ACC '0'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+        family d0910_06
+          edit EFI_STEP1 '198 204 210 216 222 228 234 240'
+          edit EFI_STEP2 '198 204 210 216 222 228 234 240'
+          edit ACC '0'
+          family 2t
+            edit RF_NAME '2t'
+            task prep
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+    family clim
+      trigger ./clim:YMD lt ./hind:YMD
+      repeat date YMD 20080403 20121212 1
+      edit EMOS_BASE '00'
+      family op
+        family steps24
+          family 000_024
+            edit ACC '24'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '24'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '24'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '24'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '24'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '24'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '24'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '24'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '24'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '24'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '24'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 000_120
+          edit ACC '120'
+          edit EFI_STEP1 '000'
+          edit EFI_STEP2 '120'
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+        endfamily
+        family 024_144
+          edit ACC '120'
+          edit EFI_STEP1 '024'
+          edit EFI_STEP2 '144'
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+        endfamily
+        family 000_240
+          edit ACC '240'
+          edit EFI_STEP1 '000'
+          edit EFI_STEP2 '240'
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+        endfamily
+      endfamily
+      family nop
+        family steps24
+          family 000_024
+            edit ACC '24'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '24'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '24'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '24'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '24'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '24'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '24'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '24'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '24'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '24'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '24'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '24'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '24'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '24'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '24'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_264
+            edit ACC '24'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '264'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 264_288
+            edit ACC '24'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '288'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 288_312
+            edit ACC '24'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '312'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 312_336
+            edit ACC '24'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 336_360
+            edit ACC '24'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '360'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family steps06
+          family 006_006
+            edit ACC '0'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '006'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_012
+            edit ACC '0'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '012'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 018_018
+            edit ACC '0'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '018'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_024
+            edit ACC '0'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 030_030
+            edit ACC '0'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '030'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_036
+            edit ACC '0'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 042_042
+            edit ACC '0'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '042'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_048
+            edit ACC '0'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 054_054
+            edit ACC '0'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '054'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_060
+            edit ACC '0'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 066_066
+            edit ACC '0'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '066'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_072
+            edit ACC '0'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 078_078
+            edit ACC '0'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '078'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_084
+            edit ACC '0'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 090_090
+            edit ACC '0'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '090'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_096
+            edit ACC '0'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 102_102
+            edit ACC '0'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '102'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_108
+            edit ACC '0'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 114_114
+            edit ACC '0'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '114'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_120
+            edit ACC '0'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 126_126
+            edit ACC '0'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '126'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 132_132
+            edit ACC '0'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 138_138
+            edit ACC '0'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '138'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_144
+            edit ACC '0'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 150_150
+            edit ACC '0'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '150'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 156_156
+            edit ACC '0'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '156'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 162_162
+            edit ACC '0'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '162'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_168
+            edit ACC '0'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 174_174
+            edit ACC '0'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '174'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 180_180
+            edit ACC '0'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '180'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 186_186
+            edit ACC '0'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '186'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_192
+            edit ACC '0'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '192'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 198_198
+            edit ACC '0'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '198'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 204_204
+            edit ACC '0'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '204'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 210_210
+            edit ACC '0'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '210'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_216
+            edit ACC '0'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '216'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 222_222
+            edit ACC '0'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '222'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 228_228
+            edit ACC '0'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '228'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 234_234
+            edit ACC '0'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '234'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_240
+            edit ACC '0'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 120_168
+          trigger ./steps24 eq complete
+          edit ACC '48'
+          edit EFI_STEP1 '120'
+          edit EFI_STEP2 '168'
+          family 2t
+            edit RF_NAME '2t'
+            task prep_sort
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep_sort
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep_sort
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep_sort
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep_sort
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep_sort
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep_sort
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep_sort
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep_sort
+          endfamily
+        endfamily
+        family 168_240
+          trigger ./steps24 eq complete
+          edit ACC '72'
+          edit EFI_STEP1 '168'
+          edit EFI_STEP2 '240'
+          family 2t
+            edit RF_NAME '2t'
+            task prep_sort
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep_sort
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep_sort
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep_sort
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep_sort
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep_sort
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep_sort
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep_sort
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep_sort
+          endfamily
+        endfamily
+        family 000_168
+          trigger ./steps24 eq complete
+          edit ACC '168'
+          edit EFI_STEP1 '000'
+          edit EFI_STEP2 '168'
+          family 2t
+            edit RF_NAME '2t'
+            task prep_sort
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep_sort
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep_sort
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep_sort
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep_sort
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep_sort
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep_sort
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep_sort
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep_sort
+          endfamily
+        endfamily
+        family 240_336
+          trigger ./steps24 eq complete
+          edit ACC '96'
+          edit EFI_STEP1 '240'
+          edit EFI_STEP2 '336'
+          family 2t
+            edit RF_NAME '2t'
+            task prep_sort
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep_sort
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep_sort
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep_sort
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep_sort
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep_sort
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep_sort
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep_sort
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep_sort
+          endfamily
+        endfamily
+        family 168_336
+          trigger ./steps24 eq complete
+          edit ACC '168'
+          edit EFI_STEP1 '168'
+          edit EFI_STEP2 '336'
+          family 2t
+            edit RF_NAME '2t'
+            task prep_sort
+          endfamily
+          family 10ff
+            edit RF_NAME '10ff'
+            task prep_sort
+          endfamily
+          family 10fg
+            edit RF_NAME '10fg'
+            task prep_sort
+          endfamily
+          family tp
+            edit RF_NAME 'tp'
+            task prep_sort
+          endfamily
+          family 2tmin
+            edit RF_NAME '2tmin'
+            task prep_sort
+          endfamily
+          family 2tmax
+            edit RF_NAME '2tmax'
+            task prep_sort
+          endfamily
+          family 10dd
+            edit RF_NAME '10dd'
+            task prep_sort
+          endfamily
+          family ts
+            edit RF_NAME 'ts'
+            task prep_sort
+          endfamily
+          family tcc
+            edit RF_NAME 'tcc'
+            task prep_sort
+          endfamily
+          family hsttmax
+            edit RF_NAME 'hsttmax'
+            task prep_sort
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+    family mn
+      trigger ./mn:YMD lt ./clim:YMD
+      repeat date YMD 20080221 20121212 1
+      family 12
+        edit EMOS_BASE '12'
+        family op
+          task stage
+            edit NC_DAYS '31'
+          family 000_120
+            trigger ./stage eq complete
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 024_144
+            trigger ./stage eq complete
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 000_240
+            trigger ./stage eq complete
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 012_036
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 036_060
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 060_084
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 084_108
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 108_132
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+        endfamily
+        family nop
+          task stage
+            edit NC_DAYS '31'
+          family 228_324
+            trigger ./stage eq complete
+            edit ACC '96'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '324'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 168_336
+            trigger ./stage eq complete
+            edit ACC '168'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 000_024
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 024_048
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 048_072
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 072_096
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 096_120
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 120_144
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 108_156
+            trigger ./stage eq complete
+            edit ACC '48'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '156'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 156_228
+            trigger ./stage eq complete
+            edit ACC '72'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '228'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 000_168
+            trigger ./stage eq complete
+            edit ACC '168'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 012_036
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 036_060
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 060_084
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 084_108
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 108_132
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+        endfamily
+        family arch_op
+          trigger op eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family pf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'pf'
+            edit EFI_TYPE 'efi'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+          family cf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'cf'
+            edit EFI_TYPE 'efic'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+        endfamily
+        family arch_nop
+          trigger nop eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family pf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'pf'
+            edit EFI_TYPE 'efi'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+          family cf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'cf'
+            edit EFI_TYPE 'efic'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family 00
+        edit EMOS_BASE '00'
+        edit DELTA_DAY '1'
+        family op
+          task stage
+            edit NC_DAYS '31'
+          family 000_120
+            trigger ./stage eq complete
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 024_144
+            trigger ./stage eq complete
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 000_240
+            trigger ./stage eq complete
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 000_024
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 024_048
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 048_072
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 072_096
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+          family 096_120
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+          endfamily
+        endfamily
+        family nop
+          task stage
+            edit NC_DAYS '31'
+          family 240_336
+            trigger ./stage eq complete
+            edit ACC '96'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 168_336
+            trigger ./stage eq complete
+            edit ACC '168'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 012_036
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 036_060
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 060_084
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 084_108
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 108_132
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 120_144
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 120_168
+            trigger ./stage eq complete
+            edit ACC '48'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 168_240
+            trigger ./stage eq complete
+            edit ACC '72'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 000_168
+            trigger ./stage eq complete
+            edit ACC '168'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task extindex
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task extindex
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task extindex
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task extindex
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 000_024
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 024_048
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 048_072
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 072_096
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+          family 096_120
+            trigger ./stage eq complete
+            edit ACC '24'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task extindex
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task extindex
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task extindex
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task extindex
+            endfamily
+          endfamily
+        endfamily
+        family arch_op
+          trigger op eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family pf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'pf'
+            edit EFI_TYPE 'efi'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+          family cf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'cf'
+            edit EFI_TYPE 'efic'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+        endfamily
+        family arch_nop
+          trigger nop eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family pf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'pf'
+            edit EFI_TYPE 'efi'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+          family cf
+            trigger ./efi2fdb eq complete
+            edit EMOS_TYPE 'cf'
+            edit EFI_TYPE 'efic'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+  endfamily
+  family efi_next
+    edit VERSION '0039'
+    edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi'
+    edit EVERSION '0001'
+    edit IMPL_DATE '2012121212'
+    edit EMOS_BASE '00'
+    edit MARS_DB 'marsod'
+    edit EMOS_TYPE 'undef'
+    edit EPS_VERSION '0001'
+    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+    edit SMSURL 'GENFO/00'
+    edit MARS_NEW '0'
+    edit UPDATE_WEB_NOW 'yes'
+    edit SCHOST 'c1a'
+    edit STHOST '/s1a'
+    edit SCHOST_BKUP 'c1b'
+    edit SCLOGDIR '/s1a/emos_esuite/emos_data/0039/log'
+    edit LOGDIR '/s1a/emos_esuite/emos_data/0039/log'
+    edit SMSOUT '/s1a/emos_esuite/emos_data/0039/log'
+    edit SMSLOGHOST 'c1a'
+    limit ext 35
+    inlimit ext
+    family mn
+      trigger ./mn:YMD lt ./clim:YMD
+      repeat date YMD 20080221 20121212 1
+      edit EFINENS '50'
+      family deps
+        edit SMSFILES '/home/ma/emos/def/emc_33r1/ref'
+        family 00
+          time 09:30
+          task dummy
+            edit SMSPASS 'stripped'
+        endfamily
+        family 12
+          time 21:30
+          task dummy
+        endfamily
+      endfamily
+      family 12
+        trigger ./deps/12 eq complete
+        edit EMOS_BASE '12'
+        family op
+          edit EPSLEG '1'
+          task stage
+          family 024
+            family 012_036
+              edit ACC '024'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_060
+              edit ACC '024'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_084
+              edit ACC '024'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_108
+              edit ACC '024'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_132
+              edit ACC '024'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '024'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '024'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '024'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            trigger ./024 eq complete
+            family 000_120
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_144
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            trigger ./024 eq complete
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family nop
+          edit EPSLEG '2'
+          task stage
+          family 024
+            family 012_036
+              edit ACC '024'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_060
+              edit ACC '024'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_084
+              edit ACC '024'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_108
+              edit ACC '024'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_132
+              edit ACC '024'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 132_156
+              edit ACC '024'
+              edit EFI_STEP1 '132'
+              edit EFI_STEP2 '156'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 156_180
+              edit ACC '024'
+              edit EFI_STEP1 '156'
+              edit EFI_STEP2 '180'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 180_204
+              edit ACC '024'
+              edit EFI_STEP1 '180'
+              edit EFI_STEP2 '204'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 204_228
+              edit ACC '024'
+              edit EFI_STEP1 '204'
+              edit EFI_STEP2 '228'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '24'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '24'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '24'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 240_264
+              edit ACC '24'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '264'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 264_288
+              edit ACC '24'
+              edit EFI_STEP1 '264'
+              edit EFI_STEP2 '288'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 288_312
+              edit ACC '24'
+              edit EFI_STEP1 '288'
+              edit EFI_STEP2 '312'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 312_336
+              edit ACC '24'
+              edit EFI_STEP1 '312'
+              edit EFI_STEP2 '336'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 336_360
+              edit ACC '24'
+              edit EFI_STEP1 '336'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 072
+            family 012_084
+              edit ACC '072'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '084'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_108
+              edit ACC '072'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '108'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_132
+              edit ACC '072'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '132'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_156
+              edit ACC '072'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '156'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_180
+              edit ACC '072'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '180'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 132_204
+              edit ACC '072'
+              edit EFI_STEP1 '132'
+              edit EFI_STEP2 '204'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 156_228
+              edit ACC '072'
+              edit EFI_STEP1 '156'
+              edit EFI_STEP2 '228'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            family 012_132
+              edit ACC '120'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '132'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_156
+              edit ACC '120'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '156'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_180
+              edit ACC '120'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '180'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_204
+              edit ACC '120'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '204'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_228
+              edit ACC '120'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '228'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 240_360
+              edit ACC '120'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 360
+            family 000_360
+              edit ACC '360'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_op
+          trigger op eq complete
+          edit EPSLEG '1'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_nop
+          trigger nop eq complete
+          edit EPSLEG '2'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmin
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family ts
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family hsttmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family data
+          trigger ./op eq complete and ./nop eq complete and ./arch_nop eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efidata
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efidata
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efidata
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efidata
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efidata
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efidata
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efidata
+          endfamily
+          family hsstmax
+            edit PARAM 'hsttmax'
+            task efidata
+          endfamily
+        endfamily
+        family plot
+          trigger ./op eq complete and ./nop eq complete and data eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
+          edit METVIEW 'metview_new'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efiplot
+              edit SMSPASS 'stripped'
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efiplot
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efiplot
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efiplot
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efiplot
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efiplot
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efiplot
+          endfamily
+          family hsttmax
+            edit PARAM 'hsttmax'
+            task efiplot
+          endfamily
+        endfamily
+      endfamily
+      family 00
+        trigger ./deps/00 eq complete and ./12 eq complete
+        edit EMOS_BASE '00'
+        edit DELTA_DAY '1'
+        family op
+          edit EPSLEG '1'
+          task stage
+          family 024
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '024'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '024'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '024'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            trigger ./024 eq complete
+            family 000_120
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_144
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            trigger ./024 eq complete
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family nop
+          edit EPSLEG '2'
+          task stage
+          family 024
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family reproc
+              family 120_144
+                edit ACC '024'
+                edit EFI_STEP1 '120'
+                edit EFI_STEP2 '144'
+                family tp
+                  edit RF_NAME 'tp'
+                  task extindex
+                endfamily
+              endfamily
+              family 144_168
+                edit ACC '024'
+                edit EFI_STEP1 '144'
+                edit EFI_STEP2 '168'
+                family tp
+                  edit RF_NAME 'tp'
+                  task extindex
+                endfamily
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '24'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '24'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '24'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 240_264
+              edit ACC '24'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '264'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 264_288
+              edit ACC '24'
+              edit EFI_STEP1 '264'
+              edit EFI_STEP2 '288'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 288_312
+              edit ACC '24'
+              edit EFI_STEP1 '288'
+              edit EFI_STEP2 '312'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 312_336
+              edit ACC '24'
+              edit EFI_STEP1 '312'
+              edit EFI_STEP2 '336'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 336_360
+              edit ACC '24'
+              edit EFI_STEP1 '336'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 072
+            family 000_072
+              edit ACC '072'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '072'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_096
+              edit ACC '072'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '096'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_120
+              edit ACC '072'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_144
+              edit ACC '072'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_168
+              edit ACC '072'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 120_192
+              edit ACC '072'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 144_216
+              edit ACC '072'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            family 000_120
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_144
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_168
+              edit ACC '120'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_192
+              edit ACC '120'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_216
+              edit ACC '120'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 240_360
+              edit ACC '120'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 360
+            family 000_360
+              edit ACC '360'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_op
+          trigger op eq complete
+          edit EPSLEG '1'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_nop
+          trigger nop eq complete
+          edit EPSLEG '2'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmin
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family ts
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family hsttmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family data
+          trigger ./op eq complete and ./nop eq complete and ./arch_nop eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efidata
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efidata
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efidata
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efidata
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efidata
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efidata
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efidata
+          endfamily
+          family hsstmax
+            edit PARAM 'hsttmax'
+            task efidata
+          endfamily
+        endfamily
+        family plot
+          trigger ./op eq complete and ./nop eq complete and data eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit.legc %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/smsfiles/web'
+          edit METVIEW 'metview_new'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efiplot
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efiplot
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efiplot
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efiplot
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efiplot
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efiplot
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efiplot
+          endfamily
+          family hsttmax
+            edit PARAM 'hsttmax'
+            task efiplot
+          endfamily
+        endfamily
+      endfamily
+      task efi_cleaner
+        trigger ./12 eq complete and ./00 eq complete
+    endfamily
+    family hind
+      repeat date YMD 20080717 20121212 7
+      edit DELTA_DAY '0'
+      time 09:30
+      family stage
+        edit RF_NAME 'all'
+        edit RETRIEVE 'stage'
+        task prep
+      endfamily
+      family op
+        trigger ./stage eq complete
+        edit EPSLEG '1'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+                edit SMSPASS 'stripped'
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+                edit SMSPASS 'stripped'
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+                edit SMSPASS 'stripped'
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          trigger ./024 eq complete
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          trigger ./024 eq complete
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family nop
+        trigger ./stage eq complete
+        edit EPSLEG '2'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 240_264
+            edit ACC '024'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '264'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 264_288
+            edit ACC '024'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '288'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 288_312
+            edit ACC '024'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '312'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 312_336
+            edit ACC '024'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 336_360
+            edit ACC '024'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '360'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 000
+          family 006_006
+            edit ACC '000'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '006'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 012_012
+            edit ACC '000'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '012'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 018_018
+            edit ACC '000'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '018'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 024_024
+            edit ACC '000'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '024'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 030_030
+            edit ACC '000'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '030'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 036_036
+            edit ACC '000'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '036'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 042_042
+            edit ACC '000'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '042'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 048_048
+            edit ACC '000'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '048'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 054_054
+            edit ACC '000'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '054'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 060_060
+            edit ACC '000'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '060'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 066_066
+            edit ACC '000'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '066'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 072_072
+            edit ACC '000'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '072'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 078_078
+            edit ACC '000'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '078'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 084_084
+            edit ACC '000'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '084'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 090_090
+            edit ACC '000'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '090'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 096_096
+            edit ACC '000'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '096'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 102_102
+            edit ACC '000'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '102'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 108_108
+            edit ACC '000'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '108'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 114_114
+            edit ACC '000'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '114'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_120
+            edit ACC '000'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '120'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 126_126
+            edit ACC '000'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '126'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 132_132
+            edit ACC '000'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '132'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 138_138
+            edit ACC '000'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '138'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 144_144
+            edit ACC '000'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '144'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 150_150
+            edit ACC '000'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '150'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 156_156
+            edit ACC '000'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '156'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 162_162
+            edit ACC '000'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '162'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 168_168
+            edit ACC '000'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '168'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 174_174
+            edit ACC '000'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '174'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 180_180
+            edit ACC '000'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '180'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 186_186
+            edit ACC '000'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '186'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 192_192
+            edit ACC '000'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '192'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 198_198
+            edit ACC '000'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '198'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 204_204
+            edit ACC '000'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '204'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 210_210
+            edit ACC '000'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '210'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 216_216
+            edit ACC '000'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '216'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 222_222
+            edit ACC '000'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '222'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 228_228
+            edit ACC '000'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '228'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 234_234
+            edit ACC '000'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '234'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 240_240
+            edit ACC '000'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '240'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 252_252
+            edit ACC '000'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '252'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 264_264
+            edit ACC '000'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '264'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 276_276
+            edit ACC '000'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '276'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 288_288
+            edit ACC '000'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '288'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 300_300
+            edit ACC '000'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '300'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 312_312
+            edit ACC '000'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '312'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 324_324
+            edit ACC '000'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '324'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 336_336
+            edit ACC '000'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '336'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 348_348
+            edit ACC '000'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '348'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 360_360
+            edit ACC '000'
+            edit EFI_STEP1 '360'
+            edit EFI_STEP2 '360'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 006
+          family 000_006
+            edit ACC '006'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '006'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 006_012
+            edit ACC '006'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 012_018
+            edit ACC '006'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '018'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 018_024
+            edit ACC '006'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 024_030
+            edit ACC '006'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '030'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 030_036
+            edit ACC '006'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 036_042
+            edit ACC '006'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '042'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 042_048
+            edit ACC '006'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 048_054
+            edit ACC '006'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '054'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 054_060
+            edit ACC '006'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 060_066
+            edit ACC '006'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '066'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 066_072
+            edit ACC '006'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 072_078
+            edit ACC '006'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '078'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 078_084
+            edit ACC '006'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 084_090
+            edit ACC '006'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '090'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 090_096
+            edit ACC '006'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 096_102
+            edit ACC '006'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '102'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 102_108
+            edit ACC '006'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 108_114
+            edit ACC '006'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '114'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 114_120
+            edit ACC '006'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 120_126
+            edit ACC '006'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '126'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 126_132
+            edit ACC '006'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 132_138
+            edit ACC '006'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '138'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 138_144
+            edit ACC '006'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 144_150
+            edit ACC '006'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '150'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 150_156
+            edit ACC '006'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 156_162
+            edit ACC '006'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '162'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 162_168
+            edit ACC '006'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 168_174
+            edit ACC '006'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '174'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 174_180
+            edit ACC '006'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 180_186
+            edit ACC '006'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '186'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 186_192
+            edit ACC '006'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 192_198
+            edit ACC '006'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '198'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 198_204
+            edit ACC '006'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 204_210
+            edit ACC '006'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '210'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 210_216
+            edit ACC '006'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 216_222
+            edit ACC '006'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '222'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 222_228
+            edit ACC '006'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 228_234
+            edit ACC '006'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '234'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 234_240
+            edit ACC '006'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 012
+          family 000_012
+            edit ACC '012'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 012_024
+            edit ACC '012'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 024_036
+            edit ACC '012'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 036_048
+            edit ACC '012'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 048_060
+            edit ACC '012'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 060_072
+            edit ACC '012'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 072_084
+            edit ACC '012'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 084_096
+            edit ACC '012'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 096_108
+            edit ACC '012'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 108_120
+            edit ACC '012'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 120_132
+            edit ACC '012'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 132_144
+            edit ACC '012'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 144_156
+            edit ACC '012'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 156_168
+            edit ACC '012'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 168_180
+            edit ACC '012'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 180_192
+            edit ACC '012'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 192_204
+            edit ACC '012'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 204_216
+            edit ACC '012'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 216_228
+            edit ACC '012'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 228_240
+            edit ACC '012'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 240_252
+            edit ACC '012'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '252'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 252_264
+            edit ACC '012'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '264'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 264_276
+            edit ACC '012'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '276'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 276_288
+            edit ACC '012'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '288'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 288_300
+            edit ACC '012'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '300'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 300_312
+            edit ACC '012'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '312'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 312_324
+            edit ACC '012'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '324'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 324_336
+            edit ACC '012'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '336'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 336_348
+            edit ACC '012'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '348'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 348_360
+            edit ACC '012'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 072
+          trigger ./024 eq complete
+          family 000_072
+            edit ACC '072'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 024_096
+            edit ACC '072'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 048_120
+            edit ACC '072'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 072_144
+            edit ACC '072'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 096_168
+            edit ACC '072'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_192
+            edit ACC '072'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 144_216
+            edit ACC '072'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 168_240
+            edit ACC '072'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          trigger ./024 eq complete
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 048_168
+            edit ACC '120'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 072_192
+            edit ACC '120'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 096_216
+            edit ACC '120'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_240
+            edit ACC '120'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 240_360
+            edit ACC '120'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          trigger ./024 eq complete
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_360
+            edit ACC '240'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 360
+          trigger ./024 eq complete
+          family 000_360
+            edit ACC '360'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family check_nrt
+        complete ./check_nrt/go eq complete
+        edit REFPATH '/mofc/hc2'
+        family catchup
+          task check_nrt
+            event ok
+        endfamily
+        family rt
+          trigger catchup eq complete
+          task check_nrt
+            event ok
+            cron -w 1 08:00
+        endfamily
+        task go
+          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
+          trigger 0 eq 1
+      endfamily
+    endfamily
+    family clim
+      trigger ./clim:YMD lt ./hind:YMD
+      repeat date YMD 20080717 20121212 7
+      edit EFI_REMOVE_GRIB 'echo'
+      edit DELTA_DAY '-7'
+      time 09:30
+      family op
+        edit EPSLEG '1'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family op2fdb
+        trigger op eq complete
+        edit EPSLEG '1'
+        task efi2fdb
+          edit KIND 'clim1'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+      endfamily
+      family nop
+        edit EPSLEG '2'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_264
+            edit ACC '024'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '264'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 264_288
+            edit ACC '024'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '288'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 288_312
+            edit ACC '024'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '312'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 312_336
+            edit ACC '024'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 336_360
+            edit ACC '024'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '360'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 000
+          family 006_006
+            edit ACC '000'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '006'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_012
+            edit ACC '000'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '012'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 018_018
+            edit ACC '000'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '018'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_024
+            edit ACC '000'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '024'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 030_030
+            edit ACC '000'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '030'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_036
+            edit ACC '000'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '036'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 042_042
+            edit ACC '000'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '042'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_048
+            edit ACC '000'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '048'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 054_054
+            edit ACC '000'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '054'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_060
+            edit ACC '000'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '060'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 066_066
+            edit ACC '000'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '066'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_072
+            edit ACC '000'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '072'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 078_078
+            edit ACC '000'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '078'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_084
+            edit ACC '000'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '084'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 090_090
+            edit ACC '000'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '090'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_096
+            edit ACC '000'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '096'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 102_102
+            edit ACC '000'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '102'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_108
+            edit ACC '000'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '108'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 114_114
+            edit ACC '000'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '114'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_120
+            edit ACC '000'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '120'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 126_126
+            edit ACC '000'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '126'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 132_132
+            edit ACC '000'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '132'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 138_138
+            edit ACC '000'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '138'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_144
+            edit ACC '000'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '144'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 150_150
+            edit ACC '000'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '150'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 156_156
+            edit ACC '000'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '156'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 162_162
+            edit ACC '000'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '162'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_168
+            edit ACC '000'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '168'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 174_174
+            edit ACC '000'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '174'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 180_180
+            edit ACC '000'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '180'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 186_186
+            edit ACC '000'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '186'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_192
+            edit ACC '000'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '192'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 198_198
+            edit ACC '000'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '198'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 204_204
+            edit ACC '000'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '204'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 210_210
+            edit ACC '000'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '210'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_216
+            edit ACC '000'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '216'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 222_222
+            edit ACC '000'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '222'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 228_228
+            edit ACC '000'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '228'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 234_234
+            edit ACC '000'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '234'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_240
+            edit ACC '000'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '240'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 252_252
+            edit ACC '000'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '252'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 264_264
+            edit ACC '000'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '264'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 276_276
+            edit ACC '000'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '276'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 288_288
+            edit ACC '000'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '288'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 300_300
+            edit ACC '000'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '300'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 312_312
+            edit ACC '000'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '312'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 324_324
+            edit ACC '000'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '324'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 336_336
+            edit ACC '000'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '336'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 348_348
+            edit ACC '000'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '348'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 360_360
+            edit ACC '000'
+            edit EFI_STEP1 '360'
+            edit EFI_STEP2 '360'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 006
+          family 000_006
+            edit ACC '006'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '006'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 006_012
+            edit ACC '006'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_018
+            edit ACC '006'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '018'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 018_024
+            edit ACC '006'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_030
+            edit ACC '006'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '030'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 030_036
+            edit ACC '006'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_042
+            edit ACC '006'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '042'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 042_048
+            edit ACC '006'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_054
+            edit ACC '006'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '054'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 054_060
+            edit ACC '006'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_066
+            edit ACC '006'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '066'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 066_072
+            edit ACC '006'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_078
+            edit ACC '006'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '078'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 078_084
+            edit ACC '006'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_090
+            edit ACC '006'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '090'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 090_096
+            edit ACC '006'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_102
+            edit ACC '006'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '102'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 102_108
+            edit ACC '006'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_114
+            edit ACC '006'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '114'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 114_120
+            edit ACC '006'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_126
+            edit ACC '006'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '126'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 126_132
+            edit ACC '006'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 132_138
+            edit ACC '006'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '138'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 138_144
+            edit ACC '006'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_150
+            edit ACC '006'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '150'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 150_156
+            edit ACC '006'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 156_162
+            edit ACC '006'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '162'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 162_168
+            edit ACC '006'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_174
+            edit ACC '006'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '174'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 174_180
+            edit ACC '006'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 180_186
+            edit ACC '006'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '186'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 186_192
+            edit ACC '006'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_198
+            edit ACC '006'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '198'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 198_204
+            edit ACC '006'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 204_210
+            edit ACC '006'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '210'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 210_216
+            edit ACC '006'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_222
+            edit ACC '006'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '222'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 222_228
+            edit ACC '006'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 228_234
+            edit ACC '006'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '234'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 234_240
+            edit ACC '006'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 012
+          family 000_012
+            edit ACC '012'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_024
+            edit ACC '012'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_036
+            edit ACC '012'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_048
+            edit ACC '012'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_060
+            edit ACC '012'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_072
+            edit ACC '012'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_084
+            edit ACC '012'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_096
+            edit ACC '012'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_108
+            edit ACC '012'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_120
+            edit ACC '012'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_132
+            edit ACC '012'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 132_144
+            edit ACC '012'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_156
+            edit ACC '012'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 156_168
+            edit ACC '012'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_180
+            edit ACC '012'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 180_192
+            edit ACC '012'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_204
+            edit ACC '012'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 204_216
+            edit ACC '012'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_228
+            edit ACC '012'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 228_240
+            edit ACC '012'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_252
+            edit ACC '012'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '252'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 252_264
+            edit ACC '012'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '264'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 264_276
+            edit ACC '012'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '276'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 276_288
+            edit ACC '012'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '288'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 288_300
+            edit ACC '012'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '300'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 300_312
+            edit ACC '012'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '312'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 312_324
+            edit ACC '012'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '324'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 324_336
+            edit ACC '012'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '336'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 336_348
+            edit ACC '012'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '348'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 348_360
+            edit ACC '012'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 072
+          family 000_072
+            edit ACC '072'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_096
+            edit ACC '072'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_120
+            edit ACC '072'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_144
+            edit ACC '072'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_168
+            edit ACC '072'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_192
+            edit ACC '072'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_216
+            edit ACC '072'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_240
+            edit ACC '072'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_168
+            edit ACC '120'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_192
+            edit ACC '120'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_216
+            edit ACC '120'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_240
+            edit ACC '120'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_360
+            edit ACC '120'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_360
+            edit ACC '240'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 360
+          family 000_360
+            edit ACC '360'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family nop2fdb
+        trigger nop eq complete and ./op2fdb eq complete
+        edit EPSLEG '2'
+        task efi2fdb
+          edit KIND 'clim2'
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/mc/efi_hdc'
+      endfamily
+      family arch_nop
+        trigger nop2fdb eq complete
+        edit EPSLEG '2'
+        edit SMSFILES '/home/ma/emos/def/emc_33r1/archive'
+        family 2t
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '2t'
+          task eficlim
+            label info ""
+        endfamily
+        family 10ff
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '10ff'
+          task eficlim
+            label info ""
+        endfamily
+        family 10fg
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '10fg'
+          task eficlim
+            label info ""
+        endfamily
+        family tp
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'tp'
+          task eficlim
+            label info ""
+        endfamily
+        family 2tmin
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '2tmin'
+          task eficlim
+            label info ""
+        endfamily
+        family 2tmax
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '2tmax'
+          task eficlim
+            label info ""
+        endfamily
+        family ts
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'ts'
+          task eficlim
+            label info ""
+        endfamily
+        family hsttmax
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'hsttmax'
+          task eficlim
+            label info ""
+        endfamily
+        family 10dd
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '10dd'
+          task eficlim
+            label info ""
+        endfamily
+        family 850t
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '850t'
+          task eficlim
+            label info ""
+        endfamily
+        family 500z
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '500z'
+          task eficlim
+            label info ""
+        endfamily
+        family 2tmean
+          edit step2 '24'
+          edit RF_NAME '2t'
+          edit step1 '0'
+          task eficlim
+            label info ""
+        endfamily
+        family 10ffmean
+          edit step2 '24'
+          edit RF_NAME '10ff'
+          edit step1 '0'
+          task eficlim
+            label info ""
+        endfamily
+        family tcc
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'tcc'
+          task eficlim
+            label info ""
+        endfamily
+        family tccmean
+          edit step2 '24'
+          edit RF_NAME 'tcc'
+          edit step1 '0'
+          task eficlim
+            label info ""
+        endfamily
+      endfamily
+      task efi_cleaner
+        trigger arch_nop eq complete and op eq complete and nop eq complete and op2fdb eq complete and nop2fdb eq complete
+        edit DELTA_DAY '-43'
+      family gdb
+        trigger ( op eq complete and nop eq complete) and ( arch_nop eq complete)
+        edit RHOST 'epsgrams'
+        edit RDIR '/webapps/epsgrams/data/'
+        edit KIND 'clim_15_days'
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /limits:linux_cluster
+        task sync_climate
+        task gclean
+          trigger sync_climate eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/pop/data/epsgrams/grams'
+          edit KEEP_DAYS '14'
+          edit REMOTE_KEEP_DAYS '14'
+        task gdb
+          trigger gclean eq complete and ( /mc/main:YMD ge /emc_33r1/efi_next/mn:YMD and /mc/main/00 eq complete)
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/pop/data/epsgrams/grams'
+          label files "="
+          label info "="
+          label local "="
+          label remote "="
+          event fdb
+        task glink
+          trigger gdb eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_33r1/pop/data/epsgrams/grams'
+      endfamily
+      family check_nrt
+        complete ./check_nrt/go eq complete
+        edit REFPATH '/mofc/hc2'
+        family catchup
+          task check_nrt
+            event ok
+        endfamily
+        family rt
+          trigger catchup eq complete
+          task check_nrt
+            event ok
+            cron -w 3 06:30
+        endfamily
+        task go
+          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
+          trigger 0 eq 1
+      endfamily
+    endfamily
+  endfamily
+  family limits
+    limit mars 4
+    limit pftotal 20
+    limit pertic 13
+    limit modelepsA 13
+    limit modelepsB 15
+    limit pl 3
+    limit sfc 2
+    limit prodeps 5
+    limit prodwave 4
+    limit pdb 5
+    limit q2diss 5
+    limit efi 13
+    limit efih 13
+    limit refc 10
+    limit tc 5
+    limit webplots 10
+    limit dp 16
+    limit hind 14
+    limit pesh 20
+  endfamily
+endsuite
+suite metops_test
+  repeat date YMD 20090401 20191210 1
+  edit USER 'emos'
+  edit SCHOST 'c1a'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/c1a/emos_dir/0001/log'
+  edit USE_YMD 'true'
+  edit VERSION '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '00'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY ''
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit PGNPES '3'
+  edit SVNPES '8'
+  edit REINITIALIZE 'false'
+  edit DATEMASK '*.*.*'
+  edit REMOVE_ADIR 'false'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/metops_test/include'
+  edit SMSURLBASE 'http://www.ecmwf.int'
+  edit SMSURL 'publications/manuals/sms'
+  edit ACCOUNT 'oosu'
+  edit STREAM 'DA'
+  edit EMOS_STREAM 'DA'
+  edit FAMILY 'metops_test'
+  edit MARS_DB 'marsod'
+  edit OBSHOST 'dummy'
+  edit SUITE_START '2000022100'
+  edit QUEUE 'plots-medium'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+  edit LOGDIR '/vol/emos_nc/output'
+  edit SMSOUT '/vol/emos_nc/output'
+  edit SLEEPTIME '1'
+  inlimit /limits:linux_cluster
+  clock hybrid 
+  family 00
+    edit EMOS_BASE '00'
+    family web
+      family quartiles
+        edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia'
+        edit STEP_LIST '18/TO/126/by/12'
+        edit STEP_PLOT '12/TO/120/by/12'
+        edit ENSEMBLES '50'
+        time 10:00
+        task w_tp_quartiles
+        task w_wind_quartiles
+        task w_wgust_quartiles
+        task w_wind925_quartiles
+        task w_cape_quartiles
+      endfamily
+      family genesis
+        task w_tc_genesis
+          edit UPDATE_WEB_NOW 'yes'
+          time 10:00
+      endfamily
+      family swfdp_pacific
+        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swfdp_pacific'
+        edit PLOTDOM '-40/150/10/-120'
+        edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+        edit UPDATE_WEB_NOW 'yes'
+        edit SMSINCLUDE '/home/ma/emos/def/o/include'
+        edit PLOT_STEPS '12/to/144/by/12'
+        time 10:00
+        family proba
+          task swfdp_pacific_proba
+          task swfdp_pacific_tp
+            trigger swfdp_pacific_proba eq complete
+          task swfdp_pacific_ff
+            trigger swfdp_pacific_proba eq complete
+          task swfdp_pacific_tp24
+            trigger swfdp_pacific_proba eq complete
+            edit STEPS '24/48/72/96/120'
+          task swfdp_pacific_proba_clean
+            trigger swfdp_pacific_tp eq complete and swfdp_pacific_ff eq complete and swfdp_pacific_tp24 eq complete
+        endfamily
+        family efi
+          edit QUEUE 'plots-medium'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSINCLUDE '/home/ma/emos/def/o/include'
+          inlimit /limits:linux_cluster
+          family swfdp_pacific_tpi
+            task w_efi
+              edit PARAMETER 'tpi'
+          endfamily
+          family swfdp_pacific_10wsi
+            task w_efi
+              edit PARAMETER '10wsi'
+          endfamily
+          family swfdp_pacific_2ti
+            task w_efi
+              edit PARAMETER '2ti'
+          endfamily
+          family swfdp_pacific_10fgi
+            task w_efi
+              edit PARAMETER '10fgi'
+          endfamily
+        endfamily
+        task pb_swh
+        task pb_mwp
+        task swfdp_pacific_wavegrams
+          edit SMSINCLUDE '/home/ma/emos/def/metops_test/include'
+        family maps
+          edit PLOT_LOCATION '/webplots_e/data/swfdp_pacific/maps'
+          edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+          task swfdp_pacific_maps
+          task swfdp_pacific_toweb1
+            trigger swfdp_pacific_maps eq complete
+          task swfdp_pacific_toweb2
+            trigger swfdp_pacific_maps eq complete
+          task swfdp_pacific_toweb3
+            trigger swfdp_pacific_maps eq complete
+          task swfdp_pacific_clean
+            trigger swfdp_pacific_toweb1 eq complete and swfdp_pacific_toweb2 eq complete and swfdp_pacific_toweb3 eq complete
+        endfamily
+        family waves
+          edit PLOT_LEGS '1'
+          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+          task wave_data
+          family plots
+            task swfdp_pacific_swh
+              trigger ../wave_data eq complete
+            task swfdp_pacific_mwp
+              trigger ../wave_data eq complete
+            task swfdp_pacific_wwsh
+              trigger ../wave_data eq complete
+            task swfdp_pacific_wwmp
+              trigger ../wave_data eq complete
+            task swfdp_pacific_tssh
+              trigger ../wave_data eq complete
+            task swfdp_pacific_tsmp
+              trigger ../wave_data eq complete
+          endfamily
+          task swfdp_pacific_wave_clean
+            trigger ./plots eq complete
+        endfamily
+      endfamily
+      family swdfp
+        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swdfp'
+        edit PLOTDOM '-45/-10/6/62'
+        edit UPDATE_WEB_NOW 'yes'
+        edit SMSINCLUDE '/home/ma/emos/def/o/include'
+        edit PLOT_STEPS '12/to/144/by/12'
+        time 10:00
+        family waves
+          edit SMSINCLUDE '/home/ma/emos/def/o/include'
+          edit PLOT_LEGS '1'
+          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+          task wave_data
+          family plots
+            task swdfp_swh
+              trigger ../wave_data eq complete
+            task swdfp_mwp
+              trigger ../wave_data eq complete
+            task swdfp_wwsh
+              trigger ../wave_data eq complete
+            task swdfp_wwmp
+              trigger ../wave_data eq complete
+            task swdfp_tssh
+              trigger ../wave_data eq complete
+            task swdfp_tsmp
+              trigger ../wave_data eq complete
+          endfamily
+          task swdfp_wave_clean
+            trigger ./plots eq complete
+        endfamily
+        task pb_swdfp_swh
+        task pb_swdfp_mwp
+      endfamily
+      family wave_verif
+        edit UPDATE_WEB_NOW 'yes'
+        time 10:00
+        task w_wave_timeseries
+        task w_wave_annualscores
+        task w_wave_intercomparison
+      endfamily
+      family newcluster
+        task cluster_plot
+          edit UPDATE_WEB_NOW 'yes'
+          time 10:00
+      endfamily
+    endfamily
+  endfamily
+  family 12
+    edit EMOS_BASE '12'
+    family web
+      family quartiles
+        edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia'
+        edit STEP_LIST '18/TO/126/by/12'
+        edit STEP_PLOT '12/TO/120/by/12'
+        edit ENSEMBLES '50'
+        time 20:45
+        task w_tp_quartiles
+        task w_wind_quartiles
+        task w_wgust_quartiles
+        task w_wind925_quartiles
+        task w_cape_quartiles
+      endfamily
+      family genesis
+        task w_tc_genesis
+          edit UPDATE_WEB_NOW 'yes'
+          time 20:45
+      endfamily
+      family swfdp_pacific
+        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swfdp_pacific'
+        edit PLOTDOM '-40/150/10/-120'
+        edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+        edit UPDATE_WEB_NOW 'yes'
+        edit SMSINCLUDE '/home/ma/emos/def/o/include'
+        edit PLOT_STEPS '12/to/144/by/12'
+        time 20:45
+        family proba
+          task swfdp_pacific_proba
+          task swfdp_pacific_tp
+            trigger swfdp_pacific_proba eq complete
+          task swfdp_pacific_ff
+            trigger swfdp_pacific_proba eq complete
+          task swfdp_pacific_tp24
+            trigger swfdp_pacific_proba eq complete
+            edit STEPS '24/48/72/96/120'
+          task swfdp_pacific_proba_clean
+            trigger swfdp_pacific_tp eq complete and swfdp_pacific_ff eq complete and swfdp_pacific_tp24 eq complete
+        endfamily
+        family efi
+          edit QUEUE 'plots-medium'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSINCLUDE '/home/ma/emos/def/o/include'
+          inlimit /limits:linux_cluster
+          family swfdp_pacific_tpi
+            task w_efi
+              edit PARAMETER 'tpi'
+          endfamily
+          family swfdp_pacific_10wsi
+            task w_efi
+              edit PARAMETER '10wsi'
+          endfamily
+          family swfdp_pacific_2ti
+            task w_efi
+              edit PARAMETER '2ti'
+          endfamily
+          family swfdp_pacific_10fgi
+            task w_efi
+              edit PARAMETER '10fgi'
+          endfamily
+        endfamily
+        task pb_swh
+        task pb_mwp
+        task swfdp_pacific_wavegrams
+          edit SMSINCLUDE '/home/ma/emos/def/metops_test/include'
+        family maps
+          edit PLOT_LOCATION '/webplots_e/data/swfdp_pacific/maps'
+          edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+          task swfdp_pacific_maps
+          task swfdp_pacific_toweb1
+            trigger swfdp_pacific_maps eq complete
+          task swfdp_pacific_toweb2
+            trigger swfdp_pacific_maps eq complete
+          task swfdp_pacific_toweb3
+            trigger swfdp_pacific_maps eq complete
+          task swfdp_pacific_clean
+            trigger swfdp_pacific_toweb1 eq complete and swfdp_pacific_toweb2 eq complete and swfdp_pacific_toweb3 eq complete
+        endfamily
+        family waves
+          edit PLOT_LEGS '1'
+          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+          task wave_data
+          family plots
+            task swfdp_pacific_swh
+              trigger ../wave_data eq complete
+            task swfdp_pacific_mwp
+              trigger ../wave_data eq complete
+            task swfdp_pacific_wwsh
+              trigger ../wave_data eq complete
+            task swfdp_pacific_wwmp
+              trigger ../wave_data eq complete
+            task swfdp_pacific_tssh
+              trigger ../wave_data eq complete
+            task swfdp_pacific_tsmp
+              trigger ../wave_data eq complete
+          endfamily
+          task swfdp_pacific_wave_clean
+            trigger ./plots eq complete
+        endfamily
+      endfamily
+      family swdfp
+        edit SMSFILES '/home/ma/emos/def/metops_test/smsfiles/swdfp'
+        edit PLOTDOM '-45/-10/6/62'
+        edit UPDATE_WEB_NOW 'yes'
+        time 20:45
+        family waves
+          edit PLOT_LEGS '1'
+          edit STEPS '6/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+          task wave_data
+          family plots
+            task swdfp_wwsh
+              trigger ../wave_data eq complete
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+  endfamily
+endsuite
+suite verify
+  edit METPY_VERSION '3.4.2.emos'
+  edit METPY 'metpy_001'
+  edit VERIFY 'metpy_001'
+  edit FIRST_DATE '20091008'
+  edit LAST_DATE '20111031'
+  edit DATE_INCREMENT '1'
+  edit RUNS_PER_DAY '1'
+  edit OPERATIONAL 'yes'
+  edit USER 'emos'
+  edit SCHOST 'c1a'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/c1a/emos_dir/0001/log'
+  edit USE_YMD 'true'
+  edit VERSION '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '1'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '12'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY ''
+  edit STHOST_BKUP 'toto'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit PGNPES '3'
+  edit SVNPES '8'
+  edit REINITIALIZE 'false'
+  edit DATEMASK '*.*.*'
+  edit YMD 'dummy'
+  edit REMOVE_ADIR 'false'
+  edit ANNPES '18'
+  edit ANMEM '3584'
+  edit ANSTACK '700'
+  edit ANMRFS '160'
+  edit FCNPES '24'
+  edit FCMEM '3584'
+  edit FCSTACK '690'
+  edit FCMRFS '32'
+  edit PERIOD_4D '12'
+  edit WINDOW_LENGTH_4D '12'
+  edit WINDOW_OFFSET_4D '12'
+  edit MKCMANPES '6'
+  edit MKCMAMEM '3284'
+  edit MKCMASTACK '600'
+  edit MKCMAMRFS '600'
+  edit SMSHOME '/home/ma/emos/def/verify'
+  edit SMSFILES '/home/ma/emos/def/verify'
+  edit SMSINCLUDE '/home/ma/emos/def/verify/include'
+  edit ACCOUNT 'oosu'
+  edit STREAM 'DA'
+  edit EMOS_STREAM 'DA'
+  edit MARS_DB 'marsod'
+  edit OBSHOST 'ha_pp'
+  edit SUITE_START '19971117'
+  edit SCRIPTFILES '/home/ma/emos/def/verify/scripts'
+  edit VERIFY_CACHE '/var/tmp/verify'
+  edit WSHOST 'swarm'
+  edit QUEUE 'verify'
+  edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+  edit LOGDIR '/vol/emos_nc/output'
+  edit SMSOUT '/vol/emos_nc/output'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family 00
+    repeat date YMD 20091009 20111031 1
+    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
+    edit EMOS_BASE '00'
+    family hr
+      trigger /o/lag/00/archive/fc240 eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'oper'
+      limit count 3
+      inlimit count
+      task hr_retrieve
+        edit SMSTRIES '2'
+      family z
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'z'
+        task hr_upperair
+      endfamily
+      family t
+        trigger hr_retrieve eq complete
+        edit PARAMETER 't'
+        task hr_upperair
+      endfamily
+      family u_v_ff
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'u,v,ff'
+        task hr_upperair
+          edit SMSPASS 'stripped'
+      endfamily
+      family r
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'r'
+        task hr_upperair
+      endfamily
+      family q
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'q'
+        task hr_upperair
+      endfamily
+      family o3
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'o3'
+        task hr_upperair
+      endfamily
+      task hr_sfc
+        trigger hr_retrieve eq complete
+      task hr_to_ct
+        trigger hr_retrieve eq complete
+      task hr_from_ct
+        trigger hr_to_ct eq complete
+      task hr_to_ct_wind_850
+        trigger hr_retrieve eq complete
+      task hr_from_ct_wind_850
+        trigger hr_to_ct_wind_850 eq complete
+      task hr_to_ct_wind_250
+        trigger hr_retrieve eq complete
+      task hr_from_ct_wind_250
+        trigger hr_to_ct_wind_250 eq complete
+    endfamily
+    family hrobs
+      trigger ./hr eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores1'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FDB_HOST 'scores1'
+      edit STREAM 'oper'
+      edit DELTA_DAY '-2'
+      limit count 2
+      inlimit count
+      task hrobs_retrieve1
+        edit SMSTRIES '2'
+      task hrobs_retrieve2
+        edit SMSTRIES '2'
+      family z
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'z'
+        task hrobs
+      endfamily
+      family t
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 't'
+        task hrobs
+      endfamily
+      family u_v_ff
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'u,v,ff'
+        task hrobs
+      endfamily
+      family r
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'r'
+        task hrobs
+      endfamily
+      family q
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'q'
+        task hrobs
+      endfamily
+    endfamily
+    family ctrl
+      trigger /mc/main/00/legB/postproc eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'enfo'
+      limit count 2
+      inlimit count
+      task ctrl_retrieve
+      family z
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'z'
+        task ctrl_upperair
+      endfamily
+      family t
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 't'
+        task ctrl_upperair
+      endfamily
+      family u_v_ff
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'u,v,ff'
+        task ctrl_upperair
+      endfamily
+      family r
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'r'
+        task ctrl_upperair
+      endfamily
+      family q
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'q'
+        task ctrl_upperair
+      endfamily
+      task ctrl_sfc
+        trigger ctrl_retrieve eq complete
+      task ctrl_to_ct
+        trigger ctrl_retrieve eq complete
+      task ctrl_from_ct
+        trigger ctrl_to_ct eq complete
+      task ctrl_to_ct_wind_850
+        trigger ctrl_retrieve eq complete
+      task ctrl_from_ct_wind_850
+        trigger ctrl_to_ct_wind_850 eq complete
+      task ctrl_to_ct_wind_250
+        trigger ctrl_retrieve eq complete
+      task ctrl_from_ct_wind_250
+        trigger ctrl_to_ct_wind_250 eq complete
+    endfamily
+    family ctrlobs
+      trigger ./ctrl eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores1'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FDB_HOST 'scores1'
+      edit STREAM 'enfo'
+      edit DELTA_DAY '-2'
+      limit count 2
+      inlimit count
+      task ctrlobs_retrieve1
+        edit SMSTRIES '2'
+      task ctrlobs_retrieve2
+        edit SMSTRIES '2'
+      family z
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'z'
+        task ctrlobs
+      endfamily
+      family t
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 't'
+        task ctrlobs
+      endfamily
+      family r
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'r'
+        task ctrlobs
+      endfamily
+      family q
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'q'
+        task ctrlobs
+      endfamily
+      family u_v_ff
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'u,v,ff'
+        task ctrlobs
+      endfamily
+    endfamily
+    family eps
+      trigger /mc/main/00/legB/postproc eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'enfo'
+      limit count 4
+      inlimit count
+      task eps_retrieve
+        edit SMSTRIES '2'
+      task eps_to_ct_z
+        trigger eps_retrieve eq complete
+      task eps_to_ct_msl
+        trigger eps_retrieve eq complete
+      task eps_to_ct_t
+        trigger eps_retrieve eq complete
+      task eps_from_ct
+        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
+      task eps_to_ct_wind_850
+        trigger eps_retrieve eq complete
+      task eps_from_ct_wind_850
+        trigger eps_to_ct_wind_850 eq complete
+      task eps_to_ct_wind_250
+        trigger eps_retrieve eq complete
+      task eps_from_ct_wind_250
+        trigger eps_to_ct_wind_250 eq complete
+      task eps_spread_score1
+        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
+      task eps_spread_score2
+        trigger eps_to_ct_wind_850 eq complete and eps_to_ct_wind_250 eq complete
+      task eps_cal_val
+      task eps_mean_spread_z
+        trigger eps_to_ct_z eq complete
+      task eps_mean_spread_t
+        trigger eps_to_ct_t eq complete
+      task eps_mean_spread_msl
+        trigger eps_to_ct_msl eq complete
+      task eps_mean_spread_wind_850
+        trigger eps_to_ct_wind_850 eq complete
+      task eps_mean_spread_wind_250
+        trigger eps_to_ct_wind_250 eq complete
+    endfamily
+    family clim
+      trigger /o/main/00/an eq complete
+      edit STREAM 'oper'
+      limit count 1
+      inlimit count
+      task clim_z
+      task clim_msl
+      task clim_t
+      task clim_wind_850
+      task clim_wind_250
+      task clim_waves_mwp
+      task clim_waves_swh
+    endfamily
+    family waves
+      trigger /mc/main/00/legB/postproc eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      limit count 4
+      inlimit count
+      task waves_retrieve
+        edit SMSTRIES '2'
+      task waves_retrieve_ff
+        edit SMSTRIES '2'
+      task waves_eps_retrieve
+        edit SMSTRIES '2'
+      task waves_ctrl_retrieve
+        edit SMSTRIES '2'
+      task waves
+        trigger waves_retrieve eq complete
+      task waves_ff
+        trigger waves_retrieve_ff eq complete
+      task waves_ff_sea
+        trigger waves_ff eq complete
+      task waves_to_ct
+        trigger waves eq complete
+      task waves_from_ct
+        trigger waves_to_ct eq complete
+      task waves_ctrl
+        trigger waves_ctrl_retrieve eq complete
+      task waves_ctrl_to_ct
+        trigger waves_ctrl eq complete
+      task waves_ctrl_from_ct
+        trigger waves_ctrl_to_ct eq complete
+      task waves_eps_to_ct
+        trigger waves_eps_retrieve eq complete
+      task waves_eps_from_ct
+        trigger waves_eps_to_ct eq complete
+      task waves_eps_mean_spread
+        trigger waves_eps_to_ct eq complete
+      task waves_eps_spread_score
+        trigger waves_eps_to_ct eq complete
+    endfamily
+    family other
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'oper'
+      limit count 3
+      inlimit count
+      time 08:00
+      task other_ukmo_fc
+      task other_ukmo_an
+      task other_ncep_fc
+      task other_ncep_an
+      task other_dwd_fc
+      task other_dwd_an
+      task other_metfr_fc
+      task other_metfr_an
+      task other_jma_fc
+      task other_jma_an
+      task other_cmc_fc
+      task other_cmc_an
+      task other_bom_fc
+      task other_bom_an
+    endfamily
+    task restart
+      time 17:00
+  endfamily
+  family 12
+    repeat date YMD 20091008 20111031 1
+    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
+    edit EMOS_BASE '12'
+    edit OVERWRITE 'yes'
+    family hr
+      trigger /o/lag/12/archive/fc240 eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'oper'
+      limit count 3
+      inlimit count
+      task hr_retrieve
+        edit SMSTRIES '2'
+      family z
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'z'
+        task hr_upperair
+      endfamily
+      family t
+        trigger hr_retrieve eq complete
+        edit PARAMETER 't'
+        task hr_upperair
+      endfamily
+      family u_v_ff
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'u,v,ff'
+        task hr_upperair
+      endfamily
+      family r
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'r'
+        task hr_upperair
+      endfamily
+      family q
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'q'
+        task hr_upperair
+      endfamily
+      family o3
+        trigger hr_retrieve eq complete
+        edit PARAMETER 'o3'
+        task hr_upperair
+      endfamily
+      task hr_sfc
+        trigger hr_retrieve eq complete
+      task hr_to_ct
+        trigger hr_retrieve eq complete
+      task hr_from_ct
+        trigger hr_to_ct eq complete
+      task hr_to_ct_wind_850
+        trigger hr_retrieve eq complete
+      task hr_from_ct_wind_850
+        trigger hr_to_ct_wind_850 eq complete
+      task hr_to_ct_wind_250
+        trigger hr_retrieve eq complete
+      task hr_from_ct_wind_250
+        trigger hr_to_ct_wind_250 eq complete
+    endfamily
+    family hrobs
+      trigger ./hr eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores1'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FDB_HOST 'scores1'
+      edit STREAM 'oper'
+      edit DELTA_DAY '-2'
+      edit OVERWRITE 'yes'
+      limit count 2
+      inlimit count
+      task hrobs_retrieve1
+        edit SMSTRIES '2'
+      task hrobs_retrieve2
+        edit SMSTRIES '2'
+      family z
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'z'
+        task hrobs
+      endfamily
+      family t
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 't'
+        task hrobs
+      endfamily
+      family u_v_ff
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'u,v,ff'
+        task hrobs
+      endfamily
+      family r
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'r'
+        task hrobs
+      endfamily
+      family q
+        trigger hrobs_retrieve1 eq complete and hrobs_retrieve2 eq complete
+        edit PARAMETER 'q'
+        task hrobs
+      endfamily
+    endfamily
+    family ctrl
+      trigger /mc/main/12/legB/postproc eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'enfo'
+      limit count 2
+      inlimit count
+      task ctrl_retrieve
+        edit SMSTRIES '2'
+      family z
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'z'
+        task ctrl_upperair
+      endfamily
+      family t
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 't'
+        task ctrl_upperair
+      endfamily
+      family u_v_ff
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'u,v,ff'
+        task ctrl_upperair
+      endfamily
+      family r
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'r'
+        task ctrl_upperair
+      endfamily
+      family q
+        trigger ctrl_retrieve eq complete
+        edit PARAMETER 'q'
+        task ctrl_upperair
+      endfamily
+      task ctrl_sfc
+        trigger ctrl_retrieve eq complete
+      task ctrl_to_ct
+        trigger ctrl_retrieve eq complete
+      task ctrl_from_ct
+        trigger ctrl_to_ct eq complete
+      task ctrl_to_ct_wind_850
+        trigger ctrl_retrieve eq complete
+      task ctrl_from_ct_wind_850
+        trigger ctrl_to_ct_wind_850 eq complete
+      task ctrl_to_ct_wind_250
+        trigger ctrl_retrieve eq complete
+      task ctrl_from_ct_wind_250
+        trigger ctrl_to_ct_wind_250 eq complete
+    endfamily
+    family ctrlobs
+      trigger ./ctrl eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores1'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FDB_HOST 'scores1'
+      edit STREAM 'enfo'
+      edit DELTA_DAY '-2'
+      edit OVERWRITE 'yes'
+      limit count 2
+      inlimit count
+      task ctrlobs_retrieve1
+        edit SMSTRIES '2'
+      task ctrlobs_retrieve2
+        edit SMSTRIES '2'
+      family z
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'z'
+        task ctrlobs
+      endfamily
+      family t
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 't'
+        task ctrlobs
+      endfamily
+      family r
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'r'
+        task ctrlobs
+      endfamily
+      family q
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'q'
+        task ctrlobs
+      endfamily
+      family u_v_ff
+        trigger ctrlobs_retrieve1 eq complete and ctrlobs_retrieve2 eq complete
+        edit PARAMETER 'u,v,ff'
+        task ctrlobs
+      endfamily
+    endfamily
+    family eps
+      trigger /mc/main/12/legB/postproc eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'enfo'
+      limit count 2
+      inlimit count
+      task eps_retrieve
+        edit SMSTRIES '2'
+      task eps_to_ct_z
+        trigger eps_retrieve eq complete
+      task eps_to_ct_msl
+        trigger eps_retrieve eq complete
+      task eps_to_ct_t
+        trigger eps_retrieve eq complete
+      task eps_from_ct
+        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
+      task eps_to_ct_wind_850
+        trigger eps_retrieve eq complete
+      task eps_from_ct_wind_850
+        trigger eps_to_ct_wind_850 eq complete
+      task eps_to_ct_wind_250
+        trigger eps_retrieve eq complete
+      task eps_from_ct_wind_250
+        trigger eps_to_ct_wind_250 eq complete
+      task eps_spread_score1
+        trigger eps_to_ct_z eq complete and eps_to_ct_t eq complete and eps_to_ct_msl eq complete
+      task eps_spread_score2
+        trigger eps_to_ct_wind_850 eq complete and eps_to_ct_wind_250 eq complete
+      task eps_cal_val
+      task eps_mean_spread_z
+        trigger eps_to_ct_z eq complete
+      task eps_mean_spread_t
+        trigger eps_to_ct_t eq complete
+      task eps_mean_spread_msl
+        trigger eps_to_ct_msl eq complete
+      task eps_mean_spread_wind_850
+        trigger eps_to_ct_wind_850 eq complete
+      task eps_mean_spread_wind_250
+        trigger eps_to_ct_wind_250 eq complete
+    endfamily
+    family clim
+      trigger /o/main/12/an eq complete
+      edit STREAM 'oper'
+      limit count 1
+      inlimit count
+      task clim_z
+      task clim_msl
+      task clim_t
+      task clim_wind_850
+      task clim_wind_250
+      task clim_waves_mwp
+      task clim_waves_swh
+    endfamily
+    family waves
+      trigger /mc/main/12/legB/postproc eq complete
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit OVERWRITE 'yes'
+      limit count 4
+      inlimit count
+      task waves_retrieve
+        edit SMSTRIES '2'
+      task waves_retrieve_ff
+        edit SMSTRIES '2'
+      task waves_eps_retrieve
+        edit SMSTRIES '2'
+      task waves_ctrl_retrieve
+        edit SMSTRIES '2'
+      task waves
+        trigger waves_retrieve eq complete
+        edit SMSSTATUS '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      task waves_ff
+        trigger waves_retrieve_ff eq complete
+      task waves_ff_sea
+        trigger waves_ff eq complete
+      task waves_to_ct
+        trigger waves eq complete
+      task waves_from_ct
+        trigger waves_to_ct eq complete
+      task waves_ctrl
+        trigger waves_ctrl_retrieve eq complete
+      task waves_ctrl_to_ct
+        trigger waves_ctrl eq complete
+      task waves_ctrl_from_ct
+        trigger waves_ctrl_to_ct eq complete
+      task waves_eps_to_ct
+        trigger waves_eps_retrieve eq complete
+      task waves_eps_from_ct
+        trigger waves_eps_to_ct eq complete
+      task waves_eps_mean_spread
+        trigger waves_eps_to_ct eq complete
+      task waves_eps_spread_score
+        trigger waves_eps_to_ct eq complete
+    endfamily
+    family other
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'oper'
+      limit count 3
+      inlimit count
+      time 22:00
+      task other_ukmo_fc
+      task other_ukmo_an
+      task other_ncep_fc
+      task other_ncep_an
+      task other_dwd_fc
+      task other_dwd_an
+      task other_metfr_fc
+      task other_metfr_an
+      task other_jma_fc
+      task other_jma_an
+      task other_cmc_fc
+      task other_cmc_an
+      task other_bom_fc
+      task other_bom_an
+    endfamily
+    task restart
+      time 17:30
+  endfamily
+  family 06
+    repeat date YMD 20091008 20111031 1
+    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
+    edit EMOS_BASE '06'
+    family bc
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'scda'
+      limit count 1
+      inlimit count
+      task bc_upperair
+      task bc_sfc
+    endfamily
+    task restart
+      time 17:00
+  endfamily
+  family 18
+    repeat date YMD 20091008 20111031 1
+    edit SMSFILES '/home/ma/emos/def/verify/verify_oper'
+    edit EMOS_BASE '18'
+    family bc
+      edit WSHOST 'swarm'
+      edit QUEUE 'verify@scores2'
+      edit SMSCMD 'smssubmit.claude1 %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOBOUT%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'scda'
+      limit count 1
+      inlimit count
+      task bc_upperair
+      task bc_sfc
+    endfamily
+    task restart
+      time 09:00
+  endfamily
+endsuite
+suite macc
+  edit USER 'emos'
+  edit SCHOST 'bee01'
+  edit SCHOST_BKUP 'drn01'
+  edit WSHOST 'swarm'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/emos_dir/f93i/log'
+  edit USE_YMD 'true'
+  edit YMD '20090601'
+  edit DATEMASK '*.*.*'
+  edit VERSION 'f93i'
+  edit INIEXPVER '0001'
+  edit TCINIEXPVER '0001'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '00'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'tc'
+  edit USER_PRIORITY '70'
+  edit REINITIALIZE 'false'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/macc/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/macc/include'
+  edit ACCOUNT 'oosu'
+  edit STREAM 'EF'
+  edit EMOS_STREAM 'EF'
+  edit ENSEMBLES '50'
+  edit ENS_SIZE '50'
+  edit MARS_DB 'marsod'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit SMSLOGHOST 'c1a'
+  edit SMSLOGPORT '9316'
+  edit OD_PROJ 'od'
+  edit SUITE_START '20090602'
+  edit QUEUE 'emos-e'
+  edit QUEUE_EPILOG 'emos-exp'
+  edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB%'
+  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/vol/emos_nc/output'
+  edit SMSOUT '/vol/emos_nc/output'
+  edit SLEEPTIME '1'
+  inlimit /limits:swarm
+  clock hybrid 
+  family limits
+    limit linux_cluster 8
+    limit raq_ensemble 2
+    limit calchas 4
+  endfamily
+  family gac
+    inlimit /macc/limits:linux_cluster
+    family plot
+      edit METPY 'metpy'
+      edit UPDATE_WEB_NOW 'yes'
+      edit DO_PUSH_TO_WEB 'yes'
+      family nrt
+        repeat date YMD 20090928 20111215 1
+        edit METPY 'metpy'
+        edit VERSION 'f93i'
+        edit PARAMETERS 'co,go3'
+        edit LEVELS '850,500,300,50'
+        task nrt_fields
+          trigger ( /ecgems/f93i/an/lag:YMD gt /macc/gac/plot/nrt:YMD) or ( /ecgems/f93i/an/lag:YMD eq /macc/gac/plot/nrt:YMD and /ecgems/f93i/an/lag/00/archive eq complete)
+        task nrt_totalcolumns
+          trigger nrt_fields eq complete
+          edit PARAMETERS 'tcco,gtco3'
+        task nrt_zonalmean
+          trigger nrt_totalcolumns eq complete
+          edit METPY 'metpy_new'
+        task nrt_opticaldepth
+          trigger nrt_zonalmean eq complete
+          edit AERTYPES 'total,natural,anthropogenic'
+          edit METPY 'metpy_new'
+        task nrt_uvindex
+          trigger nrt_opticaldepth eq complete
+      endfamily
+      family fcampaign
+        repeat date YMD 20090928 20111215 1
+        edit VERSION 'f7kn'
+        edit OWNER 'nal'
+        family deps
+          task dummy
+            time 09:00
+        endfamily
+        task fcampaign_retrieve_and_process
+          trigger deps eq complete
+        task fcampaign_make_horiz_plots
+          trigger fcampaign_retrieve_and_process eq complete
+        task fcampaign_make_xs_plots
+          trigger fcampaign_make_horiz_plots eq complete
+        task fcampaign_cleanup
+          trigger fcampaign_make_xs_plots eq complete
+      endfamily
+      family gems_reanalysis
+        repeat enumerated month "200301" "200302" "200303" "200304" "200305" "200306" "200307" "200308" "200309" "200310" "200311" "200312" "200401" "200402" "200403" "200404" "200405" "200406" "200407" "200408" "200409" "200410" "200411" "200412" "200501" "200502" "200503" "200504" "200505" "200506" "200507" "200508" "200509" "200510" "200511" "200512" "200601" "200602" "200603" "200604" "200605" "200606" "200607" "200608" "200609" "200610" "200611" "200612" "200701" "200702" "200703" "200704" "200705" "200706" "200707" "200708" "200709" "200710" "200711" "200712" "200801" "200802" "200803" "200804" "200805" "200806" "200807" "200808" "200809" "200810" "200811" "200812" "200901" "200902" "200903" "200904"
+        edit VERSION 'f026'
+        edit LEVELS '850,500,300,50'
+        edit title 'GEMS_Reanalysis'
+        edit PARAMETERS 'co,go3,hcho,ch4,nox'
+        task gems_monthly_fields
+        task gems_monthly_zonalmean
+          trigger gems_monthly_fields eq complete
+          edit METPY 'metpy_new'
+        task gems_monthly_totalcolumns
+          trigger gems_monthly_zonalmean eq complete
+          edit PARAMETERS 'tcco,gtco3,tchcho,tcch4'
+      endfamily
+      family fire_products
+        repeat date YMD 20090928 20111215 1
+        edit METPY 'metpy_new'
+        family deps
+          task dummy
+            time 07:00
+        endfamily
+        task fire_radiative_power
+          trigger deps eq complete
+      endfamily
+    endfamily
+    family verif
+      family aer
+        family nrt
+          repeat date YMD 20090928 20111215 1
+          edit OWNER 'nal'
+          task aerover_nrt_make_plots
+            trigger ( /ecgems/f93i/an/lag:YMD gt /macc/gac/verif/aer/nrt:YMD) or ( /ecgems/f93i/an/lag:YMD eq /macc/gac/verif/aer/nrt:YMD and /ecgems/f93i/an/lag/00/archive eq complete)
+          family publish
+            repeat integer imonth 1 0 -1
+            task aerover_nrt_push_statistic_plots
+              trigger ../aerover_nrt_make_plots eq complete
+            task aerover_nrt_push_station_plots
+              trigger aerover_nrt_push_statistic_plots eq complete
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+  endfamily
+  family diss
+    task fcampaign_diss
+      trigger ( /macc/gac/plot/fcampaign:YMD gt /macc/diss/fcampaign_diss:YMD) or ( /macc/gac/plot/fcampaign:YMD eq /macc/diss/fcampaign_diss:YMD and /macc/gac/plot/fcampaign eq complete)
+      repeat date YMD 20090928 20111215 1
+    task nrt_diss
+      trigger ( /macc/gac/plot/nrt:YMD gt /macc/diss/nrt_diss:YMD) or ( /macc/gac/plot/nrt:YMD eq /macc/diss/nrt_diss:YMD and /macc/gac/plot/nrt eq complete)
+      repeat date YMD 20090928 20111215 1
+  endfamily
+endsuite
+suite ecgems
+  edit SMSFILES '/home/ma/emos/def/sync'
+  edit SLEEPTIME '1'
+  clock hybrid 
+  family f93i
+    family an
+      family lag
+        edit YMD '20100114'
+        family 00
+          task archive
+        endfamily
+        family 12
+          task archive
+        endfamily
+      endfamily
+    endfamily
+  endfamily
+  family f8na
+    family an
+      family lag
+        edit YMD '20010101'
+        family 00
+          task archive
+        endfamily
+        family 12
+          task archive
+        endfamily
+      endfamily
+    endfamily
+  endfamily
+endsuite
+suite e_36r1
+  edit CALC_PSBIAS 'true'
+  edit CALC_RSTRHBIAS 'false'
+  edit OBREALTIME 'true'
+  edit LFULL_IASI 'true'
+  edit USER 'emos'
+  edit SCHOST 'c1b'
+  edit STHOST '/s1b'
+  edit SCHOST_BKUP 'c1a'
+  edit STHOST_BKUP '/s1a'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit SMSLOGHOST 'c1b'
+  edit SMSLOGPORT '9316'
+  edit RESERVATION_ON '0'
+  edit VERSION '0046'
+  edit INIEXPVER '0045'
+  edit INISTREAM 'DCDA'
+  edit INIOFFSET_4D '3'
+  edit INICLASS 'od'
+  edit INILEVELS '91'
+  edit INIRESOL '1279'
+  edit FIRST_DAY '0'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '12'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY ''
+  edit INITIME '2009111800'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit PGNPES '64'
+  edit SVNPES '8'
+  edit ININPES '64'
+  edit REINITIALIZE 'false'
+  edit REINIEXPVER '0046'
+  edit REINIPERIOD_4D '12'
+  edit REINISTREAM 'DCDA'
+  edit REINIOFFSET '6'
+  edit REINI_NOT_ED 'false'
+  edit DATEMASK '*.*.*'
+  edit YMD '20091118'
+  edit USE_YMD 'true'
+  edit PARALLEL '4'
+  edit USER_PRIORITY '70'
+  edit FC_USER_PRIORITY '90'
+  edit ANNPES '192'
+  edit NPES_CCMA '%ANNPES%'
+  edit ANMEM '3584'
+  edit ANSTACK '700'
+  edit ANMRFS '160'
+  edit FCNPES '192'
+  edit FCMEM '3584'
+  edit FCSTACK '690'
+  edit FCMRFS '32'
+  edit PERIOD_4D '12'
+  edit WINDOW_LENGTH_4D '12'
+  edit WINDOW_OFFSET_4D '3'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/e_36r1'
+  edit SMSINCLUDE '/home/ma/emos/def/e_36r1/include'
+  edit ACCOUNT 'oesu'
+  edit STREAM 'DA'
+  edit EMOS_STREAM 'DA'
+  edit PGEN_BINDIR '/home/ma/emos/bin/diss'
+  edit PGEN_OBJDIR '/home/ma/emos/bin/diss'
+  edit DISS_REQDB_ROOT '/diss/requirements'
+  edit DISS_BINDIR '/diss/bin/DISS'
+  edit MARS_DB 'marsod'
+  edit OBSHOST 'pp1'
+  edit OBS_USER 'emos'
+  edit OBS_BASE '/pp1'
+  edit LANONLY 'true'
+  edit LAR_4V_EF 'true'
+  edit LFC_DIR_FREQ 'true'
+  edit SMSLOGTIMEOUT '10'
+  edit INIVARBC 'true'
+  edit RUN_3HOURS_PP '1'
+  edit VERIFY 'verify'
+  edit SUITE_START '2009100212'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit.36r1 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+  edit SLEEPTIME '1'
+  inlimit /limits:c1b
+  clock hybrid 
+  family limits
+    limit mars 7
+    limit obs 1
+    limit ml 3
+    limit prod 20
+    limit q2diss 8
+    limit w2diss 2
+    limit pdb 8
+    limit prod_bc 6
+    limit prod_bc2 6
+    limit q2diss_bc 5
+    limit pdb_bc 2
+    limit prodcheck 1
+    limit backupprod 4
+    limit dissbackup 4
+    limit webplots 4
+    limit satmon 7
+    limit smon 3
+    limit obs_get 5
+    limit sync_fdb 1
+    limit sync_data 1
+    limit reservation 1
+    limit satimsim 20
+    limit satimsim_ret 5
+  endfamily
+  family main
+    trigger ( main:YMD le ( lag:YMD + 3))
+    repeat date YMD 20091118 20121212 1
+    family make
+      edit DELTA_DAY '-1'
+      edit EMOS_BASE '18'
+      edit STREAM 'DCDA'
+      task setup
+      task links
+        trigger setup eq complete
+        edit FSFAMILY 'an'
+        edit WSHOST 'bee01'
+      task datalinks
+        trigger setup eq complete and links eq complete
+        edit FSFAMILY 'an'
+      family bins
+        trigger ./links eq complete and ./datalinks eq complete
+        edit SMSFILES '/home/ma/emos/def/e_36r1/make'
+        task odbsql
+        task odbtools
+          trigger odbsql eq complete
+        task b2otools
+          trigger odbtools eq complete
+        task black
+          edit FSFAMILY 'an'
+        task ifs
+          trigger black eq complete and b2otools eq complete
+          edit FSFAMILY 'an'
+        task ssaabs
+          trigger ifs eq complete
+          edit FSFAMILY 'surf_anal'
+        task wamabs
+        task satrad
+          trigger ifs eq complete
+        task scat
+        task obstat
+          trigger odbsql eq complete
+        task satmon
+          trigger odbtools eq complete
+        task prepdata
+          trigger b2otools eq complete
+        task satimbin
+      endfamily
+      family const
+        edit SMSFILES '/home/ma/emos/def/e_36r1/make'
+        task wconst
+          trigger ../bins/wamabs eq complete
+        task wavini
+          trigger wconst eq complete
+          edit FSFAMILY 'fc'
+      endfamily
+      task obstat_ws
+        trigger links eq complete and datalinks eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSTRIES '1'
+        inlimit /limits:linux_cluster
+      task sync_basedir
+      task getini
+        trigger links eq complete and datalinks eq complete and ./bins/prepdata eq complete
+        edit FSFAMILY 'fc'
+      task inidata
+        trigger ./bins/ifs eq complete and getini eq complete
+        edit THREADS '8'
+        edit FSFAMILY 'fc'
+      family fc
+        trigger inidata eq complete and const eq complete
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task model
+          trigger getfcdata eq complete
+          edit FCLENGTH '15'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          meter step -1 15 15
+        task clean
+          trigger model eq complete
+          edit DELTA_DAY '-2'
+      endfamily
+      family prod
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod/make'
+        edit EMOS_DOMAIN 'g'
+        edit EMOS_TYPE 'fc'
+        edit EMOS_STREAM 'OPER'
+        task wparam
+          edit EMOS_TYPE 'wp'
+        task tf
+          edit EMOS_TYPE 'tf'
+        task sortreq
+        task bitmap
+        task clima
+        task disssch
+        task tools
+        task oper
+        task wave
+          edit EMOS_STREAM 'WAVE'
+      endfamily
+      task plotdb
+        trigger links eq complete and datalinks eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /limits:linux_cluster
+    endfamily
+    family 00dc
+      trigger make eq complete
+      edit EMOS_BASE '00'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/dc00/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc00/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc00/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        family getplus6
+          edit EMOS_BASE '06'
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/dc06/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc06/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc06/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete and ./getplus6 eq complete
+        family prepare_obs
+          trigger ./get eq complete and ./getplus6 eq complete
+          task preobs
+            edit mode 'not1crad'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+        family reservation
+          late -c +00:03
+          trigger ./get/get_stor eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task adv_res
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '30'
+            edit RESERVE_IN '30'
+            edit RESERVED_NODES '48'
+            edit RESERVATION_LABEL 'emos00dcA'
+            label info ""
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit PERIOD_4D '12'
+        edit WINDOW_LENGTH_4D '12'
+        edit WINDOW_OFFSET_4D '3'
+        edit ACCOUNT 'oedcdaan'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          event hires
+        task fetcherr
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+        task emiskf
+          trigger ./4dvar/uptraj_0/ifstraj eq complete
+          edit THREADS '1'
+        task update_psbias
+          trigger ./4dvar/ifstraj:finalwave
+        task update_rstrhbias
+          trigger ./4dvar/ifstraj:finalwave
+        task dcda_to_da
+          trigger ./4dvar eq complete and surf_anal eq complete
+          edit EMOS_TYPE 'an'
+          edit OPHOST 'c1b'
+        family reservation1
+          late -c +00:03
+          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:02 -c +00:02
+            edit RESERVED_CPUS '3328'
+            edit RESERVE_FOR '65'
+            label info ""
+          task rm_res
+            late -s +00:02 -c +00:02
+            edit RESERVATION_LABEL 'emos00'
+            label info ""
+          task set_class
+            late -s +00:02 -c +00:02
+            edit RESERVATION_DEFINITION 'default_nodiag'
+            label info ""
+        endfamily
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit EMOS_BASE '06'
+        edit ACCOUNT 'oedcdafc'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task model
+          late -s +00:02
+          trigger getfcdata eq complete
+          edit FCLENGTH '15'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          meter step -1 15 15
+        task ddh
+          trigger model eq complete
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./getfcdata eq active or ./getfcdata eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '3072'
+            edit RESERVE_FOR '4'
+            label info ""
+        endfamily
+        family reservation2
+          late -c +00:03
+          trigger ./model eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reset_cpu
+            late -s +00:03 -c +00:02
+            complete /e_36r1/main/12/an/vardata eq active or /e_36r1/main/12/an/vardata eq complete
+            edit RESERVED_CPUS '0'
+            label info ""
+        endfamily
+      endfamily
+    endfamily
+    family 06
+      trigger make eq complete
+      edit EMOS_BASE '06'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DA'
+      edit LAR_4V_EF 'false'
+      edit LFC_DIR_FREQ 'false'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/ex06/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete
+        family prepare_obs
+          trigger ./get eq complete
+          task preobs
+            edit mode 'not1crad'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit ACCOUNT 'oeoperan'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          trigger ../../00dc/fc/model:step ge 6 or ../../00dc/fc/model eq complete
+          event hires
+        task fetcherr
+          trigger ../../00dc/an eq complete
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit ACCOUNT 'oeoperfc'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task getpersSST
+          trigger getfcdata eq complete
+          edit SSTLEN '9'
+          edit SSTINT '1'
+          edit THREADS '2'
+          edit NPES '16'
+          edit MEM '1000'
+          edit CPUTIME '960'
+        task model
+          late -s +00:02
+          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
+          edit PERSST 'true'
+          edit FCLENGTH '9'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          meter step -1 9 9
+        task ddh
+          trigger model eq complete
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete
+      endfamily
+    endfamily
+    family 12bc
+      edit EMOS_BASE '12'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '0'
+      edit ACCOUNT 'opebcpg'
+      edit SMSURL 'GSCDA/12'
+      edit USER_PRIORITY '91'
+      family getreq
+        trigger ( /e_36r1/main/12/an/4dvar eq active or /e_36r1/main/12/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit PROD_TASK '1'
+        edit EMOS_DOMAIN 'G'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_PROJECT '12'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'SCDA'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '12'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger collectreq eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete and ( req:001 or req eq complete)
+          label info ""
+          event 1 
+      endfamily
+      family prod
+        trigger ( getreq/req:001 or getreq/req eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit EMOS_PROJECT '12'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        family an
+          trigger /e_36r1/main/12/an/surf_anal eq complete and ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar/ifstraj eq complete) and 0 eq 0
+          edit EMOS_TYPE 'an'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ../090/prodgen eq complete and ../../prod eq queued and /e_36r1/main/12/prod eq complete
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 000
+          trigger ( /e_36r1/main/12/fc/model:step ge 000 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0000'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 12 or /e_36r1/main/12/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 003
+          trigger ( /e_36r1/main/12/fc/model:step ge 003 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 15 or /e_36r1/main/12/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 006
+          trigger ( /e_36r1/main/12/fc/model:step ge 006 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 18 or /e_36r1/main/12/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 009
+          trigger ( /e_36r1/main/12/fc/model:step ge 009 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 21 or /e_36r1/main/12/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 012
+          trigger ( /e_36r1/main/12/fc/model:step ge 012 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 24 or /e_36r1/main/12/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 015
+          trigger ( /e_36r1/main/12/fc/model:step ge 015 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 27 or /e_36r1/main/12/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 018
+          trigger ( /e_36r1/main/12/fc/model:step ge 018 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 30 or /e_36r1/main/12/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 021
+          trigger ( /e_36r1/main/12/fc/model:step ge 021 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 33 or /e_36r1/main/12/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 024
+          trigger ( /e_36r1/main/12/fc/model:step ge 024 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 36 or /e_36r1/main/12/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 027
+          trigger ( /e_36r1/main/12/fc/model:step ge 027 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 39 or /e_36r1/main/12/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 030
+          trigger ( /e_36r1/main/12/fc/model:step ge 030 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 42 or /e_36r1/main/12/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 033
+          trigger ( /e_36r1/main/12/fc/model:step ge 033 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 45 or /e_36r1/main/12/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 036
+          trigger ( /e_36r1/main/12/fc/model:step ge 036 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0036'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 48 or /e_36r1/main/12/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 039
+          trigger ( /e_36r1/main/12/fc/model:step ge 039 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0039'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 51 or /e_36r1/main/12/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 042
+          trigger ( /e_36r1/main/12/fc/model:step ge 042 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0042'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 54 or /e_36r1/main/12/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 045
+          trigger ( /e_36r1/main/12/fc/model:step ge 045 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0045'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 57 or /e_36r1/main/12/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 048
+          trigger ( /e_36r1/main/12/fc/model:step ge 048 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0048'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 60 or /e_36r1/main/12/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 051
+          trigger ( /e_36r1/main/12/fc/model:step ge 051 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0051'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 63 or /e_36r1/main/12/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 054
+          trigger ( /e_36r1/main/12/fc/model:step ge 054 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0054'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 66 or /e_36r1/main/12/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 057
+          trigger ( /e_36r1/main/12/fc/model:step ge 057 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0057'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 69 or /e_36r1/main/12/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 060
+          trigger ( /e_36r1/main/12/fc/model:step ge 060 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0060'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 72 or /e_36r1/main/12/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 063
+          trigger ( /e_36r1/main/12/fc/model:step ge 063 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0063'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 75 or /e_36r1/main/12/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 066
+          trigger ( /e_36r1/main/12/fc/model:step ge 066 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0066'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 78 or /e_36r1/main/12/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 069
+          trigger ( /e_36r1/main/12/fc/model:step ge 069 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0069'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 81 or /e_36r1/main/12/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 072
+          trigger ( /e_36r1/main/12/fc/model:step ge 072 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0072'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 84 or /e_36r1/main/12/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 075
+          trigger ( /e_36r1/main/12/fc/model:step ge 075 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0075'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 87 or /e_36r1/main/12/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 078
+          trigger ( /e_36r1/main/12/fc/model:step ge 078 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0078'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/12/fc/model:step ge 90 or /e_36r1/main/12/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 081
+          trigger ( /e_36r1/main/12/fc/model:step ge 081 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0081'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+        family 084
+          trigger ( /e_36r1/main/12/fc/model:step ge 084 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0084'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+        family 087
+          trigger ( /e_36r1/main/12/fc/model:step ge 087 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0087'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+        family 090
+          trigger ( /e_36r1/main/12/fc/model:step ge 090 or /e_36r1/main/12/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0090'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        task operation_is_late
+          event yes
+        family oper
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '92'
+          edit SMSURL 'GSCDA/12'
+          edit EMOS_PROJECT '12'
+          family an
+            task pdb
+              trigger ../../../prod/an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event 1 
+          endfamily
+          family 000
+            edit EMOS_TIME_STEP_H '0000'
+            task pdb
+              trigger ../../../prod/000/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ../an/q2diss eq complete
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 003
+            edit EMOS_TIME_STEP_H '0003'
+            task pdb
+              trigger ../../../prod/003/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/003/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 006
+            edit EMOS_TIME_STEP_H '0006'
+            task pdb
+              trigger ../../../prod/006/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/006/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 009
+            edit EMOS_TIME_STEP_H '0009'
+            task pdb
+              trigger ../../../prod/009/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/009/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 012
+            edit EMOS_TIME_STEP_H '0012'
+            task pdb
+              trigger ../../../prod/012/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/012/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 015
+            edit EMOS_TIME_STEP_H '0015'
+            task pdb
+              trigger ../../../prod/015/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/015/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 018
+            edit EMOS_TIME_STEP_H '0018'
+            task pdb
+              trigger ../../../prod/018/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/018/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 021
+            edit EMOS_TIME_STEP_H '0021'
+            task pdb
+              trigger ../../../prod/021/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/021/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 024
+            edit EMOS_TIME_STEP_H '0024'
+            task pdb
+              trigger ../../../prod/024/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/024/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 027
+            edit EMOS_TIME_STEP_H '0027'
+            task pdb
+              trigger ../../../prod/027/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/027/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 030
+            edit EMOS_TIME_STEP_H '0030'
+            task pdb
+              trigger ../../../prod/030/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/030/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 033
+            edit EMOS_TIME_STEP_H '0033'
+            task pdb
+              trigger ../../../prod/033/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/033/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 036
+            edit EMOS_TIME_STEP_H '0036'
+            task pdb
+              trigger ../../../prod/036/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/036/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 039
+            edit EMOS_TIME_STEP_H '0039'
+            task pdb
+              trigger ../../../prod/039/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/039/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 042
+            edit EMOS_TIME_STEP_H '0042'
+            task pdb
+              trigger ../../../prod/042/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/042/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 045
+            edit EMOS_TIME_STEP_H '0045'
+            task pdb
+              trigger ../../../prod/045/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/045/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 048
+            edit EMOS_TIME_STEP_H '0048'
+            task pdb
+              trigger ../../../prod/048/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/048/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 051
+            edit EMOS_TIME_STEP_H '0051'
+            task pdb
+              trigger ../../../prod/051/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/051/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 054
+            edit EMOS_TIME_STEP_H '0054'
+            task pdb
+              trigger ../../../prod/054/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/054/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 057
+            edit EMOS_TIME_STEP_H '0057'
+            task pdb
+              trigger ../../../prod/057/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/057/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 060
+            edit EMOS_TIME_STEP_H '0060'
+            task pdb
+              trigger ../../../prod/060/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/060/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 063
+            edit EMOS_TIME_STEP_H '0063'
+            task pdb
+              trigger ../../../prod/063/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/063/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 066
+            edit EMOS_TIME_STEP_H '0066'
+            task pdb
+              trigger ../../../prod/066/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/066/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 069
+            edit EMOS_TIME_STEP_H '0069'
+            task pdb
+              trigger ../../../prod/069/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/069/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 072
+            edit EMOS_TIME_STEP_H '0072'
+            task pdb
+              trigger ../../../prod/072/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/072/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 075
+            edit EMOS_TIME_STEP_H '0075'
+            task pdb
+              trigger ../../../prod/075/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/075/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 078
+            edit EMOS_TIME_STEP_H '0078'
+            task pdb
+              trigger ../../../prod/078/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/078/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 081
+            edit EMOS_TIME_STEP_H '0081'
+            task pdb
+              trigger ../../../prod/081/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 084
+            edit EMOS_TIME_STEP_H '0084'
+            task pdb
+              trigger ../../../prod/084/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 087
+            edit EMOS_TIME_STEP_H '0087'
+            task pdb
+              trigger ../../../prod/087/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 090
+            edit EMOS_TIME_STEP_H '0090'
+            task pdb
+              trigger ../../../prod/090/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          task check
+            trigger ./078 eq complete
+        endfamily
+      endfamily
+    endfamily
+    family 12
+      trigger make eq complete
+      edit EMOS_BASE '12'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      edit ACCOUNT 'oeoperpg'
+      edit SMSURL 'GOPER/12'
+      edit USER_PRIORITY '90'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/ex12/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex12/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex12/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete
+        family prepare_obs
+          trigger ./get eq complete
+          task preobs
+            trigger /e_36r1/main/00dc/an/update_psbias eq complete and /e_36r1/main/00dc/an/update_rstrhbias eq complete
+            edit mode 'not1crad'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+        family reservation
+          late -c +00:03
+          trigger ./get/get_stor eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task adv_res
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '30'
+            edit RESERVE_IN '60'
+            edit RESERVED_NODES '45'
+            edit RESERVATION_LABEL 'emos12XP'
+            label info ""
+          task adv_resA
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '80'
+            edit RESERVE_IN '11'
+            edit RESERVED_NODES '48'
+            edit RESERVATION_LABEL 'emos12A'
+            label info ""
+          task adv_resB
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '30'
+            edit RESERVE_IN '48'
+            edit RESERVED_NODES '48'
+            edit RESERVATION_LABEL 'emos12B'
+            label info ""
+          task adv_resC
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '50'
+            edit RESERVE_IN '55'
+            edit RESERVED_NODES '132'
+            edit RESERVATION_LABEL 'emos12C'
+            label info ""
+          task loadl_cycle_limit
+            late -s +00:03 -c +00:02
+            edit LOADL_CYCLE '65'
+            label info ""
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit PERIOD_4D '6'
+        edit WINDOW_LENGTH_4D '6'
+        edit WINDOW_OFFSET_4D '3'
+        edit ACCOUNT 'oeoperan'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          trigger ( ../../00dc/fc/model:step ge 6 or ../../00dc/fc/model eq complete) and ../../06/an eq complete
+          event hires
+        task fetcherr
+          trigger ../../06/an eq complete and ../../00dc/an eq complete
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '3328'
+            edit RESERVE_FOR '80'
+            label info ""
+          task rm_res
+            late -s +00:03 -c +00:02
+            edit RESERVATION_LABEL 'emos12A'
+            label info ""
+          task ms_cpu
+            late -s +00:03 -c +00:02
+            edit MS_CPUS '$((64*30))'
+            label info ""
+        endfamily
+        family reservation3
+          late -c +00:03
+          trigger ./4dvar/uptraj_1 eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task set_class
+            late -s +00:03 -c +00:02
+            edit RESERVATION_DEFINITION 'default'
+            label info ""
+        endfamily
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit ACCOUNT 'oeoperfc'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task getpersSST
+          trigger getfcdata eq complete
+          edit SSTLEN '240'
+          edit SSTINT '1'
+          edit THREADS '2'
+          edit NPES '16'
+          edit MEM '1000'
+          edit CPUTIME '960'
+        task model
+          late -s +00:02
+          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
+          edit PERSST 'true'
+          edit FCLENGTH '240'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          meter step -1 240 240
+        task ddh
+          trigger model eq complete
+        task imet
+          trigger ddh eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task ddh_arm
+          trigger ddh eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete and ../../00dc/fc eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./getfcdata eq active or ./getfcdata eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          family xp
+            task set_xp
+              late -s +00:03 -c +00:02
+              edit RESERVATION_LABEL 'emos12XP'
+              label info ""
+            task rm_res
+              late -s +00:03 -c +00:02
+              trigger ./set_xp eq complete
+              edit RESERVATION_LABEL 'emos12XP'
+              label info ""
+          endfamily
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '12160'
+            edit RESERVE_FOR '2'
+            label info ""
+          task rm_res
+            late -s +00:03 -c +00:02
+            edit RESERVATION_LABEL 'emos12B'
+            label info ""
+        endfamily
+      endfamily
+      family getreq
+        trigger ( /e_36r1/main/12/an/4dvar eq active or /e_36r1/main/12/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit PROD_TASK '1'
+        edit EMOS_DOMAIN 'G'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_PROJECT '12'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'OPER'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '12'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger collectreq eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete and ( req:001 or req eq complete)
+          label info ""
+          event 1 
+        task collectwave
+          trigger ./collectbitmap eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '12'
+          edit EMOS_STREAM 'WAVE'
+        task wavereq
+          late -s +00:03 -c +00:10
+          trigger ./collectwave eq complete
+          edit EMOS_STREAM 'WAVE'
+          label info ""
+          event 1 
+        task pgclima
+          late -s +00:03 -c +00:10
+          event 1 
+        task cleanpdb
+      endfamily
+      family prod
+        trigger ( getreq/req:001 or getreq/req eq complete) and ( getreq/bitmap:001 or getreq/bitmap eq complete) and ( getreq/wavereq:001 or getreq/wavereq eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit EMOS_PROJECT '12'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        family 06an
+          trigger /e_36r1/main/00dc/an/dcda_to_da eq complete
+          edit EMOS_TYPE 'an'
+          edit EMOS_BASE '06'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 12an
+          trigger /e_36r1/main/12/an/surf_anal eq complete and ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar/ifstraj eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TYPE 'an'
+          edit PGNPES '90'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            edit SMSPASS 'stripped'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ( ./derived_param:SMOS or ./derived_param eq complete) and ( ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar/ifstraj eq complete))
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 000
+          trigger ( /e_36r1/main/12/fc/model:step ge 000 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0000'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '000'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 003
+          trigger ( /e_36r1/main/12/fc/model:step ge 003 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '003'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 006
+          trigger ( /e_36r1/main/12/fc/model:step ge 006 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '006'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 009
+          trigger ( /e_36r1/main/12/fc/model:step ge 009 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '009'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 012
+          trigger ( /e_36r1/main/12/fc/model:step ge 012 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '012'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 015
+          trigger ( /e_36r1/main/12/fc/model:step ge 015 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '015'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 018
+          trigger ( /e_36r1/main/12/fc/model:step ge 018 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '018'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 021
+          trigger ( /e_36r1/main/12/fc/model:step ge 021 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '021'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 024
+          trigger ( /e_36r1/main/12/fc/model:step ge 024 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '024'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 027
+          trigger ( /e_36r1/main/12/fc/model:step ge 027 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '027'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 030
+          trigger ( /e_36r1/main/12/fc/model:step ge 030 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '030'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 033
+          trigger ( /e_36r1/main/12/fc/model:step ge 033 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '033'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 036
+          trigger ( /e_36r1/main/12/fc/model:step ge 036 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0036'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '036'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 039
+          trigger ( /e_36r1/main/12/fc/model:step ge 039 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0039'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '039'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 042
+          trigger ( /e_36r1/main/12/fc/model:step ge 042 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0042'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '042'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 045
+          trigger ( /e_36r1/main/12/fc/model:step ge 045 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0045'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '045'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 048
+          trigger ( /e_36r1/main/12/fc/model:step ge 048 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0048'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '048'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 051
+          trigger ( /e_36r1/main/12/fc/model:step ge 051 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0051'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '051'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 054
+          trigger ( /e_36r1/main/12/fc/model:step ge 054 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0054'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '054'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 057
+          trigger ( /e_36r1/main/12/fc/model:step ge 057 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0057'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '057'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 060
+          trigger ( /e_36r1/main/12/fc/model:step ge 060 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0060'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '060'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 063
+          trigger ( /e_36r1/main/12/fc/model:step ge 063 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0063'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '063'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 066
+          trigger ( /e_36r1/main/12/fc/model:step ge 066 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0066'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '066'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 069
+          trigger ( /e_36r1/main/12/fc/model:step ge 069 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0069'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '069'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 072
+          trigger ( /e_36r1/main/12/fc/model:step ge 072 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0072'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '072'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 075
+          trigger ( /e_36r1/main/12/fc/model:step ge 075 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0075'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '075'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 078
+          trigger ( /e_36r1/main/12/fc/model:step ge 078 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0078'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '078'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 081
+          trigger ( /e_36r1/main/12/fc/model:step ge 081 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0081'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '081'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 084
+          trigger ( /e_36r1/main/12/fc/model:step ge 084 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0084'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '084'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 087
+          trigger ( /e_36r1/main/12/fc/model:step ge 087 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0087'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '087'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 090
+          trigger ( /e_36r1/main/12/fc/model:step ge 090 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0090'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '090'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 093
+          trigger ( /e_36r1/main/12/fc/model:step ge 093 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0093'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../090/derived_param:SMOS or ../090/derived_param eq complete) or ( ../090/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '093'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 096
+          trigger ( /e_36r1/main/12/fc/model:step ge 096 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0096'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../093/derived_param:SMOS or ../093/derived_param eq complete) or ( ../093/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '096'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 099
+          trigger ( /e_36r1/main/12/fc/model:step ge 099 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0099'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../096/derived_param:SMOS or ../096/derived_param eq complete) or ( ../096/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '099'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 102
+          trigger ( /e_36r1/main/12/fc/model:step ge 102 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0102'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../099/derived_param:SMOS or ../099/derived_param eq complete) or ( ../099/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '102'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 105
+          trigger ( /e_36r1/main/12/fc/model:step ge 105 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0105'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../102/derived_param:SMOS or ../102/derived_param eq complete) or ( ../102/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '105'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 108
+          trigger ( /e_36r1/main/12/fc/model:step ge 108 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0108'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../105/derived_param:SMOS or ../105/derived_param eq complete) or ( ../105/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '108'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 111
+          trigger ( /e_36r1/main/12/fc/model:step ge 111 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0111'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../108/derived_param:SMOS or ../108/derived_param eq complete) or ( ../108/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '111'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 114
+          trigger ( /e_36r1/main/12/fc/model:step ge 114 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0114'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../111/derived_param:SMOS or ../111/derived_param eq complete) or ( ../111/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '114'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 117
+          trigger ( /e_36r1/main/12/fc/model:step ge 117 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0117'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../114/derived_param:SMOS or ../114/derived_param eq complete) or ( ../114/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '117'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 120
+          trigger ( /e_36r1/main/12/fc/model:step ge 120 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0120'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../117/derived_param:SMOS or ../117/derived_param eq complete) or ( ../117/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '120'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 123
+          trigger ( /e_36r1/main/12/fc/model:step ge 123 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0123'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../120/derived_param:SMOS or ../120/derived_param eq complete) or ( ../120/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '123'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 126
+          trigger ( /e_36r1/main/12/fc/model:step ge 126 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0126'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../123/derived_param:SMOS or ../123/derived_param eq complete) or ( ../123/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '126'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 129
+          trigger ( /e_36r1/main/12/fc/model:step ge 129 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0129'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../126/derived_param:SMOS or ../126/derived_param eq complete) or ( ../126/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '129'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 132
+          trigger ( /e_36r1/main/12/fc/model:step ge 132 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0132'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../129/derived_param:SMOS or ../129/derived_param eq complete) or ( ../129/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '132'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 135
+          trigger ( /e_36r1/main/12/fc/model:step ge 135 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0135'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../132/derived_param:SMOS or ../132/derived_param eq complete) or ( ../132/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '135'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 138
+          trigger ( /e_36r1/main/12/fc/model:step ge 138 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0138'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../135/derived_param:SMOS or ../135/derived_param eq complete) or ( ../135/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '138'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 141
+          trigger ( /e_36r1/main/12/fc/model:step ge 141 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0141'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../138/derived_param:SMOS or ../138/derived_param eq complete) or ( ../138/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '141'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 144
+          trigger ( /e_36r1/main/12/fc/model:step ge 144 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0144'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../141/derived_param:SMOS or ../141/derived_param eq complete) or ( ../141/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '144'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 150
+          trigger ( /e_36r1/main/12/fc/model:step ge 150 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0150'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../144/derived_param:SMOS or ../144/derived_param eq complete) or ( ../144/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '150'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 156
+          trigger ( /e_36r1/main/12/fc/model:step ge 156 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0156'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../150/derived_param:SMOS or ../150/derived_param eq complete) or ( ../150/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '156'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 162
+          trigger ( /e_36r1/main/12/fc/model:step ge 162 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0162'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../156/derived_param:SMOS or ../156/derived_param eq complete) or ( ../156/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '162'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 168
+          trigger ( /e_36r1/main/12/fc/model:step ge 168 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0168'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../162/derived_param:SMOS or ../162/derived_param eq complete) or ( ../162/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '168'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 174
+          trigger ( /e_36r1/main/12/fc/model:step ge 174 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0174'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../168/derived_param:SMOS or ../168/derived_param eq complete) or ( ../168/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '174'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 180
+          trigger ( /e_36r1/main/12/fc/model:step ge 180 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0180'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../174/derived_param:SMOS or ../174/derived_param eq complete) or ( ../174/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '180'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 186
+          trigger ( /e_36r1/main/12/fc/model:step ge 186 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0186'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../180/derived_param:SMOS or ../180/derived_param eq complete) or ( ../180/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '186'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 192
+          trigger ( /e_36r1/main/12/fc/model:step ge 192 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0192'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../186/derived_param:SMOS or ../186/derived_param eq complete) or ( ../186/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '192'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 198
+          trigger ( /e_36r1/main/12/fc/model:step ge 198 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0198'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../192/derived_param:SMOS or ../192/derived_param eq complete) or ( ../192/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '198'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 204
+          trigger ( /e_36r1/main/12/fc/model:step ge 204 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0204'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../198/derived_param:SMOS or ../198/derived_param eq complete) or ( ../198/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '204'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 210
+          trigger ( /e_36r1/main/12/fc/model:step ge 210 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0210'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../204/derived_param:SMOS or ../204/derived_param eq complete) or ( ../204/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '210'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 216
+          trigger ( /e_36r1/main/12/fc/model:step ge 216 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0216'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../210/derived_param:SMOS or ../210/derived_param eq complete) or ( ../210/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '216'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 222
+          trigger ( /e_36r1/main/12/fc/model:step ge 222 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0222'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../216/derived_param:SMOS or ../216/derived_param eq complete) or ( ../216/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '222'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 228
+          trigger ( /e_36r1/main/12/fc/model:step ge 228 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0228'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../222/derived_param:SMOS or ../222/derived_param eq complete) or ( ../222/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '228'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 234
+          trigger ( /e_36r1/main/12/fc/model:step ge 234 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0234'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../228/derived_param:SMOS or ../228/derived_param eq complete) or ( ../228/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '234'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 240
+          trigger ( /e_36r1/main/12/fc/model:step ge 240 or /e_36r1/main/12/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete) and ../getreq/cleanpdb eq complete
+          edit EMOS_TIME_STEP_H '0240'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodmet
+            late -s +00:05 -c +00:15
+            edit PROD_TASK '5'
+            edit PGNPES '1'
+            edit EMOS_TYPE 'mt'
+            inlimit /e_36r1/limits:prod
+          task prod_wparam
+            late -s +00:05 -c +00:15
+            trigger ./derived_param eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TYPE 'wp'
+            edit PGNPES '64'
+            edit INIMEM '800'
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../234/derived_param:SMOS or ../234/derived_param eq complete) or ( ../234/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '240'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family reservation1
+          late -c +00:03
+          trigger /e_36r1/main/12bc/prod/078/prodgen eq active or /e_36r1/main/12bc/prod/078/prodgen eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task set_xp
+            late -s +00:03 -c +00:02
+            edit RESERVATION_NODES '45'
+            label info ""
+        endfamily
+        family reservation2
+          late -c +00:03
+          trigger /e_36r1/main/12/prod/240/prodgen eq active or /e_36r1/main/12/prod/240/prodgen eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task set_xp
+            late -s +00:03 -c +00:02
+            edit RESERVATION_NODES '20'
+            label info ""
+        endfamily
+        family reservation3
+          late -c +00:03
+          trigger /e_36r1/main/12/prod/240/prodgen eq active or /e_36r1/main/12/prod/240/prodgen eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reset_xp
+            late -s +00:03 -c +00:02
+            trigger /emc_36r1/main/12/legB/prod eq complete
+            edit RESERVATION_NODES '0'
+            label info ""
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        task operation_is_late
+          event yes
+        family oper
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '92'
+          edit EMOS_PROJECT '12'
+          edit SMSURL 'GSCDA/12'
+          family 06an
+            edit EMOS_BASE '06'
+            edit EMOS_TYPE 'an'
+            edit SMSURL 'GOPER/06'
+            task pdb
+              trigger ../../../prod/06an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 12an
+            edit EMOS_TYPE 'an'
+            edit SMSURL 'GOPER/12'
+            task pdb
+              trigger ../../../prod/12an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 000
+            edit EMOS_TIME_STEP_H '0000'
+            task pdb
+              trigger ../../../prod/000/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../12an/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 003
+            edit EMOS_TIME_STEP_H '0003'
+            task pdb
+              trigger ../../../prod/003/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 006
+            edit EMOS_TIME_STEP_H '0006'
+            task pdb
+              trigger ../../../prod/006/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 009
+            edit EMOS_TIME_STEP_H '0009'
+            task pdb
+              trigger ../../../prod/009/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 012
+            edit EMOS_TIME_STEP_H '0012'
+            task pdb
+              trigger ../../../prod/012/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 015
+            edit EMOS_TIME_STEP_H '0015'
+            task pdb
+              trigger ../../../prod/015/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 018
+            edit EMOS_TIME_STEP_H '0018'
+            task pdb
+              trigger ../../../prod/018/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 021
+            edit EMOS_TIME_STEP_H '0021'
+            task pdb
+              trigger ../../../prod/021/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 024
+            edit EMOS_TIME_STEP_H '0024'
+            task pdb
+              trigger ../../../prod/024/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 027
+            edit EMOS_TIME_STEP_H '0027'
+            task pdb
+              trigger ../../../prod/027/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 030
+            edit EMOS_TIME_STEP_H '0030'
+            task pdb
+              trigger ../../../prod/030/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 033
+            edit EMOS_TIME_STEP_H '0033'
+            task pdb
+              trigger ../../../prod/033/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 036
+            edit EMOS_TIME_STEP_H '0036'
+            task pdb
+              trigger ../../../prod/036/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 039
+            edit EMOS_TIME_STEP_H '0039'
+            task pdb
+              trigger ../../../prod/039/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 042
+            edit EMOS_TIME_STEP_H '0042'
+            task pdb
+              trigger ../../../prod/042/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 045
+            edit EMOS_TIME_STEP_H '0045'
+            task pdb
+              trigger ../../../prod/045/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 048
+            edit EMOS_TIME_STEP_H '0048'
+            task pdb
+              trigger ../../../prod/048/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 051
+            edit EMOS_TIME_STEP_H '0051'
+            task pdb
+              trigger ../../../prod/051/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 054
+            edit EMOS_TIME_STEP_H '0054'
+            task pdb
+              trigger ../../../prod/054/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 057
+            edit EMOS_TIME_STEP_H '0057'
+            task pdb
+              trigger ../../../prod/057/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 060
+            edit EMOS_TIME_STEP_H '0060'
+            task pdb
+              trigger ../../../prod/060/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 063
+            edit EMOS_TIME_STEP_H '0063'
+            task pdb
+              trigger ../../../prod/063/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 066
+            edit EMOS_TIME_STEP_H '0066'
+            task pdb
+              trigger ../../../prod/066/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 069
+            edit EMOS_TIME_STEP_H '0069'
+            task pdb
+              trigger ../../../prod/069/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 072
+            edit EMOS_TIME_STEP_H '0072'
+            task pdb
+              trigger ../../../prod/072/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 075
+            edit EMOS_TIME_STEP_H '0075'
+            task pdb
+              trigger ../../../prod/075/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 078
+            edit EMOS_TIME_STEP_H '0078'
+            task pdb
+              trigger ../../../prod/078/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 081
+            edit EMOS_TIME_STEP_H '0081'
+            task pdb
+              trigger ../../../prod/081/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 084
+            edit EMOS_TIME_STEP_H '0084'
+            task pdb
+              trigger ../../../prod/084/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 087
+            edit EMOS_TIME_STEP_H '0087'
+            task pdb
+              trigger ../../../prod/087/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 090
+            edit EMOS_TIME_STEP_H '0090'
+            task pdb
+              trigger ../../../prod/090/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 093
+            edit EMOS_TIME_STEP_H '0093'
+            task pdb
+              trigger ../../../prod/093/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../090/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 096
+            edit EMOS_TIME_STEP_H '0096'
+            task pdb
+              trigger ../../../prod/096/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../093/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 099
+            edit EMOS_TIME_STEP_H '0099'
+            task pdb
+              trigger ../../../prod/099/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../096/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 102
+            edit EMOS_TIME_STEP_H '0102'
+            task pdb
+              trigger ../../../prod/102/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../099/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 105
+            edit EMOS_TIME_STEP_H '0105'
+            task pdb
+              trigger ../../../prod/105/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../102/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 108
+            edit EMOS_TIME_STEP_H '0108'
+            task pdb
+              trigger ../../../prod/108/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../105/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 111
+            edit EMOS_TIME_STEP_H '0111'
+            task pdb
+              trigger ../../../prod/111/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../108/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 114
+            edit EMOS_TIME_STEP_H '0114'
+            task pdb
+              trigger ../../../prod/114/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../111/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 117
+            edit EMOS_TIME_STEP_H '0117'
+            task pdb
+              trigger ../../../prod/117/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../114/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 120
+            edit EMOS_TIME_STEP_H '0120'
+            task pdb
+              trigger ../../../prod/120/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../117/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 123
+            edit EMOS_TIME_STEP_H '0123'
+            task pdb
+              trigger ../../../prod/123/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../120/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 126
+            edit EMOS_TIME_STEP_H '0126'
+            task pdb
+              trigger ../../../prod/126/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../123/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 129
+            edit EMOS_TIME_STEP_H '0129'
+            task pdb
+              trigger ../../../prod/129/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../126/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 132
+            edit EMOS_TIME_STEP_H '0132'
+            task pdb
+              trigger ../../../prod/132/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../129/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 135
+            edit EMOS_TIME_STEP_H '0135'
+            task pdb
+              trigger ../../../prod/135/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../132/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 138
+            edit EMOS_TIME_STEP_H '0138'
+            task pdb
+              trigger ../../../prod/138/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../135/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 141
+            edit EMOS_TIME_STEP_H '0141'
+            task pdb
+              trigger ../../../prod/141/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../138/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 144
+            edit EMOS_TIME_STEP_H '0144'
+            task pdb
+              trigger ../../../prod/144/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../141/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 150
+            edit EMOS_TIME_STEP_H '0150'
+            task pdb
+              trigger ../../../prod/150/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../144/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 156
+            edit EMOS_TIME_STEP_H '0156'
+            task pdb
+              trigger ../../../prod/156/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../150/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 162
+            edit EMOS_TIME_STEP_H '0162'
+            task pdb
+              trigger ../../../prod/162/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../156/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 168
+            edit EMOS_TIME_STEP_H '0168'
+            task pdb
+              trigger ../../../prod/168/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../162/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 174
+            edit EMOS_TIME_STEP_H '0174'
+            task pdb
+              trigger ../../../prod/174/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../168/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 180
+            edit EMOS_TIME_STEP_H '0180'
+            task pdb
+              trigger ../../../prod/180/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../174/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 186
+            edit EMOS_TIME_STEP_H '0186'
+            task pdb
+              trigger ../../../prod/186/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../180/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 192
+            edit EMOS_TIME_STEP_H '0192'
+            task pdb
+              trigger ../../../prod/192/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../186/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 198
+            edit EMOS_TIME_STEP_H '0198'
+            task pdb
+              trigger ../../../prod/198/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../192/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 204
+            edit EMOS_TIME_STEP_H '0204'
+            task pdb
+              trigger ../../../prod/204/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../198/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 210
+            edit EMOS_TIME_STEP_H '0210'
+            task pdb
+              trigger ../../../prod/210/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../204/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 216
+            edit EMOS_TIME_STEP_H '0216'
+            task pdb
+              trigger ../../../prod/216/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../210/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 222
+            edit EMOS_TIME_STEP_H '0222'
+            task pdb
+              trigger ../../../prod/222/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../216/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 228
+            edit EMOS_TIME_STEP_H '0228'
+            task pdb
+              trigger ../../../prod/228/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../222/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 234
+            edit EMOS_TIME_STEP_H '0234'
+            task pdb
+              trigger ../../../prod/234/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../228/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 240
+            edit EMOS_TIME_STEP_H '0240'
+            task pdb
+              trigger ../../../prod/240/prodgen eq complete and ../../../prod/240/prodmet eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../234/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+            task diss_wparam
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/240/prod_wparam eq complete
+              edit PROD_TASK 'w'
+              edit EMOS_TYPE 'wp'
+              label info ""
+              event pdb
+          endfamily
+          task check
+            trigger ./240 eq complete
+        endfamily
+        family wave
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit EMOS_PROJECT '12'
+          edit EMOS_STREAM 'WV'
+          edit SMSURL 'GWAVE/12'
+          inlimit /e_36r1/limits:w2diss
+          inlimit /limits:q2diss
+          family 06an
+            edit EMOS_TYPE 'an'
+            edit EMOS_BASE '06'
+            task diss
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/06an/prodwave eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event pdb
+          endfamily
+          family 12an
+            edit EMOS_TYPE 'an'
+            task diss
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/12an/prodwave eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event pdb
+          endfamily
+          family 000
+            trigger ../../prod/000/prodwave eq complete and ./06an eq complete and ./12an eq complete
+            edit EMOS_TIME_STEP_H '0000'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 003
+            trigger ../../prod/003/prodwave eq complete and ( ./000/diss:pdb or ./000 eq complete)
+            edit EMOS_TIME_STEP_H '0003'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 006
+            trigger ../../prod/006/prodwave eq complete and ( ./003/diss:pdb or ./003 eq complete)
+            edit EMOS_TIME_STEP_H '0006'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 009
+            trigger ../../prod/009/prodwave eq complete and ( ./006/diss:pdb or ./006 eq complete)
+            edit EMOS_TIME_STEP_H '0009'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 012
+            trigger ../../prod/012/prodwave eq complete and ( ./009/diss:pdb or ./009 eq complete)
+            edit EMOS_TIME_STEP_H '0012'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 015
+            trigger ../../prod/015/prodwave eq complete and ( ./012/diss:pdb or ./012 eq complete)
+            edit EMOS_TIME_STEP_H '0015'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 018
+            trigger ../../prod/018/prodwave eq complete and ( ./015/diss:pdb or ./015 eq complete)
+            edit EMOS_TIME_STEP_H '0018'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 021
+            trigger ../../prod/021/prodwave eq complete and ( ./018/diss:pdb or ./018 eq complete)
+            edit EMOS_TIME_STEP_H '0021'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 024
+            trigger ../../prod/024/prodwave eq complete and ( ./021/diss:pdb or ./021 eq complete)
+            edit EMOS_TIME_STEP_H '0024'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 027
+            trigger ../../prod/027/prodwave eq complete and ( ./024/diss:pdb or ./024 eq complete)
+            edit EMOS_TIME_STEP_H '0027'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 030
+            trigger ../../prod/030/prodwave eq complete and ( ./027/diss:pdb or ./027 eq complete)
+            edit EMOS_TIME_STEP_H '0030'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 033
+            trigger ../../prod/033/prodwave eq complete and ( ./030/diss:pdb or ./030 eq complete)
+            edit EMOS_TIME_STEP_H '0033'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 036
+            trigger ../../prod/036/prodwave eq complete and ( ./033/diss:pdb or ./033 eq complete)
+            edit EMOS_TIME_STEP_H '0036'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 039
+            trigger ../../prod/039/prodwave eq complete and ( ./036/diss:pdb or ./036 eq complete)
+            edit EMOS_TIME_STEP_H '0039'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 042
+            trigger ../../prod/042/prodwave eq complete and ( ./039/diss:pdb or ./039 eq complete)
+            edit EMOS_TIME_STEP_H '0042'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 045
+            trigger ../../prod/045/prodwave eq complete and ( ./042/diss:pdb or ./042 eq complete)
+            edit EMOS_TIME_STEP_H '0045'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 048
+            trigger ../../prod/048/prodwave eq complete and ( ./045/diss:pdb or ./045 eq complete)
+            edit EMOS_TIME_STEP_H '0048'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 051
+            trigger ../../prod/051/prodwave eq complete and ( ./048/diss:pdb or ./048 eq complete)
+            edit EMOS_TIME_STEP_H '0051'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 054
+            trigger ../../prod/054/prodwave eq complete and ( ./051/diss:pdb or ./051 eq complete)
+            edit EMOS_TIME_STEP_H '0054'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 057
+            trigger ../../prod/057/prodwave eq complete and ( ./054/diss:pdb or ./054 eq complete)
+            edit EMOS_TIME_STEP_H '0057'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 060
+            trigger ../../prod/060/prodwave eq complete and ( ./057/diss:pdb or ./057 eq complete)
+            edit EMOS_TIME_STEP_H '0060'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 063
+            trigger ../../prod/063/prodwave eq complete and ( ./060/diss:pdb or ./060 eq complete)
+            edit EMOS_TIME_STEP_H '0063'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 066
+            trigger ../../prod/066/prodwave eq complete and ( ./063/diss:pdb or ./063 eq complete)
+            edit EMOS_TIME_STEP_H '0066'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 069
+            trigger ../../prod/069/prodwave eq complete and ( ./066/diss:pdb or ./066 eq complete)
+            edit EMOS_TIME_STEP_H '0069'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 072
+            trigger ../../prod/072/prodwave eq complete and ( ./069/diss:pdb or ./069 eq complete)
+            edit EMOS_TIME_STEP_H '0072'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 075
+            trigger ../../prod/075/prodwave eq complete and ( ./072/diss:pdb or ./072 eq complete)
+            edit EMOS_TIME_STEP_H '0075'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 078
+            trigger ../../prod/078/prodwave eq complete and ( ./075/diss:pdb or ./075 eq complete)
+            edit EMOS_TIME_STEP_H '0078'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 081
+            trigger ../../prod/081/prodwave eq complete and ( ./078/diss:pdb or ./078 eq complete)
+            edit EMOS_TIME_STEP_H '0081'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 084
+            trigger ../../prod/084/prodwave eq complete and ( ./081/diss:pdb or ./081 eq complete)
+            edit EMOS_TIME_STEP_H '0084'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 087
+            trigger ../../prod/087/prodwave eq complete and ( ./084/diss:pdb or ./084 eq complete)
+            edit EMOS_TIME_STEP_H '0087'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 090
+            trigger ../../prod/090/prodwave eq complete and ( ./087/diss:pdb or ./087 eq complete)
+            edit EMOS_TIME_STEP_H '0090'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 093
+            trigger ../../prod/093/prodwave eq complete and ( ./090/diss:pdb or ./090 eq complete)
+            edit EMOS_TIME_STEP_H '0093'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 096
+            trigger ../../prod/096/prodwave eq complete and ( ./093/diss:pdb or ./093 eq complete)
+            edit EMOS_TIME_STEP_H '0096'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 099
+            trigger ../../prod/099/prodwave eq complete and ( ./096/diss:pdb or ./096 eq complete)
+            edit EMOS_TIME_STEP_H '0099'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 102
+            trigger ../../prod/102/prodwave eq complete and ( ./099/diss:pdb or ./099 eq complete)
+            edit EMOS_TIME_STEP_H '0102'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 105
+            trigger ../../prod/105/prodwave eq complete and ( ./102/diss:pdb or ./102 eq complete)
+            edit EMOS_TIME_STEP_H '0105'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 108
+            trigger ../../prod/108/prodwave eq complete and ( ./105/diss:pdb or ./105 eq complete)
+            edit EMOS_TIME_STEP_H '0108'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 111
+            trigger ../../prod/111/prodwave eq complete and ( ./108/diss:pdb or ./108 eq complete)
+            edit EMOS_TIME_STEP_H '0111'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 114
+            trigger ../../prod/114/prodwave eq complete and ( ./111/diss:pdb or ./111 eq complete)
+            edit EMOS_TIME_STEP_H '0114'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 117
+            trigger ../../prod/117/prodwave eq complete and ( ./114/diss:pdb or ./114 eq complete)
+            edit EMOS_TIME_STEP_H '0117'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 120
+            trigger ../../prod/120/prodwave eq complete and ( ./117/diss:pdb or ./117 eq complete)
+            edit EMOS_TIME_STEP_H '0120'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 123
+            trigger ../../prod/123/prodwave eq complete and ( ./120/diss:pdb or ./120 eq complete)
+            edit EMOS_TIME_STEP_H '0123'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 126
+            trigger ../../prod/126/prodwave eq complete and ( ./123/diss:pdb or ./123 eq complete)
+            edit EMOS_TIME_STEP_H '0126'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 129
+            trigger ../../prod/129/prodwave eq complete and ( ./126/diss:pdb or ./126 eq complete)
+            edit EMOS_TIME_STEP_H '0129'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 132
+            trigger ../../prod/132/prodwave eq complete and ( ./129/diss:pdb or ./129 eq complete)
+            edit EMOS_TIME_STEP_H '0132'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 135
+            trigger ../../prod/135/prodwave eq complete and ( ./132/diss:pdb or ./132 eq complete)
+            edit EMOS_TIME_STEP_H '0135'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 138
+            trigger ../../prod/138/prodwave eq complete and ( ./135/diss:pdb or ./135 eq complete)
+            edit EMOS_TIME_STEP_H '0138'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 141
+            trigger ../../prod/141/prodwave eq complete and ( ./138/diss:pdb or ./138 eq complete)
+            edit EMOS_TIME_STEP_H '0141'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 144
+            trigger ../../prod/144/prodwave eq complete and ( ./141/diss:pdb or ./141 eq complete)
+            edit EMOS_TIME_STEP_H '0144'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 150
+            trigger ../../prod/150/prodwave eq complete and ( ./144/diss:pdb or ./144 eq complete)
+            edit EMOS_TIME_STEP_H '0150'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 156
+            trigger ../../prod/156/prodwave eq complete and ( ./150/diss:pdb or ./150 eq complete)
+            edit EMOS_TIME_STEP_H '0156'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 162
+            trigger ../../prod/162/prodwave eq complete and ( ./156/diss:pdb or ./156 eq complete)
+            edit EMOS_TIME_STEP_H '0162'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 168
+            trigger ../../prod/168/prodwave eq complete and ( ./162/diss:pdb or ./162 eq complete)
+            edit EMOS_TIME_STEP_H '0168'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 174
+            trigger ../../prod/174/prodwave eq complete and ( ./168/diss:pdb or ./168 eq complete)
+            edit EMOS_TIME_STEP_H '0174'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 180
+            trigger ../../prod/180/prodwave eq complete and ( ./174/diss:pdb or ./174 eq complete)
+            edit EMOS_TIME_STEP_H '0180'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 186
+            trigger ../../prod/186/prodwave eq complete and ( ./180/diss:pdb or ./180 eq complete)
+            edit EMOS_TIME_STEP_H '0186'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 192
+            trigger ../../prod/192/prodwave eq complete and ( ./186/diss:pdb or ./186 eq complete)
+            edit EMOS_TIME_STEP_H '0192'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 198
+            trigger ../../prod/198/prodwave eq complete and ( ./192/diss:pdb or ./192 eq complete)
+            edit EMOS_TIME_STEP_H '0198'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 204
+            trigger ../../prod/204/prodwave eq complete and ( ./198/diss:pdb or ./198 eq complete)
+            edit EMOS_TIME_STEP_H '0204'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 210
+            trigger ../../prod/210/prodwave eq complete and ( ./204/diss:pdb or ./204 eq complete)
+            edit EMOS_TIME_STEP_H '0210'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 216
+            trigger ../../prod/216/prodwave eq complete and ( ./210/diss:pdb or ./210 eq complete)
+            edit EMOS_TIME_STEP_H '0216'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 222
+            trigger ../../prod/222/prodwave eq complete and ( ./216/diss:pdb or ./216 eq complete)
+            edit EMOS_TIME_STEP_H '0222'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 228
+            trigger ../../prod/228/prodwave eq complete and ( ./222/diss:pdb or ./222 eq complete)
+            edit EMOS_TIME_STEP_H '0228'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 234
+            trigger ../../prod/234/prodwave eq complete and ( ./228/diss:pdb or ./228 eq complete)
+            edit EMOS_TIME_STEP_H '0234'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 240
+            trigger ../../prod/240/prodwave eq complete and ( ./234/diss:pdb or ./234 eq complete)
+            edit EMOS_TIME_STEP_H '0240'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          task check
+            trigger ./240 eq complete
+        endfamily
+      endfamily
+    endfamily
+    family 18bc
+      trigger ( ./make eq complete) and ( /e_36r1/main/12/fc eq complete)
+      edit EMOS_BASE '18'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '0'
+      edit ACCOUNT 'opebcpg'
+      edit SMSURL 'GSCDA/18'
+      edit USER_PRIORITY '91'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/ex18/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete
+        family prepare_obs
+          trigger ./get eq complete
+          task preobs
+            trigger /e_36r1/main/00dc/an/update_psbias eq complete and /e_36r1/main/00dc/an/update_rstrhbias eq complete
+            edit mode 'not1crad'
+            edit REINITIALIZE 'true'
+            edit REINIPERIOD_4D '6'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+        family reservation
+          late -c +00:03
+          trigger ./get/get_stor eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task adv_res
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '30'
+            edit RESERVE_IN '11'
+            edit RESERVED_NODES '32'
+            edit RESERVATION_LABEL 'emos18A'
+            label info ""
+          task loadl_cycle_limit
+            late -s +00:03 -c +00:02
+            edit LOADL_CYCLE '65'
+            label info ""
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit PERIOD_4D '6'
+        edit WINDOW_LENGTH_4D '6'
+        edit WINDOW_OFFSET_4D '3'
+        edit ACCOUNT 'opebcan'
+        edit REINITIALIZE 'true'
+        edit ANNPES '144'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          trigger ( ../../12/fc/model:step ge 9 or ../../12/fc/model eq complete)
+          event hires
+        task fetcherr
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '2432'
+            edit RESERVE_FOR '35'
+            label info ""
+          task rm_res
+            late -s +00:03 -c +00:02
+            edit RESERVATION_LABEL 'emos18A'
+            label info ""
+        endfamily
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit ACCOUNT 'opebcfc'
+        edit REINITIALIZE 'true'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task getpersSST
+          trigger getfcdata eq complete
+          edit SSTLEN '90'
+          edit SSTINT '1'
+          edit THREADS '2'
+          edit NPES '16'
+          edit MEM '1000'
+          edit CPUTIME '960'
+        task model
+          late -s +00:02
+          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
+          edit PERSST 'true'
+          edit FCLENGTH '90'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          edit FCNPES '144'
+          meter step -1 90 90
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./getfcdata eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '3072'
+            edit RESERVE_FOR '20'
+            label info ""
+        endfamily
+        family reservation2
+          late -c +00:03
+          trigger ./model eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reset_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '0'
+            label info ""
+        endfamily
+      endfamily
+      family getreq
+        trigger ( /e_36r1/main/18bc/an/4dvar eq active or /e_36r1/main/18bc/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit PROD_TASK '1'
+        edit EMOS_DOMAIN 'G'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_PROJECT '12'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'SCDA'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '18'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger collectreq eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete and ( req:001 or req eq complete)
+          label info ""
+          event 1 
+      endfamily
+      family prod
+        trigger ( getreq/req:001 or getreq/req eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit EMOS_PROJECT '12'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        family an
+          trigger /e_36r1/main/18bc/an/surf_anal eq complete and ( /e_36r1/main/18bc/an/4dvar/ifstraj:finalwave or /e_36r1/main/18bc/an/4dvar/ifstraj eq complete) and 0 eq 0
+          edit EMOS_TYPE 'an'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ../090/prodgen eq complete and ( /e_36r1/main/18bc/fc/model:step ge 12 or /e_36r1/main/18bc/fc/model eq complete)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 000
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 000 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0000'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 12 or /e_36r1/main/18bc/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '000'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 003
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 003 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 15 or /e_36r1/main/18bc/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '003'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 006
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 006 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 18 or /e_36r1/main/18bc/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '006'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 009
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 009 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 21 or /e_36r1/main/18bc/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '009'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 012
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 012 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 24 or /e_36r1/main/18bc/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '012'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 015
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 015 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 27 or /e_36r1/main/18bc/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '015'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 018
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 018 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 30 or /e_36r1/main/18bc/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '018'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 021
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 021 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 33 or /e_36r1/main/18bc/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '021'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 024
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 024 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 36 or /e_36r1/main/18bc/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '024'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 027
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 027 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 39 or /e_36r1/main/18bc/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '027'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 030
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 030 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 42 or /e_36r1/main/18bc/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '030'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 033
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 033 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 45 or /e_36r1/main/18bc/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '033'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 036
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 036 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0036'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 48 or /e_36r1/main/18bc/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '036'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 039
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 039 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0039'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 51 or /e_36r1/main/18bc/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '039'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 042
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 042 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0042'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 54 or /e_36r1/main/18bc/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '042'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 045
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 045 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0045'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 57 or /e_36r1/main/18bc/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '045'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 048
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 048 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0048'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 60 or /e_36r1/main/18bc/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '048'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 051
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 051 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0051'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 63 or /e_36r1/main/18bc/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '051'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 054
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 054 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0054'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 66 or /e_36r1/main/18bc/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '054'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 057
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 057 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0057'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 69 or /e_36r1/main/18bc/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '057'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 060
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 060 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0060'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 72 or /e_36r1/main/18bc/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '060'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 063
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 063 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0063'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 75 or /e_36r1/main/18bc/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '063'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 066
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 066 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0066'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 78 or /e_36r1/main/18bc/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '066'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 069
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 069 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0069'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 81 or /e_36r1/main/18bc/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '069'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 072
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 072 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0072'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 84 or /e_36r1/main/18bc/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '072'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 075
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 075 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0075'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 87 or /e_36r1/main/18bc/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '075'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 078
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 078 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0078'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/18bc/fc/model:step ge 90 or /e_36r1/main/18bc/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '078'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 081
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 081 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0081'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '081'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 084
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 084 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0084'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '084'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 087
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 087 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0087'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '087'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 090
+          trigger ( /e_36r1/main/18bc/fc/model:step ge 090 or /e_36r1/main/18bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0090'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '090'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        task operation_is_late
+          event yes
+        family oper
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '92'
+          edit SMSURL 'GSCDA/18'
+          edit EMOS_PROJECT '12'
+          family an
+            task pdb
+              trigger ../../../prod/an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event 1 
+          endfamily
+          family 000
+            edit EMOS_TIME_STEP_H '0000'
+            task pdb
+              trigger ../../../prod/000/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ../an/q2diss eq complete
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 003
+            edit EMOS_TIME_STEP_H '0003'
+            task pdb
+              trigger ../../../prod/003/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/003/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 006
+            edit EMOS_TIME_STEP_H '0006'
+            task pdb
+              trigger ../../../prod/006/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/006/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 009
+            edit EMOS_TIME_STEP_H '0009'
+            task pdb
+              trigger ../../../prod/009/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/009/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 012
+            edit EMOS_TIME_STEP_H '0012'
+            task pdb
+              trigger ../../../prod/012/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/012/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 015
+            edit EMOS_TIME_STEP_H '0015'
+            task pdb
+              trigger ../../../prod/015/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/015/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 018
+            edit EMOS_TIME_STEP_H '0018'
+            task pdb
+              trigger ../../../prod/018/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/018/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 021
+            edit EMOS_TIME_STEP_H '0021'
+            task pdb
+              trigger ../../../prod/021/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/021/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 024
+            edit EMOS_TIME_STEP_H '0024'
+            task pdb
+              trigger ../../../prod/024/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/024/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 027
+            edit EMOS_TIME_STEP_H '0027'
+            task pdb
+              trigger ../../../prod/027/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/027/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 030
+            edit EMOS_TIME_STEP_H '0030'
+            task pdb
+              trigger ../../../prod/030/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/030/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 033
+            edit EMOS_TIME_STEP_H '0033'
+            task pdb
+              trigger ../../../prod/033/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/033/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 036
+            edit EMOS_TIME_STEP_H '0036'
+            task pdb
+              trigger ../../../prod/036/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/036/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 039
+            edit EMOS_TIME_STEP_H '0039'
+            task pdb
+              trigger ../../../prod/039/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/039/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 042
+            edit EMOS_TIME_STEP_H '0042'
+            task pdb
+              trigger ../../../prod/042/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/042/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 045
+            edit EMOS_TIME_STEP_H '0045'
+            task pdb
+              trigger ../../../prod/045/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/045/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 048
+            edit EMOS_TIME_STEP_H '0048'
+            task pdb
+              trigger ../../../prod/048/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/048/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 051
+            edit EMOS_TIME_STEP_H '0051'
+            task pdb
+              trigger ../../../prod/051/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/051/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 054
+            edit EMOS_TIME_STEP_H '0054'
+            task pdb
+              trigger ../../../prod/054/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/054/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 057
+            edit EMOS_TIME_STEP_H '0057'
+            task pdb
+              trigger ../../../prod/057/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/057/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 060
+            edit EMOS_TIME_STEP_H '0060'
+            task pdb
+              trigger ../../../prod/060/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/060/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 063
+            edit EMOS_TIME_STEP_H '0063'
+            task pdb
+              trigger ../../../prod/063/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/063/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 066
+            edit EMOS_TIME_STEP_H '0066'
+            task pdb
+              trigger ../../../prod/066/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/066/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 069
+            edit EMOS_TIME_STEP_H '0069'
+            task pdb
+              trigger ../../../prod/069/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/069/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 072
+            edit EMOS_TIME_STEP_H '0072'
+            task pdb
+              trigger ../../../prod/072/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/072/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 075
+            edit EMOS_TIME_STEP_H '0075'
+            task pdb
+              trigger ../../../prod/075/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/075/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 078
+            edit EMOS_TIME_STEP_H '0078'
+            task pdb
+              trigger ../../../prod/078/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/078/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 081
+            edit EMOS_TIME_STEP_H '0081'
+            task pdb
+              trigger ../../../prod/081/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 084
+            edit EMOS_TIME_STEP_H '0084'
+            task pdb
+              trigger ../../../prod/084/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 087
+            edit EMOS_TIME_STEP_H '0087'
+            task pdb
+              trigger ../../../prod/087/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 090
+            edit EMOS_TIME_STEP_H '0090'
+            task pdb
+              trigger ../../../prod/090/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          task check
+            trigger ./078 eq complete
+        endfamily
+      endfamily
+    endfamily
+    family 12dc
+      trigger make eq complete
+      edit EMOS_BASE '12'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/dc12/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc12/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc12/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        family getplus6
+          edit EMOS_BASE '18'
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/dc18/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/dc18/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/dc18/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete and ./getplus6 eq complete
+        family prepare_obs
+          trigger ./get eq complete and ./getplus6 eq complete
+          task preobs
+            trigger /e_36r1/main/00dc/an/update_psbias eq complete and /e_36r1/main/00dc/an/update_rstrhbias eq complete
+            edit mode 'not1crad'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+        family reservation
+          late -c +00:03
+          trigger ./get/get_stor eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task adv_res
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '30'
+            edit RESERVE_IN '30'
+            edit RESERVED_NODES '48'
+            edit RESERVATION_LABEL 'emos12dcA'
+            label info ""
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit PERIOD_4D '12'
+        edit WINDOW_LENGTH_4D '12'
+        edit WINDOW_OFFSET_4D '3'
+        edit ACCOUNT 'oedcdaan'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          trigger ( ../../00dc/fc/model:step ge 9 or ../../00dc/fc/model eq complete)
+          event hires
+        task fetcherr
+          trigger ../../00dc/an eq complete
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+        task emiskf
+          trigger ./4dvar/uptraj_0/ifstraj eq complete
+          edit THREADS '1'
+        task update_psbias
+          trigger ./4dvar/ifstraj:finalwave
+        task update_rstrhbias
+          trigger ./4dvar/ifstraj:finalwave
+        task dcda_to_da
+          trigger ./4dvar eq complete and surf_anal eq complete
+          edit EMOS_TYPE 'an'
+          edit OPHOST 'c1b'
+        family reservation1
+          late -c +00:03
+          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:02 -c +00:02
+            edit RESERVED_CPUS '3328'
+            edit RESERVE_FOR '65'
+            label info ""
+          task rm_res
+            late -s +00:02 -c +00:02
+            edit RESERVATION_LABEL 'emos12'
+            label info ""
+          task set_class
+            late -s +00:02 -c +00:02
+            edit RESERVATION_DEFINITION 'default_nodiag'
+            label info ""
+        endfamily
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit EMOS_BASE '18'
+        edit ACCOUNT 'oedcdafc'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task model
+          late -s +00:02
+          trigger getfcdata eq complete
+          edit FCLENGTH '15'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          meter step -1 15 15
+        task ddh
+          trigger model eq complete
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete and ../../12/fc eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./getfcdata eq active or ./getfcdata eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '3072'
+            edit RESERVE_FOR '4'
+            label info ""
+        endfamily
+        family reservation2
+          late -c +00:03
+          trigger ./model eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reset_cpu
+            late -s +00:03 -c +00:02
+            complete /e_36r1/main/00/an/vardata eq active or /e_36r1/main/00/an/vardata eq complete
+            edit RESERVED_CPUS '0'
+            label info ""
+        endfamily
+      endfamily
+    endfamily
+    family 18
+      trigger make eq complete
+      edit EMOS_BASE '18'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DA'
+      edit LAR_4V_EF 'false'
+      edit LFC_DIR_FREQ 'false'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/ex18/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex18/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex18/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete
+        family prepare_obs
+          trigger ./get eq complete
+          task preobs
+            edit mode 'not1crad'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+        family reservation
+          late -c +00:03
+          trigger ./get/get_stor eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit ACCOUNT 'oeoperan'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          trigger ../../12dc/fc/model:step ge 6 or ../../12dc/fc/model eq complete
+          event hires
+        task fetcherr
+          trigger ../../12dc/an eq complete
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+        endfamily
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit ACCOUNT 'oeoperfc'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task getpersSST
+          trigger getfcdata eq complete
+          edit SSTLEN '9'
+          edit SSTINT '1'
+          edit THREADS '2'
+          edit NPES '16'
+          edit MEM '1000'
+          edit CPUTIME '960'
+        task model
+          late -s +00:02
+          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
+          edit PERSST 'true'
+          edit FCLENGTH '9'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          meter step -1 9 9
+        task ddh
+          trigger model eq complete
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete
+        family reservation1
+          late -c +00:03
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+        endfamily
+      endfamily
+    endfamily
+    family 00bc
+      edit EMOS_BASE '00'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '1'
+      edit ACCOUNT 'opebcpg'
+      edit SMSURL 'GSCDA/00'
+      edit USER_PRIORITY '91'
+      family getreq
+        trigger ( /e_36r1/main/00/an/4dvar eq active or /e_36r1/main/00/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit PROD_TASK '1'
+        edit EMOS_DOMAIN 'G'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_PROJECT '12'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'SCDA'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '00'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger collectreq eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete and ( req:001 or req eq complete)
+          label info ""
+          event 1 
+      endfamily
+      family prod
+        trigger ( getreq/req:001 or getreq/req eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit EMOS_PROJECT '12'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit EMOS_BASE '00'
+        family an
+          trigger /e_36r1/main/00/an/surf_anal eq complete and ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar/ifstraj eq complete) and 0 eq 0
+          edit EMOS_TYPE 'an'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ../090/prodgen eq complete and ../../prod eq queued and /e_36r1/main/00/prod eq complete
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 000
+          trigger ( /e_36r1/main/00/fc/model:step ge 000 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0000'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 12 or /e_36r1/main/00/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 003
+          trigger ( /e_36r1/main/00/fc/model:step ge 003 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 15 or /e_36r1/main/00/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 006
+          trigger ( /e_36r1/main/00/fc/model:step ge 006 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 18 or /e_36r1/main/00/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 009
+          trigger ( /e_36r1/main/00/fc/model:step ge 009 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 21 or /e_36r1/main/00/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 012
+          trigger ( /e_36r1/main/00/fc/model:step ge 012 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 24 or /e_36r1/main/00/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 015
+          trigger ( /e_36r1/main/00/fc/model:step ge 015 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 27 or /e_36r1/main/00/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 018
+          trigger ( /e_36r1/main/00/fc/model:step ge 018 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 30 or /e_36r1/main/00/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 021
+          trigger ( /e_36r1/main/00/fc/model:step ge 021 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 33 or /e_36r1/main/00/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 024
+          trigger ( /e_36r1/main/00/fc/model:step ge 024 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 36 or /e_36r1/main/00/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 027
+          trigger ( /e_36r1/main/00/fc/model:step ge 027 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 39 or /e_36r1/main/00/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 030
+          trigger ( /e_36r1/main/00/fc/model:step ge 030 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 42 or /e_36r1/main/00/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 033
+          trigger ( /e_36r1/main/00/fc/model:step ge 033 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 45 or /e_36r1/main/00/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 036
+          trigger ( /e_36r1/main/00/fc/model:step ge 036 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0036'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 48 or /e_36r1/main/00/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 039
+          trigger ( /e_36r1/main/00/fc/model:step ge 039 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0039'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 51 or /e_36r1/main/00/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 042
+          trigger ( /e_36r1/main/00/fc/model:step ge 042 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0042'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 54 or /e_36r1/main/00/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 045
+          trigger ( /e_36r1/main/00/fc/model:step ge 045 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0045'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 57 or /e_36r1/main/00/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 048
+          trigger ( /e_36r1/main/00/fc/model:step ge 048 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0048'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 60 or /e_36r1/main/00/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 051
+          trigger ( /e_36r1/main/00/fc/model:step ge 051 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0051'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 63 or /e_36r1/main/00/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 054
+          trigger ( /e_36r1/main/00/fc/model:step ge 054 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0054'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 66 or /e_36r1/main/00/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 057
+          trigger ( /e_36r1/main/00/fc/model:step ge 057 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0057'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 69 or /e_36r1/main/00/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 060
+          trigger ( /e_36r1/main/00/fc/model:step ge 060 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0060'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 72 or /e_36r1/main/00/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 063
+          trigger ( /e_36r1/main/00/fc/model:step ge 063 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0063'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 75 or /e_36r1/main/00/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 066
+          trigger ( /e_36r1/main/00/fc/model:step ge 066 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0066'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 78 or /e_36r1/main/00/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 069
+          trigger ( /e_36r1/main/00/fc/model:step ge 069 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0069'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 81 or /e_36r1/main/00/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 072
+          trigger ( /e_36r1/main/00/fc/model:step ge 072 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0072'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 84 or /e_36r1/main/00/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 075
+          trigger ( /e_36r1/main/00/fc/model:step ge 075 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0075'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 87 or /e_36r1/main/00/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 078
+          trigger ( /e_36r1/main/00/fc/model:step ge 078 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0078'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/00/fc/model:step ge 90 or /e_36r1/main/00/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+        endfamily
+        family 081
+          trigger ( /e_36r1/main/00/fc/model:step ge 081 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0081'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+        family 084
+          trigger ( /e_36r1/main/00/fc/model:step ge 084 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0084'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+        family 087
+          trigger ( /e_36r1/main/00/fc/model:step ge 087 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0087'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+        family 090
+          trigger ( /e_36r1/main/00/fc/model:step ge 090 or /e_36r1/main/00/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0090'
+          task prodgen
+            late -s +00:05 -c +00:15
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        task operation_is_late
+          event yes
+        family oper
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '92'
+          edit SMSURL 'GSCDA/00'
+          edit EMOS_BASE '00'
+          edit EMOS_PROJECT '12'
+          family an
+            task pdb
+              trigger ../../../prod/an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event 1 
+          endfamily
+          family 000
+            edit EMOS_TIME_STEP_H '0000'
+            task pdb
+              trigger ../../../prod/000/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ../an/q2diss eq complete
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 003
+            edit EMOS_TIME_STEP_H '0003'
+            task pdb
+              trigger ../../../prod/003/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/003/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 006
+            edit EMOS_TIME_STEP_H '0006'
+            task pdb
+              trigger ../../../prod/006/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/006/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 009
+            edit EMOS_TIME_STEP_H '0009'
+            task pdb
+              trigger ../../../prod/009/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/009/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 012
+            edit EMOS_TIME_STEP_H '0012'
+            task pdb
+              trigger ../../../prod/012/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/012/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 015
+            edit EMOS_TIME_STEP_H '0015'
+            task pdb
+              trigger ../../../prod/015/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/015/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 018
+            edit EMOS_TIME_STEP_H '0018'
+            task pdb
+              trigger ../../../prod/018/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/018/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 021
+            edit EMOS_TIME_STEP_H '0021'
+            task pdb
+              trigger ../../../prod/021/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/021/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 024
+            edit EMOS_TIME_STEP_H '0024'
+            task pdb
+              trigger ../../../prod/024/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/024/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 027
+            edit EMOS_TIME_STEP_H '0027'
+            task pdb
+              trigger ../../../prod/027/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/027/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 030
+            edit EMOS_TIME_STEP_H '0030'
+            task pdb
+              trigger ../../../prod/030/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/030/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 033
+            edit EMOS_TIME_STEP_H '0033'
+            task pdb
+              trigger ../../../prod/033/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/033/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 036
+            edit EMOS_TIME_STEP_H '0036'
+            task pdb
+              trigger ../../../prod/036/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/036/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 039
+            edit EMOS_TIME_STEP_H '0039'
+            task pdb
+              trigger ../../../prod/039/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/039/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 042
+            edit EMOS_TIME_STEP_H '0042'
+            task pdb
+              trigger ../../../prod/042/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/042/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 045
+            edit EMOS_TIME_STEP_H '0045'
+            task pdb
+              trigger ../../../prod/045/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/045/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 048
+            edit EMOS_TIME_STEP_H '0048'
+            task pdb
+              trigger ../../../prod/048/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/048/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 051
+            edit EMOS_TIME_STEP_H '0051'
+            task pdb
+              trigger ../../../prod/051/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/051/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 054
+            edit EMOS_TIME_STEP_H '0054'
+            task pdb
+              trigger ../../../prod/054/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/054/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 057
+            edit EMOS_TIME_STEP_H '0057'
+            task pdb
+              trigger ../../../prod/057/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/057/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 060
+            edit EMOS_TIME_STEP_H '0060'
+            task pdb
+              trigger ../../../prod/060/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/060/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 063
+            edit EMOS_TIME_STEP_H '0063'
+            task pdb
+              trigger ../../../prod/063/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/063/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 066
+            edit EMOS_TIME_STEP_H '0066'
+            task pdb
+              trigger ../../../prod/066/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/066/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 069
+            edit EMOS_TIME_STEP_H '0069'
+            task pdb
+              trigger ../../../prod/069/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/069/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 072
+            edit EMOS_TIME_STEP_H '0072'
+            task pdb
+              trigger ../../../prod/072/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/072/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 075
+            edit EMOS_TIME_STEP_H '0075'
+            task pdb
+              trigger ../../../prod/075/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/075/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 078
+            edit EMOS_TIME_STEP_H '0078'
+            task pdb
+              trigger ../../../prod/078/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/078/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 081
+            edit EMOS_TIME_STEP_H '0081'
+            task pdb
+              trigger ../../../prod/081/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 084
+            edit EMOS_TIME_STEP_H '0084'
+            task pdb
+              trigger ../../../prod/084/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 087
+            edit EMOS_TIME_STEP_H '0087'
+            task pdb
+              trigger ../../../prod/087/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 090
+            edit EMOS_TIME_STEP_H '0090'
+            task pdb
+              trigger ../../../prod/090/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          task check
+            trigger ./078 eq complete
+        endfamily
+      endfamily
+    endfamily
+    family 00
+      trigger make eq complete
+      edit EMOS_BASE '00'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '1'
+      edit ACCOUNT 'oeoperpg'
+      edit SMSURL 'GOPER/00'
+      edit USER_PRIORITY '90'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/ex00/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex00/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex00/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete
+        family prepare_obs
+          trigger ./get eq complete
+          task preobs
+            trigger /e_36r1/main/12dc/an/update_psbias eq complete and /e_36r1/main/12dc/an/update_rstrhbias eq complete
+            edit mode 'not1crad'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+        family reservation
+          late -c +00:03
+          trigger ./get/get_stor eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task adv_res
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '40'
+            edit RESERVE_IN '60'
+            edit RESERVED_NODES '24'
+            edit RESERVATION_LABEL 'emos00XP'
+            label info ""
+          task adv_resA
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '100'
+            edit RESERVE_IN '11'
+            edit RESERVED_NODES '48'
+            edit RESERVATION_LABEL 'emos00A'
+            label info ""
+          task adv_resB
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '30'
+            edit RESERVE_IN '48'
+            edit RESERVED_NODES '48'
+            edit RESERVATION_LABEL 'emos00B'
+            label info ""
+          task adv_resC
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '80'
+            edit RESERVE_IN '60'
+            edit RESERVED_NODES '120'
+            edit RESERVATION_LABEL 'emos00C'
+            label info ""
+          task loadl_cycle_limit
+            late -s +00:03 -c +00:02
+            edit LOADL_CYCLE '65'
+            label info ""
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit PERIOD_4D '6'
+        edit WINDOW_LENGTH_4D '6'
+        edit WINDOW_OFFSET_4D '3'
+        edit ACCOUNT 'oeoperan'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          trigger ( ../../12dc/fc/model:step ge 6 or ../../12dc/fc/model eq complete) and ../../18/an eq complete
+          event hires
+        task fetcherr
+          trigger ../../18/an eq complete and ../../12dc/an eq complete
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '3072'
+            edit RESERVE_FOR '100'
+            label info ""
+          task rm_res
+            late -s +00:03 -c +00:02
+            edit RESERVATION_LABEL 'emos00A'
+            label info ""
+          task ms_cpu
+            late -s +00:03 -c +00:02
+            edit MS_CPUS '$((64*30))'
+            label info ""
+        endfamily
+        family reservation3
+          late -c +00:03
+          trigger ./4dvar/uptraj_1 eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task set_class
+            late -s +00:03 -c +00:02
+            edit RESERVATION_DEFINITION 'default'
+            label info ""
+        endfamily
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit ACCOUNT 'oeoperfc'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task getpersSST
+          trigger getfcdata eq complete
+          edit SSTLEN '240'
+          edit SSTINT '1'
+          edit THREADS '2'
+          edit NPES '16'
+          edit MEM '1000'
+          edit CPUTIME '960'
+        task model
+          late -s +00:02
+          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
+          edit PERSST 'true'
+          edit FCLENGTH '240'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          meter step -1 240 240
+        task ddh
+          trigger model eq complete
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete and ddh eq complete and ../../12dc/fc eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./getfcdata eq active or ./getfcdata eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          family xp
+            task set_xp
+              late -s +00:03 -c +00:02
+              edit RESERVATION_LABEL 'emos00XP'
+              label info ""
+            task rm_res
+              late -s +00:03 -c +00:02
+              trigger ./set_xp eq complete
+              edit RESERVATION_LABEL 'emos00XP'
+              label info ""
+          endfamily
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '12160'
+            edit RESERVE_FOR '2'
+            label info ""
+          task rm_res
+            late -s +00:03 -c +00:02
+            edit RESERVATION_LABEL 'emos00B'
+            label info ""
+        endfamily
+      endfamily
+      family getreq
+        trigger ( /e_36r1/main/00/an/4dvar eq active or /e_36r1/main/00/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit PROD_TASK '1'
+        edit EMOS_DOMAIN 'G'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_PROJECT '12'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'OPER'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '00'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger collectreq eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete and ( req:001 or req eq complete)
+          label info ""
+          event 1 
+        task collectwave
+          trigger ./collectbitmap eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '00'
+          edit EMOS_STREAM 'WAVE'
+        task wavereq
+          late -s +00:03 -c +00:10
+          trigger ./collectwave eq complete
+          edit EMOS_STREAM 'WAVE'
+          label info ""
+          event 1 
+        task pgclima
+          late -s +00:03 -c +00:10
+          event 1 
+      endfamily
+      family prod
+        trigger ( getreq/req:001 or getreq/req eq complete) and ( getreq/bitmap:001 or getreq/bitmap eq complete) and ( getreq/wavereq:001 or getreq/wavereq eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit EMOS_PROJECT '12'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit EMOS_BASE '00'
+        family 18an
+          trigger /e_36r1/main/12dc/an/dcda_to_da eq complete
+          edit EMOS_TYPE 'an'
+          edit EMOS_BASE '18'
+          edit DELTA_DAY '0'
+          edit SMSURL 'GOPER/18'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 00an
+          trigger /e_36r1/main/00/an/surf_anal eq complete and ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar/ifstraj eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TYPE 'an'
+          edit PGNPES '90'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ( ./derived_param:SMOS or ./derived_param eq complete) and ( ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar/ifstraj eq complete))
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 000
+          trigger ( /e_36r1/main/00/fc/model:step ge 000 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0000'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '000'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 003
+          trigger ( /e_36r1/main/00/fc/model:step ge 003 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '003'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 006
+          trigger ( /e_36r1/main/00/fc/model:step ge 006 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '006'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 009
+          trigger ( /e_36r1/main/00/fc/model:step ge 009 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '009'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 012
+          trigger ( /e_36r1/main/00/fc/model:step ge 012 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '012'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 015
+          trigger ( /e_36r1/main/00/fc/model:step ge 015 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '015'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 018
+          trigger ( /e_36r1/main/00/fc/model:step ge 018 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '018'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 021
+          trigger ( /e_36r1/main/00/fc/model:step ge 021 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '021'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 024
+          trigger ( /e_36r1/main/00/fc/model:step ge 024 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '024'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 027
+          trigger ( /e_36r1/main/00/fc/model:step ge 027 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '027'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 030
+          trigger ( /e_36r1/main/00/fc/model:step ge 030 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '030'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 033
+          trigger ( /e_36r1/main/00/fc/model:step ge 033 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '033'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 036
+          trigger ( /e_36r1/main/00/fc/model:step ge 036 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0036'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '036'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 039
+          trigger ( /e_36r1/main/00/fc/model:step ge 039 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0039'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '039'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 042
+          trigger ( /e_36r1/main/00/fc/model:step ge 042 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0042'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '042'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 045
+          trigger ( /e_36r1/main/00/fc/model:step ge 045 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0045'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '045'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 048
+          trigger ( /e_36r1/main/00/fc/model:step ge 048 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0048'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '048'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 051
+          trigger ( /e_36r1/main/00/fc/model:step ge 051 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0051'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '051'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 054
+          trigger ( /e_36r1/main/00/fc/model:step ge 054 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0054'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '054'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 057
+          trigger ( /e_36r1/main/00/fc/model:step ge 057 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0057'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '057'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 060
+          trigger ( /e_36r1/main/00/fc/model:step ge 060 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0060'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '060'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 063
+          trigger ( /e_36r1/main/00/fc/model:step ge 063 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0063'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '063'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 066
+          trigger ( /e_36r1/main/00/fc/model:step ge 066 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0066'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '066'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 069
+          trigger ( /e_36r1/main/00/fc/model:step ge 069 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0069'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '069'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 072
+          trigger ( /e_36r1/main/00/fc/model:step ge 072 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0072'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '072'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 075
+          trigger ( /e_36r1/main/00/fc/model:step ge 075 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0075'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '075'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 078
+          trigger ( /e_36r1/main/00/fc/model:step ge 078 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0078'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '078'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 081
+          trigger ( /e_36r1/main/00/fc/model:step ge 081 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0081'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '081'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 084
+          trigger ( /e_36r1/main/00/fc/model:step ge 084 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0084'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '084'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 087
+          trigger ( /e_36r1/main/00/fc/model:step ge 087 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0087'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '087'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 090
+          trigger ( /e_36r1/main/00/fc/model:step ge 090 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0090'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '090'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 093
+          trigger ( /e_36r1/main/00/fc/model:step ge 093 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0093'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../090/derived_param:SMOS or ../090/derived_param eq complete) or ( ../090/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '093'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 096
+          trigger ( /e_36r1/main/00/fc/model:step ge 096 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0096'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../093/derived_param:SMOS or ../093/derived_param eq complete) or ( ../093/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '096'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 099
+          trigger ( /e_36r1/main/00/fc/model:step ge 099 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0099'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../096/derived_param:SMOS or ../096/derived_param eq complete) or ( ../096/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '099'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 102
+          trigger ( /e_36r1/main/00/fc/model:step ge 102 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0102'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../099/derived_param:SMOS or ../099/derived_param eq complete) or ( ../099/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '102'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 105
+          trigger ( /e_36r1/main/00/fc/model:step ge 105 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0105'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../102/derived_param:SMOS or ../102/derived_param eq complete) or ( ../102/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '105'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 108
+          trigger ( /e_36r1/main/00/fc/model:step ge 108 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0108'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../105/derived_param:SMOS or ../105/derived_param eq complete) or ( ../105/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '108'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 111
+          trigger ( /e_36r1/main/00/fc/model:step ge 111 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0111'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../108/derived_param:SMOS or ../108/derived_param eq complete) or ( ../108/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '111'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 114
+          trigger ( /e_36r1/main/00/fc/model:step ge 114 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0114'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../111/derived_param:SMOS or ../111/derived_param eq complete) or ( ../111/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '114'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 117
+          trigger ( /e_36r1/main/00/fc/model:step ge 117 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0117'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../114/derived_param:SMOS or ../114/derived_param eq complete) or ( ../114/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '117'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 120
+          trigger ( /e_36r1/main/00/fc/model:step ge 120 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0120'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../117/derived_param:SMOS or ../117/derived_param eq complete) or ( ../117/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '120'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 123
+          trigger ( /e_36r1/main/00/fc/model:step ge 123 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0123'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../120/derived_param:SMOS or ../120/derived_param eq complete) or ( ../120/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '123'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 126
+          trigger ( /e_36r1/main/00/fc/model:step ge 126 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0126'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../123/derived_param:SMOS or ../123/derived_param eq complete) or ( ../123/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '126'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 129
+          trigger ( /e_36r1/main/00/fc/model:step ge 129 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0129'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../126/derived_param:SMOS or ../126/derived_param eq complete) or ( ../126/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '129'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 132
+          trigger ( /e_36r1/main/00/fc/model:step ge 132 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0132'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../129/derived_param:SMOS or ../129/derived_param eq complete) or ( ../129/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '132'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 135
+          trigger ( /e_36r1/main/00/fc/model:step ge 135 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0135'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../132/derived_param:SMOS or ../132/derived_param eq complete) or ( ../132/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '135'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 138
+          trigger ( /e_36r1/main/00/fc/model:step ge 138 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0138'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../135/derived_param:SMOS or ../135/derived_param eq complete) or ( ../135/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '138'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 141
+          trigger ( /e_36r1/main/00/fc/model:step ge 141 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0141'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../138/derived_param:SMOS or ../138/derived_param eq complete) or ( ../138/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '141'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 144
+          trigger ( /e_36r1/main/00/fc/model:step ge 144 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0144'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../141/derived_param:SMOS or ../141/derived_param eq complete) or ( ../141/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '144'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 150
+          trigger ( /e_36r1/main/00/fc/model:step ge 150 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0150'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../144/derived_param:SMOS or ../144/derived_param eq complete) or ( ../144/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '150'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 156
+          trigger ( /e_36r1/main/00/fc/model:step ge 156 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0156'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../150/derived_param:SMOS or ../150/derived_param eq complete) or ( ../150/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '156'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 162
+          trigger ( /e_36r1/main/00/fc/model:step ge 162 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0162'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../156/derived_param:SMOS or ../156/derived_param eq complete) or ( ../156/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '162'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 168
+          trigger ( /e_36r1/main/00/fc/model:step ge 168 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0168'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../162/derived_param:SMOS or ../162/derived_param eq complete) or ( ../162/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '168'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 174
+          trigger ( /e_36r1/main/00/fc/model:step ge 174 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0174'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../168/derived_param:SMOS or ../168/derived_param eq complete) or ( ../168/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '174'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 180
+          trigger ( /e_36r1/main/00/fc/model:step ge 180 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0180'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../174/derived_param:SMOS or ../174/derived_param eq complete) or ( ../174/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '180'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 186
+          trigger ( /e_36r1/main/00/fc/model:step ge 186 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0186'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../180/derived_param:SMOS or ../180/derived_param eq complete) or ( ../180/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '186'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 192
+          trigger ( /e_36r1/main/00/fc/model:step ge 192 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0192'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../186/derived_param:SMOS or ../186/derived_param eq complete) or ( ../186/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '192'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 198
+          trigger ( /e_36r1/main/00/fc/model:step ge 198 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0198'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../192/derived_param:SMOS or ../192/derived_param eq complete) or ( ../192/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '198'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 204
+          trigger ( /e_36r1/main/00/fc/model:step ge 204 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0204'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../198/derived_param:SMOS or ../198/derived_param eq complete) or ( ../198/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '204'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 210
+          trigger ( /e_36r1/main/00/fc/model:step ge 210 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0210'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../204/derived_param:SMOS or ../204/derived_param eq complete) or ( ../204/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '210'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 216
+          trigger ( /e_36r1/main/00/fc/model:step ge 216 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0216'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../210/derived_param:SMOS or ../210/derived_param eq complete) or ( ../210/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '216'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 222
+          trigger ( /e_36r1/main/00/fc/model:step ge 222 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0222'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../216/derived_param:SMOS or ../216/derived_param eq complete) or ( ../216/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '222'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 228
+          trigger ( /e_36r1/main/00/fc/model:step ge 228 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0228'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../222/derived_param:SMOS or ../222/derived_param eq complete) or ( ../222/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '228'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 234
+          trigger ( /e_36r1/main/00/fc/model:step ge 234 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0234'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../228/derived_param:SMOS or ../228/derived_param eq complete) or ( ../228/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '234'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 240
+          trigger ( /e_36r1/main/00/fc/model:step ge 240 or /e_36r1/main/00/fc/model eq complete) and ( ../getreq/pgclima:001 or ../getreq/pgclima eq complete)
+          edit EMOS_TIME_STEP_H '0240'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '91'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task prod_wparam
+            late -s +00:05 -c +00:15
+            trigger ./derived_param eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TYPE 'wp'
+            edit PGNPES '64'
+            edit INIMEM '800'
+            inlimit /e_36r1/limits:prod
+          task prodwave
+            late -s +00:05 -c +00:15
+            edit EMOS_STREAM 'WV'
+            edit PGNPES '2'
+            inlimit /limits:prod
+            inlimit /e_36r1/limits:prod
+          task derived_param
+            trigger ( ../234/derived_param:SMOS or ../234/derived_param eq complete) or ( ../234/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '240'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family reservation1
+          late -c +00:03
+          trigger /e_36r1/main/00bc/prod/078/prodgen eq active or /e_36r1/main/00bc/prod/078/prodgen eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task set_xp
+            late -s +00:03 -c +00:02
+            edit RESERVATION_NODES '18'
+            label info ""
+        endfamily
+        family reservation2
+          late -c +00:03
+          trigger /e_36r1/main/00/prod/240/prodgen eq active or /e_36r1/main/00/prod/240/prodgen eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task set_xp
+            late -s +00:03 -c +00:02
+            edit RESERVATION_NODES '18'
+            label info ""
+        endfamily
+        family reservation3
+          late -c +00:03
+          trigger /e_36r1/main/00/prod/240/prodgen eq active or /e_36r1/main/00/prod/240/prodgen eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reset_xp
+            late -s +00:03 -c +00:02
+            trigger /emc_36r1/main/00/legB/prod eq complete
+            edit RESERVATION_NODES '0'
+            label info ""
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        task operation_is_late
+          event yes
+        family oper
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '92'
+          edit EMOS_PROJECT '12'
+          edit SMSURL 'GOPER/00'
+          edit EMOS_BASE '00'
+          family 18an
+            edit EMOS_TYPE 'an'
+            edit EMOS_BASE '18'
+            edit SMSURL 'GOPER/18'
+            edit DELTA_DAY '0'
+            task pdb
+              trigger ../../../prod/18an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 00an
+            edit EMOS_TYPE 'an'
+            task pdb
+              trigger ../../../prod/00an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 000
+            edit EMOS_TIME_STEP_H '0000'
+            task pdb
+              trigger ../../../prod/000/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../00an/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 003
+            edit EMOS_TIME_STEP_H '0003'
+            task pdb
+              trigger ../../../prod/003/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 006
+            edit EMOS_TIME_STEP_H '0006'
+            task pdb
+              trigger ../../../prod/006/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 009
+            edit EMOS_TIME_STEP_H '0009'
+            task pdb
+              trigger ../../../prod/009/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 012
+            edit EMOS_TIME_STEP_H '0012'
+            task pdb
+              trigger ../../../prod/012/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 015
+            edit EMOS_TIME_STEP_H '0015'
+            task pdb
+              trigger ../../../prod/015/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 018
+            edit EMOS_TIME_STEP_H '0018'
+            task pdb
+              trigger ../../../prod/018/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 021
+            edit EMOS_TIME_STEP_H '0021'
+            task pdb
+              trigger ../../../prod/021/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 024
+            edit EMOS_TIME_STEP_H '0024'
+            task pdb
+              trigger ../../../prod/024/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 027
+            edit EMOS_TIME_STEP_H '0027'
+            task pdb
+              trigger ../../../prod/027/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 030
+            edit EMOS_TIME_STEP_H '0030'
+            task pdb
+              trigger ../../../prod/030/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 033
+            edit EMOS_TIME_STEP_H '0033'
+            task pdb
+              trigger ../../../prod/033/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 036
+            edit EMOS_TIME_STEP_H '0036'
+            task pdb
+              trigger ../../../prod/036/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 039
+            edit EMOS_TIME_STEP_H '0039'
+            task pdb
+              trigger ../../../prod/039/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 042
+            edit EMOS_TIME_STEP_H '0042'
+            task pdb
+              trigger ../../../prod/042/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 045
+            edit EMOS_TIME_STEP_H '0045'
+            task pdb
+              trigger ../../../prod/045/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 048
+            edit EMOS_TIME_STEP_H '0048'
+            task pdb
+              trigger ../../../prod/048/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 051
+            edit EMOS_TIME_STEP_H '0051'
+            task pdb
+              trigger ../../../prod/051/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 054
+            edit EMOS_TIME_STEP_H '0054'
+            task pdb
+              trigger ../../../prod/054/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 057
+            edit EMOS_TIME_STEP_H '0057'
+            task pdb
+              trigger ../../../prod/057/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 060
+            edit EMOS_TIME_STEP_H '0060'
+            task pdb
+              trigger ../../../prod/060/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 063
+            edit EMOS_TIME_STEP_H '0063'
+            task pdb
+              trigger ../../../prod/063/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 066
+            edit EMOS_TIME_STEP_H '0066'
+            task pdb
+              trigger ../../../prod/066/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 069
+            edit EMOS_TIME_STEP_H '0069'
+            task pdb
+              trigger ../../../prod/069/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 072
+            edit EMOS_TIME_STEP_H '0072'
+            task pdb
+              trigger ../../../prod/072/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 075
+            edit EMOS_TIME_STEP_H '0075'
+            task pdb
+              trigger ../../../prod/075/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 078
+            edit EMOS_TIME_STEP_H '0078'
+            task pdb
+              trigger ../../../prod/078/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 081
+            edit EMOS_TIME_STEP_H '0081'
+            task pdb
+              trigger ../../../prod/081/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 084
+            edit EMOS_TIME_STEP_H '0084'
+            task pdb
+              trigger ../../../prod/084/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 087
+            edit EMOS_TIME_STEP_H '0087'
+            task pdb
+              trigger ../../../prod/087/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 090
+            edit EMOS_TIME_STEP_H '0090'
+            task pdb
+              trigger ../../../prod/090/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 093
+            edit EMOS_TIME_STEP_H '0093'
+            task pdb
+              trigger ../../../prod/093/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../090/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 096
+            edit EMOS_TIME_STEP_H '0096'
+            task pdb
+              trigger ../../../prod/096/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../093/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 099
+            edit EMOS_TIME_STEP_H '0099'
+            task pdb
+              trigger ../../../prod/099/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../096/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 102
+            edit EMOS_TIME_STEP_H '0102'
+            task pdb
+              trigger ../../../prod/102/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../099/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 105
+            edit EMOS_TIME_STEP_H '0105'
+            task pdb
+              trigger ../../../prod/105/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../102/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 108
+            edit EMOS_TIME_STEP_H '0108'
+            task pdb
+              trigger ../../../prod/108/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../105/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 111
+            edit EMOS_TIME_STEP_H '0111'
+            task pdb
+              trigger ../../../prod/111/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../108/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 114
+            edit EMOS_TIME_STEP_H '0114'
+            task pdb
+              trigger ../../../prod/114/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../111/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 117
+            edit EMOS_TIME_STEP_H '0117'
+            task pdb
+              trigger ../../../prod/117/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../114/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 120
+            edit EMOS_TIME_STEP_H '0120'
+            task pdb
+              trigger ../../../prod/120/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../117/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 123
+            edit EMOS_TIME_STEP_H '0123'
+            task pdb
+              trigger ../../../prod/123/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../120/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 126
+            edit EMOS_TIME_STEP_H '0126'
+            task pdb
+              trigger ../../../prod/126/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../123/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 129
+            edit EMOS_TIME_STEP_H '0129'
+            task pdb
+              trigger ../../../prod/129/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../126/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 132
+            edit EMOS_TIME_STEP_H '0132'
+            task pdb
+              trigger ../../../prod/132/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../129/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 135
+            edit EMOS_TIME_STEP_H '0135'
+            task pdb
+              trigger ../../../prod/135/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../132/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 138
+            edit EMOS_TIME_STEP_H '0138'
+            task pdb
+              trigger ../../../prod/138/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../135/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 141
+            edit EMOS_TIME_STEP_H '0141'
+            task pdb
+              trigger ../../../prod/141/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../138/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 144
+            edit EMOS_TIME_STEP_H '0144'
+            task pdb
+              trigger ../../../prod/144/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../141/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 150
+            edit EMOS_TIME_STEP_H '0150'
+            task pdb
+              trigger ../../../prod/150/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../144/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 156
+            edit EMOS_TIME_STEP_H '0156'
+            task pdb
+              trigger ../../../prod/156/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../150/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 162
+            edit EMOS_TIME_STEP_H '0162'
+            task pdb
+              trigger ../../../prod/162/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../156/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 168
+            edit EMOS_TIME_STEP_H '0168'
+            task pdb
+              trigger ../../../prod/168/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../162/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 174
+            edit EMOS_TIME_STEP_H '0174'
+            task pdb
+              trigger ../../../prod/174/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../168/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 180
+            edit EMOS_TIME_STEP_H '0180'
+            task pdb
+              trigger ../../../prod/180/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../174/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 186
+            edit EMOS_TIME_STEP_H '0186'
+            task pdb
+              trigger ../../../prod/186/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../180/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 192
+            edit EMOS_TIME_STEP_H '0192'
+            task pdb
+              trigger ../../../prod/192/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../186/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 198
+            edit EMOS_TIME_STEP_H '0198'
+            task pdb
+              trigger ../../../prod/198/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../192/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 204
+            edit EMOS_TIME_STEP_H '0204'
+            task pdb
+              trigger ../../../prod/204/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../198/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 210
+            edit EMOS_TIME_STEP_H '0210'
+            task pdb
+              trigger ../../../prod/210/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../204/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 216
+            edit EMOS_TIME_STEP_H '0216'
+            task pdb
+              trigger ../../../prod/216/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../210/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 222
+            edit EMOS_TIME_STEP_H '0222'
+            task pdb
+              trigger ../../../prod/222/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../216/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 228
+            edit EMOS_TIME_STEP_H '0228'
+            task pdb
+              trigger ../../../prod/228/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../222/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 234
+            edit EMOS_TIME_STEP_H '0234'
+            task pdb
+              trigger ../../../prod/234/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../228/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family 240
+            edit EMOS_TIME_STEP_H '0240'
+            task pdb
+              trigger ../../../prod/240/prodgen eq complete
+              inlimit /e_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../234/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+            task diss_wparam
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/240/prod_wparam eq complete
+              edit PROD_TASK 'w'
+              edit EMOS_TYPE 'wp'
+              label info ""
+              event pdb
+          endfamily
+          task check
+            trigger ./240 eq complete
+        endfamily
+        family wave
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit EMOS_PROJECT '12'
+          edit EMOS_STREAM 'WV'
+          edit SMSURL 'GWAVE/00'
+          inlimit /e_36r1/limits:w2diss
+          inlimit /limits:q2diss
+          family 18an
+            edit EMOS_TYPE 'an'
+            edit EMOS_BASE '18'
+            edit SMSURL 'GWAVE/18'
+            edit DELTA_DAY '0'
+            task diss
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/18an/prodwave eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event pdb
+          endfamily
+          family 00an
+            edit EMOS_TYPE 'an'
+            task diss
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/00an/prodwave eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event pdb
+          endfamily
+          family 000
+            trigger ../../prod/000/prodwave eq complete and ./18an eq complete and ./00an eq complete
+            edit EMOS_TIME_STEP_H '0000'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 003
+            trigger ../../prod/003/prodwave eq complete and ( ./000/diss:pdb or ./000 eq complete)
+            edit EMOS_TIME_STEP_H '0003'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 006
+            trigger ../../prod/006/prodwave eq complete and ( ./003/diss:pdb or ./003 eq complete)
+            edit EMOS_TIME_STEP_H '0006'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 009
+            trigger ../../prod/009/prodwave eq complete and ( ./006/diss:pdb or ./006 eq complete)
+            edit EMOS_TIME_STEP_H '0009'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 012
+            trigger ../../prod/012/prodwave eq complete and ( ./009/diss:pdb or ./009 eq complete)
+            edit EMOS_TIME_STEP_H '0012'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 015
+            trigger ../../prod/015/prodwave eq complete and ( ./012/diss:pdb or ./012 eq complete)
+            edit EMOS_TIME_STEP_H '0015'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 018
+            trigger ../../prod/018/prodwave eq complete and ( ./015/diss:pdb or ./015 eq complete)
+            edit EMOS_TIME_STEP_H '0018'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 021
+            trigger ../../prod/021/prodwave eq complete and ( ./018/diss:pdb or ./018 eq complete)
+            edit EMOS_TIME_STEP_H '0021'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 024
+            trigger ../../prod/024/prodwave eq complete and ( ./021/diss:pdb or ./021 eq complete)
+            edit EMOS_TIME_STEP_H '0024'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 027
+            trigger ../../prod/027/prodwave eq complete and ( ./024/diss:pdb or ./024 eq complete)
+            edit EMOS_TIME_STEP_H '0027'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 030
+            trigger ../../prod/030/prodwave eq complete and ( ./027/diss:pdb or ./027 eq complete)
+            edit EMOS_TIME_STEP_H '0030'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 033
+            trigger ../../prod/033/prodwave eq complete and ( ./030/diss:pdb or ./030 eq complete)
+            edit EMOS_TIME_STEP_H '0033'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 036
+            trigger ../../prod/036/prodwave eq complete and ( ./033/diss:pdb or ./033 eq complete)
+            edit EMOS_TIME_STEP_H '0036'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 039
+            trigger ../../prod/039/prodwave eq complete and ( ./036/diss:pdb or ./036 eq complete)
+            edit EMOS_TIME_STEP_H '0039'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 042
+            trigger ../../prod/042/prodwave eq complete and ( ./039/diss:pdb or ./039 eq complete)
+            edit EMOS_TIME_STEP_H '0042'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 045
+            trigger ../../prod/045/prodwave eq complete and ( ./042/diss:pdb or ./042 eq complete)
+            edit EMOS_TIME_STEP_H '0045'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 048
+            trigger ../../prod/048/prodwave eq complete and ( ./045/diss:pdb or ./045 eq complete)
+            edit EMOS_TIME_STEP_H '0048'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 051
+            trigger ../../prod/051/prodwave eq complete and ( ./048/diss:pdb or ./048 eq complete)
+            edit EMOS_TIME_STEP_H '0051'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 054
+            trigger ../../prod/054/prodwave eq complete and ( ./051/diss:pdb or ./051 eq complete)
+            edit EMOS_TIME_STEP_H '0054'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 057
+            trigger ../../prod/057/prodwave eq complete and ( ./054/diss:pdb or ./054 eq complete)
+            edit EMOS_TIME_STEP_H '0057'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 060
+            trigger ../../prod/060/prodwave eq complete and ( ./057/diss:pdb or ./057 eq complete)
+            edit EMOS_TIME_STEP_H '0060'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 063
+            trigger ../../prod/063/prodwave eq complete and ( ./060/diss:pdb or ./060 eq complete)
+            edit EMOS_TIME_STEP_H '0063'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 066
+            trigger ../../prod/066/prodwave eq complete and ( ./063/diss:pdb or ./063 eq complete)
+            edit EMOS_TIME_STEP_H '0066'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 069
+            trigger ../../prod/069/prodwave eq complete and ( ./066/diss:pdb or ./066 eq complete)
+            edit EMOS_TIME_STEP_H '0069'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 072
+            trigger ../../prod/072/prodwave eq complete and ( ./069/diss:pdb or ./069 eq complete)
+            edit EMOS_TIME_STEP_H '0072'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 075
+            trigger ../../prod/075/prodwave eq complete and ( ./072/diss:pdb or ./072 eq complete)
+            edit EMOS_TIME_STEP_H '0075'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 078
+            trigger ../../prod/078/prodwave eq complete and ( ./075/diss:pdb or ./075 eq complete)
+            edit EMOS_TIME_STEP_H '0078'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 081
+            trigger ../../prod/081/prodwave eq complete and ( ./078/diss:pdb or ./078 eq complete)
+            edit EMOS_TIME_STEP_H '0081'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 084
+            trigger ../../prod/084/prodwave eq complete and ( ./081/diss:pdb or ./081 eq complete)
+            edit EMOS_TIME_STEP_H '0084'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 087
+            trigger ../../prod/087/prodwave eq complete and ( ./084/diss:pdb or ./084 eq complete)
+            edit EMOS_TIME_STEP_H '0087'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 090
+            trigger ../../prod/090/prodwave eq complete and ( ./087/diss:pdb or ./087 eq complete)
+            edit EMOS_TIME_STEP_H '0090'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 093
+            trigger ../../prod/093/prodwave eq complete and ( ./090/diss:pdb or ./090 eq complete)
+            edit EMOS_TIME_STEP_H '0093'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 096
+            trigger ../../prod/096/prodwave eq complete and ( ./093/diss:pdb or ./093 eq complete)
+            edit EMOS_TIME_STEP_H '0096'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 099
+            trigger ../../prod/099/prodwave eq complete and ( ./096/diss:pdb or ./096 eq complete)
+            edit EMOS_TIME_STEP_H '0099'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 102
+            trigger ../../prod/102/prodwave eq complete and ( ./099/diss:pdb or ./099 eq complete)
+            edit EMOS_TIME_STEP_H '0102'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 105
+            trigger ../../prod/105/prodwave eq complete and ( ./102/diss:pdb or ./102 eq complete)
+            edit EMOS_TIME_STEP_H '0105'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 108
+            trigger ../../prod/108/prodwave eq complete and ( ./105/diss:pdb or ./105 eq complete)
+            edit EMOS_TIME_STEP_H '0108'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 111
+            trigger ../../prod/111/prodwave eq complete and ( ./108/diss:pdb or ./108 eq complete)
+            edit EMOS_TIME_STEP_H '0111'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 114
+            trigger ../../prod/114/prodwave eq complete and ( ./111/diss:pdb or ./111 eq complete)
+            edit EMOS_TIME_STEP_H '0114'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 117
+            trigger ../../prod/117/prodwave eq complete and ( ./114/diss:pdb or ./114 eq complete)
+            edit EMOS_TIME_STEP_H '0117'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 120
+            trigger ../../prod/120/prodwave eq complete and ( ./117/diss:pdb or ./117 eq complete)
+            edit EMOS_TIME_STEP_H '0120'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 123
+            trigger ../../prod/123/prodwave eq complete and ( ./120/diss:pdb or ./120 eq complete)
+            edit EMOS_TIME_STEP_H '0123'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 126
+            trigger ../../prod/126/prodwave eq complete and ( ./123/diss:pdb or ./123 eq complete)
+            edit EMOS_TIME_STEP_H '0126'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 129
+            trigger ../../prod/129/prodwave eq complete and ( ./126/diss:pdb or ./126 eq complete)
+            edit EMOS_TIME_STEP_H '0129'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 132
+            trigger ../../prod/132/prodwave eq complete and ( ./129/diss:pdb or ./129 eq complete)
+            edit EMOS_TIME_STEP_H '0132'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 135
+            trigger ../../prod/135/prodwave eq complete and ( ./132/diss:pdb or ./132 eq complete)
+            edit EMOS_TIME_STEP_H '0135'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 138
+            trigger ../../prod/138/prodwave eq complete and ( ./135/diss:pdb or ./135 eq complete)
+            edit EMOS_TIME_STEP_H '0138'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 141
+            trigger ../../prod/141/prodwave eq complete and ( ./138/diss:pdb or ./138 eq complete)
+            edit EMOS_TIME_STEP_H '0141'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 144
+            trigger ../../prod/144/prodwave eq complete and ( ./141/diss:pdb or ./141 eq complete)
+            edit EMOS_TIME_STEP_H '0144'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 150
+            trigger ../../prod/150/prodwave eq complete and ( ./144/diss:pdb or ./144 eq complete)
+            edit EMOS_TIME_STEP_H '0150'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 156
+            trigger ../../prod/156/prodwave eq complete and ( ./150/diss:pdb or ./150 eq complete)
+            edit EMOS_TIME_STEP_H '0156'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 162
+            trigger ../../prod/162/prodwave eq complete and ( ./156/diss:pdb or ./156 eq complete)
+            edit EMOS_TIME_STEP_H '0162'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 168
+            trigger ../../prod/168/prodwave eq complete and ( ./162/diss:pdb or ./162 eq complete)
+            edit EMOS_TIME_STEP_H '0168'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 174
+            trigger ../../prod/174/prodwave eq complete and ( ./168/diss:pdb or ./168 eq complete)
+            edit EMOS_TIME_STEP_H '0174'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 180
+            trigger ../../prod/180/prodwave eq complete and ( ./174/diss:pdb or ./174 eq complete)
+            edit EMOS_TIME_STEP_H '0180'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 186
+            trigger ../../prod/186/prodwave eq complete and ( ./180/diss:pdb or ./180 eq complete)
+            edit EMOS_TIME_STEP_H '0186'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 192
+            trigger ../../prod/192/prodwave eq complete and ( ./186/diss:pdb or ./186 eq complete)
+            edit EMOS_TIME_STEP_H '0192'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 198
+            trigger ../../prod/198/prodwave eq complete and ( ./192/diss:pdb or ./192 eq complete)
+            edit EMOS_TIME_STEP_H '0198'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 204
+            trigger ../../prod/204/prodwave eq complete and ( ./198/diss:pdb or ./198 eq complete)
+            edit EMOS_TIME_STEP_H '0204'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 210
+            trigger ../../prod/210/prodwave eq complete and ( ./204/diss:pdb or ./204 eq complete)
+            edit EMOS_TIME_STEP_H '0210'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 216
+            trigger ../../prod/216/prodwave eq complete and ( ./210/diss:pdb or ./210 eq complete)
+            edit EMOS_TIME_STEP_H '0216'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 222
+            trigger ../../prod/222/prodwave eq complete and ( ./216/diss:pdb or ./216 eq complete)
+            edit EMOS_TIME_STEP_H '0222'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 228
+            trigger ../../prod/228/prodwave eq complete and ( ./222/diss:pdb or ./222 eq complete)
+            edit EMOS_TIME_STEP_H '0228'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 234
+            trigger ../../prod/234/prodwave eq complete and ( ./228/diss:pdb or ./228 eq complete)
+            edit EMOS_TIME_STEP_H '0234'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 240
+            trigger ../../prod/240/prodwave eq complete and ( ./234/diss:pdb or ./234 eq complete)
+            edit EMOS_TIME_STEP_H '0240'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          task check
+            trigger ./240 eq complete
+        endfamily
+      endfamily
+    endfamily
+    family 06bc
+      trigger ( ( ./make eq complete) and ( /e_36r1/main/00/fc eq complete)) and ( /e_36r1/main/18bc/fc eq complete)
+      edit EMOS_BASE '06'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '1'
+      edit ACCOUNT 'opebcpg'
+      edit SMSURL 'GSCDA/06'
+      edit USER_PRIORITY '91'
+      family obs
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/obs'
+        family get
+          inlimit /e_36r1/limits:obs_get
+          inlimit /limits:obs_get
+          task get_nonbin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/nonbin eq complete
+            edit OBSFILE_OBSHOST 'BUFR'
+            edit OBSFILE_HPCF 'bufr'
+          task get_ers1_wa
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ers1_wa eq complete
+            edit OBSFILE_OBSHOST 'UWAX'
+            edit OBSFILE_HPCF 'wavescat'
+          task get_eas1
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/eas1 eq complete
+            edit OBSFILE_OBSHOST 'EAS1'
+            edit OBSFILE_HPCF 'wavesar'
+          task get_ers1_wi
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ers1_wi eq complete
+            edit OBSFILE_OBSHOST 'UWIX'
+            edit OBSFILE_HPCF 'scat'
+          task get_ers1_ra
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ers1_ra eq complete
+            edit OBSFILE_OBSHOST 'URAX'
+            edit OBSFILE_HPCF 'ralt'
+          task get_rtovs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/rtovs eq complete
+            edit OBSFILE_OBSHOST 'TOVH'
+            edit OBSFILE_HPCF 'tovh'
+          task get_ssbt
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ssbt eq complete
+            edit OBSFILE_OBSHOST 'SSBT'
+            edit OBSFILE_HPCF 'ssbt'
+          task get_sst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/sst/sst_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_atov
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/atov eq complete
+            edit OBSFILE_OBSHOST 'ATOV'
+            edit OBSFILE_HPCF 'atov'
+          task get_grad
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/grad eq complete
+            edit OBSFILE_OBSHOST 'GRAD'
+            edit OBSFILE_HPCF 'grad'
+          task get_stor
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/stor eq complete
+            edit OBSFILE_OBSHOST 'STOR'
+            edit OBSFILE_HPCF 'storm'
+          task get_trmm
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/trmm eq complete
+            edit OBSFILE_OBSHOST 'TRMM'
+            edit OBSFILE_HPCF 'tmi'
+          task get_qsca
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/qsca eq complete
+            edit OBSFILE_OBSHOST 'QSCA'
+            edit OBSFILE_HPCF 'qsca'
+          task get_sbuv
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/sbuv eq complete
+            edit OBSFILE_OBSHOST 'SBUV'
+            edit OBSFILE_HPCF 'reo3'
+          task get_airs
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/airs eq complete
+            edit OBSFILE_OBSHOST 'AIRS'
+            edit OBSFILE_HPCF 'airs'
+          task get_ice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ice/ice_fdb_c1b eq complete
+            edit OBSFILE_OBSHOST 'nil'
+            edit OBSFILE_HPCF 'nil'
+          task get_snow
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/snow eq complete
+            edit OBSFILE_OBSHOST 'SNOW'
+            edit OBSFILE_HPCF 'imssnow'
+          task get_ateu
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/ateu eq complete
+            edit OBSFILE_OBSHOST 'ATEU'
+            edit OBSFILE_HPCF 'amsu_ears'
+          task get_bice
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/bice eq complete
+            edit OBSFILE_OBSHOST 'BICE'
+            edit OBSFILE_HPCF 'baltic_ci'
+          task get_amsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/amsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AMSA'
+            edit OBSFILE_HPCF 'amsa'
+          task get_mhsa
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/mhsa eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MHSA'
+            edit OBSFILE_HPCF 'mhsa'
+          task get_hirs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/hirs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'HIRS'
+            edit OBSFILE_HPCF 'hirs'
+          task get_amsr
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/amsr eq complete
+            edit OBSFILE_OBSHOST 'AMSR'
+            edit OBSFILE_HPCF 'amsre_aq'
+          task get_rado
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/rado eq complete
+            edit OBSFILE_OBSHOST 'RADO'
+            edit OBSFILE_HPCF 'gpsro'
+          task get_smin
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/smin eq complete
+            edit OBSFILE_OBSHOST 'SMIN'
+            edit OBSFILE_HPCF 'ssmisbt'
+          task get_iasi
+            late -s +00:02 -c +00:07
+            trigger /pp2/main/extractions/ex06/iasi eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'IASI'
+            edit OBSFILE_HPCF 'iasi'
+          task get_gras
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/gras eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'GRAS'
+            edit OBSFILE_HPCF 'gras'
+          task get_modw
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/modw eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'MODW'
+            edit OBSFILE_HPCF 'dbmodiswinds'
+          task get_avhn
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/avhn eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'AVHN'
+            edit OBSFILE_HPCF 'avhrrwinds'
+          task get_atap
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/atap eq complete
+            edit OBSFILE_OBSHOST 'ATAP'
+            edit OBSFILE_HPCF 'amsu_pacrars'
+          task get_g2to
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/g2to eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'G2TO'
+            edit OBSFILE_HPCF 'reo3_gome2'
+          task get_grst
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/grst eq complete
+            edit OBSFILE_OBSHOST 'GRST'
+            edit OBSFILE_HPCF 'ostia'
+          task get_emer
+            late -s +00:02 -c +00:04
+            trigger /pp1/main/extractions/ex06/emer eq complete
+            edit OBSFILE_OBSHOST 'EMER'
+            edit OBSFILE_HPCF 'envisat_meris'
+          task get_j2nb
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/j2nb eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2NB'
+            edit OBSFILE_HPCF 'j2nb'
+          task get_j2eo
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/j2eo eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'J2EO'
+            edit OBSFILE_HPCF 'j2eo'
+          task get_asc2
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/asc2 eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASC2'
+            edit OBSFILE_HPCF 'ascat_l2'
+          task get_asel
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/asel eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASEL'
+            edit OBSFILE_HPCF 'ascat_ears'
+          task get_ascs
+            late -s +00:02 -c +00:04
+            trigger /pp2/main/extractions/ex06/ascs eq complete
+            edit OBSHOST 'pp2'
+            edit OBS_BASE '/pp2'
+            edit OBSFILE_OBSHOST 'ASCS'
+            edit OBSFILE_HPCF 'ascat_sm'
+          task atovairs
+            trigger get_atov eq complete and get_airs eq complete and get_ateu eq complete and get_amsa eq complete and get_mhsa eq complete and get_hirs eq complete and get_atap eq complete
+          task snowlinks
+            trigger get_nonbin eq complete and get_ers1_wi eq complete and get_rtovs eq complete and get_snow eq complete
+          task ro_combine
+            trigger get_rado eq complete and get_gras eq complete
+          task reo3_combine
+            trigger get_sbuv eq complete and get_g2to eq complete
+          task bufr_combine
+            trigger get_nonbin eq complete and get_modw eq complete and get_avhn eq complete
+          task jason2_combine
+            trigger get_ers1_ra eq complete and get_j2nb eq complete and get_j2eo eq complete
+          task ascat_combine
+            trigger get_asc2 eq complete and get_asel eq complete and get_ascs eq complete
+        endfamily
+        task fetchmars
+          trigger ./get eq complete
+        family prepare_obs
+          trigger ./get eq complete
+          task preobs
+            trigger /e_36r1/main/12dc/an/update_psbias eq complete and /e_36r1/main/12dc/an/update_rstrhbias eq complete
+            edit mode 'not1crad'
+            edit REINITIALIZE 'true'
+            edit REINIPERIOD_4D '6'
+          task premwimg
+          task preobs_wave
+            edit mode 'wave'
+          task pre1crad_prepare
+            edit mode '1crad'
+          task pre1crad_airs
+            trigger pre1crad_prepare eq complete
+          family pre1crad_iasi
+            trigger pre1crad_prepare eq complete
+            edit CPUTIME '1500'
+            edit MAXTASK '16'
+            task pre1crad_iasi_split_1
+              edit TASKNO '1'
+            task pre1crad_iasi_split_2
+              edit TASKNO '2'
+            task pre1crad_iasi_1
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '1'
+            task pre1crad_iasi_2
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '2'
+            task pre1crad_iasi_3
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '3'
+            task pre1crad_iasi_4
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '4'
+            task pre1crad_iasi_5
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '5'
+            task pre1crad_iasi_6
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '6'
+            task pre1crad_iasi_7
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '7'
+            task pre1crad_iasi_8
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '8'
+            task pre1crad_iasi_9
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '9'
+            task pre1crad_iasi_10
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '10'
+            task pre1crad_iasi_11
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '11'
+            task pre1crad_iasi_12
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '12'
+            task pre1crad_iasi_13
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '13'
+            task pre1crad_iasi_14
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '14'
+            task pre1crad_iasi_15
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '15'
+            task pre1crad_iasi_16
+              trigger pre1crad_iasi_split_1 eq complete and pre1crad_iasi_split_2 eq complete
+              edit TASKNO '16'
+          endfamily
+          task pre1crad_hirs
+            trigger pre1crad_prepare eq complete
+          task pre1crad_msu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_ssu
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsua
+            trigger pre1crad_prepare eq complete
+          task pre1crad_amsub
+            trigger pre1crad_prepare eq complete
+          task pre1crad_mhs
+            trigger pre1crad_prepare eq complete
+          task pregeos
+          task prereo3
+          task prescat
+        endfamily
+        family reservation
+          late -c +00:03
+          trigger ./get/get_stor eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task adv_res
+            late -s +00:03 -c +00:02
+            edit RESERVE_FOR '30'
+            edit RESERVE_IN '11'
+            edit RESERVED_NODES '32'
+            edit RESERVATION_LABEL 'emos06A'
+            label info ""
+          task loadl_cycle_limit
+            late -s +00:03 -c +00:02
+            edit LOADL_CYCLE '65'
+            label info ""
+        endfamily
+      endfamily
+      family an
+        trigger ./obs/fetchmars eq complete and ./obs/prepare_obs eq complete
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+        edit PERIOD_4D '6'
+        edit WINDOW_LENGTH_4D '6'
+        edit WINDOW_OFFSET_4D '3'
+        edit ACCOUNT 'opebcan'
+        edit REINITIALIZE 'true'
+        edit ANNPES '144'
+        family makeodb
+          edit NPES '16'
+          task cleanodb
+          family bufr2odb
+            trigger cleanodb eq complete
+            edit THREADS '1'
+            edit NPOOLS '%ANNPES%'
+            edit THINFAC '1'
+            edit SENSOR '-1'
+            edit REBALANCE '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task b2o_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit USER_PRIORITY '90'
+            task b2o_surf_conv
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+            task b2o_airs
+              late -s +00:05 -c +00:15
+              edit THREADS '2'
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '57'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_iasi
+              late -s +00:05 -c +00:15
+              edit SENSOR '993'
+              edit SUBTYPES_INCLUDE '240'
+              edit THREADS '4'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_hirs
+              late -s +00:05 -c +00:15
+              edit SENSOR '0'
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPOOLS '$((2* %ANNPES%))'
+            task b2o_msu
+              late -s +00:05 -c +00:15
+              edit SENSOR '1'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_ssu
+              late -s +00:05 -c +00:15
+              edit SENSOR '2'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsua
+              late -s +00:05 -c +00:15
+              edit SENSOR '3'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_amsub
+              late -s +00:05 -c +00:15
+              edit SENSOR '4'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_mhs
+              late -s +00:05 -c +00:15
+              edit SENSOR '11'
+              edit SUBTYPES_INCLUDE '54 55'
+            task b2o_satob
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '82 83 87'
+            task b2o_reo3
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+            task b2o_ssmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '6'
+              edit SUBTYPES_INCLUDE '55 127'
+            task b2o_ssmis
+              late -s +00:05 -c +00:15
+              edit SENSOR '10'
+              edit SUBTYPES_INCLUDE '49'
+            task b2o_amsre
+              late -s +00:05 -c +00:15
+              edit SENSOR '17'
+              edit SUBTYPES_INCLUDE '59'
+            task b2o_tmi
+              late -s +00:05 -c +00:15
+              edit SENSOR '9'
+              edit SUBTYPES_INCLUDE '129'
+            task b2o_scatt
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task b2o_geos
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+            task b2o_gpsro
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '250'
+            task b2o_meris
+              late -s +00:05 -c +00:15
+              edit SENSOR '-1'
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergeodb
+            trigger bufr2odb eq complete
+          task mergeodb_surf
+            trigger ./bufr2odb/b2o_surf_conv eq complete
+            edit NPES '16'
+            edit THREADS '1'
+        endfamily
+        task restartodb
+          trigger makeodb eq complete
+        task preCleanFDB
+        task vardata
+          trigger ( ../../00/fc/model:step ge 9 or ../../00/fc/model eq complete)
+          event hires
+        task fetcherr
+        task lowres
+          trigger vardata:hires
+          edit THREADS '4'
+          edit ININPES '32'
+        family surf_anal
+          trigger makeodb eq complete and restartodb eq complete and preCleanFDB eq complete and vardata:hires
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          edit FSFAMILY 'surf_anal'
+          task t2ana
+            edit mode 't2m'
+          task rh2ana
+            trigger t2ana eq complete
+            edit mode 'rh2m'
+          task snow
+            trigger rh2ana eq complete
+            edit mode 'snow'
+          task sst
+            edit THREADS '4'
+          task slwet
+            trigger sst eq complete and snow eq complete
+        endfamily
+        family 4dvar
+          trigger makeodb eq complete and restartodb eq complete and vardata eq complete and fetcherr eq complete and lowres eq complete and preCleanFDB eq complete
+          edit THREADS '8'
+          edit VAR_DELAY '00'
+          edit EMOS_SLEEP '00'
+          family uptraj_0
+            edit uptraj '0'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '91'
+              edit SMSTRIES '1'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '92'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '93'
+          endfamily
+          family uptraj_1
+            trigger uptraj_0 eq complete
+            edit uptraj '1'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '93'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '94'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '95'
+          endfamily
+          family uptraj_2
+            trigger uptraj_1 eq complete
+            edit uptraj '2'
+            task ifstraj
+              late -s +00:02
+              edit mode 'traj'
+              edit USER_PRIORITY '95'
+            task ifsmin
+              late -s +00:02
+              trigger ifstraj eq complete
+              edit mode 'min'
+              edit USER_PRIORITY '96'
+            task ifstsave
+              trigger ifstraj eq complete
+              edit THREADS '1'
+              edit USER_PRIORITY '97'
+          endfamily
+          task ifstraj
+            late -s +00:02
+            trigger uptraj_2 eq complete
+            edit uptraj '3'
+            edit mode 'traj'
+            edit USER_PRIORITY '97'
+            event finaltraj
+            event finalwave
+        endfamily
+        task forceinv
+          trigger ./4dvar/ifstraj:finaltraj and ./surf_anal eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./4dvar/uptraj_0/ifstraj eq active or ./4dvar/uptraj_0/ifstraj eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '2432'
+            edit RESERVE_FOR '35'
+            label info ""
+          task rm_res
+            late -s +00:03 -c +00:02
+            edit RESERVATION_LABEL 'emos06A'
+            label info ""
+        endfamily
+      endfamily
+      family fc
+        trigger an/forceinv eq complete and ( an/4dvar/ifstraj:finalwave or an/4dvar eq complete)
+        edit ACCOUNT 'opebcfc'
+        edit REINITIALIZE 'true'
+        edit FSFAMILY 'fc'
+        task getfcdata
+        task getpersSST
+          trigger getfcdata eq complete
+          edit SSTLEN '90'
+          edit SSTINT '1'
+          edit THREADS '2'
+          edit NPES '16'
+          edit MEM '1000'
+          edit CPUTIME '960'
+        task model
+          late -s +00:02
+          trigger ( getfcdata eq complete) and ( getpersSST eq complete)
+          edit PERSST 'true'
+          edit FCLENGTH '90'
+          edit THREADS '8'
+          edit USER_PRIORITY '94'
+          edit FCNPES '144'
+          meter step -1 90 90
+        task clean
+          trigger ../an eq complete and getfcdata eq complete and model eq complete and ../../18bc/fc eq complete
+        family reservation1
+          late -c +00:03
+          trigger ./getfcdata eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reserve_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '3072'
+            edit RESERVE_FOR '20'
+            label info ""
+        endfamily
+        family reservation2
+          late -c +00:03
+          trigger ./model eq complete
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+          inlimit /e_36r1/limits:reservation
+          task reset_cpu
+            late -s +00:03 -c +00:02
+            edit RESERVED_CPUS '0'
+            label info ""
+        endfamily
+      endfamily
+      family getreq
+        trigger ( /e_36r1/main/06bc/an/4dvar eq active or /e_36r1/main/06bc/an/4dvar eq complete) and ( ./prod eq queued or ./prod eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit PROD_TASK '1'
+        edit EMOS_DOMAIN 'G'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_PROJECT '12'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'SCDA'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '06'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger collectreq eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete and ( req:001 or req eq complete)
+          label info ""
+          event 1 
+      endfamily
+      family prod
+        trigger ( getreq/req:001 or getreq/req eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit EMOS_PROJECT '12'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        family an
+          trigger /e_36r1/main/06bc/an/surf_anal eq complete and ( /e_36r1/main/06bc/an/4dvar/ifstraj:finalwave or /e_36r1/main/06bc/an/4dvar/ifstraj eq complete) and 0 eq 0
+          edit EMOS_TYPE 'an'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ../090/prodgen eq complete and ( /e_36r1/main/06bc/fc/model:step ge 12 or /e_36r1/main/06bc/fc/model eq complete)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 000
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 000 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0000'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 12 or /e_36r1/main/06bc/fc/model eq complete) and ( ../an/backupprod eq complete or ../an/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            edit MEMBER 'off'
+            edit STEPS '000'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 003
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 003 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 15 or /e_36r1/main/06bc/fc/model eq complete) and ( ../000/backupprod eq complete or ../000/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../000/derived_param:SMOS or ../000/derived_param eq complete) or ( ../000/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '003'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 006
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 006 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 18 or /e_36r1/main/06bc/fc/model eq complete) and ( ../003/backupprod eq complete or ../003/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../003/derived_param:SMOS or ../003/derived_param eq complete) or ( ../003/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '006'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 009
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 009 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 21 or /e_36r1/main/06bc/fc/model eq complete) and ( ../006/backupprod eq complete or ../006/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../006/derived_param:SMOS or ../006/derived_param eq complete) or ( ../006/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '009'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 012
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 012 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 24 or /e_36r1/main/06bc/fc/model eq complete) and ( ../009/backupprod eq complete or ../009/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../009/derived_param:SMOS or ../009/derived_param eq complete) or ( ../009/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '012'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 015
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 015 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 27 or /e_36r1/main/06bc/fc/model eq complete) and ( ../012/backupprod eq complete or ../012/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../012/derived_param:SMOS or ../012/derived_param eq complete) or ( ../012/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '015'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 018
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 018 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 30 or /e_36r1/main/06bc/fc/model eq complete) and ( ../015/backupprod eq complete or ../015/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../015/derived_param:SMOS or ../015/derived_param eq complete) or ( ../015/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '018'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 021
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 021 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 33 or /e_36r1/main/06bc/fc/model eq complete) and ( ../018/backupprod eq complete or ../018/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../018/derived_param:SMOS or ../018/derived_param eq complete) or ( ../018/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '021'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 024
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 024 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 36 or /e_36r1/main/06bc/fc/model eq complete) and ( ../021/backupprod eq complete or ../021/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../021/derived_param:SMOS or ../021/derived_param eq complete) or ( ../021/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '024'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 027
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 027 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 39 or /e_36r1/main/06bc/fc/model eq complete) and ( ../024/backupprod eq complete or ../024/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../024/derived_param:SMOS or ../024/derived_param eq complete) or ( ../024/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '027'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 030
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 030 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 42 or /e_36r1/main/06bc/fc/model eq complete) and ( ../027/backupprod eq complete or ../027/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../027/derived_param:SMOS or ../027/derived_param eq complete) or ( ../027/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '030'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 033
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 033 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 45 or /e_36r1/main/06bc/fc/model eq complete) and ( ../030/backupprod eq complete or ../030/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../030/derived_param:SMOS or ../030/derived_param eq complete) or ( ../030/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '033'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 036
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 036 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0036'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 48 or /e_36r1/main/06bc/fc/model eq complete) and ( ../033/backupprod eq complete or ../033/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../033/derived_param:SMOS or ../033/derived_param eq complete) or ( ../033/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '036'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 039
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 039 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0039'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 51 or /e_36r1/main/06bc/fc/model eq complete) and ( ../036/backupprod eq complete or ../036/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../036/derived_param:SMOS or ../036/derived_param eq complete) or ( ../036/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '039'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 042
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 042 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0042'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 54 or /e_36r1/main/06bc/fc/model eq complete) and ( ../039/backupprod eq complete or ../039/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../039/derived_param:SMOS or ../039/derived_param eq complete) or ( ../039/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '042'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 045
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 045 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0045'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 57 or /e_36r1/main/06bc/fc/model eq complete) and ( ../042/backupprod eq complete or ../042/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../042/derived_param:SMOS or ../042/derived_param eq complete) or ( ../042/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '045'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 048
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 048 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0048'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 60 or /e_36r1/main/06bc/fc/model eq complete) and ( ../045/backupprod eq complete or ../045/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../045/derived_param:SMOS or ../045/derived_param eq complete) or ( ../045/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '048'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 051
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 051 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0051'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 63 or /e_36r1/main/06bc/fc/model eq complete) and ( ../048/backupprod eq complete or ../048/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../048/derived_param:SMOS or ../048/derived_param eq complete) or ( ../048/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '051'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 054
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 054 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0054'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 66 or /e_36r1/main/06bc/fc/model eq complete) and ( ../051/backupprod eq complete or ../051/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../051/derived_param:SMOS or ../051/derived_param eq complete) or ( ../051/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '054'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 057
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 057 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0057'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 69 or /e_36r1/main/06bc/fc/model eq complete) and ( ../054/backupprod eq complete or ../054/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../054/derived_param:SMOS or ../054/derived_param eq complete) or ( ../054/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '057'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 060
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 060 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0060'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 72 or /e_36r1/main/06bc/fc/model eq complete) and ( ../057/backupprod eq complete or ../057/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../057/derived_param:SMOS or ../057/derived_param eq complete) or ( ../057/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '060'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 063
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 063 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0063'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 75 or /e_36r1/main/06bc/fc/model eq complete) and ( ../060/backupprod eq complete or ../060/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../060/derived_param:SMOS or ../060/derived_param eq complete) or ( ../060/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '063'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 066
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 066 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0066'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 78 or /e_36r1/main/06bc/fc/model eq complete) and ( ../063/backupprod eq complete or ../063/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../063/derived_param:SMOS or ../063/derived_param eq complete) or ( ../063/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '066'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 069
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 069 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0069'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 81 or /e_36r1/main/06bc/fc/model eq complete) and ( ../066/backupprod eq complete or ../066/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../066/derived_param:SMOS or ../066/derived_param eq complete) or ( ../066/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '069'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 072
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 072 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0072'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 84 or /e_36r1/main/06bc/fc/model eq complete) and ( ../069/backupprod eq complete or ../069/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../069/derived_param:SMOS or ../069/derived_param eq complete) or ( ../069/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '072'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 075
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 075 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0075'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 87 or /e_36r1/main/06bc/fc/model eq complete) and ( ../072/backupprod eq complete or ../072/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../072/derived_param:SMOS or ../072/derived_param eq complete) or ( ../072/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '075'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 078
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 078 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0078'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task backupprod
+            late -s +00:05 -c +00:20
+            trigger ( /e_36r1/main/06bc/fc/model:step ge 90 or /e_36r1/main/06bc/fc/model eq complete) and ( ../075/backupprod eq complete or ../075/backupprod eq active)
+            edit PGNPES '16'
+            inlimit /e_36r1/limits:backupprod
+          task derived_param
+            trigger ( ../075/derived_param:SMOS or ../075/derived_param eq complete) or ( ../075/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '078'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 081
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 081 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0081'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../078/derived_param:SMOS or ../078/derived_param eq complete) or ( ../078/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '081'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 084
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 084 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0084'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../081/derived_param:SMOS or ../081/derived_param eq complete) or ( ../081/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '084'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 087
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 087 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0087'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../084/derived_param:SMOS or ../084/derived_param eq complete) or ( ../084/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '087'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+        family 090
+          trigger ( /e_36r1/main/06bc/fc/model:step ge 090 or /e_36r1/main/06bc/fc/model eq complete) and 0 eq 0
+          edit EMOS_TIME_STEP_H '0090'
+          task prodgen
+            late -s +00:05 -c +00:15
+            trigger ./derived_param:SMOS or ./derived_param eq complete
+            edit USER_PRIORITY '92'
+            inlimit /e_36r1/limits:prod
+            inlimit /e_36r1/limits:prod_bc2
+          task derived_param
+            trigger ( ../087/derived_param:SMOS or ../087/derived_param eq complete) or ( ../087/derived_param eq aborted)
+            edit MEMBER 'off'
+            edit STEPS '090'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/mc/fc'
+            event SMOS
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/prod'
+        task operation_is_late
+          event yes
+        family oper
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'fc'
+          edit FSFAMILY 'ppdi'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '92'
+          edit SMSURL 'GSCDA/06'
+          edit EMOS_PROJECT '12'
+          family an
+            task pdb
+              trigger ../../../prod/an/prodgen eq complete
+              edit EMOS_TYPE 'an'
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit EMOS_TYPE 'an'
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../090/q2diss eq complete and ../../../prod/an/backupprod eq complete
+              edit EMOS_TYPE 'an'
+              label info ""
+              event 1 
+          endfamily
+          family 000
+            edit EMOS_TIME_STEP_H '0000'
+            task pdb
+              trigger ../../../prod/000/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ../an/q2diss eq complete
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 003
+            edit EMOS_TIME_STEP_H '0003'
+            task pdb
+              trigger ../../../prod/003/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../000/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/003/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 006
+            edit EMOS_TIME_STEP_H '0006'
+            task pdb
+              trigger ../../../prod/006/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../003/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/006/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 009
+            edit EMOS_TIME_STEP_H '0009'
+            task pdb
+              trigger ../../../prod/009/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../006/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/009/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 012
+            edit EMOS_TIME_STEP_H '0012'
+            task pdb
+              trigger ../../../prod/012/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../009/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/012/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 015
+            edit EMOS_TIME_STEP_H '0015'
+            task pdb
+              trigger ../../../prod/015/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../012/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/015/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 018
+            edit EMOS_TIME_STEP_H '0018'
+            task pdb
+              trigger ../../../prod/018/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../015/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/018/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 021
+            edit EMOS_TIME_STEP_H '0021'
+            task pdb
+              trigger ../../../prod/021/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../018/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/021/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 024
+            edit EMOS_TIME_STEP_H '0024'
+            task pdb
+              trigger ../../../prod/024/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../021/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/024/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 027
+            edit EMOS_TIME_STEP_H '0027'
+            task pdb
+              trigger ../../../prod/027/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../024/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/027/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 030
+            edit EMOS_TIME_STEP_H '0030'
+            task pdb
+              trigger ../../../prod/030/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../027/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/030/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 033
+            edit EMOS_TIME_STEP_H '0033'
+            task pdb
+              trigger ../../../prod/033/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../030/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/033/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 036
+            edit EMOS_TIME_STEP_H '0036'
+            task pdb
+              trigger ../../../prod/036/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../033/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/036/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 039
+            edit EMOS_TIME_STEP_H '0039'
+            task pdb
+              trigger ../../../prod/039/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../036/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/039/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 042
+            edit EMOS_TIME_STEP_H '0042'
+            task pdb
+              trigger ../../../prod/042/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../039/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/042/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 045
+            edit EMOS_TIME_STEP_H '0045'
+            task pdb
+              trigger ../../../prod/045/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../042/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/045/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 048
+            edit EMOS_TIME_STEP_H '0048'
+            task pdb
+              trigger ../../../prod/048/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../045/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/048/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 051
+            edit EMOS_TIME_STEP_H '0051'
+            task pdb
+              trigger ../../../prod/051/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../048/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/051/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 054
+            edit EMOS_TIME_STEP_H '0054'
+            task pdb
+              trigger ../../../prod/054/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../051/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/054/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 057
+            edit EMOS_TIME_STEP_H '0057'
+            task pdb
+              trigger ../../../prod/057/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../054/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/057/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 060
+            edit EMOS_TIME_STEP_H '0060'
+            task pdb
+              trigger ../../../prod/060/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../057/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/060/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 063
+            edit EMOS_TIME_STEP_H '0063'
+            task pdb
+              trigger ../../../prod/063/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../060/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/063/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 066
+            edit EMOS_TIME_STEP_H '0066'
+            task pdb
+              trigger ../../../prod/066/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../063/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/066/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 069
+            edit EMOS_TIME_STEP_H '0069'
+            task pdb
+              trigger ../../../prod/069/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../066/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/069/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 072
+            edit EMOS_TIME_STEP_H '0072'
+            task pdb
+              trigger ../../../prod/072/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../069/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/072/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 075
+            edit EMOS_TIME_STEP_H '0075'
+            task pdb
+              trigger ../../../prod/075/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../072/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/075/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 078
+            edit EMOS_TIME_STEP_H '0078'
+            task pdb
+              trigger ../../../prod/078/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../075/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+            task dissbackup
+              late -s +00:05 -c +00:15
+              trigger ../../../prod/078/backupprod eq complete
+              inlimit /e_36r1/limits:dissbackup
+              label info ""
+              event 1 
+          endfamily
+          family 081
+            edit EMOS_TIME_STEP_H '0081'
+            task pdb
+              trigger ../../../prod/081/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../078/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 084
+            edit EMOS_TIME_STEP_H '0084'
+            task pdb
+              trigger ../../../prod/084/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../081/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 087
+            edit EMOS_TIME_STEP_H '0087'
+            task pdb
+              trigger ../../../prod/087/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../084/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          family 090
+            edit EMOS_TIME_STEP_H '0090'
+            task pdb
+              trigger ../../../prod/090/prodgen eq complete
+              inlimit /e_36r1/limits:pdb_bc
+              inlimit /limits:pdb_bc
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete and ( not ../../../prod2diss/operation_is_late:yes or ../087/q2diss eq complete)
+              edit USER_PRIORITY '93'
+              inlimit /e_36r1/limits:q2diss_bc
+              inlimit /limits:q2diss_bc
+              label info ""
+              event 1 
+          endfamily
+          task check
+            trigger ./078 eq complete
+        endfamily
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'main'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger make eq complete and ./00dc eq complete and ./06 eq complete and ./12 eq complete and ./12dc eq complete and ./18 eq complete and ./00 eq complete and ./12bc eq complete and ./18bc eq complete and ./00bc eq complete and ./06bc eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'main'
+      edit MOVE_TO_ECFS 'no'
+      time 12:00
+  endfamily
+  family lag
+    repeat date YMD 20091118 20121212 1
+    edit MARS_DB 'marsod'
+    family 00dc
+      edit EMOS_BASE '00'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      family ddh
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/fc eq complete)
+        edit EMOS_BASE '06'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
+        task ddh
+      endfamily
+      family sync
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/an eq complete)
+        edit EMOS_TYPE 'an'
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
+        task dcda_to_da_bk
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit OPHOST 'c1b'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_satmon
+          trigger ../satmon eq complete
+        task sync_bias
+        task sync_fc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00dc/fc/model:step gt 6 or /e_36r1/main/00dc/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit EMOS_BASE '06'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_an
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit EMOS_BASE '06'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00dc/fc/model:step gt 3 or /e_36r1/main/00dc/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit EMOS_BASE '06'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_clean
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+      endfamily
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/00dc/an eq complete and ( ../../main/00dc/fc/model:step ge 15 or ../../main/00dc/fc/model eq complete))
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task sp2fdb
+          edit STEPS '3/6/9/12/18'
+          label files ""
+          label info ""
+          event fdb
+        task ansfc
+          trigger sp2fdb eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '15'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ./ansfc eq complete
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00dc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/00dc/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc015
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/fc/model:step ge 21 or /e_36r1/main/00dc/fc/model eq complete)
+          edit STEPS '3/6/9/12/15'
+          edit EMOS_BASE '06'
+          edit EMOS_TYPE 'fc'
+          task sp2fdb
+            label files ""
+            label info ""
+            event fdb
+          task fcsfc
+            trigger sp2fdb eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/fc/model eq complete)
+          edit STEPS_SPECTRAL '6/12'
+          edit EMOS_BASE '06'
+          edit STEPS '0/3/6/9/12/15'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00dc/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'oedcdaan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00dc/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      family traj
+        task feed
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00dc/fc eq complete)
+        task cp_to_other
+          trigger feed eq complete
+      endfamily
+      family satmon
+        edit FSFAMILY 'an'
+        inlimit /e_36r1/limits:smon
+        task getsmon
+          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
+        task smon_meris
+          trigger getsmon eq complete
+          edit smon_smsmode 'MERIS'
+        task smon_amsre
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMSRE'
+        task smon_ssmis
+          trigger getsmon eq complete
+          edit smon_smsmode 'SSMIS'
+        task smon_tmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'TMI'
+        task smon_gpsro
+          trigger getsmon eq complete
+          edit smon_smsmode 'GPSRO'
+        task smon_pacrars
+          trigger getsmon eq complete
+          edit smon_smsmode 'PACRARS'
+        task smon_ears
+          trigger getsmon eq complete
+          edit smon_smsmode 'EARS'
+        task smon_o3msg
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3MSG'
+        task smon_o3knmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3KNMI'
+        task smon_pwc
+          trigger getsmon eq complete
+          edit smon_smsmode 'PWC'
+        task smon_temp
+          trigger getsmon eq complete
+          edit smon_smsmode 'TEMP'
+        task smon_iasi
+          trigger getsmon eq complete
+          edit smon_smsmode 'IASI'
+        task smon_airs
+          trigger getsmon eq complete
+          edit smon_smsmode 'AIRS'
+        task smon_dbamv
+          trigger getsmon eq complete
+          edit smon_smsmode 'DBAMV'
+        task smon_amv
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMV'
+        task smon_o3
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3'
+        task smon_dmsp
+          trigger getsmon eq complete
+          edit smon_smsmode 'DMSP'
+        task smon_noaa
+          trigger getsmon eq complete
+          edit smon_smsmode 'NOAA'
+        task smon_geos
+          trigger getsmon eq complete
+          edit smon_smsmode 'GEOS'
+        task smon_scatt
+          trigger getsmon eq complete
+          edit smon_smsmode 'SCATT'
+        task smon_slmoist
+          trigger getsmon eq complete
+          edit smon_smsmode 'SLMOIST'
+        task smon_clean
+          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
+      endfamily
+      task clean
+        trigger fb eq complete and satmon eq complete
+        edit FSFAMILY 'an'
+      task cleanplus6
+        trigger clean eq complete
+        edit EMOS_BASE '06'
+        edit FSFAMILY 'an'
+      family verif
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
+        edit DELTA_DAY '1'
+        inlimit /limits:linux_cluster
+        family fc
+          task v12li1
+          task v12li2
+          task v12up1
+            trigger v12li1 eq complete
+          task v12up2
+            trigger v12up1 eq complete and v12li2 eq complete
+          task v12pl
+            trigger v12up2 eq complete
+          task v12memv
+            trigger v12up2 eq complete
+            edit DATEMASK '02.*.*'
+          task v12memb
+            trigger v12up2 eq complete
+            edit DATEMASK '11.*.*'
+          task v12upmv
+            trigger v12memv eq complete
+            edit DATEMASK '02.*.*'
+          task v12upmb
+            trigger v12memb eq complete
+            edit DATEMASK '11.*.*'
+          task v12crmv
+            edit DATEMASK '28.*.*'
+          task v12crmb
+            edit DATEMASK '28.*.*'
+          task v12crd
+            edit DATEMASK '28.*.*'
+        endfamily
+        family oc
+          trigger ./fc eq complete or ./fc eq aborted
+          task mk_dummy_fields
+            edit QUEUE 'emos'
+            edit USER 'emos'
+            edit PP_BASE '/pp1'
+            edit WSHOST 'pp1'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit LOGDIR '/pp1/log'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit SMSOUT '/vol/emos_nc/output'
+          task insert_fields
+            trigger mk_dummy_fields eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit PP_BASE '/pp1'
+            inlimit /limits:linux_cluster
+          task vbrli1
+            trigger insert_fields eq complete
+          task vbrli2
+            trigger vbrli1 eq complete
+          task vwali1
+            trigger insert_fields eq complete
+          task vwali2
+            trigger vwali1 eq complete
+          task vwali3
+            trigger vwali2 eq complete
+          task vofli
+            trigger insert_fields eq complete
+          task vtlli
+            trigger insert_fields eq complete
+          task vtoli
+            trigger insert_fields eq complete
+          task vmoli
+            trigger insert_fields eq complete
+          task vbrup1
+            trigger vbrli1 eq complete
+          task vbrup2
+            trigger vbrup1 eq complete and vbrli2 eq complete
+          task vwaup1
+            trigger vwali1 eq complete
+          task vwaup2
+            trigger vwaup1 eq complete and vwali2 eq complete
+          task vwaup3
+            trigger vwaup2 eq complete and vwali3 eq complete
+          task vofup
+            trigger vofli eq complete
+          task vtlup
+            trigger vtlli eq complete
+          task vtoup
+            trigger vtoli eq complete
+          task vmoup
+            trigger vmoli eq complete
+          task vmeli
+            trigger insert_fields eq complete
+          task vmeup
+            trigger vmeli eq complete
+          task voccrd
+            edit DATEMASK '28.*.*'
+          task voccrm
+            edit DATEMASK '28.*.*'
+          task vocmem
+            edit DATEMASK '11.*.*'
+          task vocupm
+            trigger vocmem eq complete
+            edit DATEMASK '11.*.*'
+          task cleanup
+            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+        endfamily
+        family cf
+          trigger oc eq complete or oc eq aborted
+          task vcnli1
+            late -c +02:00
+          task vcnli2
+          task vcnup1
+            trigger vcnli1 eq complete
+          task vcnup2
+            trigger vcnup1 eq complete and vcnli2 eq complete
+          task vcnpl
+            trigger vcnup2 eq complete
+          task vcncrd
+          task vcncrm
+            edit DATEMASK '28.*.*'
+          task vcnmem
+            trigger vcnup2 eq complete
+            edit DATEMASK '11.*.*'
+          task vcnupm
+            trigger vcnmem eq complete
+            edit DATEMASK '11.*.*'
+          task vcnli3
+          task vcnli4
+          task vcnup3
+            trigger vcnup2 eq complete and vcnli3 eq complete
+          task vcnup4
+            trigger vcnup3 eq complete and vcnli4 eq complete
+          task vcnmem2
+            trigger vcnup4 eq complete
+            edit DATEMASK '22.*.*'
+          task vcnupm2
+            trigger vcnmem2 eq complete
+            edit DATEMASK '22.*.*'
+        endfamily
+        family ob
+          trigger oc eq complete or oc eq aborted
+          time 05:00
+          family stage1
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          family stage2
+            trigger ./stage1 eq complete
+            edit EMOS_BASE '00'
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          task vobcrd
+            edit DATEMASK '28.*.*'
+          task vobcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family em
+          task vemli
+            late -c +02:00
+          task vemup
+            trigger vemli eq complete
+          task vemcrd
+            edit DATEMASK '28.*.*'
+          task vemcrm
+            edit DATEMASK '28.*.*'
+          task vemmem
+            trigger vemup eq complete
+            edit DATEMASK '11.*.*'
+          task vemupm
+            trigger vemmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family es
+          trigger em eq complete
+          task vesli
+            late -c +02:00
+          task vesup
+            trigger vesli eq complete
+          task vescrd
+            edit DATEMASK '28.*.*'
+          task vescrm
+            edit DATEMASK '28.*.*'
+          task vesmem
+            trigger vesup eq complete
+            edit DATEMASK '11.*.*'
+          task vesupm
+            trigger vesmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family cv
+          trigger es eq complete
+          task vcvli
+            late -c +02:00
+          task vcvup
+            trigger vcvli eq complete
+          task vcvcrd
+            edit DATEMASK '28.*.*'
+          task vcvcrm
+            edit DATEMASK '28.*.*'
+          task vcvmem
+            trigger vcvup eq complete
+            edit DATEMASK '11.*.*'
+          task vcvupm
+            trigger vcvmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00dc/fc/model eq complete)
+          task glver
+          task glupr
+            trigger glver eq complete
+          task glcrr
+            edit DATEMASK '28.*.*'
+          task ff10ver
+            trigger glver eq complete
+          task ff10upr
+            trigger ff10ver eq complete and glupr eq complete
+          task glmem
+            trigger ff10upr eq complete
+            edit DATEMASK '11.*.*'
+          task glupm
+            trigger glmem eq complete
+            edit DATEMASK '11.*.*'
+          task glcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family sf
+          trigger fc eq complete or fc eq aborted
+          task vseli1
+          task vseli2
+          task vseup1
+            trigger vseli1 eq complete
+          task vseup2
+            trigger vseup1 eq complete and vseli2 eq complete
+          task vsecrd
+            edit DATEMASK '28.*.*'
+          task vsecrm
+            edit DATEMASK '28.*.*'
+          task vsemem
+            trigger vseup2 eq complete
+            edit DATEMASK '12.*.*'
+          task vseupm
+            trigger vsemem eq complete
+            edit DATEMASK '12.*.*'
+        endfamily
+      endfamily
+    endfamily
+    family 06
+      edit EMOS_BASE '06'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DA'
+      edit LAR_4V_EF 'false'
+      edit LFC_DIR_FREQ 'false'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/12/prod/06an eq complete)
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task ansfc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod/06an/derived_param eq complete))
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '6'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod/06an/derived_param eq complete))
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task highres
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/06/an/4dvar/ifstraj:finaltraj or /e_36r1/main/06/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc015
+          edit STEPS '3/6/9/12/15'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06/fc/model eq complete)
+          edit STEPS '0/3/6/9/12/15'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'oeoperan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      family traj
+        task feed
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06/fc eq complete)
+        task cp_to_other
+          trigger feed eq complete
+      endfamily
+      family satmon
+        trigger ../00dc/satmon eq complete
+        edit FSFAMILY 'an'
+        inlimit /e_36r1/limits:smon
+        task getsmon
+          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
+        task smon_meris
+          trigger getsmon eq complete
+          edit smon_smsmode 'MERIS'
+        task smon_amsre
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMSRE'
+        task smon_ssmis
+          trigger getsmon eq complete
+          edit smon_smsmode 'SSMIS'
+        task smon_tmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'TMI'
+        task smon_gpsro
+          trigger getsmon eq complete
+          edit smon_smsmode 'GPSRO'
+        task smon_pacrars
+          trigger getsmon eq complete
+          edit smon_smsmode 'PACRARS'
+        task smon_ears
+          trigger getsmon eq complete
+          edit smon_smsmode 'EARS'
+        task smon_o3msg
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3MSG'
+        task smon_o3knmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3KNMI'
+        task smon_pwc
+          trigger getsmon eq complete
+          edit smon_smsmode 'PWC'
+        task smon_temp
+          trigger getsmon eq complete
+          edit smon_smsmode 'TEMP'
+        task smon_iasi
+          trigger getsmon eq complete
+          edit smon_smsmode 'IASI'
+        task smon_airs
+          trigger getsmon eq complete
+          edit smon_smsmode 'AIRS'
+        task smon_dbamv
+          trigger getsmon eq complete
+          edit smon_smsmode 'DBAMV'
+        task smon_amv
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMV'
+        task smon_o3
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3'
+        task smon_dmsp
+          trigger getsmon eq complete
+          edit smon_smsmode 'DMSP'
+        task smon_noaa
+          trigger getsmon eq complete
+          edit smon_smsmode 'NOAA'
+        task smon_geos
+          trigger getsmon eq complete
+          edit smon_smsmode 'GEOS'
+        task smon_scatt
+          trigger getsmon eq complete
+          edit smon_smsmode 'SCATT'
+        task smon_slmoist
+          trigger getsmon eq complete
+          edit smon_smsmode 'SLMOIST'
+        task smon_clean
+          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
+      endfamily
+      task clean
+        trigger fb eq complete and ../00dc/clean eq complete
+        edit FSFAMILY 'an'
+      family verif
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
+        edit DELTA_DAY '1'
+        inlimit /limits:linux_cluster
+        family fc
+          task v12li1
+          task v12li2
+          task v12up1
+            trigger v12li1 eq complete
+          task v12up2
+            trigger v12up1 eq complete and v12li2 eq complete
+          task v12pl
+            trigger v12up2 eq complete
+          task v12memv
+            trigger v12up2 eq complete
+            edit DATEMASK '02.*.*'
+          task v12memb
+            trigger v12up2 eq complete
+            edit DATEMASK '11.*.*'
+          task v12upmv
+            trigger v12memv eq complete
+            edit DATEMASK '02.*.*'
+          task v12upmb
+            trigger v12memb eq complete
+            edit DATEMASK '11.*.*'
+          task v12crmv
+            edit DATEMASK '28.*.*'
+          task v12crmb
+            edit DATEMASK '28.*.*'
+          task v12crd
+            edit DATEMASK '28.*.*'
+        endfamily
+        family oc
+          trigger ./fc eq complete or ./fc eq aborted
+          task mk_dummy_fields
+            edit QUEUE 'emos'
+            edit USER 'emos'
+            edit PP_BASE '/pp1'
+            edit WSHOST 'pp1'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit LOGDIR '/pp1/log'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit SMSOUT '/vol/emos_nc/output'
+          task insert_fields
+            trigger mk_dummy_fields eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit PP_BASE '/pp1'
+            inlimit /limits:linux_cluster
+          task vbrli1
+            trigger insert_fields eq complete
+          task vbrli2
+            trigger vbrli1 eq complete
+          task vwali1
+            trigger insert_fields eq complete
+          task vwali2
+            trigger vwali1 eq complete
+          task vwali3
+            trigger vwali2 eq complete
+          task vofli
+            trigger insert_fields eq complete
+          task vtlli
+            trigger insert_fields eq complete
+          task vtoli
+            trigger insert_fields eq complete
+          task vmoli
+            trigger insert_fields eq complete
+          task vbrup1
+            trigger vbrli1 eq complete
+          task vbrup2
+            trigger vbrup1 eq complete and vbrli2 eq complete
+          task vwaup1
+            trigger vwali1 eq complete
+          task vwaup2
+            trigger vwaup1 eq complete and vwali2 eq complete
+          task vwaup3
+            trigger vwaup2 eq complete and vwali3 eq complete
+          task vofup
+            trigger vofli eq complete
+          task vtlup
+            trigger vtlli eq complete
+          task vtoup
+            trigger vtoli eq complete
+          task vmoup
+            trigger vmoli eq complete
+          task vmeli
+            trigger insert_fields eq complete
+          task vmeup
+            trigger vmeli eq complete
+          task voccrd
+            edit DATEMASK '28.*.*'
+          task voccrm
+            edit DATEMASK '28.*.*'
+          task vocmem
+            edit DATEMASK '11.*.*'
+          task vocupm
+            trigger vocmem eq complete
+            edit DATEMASK '11.*.*'
+          task cleanup
+            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+        endfamily
+        family cf
+          trigger oc eq complete or oc eq aborted
+          task vcnli1
+            late -c +02:00
+          task vcnli2
+          task vcnup1
+            trigger vcnli1 eq complete
+          task vcnup2
+            trigger vcnup1 eq complete and vcnli2 eq complete
+          task vcnpl
+            trigger vcnup2 eq complete
+          task vcncrd
+          task vcncrm
+            edit DATEMASK '28.*.*'
+          task vcnmem
+            trigger vcnup2 eq complete
+            edit DATEMASK '11.*.*'
+          task vcnupm
+            trigger vcnmem eq complete
+            edit DATEMASK '11.*.*'
+          task vcnli3
+          task vcnli4
+          task vcnup3
+            trigger vcnup2 eq complete and vcnli3 eq complete
+          task vcnup4
+            trigger vcnup3 eq complete and vcnli4 eq complete
+          task vcnmem2
+            trigger vcnup4 eq complete
+            edit DATEMASK '22.*.*'
+          task vcnupm2
+            trigger vcnmem2 eq complete
+            edit DATEMASK '22.*.*'
+        endfamily
+        family ob
+          trigger oc eq complete or oc eq aborted
+          time 05:00
+          family stage1
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          family stage2
+            trigger ./stage1 eq complete
+            edit EMOS_BASE '00'
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          task vobcrd
+            edit DATEMASK '28.*.*'
+          task vobcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family em
+          task vemli
+            late -c +02:00
+          task vemup
+            trigger vemli eq complete
+          task vemcrd
+            edit DATEMASK '28.*.*'
+          task vemcrm
+            edit DATEMASK '28.*.*'
+          task vemmem
+            trigger vemup eq complete
+            edit DATEMASK '11.*.*'
+          task vemupm
+            trigger vemmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family es
+          trigger em eq complete
+          task vesli
+            late -c +02:00
+          task vesup
+            trigger vesli eq complete
+          task vescrd
+            edit DATEMASK '28.*.*'
+          task vescrm
+            edit DATEMASK '28.*.*'
+          task vesmem
+            trigger vesup eq complete
+            edit DATEMASK '11.*.*'
+          task vesupm
+            trigger vesmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family cv
+          trigger es eq complete
+          task vcvli
+            late -c +02:00
+          task vcvup
+            trigger vcvli eq complete
+          task vcvcrd
+            edit DATEMASK '28.*.*'
+          task vcvcrm
+            edit DATEMASK '28.*.*'
+          task vcvmem
+            trigger vcvup eq complete
+            edit DATEMASK '11.*.*'
+          task vcvupm
+            trigger vcvmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06/fc/model eq complete)
+          task glver
+          task glupr
+            trigger glver eq complete
+          task glcrr
+            edit DATEMASK '28.*.*'
+          task ff10ver
+            trigger glver eq complete
+          task ff10upr
+            trigger ff10ver eq complete and glupr eq complete
+          task glmem
+            trigger ff10upr eq complete
+            edit DATEMASK '11.*.*'
+          task glupm
+            trigger glmem eq complete
+            edit DATEMASK '11.*.*'
+          task glcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family sf
+          trigger fc eq complete or fc eq aborted
+          task vseli1
+          task vseli2
+          task vseup1
+            trigger vseli1 eq complete
+          task vseup2
+            trigger vseup1 eq complete and vseli2 eq complete
+          task vsecrd
+            edit DATEMASK '28.*.*'
+          task vsecrm
+            edit DATEMASK '28.*.*'
+          task vsemem
+            trigger vseup2 eq complete
+            edit DATEMASK '12.*.*'
+          task vseupm
+            trigger vsemem eq complete
+            edit DATEMASK '12.*.*'
+        endfamily
+      endfamily
+    endfamily
+    family 12
+      edit EMOS_BASE '12'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      family ddh
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/fc eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
+        task ddh
+      endfamily
+      family sync
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/an eq complete)
+        edit EMOS_TYPE 'an'
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
+        task sync_bias
+          edit CALC_PSBIAS 'false'
+        task sync_fc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/fc/model:step gt 6 or /e_36r1/main/12/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_an
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/fc/model:step gt 3 or /e_36r1/main/12/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_clean
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+      endfamily
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/12/an eq complete and ( ../../main/12/fc/model:step ge 9 or ../../main/12/fc/model eq complete))
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task ansfc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/000 eq complete and /e_36r1/main/12/prod/12an eq complete)
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '240'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ./ansfc eq complete
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/an/4dvar/ifstraj:finaltraj or /e_36r1/main/12/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc024
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/024 eq complete)
+          edit STEPS '0/3/006/009/012/015/018/021/024'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc048
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/048 eq complete)
+          edit STEPS '027/030/033/036/039/042/045/048'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc072
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/072 eq complete)
+          edit STEPS '051/054/057/060/063/066/069/072'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc096
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/096 eq complete)
+          edit STEPS '075/078/081/084/087/090/093/096'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc120
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/120 eq complete)
+          edit STEPS '099/102/105/108/111/114/117/120'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc144
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/144 eq complete)
+          edit STEPS '123/126/129/132/135/138/141/144'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc192
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/192 eq complete)
+          edit STEPS '150/156/162/168/174/180/186/192'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc240
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/prod/240 eq complete)
+          edit STEPS '198/204/210/216/222/228/234/240'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family satim1
+          task satim
+            trigger ../../satim eq complete
+            edit STEPS '0/to/48/by/3'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family satim2
+          task satim
+            trigger ../../satim eq complete
+            edit STEPS '54/to/120/by/6'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/fc/model eq complete)
+          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
+          edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task rmfdb
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/obs eq complete)
+        task flush
+          edit STREAM 'oper'
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'oeoperan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      family traj
+        task feed
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12/fc eq complete)
+        task cp_to_other
+          trigger feed eq complete
+      endfamily
+      family satim
+        edit QUEUE 'ns'
+        edit QUEUE_EPILOG 'ns'
+        edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+        edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+        edit MEM '11000'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+        edit SMSURLBASE 'http://intra.ecmwf.int/publications/cms/get/metapps'
+        inlimit /limits:c1b
+        task display_seaice
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/an eq complete)
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/admin'
+          edit FSFAMILY 'undef'
+          edit METVIEW 'metview_emos'
+          edit SMSURL 'seaice'
+          inlimit /limits:linux_cluster
+        task display_sst
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FSFAMILY 'undef'
+          edit SMSURL 'sst'
+          inlimit /limits:linux_cluster
+        family satim_0
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '0'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_3
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '3'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_6
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '6'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_9
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '9'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_12
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '12'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_15
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '15'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_18
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '18'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_21
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '21'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_24
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '24'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_27
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '27'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_30
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '30'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_33
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '33'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_36
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '36'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_39
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '39'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_42
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '42'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_45
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '45'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_48
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '48'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_54
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '54'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_60
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '60'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_66
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '66'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_72
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '72'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_78
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '78'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_84
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '84'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_90
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '90'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_96
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '96'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_102
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '102'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_108
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '108'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_114
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '114'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_120
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12/prod eq complete))
+          edit IMAGETIME '120'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+      endfamily
+      family satmon
+        trigger ../00dc/satmon eq complete
+        edit FSFAMILY 'an'
+        inlimit /e_36r1/limits:smon
+        task getsmon
+          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
+        task smon_meris
+          trigger getsmon eq complete
+          edit smon_smsmode 'MERIS'
+        task smon_amsre
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMSRE'
+        task smon_ssmis
+          trigger getsmon eq complete
+          edit smon_smsmode 'SSMIS'
+        task smon_tmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'TMI'
+        task smon_gpsro
+          trigger getsmon eq complete
+          edit smon_smsmode 'GPSRO'
+        task smon_pacrars
+          trigger getsmon eq complete
+          edit smon_smsmode 'PACRARS'
+        task smon_ears
+          trigger getsmon eq complete
+          edit smon_smsmode 'EARS'
+        task smon_o3msg
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3MSG'
+        task smon_o3knmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3KNMI'
+        task smon_pwc
+          trigger getsmon eq complete
+          edit smon_smsmode 'PWC'
+        task smon_temp
+          trigger getsmon eq complete
+          edit smon_smsmode 'TEMP'
+        task smon_iasi
+          trigger getsmon eq complete
+          edit smon_smsmode 'IASI'
+        task smon_airs
+          trigger getsmon eq complete
+          edit smon_smsmode 'AIRS'
+        task smon_dbamv
+          trigger getsmon eq complete
+          edit smon_smsmode 'DBAMV'
+        task smon_amv
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMV'
+        task smon_o3
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3'
+        task smon_dmsp
+          trigger getsmon eq complete
+          edit smon_smsmode 'DMSP'
+        task smon_noaa
+          trigger getsmon eq complete
+          edit smon_smsmode 'NOAA'
+        task smon_geos
+          trigger getsmon eq complete
+          edit smon_smsmode 'GEOS'
+        task smon_scatt
+          trigger getsmon eq complete
+          edit smon_smsmode 'SCATT'
+        task smon_slmoist
+          trigger getsmon eq complete
+          edit smon_smsmode 'SLMOIST'
+        task smon_clean
+          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
+      endfamily
+      task clean
+        trigger fb eq complete and ../06/clean eq complete
+        edit FSFAMILY 'an'
+      family verif
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
+        edit DELTA_DAY '1'
+        inlimit /limits:linux_cluster
+        time 02:00
+        family fc
+          task v12li1
+          task v12li2
+          task v12up1
+            trigger v12li1 eq complete
+          task v12up2
+            trigger v12up1 eq complete and v12li2 eq complete
+          task v12pl
+            trigger v12up2 eq complete
+          task v12memv
+            trigger v12up2 eq complete
+            edit DATEMASK '02.*.*'
+          task v12memb
+            trigger v12up2 eq complete
+            edit DATEMASK '11.*.*'
+          task v12upmv
+            trigger v12memv eq complete
+            edit DATEMASK '02.*.*'
+          task v12upmb
+            trigger v12memb eq complete
+            edit DATEMASK '11.*.*'
+          task v12crmv
+            edit DATEMASK '28.*.*'
+          task v12crmb
+            edit DATEMASK '28.*.*'
+          task v12crd
+            edit DATEMASK '28.*.*'
+        endfamily
+        family oc
+          trigger ./fc eq complete or ./fc eq aborted
+          task mk_dummy_fields
+            edit QUEUE 'emos'
+            edit USER 'emos'
+            edit PP_BASE '/pp1'
+            edit WSHOST 'pp1'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit LOGDIR '/pp1/log'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit SMSOUT '/vol/emos_nc/output'
+          task insert_fields
+            trigger mk_dummy_fields eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit PP_BASE '/pp1'
+            inlimit /limits:linux_cluster
+          task vbrli1
+            trigger insert_fields eq complete
+          task vbrli2
+            trigger vbrli1 eq complete
+          task vwali1
+            trigger insert_fields eq complete
+          task vwali2
+            trigger vwali1 eq complete
+          task vwali3
+            trigger vwali2 eq complete
+          task vofli
+            trigger insert_fields eq complete
+          task vtlli
+            trigger insert_fields eq complete
+          task vtoli
+            trigger insert_fields eq complete
+          task vmoli
+            trigger insert_fields eq complete
+          task vbrup1
+            trigger vbrli1 eq complete
+          task vbrup2
+            trigger vbrup1 eq complete and vbrli2 eq complete
+          task vwaup1
+            trigger vwali1 eq complete
+          task vwaup2
+            trigger vwaup1 eq complete and vwali2 eq complete
+          task vwaup3
+            trigger vwaup2 eq complete and vwali3 eq complete
+          task vofup
+            trigger vofli eq complete
+          task vtlup
+            trigger vtlli eq complete
+          task vtoup
+            trigger vtoli eq complete
+          task vmoup
+            trigger vmoli eq complete
+          task vmeli
+            trigger insert_fields eq complete
+          task vmeup
+            trigger vmeli eq complete
+          task voccrd
+            edit DATEMASK '28.*.*'
+          task voccrm
+            edit DATEMASK '28.*.*'
+          task vocmem
+            edit DATEMASK '11.*.*'
+          task vocupm
+            trigger vocmem eq complete
+            edit DATEMASK '11.*.*'
+          task cleanup
+            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+        endfamily
+        family cf
+          trigger oc eq complete or oc eq aborted
+          task vcnli1
+            late -c +02:00
+          task vcnli2
+          task vcnup1
+            trigger vcnli1 eq complete
+          task vcnup2
+            trigger vcnup1 eq complete and vcnli2 eq complete
+          task vcnpl
+            trigger vcnup2 eq complete
+          task vcncrd
+          task vcncrm
+            edit DATEMASK '28.*.*'
+          task vcnmem
+            trigger vcnup2 eq complete
+            edit DATEMASK '11.*.*'
+          task vcnupm
+            trigger vcnmem eq complete
+            edit DATEMASK '11.*.*'
+          task vcnli3
+          task vcnli4
+          task vcnup3
+            trigger vcnup2 eq complete and vcnli3 eq complete
+          task vcnup4
+            trigger vcnup3 eq complete and vcnli4 eq complete
+          task vcnmem2
+            trigger vcnup4 eq complete
+            edit DATEMASK '22.*.*'
+          task vcnupm2
+            trigger vcnmem2 eq complete
+            edit DATEMASK '22.*.*'
+        endfamily
+        family ob
+          trigger oc eq complete or oc eq aborted
+          time 05:00
+          family stage1
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          family stage2
+            trigger ./stage1 eq complete
+            edit EMOS_BASE '00'
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          task vobcrd
+            edit DATEMASK '28.*.*'
+          task vobcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family em
+          task vemli
+            late -c +02:00
+          task vemup
+            trigger vemli eq complete
+          task vemcrd
+            edit DATEMASK '28.*.*'
+          task vemcrm
+            edit DATEMASK '28.*.*'
+          task vemmem
+            trigger vemup eq complete
+            edit DATEMASK '11.*.*'
+          task vemupm
+            trigger vemmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family es
+          trigger em eq complete
+          task vesli
+            late -c +02:00
+          task vesup
+            trigger vesli eq complete
+          task vescrd
+            edit DATEMASK '28.*.*'
+          task vescrm
+            edit DATEMASK '28.*.*'
+          task vesmem
+            trigger vesup eq complete
+            edit DATEMASK '11.*.*'
+          task vesupm
+            trigger vesmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family cv
+          trigger es eq complete
+          task vcvli
+            late -c +02:00
+          task vcvup
+            trigger vcvli eq complete
+          task vcvcrd
+            edit DATEMASK '28.*.*'
+          task vcvcrm
+            edit DATEMASK '28.*.*'
+          task vcvmem
+            trigger vcvup eq complete
+            edit DATEMASK '11.*.*'
+          task vcvupm
+            trigger vcvmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12/fc/model eq complete)
+          task glver
+          task glupr
+            trigger glver eq complete
+          task glcrr
+            edit DATEMASK '28.*.*'
+          task ff10ver
+            trigger glver eq complete
+          task ff10upr
+            trigger ff10ver eq complete and glupr eq complete
+          task glmem
+            trigger ff10upr eq complete
+            edit DATEMASK '11.*.*'
+          task glupm
+            trigger glmem eq complete
+            edit DATEMASK '11.*.*'
+          task glcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family sf
+          trigger fc eq complete or fc eq aborted
+          task vseli1
+          task vseli2
+          task vseup1
+            trigger vseli1 eq complete
+          task vseup2
+            trigger vseup1 eq complete and vseli2 eq complete
+          task vsecrd
+            edit DATEMASK '28.*.*'
+          task vsecrm
+            edit DATEMASK '28.*.*'
+          task vsemem
+            trigger vseup2 eq complete
+            edit DATEMASK '12.*.*'
+          task vseupm
+            trigger vsemem eq complete
+            edit DATEMASK '12.*.*'
+        endfamily
+      endfamily
+    endfamily
+    family 12dc
+      edit EMOS_BASE '12'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      family ddh
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/fc eq complete)
+        edit EMOS_BASE '18'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
+        task ddh
+      endfamily
+      family sync
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/an eq complete)
+        edit EMOS_TYPE 'an'
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
+        task dcda_to_da_bk
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit OPHOST 'c1b'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/an'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_satmon
+          trigger ../satmon eq complete
+        task sync_bias
+        task sync_fc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12dc/fc/model:step gt 6 or /e_36r1/main/12dc/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit EMOS_BASE '18'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_an
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit EMOS_BASE '18'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12dc/fc/model:step gt 3 or /e_36r1/main/12dc/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          edit EMOS_BASE '18'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_clean
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+      endfamily
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/12dc/an eq complete and ( ../../main/12dc/fc/model:step ge 15 or ../../main/12dc/fc/model eq complete))
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task sp2fdb
+          edit STEPS '3/6/9/12/18'
+          label files ""
+          label info ""
+          event fdb
+        task ansfc
+          trigger sp2fdb eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '15'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ./ansfc eq complete
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/12dc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/12dc/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc015
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/fc/model:step ge 21 or /e_36r1/main/12dc/fc/model eq complete)
+          edit STEPS '3/6/9/12/15'
+          edit EMOS_BASE '18'
+          edit EMOS_TYPE 'fc'
+          task sp2fdb
+            label files ""
+            label info ""
+            event fdb
+          task fcsfc
+            trigger sp2fdb eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/fc/model eq complete)
+          edit STEPS_SPECTRAL '6/12'
+          edit EMOS_BASE '18'
+          edit STEPS '0/3/6/9/12/15'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task rmfdb
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/obs eq complete)
+        task flush
+          edit STREAM 'oper'
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12dc/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'oedcdaan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12dc/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      family traj
+        task feed
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12dc/fc eq complete)
+        task cp_to_other
+          trigger feed eq complete
+      endfamily
+      family satmon
+        trigger ../00dc/satmon eq complete
+        edit FSFAMILY 'an'
+        inlimit /e_36r1/limits:smon
+        task getsmon
+          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
+        task smon_meris
+          trigger getsmon eq complete
+          edit smon_smsmode 'MERIS'
+        task smon_amsre
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMSRE'
+        task smon_ssmis
+          trigger getsmon eq complete
+          edit smon_smsmode 'SSMIS'
+        task smon_tmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'TMI'
+        task smon_gpsro
+          trigger getsmon eq complete
+          edit smon_smsmode 'GPSRO'
+        task smon_pacrars
+          trigger getsmon eq complete
+          edit smon_smsmode 'PACRARS'
+        task smon_ears
+          trigger getsmon eq complete
+          edit smon_smsmode 'EARS'
+        task smon_o3msg
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3MSG'
+        task smon_o3knmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3KNMI'
+        task smon_pwc
+          trigger getsmon eq complete
+          edit smon_smsmode 'PWC'
+        task smon_temp
+          trigger getsmon eq complete
+          edit smon_smsmode 'TEMP'
+        task smon_iasi
+          trigger getsmon eq complete
+          edit smon_smsmode 'IASI'
+        task smon_airs
+          trigger getsmon eq complete
+          edit smon_smsmode 'AIRS'
+        task smon_dbamv
+          trigger getsmon eq complete
+          edit smon_smsmode 'DBAMV'
+        task smon_amv
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMV'
+        task smon_o3
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3'
+        task smon_dmsp
+          trigger getsmon eq complete
+          edit smon_smsmode 'DMSP'
+        task smon_noaa
+          trigger getsmon eq complete
+          edit smon_smsmode 'NOAA'
+        task smon_geos
+          trigger getsmon eq complete
+          edit smon_smsmode 'GEOS'
+        task smon_scatt
+          trigger getsmon eq complete
+          edit smon_smsmode 'SCATT'
+        task smon_slmoist
+          trigger getsmon eq complete
+          edit smon_smsmode 'SLMOIST'
+        task smon_clean
+          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
+      endfamily
+      task clean
+        trigger fb eq complete and ../12/clean eq complete
+        edit FSFAMILY 'an'
+      task cleanplus6
+        trigger clean eq complete
+        edit EMOS_BASE '18'
+        edit FSFAMILY 'an'
+      family verif
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
+        edit DELTA_DAY '1'
+        inlimit /limits:linux_cluster
+        family fc
+          task v12li1
+          task v12li2
+          task v12up1
+            trigger v12li1 eq complete
+          task v12up2
+            trigger v12up1 eq complete and v12li2 eq complete
+          task v12pl
+            trigger v12up2 eq complete
+          task v12memv
+            trigger v12up2 eq complete
+            edit DATEMASK '02.*.*'
+          task v12memb
+            trigger v12up2 eq complete
+            edit DATEMASK '11.*.*'
+          task v12upmv
+            trigger v12memv eq complete
+            edit DATEMASK '02.*.*'
+          task v12upmb
+            trigger v12memb eq complete
+            edit DATEMASK '11.*.*'
+          task v12crmv
+            edit DATEMASK '28.*.*'
+          task v12crmb
+            edit DATEMASK '28.*.*'
+          task v12crd
+            edit DATEMASK '28.*.*'
+        endfamily
+        family oc
+          trigger ./fc eq complete or ./fc eq aborted
+          task mk_dummy_fields
+            edit QUEUE 'emos'
+            edit USER 'emos'
+            edit PP_BASE '/pp1'
+            edit WSHOST 'pp1'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit LOGDIR '/pp1/log'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit SMSOUT '/vol/emos_nc/output'
+          task insert_fields
+            trigger mk_dummy_fields eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit PP_BASE '/pp1'
+            inlimit /limits:linux_cluster
+          task vbrli1
+            trigger insert_fields eq complete
+          task vbrli2
+            trigger vbrli1 eq complete
+          task vwali1
+            trigger insert_fields eq complete
+          task vwali2
+            trigger vwali1 eq complete
+          task vwali3
+            trigger vwali2 eq complete
+          task vofli
+            trigger insert_fields eq complete
+          task vtlli
+            trigger insert_fields eq complete
+          task vtoli
+            trigger insert_fields eq complete
+          task vmoli
+            trigger insert_fields eq complete
+          task vbrup1
+            trigger vbrli1 eq complete
+          task vbrup2
+            trigger vbrup1 eq complete and vbrli2 eq complete
+          task vwaup1
+            trigger vwali1 eq complete
+          task vwaup2
+            trigger vwaup1 eq complete and vwali2 eq complete
+          task vwaup3
+            trigger vwaup2 eq complete and vwali3 eq complete
+          task vofup
+            trigger vofli eq complete
+          task vtlup
+            trigger vtlli eq complete
+          task vtoup
+            trigger vtoli eq complete
+          task vmoup
+            trigger vmoli eq complete
+          task vmeli
+            trigger insert_fields eq complete
+          task vmeup
+            trigger vmeli eq complete
+          task voccrd
+            edit DATEMASK '28.*.*'
+          task voccrm
+            edit DATEMASK '28.*.*'
+          task vocmem
+            edit DATEMASK '11.*.*'
+          task vocupm
+            trigger vocmem eq complete
+            edit DATEMASK '11.*.*'
+          task cleanup
+            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+        endfamily
+        family cf
+          trigger oc eq complete or oc eq aborted
+          task vcnli1
+            late -c +02:00
+          task vcnli2
+          task vcnup1
+            trigger vcnli1 eq complete
+          task vcnup2
+            trigger vcnup1 eq complete and vcnli2 eq complete
+          task vcnpl
+            trigger vcnup2 eq complete
+          task vcncrd
+          task vcncrm
+            edit DATEMASK '28.*.*'
+          task vcnmem
+            trigger vcnup2 eq complete
+            edit DATEMASK '11.*.*'
+          task vcnupm
+            trigger vcnmem eq complete
+            edit DATEMASK '11.*.*'
+          task vcnli3
+          task vcnli4
+          task vcnup3
+            trigger vcnup2 eq complete and vcnli3 eq complete
+          task vcnup4
+            trigger vcnup3 eq complete and vcnli4 eq complete
+          task vcnmem2
+            trigger vcnup4 eq complete
+            edit DATEMASK '22.*.*'
+          task vcnupm2
+            trigger vcnmem2 eq complete
+            edit DATEMASK '22.*.*'
+        endfamily
+        family ob
+          trigger oc eq complete or oc eq aborted
+          time 05:00
+          family stage1
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          family stage2
+            trigger ./stage1 eq complete
+            edit EMOS_BASE '00'
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          task vobcrd
+            edit DATEMASK '28.*.*'
+          task vobcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family em
+          task vemli
+            late -c +02:00
+          task vemup
+            trigger vemli eq complete
+          task vemcrd
+            edit DATEMASK '28.*.*'
+          task vemcrm
+            edit DATEMASK '28.*.*'
+          task vemmem
+            trigger vemup eq complete
+            edit DATEMASK '11.*.*'
+          task vemupm
+            trigger vemmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family es
+          trigger em eq complete
+          task vesli
+            late -c +02:00
+          task vesup
+            trigger vesli eq complete
+          task vescrd
+            edit DATEMASK '28.*.*'
+          task vescrm
+            edit DATEMASK '28.*.*'
+          task vesmem
+            trigger vesup eq complete
+            edit DATEMASK '11.*.*'
+          task vesupm
+            trigger vesmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family cv
+          trigger es eq complete
+          task vcvli
+            late -c +02:00
+          task vcvup
+            trigger vcvli eq complete
+          task vcvcrd
+            edit DATEMASK '28.*.*'
+          task vcvcrm
+            edit DATEMASK '28.*.*'
+          task vcvmem
+            trigger vcvup eq complete
+            edit DATEMASK '11.*.*'
+          task vcvupm
+            trigger vcvmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/12dc/fc/model eq complete)
+          task glver
+          task glupr
+            trigger glver eq complete
+          task glcrr
+            edit DATEMASK '28.*.*'
+          task ff10ver
+            trigger glver eq complete
+          task ff10upr
+            trigger ff10ver eq complete and glupr eq complete
+          task glmem
+            trigger ff10upr eq complete
+            edit DATEMASK '11.*.*'
+          task glupm
+            trigger glmem eq complete
+            edit DATEMASK '11.*.*'
+          task glcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family sf
+          trigger fc eq complete or fc eq aborted
+          task vseli1
+          task vseli2
+          task vseup1
+            trigger vseli1 eq complete
+          task vseup2
+            trigger vseup1 eq complete and vseli2 eq complete
+          task vsecrd
+            edit DATEMASK '28.*.*'
+          task vsecrm
+            edit DATEMASK '28.*.*'
+          task vsemem
+            trigger vseup2 eq complete
+            edit DATEMASK '12.*.*'
+          task vseupm
+            trigger vsemem eq complete
+            edit DATEMASK '12.*.*'
+        endfamily
+      endfamily
+    endfamily
+    family 18
+      edit EMOS_BASE '18'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DA'
+      edit LAR_4V_EF 'false'
+      edit LFC_DIR_FREQ 'false'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/00/prod/18an eq complete)
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task ansfc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod/18an/derived_param eq complete))
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '6'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod/18an/derived_param eq complete))
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/18/an/4dvar/ifstraj:finaltraj or /e_36r1/main/18/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc015
+          edit STEPS '3/6/9/12/15'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18/fc/model eq complete)
+          edit STEPS '0/3/6/9/12/15'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'oeoperan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      family traj
+        task feed
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18/fc eq complete)
+        task cp_to_other
+          trigger feed eq complete
+      endfamily
+      family satmon
+        trigger ../00dc/satmon eq complete
+        edit FSFAMILY 'an'
+        inlimit /e_36r1/limits:smon
+        task getsmon
+          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
+        task smon_meris
+          trigger getsmon eq complete
+          edit smon_smsmode 'MERIS'
+        task smon_amsre
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMSRE'
+        task smon_ssmis
+          trigger getsmon eq complete
+          edit smon_smsmode 'SSMIS'
+        task smon_tmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'TMI'
+        task smon_gpsro
+          trigger getsmon eq complete
+          edit smon_smsmode 'GPSRO'
+        task smon_pacrars
+          trigger getsmon eq complete
+          edit smon_smsmode 'PACRARS'
+        task smon_ears
+          trigger getsmon eq complete
+          edit smon_smsmode 'EARS'
+        task smon_o3msg
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3MSG'
+        task smon_o3knmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3KNMI'
+        task smon_pwc
+          trigger getsmon eq complete
+          edit smon_smsmode 'PWC'
+        task smon_temp
+          trigger getsmon eq complete
+          edit smon_smsmode 'TEMP'
+        task smon_iasi
+          trigger getsmon eq complete
+          edit smon_smsmode 'IASI'
+        task smon_airs
+          trigger getsmon eq complete
+          edit smon_smsmode 'AIRS'
+        task smon_dbamv
+          trigger getsmon eq complete
+          edit smon_smsmode 'DBAMV'
+        task smon_amv
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMV'
+        task smon_o3
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3'
+        task smon_dmsp
+          trigger getsmon eq complete
+          edit smon_smsmode 'DMSP'
+        task smon_noaa
+          trigger getsmon eq complete
+          edit smon_smsmode 'NOAA'
+        task smon_geos
+          trigger getsmon eq complete
+          edit smon_smsmode 'GEOS'
+        task smon_scatt
+          trigger getsmon eq complete
+          edit smon_smsmode 'SCATT'
+        task smon_slmoist
+          trigger getsmon eq complete
+          edit smon_smsmode 'SLMOIST'
+        task smon_clean
+          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
+      endfamily
+      task clean
+        trigger fb eq complete and ../12dc/clean eq complete
+        edit FSFAMILY 'an'
+      family verif
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
+        edit DELTA_DAY '1'
+        inlimit /limits:linux_cluster
+        family fc
+          task v12li1
+          task v12li2
+          task v12up1
+            trigger v12li1 eq complete
+          task v12up2
+            trigger v12up1 eq complete and v12li2 eq complete
+          task v12pl
+            trigger v12up2 eq complete
+          task v12memv
+            trigger v12up2 eq complete
+            edit DATEMASK '02.*.*'
+          task v12memb
+            trigger v12up2 eq complete
+            edit DATEMASK '11.*.*'
+          task v12upmv
+            trigger v12memv eq complete
+            edit DATEMASK '02.*.*'
+          task v12upmb
+            trigger v12memb eq complete
+            edit DATEMASK '11.*.*'
+          task v12crmv
+            edit DATEMASK '28.*.*'
+          task v12crmb
+            edit DATEMASK '28.*.*'
+          task v12crd
+            edit DATEMASK '28.*.*'
+        endfamily
+        family oc
+          trigger ./fc eq complete or ./fc eq aborted
+          task mk_dummy_fields
+            edit QUEUE 'emos'
+            edit USER 'emos'
+            edit PP_BASE '/pp1'
+            edit WSHOST 'pp1'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit LOGDIR '/pp1/log'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit SMSOUT '/vol/emos_nc/output'
+          task insert_fields
+            trigger mk_dummy_fields eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit PP_BASE '/pp1'
+            inlimit /limits:linux_cluster
+          task vbrli1
+            trigger insert_fields eq complete
+          task vbrli2
+            trigger vbrli1 eq complete
+          task vwali1
+            trigger insert_fields eq complete
+          task vwali2
+            trigger vwali1 eq complete
+          task vwali3
+            trigger vwali2 eq complete
+          task vofli
+            trigger insert_fields eq complete
+          task vtlli
+            trigger insert_fields eq complete
+          task vtoli
+            trigger insert_fields eq complete
+          task vmoli
+            trigger insert_fields eq complete
+          task vbrup1
+            trigger vbrli1 eq complete
+          task vbrup2
+            trigger vbrup1 eq complete and vbrli2 eq complete
+          task vwaup1
+            trigger vwali1 eq complete
+          task vwaup2
+            trigger vwaup1 eq complete and vwali2 eq complete
+          task vwaup3
+            trigger vwaup2 eq complete and vwali3 eq complete
+          task vofup
+            trigger vofli eq complete
+          task vtlup
+            trigger vtlli eq complete
+          task vtoup
+            trigger vtoli eq complete
+          task vmoup
+            trigger vmoli eq complete
+          task vmeli
+            trigger insert_fields eq complete
+          task vmeup
+            trigger vmeli eq complete
+          task voccrd
+            edit DATEMASK '28.*.*'
+          task voccrm
+            edit DATEMASK '28.*.*'
+          task vocmem
+            edit DATEMASK '11.*.*'
+          task vocupm
+            trigger vocmem eq complete
+            edit DATEMASK '11.*.*'
+          task cleanup
+            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+        endfamily
+        family cf
+          trigger oc eq complete or oc eq aborted
+          task vcnli1
+            late -c +02:00
+          task vcnli2
+          task vcnup1
+            trigger vcnli1 eq complete
+          task vcnup2
+            trigger vcnup1 eq complete and vcnli2 eq complete
+          task vcnpl
+            trigger vcnup2 eq complete
+          task vcncrd
+          task vcncrm
+            edit DATEMASK '28.*.*'
+          task vcnmem
+            trigger vcnup2 eq complete
+            edit DATEMASK '11.*.*'
+          task vcnupm
+            trigger vcnmem eq complete
+            edit DATEMASK '11.*.*'
+          task vcnli3
+          task vcnli4
+          task vcnup3
+            trigger vcnup2 eq complete and vcnli3 eq complete
+          task vcnup4
+            trigger vcnup3 eq complete and vcnli4 eq complete
+          task vcnmem2
+            trigger vcnup4 eq complete
+            edit DATEMASK '22.*.*'
+          task vcnupm2
+            trigger vcnmem2 eq complete
+            edit DATEMASK '22.*.*'
+        endfamily
+        family ob
+          trigger oc eq complete or oc eq aborted
+          time 05:00
+          family stage1
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          family stage2
+            trigger ./stage1 eq complete
+            edit EMOS_BASE '00'
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          task vobcrd
+            edit DATEMASK '28.*.*'
+          task vobcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family em
+          task vemli
+            late -c +02:00
+          task vemup
+            trigger vemli eq complete
+          task vemcrd
+            edit DATEMASK '28.*.*'
+          task vemcrm
+            edit DATEMASK '28.*.*'
+          task vemmem
+            trigger vemup eq complete
+            edit DATEMASK '11.*.*'
+          task vemupm
+            trigger vemmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family es
+          trigger em eq complete
+          task vesli
+            late -c +02:00
+          task vesup
+            trigger vesli eq complete
+          task vescrd
+            edit DATEMASK '28.*.*'
+          task vescrm
+            edit DATEMASK '28.*.*'
+          task vesmem
+            trigger vesup eq complete
+            edit DATEMASK '11.*.*'
+          task vesupm
+            trigger vesmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family cv
+          trigger es eq complete
+          task vcvli
+            late -c +02:00
+          task vcvup
+            trigger vcvli eq complete
+          task vcvcrd
+            edit DATEMASK '28.*.*'
+          task vcvcrm
+            edit DATEMASK '28.*.*'
+          task vcvmem
+            trigger vcvup eq complete
+            edit DATEMASK '11.*.*'
+          task vcvupm
+            trigger vcvmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18/fc/model eq complete)
+          task glver
+          task glupr
+            trigger glver eq complete
+          task glcrr
+            edit DATEMASK '28.*.*'
+          task ff10ver
+            trigger glver eq complete
+          task ff10upr
+            trigger ff10ver eq complete and glupr eq complete
+          task glmem
+            trigger ff10upr eq complete
+            edit DATEMASK '11.*.*'
+          task glupm
+            trigger glmem eq complete
+            edit DATEMASK '11.*.*'
+          task glcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family sf
+          trigger fc eq complete or fc eq aborted
+          task vseli1
+          task vseli2
+          task vseup1
+            trigger vseli1 eq complete
+          task vseup2
+            trigger vseup1 eq complete and vseli2 eq complete
+          task vsecrd
+            edit DATEMASK '28.*.*'
+          task vsecrm
+            edit DATEMASK '28.*.*'
+          task vsemem
+            trigger vseup2 eq complete
+            edit DATEMASK '12.*.*'
+          task vseupm
+            trigger vsemem eq complete
+            edit DATEMASK '12.*.*'
+        endfamily
+      endfamily
+    endfamily
+    family 00
+      edit EMOS_BASE '00'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '1'
+      family ddh
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/fc eq complete)
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fc'
+        task ddh
+      endfamily
+      family sync
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/an eq complete)
+        edit EMOS_TYPE 'an'
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/sync'
+        task sync_bias
+          edit CALC_PSBIAS 'false'
+        task sync_fc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/fc/model:step gt 6 or /e_36r1/main/00/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_an
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/fc/model:step gt 3 or /e_36r1/main/00/fc/model eq complete))
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+          label files ""
+          label info ""
+          event fdb
+        task sync_clean
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SCHOST 'c1a'
+          edit STHOST '/s1a'
+          edit SCHOST_BKUP 'c1b'
+          edit STHOST_BKUP '/s1b'
+          edit SMSLOGHOST 'c1a'
+          edit LOGDIR '/s1a/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1a/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1a
+      endfamily
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/00/an eq complete and ( ../../main/00/fc/model:step ge 9 or ../../main/00/fc/model eq complete))
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task ansfc
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/000 eq complete and /e_36r1/main/00/prod/00an eq complete)
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '240'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ./ansfc eq complete
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/an/4dvar/ifstraj:finaltraj or /e_36r1/main/00/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc024
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/024 eq complete)
+          edit STEPS '0/3/006/009/012/015/018/021/024'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc048
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/048 eq complete)
+          edit STEPS '027/030/033/036/039/042/045/048'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc072
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/072 eq complete)
+          edit STEPS '051/054/057/060/063/066/069/072'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc096
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/096 eq complete)
+          edit STEPS '075/078/081/084/087/090/093/096'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc120
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/120 eq complete)
+          edit STEPS '099/102/105/108/111/114/117/120'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc144
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/144 eq complete)
+          edit STEPS '123/126/129/132/135/138/141/144'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc192
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/192 eq complete)
+          edit STEPS '150/156/162/168/174/180/186/192'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc240
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/prod/240 eq complete)
+          edit STEPS '198/204/210/216/222/228/234/240'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family satim1
+          task satim
+            trigger ../../satim eq complete
+            edit STEPS '0/to/48/by/3'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family satim2
+          task satim
+            trigger ../../satim eq complete
+            edit STEPS '54/to/120/by/6'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/fc/model eq complete)
+          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
+          edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'oeoperan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      family traj
+        task feed
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00/fc eq complete)
+        task cp_to_other
+          trigger feed eq complete
+      endfamily
+      family satim
+        edit QUEUE 'ns'
+        edit QUEUE_EPILOG 'ns'
+        edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+        edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+        edit MEM '11000'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+        edit SMSURLBASE 'http://intra.ecmwf.int/publications/cms/get/metapps'
+        inlimit /limits:c1b
+        task display_seaice
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/an eq complete)
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/admin'
+          edit FSFAMILY 'undef'
+          edit METVIEW 'metview_emos'
+          edit SMSURL 'seaice'
+          inlimit /limits:linux_cluster
+        task display_sst
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FSFAMILY 'undef'
+          edit SMSURL 'sst'
+          inlimit /limits:linux_cluster
+        family satim_0
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '0'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_3
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '3'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_6
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '6'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_9
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '9'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_12
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '12'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_15
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '15'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_18
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '18'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_21
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '21'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_24
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '24'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_27
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '27'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_30
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '30'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_33
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '33'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_36
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '36'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_39
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '39'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_42
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '42'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_45
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '45'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_48
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '48'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_54
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '54'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_60
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '60'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_66
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '66'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_72
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '72'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_78
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '78'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_84
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '84'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_90
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '90'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_96
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '96'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_102
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '102'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_108
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '108'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_114
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '114'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+        family satim_120
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/00/prod eq complete))
+          edit IMAGETIME '120'
+          edit WMOID 'undef'
+          family retr
+            edit SATIM_MODE '1'
+            inlimit /e_36r1/limits:satimsim_ret
+            task satimsim
+              edit MEM '781'
+          endfamily
+          family sat
+            trigger ./retr eq complete
+            edit SATIM_MODE '2'
+            inlimit /e_36r1/limits:satimsim
+            family sat_54
+              edit WMOID '54'
+              task satimsim
+            endfamily
+            family sat_56
+              edit WMOID '56'
+              task satimsim
+            endfamily
+            family sat_171
+              edit WMOID '171'
+              task satimsim
+            endfamily
+            family sat_255
+              edit WMOID '255'
+              task satimsim
+            endfamily
+            family sat_256
+              edit WMOID '256'
+              task satimsim
+            endfamily
+          endfamily
+          family satim_flush
+            trigger ./sat eq complete
+            edit SATIM_MODE '3'
+            task satimsim
+              edit MEM '781'
+          endfamily
+        endfamily
+      endfamily
+      family satmon
+        trigger ../00dc/satmon eq complete
+        edit FSFAMILY 'an'
+        inlimit /e_36r1/limits:smon
+        task getsmon
+          trigger ../fb/fdbksave eq complete and ../archive/obs/af eq complete
+        task smon_meris
+          trigger getsmon eq complete
+          edit smon_smsmode 'MERIS'
+        task smon_amsre
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMSRE'
+        task smon_ssmis
+          trigger getsmon eq complete
+          edit smon_smsmode 'SSMIS'
+        task smon_tmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'TMI'
+        task smon_gpsro
+          trigger getsmon eq complete
+          edit smon_smsmode 'GPSRO'
+        task smon_pacrars
+          trigger getsmon eq complete
+          edit smon_smsmode 'PACRARS'
+        task smon_ears
+          trigger getsmon eq complete
+          edit smon_smsmode 'EARS'
+        task smon_o3msg
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3MSG'
+        task smon_o3knmi
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3KNMI'
+        task smon_pwc
+          trigger getsmon eq complete
+          edit smon_smsmode 'PWC'
+        task smon_temp
+          trigger getsmon eq complete
+          edit smon_smsmode 'TEMP'
+        task smon_iasi
+          trigger getsmon eq complete
+          edit smon_smsmode 'IASI'
+        task smon_airs
+          trigger getsmon eq complete
+          edit smon_smsmode 'AIRS'
+        task smon_dbamv
+          trigger getsmon eq complete
+          edit smon_smsmode 'DBAMV'
+        task smon_amv
+          trigger getsmon eq complete
+          edit smon_smsmode 'AMV'
+        task smon_o3
+          trigger getsmon eq complete
+          edit smon_smsmode 'O3'
+        task smon_dmsp
+          trigger getsmon eq complete
+          edit smon_smsmode 'DMSP'
+        task smon_noaa
+          trigger getsmon eq complete
+          edit smon_smsmode 'NOAA'
+        task smon_geos
+          trigger getsmon eq complete
+          edit smon_smsmode 'GEOS'
+        task smon_scatt
+          trigger getsmon eq complete
+          edit smon_smsmode 'SCATT'
+        task smon_slmoist
+          trigger getsmon eq complete
+          edit smon_smsmode 'SLMOIST'
+        task smon_clean
+          trigger getsmon eq complete and smon_meris eq complete and smon_amsre eq complete and smon_ssmis eq complete and smon_tmi eq complete and smon_gpsro eq complete and smon_pacrars eq complete and smon_ears eq complete and smon_o3msg eq complete and smon_o3knmi eq complete and smon_pwc eq complete and smon_temp eq complete and smon_iasi eq complete and smon_airs eq complete and smon_dbamv eq complete and smon_amv eq complete and smon_o3 eq complete and smon_dmsp eq complete and smon_noaa eq complete and smon_geos eq complete and smon_scatt eq complete and smon_slmoist eq complete
+      endfamily
+      task clean
+        trigger fb eq complete and ../18/clean eq complete
+        edit FSFAMILY 'an'
+      family verif
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/verif'
+        edit DELTA_DAY '1'
+        inlimit /limits:linux_cluster
+        time 09:00
+        family fc
+          task v12li1
+          task v12li2
+          task v12up1
+            trigger v12li1 eq complete
+          task v12up2
+            trigger v12up1 eq complete and v12li2 eq complete
+          task v12pl
+            trigger v12up2 eq complete
+          task v12memv
+            trigger v12up2 eq complete
+            edit DATEMASK '02.*.*'
+          task v12memb
+            trigger v12up2 eq complete
+            edit DATEMASK '11.*.*'
+          task v12upmv
+            trigger v12memv eq complete
+            edit DATEMASK '02.*.*'
+          task v12upmb
+            trigger v12memb eq complete
+            edit DATEMASK '11.*.*'
+          task v12crmv
+            edit DATEMASK '28.*.*'
+          task v12crmb
+            edit DATEMASK '28.*.*'
+          task v12crd
+            edit DATEMASK '28.*.*'
+        endfamily
+        family oc
+          trigger ./fc eq complete or ./fc eq aborted
+          task mk_dummy_fields
+            edit QUEUE 'emos'
+            edit USER 'emos'
+            edit PP_BASE '/pp1'
+            edit WSHOST 'pp1'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit LOGDIR '/pp1/log'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit SMSOUT '/vol/emos_nc/output'
+          task insert_fields
+            trigger mk_dummy_fields eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit PP_BASE '/pp1'
+            inlimit /limits:linux_cluster
+          task vbrli1
+            trigger insert_fields eq complete
+          task vbrli2
+            trigger vbrli1 eq complete
+          task vwali1
+            trigger insert_fields eq complete
+          task vwali2
+            trigger vwali1 eq complete
+          task vwali3
+            trigger vwali2 eq complete
+          task vofli
+            trigger insert_fields eq complete
+          task vtlli
+            trigger insert_fields eq complete
+          task vtoli
+            trigger insert_fields eq complete
+          task vmoli
+            trigger insert_fields eq complete
+          task vbrup1
+            trigger vbrli1 eq complete
+          task vbrup2
+            trigger vbrup1 eq complete and vbrli2 eq complete
+          task vwaup1
+            trigger vwali1 eq complete
+          task vwaup2
+            trigger vwaup1 eq complete and vwali2 eq complete
+          task vwaup3
+            trigger vwaup2 eq complete and vwali3 eq complete
+          task vofup
+            trigger vofli eq complete
+          task vtlup
+            trigger vtlli eq complete
+          task vtoup
+            trigger vtoli eq complete
+          task vmoup
+            trigger vmoli eq complete
+          task vmeli
+            trigger insert_fields eq complete
+          task vmeup
+            trigger vmeli eq complete
+          task voccrd
+            edit DATEMASK '28.*.*'
+          task voccrm
+            edit DATEMASK '28.*.*'
+          task vocmem
+            edit DATEMASK '11.*.*'
+          task vocupm
+            trigger vocmem eq complete
+            edit DATEMASK '11.*.*'
+          task cleanup
+            trigger vmeup eq complete and vbrup2 eq complete and vwaup3 eq complete and vofup eq complete and vtlup eq complete and vtoup eq complete and vmoup eq complete and voccrd eq complete and voccrm eq complete and vocupm eq complete
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+        endfamily
+        family cf
+          trigger oc eq complete or oc eq aborted
+          task vcnli1
+            late -c +02:00
+          task vcnli2
+          task vcnup1
+            trigger vcnli1 eq complete
+          task vcnup2
+            trigger vcnup1 eq complete and vcnli2 eq complete
+          task vcnpl
+            trigger vcnup2 eq complete
+          task vcncrd
+          task vcncrm
+            edit DATEMASK '28.*.*'
+          task vcnmem
+            trigger vcnup2 eq complete
+            edit DATEMASK '11.*.*'
+          task vcnupm
+            trigger vcnmem eq complete
+            edit DATEMASK '11.*.*'
+          task vcnli3
+          task vcnli4
+          task vcnup3
+            trigger vcnup2 eq complete and vcnli3 eq complete
+          task vcnup4
+            trigger vcnup3 eq complete and vcnli4 eq complete
+          task vcnmem2
+            trigger vcnup4 eq complete
+            edit DATEMASK '22.*.*'
+          task vcnupm2
+            trigger vcnmem2 eq complete
+            edit DATEMASK '22.*.*'
+        endfamily
+        family ob
+          trigger oc eq complete or oc eq aborted
+          time 05:00
+          family stage1
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          family stage2
+            trigger ./stage1 eq complete
+            edit EMOS_BASE '00'
+            task vobli1
+            task vobli2
+            task vobup1
+              trigger vobli1 eq complete
+            task vobup2
+              trigger vobup1 eq complete and vobli2 eq complete
+            task vobnobs
+              trigger vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobmem
+              trigger ./vobup2 eq complete
+              edit DATEMASK '03.*.*'
+            task vobupm
+              trigger vobmem eq complete
+              edit DATEMASK '03.*.*'
+          endfamily
+          task vobcrd
+            edit DATEMASK '28.*.*'
+          task vobcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family em
+          task vemli
+            late -c +02:00
+          task vemup
+            trigger vemli eq complete
+          task vemcrd
+            edit DATEMASK '28.*.*'
+          task vemcrm
+            edit DATEMASK '28.*.*'
+          task vemmem
+            trigger vemup eq complete
+            edit DATEMASK '11.*.*'
+          task vemupm
+            trigger vemmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family es
+          trigger em eq complete
+          task vesli
+            late -c +02:00
+          task vesup
+            trigger vesli eq complete
+          task vescrd
+            edit DATEMASK '28.*.*'
+          task vescrm
+            edit DATEMASK '28.*.*'
+          task vesmem
+            trigger vesup eq complete
+            edit DATEMASK '11.*.*'
+          task vesupm
+            trigger vesmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family cv
+          trigger es eq complete
+          task vcvli
+            late -c +02:00
+          task vcvup
+            trigger vcvli eq complete
+          task vcvcrd
+            edit DATEMASK '28.*.*'
+          task vcvcrm
+            edit DATEMASK '28.*.*'
+          task vcvmem
+            trigger vcvup eq complete
+            edit DATEMASK '11.*.*'
+          task vcvupm
+            trigger vcvmem eq complete
+            edit DATEMASK '11.*.*'
+        endfamily
+        family wv
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/00/fc/model eq complete)
+          task glver
+          task glupr
+            trigger glver eq complete
+          task glcrr
+            edit DATEMASK '28.*.*'
+          task ff10ver
+            trigger glver eq complete
+          task ff10upr
+            trigger ff10ver eq complete and glupr eq complete
+          task glmem
+            trigger ff10upr eq complete
+            edit DATEMASK '11.*.*'
+          task glupm
+            trigger glmem eq complete
+            edit DATEMASK '11.*.*'
+          task glcrm
+            edit DATEMASK '28.*.*'
+        endfamily
+        family sf
+          trigger fc eq complete or fc eq aborted
+          task vseli1
+          task vseli2
+          task vseup1
+            trigger vseli1 eq complete
+          task vseup2
+            trigger vseup1 eq complete and vseli2 eq complete
+          task vsecrd
+            edit DATEMASK '28.*.*'
+          task vsecrm
+            edit DATEMASK '28.*.*'
+          task vsemem
+            trigger vseup2 eq complete
+            edit DATEMASK '12.*.*'
+          task vseupm
+            trigger vsemem eq complete
+            edit DATEMASK '12.*.*'
+        endfamily
+      endfamily
+    endfamily
+    family 12bc
+      edit EMOS_BASE '12'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '0'
+      family verif
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/12/fc eq complete)
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
+        edit SCORE_STREAM 'BC_0046'
+        inlimit /limits:linux_cluster
+        task create_daily
+        task create_monthly
+          edit DATEMASK '28.*.*'
+        task clim
+          trigger create_daily eq complete
+        task non_clim
+          trigger create_daily eq complete
+        task clim_update
+          trigger clim eq complete
+        task non_clim_update
+          trigger non_clim eq complete and clim eq complete
+        task plot
+          trigger non_clim_update eq complete
+        task mean
+          trigger non_clim_update eq complete
+          edit DATEMASK '10.*.*'
+        task mean_update
+          trigger mean eq complete
+          edit DATEMASK '10.*.*'
+      endfamily
+    endfamily
+    family 18bc
+      edit EMOS_BASE '18'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '0'
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/18bc/an eq complete and ( ../../main/18bc/fc/model:step ge 90 or ../../main/18bc/fc/model eq complete))
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task ansfc
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          edit EDFAMILY 'true'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '9'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ./ansfc eq complete
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/18bc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/18bc/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc024
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/024 eq complete)
+          edit STEPS '0/3/06/09/12/15/18/21/24'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc048
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/048 eq complete)
+          edit STEPS '27/30/33/36/39/42/45/48'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc072
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/072 eq complete)
+          edit STEPS '51/54/57/60/63/66/69/72'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc090
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/prod/090 eq complete)
+          edit STEPS '75/78/81/84/87/90'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/fc/model eq complete)
+          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
+          edit STEPS '0/6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'opebcan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/18bc/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      task clean
+        trigger fb eq complete
+        edit FSFAMILY 'an'
+      family verif
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/18bc/fc eq complete)
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
+        edit SCORE_STREAM 'BC_0046'
+        inlimit /limits:linux_cluster
+        task create_daily
+        task create_monthly
+          edit DATEMASK '28.*.*'
+        task clim
+          trigger create_daily eq complete
+        task non_clim
+          trigger create_daily eq complete
+        task clim_update
+          trigger clim eq complete
+        task non_clim_update
+          trigger non_clim eq complete and clim eq complete
+        task plot
+          trigger non_clim_update eq complete
+        task mean
+          trigger non_clim_update eq complete
+          edit DATEMASK '10.*.*'
+        task mean_update
+          trigger mean eq complete
+          edit DATEMASK '10.*.*'
+      endfamily
+    endfamily
+    family 00bc
+      edit EMOS_BASE '00'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '1'
+      family verif
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/00/fc eq complete)
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
+        edit SCORE_STREAM 'BC_0046'
+        inlimit /limits:linux_cluster
+        task create_daily
+        task create_monthly
+          edit DATEMASK '28.*.*'
+        task clim
+          trigger create_daily eq complete
+        task non_clim
+          trigger create_daily eq complete
+        task clim_update
+          trigger clim eq complete
+        task non_clim_update
+          trigger non_clim eq complete and clim eq complete
+        task plot
+          trigger non_clim_update eq complete
+        task mean
+          trigger non_clim_update eq complete
+          edit DATEMASK '10.*.*'
+        task mean_update
+          trigger mean eq complete
+          edit DATEMASK '10.*.*'
+      endfamily
+    endfamily
+    family 06bc
+      edit EMOS_BASE '06'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '6'
+      edit WINDOW_OFFSET_4D '3'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '1'
+      family archive
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../main/06bc/an eq complete and ( ../../main/06bc/fc/model:step ge 90 or ../../main/06bc/fc/model eq complete))
+        edit FSFAMILY 'mars'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/archive'
+        edit EMOS_TYPE 'an'
+        inlimit /limits:mars
+        inlimit /e_36r1/limits:mars
+        task ansfc
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anml
+          trigger ansfc:fdb or ansfc eq complete
+          edit EDFAMILY 'true'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          inlimit /e_36r1/limits:ml
+          label files ""
+          label info ""
+          event fdb
+        task anpl
+          trigger anml:fdb or anml eq complete
+          edit FCLENGTH '9'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anwave
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task anil
+          trigger anpl:fdb or anpl eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task derivedp
+          trigger ./ansfc eq complete
+          edit STEPS '0'
+          label files ""
+          label info ""
+          event fdb
+        family obs
+          edit FSFAMILY 'an'
+          inlimit /e_36r1/limits:obs
+          task highres
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            inlimit /limits:linux_cluster
+          task ai
+            trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ( /e_36r1/main/06bc/an/4dvar/ifstraj:finaltraj or /e_36r1/main/06bc/an/4dvar eq complete))
+            edit TYPE 'ai'
+            label files ""
+            label info ""
+            event fdb
+          task af
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'af'
+            label files ""
+            label info ""
+            event fdb
+          task fb
+            trigger ../../fb/feedback eq complete
+            edit TYPE 'fb'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task ice_nmc
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task sst
+          trigger ansfc:fdb or ansfc eq complete
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        family fc024
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/024 eq complete)
+          edit STEPS '0/3/06/09/12/15/18/21/24'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc048
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/048 eq complete)
+          edit STEPS '27/30/33/36/39/42/45/48'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc072
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/072 eq complete)
+          edit STEPS '51/54/57/60/63/66/69/72'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family fc090
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/prod/090 eq complete)
+          edit STEPS '75/78/81/84/87/90'
+          edit EMOS_TYPE 'fc'
+          task fcsfc
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcml
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            inlimit /e_36r1/limits:ml
+            label files ""
+            label info ""
+            event fdb
+          task fcpl
+            trigger fcsfc:fdb or fcsfc eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task fcil
+            trigger fcpl:fdb or fcpl eq complete
+            inlimit /limits:mars
+            inlimit /e_36r1/limits:mars
+            label files ""
+            label info ""
+            event fdb
+          task derivedp
+            trigger fcil:fdb or fcil eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        task fc12g
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/fc/model eq complete)
+          edit STEPS_SPECTRAL '6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
+          edit STEPS '0/6/12/18/24/30/36/42/48/54/60/66/72/78/84/90'
+          inlimit /limits:mars
+          inlimit /e_36r1/limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task rmfdb
+          trigger ansfc eq complete and anml eq complete and anpl eq complete and anwave eq complete and obs eq complete
+      endfamily
+      family fb
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/an eq complete)
+        edit FSFAMILY 'an'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/fb'
+        task sync_rstrhbias
+          edit SMSFILES '/home/ma/emos/def/e_36r1/smsfiles'
+        task biassave
+          trigger sync_rstrhbias eq complete
+        family feedback
+          edit ACCOUNT 'opebcan'
+          edit NPES '8'
+          edit FBNEW2OLD '1'
+          edit LCONV '1'
+          edit LSATOB '1'
+          edit LREO3 '1'
+          edit LAEOLUS '0'
+          edit LSSMI '1'
+          edit LSSMIS '1'
+          edit LAMSRE '1'
+          edit LTMI '1'
+          edit LHIRS '1'
+          edit LMSU '1'
+          edit LSSU '1'
+          edit LAMSUA '1'
+          edit LAMSUB '1'
+          edit LMHS '1'
+          edit LGEOS '1'
+          edit LSCAT '1'
+          edit LAIRS '1'
+          edit LVTPR1 '0'
+          edit LVTPR2 '0'
+          edit LGPSRO '1'
+          edit LIASI '1'
+          edit LMERIS '1'
+          task revmatchup
+            edit NPES '128'
+            edit THREADS '2'
+          task matchup
+            trigger revmatchup eq complete
+            edit NPES '128'
+            edit THREADS '2'
+          task odbcmp_prepare
+            edit THREADS '1'
+            edit NPES '1'
+            edit MEM '1000'
+            edit CPUTIME '1000'
+            edit PRIORITY '90'
+          family odb_compress
+            trigger odbcmp_prepare eq complete and matchup eq complete
+            edit THREADS '2'
+            edit NPES '1'
+            task odbcmp_conv
+            task odbcmp_surf_conv
+            task odbcmp_airs
+            task odbcmp_iasi
+            task odbcmp_hirs
+            task odbcmp_msu
+            task odbcmp_ssu
+            task odbcmp_amsua
+            task odbcmp_amsub
+            task odbcmp_mhs
+            task odbcmp_satob
+            task odbcmp_reo3
+            task odbcmp_ssmi
+            task odbcmp_ssmis
+            task odbcmp_amsre
+            task odbcmp_tmi
+            task odbcmp_scatt
+            task odbcmp_geos
+            task odbcmp_gpsro
+            task odbcmp_meris
+          endfamily
+          family odb2bufr
+            trigger matchup eq complete
+            edit NPES '1'
+            edit SUBTYPES_INCLUDE ''
+            edit SUBTYPES_EXCLUDE ''
+            task o2b_conv
+              edit SUBTYPES_EXCLUDE '85 82 83 87'
+              edit NPES '2'
+            task o2b_surf_conv
+              edit SUBTYPES_EXCLUDE '142 143 144 145 85 82 83 87'
+              edit NPES '2'
+            task o2b_airs
+              edit SUBTYPES_INCLUDE '57'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_iasi
+              edit SUBTYPES_INCLUDE '240'
+              edit NPES '8'
+              edit THREADS '2'
+            task o2b_hirs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_msu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_ssu
+              edit SUBTYPES_INCLUDE '54 55'
+            task o2b_amsua
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_amsub
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_mhs
+              edit SUBTYPES_INCLUDE '54 55'
+              edit NPES '2'
+            task o2b_satob
+              edit SUBTYPES_INCLUDE '82 83 87'
+              edit NPES '2'
+            task o2b_reo3
+              edit SUBTYPES_INCLUDE '205 206 207 208 215'
+              edit NPES '4'
+              edit THREADS '2'
+            task o2b_ssmi
+              edit SUBTYPES_INCLUDE '55 127'
+            task o2b_ssmis
+              edit SUBTYPES_INCLUDE '49'
+            task o2b_amsre
+              edit SUBTYPES_INCLUDE '59'
+            task o2b_tmi
+              edit SUBTYPES_INCLUDE '129'
+            task o2b_scatt
+              edit SUBTYPES_INCLUDE '122 137 139'
+            task o2b_geos
+              edit SUBTYPES_INCLUDE '189 89 76 77 78'
+              edit NPES '2'
+            task o2b_gpsro
+              edit SUBTYPES_INCLUDE '250'
+            task o2b_meris
+              edit SUBTYPES_INCLUDE '212'
+          endfamily
+          task mergebufr
+            trigger odb2bufr eq complete
+        endfamily
+        family obstat
+          trigger feedback/odb2bufr eq complete
+          edit NPES '1'
+          task obstat_conv
+          task obstat_surf_conv
+          task obstat_airs
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_iasi
+            edit NPES '8'
+            edit THREADS '2'
+          task obstat_hirs
+            edit NPES '4'
+          task obstat_msu
+          task obstat_ssu
+          task obstat_amsua
+            edit NPES '2'
+          task obstat_amsub
+          task obstat_mhs
+          task obstat_satob
+          task obstat_reo3
+          task obstat_ssmi
+            edit NPES '2'
+          task obstat_ssmis
+            edit NPES '2'
+          task obstat_amsre
+            edit NPES '2'
+          task obstat_tmi
+            edit NPES '2'
+          task obstat_scatt
+          task obstat_geos
+            edit NPES '2'
+          task obstat_gpsro
+            edit NPES '2'
+          task obstat_meris
+            edit NPES '2'
+        endfamily
+        task fdbksave
+          trigger feedback eq complete and obstat eq complete
+        task clean_odbcmp
+          trigger feedback eq complete and obstat eq complete and fdbksave eq complete
+        task wavesave
+          trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and ../../../main/06bc/an/4dvar eq complete)
+        task obstat_merge
+          trigger obstat eq complete
+          edit WSHOST 'bee01'
+          edit PRIORITY '51'
+      endfamily
+      task clean
+        trigger fb eq complete
+        edit FSFAMILY 'an'
+      family verif
+        trigger ( /e_36r1/main:YMD gt /e_36r1/lag:YMD) or ( /e_36r1/main:YMD eq /e_36r1/lag:YMD and /e_36r1/main/06bc/fc eq complete)
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/e_36r1/bcverif'
+        edit SCORE_STREAM 'BC_0046'
+        inlimit /limits:linux_cluster
+        task create_daily
+        task create_monthly
+          edit DATEMASK '28.*.*'
+        task clim
+          trigger create_daily eq complete
+        task non_clim
+          trigger create_daily eq complete
+        task clim_update
+          trigger clim eq complete
+        task non_clim_update
+          trigger non_clim eq complete and clim eq complete
+        task plot
+          trigger non_clim_update eq complete
+        task mean
+          trigger non_clim_update eq complete
+          edit DATEMASK '10.*.*'
+        task mean_update
+          trigger mean eq complete
+          edit DATEMASK '10.*.*'
+      endfamily
+    endfamily
+    task checkarchive
+      trigger ./06 eq complete and ./12 eq complete and ./12dc eq complete and ./18 eq complete and ./00 eq complete and ./00dc eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FSFAMILY 'mars'
+      edit EMOS_TYPE 'an'
+      edit OSTREAN 'DCDA DCWV'
+      edit WSHOST 'linux_cluster'
+      inlimit /limits:linux_cluster
+    task checkarchivebc
+      trigger ./18bc eq complete and ./06bc eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit STREAM 'SCDA'
+      edit FSFAMILY 'mars'
+      edit EMOS_TYPE 'an'
+      edit WSTREAN 'DCDA DCWV'
+      edit WSHOST 'linux_cluster'
+      inlimit /limits:linux_cluster
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'lag'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger /e_36r1/main/make eq complete and ./00dc eq complete and ./06 eq complete and ./12 eq complete and ./12dc eq complete and ./18 eq complete and ./00 eq complete and ./12bc eq complete and ./18bc eq complete and ./00bc eq complete and ./06bc eq complete and checkarchive eq complete and checkarchivebc eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'lag'
+      edit MOVE_TO_ECFS 'no'
+      time 11:45
+  endfamily
+  family verify
+    repeat date YMD 20091118 20121212 1
+    edit VERIFY 'verify_test'
+    edit UPDATE_WEB_NOW 'yes'
+    edit SMSFILES '/home/ma/emos/def/e_36r1/verify'
+    edit FORECAST_DELTA '1'
+    edit RUN_PARALLEL '0'
+    edit EXPVERV '0046'
+    edit EXPVERP '0046'
+    edit EXPVERF '0046'
+    edit CLASSV 'od'
+    edit CLASSP 'od'
+    edit CLASSF 'od'
+    edit QUEUE 'emos-e'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit SMSOUT '/vol/emos_nc/output'
+    inlimit /limits:mars
+    inlimit /limits:linux_cluster
+    family 12
+      edit EMOS_BASE '12'
+      family forecast
+        trigger ( /e_36r1/lag:YMD gt /e_36r1/verify:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/verify:YMD and ../../lag/12/archive eq complete)
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SCORE_STREAM '36r1_0046'
+        edit OPER_STREAM 'OPER'
+        edit INDEX_SIZE '102400'
+        inlimit /limits:linux_cluster
+        task create_score
+        family clim_levels
+          trigger create_score eq complete
+          task fc_clim_levels
+          task update_score
+            trigger fc_clim_levels eq complete
+        endfamily
+        family non_clim_levels
+          trigger create_score eq complete
+          task fc_non_clim_levels
+          task update_score
+            trigger fc_non_clim_levels eq complete and ../clim_levels eq complete
+        endfamily
+        family others
+          trigger create_score eq complete
+          task fc_others
+          task update_score
+            trigger fc_others eq complete and ../non_clim_levels eq complete
+        endfamily
+      endfamily
+      family observations
+        trigger forecast eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit FORECAST_DELTA '3'
+        edit SCORE_STREAM '36r1_0046_OB'
+        edit OPER_STREAM 'O_ECMWF'
+        edit INDEX_SIZE '102400'
+        inlimit /limits:linux_cluster
+        task create_score
+        family clim_levels
+          trigger create_score eq complete
+          task ob_clim_levels
+          task update_score
+            trigger ob_clim_levels eq complete
+        endfamily
+        family non_clim_levels
+          trigger create_score eq complete
+          task ob_non_clim_levels
+          task update_score
+            trigger ob_non_clim_levels eq complete and ../clim_levels eq complete
+        endfamily
+      endfamily
+      family waves
+        trigger forecast eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit INDEX_SIZE '102400'
+        edit SCORE_STREAM '36r1_0046_WV'
+        edit OPER_STREAM 'WAVE_G'
+        inlimit /limits:linux_cluster
+        family height
+          edit STREAM 'WV'
+          task create_score
+          task wv_height
+            trigger create_score eq complete
+          task update_score
+            trigger wv_height eq complete
+        endfamily
+        family wind
+          trigger height eq complete
+          task wv_wind_all
+          task update_score
+            trigger wv_wind_all eq complete
+        endfamily
+        family wind_over_sea
+          trigger wind eq complete
+          edit INDEX_SIZE '102400'
+          edit SCORE_STREAM '36r1_0046_WV_SEA'
+          task create_score
+          task wv_wind_sea
+            trigger create_score eq complete
+          task update_score
+            trigger wv_wind_sea eq complete
+        endfamily
+      endfamily
+    endfamily
+    family 00
+      trigger ./12 eq complete
+      edit EMOS_BASE '00'
+      family forecast
+        trigger ( /e_36r1/lag:YMD gt /e_36r1/verify:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/verify:YMD and ../../lag/00/archive eq complete)
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SCORE_STREAM '36r1_0046'
+        edit OPER_STREAM 'OPER'
+        edit INDEX_SIZE '102400'
+        inlimit /limits:linux_cluster
+        task create_score
+        family clim_levels
+          trigger create_score eq complete
+          task fc_clim_levels
+          task update_score
+            trigger fc_clim_levels eq complete
+        endfamily
+        family non_clim_levels
+          trigger create_score eq complete
+          task fc_non_clim_levels
+          task update_score
+            trigger fc_non_clim_levels eq complete and ../clim_levels eq complete
+        endfamily
+        family others
+          trigger create_score eq complete
+          task fc_others
+          task update_score
+            trigger fc_others eq complete and ../non_clim_levels eq complete
+        endfamily
+      endfamily
+      family observations
+        trigger forecast eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit FORECAST_DELTA '3'
+        edit SCORE_STREAM '36r1_0046_OB'
+        edit OPER_STREAM 'O_ECMWF'
+        edit INDEX_SIZE '102400'
+        inlimit /limits:linux_cluster
+        task create_score
+        family clim_levels
+          trigger create_score eq complete
+          task ob_clim_levels
+          task update_score
+            trigger ob_clim_levels eq complete
+        endfamily
+        family non_clim_levels
+          trigger create_score eq complete
+          task ob_non_clim_levels
+          task update_score
+            trigger ob_non_clim_levels eq complete and ../clim_levels eq complete
+        endfamily
+      endfamily
+      family waves
+        trigger forecast eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit INDEX_SIZE '102400'
+        edit SCORE_STREAM '36r1_0046_WV'
+        edit OPER_STREAM 'WAVE_G'
+        inlimit /limits:linux_cluster
+        family height
+          edit STREAM 'WV'
+          task create_score
+          task wv_height
+            trigger create_score eq complete
+          task update_score
+            trigger wv_height eq complete
+        endfamily
+        family wind
+          trigger height eq complete
+          task wv_wind_all
+          task update_score
+            trigger wv_wind_all eq complete
+        endfamily
+        family wind_over_sea
+          trigger wind eq complete
+          edit INDEX_SIZE '102400'
+          edit SCORE_STREAM '36r1_0046_WV_SEA'
+          task create_score
+          task wv_wind_sea
+            trigger create_score eq complete
+          task update_score
+            trigger wv_wind_sea eq complete
+        endfamily
+      endfamily
+    endfamily
+    family plot
+      trigger ./00 eq complete and ./12 eq complete
+      edit WSHOST 'linux_cluster'
+      edit QUEUE 'serial'
+      limit plot 3
+      inlimit plot
+      family forecast
+        edit SCORE_STREAM '36r1_0046'
+        edit OPER_STREAM 'OPER'
+        edit FORECAST_DELTA '1'
+        task fc_scocom
+        task fc_scocat
+        task fc_pltime
+        task fc_error
+      endfamily
+      family observations
+        edit SCORE_STREAM '36r1_0046_OB'
+        edit OPER_STREAM 'O_ECMWF'
+        edit FORECAST_DELTA '3'
+        task ob_scocom
+        task ob_scocat
+        task ob_pltime
+        task ob_error
+      endfamily
+      family waves
+        edit SCORE_STREAM '36r1_0046_WV'
+        edit OPER_STREAM 'WAVE_G'
+        edit FORECAST_DELTA '1'
+        task wv_scocom
+        task wv_scocat
+        task wv_pltime
+        task wv_error
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'verify'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./00 eq complete and ./12 eq complete and plot eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'verify'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGSTOECFS 'no'
+      time 11:45
+  endfamily
+  family pop
+    repeat date YMD 20091118 20121212 1
+    edit VERIFY 'verify_test'
+    edit QUEUE 'emos-e'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit SMSOUT '/vol/emos_nc/output'
+    edit METVIEW '/usr/local/share/metview'
+    inlimit /limits:linux_cluster
+    family 00
+      edit EMOS_BASE '00'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '1'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
+      family data
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
+        family fields
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit STEP_LIST '12/to/240/by/12'
+          inlimit /e_36r1/limits:webplots
+          task z500
+          task mslp
+          task mslp_gg
+          task t850
+          task rain
+          task t2m
+          task w30m
+          task cloud
+          task waves
+          task rainp
+          task w10m
+          task wind
+            edit STEP_LIST '24/to/240/by/24'
+          task rh
+            edit STEP_LIST '24/to/240/by/24'
+          task vorticity
+            edit STEP_LIST '24/to/240/by/24'
+          task divergence
+            edit STEP_LIST '24/to/240/by/24'
+        endfamily
+        family metgram
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete and /mc/main/00/legA/fc eq complete)
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit RHOST 'epsgrams'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/plot/metgram'
+          inlimit /limits:linux_cluster
+          task metret
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete )
+          task metclean
+            trigger metret eq complete
+            edit DELTA_DAY '-2'
+          family fc
+            edit KIND 'metgram_fc'
+            edit ENSEMBLES '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/epsgrams/grams'
+            task gclean
+              edit REMOTE_KEEP_DAYS '3'
+              edit KEEP_DAYS '3'
+            task gdb
+              trigger gclean eq complete
+              label files ""
+              label info ""
+              event 1 
+              event fdb
+            task glink
+              trigger gdb eq complete
+          endfamily
+        endfamily
+        family bufr
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task feedback
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00/archive/obs eq complete)
+        endfamily
+      endfamily
+      family web
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+        family fc
+          trigger ../data/fields eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          inlimit /e_36r1/limits:webplots
+          family members
+            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa'
+            edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168,180,192,204,216,228,240'
+            edit PLOT_LEGS '1'
+            task w_z500t850
+            task w_mslrain
+            task w_t2m30mw
+            task w_clouds
+            task w_waves
+              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+            task w_mwp
+              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+          endfamily
+          family additional
+            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
+            edit PLOT_STEPS '0,24,48,72,96,120,144,168'
+            task w_uv_rh
+            task w_msl_uv200
+            task w_z500t850_gts
+              edit PLOT_STEPS '0,24,48,72,96,120,144,168,192,216,240'
+            task w_vordir
+              edit PLOT_STEPS '0,24,48,72,96,120,144'
+            family wmo_swh_dir
+              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
+              edit PLOT_AREAS 'Global'
+              edit PLOT_TYPE '_wmo'
+              task w_waves
+            endfamily
+            family wmo_mwp_dir
+              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
+              edit PLOT_AREAS 'Global'
+              edit PLOT_TYPE '_wmo'
+              task w_mwp
+            endfamily
+          endfamily
+          family essential
+            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
+            edit PLOT_STEPS '72,96,120,144,168,192,216,240'
+            task public_plots
+          endfamily
+          task web_update
+            trigger members eq complete and additional eq complete and essential eq complete
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            edit PACKAGES 'esuite'
+            inlimit /e_36r1/limits:webplots
+        endfamily
+        family satim
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+          edit UPDATE_WEB_NOW 'no'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit PLOT_AREAS 'Europe,North_America,South_America,Africa,Indian_Ocean,Australia,West_Pacific,East_Pacific'
+          task w_simulated
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00/satim eq complete)
+          task web_update
+            trigger ./w_simulated eq complete and ../fc eq complete
+            edit PACKAGES 'esuite'
+        endfamily
+        family an
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
+          edit SMSFILES '/home/ma/emos/def/e_36r1/plot/plot240'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          inlimit /e_36r1/limits:webplots
+          task w_albedo
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete and ../../data/fields eq complete)
+            edit WEEKDAY 'tuesday'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/'
+          task psst
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            inlimit /e_36r1/limits:webplots
+          task psw123
+          task web_update
+            trigger w_albedo eq complete and psst eq complete and psw123 eq complete
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            edit PACKAGES 'esuite'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/'
+            inlimit /e_36r1/limits:webplots
+        endfamily
+        family monitoring
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task w_coverage
+            trigger /e_36r1/pop/00/data/bufr eq complete
+          task w_tscover
+            time 07:10
+          task w_guan
+            edit DATEMASK '03.*.*'
+        endfamily
+        family cloudsat
+          trigger fc eq complete
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit PLOT_AREAS 'South_Atlantic,Pacific,Indian'
+          edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168'
+          task csat_clouds
+          task csat_waves
+          task csat_wind
+        endfamily
+        family amma
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/amma'
+          family monitoring
+            edit UPDATE_WEB_NOW 'yes'
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit WSHOST 'linux_cluster'
+            inlimit /limits:linux_cluster
+            time 10:00
+            task amma_cover
+              edit DATEMASK '03.*.*'
+            task amma_pilot
+              edit DATEMASK '03.*.*'
+            task amma_rs
+              edit DATEMASK '03.*.*'
+            task amma_tephigram
+              edit METVIEW '/usr/local/share/metview_old'
+          endfamily
+          family fc
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
+            edit UPDATE_WEB_NOW 'yes'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'serial'
+            edit PLOTDOM '-30/-35/45/40'
+            time 09:30
+            task satplot
+              edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
+            task maps
+              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
+            task tephi
+              edit METVIEW '/usr/local/share/metview_old'
+              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
+            task trajectories
+              edit STEPS '24/48/72'
+            task cross
+              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
+            task hovm
+              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+            task obs_mslp
+            task metgram
+            task prob
+              edit STEPS '60/72/84/96/108/120/132/144/156/168/180/192/204/216/228/240'
+          endfamily
+        endfamily
+        family swdfp
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00/fc/model eq complete)
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/swdfp'
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'serial'
+          edit PLOTDOM '-45/-10/6/62'
+          time 10:30
+          family maps
+            edit PLOT_LOCATION '/webplots_e/data/swdfp/maps'
+            edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+            task swdfp_maps
+            task smaps_toweb1
+              trigger swdfp_maps eq complete
+            task smaps_toweb2
+              trigger swdfp_maps eq complete
+            task smaps_toweb3
+              trigger swdfp_maps eq complete
+            task swdfp_clean
+              trigger smaps_toweb1 eq complete and smaps_toweb2 eq complete and smaps_toweb3 eq complete
+          endfamily
+          task swdfp_satplot
+            edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
+          task swdfp_tephi
+            edit METVIEW '/usr/local/share/metview_old'
+            edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
+          task swdfp_obs_mslp
+            edit PLOTDOM '-37/3/-3/55'
+          task swdfp_metgram
+        endfamily
+      endfamily
+      family paper
+        task pobstat
+          trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00/fb/obstat_merge eq complete)
+          edit FSFAMILY 'an'
+          edit WSHOST 'linux_cluster'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+      endfamily
+      task cleanup
+        trigger web eq complete
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        inlimit /e_36r1/limits:webplots
+    endfamily
+    family 12
+      edit EMOS_BASE '12'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
+      family proc
+        edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+        task buoycol
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/obs eq complete)
+          edit FSFAMILY 'fc'
+      endfamily
+      family data
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
+        family fields
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete)
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit STEP_LIST '12/to/240/by/12'
+          inlimit /e_36r1/limits:webplots
+          task z500
+          task mslp
+          task mslp_gg
+          task t850
+          task rain
+          task t2m
+          task w30m
+          task cloud
+          task waves
+          task rainp
+          task w10m
+          task wind
+            edit STEP_LIST '24/to/240/by/24'
+          task rh
+            edit STEP_LIST '24/to/240/by/24'
+          task vorticity
+            edit STEP_LIST '24/to/240/by/24'
+          task divergence
+            edit STEP_LIST '24/to/240/by/24'
+        endfamily
+        family metgram
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete and /mc/main/12/legA/fc eq complete)
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit RHOST 'epsgrams'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/plot/metgram'
+          inlimit /limits:linux_cluster
+          task metret
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete )
+          task metclean
+            trigger metret eq complete
+            edit DELTA_DAY '-3'
+          family fc
+            edit KIND 'metgram_fc'
+            edit ENSEMBLES '0'
+            edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/epsgrams/grams'
+            task gclean
+              edit REMOTE_KEEP_DAYS '3'
+              edit KEEP_DAYS '3'
+            task gdb
+              trigger gclean eq complete
+              label files ""
+              label info ""
+              event 1 
+              event fdb
+            task glink
+              trigger gdb eq complete
+          endfamily
+        endfamily
+        family bufr
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task feedback
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12/archive/obs eq complete)
+        endfamily
+      endfamily
+      family web
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+        family fc
+          trigger ../data/fields eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          inlimit /e_36r1/limits:webplots
+          family members
+            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa'
+            edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168,180,192,204,216,228,240'
+            edit PLOT_LEGS '1'
+            task w_z500t850
+            task w_mslrain
+            task w_t2m30mw
+            task w_clouds
+            task w_waves
+              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+            task w_mwp
+              edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+          endfamily
+          family additional
+            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
+            edit PLOT_STEPS '0,24,48,72,96,120,144,168'
+            task w_uv_rh
+            task w_msl_uv200
+            task w_z500t850_gts
+              edit PLOT_STEPS '0,24,48,72,96,120,144,168,192,216,240'
+            task w_vordir
+              edit PLOT_STEPS '0,24,48,72,96,120,144'
+            family wmo_swh_dir
+              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
+              edit PLOT_AREAS 'Global'
+              edit PLOT_TYPE '_wmo'
+              task w_waves
+            endfamily
+            family wmo_mwp_dir
+              edit PLOT_STEPS '0,24,48,72,96,120,144,168'
+              edit PLOT_AREAS 'Global'
+              edit PLOT_TYPE '_wmo'
+              task w_mwp
+            endfamily
+          endfamily
+          family essential
+            edit PLOT_AREAS 'Europe,North_America,South_America,Asia,Australia,Africa,North_Hemisphere,South_Hemisphere'
+            edit PLOT_STEPS '72,96,120,144,168,192,216,240'
+            task public_plots
+          endfamily
+          task web_update
+            trigger members eq complete and additional eq complete and essential eq complete
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            edit PACKAGES 'esuite'
+            inlimit /e_36r1/limits:webplots
+        endfamily
+        family satim
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+          edit UPDATE_WEB_NOW 'no'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit PLOT_AREAS 'Europe,North_America,South_America,Africa,Indian_Ocean,Australia,West_Pacific,East_Pacific'
+          task w_simulated
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12/satim eq complete)
+          task web_update
+            trigger ./w_simulated eq complete and ../fc eq complete
+            edit PACKAGES 'esuite'
+        endfamily
+        family verification
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/verification'
+          edit UPDATE_WEB_NOW 'yes'
+          family monthly
+            edit DATEMASK '11.*.*'
+            task w_2t
+            task w_cloud_humid
+            task w_preci
+            task w_scores
+            task w_scores_mean
+            task w_wmomeans
+            task w_pltime_waves
+          endfamily
+          family daily
+            trigger /e_36r1/lag/12/verif/oc eq complete
+            task w_allcentres
+            task w_weekly_centres
+              trigger w_allcentres eq complete
+              edit WEEKDAY 'monday'
+          endfamily
+        endfamily
+        family monitoring
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task w_coverage
+            trigger /e_36r1/pop/12/data/bufr eq complete
+        endfamily
+        family cloudsat
+          trigger fc eq complete
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit PLOT_AREAS 'South_Atlantic,Pacific,Indian'
+          edit PLOT_STEPS '0,12,24,36,48,60,72,84,96,108,120,132,144,156,168'
+          task csat_clouds
+          task csat_waves
+          task csat_wind
+        endfamily
+        family amma
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/amma'
+          family fc
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete)
+            edit UPDATE_WEB_NOW 'yes'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'serial'
+            edit PLOTDOM '-30/-35/45/40'
+            time 00:30
+            task satplot
+              edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
+            task maps
+              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
+            task tephi
+              edit METVIEW '/usr/local/share/metview_old'
+              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
+            task trajectories
+              edit STEPS '24/48/72'
+            task cross
+              edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120'
+            task hovm
+              edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+            task obs_mslp
+            task metgram
+            task prob
+              edit STEPS '60/72/84/96/108/120/132/144/156/168/180/192/204/216/228/240'
+          endfamily
+        endfamily
+        family swdfp
+          trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12/fc/model eq complete)
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web/swdfp'
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'serial'
+          edit PLOTDOM '-45/-10/6/62'
+          time 01:30
+          family maps
+            edit PLOT_LOCATION '/webplots_e/data/swdfp/maps'
+            edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+            task swdfp_maps
+            task smaps_toweb1
+              trigger swdfp_maps eq complete
+            task smaps_toweb2
+              trigger swdfp_maps eq complete
+            task smaps_toweb3
+              trigger swdfp_maps eq complete
+            task swdfp_clean
+              trigger smaps_toweb1 eq complete and smaps_toweb2 eq complete and smaps_toweb3 eq complete
+          endfamily
+          task swdfp_satplot
+            edit STEPS '00/06/12/15/18/24/30/36/39/42/48'
+          task swdfp_tephi
+            edit METVIEW '/usr/local/share/metview_old'
+            edit STEPS '00/06/12/18/24/30/36/42/48/54/60/66/72'
+          task swdfp_obs_mslp
+            edit PLOTDOM '-37/3/-3/55'
+          task swdfp_metgram
+        endfamily
+      endfamily
+      family paper
+        task pobstat
+          trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12/fb/obstat_merge eq complete)
+          edit FSFAMILY 'an'
+          edit WSHOST 'linux_cluster'
+          edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+      endfamily
+      family verify
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/verify'
+        family consistency
+          edit ECFS_OPTIONS '-o'
+          edit ECMWF 'ECMWF24'
+          edit BRACKNELL 'BRAKL24'
+          edit OFFENBACH 'OFFNB24'
+          edit WASHINGTON 'WASHN24'
+          edit DATEMASK '02.*.*'
+          task create_daily_files
+            edit DATEMASK '02.*.*'
+          task create_monthly_files
+            trigger create_daily_files eq complete
+            edit DATEMASK '02.01.*'
+          task ecmwf
+            trigger create_monthly_files eq complete
+            edit DATEMASK '02.*.*'
+          task bracknell
+            trigger create_monthly_files eq complete
+            edit DATEMASK '02.*.*'
+          task offenbach
+            trigger create_monthly_files eq complete
+            edit DATEMASK '02.*.*'
+          task washington
+            trigger create_monthly_files eq complete
+            edit DATEMASK '02.*.*'
+        endfamily
+      endfamily
+      task cleanup
+        trigger web eq complete
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        inlimit /e_36r1/limits:webplots
+    endfamily
+    family 00dc
+      edit EMOS_BASE '00'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
+      family web
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+        family an
+          task pincr
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00dc/an eq complete)
+            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+            edit UPDATE_WEB_NOW 'yes'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            inlimit /e_36r1/limits:webplots
+        endfamily
+        family monitoring
+          edit UPDATE_WEB_NOW 'yes'
+          family satmon
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            inlimit /limits:linux_cluster
+            task satmon
+              trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00dc/satmon eq complete)
+            family airs
+              trigger satmon eq complete
+              edit SATELLITE 'airs'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family noaa
+              trigger satmon eq complete
+              edit SATELLITE 'noaa'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family ears
+              trigger satmon eq complete
+              edit SATELLITE 'ears'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family geos
+              trigger satmon eq complete
+              edit SATELLITE 'geos'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family o3
+              trigger satmon eq complete
+              edit SATELLITE 'o3'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family o3knmi
+              trigger satmon eq complete
+              edit SATELLITE 'o3knmi'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family temp
+              trigger satmon eq complete
+              edit SATELLITE 'temp'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family pwc
+              trigger satmon eq complete
+              edit SATELLITE 'pwc'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family amv_speed
+              trigger satmon eq complete
+              edit SATELLITE 'amv_speed'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family dmsp
+              trigger satmon eq complete
+              edit SATELLITE 'dmsp'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family gpsro
+              trigger satmon eq complete
+              edit SATELLITE 'gpsro'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family tmi
+              trigger satmon eq complete
+              edit SATELLITE 'tmi'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family ssmis
+              trigger satmon eq complete
+              edit SATELLITE 'ssmis'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family amsre
+              trigger satmon eq complete
+              edit SATELLITE 'amsre'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family iasi
+              trigger satmon eq complete
+              edit SATELLITE 'iasi'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family pacrars
+              trigger satmon eq complete
+              edit SATELLITE 'pacrars'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family dbamv_speed
+              trigger satmon eq complete
+              edit SATELLITE 'dbamv_speed'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family meris
+              trigger satmon eq complete
+              edit SATELLITE 'meris'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family scatt_speed
+              trigger satmon eq complete
+              edit SATELLITE 'scatt_speed'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            family slmoist
+              trigger satmon eq complete
+              edit SATELLITE 'slmoist'
+              inlimit /e_36r1/limits:satmon
+              task w_satmon
+                edit PLOTALL 'true'
+                edit PLOTGEO 'false'
+              task w_satmon_geo
+                edit WEEKDAY 'saturday'
+                edit PLOTALL 'false'
+                edit PLOTGEO 'true'
+            endfamily
+            task web_daily
+              trigger airs eq complete and noaa eq complete and ears eq complete and geos eq complete and o3 eq complete and o3knmi eq complete and temp eq complete and pwc eq complete and amv_speed eq complete and dmsp eq complete and gpsro eq complete and tmi eq complete and ssmis eq complete and amsre eq complete and iasi eq complete and pacrars eq complete and dbamv_speed eq complete and meris eq complete and scatt_speed eq complete and slmoist eq complete
+            task web_weekly
+              trigger airs eq complete and noaa eq complete and ears eq complete and geos eq complete and o3 eq complete and o3knmi eq complete and temp eq complete and pwc eq complete and amv_speed eq complete and dmsp eq complete and gpsro eq complete and tmi eq complete and ssmis eq complete and amsre eq complete and iasi eq complete and pacrars eq complete and dbamv_speed eq complete and meris eq complete and scatt_speed eq complete and slmoist eq complete
+              edit WEEKDAY 'saturday'
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+    family 06dc
+      edit EMOS_BASE '06'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
+      family data
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
+        family bufr
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task feedback
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/00dc/archive/obs eq complete)
+        endfamily
+      endfamily
+      family web
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+        family an
+          task pincr
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/00dc/an eq complete and /e_36r1/pop/00dc/web/an/pincr eq complete)
+            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+            edit UPDATE_WEB_NOW 'yes'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            inlimit /e_36r1/limits:webplots
+        endfamily
+        family monitoring
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task w_coverage
+            trigger /e_36r1/pop/06dc/data/bufr eq complete
+        endfamily
+      endfamily
+      task cleanup
+        trigger web eq complete
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        inlimit /e_36r1/limits:webplots
+    endfamily
+    family 12dc
+      edit EMOS_BASE '12'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
+      family web
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+        family an
+          task pincr
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12dc/an eq complete)
+            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+            edit UPDATE_WEB_NOW 'yes'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            inlimit /e_36r1/limits:webplots
+        endfamily
+      endfamily
+    endfamily
+    family 18dc
+      edit EMOS_BASE '18'
+      edit MXUP_TRAJ '3'
+      edit STREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '3'
+      edit EDFAMILY 'false'
+      edit PERIOD_4D '12'
+      edit FCLENGTH '15'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/pop'
+      family data
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/'
+        family bufr
+          edit SMSFILES '/home/ma/emos/def/e_36r1/pop/data/bufr'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task feedback
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/12dc/archive/obs eq complete)
+        endfamily
+      endfamily
+      family web
+        edit SMSFILES '/home/ma/emos/def/e_36r1/pop/web'
+        family an
+          task pincr
+            trigger ( /e_36r1/main:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/main:YMD eq /e_36r1/pop:YMD and /e_36r1/main/12dc/an eq complete and /e_36r1/pop/12dc/web/an/pincr eq complete)
+            edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+            edit UPDATE_WEB_NOW 'yes'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            inlimit /e_36r1/limits:webplots
+        endfamily
+        family monitoring
+          edit UPDATE_WEB_NOW 'yes'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          task w_coverage
+            trigger /e_36r1/pop/18dc/data/bufr eq complete
+        endfamily
+      endfamily
+      task cleanup
+        trigger web eq complete
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        inlimit /e_36r1/limits:webplots
+    endfamily
+    family 18bc
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '12'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+      edit EMOS_BASE '18'
+      family paper
+        family an
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FSFAMILY 'an'
+          inlimit /limits:linux_cluster
+          task pobstat
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/18bc/fb/obstat_merge eq complete)
+            edit PRIORITY '51'
+        endfamily
+      endfamily
+      task prod_2t
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'serial'
+        edit SMSFILES '/home/mo/moz/sms/other_smsfiles/global_efi/daily'
+        edit REFDATE '0'
+        edit EFI_PARAM '2t'
+    endfamily
+    family 06bc
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '12'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '1'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/plot'
+      edit EMOS_BASE '06'
+      family paper
+        family an
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FSFAMILY 'an'
+          inlimit /limits:linux_cluster
+          task pobstat
+            trigger ( /e_36r1/lag:YMD gt /e_36r1/pop:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/pop:YMD and /e_36r1/lag/06bc/fb/obstat_merge eq complete)
+            edit PRIORITY '51'
+        endfamily
+      endfamily
+      task prod_2t
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'serial'
+        edit SMSFILES '/home/mo/moz/sms/other_smsfiles/global_efi/daily'
+        edit REFDATE '0'
+        edit EFI_PARAM '2t'
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'pop'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ../main/make eq complete and ./00 eq complete and ./12 eq complete and ./00dc eq complete and ./06dc eq complete and ./12dc eq complete and ./18dc eq complete and ./18bc eq complete and ./06bc eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'pop'
+      edit MOVE_TO_ECFS 'no'
+      time 14:15
+  endfamily
+  family msjobs
+    complete ( /e_36r1/msjobs:YMD le /e_36r1/main:YMD) and /e_36r1/main/logfiles eq active
+    trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD or ( /e_36r1/lag:YMD gt /e_36r1/msjobs:YMD)) or ( /e_36r1/lag:YMD eq /e_36r1/msjobs:YMD or ( /e_36r1/pop:YMD gt /e_36r1/msjobs:YMD)) or ( /e_36r1/pop:YMD eq /e_36r1/msjobs:YMD)
+    repeat date YMD 20091118 20121212 1
+    edit SMSURLBASE 'http://ecgate.ecmwf.int:9080/'
+    edit SMSURL 'do/events'
+    family 12
+      edit EMOS_BASE '12'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '-1'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
+      edit SMSTRYNO '1'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'ecgate'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGDIR '/vol/emos_nc/output'
+      family mstraj
+        trigger ( /e_36r1/lag:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/msjobs:YMD and /e_36r1/lag/12/traj/cp_to_other eq complete)
+        edit MSJ_DIR 'tr12h000'
+        time 18:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms_an06
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/12/an eq complete and ( ../../main/12/fc/model:step gt 000 or ../../main/12/fc/model eq complete))
+        edit MSJ_DIR 'an06h000'
+        edit EMOS_BASE '06'
+        time 17:40
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms000
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/12/an eq complete and ( ../../main/12/fc/model:step gt 009 or ../../main/12/fc/model eq complete))
+        edit MSJ_DIR 'an12h000'
+        time 17:40
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms036
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 036 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/036/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0036'
+        edit MSJ_DIR 'fc12h036'
+        time 17:56
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms072
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 072 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/072/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0072'
+        edit MSJ_DIR 'fc12h072'
+        time 18:06
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms144
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 144 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/144/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0144'
+        edit MSJ_DIR 'fc12h144'
+        time 18:27
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms240
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc/model:step gt 240 or /e_36r1/main/12/fc/model eq complete) and /e_36r1/main/12/prod/240/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0240'
+        edit MSJ_DIR 'fc12h240'
+        time 18:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family mswave
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/12/fc/model eq complete)
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'wg12h240'
+        time 18:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family msmetgram
+        trigger ( /e_36r1/pop:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/pop:YMD eq /e_36r1/msjobs:YMD and /e_36r1/pop/12/data/metgram eq complete)
+        edit MSJ_DIR 'fc12hmetgram'
+        time 18:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      task test_ll
+        edit MSJ_DIR 'test_ll'
+        edit USE_NEW_MSJ 'true'
+    endfamily
+    family 00
+      edit EMOS_BASE '00'
+      edit MXUP_TRAJ '3'
+      edit REINISTREAM 'DCDA'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit REINITIALIZE 'true'
+      edit EDFAMILY 'true'
+      edit PERIOD_4D '6'
+      edit FCLENGTH '9'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
+      edit SMSTRYNO '1'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'ecgate'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGDIR '/vol/emos_nc/output'
+      family mstraj
+        trigger ( /e_36r1/lag:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/lag:YMD eq /e_36r1/msjobs:YMD and /e_36r1/lag/00/traj/cp_to_other eq complete)
+        edit MSJ_DIR 'tr12h000'
+        time 06:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms_an18
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/00/an eq complete and ( ../../main/00/fc/model:step gt 000 or ../../main/00/fc/model eq complete))
+        edit DELTA_DAY '0'
+        edit EMOS_BASE '18'
+        edit MSJ_DIR 'an18h000'
+        time 05:40
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms000
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/00/an eq complete and ( ../../main/00/fc/model:step gt 009 or ../../main/00/fc/model eq complete))
+        edit MSJ_DIR 'an00h000'
+        time 05:40
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms036
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 036 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/036/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0036'
+        edit MSJ_DIR 'fc00h036'
+        time 05:56
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms072
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 072 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/072/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0072'
+        edit MSJ_DIR 'fc00h072'
+        time 06:06
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms144
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 144 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/144/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0144'
+        edit MSJ_DIR 'fc00h144'
+        time 06:27
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms240
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc/model:step gt 240 or /e_36r1/main/00/fc/model eq complete) and /e_36r1/main/00/prod/240/derived_param eq complete)
+        edit EMOS_TIME_STEP_H '0240'
+        edit MSJ_DIR 'fc00h240'
+        time 06:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family mswave
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and /e_36r1/main/00/fc/model eq complete)
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'wg00h240'
+        time 06:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family msmetgram
+        trigger ( /e_36r1/pop:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/pop:YMD eq /e_36r1/msjobs:YMD and /e_36r1/pop/00/data/metgram eq complete)
+        edit MSJ_DIR 'fc00hmetgram'
+        time 06:55
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      task test_ll
+        edit MSJ_DIR 'test_ll'
+        edit USE_NEW_MSJ 'true'
+    endfamily
+    family 12bc
+      edit EMOS_BASE '12'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '-1'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
+      edit SMSTRYNO '1'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'ecgate'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGDIR '/vol/emos_nc/output'
+      family ms012
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc eq complete or /e_36r1/main/12/fc/model:step gt 012))
+        edit EMOS_TIME_STEP_H '0012'
+        edit MSJ_DIR 'bc12h012'
+        time 17:49
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms072
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/12/fc eq complete or /e_36r1/main/12/fc/model:step gt 072))
+        edit EMOS_TIME_STEP_H '0072'
+        edit MSJ_DIR 'bc12h072'
+        time 18:06
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+    endfamily
+    family 18bc
+      edit EMOS_BASE '18'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '-1'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
+      edit SMSTRYNO '1'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'ecgate'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGDIR '/vol/emos_nc/output'
+      family ms012
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/18bc/fc eq complete or /e_36r1/main/18bc/fc/model:step gt 012))
+        edit EMOS_TIME_STEP_H '0012'
+        edit MSJ_DIR 'bc18h012'
+        time 23:49
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms072
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/18bc/fc eq complete or /e_36r1/main/18bc/fc/model:step gt 072))
+        edit EMOS_TIME_STEP_H '0072'
+        edit MSJ_DIR 'bc18h072'
+        time 00:06
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+    endfamily
+    family 00bc
+      edit EMOS_BASE '00'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
+      edit SMSTRYNO '1'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'ecgate'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGDIR '/vol/emos_nc/output'
+      family ms012
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc eq complete or /e_36r1/main/00/fc/model:step gt 012))
+        edit EMOS_TIME_STEP_H '0012'
+        edit MSJ_DIR 'bc00h012'
+        time 05:49
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms072
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/00/fc eq complete or /e_36r1/main/00/fc/model:step gt 072))
+        edit EMOS_TIME_STEP_H '0072'
+        edit MSJ_DIR 'bc00h072'
+        time 06:06
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+    endfamily
+    family 06bc
+      edit EMOS_BASE '06'
+      edit EDFAMILY 'false'
+      edit INISTREAM 'DA'
+      edit REINITIALIZE 'false'
+      edit REINIEXPVER '0046'
+      edit INIEXPVER '0045'
+      edit REINIPERIOD_4D '6'
+      edit REINISTREAM 'DA'
+      edit REINIOFFSET '6'
+      edit RUN_HOURLY_PP '0'
+      edit PERIOD_4D '6'
+      edit WINDOW_LENGTH_4D '12'
+      edit WINDOW_OFFSET_4D '9'
+      edit MXUP_TRAJ '3'
+      edit PARALLEL '4'
+      edit LANONLY 'false'
+      edit ACCOUNT 'opebcmis'
+      edit STREAM 'SCDA'
+      edit EMOS_STREAM 'SCDA'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/e_36r1/msjobs'
+      edit SMSTRYNO '1'
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'ecgate'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGDIR '/vol/emos_nc/output'
+      family ms012
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/06bc/fc eq complete or /e_36r1/main/06bc/fc/model:step gt 012))
+        edit EMOS_TIME_STEP_H '0012'
+        edit MSJ_DIR 'bc06h012'
+        time 11:49
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+      family ms072
+        trigger ( /e_36r1/main:YMD gt /e_36r1/msjobs:YMD) or ( /e_36r1/main:YMD eq /e_36r1/msjobs:YMD and ( /e_36r1/main/06bc/fc eq complete or /e_36r1/main/06bc/fc/model:step gt 072))
+        edit EMOS_TIME_STEP_H '0072'
+        edit MSJ_DIR 'bc06h072'
+        time 12:06
+        task ms_ec
+          edit SMSTRIES '1'
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'msjobs'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger ./12 eq complete and ./00 eq complete and ./12bc eq complete and ./18bc eq complete and ./00bc eq complete and ./06bc eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit SMSFILES '/home/ma/emos/def/e_36r1'
+      edit LOGTASK 'msjobs'
+      edit MOVE_TO_ECFS 'no'
+      time 14:20
+  endfamily
+endsuite
+suite emc_36r1
+  edit USER 'emos'
+  edit SCHOST 'c1b'
+  edit STHOST '/s1b'
+  edit SCHOST_BKUP 'c1a'
+  edit STHOST_BKUP '/s1a'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit USE_YMD 'true'
+  edit YMD '20091003'
+  edit DATEMASK '*.*.*'
+  edit VERSION '0046'
+  edit INIEXPVER '0046'
+  edit TCINIEXPVER '0046'
+  edit FIRST_DAY '1'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '12'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY 'mc'
+  edit IMPL_DATE '2012123112'
+  edit EVERSION '0001'
+  edit USER_PRIORITY '70'
+  edit ININPES '24'
+  edit FCNPES '32'
+  edit PGNPES '32'
+  edit ANNPES '4'
+  edit REINITIALIZE 'false'
+  edit RESERVATION_ON '0'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/emc_36r1'
+  edit SMSINCLUDE '/home/ma/emos/def/emc_36r1/include'
+  edit ACCOUNT 'oeenfo'
+  edit STREAM 'EF'
+  edit EMOS_STREAM 'EF'
+  edit ENSEMBLES '50'
+  edit ENS_SIZE '50'
+  edit MARS_DB 'marsod'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit INILEVELS '91'
+  edit INIPERIOD_4D '6'
+  edit IS_REAL_TIME 'is_real_time'
+  edit RUN_3HOURS_PP '1'
+  edit RUNHINDCAST '0'
+  edit ERA40END '2002073100'
+  edit NH_YEARS '18'
+  edit NH_WEEKS '2'
+  edit PGEN_BINDIR '/home/ma/emos/bin/diss'
+  edit PGEN_OBJDIR '/home/ma/emos/bin/diss'
+  edit DISS_REQDB_ROOT '/diss/requirements'
+  edit DISS_BINDIR '/diss/bin/DISS'
+  edit DELTA_DAY_M '-15'
+  edit DELTA_DAY_P '25'
+  edit FCGTYPE 'l_2'
+  edit EPSFCGTYPE 'l_2'
+  edit LUSE_RSTRHBIAS 'true'
+  edit FCGROUP 'fc0'
+  edit SMSLOGHOST 'c1b'
+  edit SMSLOGPORT '9316'
+  edit COURTESY '0'
+  edit OCNPES_OC '8'
+  edit OCNPES_IFS '56'
+  edit OD_PROJ 'od'
+  edit SMSURLBASE 'http://datasvc.ecmwf.int/twiki/bin/view/Main'
+  edit SMSURL 'CurrentAndOldESuites'
+  edit SUITE_START '20091004'
+  edit PRODUCE_EPS_ML '1'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit.map %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+  edit NOEFI '0'
+  edit SLEEPTIME '1'
+  inlimit /limits:c1b
+  clock hybrid 
+  family hc0
+    repeat date YMD 20091008 20121212 7
+    edit ACCOUNT 'oeenfo'
+    edit LOGTASK 'hc0'
+    edit QUEUE 'ns'
+    edit QUEUE_EPILOG 'ns'
+    edit ENSEMBLES '4'
+    edit ENS_SIZE '4'
+    edit RUNHINDCAST '1'
+    edit STREAM 'ENFH'
+    edit EMOS_STREAM 'ENFH'
+    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+    edit EMOS_BASE '00'
+    edit INICLASS 'EI'
+    edit INIEXPVER '0001'
+    edit INILEVELS '60'
+    edit DELETE_FAMILY 'true'
+    family back
+      trigger /emc_36r1/main/make eq complete
+      edit RUNVARFC '1'
+      edit YMD '20091217'
+      inlimit /emc_36r1/limits:hind
+      task stage_hc
+        edit RUNVARFC '1'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+      task rmfdb
+        trigger stage_hc eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+        edit NH_WEEKS_KEPT '1'
+      task lock_fam
+        trigger 0 eq 1
+      task lock_1701
+        complete ./18 eq complete
+        trigger 0 eq 1
+      family 18
+        trigger ./rmfdb eq complete
+        edit DELTA_YEAR '-18'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 17
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-17'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 16
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-16'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 15
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-15'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 14
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-14'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 13
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-13'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 12
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-12'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 11
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-11'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 10
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-10'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 09
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-09'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 08
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-08'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 07
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-07'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 06
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-06'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 05
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-05'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 04
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-04'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 03
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-03'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 02
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-02'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+      family 01
+        trigger ( ./rmfdb eq complete) and ( ./lock_1701 eq complete)
+        edit DELTA_YEAR '-01'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      endfamily
+    endfamily
+    family arch
+      edit EMOS_TYPE 'an'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+      edit FSFAMILY 'mars'
+      edit OVERLAP '0'
+      edit YMD '20100121'
+      limit mutex 1
+      inlimit /emc_36r1/limits:mars
+      inlimit /limits:mars
+      family 18
+        trigger ( ../back/18 eq complete)
+        edit DELTA_YEAR '-18'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/18/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 17
+        trigger ( ../back/17 eq complete)
+        edit DELTA_YEAR '-17'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/17/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 16
+        trigger ( ../back/16 eq complete)
+        edit DELTA_YEAR '-16'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/16/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 15
+        trigger ( ../back/15 eq complete)
+        edit DELTA_YEAR '-15'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/15/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 14
+        trigger ( ../back/14 eq complete)
+        edit DELTA_YEAR '-14'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/14/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 13
+        trigger ( ../back/13 eq complete)
+        edit DELTA_YEAR '-13'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/13/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 12
+        trigger ( ../back/12 eq complete)
+        edit DELTA_YEAR '-12'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/12/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 11
+        trigger ( ../back/11 eq complete)
+        edit DELTA_YEAR '-11'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/11/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 10
+        trigger ( ../back/10 eq complete)
+        edit DELTA_YEAR '-10'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/10/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 09
+        trigger ( ../back/09 eq complete)
+        edit DELTA_YEAR '-09'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/09/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 08
+        trigger ( ../back/08 eq complete)
+        edit DELTA_YEAR '-08'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/08/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 07
+        trigger ( ../back/07 eq complete)
+        edit DELTA_YEAR '-07'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/07/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 06
+        trigger ( ../back/06 eq complete)
+        edit DELTA_YEAR '-06'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/06/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 05
+        trigger ( ../back/05 eq complete)
+        edit DELTA_YEAR '-05'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/05/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 04
+        trigger ( ../back/04 eq complete)
+        edit DELTA_YEAR '-04'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/04/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 03
+        trigger ( ../back/03 eq complete)
+        edit DELTA_YEAR '-03'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/03/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 02
+        trigger ( ../back/02 eq complete)
+        edit DELTA_YEAR '-02'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/02/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 01
+        trigger ( ../back/01 eq complete)
+        edit DELTA_YEAR '-01'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+    endfamily
+    family postproc
+      trigger ./back eq complete and ( ../hc2:YMD gt ../hc0:YMD or ( ../hc2:YMD eq ../hc0:YMD and ../hc2/back eq complete))
+      edit EMOS_TYPE '00'
+      edit FCCHUNK '1'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+      inlimit /emc_36r1/limits:postproc
+      task stage_hc
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+      family legA
+        trigger ./stage_hc eq complete
+        edit FCLENGTH0 '0'
+        edit FCLENGTH '240'
+        edit EPSFCRES '399'
+        edit FCCHUNK '1'
+        edit STEP1 '0'
+        edit STEP2 '240'
+        task ensm
+        family reord
+          edit EPSCOUPLE '1'
+          edit EMOS_TYPE 'pf'
+          edit FCLENGTH0 '0'
+          edit FCLENGTH '240'
+          edit EPSFCRES '399'
+          edit FCCHUNK '1'
+          edit STEP1 '0'
+          edit STEP2 '240'
+          edit STEPS '-1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+          edit RUNVARFC '1'
+          limit reord 1
+          inlimit reord
+          label info ""
+          family 130
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '130.128'
+            task reord
+              label info ""
+          endfamily
+          family 228
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '228.128'
+            task reord
+              label info ""
+          endfamily
+          family 207
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '207.128'
+            task reord
+              label info ""
+          endfamily
+          family 167
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '167.128'
+            task reord
+              label info ""
+          endfamily
+          family 164
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '164.128'
+            task reord
+              label info ""
+          endfamily
+          family arch
+            trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
+            edit GENERATE '0'
+            edit ARCHIVE '1'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task reord
+              label info ""
+          endfamily
+        endfamily
+      endfamily
+      family legB
+        trigger legA eq complete
+        edit FCLENGTH0 '240'
+        edit FCLENGTH '768'
+        edit EPSFCRES '255'
+        edit FCCHUNK '1'
+        edit STEP1 '240'
+        edit STEP2 '768'
+        task ensm
+        family reord
+          edit EPSCOUPLE '1'
+          edit EMOS_TYPE 'pf'
+          edit FCLENGTH0 '240'
+          edit FCLENGTH '768'
+          edit EPSFCRES '255'
+          edit FCCHUNK '1'
+          edit STEP1 '240'
+          edit STEP2 '768'
+          edit STEPS '-1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+          edit RUNVARFC '1'
+          limit reord 1
+          inlimit reord
+          label info ""
+          family 130
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '130.128'
+            task reord
+              label info ""
+          endfamily
+          family 228
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '228.128'
+            task reord
+              label info ""
+          endfamily
+          family 207
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '207.128'
+            task reord
+              label info ""
+          endfamily
+          family 167
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '167.128'
+            task reord
+              label info ""
+          endfamily
+          family 164
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '164.128'
+            task reord
+              label info ""
+          endfamily
+          family arch
+            trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
+            edit GENERATE '0'
+            edit ARCHIVE '1'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task reord
+              label info ""
+          endfamily
+        endfamily
+      endfamily
+      task wmem_veps
+        trigger legA eq complete and legB eq complete
+        edit EMOS_TYPE 'UNDEF'
+        edit FCCHUNK '1'
+        edit FCLENGTH '768'
+      task wmem_archive
+        trigger wmem_veps eq complete and ./legA eq complete and ./legB eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+        edit FCLENGTH '768'
+        label info ""
+      family clim
+        trigger ../arch eq complete and ./stage_hc eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg/clim'
+        edit CLIM_FC_YEARS '0'
+        edit OCSUITE 'vareps'
+        edit ERA40 'YES'
+        edit START_DAY '20091008'
+        edit END_DAY '20121213'
+        edit RUNVARFC '1'
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /limits:linux_cluster
+        family init
+          task listclim
+          task getdata
+            trigger listclim eq complete
+          task getobsclim
+            trigger getdata eq complete
+        endfamily
+        family bias
+          trigger init eq complete
+          task cal_bias
+          task plot_bias
+            trigger cal_bias eq complete
+          task plot_clim
+            trigger plot_bias eq complete
+          task cal_zondia
+            trigger plot_clim eq complete
+          task plot_zondia
+            trigger cal_zondia eq complete
+          task migrate_bias
+            trigger plot_zondia eq complete
+          task clean_bias
+            trigger migrate_bias eq complete
+          task clean
+            trigger clean_bias eq complete
+        endfamily
+      endfamily
+    endfamily
+    family prod
+      trigger ./back eq complete and ./postproc eq complete
+      edit SMSFILES '/home/ma/emos/def/mc/prod'
+      edit EMOS_DOMAIN 'G'
+      edit EMOS_TYPE 'FC'
+      edit PROD_TASK '1'
+      edit EMOS_PROJECT '00'
+      edit EMOS_BASE '00'
+      edit PGNPES '32'
+      edit EMOS_STREAM 'ENFH'
+      family getreq
+        trigger ../back eq complete
+        edit EMOS_TYPE 'cm'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_PROJECT '12'
+        edit PROD_TASK '1'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'ENFH'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_BASE '00'
+        task eps
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectwave
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit EMOS_STREAM 'ENWH'
+        task wave_eps
+          trigger collectwave eq complete
+          edit EMOS_STREAM 'ENWH'
+          label info ""
+          event 1 
+      endfamily
+      family eps
+        trigger ../back eq complete and ( ./getreq/eps eq complete or ./getreq/eps:001)
+        edit EMOS_STREAM 'ENFH'
+        family day01
+          edit EMOS_TIME_STEP_H '0001'
+          task prodgen
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ./pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day02
+          edit EMOS_TIME_STEP_H '0002'
+          task prodgen
+            trigger ../day01/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day01/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day03
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            trigger ../day02/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day02/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day04
+          edit EMOS_TIME_STEP_H '0004'
+          task prodgen
+            trigger ../day03/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day03/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day05
+          edit EMOS_TIME_STEP_H '0005'
+          task prodgen
+            trigger ../day04/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day04/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day06
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            trigger ../day05/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day05/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day07
+          edit EMOS_TIME_STEP_H '0007'
+          task prodgen
+            trigger ../day06/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day06/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day08
+          edit EMOS_TIME_STEP_H '0008'
+          task prodgen
+            trigger ../day07/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day07/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day09
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            trigger ../day08/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day08/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day10
+          edit EMOS_TIME_STEP_H '0010'
+          task prodgen
+            trigger ../day09/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day09/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day11
+          edit EMOS_TIME_STEP_H '0011'
+          task prodgen
+            trigger ../day10/prodgen eq complete
+            edit MEM '1900'
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day10/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day12
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            trigger ../day11/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day11/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day13
+          edit EMOS_TIME_STEP_H '0013'
+          task prodgen
+            trigger ../day12/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day12/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day14
+          edit EMOS_TIME_STEP_H '0014'
+          task prodgen
+            trigger ../day13/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day13/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day15
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            trigger ../day14/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day14/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day16
+          edit EMOS_TIME_STEP_H '0016'
+          task prodgen
+            trigger ../day15/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day15/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day17
+          edit EMOS_TIME_STEP_H '0017'
+          task prodgen
+            trigger ../day16/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day16/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day18
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            trigger ../day17/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day17/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day19
+          edit EMOS_TIME_STEP_H '0019'
+          task prodgen
+            trigger ../day18/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day18/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day20
+          edit EMOS_TIME_STEP_H '0020'
+          task prodgen
+            trigger ../day19/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day19/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day21
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            trigger ../day20/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day20/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day22
+          edit EMOS_TIME_STEP_H '0022'
+          task prodgen
+            trigger ../day21/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day21/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day23
+          edit EMOS_TIME_STEP_H '0023'
+          task prodgen
+            trigger ../day22/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day22/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day24
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            trigger ../day23/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day23/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day25
+          edit EMOS_TIME_STEP_H '0025'
+          task prodgen
+            trigger ../day24/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day24/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day26
+          edit EMOS_TIME_STEP_H '0026'
+          task prodgen
+            trigger ../day25/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day25/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day27
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            trigger ../day26/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day26/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day28
+          edit EMOS_TIME_STEP_H '0028'
+          task prodgen
+            trigger ../day27/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day27/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day29
+          edit EMOS_TIME_STEP_H '0029'
+          task prodgen
+            trigger ../day28/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day28/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day30
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            trigger ../day29/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day29/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day31
+          edit EMOS_TIME_STEP_H '0031'
+          task prodgen
+            trigger ../day30/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day30/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day32
+          edit EMOS_TIME_STEP_H '0032'
+          task prodgen
+            trigger ../day31/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day31/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day33
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            trigger ../day32/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day32/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+      endfamily
+      family wave
+        trigger ../back eq complete and ( ./getreq/wave_eps eq complete or ./getreq/eps:001)
+        edit PGNPES '4'
+        edit EMOS_STREAM 'ENWH'
+        family day01
+          edit EMOS_TIME_STEP_H '0001'
+          task prodgen
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ./pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day02
+          edit EMOS_TIME_STEP_H '0002'
+          task prodgen
+            trigger ../day01/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day01/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day03
+          edit EMOS_TIME_STEP_H '0003'
+          task prodgen
+            trigger ../day02/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day02/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day04
+          edit EMOS_TIME_STEP_H '0004'
+          task prodgen
+            trigger ../day03/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day03/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day05
+          edit EMOS_TIME_STEP_H '0005'
+          task prodgen
+            trigger ../day04/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day04/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day06
+          edit EMOS_TIME_STEP_H '0006'
+          task prodgen
+            trigger ../day05/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day05/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day07
+          edit EMOS_TIME_STEP_H '0007'
+          task prodgen
+            trigger ../day06/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day06/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day08
+          edit EMOS_TIME_STEP_H '0008'
+          task prodgen
+            trigger ../day07/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day07/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day09
+          edit EMOS_TIME_STEP_H '0009'
+          task prodgen
+            trigger ../day08/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day08/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day10
+          edit EMOS_TIME_STEP_H '0010'
+          task prodgen
+            trigger ../day09/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day09/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day11
+          edit EMOS_TIME_STEP_H '0011'
+          task prodgen
+            trigger ../day10/prodgen eq complete
+            edit MEM '1900'
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day10/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day12
+          edit EMOS_TIME_STEP_H '0012'
+          task prodgen
+            trigger ../day11/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day11/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day13
+          edit EMOS_TIME_STEP_H '0013'
+          task prodgen
+            trigger ../day12/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day12/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day14
+          edit EMOS_TIME_STEP_H '0014'
+          task prodgen
+            trigger ../day13/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day13/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day15
+          edit EMOS_TIME_STEP_H '0015'
+          task prodgen
+            trigger ../day14/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day14/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day16
+          edit EMOS_TIME_STEP_H '0016'
+          task prodgen
+            trigger ../day15/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day15/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day17
+          edit EMOS_TIME_STEP_H '0017'
+          task prodgen
+            trigger ../day16/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day16/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day18
+          edit EMOS_TIME_STEP_H '0018'
+          task prodgen
+            trigger ../day17/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day17/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day19
+          edit EMOS_TIME_STEP_H '0019'
+          task prodgen
+            trigger ../day18/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day18/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day20
+          edit EMOS_TIME_STEP_H '0020'
+          task prodgen
+            trigger ../day19/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day19/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day21
+          edit EMOS_TIME_STEP_H '0021'
+          task prodgen
+            trigger ../day20/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day20/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day22
+          edit EMOS_TIME_STEP_H '0022'
+          task prodgen
+            trigger ../day21/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day21/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day23
+          edit EMOS_TIME_STEP_H '0023'
+          task prodgen
+            trigger ../day22/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day22/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day24
+          edit EMOS_TIME_STEP_H '0024'
+          task prodgen
+            trigger ../day23/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day23/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day25
+          edit EMOS_TIME_STEP_H '0025'
+          task prodgen
+            trigger ../day24/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day24/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day26
+          edit EMOS_TIME_STEP_H '0026'
+          task prodgen
+            trigger ../day25/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day25/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day27
+          edit EMOS_TIME_STEP_H '0027'
+          task prodgen
+            trigger ../day26/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day26/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day28
+          edit EMOS_TIME_STEP_H '0028'
+          task prodgen
+            trigger ../day27/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day27/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day29
+          edit EMOS_TIME_STEP_H '0029'
+          task prodgen
+            trigger ../day28/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day28/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day30
+          edit EMOS_TIME_STEP_H '0030'
+          task prodgen
+            trigger ../day29/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day29/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day31
+          edit EMOS_TIME_STEP_H '0031'
+          task prodgen
+            trigger ../day30/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day30/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day32
+          edit EMOS_TIME_STEP_H '0032'
+          task prodgen
+            trigger ../day31/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day31/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+        family day33
+          edit EMOS_TIME_STEP_H '0033'
+          task prodgen
+            trigger ../day32/prodgen eq complete
+          task pdb
+            trigger prodgen eq complete
+            inlimit /emc_36r1/limits:pdb
+            inlimit /limits:pdb
+            label info ""
+            event 1 
+          task q2diss
+            late -s +00:05 -c +00:15
+            trigger ../day32/q2diss eq complete and pdb eq complete
+            edit USER_PRIORITY '93'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event 1 
+        endfamily
+      endfamily
+    endfamily
+    family adm
+      task hindsync
+        trigger ../back eq complete and ../arch eq complete and ../postproc eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+        edit NH_WEEKS_KEPT '3'
+        edit BACKUP_HCFDB '0'
+      family fri
+        complete ./fri/compl eq complete and ./fri/dummy eq queued
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+        task dummy
+          cron -w 5 09:00
+        task compl
+          complete dummy eq active or dummy eq submitted or dummy eq complete
+          trigger 1 eq 0
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:25
+      trigger logfilestore eq complete and back eq complete and arch eq complete and postproc eq complete and prod eq complete and adm eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+  family 00
+    repeat date YMD 20091007 20121212 7
+    edit DELTA_DAY '1'
+    edit ACCOUNT 'oeenfo'
+    edit LOGTASK '00'
+    edit EMOS_BASE '00'
+    edit QUEUE 'os'
+    family ref
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+      family thu1000
+        complete ./thu1000/compl eq complete and ./thu1000/dummy eq queued
+        task dummy
+        task compl
+          complete ./dummy eq active or ./dummy eq submitted
+          trigger 1 eq 0
+      endfamily
+      family thu2200
+        complete ./thu2200/compl eq complete and ./thu2200/dummy eq queued
+        task dummy
+        task compl
+          complete ./dummy eq active or ./dummy eq submitted
+          trigger 1 eq 0
+      endfamily
+      family wed
+        complete ./wed/compl eq complete and ./wed/dummy eq queued
+        task dummy
+          cron -w 3 18:30
+        task compl
+          complete ./dummy eq active or ./dummy eq submitted
+          trigger 1 eq 0
+      endfamily
+      family tue
+        complete ./tue/compl eq complete and ./tue/dummy eq queued
+        task dummy
+          cron -w 2 08:00
+        task compl
+          complete ./dummy eq active or ./dummy eq submitted
+          trigger 1 eq 0
+      endfamily
+    endfamily
+    family legC
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete and /emc_36r1/main/make eq complete)
+      edit EPSCOUPLE '1'
+      edit RUNCOUPLE '1'
+      edit EPSLEG '3'
+      edit EPSFCLENGTH_C '408'
+      family fc
+        edit FCMEM '2240'
+        edit FCSTACK '700'
+        edit FCMRFS '0'
+        edit PRIORITY '69'
+        edit USER_PRIORITY '69'
+        edit N_PERT_AN '10'
+        edit EPSWAMNFRE '25'
+        edit EPSWAMNANG '12'
+        edit TSTEP '2700'
+        edit EPSFCRES '639'
+        edit RESOL '639'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+        edit CPUTIME '1000'
+        edit MEM '960'
+        edit THREADS '8'
+        edit NPES '8'
+        edit EPSLEG '3'
+        family pf
+          complete /emc_36r1/main/ref/00/events:cf
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit EPSTYPE 'pf'
+          edit EMOS_TYPE 'pf'
+          edit USER_PRIORITY '69'
+          edit PRIORITY '69'
+          edit FCNPES '32'
+          edit EPSNLEGS '3'
+          edit EPSFCLEV '62'
+          edit EPSWAMNSTPW '1'
+          edit EPSINISTEP_PREVIOUS '0'
+          edit EPSWAMRESOL 'global50'
+          edit EPSFCRES '639'
+          edit EPSWAMNFRE '30'
+          edit EPSWAMNANG '24'
+          edit FCLENGTH '240'
+          edit TSTEP '1200'
+          edit EPSLEG '3'
+          edit CLASS 'od'
+          edit THREADS '2'
+          edit RUNVARFC '1'
+          inlimit /emc_36r1/limits:pftotal
+          meter step -1 408 408
+          family 01
+            edit EPSMEMBER '1'
+            edit MEMBER '1'
+            edit SUBFSFAMILY '/pf001'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/01 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 02
+            edit EPSMEMBER '2'
+            edit MEMBER '2'
+            edit SUBFSFAMILY '/pf002'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/02 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 03
+            edit EPSMEMBER '3'
+            edit MEMBER '3'
+            edit SUBFSFAMILY '/pf003'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/03 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 04
+            edit EPSMEMBER '4'
+            edit MEMBER '4'
+            edit SUBFSFAMILY '/pf004'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/04 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 05
+            edit EPSMEMBER '5'
+            edit MEMBER '5'
+            edit SUBFSFAMILY '/pf005'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/05 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 06
+            edit EPSMEMBER '6'
+            edit MEMBER '6'
+            edit SUBFSFAMILY '/pf006'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/06 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 07
+            edit EPSMEMBER '7'
+            edit MEMBER '7'
+            edit SUBFSFAMILY '/pf007'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/07 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 08
+            edit EPSMEMBER '8'
+            edit MEMBER '8'
+            edit SUBFSFAMILY '/pf008'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/08 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 09
+            edit EPSMEMBER '9'
+            edit MEMBER '9'
+            edit SUBFSFAMILY '/pf009'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/09 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 10
+            edit EPSMEMBER '10'
+            edit MEMBER '10'
+            edit SUBFSFAMILY '/pf010'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/10 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 11
+            edit EPSMEMBER '11'
+            edit MEMBER '11'
+            edit SUBFSFAMILY '/pf011'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/11 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 12
+            edit EPSMEMBER '12'
+            edit MEMBER '12'
+            edit SUBFSFAMILY '/pf012'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/12 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 13
+            edit EPSMEMBER '13'
+            edit MEMBER '13'
+            edit SUBFSFAMILY '/pf013'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/13 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 14
+            edit EPSMEMBER '14'
+            edit MEMBER '14'
+            edit SUBFSFAMILY '/pf014'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/14 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 15
+            edit EPSMEMBER '15'
+            edit MEMBER '15'
+            edit SUBFSFAMILY '/pf015'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/15 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 16
+            edit EPSMEMBER '16'
+            edit MEMBER '16'
+            edit SUBFSFAMILY '/pf016'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/16 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 17
+            edit EPSMEMBER '17'
+            edit MEMBER '17'
+            edit SUBFSFAMILY '/pf017'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/17 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 18
+            edit EPSMEMBER '18'
+            edit MEMBER '18'
+            edit SUBFSFAMILY '/pf018'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/18 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 19
+            edit EPSMEMBER '19'
+            edit MEMBER '19'
+            edit SUBFSFAMILY '/pf019'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/19 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 20
+            edit EPSMEMBER '20'
+            edit MEMBER '20'
+            edit SUBFSFAMILY '/pf020'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/20 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 21
+            edit EPSMEMBER '21'
+            edit MEMBER '21'
+            edit SUBFSFAMILY '/pf021'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/21 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 22
+            edit EPSMEMBER '22'
+            edit MEMBER '22'
+            edit SUBFSFAMILY '/pf022'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/22 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 23
+            edit EPSMEMBER '23'
+            edit MEMBER '23'
+            edit SUBFSFAMILY '/pf023'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/23 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 24
+            edit EPSMEMBER '24'
+            edit MEMBER '24'
+            edit SUBFSFAMILY '/pf024'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/24 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 25
+            edit EPSMEMBER '25'
+            edit MEMBER '25'
+            edit SUBFSFAMILY '/pf025'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/25 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 26
+            edit EPSMEMBER '26'
+            edit MEMBER '26'
+            edit SUBFSFAMILY '/pf026'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/26 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 27
+            edit EPSMEMBER '27'
+            edit MEMBER '27'
+            edit SUBFSFAMILY '/pf027'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/27 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 28
+            edit EPSMEMBER '28'
+            edit MEMBER '28'
+            edit SUBFSFAMILY '/pf028'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/28 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 29
+            edit EPSMEMBER '29'
+            edit MEMBER '29'
+            edit SUBFSFAMILY '/pf029'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/29 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 30
+            edit EPSMEMBER '30'
+            edit MEMBER '30'
+            edit SUBFSFAMILY '/pf030'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/30 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 31
+            edit EPSMEMBER '31'
+            edit MEMBER '31'
+            edit SUBFSFAMILY '/pf031'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/31 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 32
+            edit EPSMEMBER '32'
+            edit MEMBER '32'
+            edit SUBFSFAMILY '/pf032'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/32 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 33
+            edit EPSMEMBER '33'
+            edit MEMBER '33'
+            edit SUBFSFAMILY '/pf033'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/33 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 34
+            edit EPSMEMBER '34'
+            edit MEMBER '34'
+            edit SUBFSFAMILY '/pf034'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/34 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 35
+            edit EPSMEMBER '35'
+            edit MEMBER '35'
+            edit SUBFSFAMILY '/pf035'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/35 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 36
+            edit EPSMEMBER '36'
+            edit MEMBER '36'
+            edit SUBFSFAMILY '/pf036'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/36 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 37
+            edit EPSMEMBER '37'
+            edit MEMBER '37'
+            edit SUBFSFAMILY '/pf037'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/37 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 38
+            edit EPSMEMBER '38'
+            edit MEMBER '38'
+            edit SUBFSFAMILY '/pf038'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/38 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 39
+            edit EPSMEMBER '39'
+            edit MEMBER '39'
+            edit SUBFSFAMILY '/pf039'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/39 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 40
+            edit EPSMEMBER '40'
+            edit MEMBER '40'
+            edit SUBFSFAMILY '/pf040'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/40 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 41
+            edit EPSMEMBER '41'
+            edit MEMBER '41'
+            edit SUBFSFAMILY '/pf041'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/41 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 42
+            edit EPSMEMBER '42'
+            edit MEMBER '42'
+            edit SUBFSFAMILY '/pf042'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/42 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 43
+            edit EPSMEMBER '43'
+            edit MEMBER '43'
+            edit SUBFSFAMILY '/pf043'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/43 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 44
+            edit EPSMEMBER '44'
+            edit MEMBER '44'
+            edit SUBFSFAMILY '/pf044'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/44 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 45
+            edit EPSMEMBER '45'
+            edit MEMBER '45'
+            edit SUBFSFAMILY '/pf045'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/45 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 46
+            edit EPSMEMBER '46'
+            edit MEMBER '46'
+            edit SUBFSFAMILY '/pf046'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/46 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 47
+            edit EPSMEMBER '47'
+            edit MEMBER '47'
+            edit SUBFSFAMILY '/pf047'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/47 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 48
+            edit EPSMEMBER '48'
+            edit MEMBER '48'
+            edit SUBFSFAMILY '/pf048'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/48 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 49
+            edit EPSMEMBER '49'
+            edit MEMBER '49'
+            edit SUBFSFAMILY '/pf049'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/49 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+          family 50
+            edit EPSMEMBER '50'
+            edit MEMBER '50'
+            edit SUBFSFAMILY '/pf050'
+            task getvarepsdata
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/pf/50 eq complete)
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSFCRESN '319'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit THREADS '8'
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '1200'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '360'
+              edit EPSFCRES '319'
+              edit EPSLEG '3'
+              edit NPES '1'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '3'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '408'
+              edit EPSINISTEP_PREVIOUS '360'
+              edit FCLENGTH '408'
+              edit MEM '1600'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit EPSFCRESN '255'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNSTPW '1'
+              edit EPSFCLENGTH_B '360'
+              edit TSTEP '2700'
+              edit EPSFCLENGTH_A '240'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 408 408
+          endfamily
+        endfamily
+        family cf
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit MEMBER '0'
+          edit EPSMEMBER '0'
+          edit SUBFSFAMILY '/cf000'
+          edit EPSTYPE 'cf'
+          edit EMOS_TYPE 'cf'
+          edit USER_PRIORITY '70'
+          edit EPSNLEGS '3'
+          edit EPSFCLEV '62'
+          edit EPSWAMNSTPW '1'
+          edit EPSINISTEP_PREVIOUS '0'
+          edit EPSWAMRESOL 'global50'
+          edit EPSFCRES '639'
+          edit EPSWAMNFRE '30'
+          edit EPSWAMNANG '24'
+          edit TSTEP '1200'
+          edit EPSLEG '3'
+          edit CLASS 'od'
+          edit OCGROUP 'an0'
+          edit FCGROUP 'fc0'
+          edit FCCHUNK '1'
+          edit OCTOTAL '5'
+          edit FCTOTAL '51'
+          edit DAILY '0'
+          edit RUNVARFC '1'
+          edit FCLENGTH '408'
+          edit FCLENGTH1 '360'
+          task getvarepsdata
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legBcpl/fc/cf eq complete)
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit TSTEP '1200'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit EPSLEG '3'
+            edit EPSINISTEP '360'
+            edit EPSFCRES '319'
+            edit EPSFCRESN '319'
+            edit EPSWAMNSTPW '1'
+            edit EPSFCLENGTH_B '360'
+            edit CLASS 'od'
+          task intHtoL
+            trigger getvarepsdata eq complete
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit TSTEP '1200'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit EPSINISTEP '360'
+            edit EPSFCRES '319'
+            edit EPSLEG '3'
+            edit NPES '1'
+            edit CLASS 'od'
+          task modeleps
+            trigger ./intHtoL eq complete and ./getvarepsdata eq complete
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit EPSLEG '3'
+            edit EPSFCRES '319'
+            edit EPSINISTEP '408'
+            edit EPSINISTEP_PREVIOUS '360'
+            edit FCLENGTH '408'
+            edit MEM '1600'
+            edit MRF '10'
+            edit STACK '350'
+            edit FCCHUNK '1'
+            edit EPSFCRESN '255'
+            edit EPSWAMRESOL 'global50'
+            edit EPSWAMNSTPW '1'
+            edit EPSFCLENGTH_B '360'
+            edit TSTEP '2700'
+            edit EPSFCLENGTH_A '240'
+            edit SMSTRIES '1'
+            edit NPES '1'
+            edit THREADS '64'
+            edit FCNPES '1'
+            edit CLASS 'od'
+            inlimit /emc_36r1/limits:modelepsB
+            meter step -1 408 408
+        endfamily
+      endfamily
+      family postproc
+        trigger ./fc eq active or ./fc eq complete
+        edit STEPS '372/768/12/24 768/768/12/120'
+        edit FCCHUNK '1'
+        edit OCTOTAL '5'
+        edit FCTOTAL '51'
+        edit DAILY '0'
+        edit RUNVARFC '1'
+        edit FCLENGTH1 '360'
+        edit FCLENGTH '768'
+        edit FCGROUP 'fc0'
+        inlimit /emc_36r1/limits:postproc
+        family dp
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit STEPS '366:768:6'
+          inlimit /emc_36r1/limits:dp
+          family cf
+            trigger ../../fc/cf eq complete
+            edit EMOS_TYPE 'cf'
+            task derived_param
+              edit MEMBER 'off'
+          endfamily
+          family pf
+            complete /emc_36r1/main/ref/00/events:cf
+            edit EMOS_TYPE 'pf'
+            family 01
+              trigger ../../../fc/pf/01 eq complete
+              edit EPSMEMBER '1'
+              edit MEMBER '1'
+              edit SUBFSFAMILY '/pf001'
+              task derived_param
+            endfamily
+            family 02
+              trigger ../../../fc/pf/02 eq complete
+              edit EPSMEMBER '2'
+              edit MEMBER '2'
+              edit SUBFSFAMILY '/pf002'
+              task derived_param
+            endfamily
+            family 03
+              trigger ../../../fc/pf/03 eq complete
+              edit EPSMEMBER '3'
+              edit MEMBER '3'
+              edit SUBFSFAMILY '/pf003'
+              task derived_param
+            endfamily
+            family 04
+              trigger ../../../fc/pf/04 eq complete
+              edit EPSMEMBER '4'
+              edit MEMBER '4'
+              edit SUBFSFAMILY '/pf004'
+              task derived_param
+            endfamily
+            family 05
+              trigger ../../../fc/pf/05 eq complete
+              edit EPSMEMBER '5'
+              edit MEMBER '5'
+              edit SUBFSFAMILY '/pf005'
+              task derived_param
+            endfamily
+            family 06
+              trigger ../../../fc/pf/06 eq complete
+              edit EPSMEMBER '6'
+              edit MEMBER '6'
+              edit SUBFSFAMILY '/pf006'
+              task derived_param
+            endfamily
+            family 07
+              trigger ../../../fc/pf/07 eq complete
+              edit EPSMEMBER '7'
+              edit MEMBER '7'
+              edit SUBFSFAMILY '/pf007'
+              task derived_param
+            endfamily
+            family 08
+              trigger ../../../fc/pf/08 eq complete
+              edit EPSMEMBER '8'
+              edit MEMBER '8'
+              edit SUBFSFAMILY '/pf008'
+              task derived_param
+            endfamily
+            family 09
+              trigger ../../../fc/pf/09 eq complete
+              edit EPSMEMBER '9'
+              edit MEMBER '9'
+              edit SUBFSFAMILY '/pf009'
+              task derived_param
+            endfamily
+            family 10
+              trigger ../../../fc/pf/10 eq complete
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              edit SUBFSFAMILY '/pf010'
+              task derived_param
+            endfamily
+            family 11
+              trigger ../../../fc/pf/11 eq complete
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              edit SUBFSFAMILY '/pf011'
+              task derived_param
+            endfamily
+            family 12
+              trigger ../../../fc/pf/12 eq complete
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              edit SUBFSFAMILY '/pf012'
+              task derived_param
+            endfamily
+            family 13
+              trigger ../../../fc/pf/13 eq complete
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              edit SUBFSFAMILY '/pf013'
+              task derived_param
+            endfamily
+            family 14
+              trigger ../../../fc/pf/14 eq complete
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              edit SUBFSFAMILY '/pf014'
+              task derived_param
+            endfamily
+            family 15
+              trigger ../../../fc/pf/15 eq complete
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              edit SUBFSFAMILY '/pf015'
+              task derived_param
+            endfamily
+            family 16
+              trigger ../../../fc/pf/16 eq complete
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              edit SUBFSFAMILY '/pf016'
+              task derived_param
+            endfamily
+            family 17
+              trigger ../../../fc/pf/17 eq complete
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              edit SUBFSFAMILY '/pf017'
+              task derived_param
+            endfamily
+            family 18
+              trigger ../../../fc/pf/18 eq complete
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              edit SUBFSFAMILY '/pf018'
+              task derived_param
+            endfamily
+            family 19
+              trigger ../../../fc/pf/19 eq complete
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              edit SUBFSFAMILY '/pf019'
+              task derived_param
+            endfamily
+            family 20
+              trigger ../../../fc/pf/20 eq complete
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              edit SUBFSFAMILY '/pf020'
+              task derived_param
+            endfamily
+            family 21
+              trigger ../../../fc/pf/21 eq complete
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              edit SUBFSFAMILY '/pf021'
+              task derived_param
+            endfamily
+            family 22
+              trigger ../../../fc/pf/22 eq complete
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              edit SUBFSFAMILY '/pf022'
+              task derived_param
+            endfamily
+            family 23
+              trigger ../../../fc/pf/23 eq complete
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              edit SUBFSFAMILY '/pf023'
+              task derived_param
+            endfamily
+            family 24
+              trigger ../../../fc/pf/24 eq complete
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              edit SUBFSFAMILY '/pf024'
+              task derived_param
+            endfamily
+            family 25
+              trigger ../../../fc/pf/25 eq complete
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              edit SUBFSFAMILY '/pf025'
+              task derived_param
+            endfamily
+            family 26
+              trigger ../../../fc/pf/26 eq complete
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              edit SUBFSFAMILY '/pf026'
+              task derived_param
+            endfamily
+            family 27
+              trigger ../../../fc/pf/27 eq complete
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              edit SUBFSFAMILY '/pf027'
+              task derived_param
+            endfamily
+            family 28
+              trigger ../../../fc/pf/28 eq complete
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              edit SUBFSFAMILY '/pf028'
+              task derived_param
+            endfamily
+            family 29
+              trigger ../../../fc/pf/29 eq complete
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              edit SUBFSFAMILY '/pf029'
+              task derived_param
+            endfamily
+            family 30
+              trigger ../../../fc/pf/30 eq complete
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              edit SUBFSFAMILY '/pf030'
+              task derived_param
+            endfamily
+            family 31
+              trigger ../../../fc/pf/31 eq complete
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              edit SUBFSFAMILY '/pf031'
+              task derived_param
+            endfamily
+            family 32
+              trigger ../../../fc/pf/32 eq complete
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              edit SUBFSFAMILY '/pf032'
+              task derived_param
+            endfamily
+            family 33
+              trigger ../../../fc/pf/33 eq complete
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              edit SUBFSFAMILY '/pf033'
+              task derived_param
+            endfamily
+            family 34
+              trigger ../../../fc/pf/34 eq complete
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              edit SUBFSFAMILY '/pf034'
+              task derived_param
+            endfamily
+            family 35
+              trigger ../../../fc/pf/35 eq complete
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              edit SUBFSFAMILY '/pf035'
+              task derived_param
+            endfamily
+            family 36
+              trigger ../../../fc/pf/36 eq complete
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              edit SUBFSFAMILY '/pf036'
+              task derived_param
+            endfamily
+            family 37
+              trigger ../../../fc/pf/37 eq complete
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              edit SUBFSFAMILY '/pf037'
+              task derived_param
+            endfamily
+            family 38
+              trigger ../../../fc/pf/38 eq complete
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              edit SUBFSFAMILY '/pf038'
+              task derived_param
+            endfamily
+            family 39
+              trigger ../../../fc/pf/39 eq complete
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              edit SUBFSFAMILY '/pf039'
+              task derived_param
+            endfamily
+            family 40
+              trigger ../../../fc/pf/40 eq complete
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              edit SUBFSFAMILY '/pf040'
+              task derived_param
+            endfamily
+            family 41
+              trigger ../../../fc/pf/41 eq complete
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              edit SUBFSFAMILY '/pf041'
+              task derived_param
+            endfamily
+            family 42
+              trigger ../../../fc/pf/42 eq complete
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              edit SUBFSFAMILY '/pf042'
+              task derived_param
+            endfamily
+            family 43
+              trigger ../../../fc/pf/43 eq complete
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              edit SUBFSFAMILY '/pf043'
+              task derived_param
+            endfamily
+            family 44
+              trigger ../../../fc/pf/44 eq complete
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              edit SUBFSFAMILY '/pf044'
+              task derived_param
+            endfamily
+            family 45
+              trigger ../../../fc/pf/45 eq complete
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              edit SUBFSFAMILY '/pf045'
+              task derived_param
+            endfamily
+            family 46
+              trigger ../../../fc/pf/46 eq complete
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              edit SUBFSFAMILY '/pf046'
+              task derived_param
+            endfamily
+            family 47
+              trigger ../../../fc/pf/47 eq complete
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              edit SUBFSFAMILY '/pf047'
+              task derived_param
+            endfamily
+            family 48
+              trigger ../../../fc/pf/48 eq complete
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              edit SUBFSFAMILY '/pf048'
+              task derived_param
+            endfamily
+            family 49
+              trigger ../../../fc/pf/49 eq complete
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              edit SUBFSFAMILY '/pf049'
+              task derived_param
+            endfamily
+            family 50
+              trigger ../../../fc/pf/50 eq complete
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              edit SUBFSFAMILY '/pf050'
+              task derived_param
+            endfamily
+          endfamily
+        endfamily
+        family extra
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit STEPS '366:768:6'
+          inlimit /emc_36r1/limits:extra
+          family cf
+            trigger ../dp/cf eq complete
+            edit EMOS_TYPE 'cf'
+            task extrafields
+              edit EPSFCRES '319'
+              edit FCLENGTH '768'
+              edit FCLENGTH0 '360'
+            task wm_sfc
+              trigger extrafields eq complete
+              edit FCLENGTH '768'
+            task wm_ua
+              trigger wm_sfc eq complete
+              edit FCLENGTH '768'
+          endfamily
+          family pf
+            complete /emc_36r1/main/ref/00/events:cf
+            edit EMOS_TYPE 'pf'
+            family 01
+              trigger ../../dp/pf/01 eq complete
+              edit EPSMEMBER '1'
+              edit MEMBER '1'
+              edit SUBFSFAMILY '/pf001'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 02
+              trigger ../../dp/pf/02 eq complete
+              edit EPSMEMBER '2'
+              edit MEMBER '2'
+              edit SUBFSFAMILY '/pf002'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 03
+              trigger ../../dp/pf/03 eq complete
+              edit EPSMEMBER '3'
+              edit MEMBER '3'
+              edit SUBFSFAMILY '/pf003'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 04
+              trigger ../../dp/pf/04 eq complete
+              edit EPSMEMBER '4'
+              edit MEMBER '4'
+              edit SUBFSFAMILY '/pf004'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 05
+              trigger ../../dp/pf/05 eq complete
+              edit EPSMEMBER '5'
+              edit MEMBER '5'
+              edit SUBFSFAMILY '/pf005'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 06
+              trigger ../../dp/pf/06 eq complete
+              edit EPSMEMBER '6'
+              edit MEMBER '6'
+              edit SUBFSFAMILY '/pf006'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 07
+              trigger ../../dp/pf/07 eq complete
+              edit EPSMEMBER '7'
+              edit MEMBER '7'
+              edit SUBFSFAMILY '/pf007'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 08
+              trigger ../../dp/pf/08 eq complete
+              edit EPSMEMBER '8'
+              edit MEMBER '8'
+              edit SUBFSFAMILY '/pf008'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 09
+              trigger ../../dp/pf/09 eq complete
+              edit EPSMEMBER '9'
+              edit MEMBER '9'
+              edit SUBFSFAMILY '/pf009'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 10
+              trigger ../../dp/pf/10 eq complete
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              edit SUBFSFAMILY '/pf010'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 11
+              trigger ../../dp/pf/11 eq complete
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              edit SUBFSFAMILY '/pf011'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 12
+              trigger ../../dp/pf/12 eq complete
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              edit SUBFSFAMILY '/pf012'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 13
+              trigger ../../dp/pf/13 eq complete
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              edit SUBFSFAMILY '/pf013'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 14
+              trigger ../../dp/pf/14 eq complete
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              edit SUBFSFAMILY '/pf014'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 15
+              trigger ../../dp/pf/15 eq complete
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              edit SUBFSFAMILY '/pf015'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 16
+              trigger ../../dp/pf/16 eq complete
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              edit SUBFSFAMILY '/pf016'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 17
+              trigger ../../dp/pf/17 eq complete
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              edit SUBFSFAMILY '/pf017'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 18
+              trigger ../../dp/pf/18 eq complete
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              edit SUBFSFAMILY '/pf018'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 19
+              trigger ../../dp/pf/19 eq complete
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              edit SUBFSFAMILY '/pf019'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 20
+              trigger ../../dp/pf/20 eq complete
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              edit SUBFSFAMILY '/pf020'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 21
+              trigger ../../dp/pf/21 eq complete
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              edit SUBFSFAMILY '/pf021'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 22
+              trigger ../../dp/pf/22 eq complete
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              edit SUBFSFAMILY '/pf022'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 23
+              trigger ../../dp/pf/23 eq complete
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              edit SUBFSFAMILY '/pf023'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 24
+              trigger ../../dp/pf/24 eq complete
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              edit SUBFSFAMILY '/pf024'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 25
+              trigger ../../dp/pf/25 eq complete
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              edit SUBFSFAMILY '/pf025'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 26
+              trigger ../../dp/pf/26 eq complete
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              edit SUBFSFAMILY '/pf026'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 27
+              trigger ../../dp/pf/27 eq complete
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              edit SUBFSFAMILY '/pf027'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 28
+              trigger ../../dp/pf/28 eq complete
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              edit SUBFSFAMILY '/pf028'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 29
+              trigger ../../dp/pf/29 eq complete
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              edit SUBFSFAMILY '/pf029'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 30
+              trigger ../../dp/pf/30 eq complete
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              edit SUBFSFAMILY '/pf030'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 31
+              trigger ../../dp/pf/31 eq complete
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              edit SUBFSFAMILY '/pf031'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 32
+              trigger ../../dp/pf/32 eq complete
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              edit SUBFSFAMILY '/pf032'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 33
+              trigger ../../dp/pf/33 eq complete
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              edit SUBFSFAMILY '/pf033'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 34
+              trigger ../../dp/pf/34 eq complete
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              edit SUBFSFAMILY '/pf034'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 35
+              trigger ../../dp/pf/35 eq complete
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              edit SUBFSFAMILY '/pf035'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 36
+              trigger ../../dp/pf/36 eq complete
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              edit SUBFSFAMILY '/pf036'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 37
+              trigger ../../dp/pf/37 eq complete
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              edit SUBFSFAMILY '/pf037'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 38
+              trigger ../../dp/pf/38 eq complete
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              edit SUBFSFAMILY '/pf038'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 39
+              trigger ../../dp/pf/39 eq complete
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              edit SUBFSFAMILY '/pf039'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 40
+              trigger ../../dp/pf/40 eq complete
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              edit SUBFSFAMILY '/pf040'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 41
+              trigger ../../dp/pf/41 eq complete
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              edit SUBFSFAMILY '/pf041'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 42
+              trigger ../../dp/pf/42 eq complete
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              edit SUBFSFAMILY '/pf042'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 43
+              trigger ../../dp/pf/43 eq complete
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              edit SUBFSFAMILY '/pf043'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 44
+              trigger ../../dp/pf/44 eq complete
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              edit SUBFSFAMILY '/pf044'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 45
+              trigger ../../dp/pf/45 eq complete
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              edit SUBFSFAMILY '/pf045'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 46
+              trigger ../../dp/pf/46 eq complete
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              edit SUBFSFAMILY '/pf046'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 47
+              trigger ../../dp/pf/47 eq complete
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              edit SUBFSFAMILY '/pf047'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 48
+              trigger ../../dp/pf/48 eq complete
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              edit SUBFSFAMILY '/pf048'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 49
+              trigger ../../dp/pf/49 eq complete
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              edit SUBFSFAMILY '/pf049'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+            family 50
+              trigger ../../dp/pf/50 eq complete
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              edit SUBFSFAMILY '/pf050'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '768'
+                edit FCLENGTH0 '360'
+              task wm_sfc
+                trigger extrafields eq complete
+                edit FCLENGTH '768'
+              task wm_ua
+                trigger wm_sfc eq complete
+                edit FCLENGTH '768'
+            endfamily
+          endfamily
+        endfamily
+        family mofc
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+          edit EMOS_TYPE '00'
+          edit EXPVER_ENFH '0046'
+          edit EXPVER_EFHS '0046'
+          edit NH_ENSEMBLES '4'
+          task wmem_veps
+            trigger ../dp eq complete and ../extra eq complete and ../ensms eq complete
+          family wmanom
+            trigger ( /emc_36r1/hc0:YMD gt /emc_36r1/00:YMD or ( /emc_36r1/hc0:YMD eq /emc_36r1/00:YMD and /emc_36r1/hc0/postproc/wmem_veps eq complete)) and wmem_veps eq complete and ../ensms eq complete
+            edit WRITE_FDB '0'
+            family fcmean
+              edit TYPES 'fcmean'
+              family 129
+                edit PARAMS '129'
+                task wmanom
+              endfamily
+              family all
+                edit PARAMS '130 133 001 078 228'
+                task wmanom
+              endfamily
+            endfamily
+            family em
+              edit TYPES 'em'
+              family all
+                edit PARAMS 'all'
+                task wmanom
+              endfamily
+            endfamily
+            task prob_fdb
+              trigger fcmean eq complete and em eq complete
+              edit PARAM '129 130 133 001 078 228 144 all'
+              edit MARS_FDB_SET_TABLE '1'
+          endfamily
+          task signi
+            trigger wmanom eq complete
+          task prob_thr
+            trigger wmanom eq complete
+          task prob_perc
+            trigger wmanom eq complete
+        endfamily
+        family ensms
+          complete /emc_36r1/main/ref/00/events:cf
+          trigger ../fc eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+          family limits
+            limit fdb 1
+            limit gen 8
+          endfamily
+          task ensms
+            edit ENS_M 'false'
+            edit ENS_S 'false'
+            edit ENS_MARS 'false'
+            event stage
+          family 498
+            trigger ./ensms:stage or ./ensms eq complete
+            edit STEP1 '366'
+            edit STEP2 '498'
+            edit BY '6'
+            edit STEPS '0'
+            family T
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit LIST_PARAM 'T'
+              inlimit ../limits:gen
+              family 850
+                task ensms
+                  edit LIST_LEV '850'
+              endfamily
+              family 500
+                task ensms
+                  edit LIST_LEV '500'
+              endfamily
+            endfamily
+            family Z
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit LIST_PARAM 'Z'
+              inlimit ../limits:gen
+              family 1000
+                task ensms
+                  edit LIST_LEV '1000'
+              endfamily
+              family 500
+                task ensms
+                  edit LIST_LEV '500'
+              endfamily
+            endfamily
+            task ensms
+              trigger T eq complete and Z eq complete
+              edit ENS_MARS 'false'
+              inlimit ../limits:fdb
+          endfamily
+          family 636
+            trigger ./ensms:stage or ./ensms eq complete
+            edit STEP1 '504'
+            edit STEP2 '636'
+            edit BY '6'
+            edit STEPS '0'
+            family T
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit LIST_PARAM 'T'
+              inlimit ../limits:gen
+              family 850
+                task ensms
+                  edit LIST_LEV '850'
+              endfamily
+              family 500
+                task ensms
+                  edit LIST_LEV '500'
+              endfamily
+            endfamily
+            family Z
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit LIST_PARAM 'Z'
+              inlimit ../limits:gen
+              family 1000
+                task ensms
+                  edit LIST_LEV '1000'
+              endfamily
+              family 500
+                task ensms
+                  edit LIST_LEV '500'
+              endfamily
+            endfamily
+            task ensms
+              trigger T eq complete and Z eq complete
+              edit ENS_MARS 'false'
+              inlimit ../limits:fdb
+          endfamily
+          family 768
+            trigger ./ensms:stage or ./ensms eq complete
+            edit STEP1 '642'
+            edit STEP2 '768'
+            edit BY '6'
+            edit STEPS '0'
+            family T
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit LIST_PARAM 'T'
+              inlimit ../limits:gen
+              family 850
+                task ensms
+                  edit LIST_LEV '850'
+              endfamily
+              family 500
+                task ensms
+                  edit LIST_LEV '500'
+              endfamily
+            endfamily
+            family Z
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit LIST_PARAM 'Z'
+              inlimit ../limits:gen
+              family 1000
+                task ensms
+                  edit LIST_LEV '1000'
+              endfamily
+              family 500
+                task ensms
+                  edit LIST_LEV '500'
+              endfamily
+            endfamily
+            task ensms
+              trigger T eq complete and Z eq complete
+              edit ENS_MARS 'false'
+              inlimit ../limits:fdb
+          endfamily
+        endfamily
+      endfamily
+      family prod
+        trigger fc eq complete and postproc eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+        edit EMOS_STREAM 'ENFO'
+        edit EMOS_DOMAIN 'G'
+        edit EMOS_TYPE 'FC'
+        edit PROD_TASK '1'
+        edit EMOS_PROJECT '00'
+        edit EMOS_BASE '00'
+        edit PGNPES '32'
+        family eps
+          trigger ( ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and ( /emc_36r1/main/00/legA/prod/getreq/eps eq complete or /emc_36r1/main/00/legA/prod/getreq/eps:001) and ( /emc_36r1/main/00/legA/prod/getreq/bitmap eq complete or /emc_36r1/main/00/legA/prod/getreq/bitmap:001)))
+          edit EMOS_STREAM 'ENFO'
+          family day01
+            edit EMOS_TIME_STEP_H '0001'
+            task prodgen
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day02
+            edit EMOS_TIME_STEP_H '0002'
+            task prodgen
+              trigger ../day01/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day01/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day03
+            edit EMOS_TIME_STEP_H '0003'
+            task prodgen
+              trigger ../day02/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day02/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day04
+            edit EMOS_TIME_STEP_H '0004'
+            task prodgen
+              trigger ../day03/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day03/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day05
+            edit EMOS_TIME_STEP_H '0005'
+            task prodgen
+              trigger ../day04/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day04/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day06
+            edit EMOS_TIME_STEP_H '0006'
+            task prodgen
+              trigger ../day05/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day05/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day07
+            edit EMOS_TIME_STEP_H '0007'
+            task prodgen
+              trigger ../day06/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day06/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day08
+            edit EMOS_TIME_STEP_H '0008'
+            task prodgen
+              trigger ../day07/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day07/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day09
+            edit EMOS_TIME_STEP_H '0009'
+            task prodgen
+              trigger ../day08/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day08/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day10
+            edit EMOS_TIME_STEP_H '0010'
+            task prodgen
+              trigger ../day09/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day09/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day11
+            edit EMOS_TIME_STEP_H '0011'
+            task prodgen
+              trigger ../day10/prodgen eq complete
+              edit MEM '1900'
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day10/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day12
+            edit EMOS_TIME_STEP_H '0012'
+            task prodgen
+              trigger ../day11/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day11/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day13
+            edit EMOS_TIME_STEP_H '0013'
+            task prodgen
+              trigger ../day12/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day12/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day14
+            edit EMOS_TIME_STEP_H '0014'
+            task prodgen
+              trigger ../day13/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day13/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day15
+            edit EMOS_TIME_STEP_H '0015'
+            task prodgen
+              trigger ../day14/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day14/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day16
+            edit EMOS_TIME_STEP_H '0016'
+            task prodgen
+              trigger ../day15/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day15/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day17
+            edit EMOS_TIME_STEP_H '0017'
+            task prodgen
+              trigger ../day16/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day16/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day18
+            edit EMOS_TIME_STEP_H '0018'
+            task prodgen
+              trigger ../day17/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day17/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day19
+            edit EMOS_TIME_STEP_H '0019'
+            task prodgen
+              trigger ../day18/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day18/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day20
+            edit EMOS_TIME_STEP_H '0020'
+            task prodgen
+              trigger ../day19/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day19/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day21
+            edit EMOS_TIME_STEP_H '0021'
+            task prodgen
+              trigger ../day20/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day20/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day22
+            edit EMOS_TIME_STEP_H '0022'
+            task prodgen
+              trigger ../day21/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day21/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day23
+            edit EMOS_TIME_STEP_H '0023'
+            task prodgen
+              trigger ../day22/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day22/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day24
+            edit EMOS_TIME_STEP_H '0024'
+            task prodgen
+              trigger ../day23/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day23/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day25
+            edit EMOS_TIME_STEP_H '0025'
+            task prodgen
+              trigger ../day24/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day24/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day26
+            edit EMOS_TIME_STEP_H '0026'
+            task prodgen
+              trigger ../day25/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day25/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day27
+            edit EMOS_TIME_STEP_H '0027'
+            task prodgen
+              trigger ../day26/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day26/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day28
+            edit EMOS_TIME_STEP_H '0028'
+            task prodgen
+              trigger ../day27/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day27/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day29
+            edit EMOS_TIME_STEP_H '0029'
+            task prodgen
+              trigger ../day28/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day28/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day30
+            edit EMOS_TIME_STEP_H '0030'
+            task prodgen
+              trigger ../day29/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day29/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day31
+            edit EMOS_TIME_STEP_H '0031'
+            task prodgen
+              trigger ../day30/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day30/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day32
+            edit EMOS_TIME_STEP_H '0032'
+            task prodgen
+              trigger ../day31/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day31/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day33
+            edit EMOS_TIME_STEP_H '0033'
+            task prodgen
+              trigger ../day32/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day32/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+        endfamily
+        family wave
+          trigger ./eps/day33/prodgen eq complete and ( ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and ( /emc_36r1/main/00/legA/prod/getreq/wave_eps eq complete or /emc_36r1/main/00/legA/prod/getreq/wave_eps:001)))
+          edit PGNPES '4'
+          edit EMOS_STREAM 'WAEF'
+          family day01
+            edit EMOS_TIME_STEP_H '0001'
+            task prodgen
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ./pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day02
+            edit EMOS_TIME_STEP_H '0002'
+            task prodgen
+              trigger ../day01/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day01/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day03
+            edit EMOS_TIME_STEP_H '0003'
+            task prodgen
+              trigger ../day02/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day02/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day04
+            edit EMOS_TIME_STEP_H '0004'
+            task prodgen
+              trigger ../day03/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day03/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day05
+            edit EMOS_TIME_STEP_H '0005'
+            task prodgen
+              trigger ../day04/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day04/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day06
+            edit EMOS_TIME_STEP_H '0006'
+            task prodgen
+              trigger ../day05/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day05/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day07
+            edit EMOS_TIME_STEP_H '0007'
+            task prodgen
+              trigger ../day06/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day06/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day08
+            edit EMOS_TIME_STEP_H '0008'
+            task prodgen
+              trigger ../day07/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day07/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day09
+            edit EMOS_TIME_STEP_H '0009'
+            task prodgen
+              trigger ../day08/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day08/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day10
+            edit EMOS_TIME_STEP_H '0010'
+            task prodgen
+              trigger ../day09/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day09/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day11
+            edit EMOS_TIME_STEP_H '0011'
+            task prodgen
+              trigger ../day10/prodgen eq complete
+              edit MEM '1900'
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day10/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day12
+            edit EMOS_TIME_STEP_H '0012'
+            task prodgen
+              trigger ../day11/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day11/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day13
+            edit EMOS_TIME_STEP_H '0013'
+            task prodgen
+              trigger ../day12/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day12/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day14
+            edit EMOS_TIME_STEP_H '0014'
+            task prodgen
+              trigger ../day13/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day13/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day15
+            edit EMOS_TIME_STEP_H '0015'
+            task prodgen
+              trigger ../day14/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day14/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day16
+            edit EMOS_TIME_STEP_H '0016'
+            task prodgen
+              trigger ../day15/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day15/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day17
+            edit EMOS_TIME_STEP_H '0017'
+            task prodgen
+              trigger ../day16/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day16/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day18
+            edit EMOS_TIME_STEP_H '0018'
+            task prodgen
+              trigger ../day17/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day17/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day19
+            edit EMOS_TIME_STEP_H '0019'
+            task prodgen
+              trigger ../day18/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day18/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day20
+            edit EMOS_TIME_STEP_H '0020'
+            task prodgen
+              trigger ../day19/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day19/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day21
+            edit EMOS_TIME_STEP_H '0021'
+            task prodgen
+              trigger ../day20/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day20/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day22
+            edit EMOS_TIME_STEP_H '0022'
+            task prodgen
+              trigger ../day21/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day21/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day23
+            edit EMOS_TIME_STEP_H '0023'
+            task prodgen
+              trigger ../day22/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day22/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day24
+            edit EMOS_TIME_STEP_H '0024'
+            task prodgen
+              trigger ../day23/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day23/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day25
+            edit EMOS_TIME_STEP_H '0025'
+            task prodgen
+              trigger ../day24/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day24/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day26
+            edit EMOS_TIME_STEP_H '0026'
+            task prodgen
+              trigger ../day25/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day25/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day27
+            edit EMOS_TIME_STEP_H '0027'
+            task prodgen
+              trigger ../day26/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day26/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day28
+            edit EMOS_TIME_STEP_H '0028'
+            task prodgen
+              trigger ../day27/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day27/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day29
+            edit EMOS_TIME_STEP_H '0029'
+            task prodgen
+              trigger ../day28/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day28/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day30
+            edit EMOS_TIME_STEP_H '0030'
+            task prodgen
+              trigger ../day29/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day29/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day31
+            edit EMOS_TIME_STEP_H '0031'
+            task prodgen
+              trigger ../day30/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day30/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day32
+            edit EMOS_TIME_STEP_H '0032'
+            task prodgen
+              trigger ../day31/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day31/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+          family day33
+            edit EMOS_TIME_STEP_H '0033'
+            task prodgen
+              trigger ../day32/prodgen eq complete
+            task pdb
+              trigger prodgen eq complete
+              inlimit /emc_36r1/limits:pdb
+              inlimit /limits:pdb
+              label info ""
+              event 1 
+            task q2diss
+              late -s +00:05 -c +00:15
+              trigger ../day32/q2diss eq complete and pdb eq complete
+              edit USER_PRIORITY '93'
+              inlimit /emc_36r1/limits:q2diss
+              inlimit /limits:q2diss
+              label info ""
+              event 1 
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+    family arch
+      trigger ./legC/fc eq complete
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+      edit EPSLEG '3'
+      edit FSFAMILY 'mars'
+      edit OVERLAP '0'
+      edit EMOS_TYPE 'an'
+      edit EPSFCRES '255'
+      inlimit /emc_36r1/limits:mars
+      inlimit /limits:mars
+      family cf
+        edit EMOS_TYPE 'cf'
+        edit NUMBER '0'
+        family cf408
+          edit STEPS '366/to/408/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family cf480
+          edit STEPS '414/to/480/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family cf600
+          edit STEPS '486/to/600/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family cf768
+          edit STEPS '606/to/768/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+      endfamily
+      family pf
+        complete /emc_36r1/main/ref/00/events:cf
+        edit EMOS_TYPE 'pf'
+        family pf408
+          edit STEPS '366/to/408/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family pf480
+          edit STEPS '414/to/480/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family pf600
+          edit STEPS '486/to/600/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family pf768
+          edit STEPS '606/to/768/by/6'
+          task pfpl
+            inlimit /emc_36r1/limits:pl
+            label files ""
+            label info ""
+            event fdb
+          task pfsfc
+            trigger ../../postproc/dp eq complete
+            inlimit /emc_36r1/limits:sfc
+            label files ""
+            label info ""
+            event fdb
+          task pfil
+            label files ""
+            label info ""
+            event fdb
+          task pfwv
+            edit STREAM 'WAEF'
+            edit EMOS_STREAM 'WAEF'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+      endfamily
+      family postproc
+        complete /emc_36r1/main/ref/00/events:cf
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+        edit FCCHUNK '1'
+        edit FCLENGTH '768'
+        inlimit /emc_36r1/limits:postproc
+        family mofc
+          complete /emc_36r1/main/ref/00/events:cf
+          trigger /emc_36r1/00/legC/postproc/mofc eq complete
+          task prob_archive
+            label info ""
+          task wmem_archive
+            label info ""
+          task wmanom_archive
+            label info ""
+          task signi_archive
+            trigger wmanom_archive eq complete
+            label info ""
+        endfamily
+        family ensms
+          trigger /emc_36r1/00/legC/postproc/ensms eq complete
+          edit EMOS_TYPE 'an'
+          family 768
+            edit STEPS '366/to/768/by/6'
+            task mean
+              edit TYPE 'em'
+              label files ""
+              label info ""
+              event fdb
+            task stdev
+              edit TYPE 'es'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family dp
+          trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+          edit RUNVARFC '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          edit EMOS_TYPE 'pf'
+          edit STEPS '366/to/768/by/6'
+          family cf
+            edit EMOS_TYPE 'cf'
+            task derivedp
+              label files ""
+              label info ""
+              event fdb
+            task extra_arc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit STEPS '360/to/768'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            task derivedp
+              label files ""
+              label info ""
+              event fdb
+            task extra_arc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit STEPS '360/to/768'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family extra
+          trigger /emc_36r1/00/legC/postproc/extra eq complete
+          edit RUNVARFC '1'
+          task wm_sfc_arc
+            label files ""
+            label info ""
+            event fdb
+          task wm_ua_arc
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family reord
+          complete /emc_36r1/lag/ref/00/events:cf
+          edit EPSCOUPLE '1'
+          edit EMOS_TYPE 'pf'
+          edit FCLENGTH0 '360'
+          edit FCLENGTH '768'
+          edit EPSFCRES '255'
+          edit FCCHUNK '1'
+          edit STEP1 '360'
+          edit STEP2 '768'
+          edit STEPS '-1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+          limit reord 1
+          inlimit reord
+          label info ""
+          family 130
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '130.128'
+            task reord
+              label info ""
+          endfamily
+          family 228
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '228.128'
+            task reord
+              label info ""
+          endfamily
+          family 207
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '207.128'
+            task reord
+              label info ""
+          endfamily
+          family 167
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '167.128'
+            task reord
+              label info ""
+          endfamily
+          family 164
+            edit GENERATE '1'
+            edit ARCHIVE '0'
+            edit PARAMS '164.128'
+            task reord
+              label info ""
+          endfamily
+          family arch
+            trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
+            edit GENERATE '0'
+            edit ARCHIVE '1'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task reord
+              label info ""
+          endfamily
+        endfamily
+        family nino
+          edit FCCHUNK '1'
+          edit OCTOTAL '5'
+          edit FCTOTAL '51'
+          edit DAILY '0'
+          edit RUNVARFC '1'
+          edit FCLENGTH1 '360'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FCLENGTH '768'
+          edit EPSCOUPLE '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+          limit semaphore 10
+          inlimit /limits:linux_cluster
+          inlimit semaphore
+          family 00
+            edit OCGROUP 'an00'
+            edit FCGROUP 'fc0'
+            edit EPSMEMBER '0'
+            edit MEMBER '0'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 01
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc0'
+            edit EPSMEMBER '1'
+            edit MEMBER '1'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 02
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc0'
+            edit EPSMEMBER '2'
+            edit MEMBER '2'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 03
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc0'
+            edit EPSMEMBER '3'
+            edit MEMBER '3'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 04
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc0'
+            edit EPSMEMBER '4'
+            edit MEMBER '4'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 05
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc1'
+            edit EPSMEMBER '5'
+            edit MEMBER '5'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 06
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc1'
+            edit EPSMEMBER '6'
+            edit MEMBER '6'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 07
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc1'
+            edit EPSMEMBER '7'
+            edit MEMBER '7'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 08
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc1'
+            edit EPSMEMBER '8'
+            edit MEMBER '8'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 09
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc1'
+            edit EPSMEMBER '9'
+            edit MEMBER '9'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 10
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc2'
+            edit EPSMEMBER '10'
+            edit MEMBER '10'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 11
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc2'
+            edit EPSMEMBER '11'
+            edit MEMBER '11'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 12
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc2'
+            edit EPSMEMBER '12'
+            edit MEMBER '12'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 13
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc2'
+            edit EPSMEMBER '13'
+            edit MEMBER '13'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 14
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc2'
+            edit EPSMEMBER '14'
+            edit MEMBER '14'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 15
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc3'
+            edit EPSMEMBER '15'
+            edit MEMBER '15'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 16
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc3'
+            edit EPSMEMBER '16'
+            edit MEMBER '16'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 17
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc3'
+            edit EPSMEMBER '17'
+            edit MEMBER '17'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 18
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc3'
+            edit EPSMEMBER '18'
+            edit MEMBER '18'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 19
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc3'
+            edit EPSMEMBER '19'
+            edit MEMBER '19'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 20
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc4'
+            edit EPSMEMBER '20'
+            edit MEMBER '20'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 21
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc4'
+            edit EPSMEMBER '21'
+            edit MEMBER '21'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 22
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc4'
+            edit EPSMEMBER '22'
+            edit MEMBER '22'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 23
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc4'
+            edit EPSMEMBER '23'
+            edit MEMBER '23'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 24
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc4'
+            edit EPSMEMBER '24'
+            edit MEMBER '24'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 25
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc5'
+            edit EPSMEMBER '25'
+            edit MEMBER '25'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 26
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc5'
+            edit EPSMEMBER '26'
+            edit MEMBER '26'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 27
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc5'
+            edit EPSMEMBER '27'
+            edit MEMBER '27'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 28
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc5'
+            edit EPSMEMBER '28'
+            edit MEMBER '28'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 29
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc5'
+            edit EPSMEMBER '29'
+            edit MEMBER '29'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 30
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc6'
+            edit EPSMEMBER '30'
+            edit MEMBER '30'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 31
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc6'
+            edit EPSMEMBER '31'
+            edit MEMBER '31'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 32
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc6'
+            edit EPSMEMBER '32'
+            edit MEMBER '32'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 33
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc6'
+            edit EPSMEMBER '33'
+            edit MEMBER '33'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 34
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc6'
+            edit EPSMEMBER '34'
+            edit MEMBER '34'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 35
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc7'
+            edit EPSMEMBER '35'
+            edit MEMBER '35'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 36
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc7'
+            edit EPSMEMBER '36'
+            edit MEMBER '36'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 37
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc7'
+            edit EPSMEMBER '37'
+            edit MEMBER '37'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 38
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc7'
+            edit EPSMEMBER '38'
+            edit MEMBER '38'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 39
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc7'
+            edit EPSMEMBER '39'
+            edit MEMBER '39'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 40
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc8'
+            edit EPSMEMBER '40'
+            edit MEMBER '40'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 41
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc8'
+            edit EPSMEMBER '41'
+            edit MEMBER '41'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 42
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc8'
+            edit EPSMEMBER '42'
+            edit MEMBER '42'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 43
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc8'
+            edit EPSMEMBER '43'
+            edit MEMBER '43'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 44
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc8'
+            edit EPSMEMBER '44'
+            edit MEMBER '44'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 45
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc9'
+            edit EPSMEMBER '45'
+            edit MEMBER '45'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 46
+            edit OCGROUP 'an1'
+            edit FCGROUP 'fc9'
+            edit EPSMEMBER '46'
+            edit MEMBER '46'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 47
+            edit OCGROUP 'an2'
+            edit FCGROUP 'fc9'
+            edit EPSMEMBER '47'
+            edit MEMBER '47'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 48
+            edit OCGROUP 'an3'
+            edit FCGROUP 'fc9'
+            edit EPSMEMBER '48'
+            edit MEMBER '48'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 49
+            edit OCGROUP 'an4'
+            edit FCGROUP 'fc9'
+            edit EPSMEMBER '49'
+            edit MEMBER '49'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+          family 50
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc10'
+            edit EPSMEMBER '50'
+            edit MEMBER '50'
+            task nino_daily
+            task tcyc
+              trigger nino_daily eq complete or nino_daily eq aborted
+          endfamily
+        endfamily
+        task tcyctoecfs
+          trigger nino eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+          edit EPSCOUPLE '1'
+          edit FCLENGTH '768'
+          inlimit /limits:linux_cluster
+      endfamily
+      family coupled
+        complete /emc_36r1/main/ref/00/events:cf
+        edit EPSLEG '3'
+        edit OCLEG '3'
+        edit OCEPS '3'
+        edit FCCHUNK '1'
+        edit FCLENGTH '768'
+        edit FCLENGTH0 '360'
+        edit OCEPSTOT '3'
+        edit FCTOTAL '51'
+        edit RUNVARFC '1'
+        edit EPSCOUPLE '1'
+        edit RUNCOUPLE '1'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+        inlimit /emc_36r1/lag/ref/00:mutex
+        task preparcoce
+        task arcfc
+          trigger preparcoce eq complete
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+    endfamily
+    family msjobs
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/00:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/00:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete and /emc_36r1/main/make eq complete)
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'ecgate'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit VERSION '0046'
+      edit STREAM 'EF'
+      edit EMOS_STREAM 'EF'
+      edit SMSURLBASE 'http://ecgate.ecmwf.int:9080'
+      edit SMSURL 'do/events'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs'
+      edit DELAY '120'
+      edit EMOS_TIME_STEP_H '768'
+      family hindcast
+        trigger /emc_36r1/hc0/postproc eq complete and /emc_36r1/00/ref/thu1000 eq complete
+        edit STREAM 'ENFH'
+        edit EMOS_STREAM 'ENFH'
+        edit MSJ_DIR 'mofcrefc'
+        task ms_ec
+      endfamily
+      family legC
+        trigger ../legC eq complete and /emc_36r1/00/ref/thu2200 eq complete
+        edit MSJ_DIR 'mofc_all'
+        task ms_ec
+        family noaa
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit RUNVARFC '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs/noaa'
+          edit DISS_HOUR '2200'
+          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+          edit SMSURL 'CDC/EF/00'
+          edit CALL_FTP 'false'
+          edit CALL_ECPDS 'true'
+          task delete
+            trigger ncep_weekly eq complete and /emc_36r1/00/web eq complete and /emc_36r1/00/ref/tue eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+          task ncep_weekly
+            trigger /emc_36r1/00/web/process/mjo eq complete
+            edit SMSURL 'NO9/EF/00'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+            edit FCLENGTH '768'
+            edit ERA40END '2002033000'
+        endfamily
+      endfamily
+    endfamily
+    family web
+      trigger ../00:YMD + 14 le ../hc2:YMD
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit WSHOST 'linux_cluster'
+      edit QUEUE 'plots-medium'
+      edit MARS_DB 'c1b fdb'
+      edit EPSLEG '3'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+      edit EMOS_TYPE '00'
+      edit RUNVARFC '1'
+      edit NH_ENSEMBLES '4'
+      edit EXPVER_ENFH '0046'
+      edit EXPVER_EFHS '0046'
+      inlimit /limits:linux_cluster
+      inlimit /emc_36r1/limits:webplots
+      family stage
+        edit RETRIEVE 'stage'
+        task chi200
+        task olr
+        task u200
+        task u850
+      endfamily
+      family process
+        trigger ../legC/fc eq complete and ../legC/postproc eq complete
+        family anomaly
+          family temp
+            edit VAR 'TEMP'
+            task plot_anom
+          endfamily
+          family rain
+            edit VAR 'RAIN'
+            task plot_anom
+          endfamily
+          family mslp
+            edit VAR 'MSLP'
+            task plot_anom
+          endfamily
+          family 2mtm
+            edit VAR '2MTM'
+            task plot_anom
+          endfamily
+          task toweb
+            trigger temp eq complete and rain eq complete and mslp eq complete and ./2mtm eq complete
+        endfamily
+        family probanom
+          family temp
+            edit VAR 'TEMP'
+            task plot_prob
+          endfamily
+          family rain
+            edit VAR 'RAIN'
+            task plot_prob
+          endfamily
+          family mslp
+            edit VAR 'MSLP'
+            task plot_prob
+          endfamily
+          family 2mtm
+            edit VAR '2MTM'
+            task plot_prob
+          endfamily
+          task toweb
+            trigger temp eq complete and rain eq complete and mslp eq complete and ./2mtm eq complete
+        endfamily
+        family tercile
+          family temp
+            edit VAR 'TEMP'
+            task plot_terc
+          endfamily
+          family rain
+            edit VAR 'RAIN'
+            task plot_terc
+          endfamily
+          family mslp
+            edit VAR 'MSLP'
+            task plot_terc
+          endfamily
+          family 2mtm
+            edit VAR '2MTM'
+            task plot_terc
+          endfamily
+          task toweb
+            trigger temp eq complete and rain eq complete and mslp eq complete and ./2mtm eq complete
+            edit TERCILES '.terc1. .terc2.'
+        endfamily
+        family eps
+          trigger ./tercile eq complete or ./tercile/toweb eq aborted
+          family members
+            task mslp
+              late -c +02:00
+            task z500
+            task mslp_wm
+            task z500_wm
+          endfamily
+          family plumes
+            task plume31
+            task plumeter
+              trigger plume31 eq complete
+          endfamily
+          family regime
+            task kmeansclust
+            task kmeansclust_week
+            task plotkmeansclust
+              trigger kmeansclust_week eq complete and kmeansclust eq complete
+            task hovmoeller
+            task hovmoeller_itr
+            task flowz500
+            task multivar
+          endfamily
+          task epstoweb
+            trigger members eq complete and plumes eq complete and regime eq complete
+        endfamily
+        family mjo
+          trigger ../stage eq complete
+          edit FCLENGTH '768'
+          edit ERA40END '2002033000'
+          family process
+            task chi200
+            task olr
+            task u850
+            task u200
+          endfamily
+          task mjotoweb
+            trigger ceof eq complete
+          task ceof
+            trigger process eq complete
+          family ncep
+            trigger process eq complete
+            task olr_to_ncep
+            task u200_to_ncep
+            task u850_to_ncep
+          endfamily
+        endfamily
+        family tcyc
+          trigger /emc_36r1/00/arch/postproc/nino eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web/tcyc'
+          family hr
+            edit KIND 'hr'
+            family clim
+              edit PROC 'clim'
+              task tcycweb
+            endfamily
+            family map
+              edit PROC 'map'
+              task tcycweb
+            endfamily
+            family diff
+              trigger clim eq complete and map eq complete
+              edit PROC 'diff'
+              task tcycweb
+            endfamily
+          endfamily
+          family ts
+            edit KIND 'ts'
+            family clim
+              edit PROC 'clim'
+              task tcycweb
+            endfamily
+            family map
+              edit PROC 'map'
+              task tcycweb
+            endfamily
+            family diff
+              trigger clim eq complete and map eq complete
+              edit PROC 'diff'
+              task tcycweb
+            endfamily
+          endfamily
+          family td
+            edit KIND 'td'
+            family clim
+              edit PROC 'clim'
+              task tcycweb
+            endfamily
+            family map
+              edit PROC 'map'
+              task tcycweb
+            endfamily
+            family diff
+              trigger clim eq complete and map eq complete
+              edit PROC 'diff'
+              task tcycweb
+            endfamily
+          endfamily
+          task freq
+            trigger hr eq complete and ts eq complete and td eq complete
+          task tcyctoweb
+            trigger hr eq complete and ts eq complete and td eq complete and freq eq complete
+        endfamily
+        family tcyc_hc
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web/tcyc'
+          task tcyc_hc
+            edit WSHOST 'localhost'
+        endfamily
+      endfamily
+      task web_update
+        trigger ./process eq complete and /emc_36r1/00/ref/thu2200 eq complete
+      family clean
+        trigger process eq complete and web_update eq complete
+        task migrate
+        task delete
+          trigger migrate eq complete
+      endfamily
+    endfamily
+    family amma
+      trigger ./web eq complete and ./ref/thu2200 eq complete
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit UPDATE_WEB_NOW 'yes'
+      edit WSHOST 'linux_cluster'
+      edit QUEUE 'emos'
+      edit FSFAMILY 'assim'
+      edit FCTOTAL '51'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg/amma'
+      edit RUNVARFC '1'
+      edit EMOS_TYPE '00'
+      edit EMOS_BASE '00'
+      inlimit /limits:linux_cluster
+      family init
+        task list
+        task getfore
+          trigger ./list eq complete
+        task getclim
+          trigger ./getfore eq complete
+      endfamily
+      family anomaly
+        trigger ./init eq complete
+        family sf200
+          edit VAR 'SF200'
+          task stats_a
+          task plot_a
+            trigger stats_a eq complete
+        endfamily
+        family vp200
+          trigger ./sf200 eq complete
+          edit VAR 'VP200'
+          task stats_a
+          task plot_a
+            trigger stats_a eq complete
+        endfamily
+        task antoweb
+          trigger ./vp200 eq complete
+      endfamily
+      family tercile
+        trigger ./anomaly eq complete or ./anomaly/antoweb eq aborted
+        family sf200
+          edit VAR 'SF200'
+          task stats_t
+          task plot_t
+            trigger stats_t eq complete
+        endfamily
+        family vp200
+          trigger ./sf200 eq complete
+          edit VAR 'VP200'
+          task stats_t
+          task plot_t
+            trigger stats_t eq complete
+        endfamily
+        task trtoweb
+          trigger ./vp200 eq complete
+      endfamily
+      family mjo
+        trigger ./tercile eq complete or ./tercile/trtoweb eq aborted
+        edit ERA40END '2002033000'
+        task chi200
+          edit FCLENGTH '768'
+        task mjotoweb
+          trigger ./chi200 eq complete
+      endfamily
+      task cleanup
+        trigger ./mjo eq complete
+    endfamily
+    family efi
+      trigger ../hc0:YMD + 14 le ../hc2:YMD
+      edit MAXDAY '15'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+      inlimit /emc_36r1/limits:efih
+      family op
+        family clim
+          trigger /emc_36r1/hc2/efi/op eq complete
+          family steps24
+            family 000_024
+              edit ACC '24'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 012_036
+              edit ACC '24'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '24'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 036_060
+              edit ACC '24'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '24'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 060_084
+              edit ACC '24'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '24'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 084_108
+              edit ACC '24'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '24'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 108_132
+              edit ACC '24'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '24'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+            endfamily
+          endfamily
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family nop
+        family clim
+          trigger /emc_36r1/hc2/efi/nop eq complete
+          family steps24
+            family 000_024
+              edit ACC '24'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 012_036
+              edit ACC '24'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '24'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 036_060
+              edit ACC '24'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '24'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 060_084
+              edit ACC '24'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '24'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 084_108
+              edit ACC '24'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '24'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 108_132
+              edit ACC '24'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '24'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '24'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '24'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '24'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '24'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 240_264
+              edit ACC '24'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '264'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 264_288
+              edit ACC '24'
+              edit EFI_STEP1 '264'
+              edit EFI_STEP2 '288'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 288_312
+              edit ACC '24'
+              edit EFI_STEP1 '288'
+              edit EFI_STEP2 '312'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 312_336
+              edit ACC '24'
+              edit EFI_STEP1 '312'
+              edit EFI_STEP2 '336'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 336_360
+              edit ACC '24'
+              edit EFI_STEP1 '336'
+              edit EFI_STEP2 '360'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+          endfamily
+          family steps06
+            family 006_006
+              edit ACC '0'
+              edit EFI_STEP1 '006'
+              edit EFI_STEP2 '006'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 012_012
+              edit ACC '0'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '012'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 018_018
+              edit ACC '0'
+              edit EFI_STEP1 '018'
+              edit EFI_STEP2 '018'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 024_024
+              edit ACC '0'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 030_030
+              edit ACC '0'
+              edit EFI_STEP1 '030'
+              edit EFI_STEP2 '030'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 036_036
+              edit ACC '0'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '036'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 042_042
+              edit ACC '0'
+              edit EFI_STEP1 '042'
+              edit EFI_STEP2 '042'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 048_048
+              edit ACC '0'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 054_054
+              edit ACC '0'
+              edit EFI_STEP1 '054'
+              edit EFI_STEP2 '054'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 060_060
+              edit ACC '0'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '060'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 066_066
+              edit ACC '0'
+              edit EFI_STEP1 '066'
+              edit EFI_STEP2 '066'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 072_072
+              edit ACC '0'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 078_078
+              edit ACC '0'
+              edit EFI_STEP1 '078'
+              edit EFI_STEP2 '078'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 084_084
+              edit ACC '0'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '084'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 090_090
+              edit ACC '0'
+              edit EFI_STEP1 '090'
+              edit EFI_STEP2 '090'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 096_096
+              edit ACC '0'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 102_102
+              edit ACC '0'
+              edit EFI_STEP1 '102'
+              edit EFI_STEP2 '102'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 108_108
+              edit ACC '0'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '108'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 114_114
+              edit ACC '0'
+              edit EFI_STEP1 '114'
+              edit EFI_STEP2 '114'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 120_120
+              edit ACC '0'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 126_126
+              edit ACC '0'
+              edit EFI_STEP1 '126'
+              edit EFI_STEP2 '126'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 132_132
+              edit ACC '0'
+              edit EFI_STEP1 '132'
+              edit EFI_STEP2 '132'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 138_138
+              edit ACC '0'
+              edit EFI_STEP1 '138'
+              edit EFI_STEP2 '138'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 144_144
+              edit ACC '0'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 150_150
+              edit ACC '0'
+              edit EFI_STEP1 '150'
+              edit EFI_STEP2 '150'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 156_156
+              edit ACC '0'
+              edit EFI_STEP1 '156'
+              edit EFI_STEP2 '156'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 162_162
+              edit ACC '0'
+              edit EFI_STEP1 '162'
+              edit EFI_STEP2 '162'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 168_168
+              edit ACC '0'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 174_174
+              edit ACC '0'
+              edit EFI_STEP1 '174'
+              edit EFI_STEP2 '174'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 180_180
+              edit ACC '0'
+              edit EFI_STEP1 '180'
+              edit EFI_STEP2 '180'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 186_186
+              edit ACC '0'
+              edit EFI_STEP1 '186'
+              edit EFI_STEP2 '186'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 192_192
+              edit ACC '0'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '192'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 198_198
+              edit ACC '0'
+              edit EFI_STEP1 '198'
+              edit EFI_STEP2 '198'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 204_204
+              edit ACC '0'
+              edit EFI_STEP1 '204'
+              edit EFI_STEP2 '204'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 210_210
+              edit ACC '0'
+              edit EFI_STEP1 '210'
+              edit EFI_STEP2 '210'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 216_216
+              edit ACC '0'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '216'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 222_222
+              edit ACC '0'
+              edit EFI_STEP1 '222'
+              edit EFI_STEP2 '222'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 228_228
+              edit ACC '0'
+              edit EFI_STEP1 '228'
+              edit EFI_STEP2 '228'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 234_234
+              edit ACC '0'
+              edit EFI_STEP1 '234'
+              edit EFI_STEP2 '234'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+            family 240_240
+              edit ACC '0'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prep_sort
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prep_sort
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prep_sort
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prep_sort
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prep_sort
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prep_sort
+              endfamily
+              family 10dd
+                edit RF_NAME '10dd'
+                task prep_sort
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prep_sort
+              endfamily
+              family tcc
+                edit RF_NAME 'tcc'
+                task prep_sort
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prep_sort
+              endfamily
+            endfamily
+          endfamily
+          family 120_168
+            trigger ./steps24 eq complete
+            edit ACC '48'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_240
+            trigger ./steps24 eq complete
+            edit ACC '72'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 000_168
+            trigger ./steps24 eq complete
+            edit ACC '168'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_336
+            trigger ./steps24 eq complete
+            edit ACC '96'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_336
+            trigger ./steps24 eq complete
+            edit ACC '168'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      task efi_clean
+      task sync_climate
+        trigger op eq complete and nop eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi'
+        time 20:45
+      family swarm
+        trigger ./sync_climate eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        inlimit /limits:linux_cluster
+        time 20:45
+        task sync_climate
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:35
+      trigger ref eq complete and logfilestore eq complete and legC eq complete and arch eq complete and msjobs eq complete and web eq complete and amma eq complete and efi eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+  family limits
+    limit mars 15
+    limit marsret 10
+    limit reservation 1
+    limit pftotal 72
+    limit pertic 26
+    limit modelepsA 13
+    limit modelepsB 52
+    limit pl 3
+    limit sfc 3
+    limit prodeps 9
+    limit prodwave 5
+    limit pdb 5
+    limit q2diss 5
+    limit w2diss 2
+    limit hind 60
+    limit pesh 60
+    limit efih 40
+    limit refc 10
+    limit webplots 9
+    limit postproc 40
+    limit dp 8
+    limit tc 7
+    limit efi 20
+    limit extra 20
+  endfamily
+  family main
+    repeat date YMD 20091003 20121212 1
+    edit LOGTASK 'main'
+    edit SUITE_START '20091124'
+    family make
+      task setup
+      task links
+        trigger setup eq complete
+        edit FSFAMILY 'an'
+        edit WSHOST 'bee01'
+      task datalinks
+        trigger setup eq complete and links eq complete
+      family det_bins
+        trigger links eq complete and datalinks eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+        task odbsql
+        task odbtools
+          trigger odbsql eq complete
+        task black
+          edit FSFAMILY 'an'
+        task b2otools
+          trigger odbtools eq complete
+          edit CALC_PSBIAS 'false'
+          edit INIPSBIAS 'false'
+          edit USE_PSBIAS 'false'
+        task ifs
+          trigger black eq complete and odbsql eq complete and odbtools eq complete and b2otools eq complete
+          edit FSFAMILY 'an'
+      endfamily
+      family bins
+        trigger links eq complete and datalinks eq complete and det_bins eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+        task cluster
+        task wamabs
+        task prepdata
+        task tc_ws
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task mc_tools
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+          edit THREADS '1'
+        task efi
+      endfamily
+      family prod
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/prod/make'
+        edit EMOS_DOMAIN 'g'
+        edit EMOS_TYPE 'fc'
+        edit EMOS_STREAM 'OPER'
+        task wparam
+          edit EMOS_TYPE 'wp'
+        task tf
+          edit EMOS_TYPE 'tf'
+        task sortreq
+        task bitmap
+        task clima
+        task disssch
+        task tools
+        task ef
+          edit EMOS_STREAM 'ENFO'
+          edit EMOS_TYPE 'ef'
+        task waef
+          edit EMOS_STREAM 'WAEF'
+          edit EMOS_TYPE 'ef'
+      endfamily
+      family mofc
+        trigger links eq complete
+        edit EPSCOUPLE '1'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+        edit RUNCOUPLE '1'
+        edit RUNVARFC '1'
+        task ocsetup
+        task libsoc
+          trigger ocsetup eq complete
+        task oclinks
+          trigger libsoc eq complete
+        task oasis
+          trigger ../det_bins/ifs eq complete
+        task prepdata
+          trigger oclinks eq complete
+        task ma_tools
+          trigger oclinks eq complete
+        family ocean
+          trigger ./ma_tools eq complete
+          task getoce
+          task getfr
+            trigger getoce eq complete
+          task ocean
+            trigger ../libsoc eq complete
+          task forcing
+            trigger ../libsoc eq complete and ocean eq complete
+          task getcouple
+            trigger getoce eq complete
+            edit RUNCOUPLE '1'
+            edit FCGROUP 'fc0'
+        endfamily
+        task tools
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task mofc_tools
+          edit EPSCOUPLE '1'
+        task lib_pp
+          edit EPSCOUPLE '1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task lib_verif
+          edit EPSCOUPLE '1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task lib_clim
+          edit EPSCOUPLE '1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit START_DAY '20091008'
+          edit END_DAY '20121213'
+          edit RUNHINDCAST '1'
+          inlimit /limits:linux_cluster
+      endfamily
+      family wconst
+        trigger bins/wamabs eq complete and links eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+        edit EPSNLEGS '3'
+        edit EPSFCLEV '62'
+        edit EPSWAMNSTPW '1'
+        edit EPSINISTEP_PREVIOUS '0'
+        edit EPSWAMRESOL 'global50'
+        edit EPSFCRES '639'
+        edit TSTEP '1200'
+        edit EPSWAMNFRE '30'
+        edit EPSWAMNANG '24'
+        edit CLASS 'od'
+        task wconstA
+          edit EPSWAMRESOL 'global50'
+          edit EPSFCRES '639'
+          edit EPSWAMNFRE '30'
+          edit EPSWAMNANG '24'
+        task wconstB
+          trigger wconstA eq complete
+          edit EPSWAMRESOL 'global50'
+          edit EPSINISTEP '216'
+          edit EPSFCRES '319'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+        task wconstC
+          trigger wconstB eq complete
+          edit EPSCOUPLE '1'
+          edit EPSWAMRESOL 'global300'
+          edit EPSFCRES '319'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+      endfamily
+      task makesvevo
+        trigger links eq complete
+      task makesvevo_00
+        trigger links eq complete
+        edit DELTA_DAY '1'
+        edit EMOS_BASE '00'
+      task inistage
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+      family make_sv
+        trigger det_bins/ifs eq complete and links eq complete and inistage eq complete
+        family m2_12
+          edit EMOS_BASE '12'
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family m2_00
+          edit EMOS_BASE '00'
+          edit DELTA_DAY '-1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family m1_12
+          edit EMOS_BASE '12'
+          edit DELTA_DAY '-1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family m1_00
+          edit EMOS_BASE '00'
+          edit DELTA_DAY '-0'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+      endfamily
+      family calib
+        trigger links eq complete and datalinks eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+        family onws
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+          task tubes
+            edit DELTA_DAY '0'
+          task tubes_00
+            edit EMOS_BASE '00'
+            edit DELTA_DAY '1'
+        endfamily
+        family onsc
+          edit QUEUE 'ns'
+          edit QUEUE_EPILOG 'ns'
+          edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+          edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+          inlimit /limits:c1b
+          task tubes
+            edit DELTA_DAY '0'
+          task tubes_00
+            edit EMOS_BASE '00'
+            edit DELTA_DAY '1'
+        endfamily
+      endfamily
+    endfamily
+    task inistage
+      trigger ./make eq complete
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+    task inistage_1
+      trigger ./inistage eq complete
+      edit DELTA_DAY '1'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/make'
+    family ref
+      trigger /emc_36r1/main:YMD le /emc_36r1/main/ref:MC_STOP
+      edit MC_STOP '20121213'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+      limit mutex 1
+      family 12
+        edit EMOS_BASE '12'
+        task events
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+          edit HINDCAST '1'
+          edit ONLY_CF '0'
+          event noefi
+          event 240 
+          event 360 
+          event cpl
+          event 768 
+          event cf
+      endfamily
+      family 00
+        edit EMOS_BASE '00'
+        edit DELTA_DAY '1'
+        task events
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+          edit HINDCAST '1'
+          edit ONLY_CF '0'
+          event noefi
+          event 240 
+          event 360 
+          event cpl
+          event 768 
+          event cf
+      endfamily
+      task dummy
+        time 13:00
+      task cpl_nocpl
+      task wait
+        complete ( /emc_36r1/lag:YMD + 1) ge /emc_36r1/main:YMD
+        trigger ( /emc_36r1/lag:YMD + 1) ge /emc_36r1/main:YMD
+    endfamily
+    family 12
+      trigger ( ./make eq complete) and ( ./inistage eq complete)
+      edit EMOS_BASE '12'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+      family ref
+        trigger ../make eq complete and ( /emc_36r1/main:YMD le /e_36r1/main:YMD)
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit QUEUE 'emos-exp'
+        limit mutex 1
+        task an
+          trigger /e_36r1/main/12/an eq complete
+        task anfc
+          complete ( ( /e_36r1/main/12/an/surf_anal/slwet eq complete and ( /e_36r1/main/12/an/4dvar/ifstraj:finalwave or /e_36r1/main/12/an/4dvar eq complete)) or /e_36r1/main/12/an eq complete)
+          trigger 0 eq 1
+        task model_active
+          trigger /e_36r1/main/12/fc/model eq active or /e_36r1/main/12/fc/model eq complete
+        task an_active
+          trigger /e_36r1/main/12/an/4dvar/uptraj_0 eq active or /e_36r1/main/12/an/4dvar/uptraj_0 eq complete
+        task model
+          trigger /e_36r1/main/12/fc/model eq complete
+        task dc
+          trigger /e_36r1/main/00dc/fc/model:step ge 12 or /e_36r1/main/00dc/fc/model eq complete
+        task obs
+          trigger /e_36r1/main/12/obs/get/get_stor eq complete
+      endfamily
+      family sv
+        trigger ./ref/dc eq complete and ./ref/an_active eq complete
+        edit EVOLVE 'no'
+        edit FASTEX 'no'
+        edit EPSTYPE 'sv'
+        edit FCMEM '2000'
+        edit FCSTACK '400'
+        edit FCMRFS '100'
+        edit FCLENGTH '48'
+        edit EPSSVTCSUB '1'
+        edit EPSSVOP '1'
+        edit NPES '16'
+        edit EPSSVTSTEP '900'
+        task getini
+          edit LINIENDA '0'
+          edit INIDATEENDA '0'
+          edit EPSCOUPLE '0'
+          edit N_PERT_AN '10'
+          edit EPSCOUPL_A '0'
+          edit EPSCOUPL_B '0'
+          edit EPSCOUPL_C '0'
+        task inidata_sv
+          trigger getini eq complete
+          edit THREADS '8'
+        task targets
+          late -s +00:03 -c +00:10
+          trigger ../ref/obs eq complete
+          edit EPSTCBB '1'
+          label da_info ""
+          label dcda_info ""
+          event sv
+        task svsh
+          trigger inidata_sv eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit THREADS '8'
+          edit USER_PRIORITY '73'
+        task svnh
+          trigger inidata_sv eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit THREADS '8'
+          edit USER_PRIORITY '74'
+        task subspace
+          trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+        task sv1
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '1'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+          edit USER_PRIORITY '72'
+        task sv2
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '2'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+          edit USER_PRIORITY '71'
+        task sv3
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '3'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task sv4
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '4'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task sv5
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '5'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task sv6
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '6'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task getsvevo
+          event ecfs
+        task getsvs
+          trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit EPSTROP '1'
+        task sv_value
+          trigger getsvs eq complete
+          inlimit /emc_36r1/main/ref:mutex
+        task svnhevo
+          trigger svnh eq complete and ../legA/fc eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit STACK '350'
+          edit HEMISPHERE 'n'
+          edit EVOLVE 'yes'
+          edit ANNPES '8'
+          edit CPUTIME '120000'
+        task svshevo
+          trigger svsh eq complete and ../legA/fc eq complete
+          edit NPES '24'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit STACK '450'
+          edit EVOLVE 'yes'
+          edit ANNPES '8'
+          edit CPUTIME '120000'
+        task clean
+          trigger ../legA/fc eq complete and svnhevo eq complete and svshevo eq complete
+        task dcopy
+          trigger clean eq complete
+          edit SMSFILES '/home/ma/emos/def/o/system'
+      endfamily
+      family legA
+        edit EPSLEG '1'
+        family fc
+          trigger /emc_36r1/main/12/ref/anfc eq complete
+          edit FCMEM '2240'
+          edit FCSTACK '700'
+          edit FCMRFS '0'
+          edit PRIORITY '72'
+          edit USER_PRIORITY '72'
+          edit N_PERT_AN '10'
+          edit SSTLEN '240'
+          edit EPSINISTEP_PREVIOUS '0'
+          edit EPSWAMNFRE '30'
+          edit EPSWAMNANG '24'
+          edit TSTEP '1200'
+          edit EPSFCRES '639'
+          edit RESOL '639'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit CPUTIME '1000'
+          edit MEM '960'
+          edit THREADS '8'
+          edit NPES '8'
+          edit EPSLEG '1'
+          edit PERSST 'true'
+          edit SSTINT '1'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata
+            trigger getini eq complete
+            edit THREADS '8'
+          task getae
+            event 1 
+          task rot
+            trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+            edit EPSTROP '1'
+          family pert_ic
+            trigger rot eq complete and inidata eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+            inlimit /emc_36r1/limits:pertic
+            family 00
+              task pertinic
+                edit MEMBER '0'
+            endfamily
+            family 01
+              task pertinic
+                edit MEMBER '1'
+            endfamily
+            family 02
+              task pertinic
+                edit MEMBER '2'
+            endfamily
+            family 03
+              task pertinic
+                edit MEMBER '3'
+            endfamily
+            family 04
+              task pertinic
+                edit MEMBER '4'
+            endfamily
+            family 05
+              task pertinic
+                edit MEMBER '5'
+            endfamily
+            family 06
+              task pertinic
+                edit MEMBER '6'
+            endfamily
+            family 07
+              task pertinic
+                edit MEMBER '7'
+            endfamily
+            family 08
+              task pertinic
+                edit MEMBER '8'
+            endfamily
+            family 09
+              task pertinic
+                edit MEMBER '9'
+            endfamily
+            family 10
+              task pertinic
+                edit MEMBER '10'
+            endfamily
+            family 11
+              task pertinic
+                edit MEMBER '11'
+            endfamily
+            family 12
+              task pertinic
+                edit MEMBER '12'
+            endfamily
+            family 13
+              task pertinic
+                edit MEMBER '13'
+            endfamily
+            family 14
+              task pertinic
+                edit MEMBER '14'
+            endfamily
+            family 15
+              task pertinic
+                edit MEMBER '15'
+            endfamily
+            family 16
+              task pertinic
+                edit MEMBER '16'
+            endfamily
+            family 17
+              task pertinic
+                edit MEMBER '17'
+            endfamily
+            family 18
+              task pertinic
+                edit MEMBER '18'
+            endfamily
+            family 19
+              task pertinic
+                edit MEMBER '19'
+            endfamily
+            family 20
+              task pertinic
+                edit MEMBER '20'
+            endfamily
+            family 21
+              task pertinic
+                edit MEMBER '21'
+            endfamily
+            family 22
+              task pertinic
+                edit MEMBER '22'
+            endfamily
+            family 23
+              task pertinic
+                edit MEMBER '23'
+            endfamily
+            family 24
+              task pertinic
+                edit MEMBER '24'
+            endfamily
+            family 25
+              task pertinic
+                edit MEMBER '25'
+            endfamily
+            family 26
+              task pertinic
+                edit MEMBER '26'
+            endfamily
+            family 27
+              task pertinic
+                edit MEMBER '27'
+            endfamily
+            family 28
+              task pertinic
+                edit MEMBER '28'
+            endfamily
+            family 29
+              task pertinic
+                edit MEMBER '29'
+            endfamily
+            family 30
+              task pertinic
+                edit MEMBER '30'
+            endfamily
+            family 31
+              task pertinic
+                edit MEMBER '31'
+            endfamily
+            family 32
+              task pertinic
+                edit MEMBER '32'
+            endfamily
+            family 33
+              task pertinic
+                edit MEMBER '33'
+            endfamily
+            family 34
+              task pertinic
+                edit MEMBER '34'
+            endfamily
+            family 35
+              task pertinic
+                edit MEMBER '35'
+            endfamily
+            family 36
+              task pertinic
+                edit MEMBER '36'
+            endfamily
+            family 37
+              task pertinic
+                edit MEMBER '37'
+            endfamily
+            family 38
+              task pertinic
+                edit MEMBER '38'
+            endfamily
+            family 39
+              task pertinic
+                edit MEMBER '39'
+            endfamily
+            family 40
+              task pertinic
+                edit MEMBER '40'
+            endfamily
+            family 41
+              task pertinic
+                edit MEMBER '41'
+            endfamily
+            family 42
+              task pertinic
+                edit MEMBER '42'
+            endfamily
+            family 43
+              task pertinic
+                edit MEMBER '43'
+            endfamily
+            family 44
+              task pertinic
+                edit MEMBER '44'
+            endfamily
+            family 45
+              task pertinic
+                edit MEMBER '45'
+            endfamily
+            family 46
+              task pertinic
+                edit MEMBER '46'
+            endfamily
+            family 47
+              task pertinic
+                edit MEMBER '47'
+            endfamily
+            family 48
+              task pertinic
+                edit MEMBER '48'
+            endfamily
+            family 49
+              task pertinic
+                edit MEMBER '49'
+            endfamily
+            family 50
+              task pertinic
+                edit MEMBER '50'
+            endfamily
+          endfamily
+          task cp_pert
+            trigger pert_ic eq complete
+            event 1 
+          task wavini
+            trigger /emc_36r1/main/12/ref/an eq complete
+            edit FSFAMILY 'mc'
+          family cv
+            trigger ./pert_ic/00 eq complete and ./inidata eq complete and ./wavini eq complete and /emc_36r1/main/12/ref/model_active eq complete
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit EPSFCRES '639'
+            edit TSTEP '1200'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit CLASS 'od'
+            edit PERSST 'no'
+            edit EPSTYPE 'cv'
+            edit EMOS_TYPE 'cv'
+            edit EPSNLEGS '1'
+            edit EPSLEG '1'
+            edit EPSINISTEP '360'
+            edit FCLENGTH '360'
+            edit USER_PRIORITY '73'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            inlimit /emc_36r1/limits:pftotal
+            family control_1
+              edit MEMBER '1'
+              edit EPSMEMBER '1'
+              edit SUBFSFAMILY '/cv001'
+              task getiniLeg
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit FCNPES '32'
+                edit THREADS '4'
+                meter step -1 360 360
+              task derived_param
+                trigger modeleps eq complete
+                edit STEPS '0:144:3 144:360:6'
+            endfamily
+            family control_2
+              edit MEMBER '2'
+              edit EPSMEMBER '2'
+              edit SUBFSFAMILY '/cv002'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              task getiniLeg
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task intHtoL
+                trigger getiniLeg eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '1200'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                meter step -1 360 360
+              task derived_param
+                trigger modeleps eq complete
+                edit STEPS '0:144:3 144:360:6'
+            endfamily
+          endfamily
+          task wavfcdata
+            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+            edit EPSCOUPLE '1'
+          task getpersSST
+            trigger ./inidata eq complete
+            edit EPSCOUPLE '1'
+            edit EPS_INI_STREAM 'DA'
+            edit EPSFCRES '639'
+          family pf
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete and ../../ref/model_active eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTYPE 'pf'
+            edit EMOS_TYPE 'pf'
+            edit USER_PRIORITY '72'
+            edit PRIORITY '72'
+            edit FCNPES '32'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit EPSFCRES '639'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit EPSINISTEP '216'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '1'
+            edit CLASS 'od'
+            inlimit /emc_36r1/limits:pftotal
+            meter step -1 240 240
+            family 01
+              edit EPSMEMBER '1'
+              edit MEMBER '1'
+              edit SUBFSFAMILY '/pf001'
+              task getiniLeg
+                trigger ../../pert_ic/01/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 02
+              edit EPSMEMBER '2'
+              edit MEMBER '2'
+              edit SUBFSFAMILY '/pf002'
+              task getiniLeg
+                trigger ../../pert_ic/02/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 03
+              edit EPSMEMBER '3'
+              edit MEMBER '3'
+              edit SUBFSFAMILY '/pf003'
+              task getiniLeg
+                trigger ../../pert_ic/03/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 04
+              edit EPSMEMBER '4'
+              edit MEMBER '4'
+              edit SUBFSFAMILY '/pf004'
+              task getiniLeg
+                trigger ../../pert_ic/04/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 05
+              edit EPSMEMBER '5'
+              edit MEMBER '5'
+              edit SUBFSFAMILY '/pf005'
+              task getiniLeg
+                trigger ../../pert_ic/05/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 06
+              edit EPSMEMBER '6'
+              edit MEMBER '6'
+              edit SUBFSFAMILY '/pf006'
+              task getiniLeg
+                trigger ../../pert_ic/06/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 07
+              edit EPSMEMBER '7'
+              edit MEMBER '7'
+              edit SUBFSFAMILY '/pf007'
+              task getiniLeg
+                trigger ../../pert_ic/07/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 08
+              edit EPSMEMBER '8'
+              edit MEMBER '8'
+              edit SUBFSFAMILY '/pf008'
+              task getiniLeg
+                trigger ../../pert_ic/08/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 09
+              edit EPSMEMBER '9'
+              edit MEMBER '9'
+              edit SUBFSFAMILY '/pf009'
+              task getiniLeg
+                trigger ../../pert_ic/09/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 10
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              edit SUBFSFAMILY '/pf010'
+              task getiniLeg
+                trigger ../../pert_ic/10/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 11
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              edit SUBFSFAMILY '/pf011'
+              task getiniLeg
+                trigger ../../pert_ic/11/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 12
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              edit SUBFSFAMILY '/pf012'
+              task getiniLeg
+                trigger ../../pert_ic/12/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 13
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              edit SUBFSFAMILY '/pf013'
+              task getiniLeg
+                trigger ../../pert_ic/13/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 14
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              edit SUBFSFAMILY '/pf014'
+              task getiniLeg
+                trigger ../../pert_ic/14/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 15
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              edit SUBFSFAMILY '/pf015'
+              task getiniLeg
+                trigger ../../pert_ic/15/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 16
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              edit SUBFSFAMILY '/pf016'
+              task getiniLeg
+                trigger ../../pert_ic/16/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 17
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              edit SUBFSFAMILY '/pf017'
+              task getiniLeg
+                trigger ../../pert_ic/17/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 18
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              edit SUBFSFAMILY '/pf018'
+              task getiniLeg
+                trigger ../../pert_ic/18/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 19
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              edit SUBFSFAMILY '/pf019'
+              task getiniLeg
+                trigger ../../pert_ic/19/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 20
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              edit SUBFSFAMILY '/pf020'
+              task getiniLeg
+                trigger ../../pert_ic/20/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 21
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              edit SUBFSFAMILY '/pf021'
+              task getiniLeg
+                trigger ../../pert_ic/21/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 22
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              edit SUBFSFAMILY '/pf022'
+              task getiniLeg
+                trigger ../../pert_ic/22/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 23
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              edit SUBFSFAMILY '/pf023'
+              task getiniLeg
+                trigger ../../pert_ic/23/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 24
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              edit SUBFSFAMILY '/pf024'
+              task getiniLeg
+                trigger ../../pert_ic/24/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 25
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              edit SUBFSFAMILY '/pf025'
+              task getiniLeg
+                trigger ../../pert_ic/25/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 26
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              edit SUBFSFAMILY '/pf026'
+              task getiniLeg
+                trigger ../../pert_ic/26/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 27
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              edit SUBFSFAMILY '/pf027'
+              task getiniLeg
+                trigger ../../pert_ic/27/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 28
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              edit SUBFSFAMILY '/pf028'
+              task getiniLeg
+                trigger ../../pert_ic/28/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 29
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              edit SUBFSFAMILY '/pf029'
+              task getiniLeg
+                trigger ../../pert_ic/29/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 30
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              edit SUBFSFAMILY '/pf030'
+              task getiniLeg
+                trigger ../../pert_ic/30/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 31
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              edit SUBFSFAMILY '/pf031'
+              task getiniLeg
+                trigger ../../pert_ic/31/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 32
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              edit SUBFSFAMILY '/pf032'
+              task getiniLeg
+                trigger ../../pert_ic/32/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 33
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              edit SUBFSFAMILY '/pf033'
+              task getiniLeg
+                trigger ../../pert_ic/33/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 34
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              edit SUBFSFAMILY '/pf034'
+              task getiniLeg
+                trigger ../../pert_ic/34/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 35
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              edit SUBFSFAMILY '/pf035'
+              task getiniLeg
+                trigger ../../pert_ic/35/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 36
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              edit SUBFSFAMILY '/pf036'
+              task getiniLeg
+                trigger ../../pert_ic/36/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 37
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              edit SUBFSFAMILY '/pf037'
+              task getiniLeg
+                trigger ../../pert_ic/37/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 38
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              edit SUBFSFAMILY '/pf038'
+              task getiniLeg
+                trigger ../../pert_ic/38/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 39
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              edit SUBFSFAMILY '/pf039'
+              task getiniLeg
+                trigger ../../pert_ic/39/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 40
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              edit SUBFSFAMILY '/pf040'
+              task getiniLeg
+                trigger ../../pert_ic/40/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 41
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              edit SUBFSFAMILY '/pf041'
+              task getiniLeg
+                trigger ../../pert_ic/41/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 42
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              edit SUBFSFAMILY '/pf042'
+              task getiniLeg
+                trigger ../../pert_ic/42/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 43
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              edit SUBFSFAMILY '/pf043'
+              task getiniLeg
+                trigger ../../pert_ic/43/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 44
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              edit SUBFSFAMILY '/pf044'
+              task getiniLeg
+                trigger ../../pert_ic/44/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 45
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              edit SUBFSFAMILY '/pf045'
+              task getiniLeg
+                trigger ../../pert_ic/45/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 46
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              edit SUBFSFAMILY '/pf046'
+              task getiniLeg
+                trigger ../../pert_ic/46/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 47
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              edit SUBFSFAMILY '/pf047'
+              task getiniLeg
+                trigger ../../pert_ic/47/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 48
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              edit SUBFSFAMILY '/pf048'
+              task getiniLeg
+                trigger ../../pert_ic/48/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 49
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              edit SUBFSFAMILY '/pf049'
+              task getiniLeg
+                trigger ../../pert_ic/49/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 50
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              edit SUBFSFAMILY '/pf050'
+              task getiniLeg
+                trigger ../../pert_ic/50/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family cf
+            trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete and /emc_36r1/main/12/ref/model_active eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit MEMBER '0'
+            edit EPSMEMBER '0'
+            edit SUBFSFAMILY '/cf000'
+            edit EPSTYPE 'cf'
+            edit EMOS_TYPE 'cf'
+            edit USER_PRIORITY '73'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit EPSFCRES '639'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit EPSINISTEP '216'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '1'
+            edit CLASS 'od'
+            task getiniLeg
+              trigger ../inidata eq complete and ../wavini eq complete
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task modeleps
+              trigger getiniLeg eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '1'
+              edit EPSFCRES '639'
+              edit EPSINISTEP '216'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit CLASS 'od'
+              edit FCNPES '32'
+              edit THREADS '4'
+              meter step -1 240 240
+          endfamily
+          family reservation1
+            trigger ./pf/01/modeleps eq active or ./pf/01/modeleps eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reserve_cpu
+              late -s +00:02 -c +00:02
+              edit RESERVED_CPUS '10880'
+              edit RESERVE_FOR '48'
+              label info ""
+            task rm_res
+              late -s +00:02 -c +00:02
+              trigger ./reserve_cpu eq complete
+              edit RESERVATION_LABEL 'emos12'
+              label info ""
+          endfamily
+          family reservation2
+            trigger ( ./pf/46/modeleps eq active or ./pf/46/modeleps eq complete) and ( ./pf/47/modeleps eq active or ./pf/47/modeleps eq complete) and ( ./pf/48/modeleps eq active or ./pf/48/modeleps eq complete) and ( ./pf/49/modeleps eq active or ./pf/49/modeleps eq complete) and ( ./pf/50/modeleps eq active or ./pf/50/modeleps eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reset_class
+              late -s +00:02 -c +00:02
+              edit RESERVATION_DEFINITION 'default'
+              label info ""
+            task ms_cpu
+              late -s +00:02 -c +00:02
+              edit MS_CPUS '12800'
+              label info ""
+            task reserve_cpu
+              late -s +00:02 -c +00:02
+              edit RESERVED_CPUS '6400'
+              edit RESERVE_FOR '40'
+              label info ""
+          endfamily
+          family reservation3
+            trigger ( ./pf eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reserve_cpu
+              late -s +00:02 -c +00:02
+              edit RESERVED_CPUS '1024'
+              edit RESERVE_FOR '20'
+              label info ""
+          endfamily
+        endfamily
+        family fax
+          trigger /emc_36r1/main/12/ref/an eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+          task ena4
+            trigger ../postproc/clusters eq complete and ../postproc/ensms eq complete
+            edit ANALYSIS 'NO'
+          task plume
+            trigger ../postproc/prob eq complete and /emc_36r1/main/12/ref/model eq complete
+            edit ANALYSIS 'YES'
+          task fax
+            trigger plume eq complete and ena4 eq complete
+            edit SMSTRIES '1'
+          task manfax
+            trigger plume eq complete and ena4 eq complete
+            edit SMSTRIES '1'
+            edit COUNTRY ''
+          task faxcheck
+            trigger fax eq complete
+          task faxcheck2
+            trigger fax eq complete
+            time 08:00
+        endfamily
+        family postproc
+          trigger ./fc ne queued
+          edit STEPS '24/240/12/24 168/168/12/48 240/240/12/72 240/240/12/120'
+          inlimit /emc_36r1/limits:postproc
+          family prepare
+            complete /emc_36r1/main/ref/12/events:cf
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            family all
+              complete ../../fc eq complete and ./query eq active
+              trigger ../../fc eq complete and ( ./query eq queued or ./query eq complete)
+              edit KIND 'all'
+              edit STEP '-1'
+              family t850
+                edit PARAM 'T'
+                edit LEVEL '850'
+                task pp_prep
+              endfamily
+              family t500
+                edit PARAM 'T'
+                edit LEVEL '500'
+                task pp_prep
+              endfamily
+              family z1000
+                edit PARAM 'Z'
+                edit LEVEL '1000'
+                task pp_prep
+              endfamily
+              family z500
+                edit PARAM 'Z'
+                edit LEVEL '500'
+                task pp_prep
+              endfamily
+            endfamily
+            family query
+              complete ../../fc eq complete and ../../fc/pf:step le 0
+              trigger ( ( ../../fc/pf:step ge 0) and ( ../../fc/cf/modeleps:step ge 0)) or ( ../../fc/pf eq complete and ../../fc/cf eq complete)
+              edit KIND 'query'
+              family t850
+                edit PARAM 'T'
+                edit LEVEL '850'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+              family t500
+                edit PARAM 'T'
+                edit LEVEL '500'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+              family z1000
+                edit PARAM 'Z'
+                edit LEVEL '1000'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+              family z500
+                edit PARAM 'Z'
+                edit LEVEL '500'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+            endfamily
+          endfamily
+          family ensms
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger ( ../fc eq complete) and ( ./prepare eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            family limits
+              limit fdb 1
+              limit gen 8
+            endfamily
+            task ensms
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit ENS_MARS 'false'
+              event stage
+            family 048
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '003'
+              edit STEP2 '048'
+              edit BY '3'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 096
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '051'
+              edit STEP2 '096'
+              edit BY '3'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 144
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '099'
+              edit STEP2 '144'
+              edit BY '3'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 240
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '150'
+              edit STEP2 '240'
+              edit BY '6'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+          endfamily
+          family prob
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger /emc_36r1/main/12/legA/fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            edit STEP1 '12'
+            edit STEP2 '240'
+            edit BY '12'
+            family 24
+              edit STEP1 '24'
+              edit STEP2 '240'
+              edit BY '24'
+              family t850
+                trigger ../../prepare/all/t850 eq complete
+                family 120_240
+                  edit STEPS '120 240'
+                  task t850
+                    event 1 
+                endfamily
+                family 120_168
+                  trigger ./120_240/t850:1 or ./120_240 eq complete
+                  edit STEPS '120 168'
+                  task t850
+                    event 1 
+                endfamily
+                family 168_240
+                  trigger ./120_240/t850:1 or ./120_240 eq complete
+                  edit STEPS '168 240'
+                  task t850
+                    event 1 
+                endfamily
+              endfamily
+              task rain
+              task ff
+            endfamily
+            family 12
+              edit STEP1 '12'
+              edit STEP2 '228'
+              edit BY '24'
+              task t850
+                trigger ../../prepare/all/t850 eq complete
+              task rain
+              task ff
+            endfamily
+            task 2t
+            task swh
+            task mwp
+            task 10fg
+              trigger ../dp eq complete
+            task prob_fdb
+              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
+          endfamily
+          family tc
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger ../fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
+            edit TCINIEXPVER '0046'
+            family obsdata
+              trigger ( /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/legA/fc/cf eq complete)
+              task retrieve
+                late -c +00:10
+                trigger ( /emc_36r1/main/12/sv/targets eq complete or /emc_36r1/main/12/sv/targets:sv)
+                label info ""
+                event notc
+              task obs
+                trigger retrieve eq complete
+            endfamily
+            family stage
+              trigger ( /emc_36r1/main/12/legA/fc eq complete)
+              task an
+              task fc
+              task pf
+              task cf
+            endfamily
+            family tracking
+              trigger obsdata/obs eq complete and stage eq complete
+              inlimit /emc_36r1/limits:tc
+              family 1
+                edit MEMBER '1'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 2
+                edit MEMBER '2'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 3
+                edit MEMBER '3'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 4
+                edit MEMBER '4'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 5
+                edit MEMBER '5'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 6
+                edit MEMBER '6'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 7
+                edit MEMBER '7'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 8
+                edit MEMBER '8'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 9
+                edit MEMBER '9'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 10
+                edit MEMBER '10'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 11
+                edit MEMBER '11'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 12
+                edit MEMBER '12'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 13
+                edit MEMBER '13'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 14
+                edit MEMBER '14'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 15
+                edit MEMBER '15'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 16
+                edit MEMBER '16'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 17
+                edit MEMBER '17'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 18
+                edit MEMBER '18'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 19
+                edit MEMBER '19'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 20
+                edit MEMBER '20'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 21
+                edit MEMBER '21'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 22
+                edit MEMBER '22'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 23
+                edit MEMBER '23'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 24
+                edit MEMBER '24'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 25
+                edit MEMBER '25'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 26
+                edit MEMBER '26'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 27
+                edit MEMBER '27'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 28
+                edit MEMBER '28'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 29
+                edit MEMBER '29'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 30
+                edit MEMBER '30'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 31
+                edit MEMBER '31'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 32
+                edit MEMBER '32'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 33
+                edit MEMBER '33'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 34
+                edit MEMBER '34'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 35
+                edit MEMBER '35'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 36
+                edit MEMBER '36'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 37
+                edit MEMBER '37'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 38
+                edit MEMBER '38'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 39
+                edit MEMBER '39'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 40
+                edit MEMBER '40'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 41
+                edit MEMBER '41'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 42
+                edit MEMBER '42'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 43
+                edit MEMBER '43'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 44
+                edit MEMBER '44'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 45
+                edit MEMBER '45'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 46
+                edit MEMBER '46'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 47
+                edit MEMBER '47'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 48
+                edit MEMBER '48'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 49
+                edit MEMBER '49'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 50
+                edit MEMBER '50'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family cf
+                edit MEMBER '51'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family oper
+                edit MEMBER '52'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+            endfamily
+            family post_process
+              task to_bufr
+                trigger ../tracking eq complete
+            endfamily
+          endfamily
+          family calibrate
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger /emc_36r1/main/12/ref/an eq complete and ../fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
+            family onsc
+              edit QUEUE 'ns'
+              edit QUEUE_EPILOG 'ns'
+              edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+              edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+              inlimit /limits:c1b
+              task feedupcal
+              task upcal
+                trigger feedupcal eq complete
+                edit Z500_EXPVER '0001'
+                edit METVIEW 'metview'
+              task revertupcal
+            endfamily
+          endfamily
+          family clusters
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger ./calibrate/onsc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/clusters'
+            edit USER_PRIORITY '81'
+            edit QUEUE 'ns'
+            edit QUEUE_EPILOG 'ns'
+            edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+            edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+            inlimit /limits:c1b
+            task cthresh
+            task cluster
+              trigger cthresh eq complete and /emc_36r1/main/12/ref/model eq complete
+              edit USER_PRIORITY '76'
+            task tubcon
+              trigger /emc_36r1/main/12/ref/model eq complete
+            task tubgen
+              late -c +00:20
+              trigger tubcon eq complete
+          endfamily
+          family efi
+            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
+            trigger /emc_36r1/main/12/legA/postproc/dp eq complete
+            edit HC_VERSION '0046'
+            edit HC_EXPVER '0046'
+            edit REF_VERSION '0046'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            edit NC_DAYS '31'
+            edit EPSLEG '1'
+            inlimit /emc_36r1/limits:efi
+            task stage
+              edit NC_DAYS '31'
+            family 000_120
+              trigger ./stage eq complete
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 024_144
+              trigger ./stage eq complete
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 000_240
+              trigger ./stage eq complete
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 012_036
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 036_060
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 060_084
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 084_108
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 108_132
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+          endfamily
+          task efi2fdb
+            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
+            trigger ./efi eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            inlimit /emc_36r1/main/ref:mutex
+            event none
+          family dp
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '0:144:3 144:240:6'
+            inlimit /emc_36r1/limits:dp
+            family cf
+              trigger ../../fc/cf eq complete
+              edit EMOS_TYPE 'cf'
+              task derived_param
+                edit MEMBER 'off'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/12/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                trigger ../../../fc/pf/01 eq complete
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task derived_param
+              endfamily
+              family 02
+                trigger ../../../fc/pf/02 eq complete
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task derived_param
+              endfamily
+              family 03
+                trigger ../../../fc/pf/03 eq complete
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task derived_param
+              endfamily
+              family 04
+                trigger ../../../fc/pf/04 eq complete
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task derived_param
+              endfamily
+              family 05
+                trigger ../../../fc/pf/05 eq complete
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task derived_param
+              endfamily
+              family 06
+                trigger ../../../fc/pf/06 eq complete
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task derived_param
+              endfamily
+              family 07
+                trigger ../../../fc/pf/07 eq complete
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task derived_param
+              endfamily
+              family 08
+                trigger ../../../fc/pf/08 eq complete
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task derived_param
+              endfamily
+              family 09
+                trigger ../../../fc/pf/09 eq complete
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task derived_param
+              endfamily
+              family 10
+                trigger ../../../fc/pf/10 eq complete
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task derived_param
+              endfamily
+              family 11
+                trigger ../../../fc/pf/11 eq complete
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task derived_param
+              endfamily
+              family 12
+                trigger ../../../fc/pf/12 eq complete
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task derived_param
+              endfamily
+              family 13
+                trigger ../../../fc/pf/13 eq complete
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task derived_param
+              endfamily
+              family 14
+                trigger ../../../fc/pf/14 eq complete
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task derived_param
+              endfamily
+              family 15
+                trigger ../../../fc/pf/15 eq complete
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task derived_param
+              endfamily
+              family 16
+                trigger ../../../fc/pf/16 eq complete
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task derived_param
+              endfamily
+              family 17
+                trigger ../../../fc/pf/17 eq complete
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task derived_param
+              endfamily
+              family 18
+                trigger ../../../fc/pf/18 eq complete
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task derived_param
+              endfamily
+              family 19
+                trigger ../../../fc/pf/19 eq complete
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task derived_param
+              endfamily
+              family 20
+                trigger ../../../fc/pf/20 eq complete
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task derived_param
+              endfamily
+              family 21
+                trigger ../../../fc/pf/21 eq complete
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task derived_param
+              endfamily
+              family 22
+                trigger ../../../fc/pf/22 eq complete
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task derived_param
+              endfamily
+              family 23
+                trigger ../../../fc/pf/23 eq complete
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task derived_param
+              endfamily
+              family 24
+                trigger ../../../fc/pf/24 eq complete
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task derived_param
+              endfamily
+              family 25
+                trigger ../../../fc/pf/25 eq complete
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task derived_param
+              endfamily
+              family 26
+                trigger ../../../fc/pf/26 eq complete
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task derived_param
+              endfamily
+              family 27
+                trigger ../../../fc/pf/27 eq complete
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task derived_param
+              endfamily
+              family 28
+                trigger ../../../fc/pf/28 eq complete
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task derived_param
+              endfamily
+              family 29
+                trigger ../../../fc/pf/29 eq complete
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task derived_param
+              endfamily
+              family 30
+                trigger ../../../fc/pf/30 eq complete
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task derived_param
+              endfamily
+              family 31
+                trigger ../../../fc/pf/31 eq complete
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task derived_param
+              endfamily
+              family 32
+                trigger ../../../fc/pf/32 eq complete
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task derived_param
+              endfamily
+              family 33
+                trigger ../../../fc/pf/33 eq complete
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task derived_param
+              endfamily
+              family 34
+                trigger ../../../fc/pf/34 eq complete
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task derived_param
+              endfamily
+              family 35
+                trigger ../../../fc/pf/35 eq complete
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task derived_param
+              endfamily
+              family 36
+                trigger ../../../fc/pf/36 eq complete
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task derived_param
+              endfamily
+              family 37
+                trigger ../../../fc/pf/37 eq complete
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task derived_param
+              endfamily
+              family 38
+                trigger ../../../fc/pf/38 eq complete
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task derived_param
+              endfamily
+              family 39
+                trigger ../../../fc/pf/39 eq complete
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task derived_param
+              endfamily
+              family 40
+                trigger ../../../fc/pf/40 eq complete
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task derived_param
+              endfamily
+              family 41
+                trigger ../../../fc/pf/41 eq complete
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task derived_param
+              endfamily
+              family 42
+                trigger ../../../fc/pf/42 eq complete
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task derived_param
+              endfamily
+              family 43
+                trigger ../../../fc/pf/43 eq complete
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task derived_param
+              endfamily
+              family 44
+                trigger ../../../fc/pf/44 eq complete
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task derived_param
+              endfamily
+              family 45
+                trigger ../../../fc/pf/45 eq complete
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task derived_param
+              endfamily
+              family 46
+                trigger ../../../fc/pf/46 eq complete
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task derived_param
+              endfamily
+              family 47
+                trigger ../../../fc/pf/47 eq complete
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task derived_param
+              endfamily
+              family 48
+                trigger ../../../fc/pf/48 eq complete
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task derived_param
+              endfamily
+              family 49
+                trigger ../../../fc/pf/49 eq complete
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task derived_param
+              endfamily
+              family 50
+                trigger ../../../fc/pf/50 eq complete
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task derived_param
+              endfamily
+            endfamily
+          endfamily
+          family extra
+            trigger ./dp eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '0:144:3 144:240:6'
+            inlimit /emc_36r1/limits:extra
+            family cf
+              edit EMOS_TYPE 'cf'
+              task extrafields
+                edit EPSFCRES '639'
+                edit FCLENGTH '240'
+                edit FCLENGTH0 '0'
+                edit RUNVARFC '1'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/12/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 05
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 06
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 07
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 08
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 09
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 10
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 11
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 12
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 13
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 14
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 15
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 16
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 17
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 18
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 19
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 20
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 21
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 22
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 23
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 24
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 25
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 26
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 27
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 28
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 29
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 30
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 31
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 32
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 33
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 34
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 35
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 36
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 37
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 38
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 39
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 40
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 41
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 42
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 43
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 44
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 45
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 46
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 47
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 48
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 49
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 50
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family prod
+          edit MEM '3000'
+          edit ACCOUNT 'oeenfopg'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'cp'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '90'
+          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
+          edit SMSURL 'sub=fixed/'
+          inlimit /limits:prod
+          family eps
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            inlimit /emc_36r1/limits:prodeps
+            family 0000
+              edit EMOS_TIME_STEP_H '0000'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0003
+              edit EMOS_TIME_STEP_H '0003'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0006
+              edit EMOS_TIME_STEP_H '0006'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0009
+              edit EMOS_TIME_STEP_H '0009'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0012
+              edit EMOS_TIME_STEP_H '0012'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0015
+              edit EMOS_TIME_STEP_H '0015'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0018
+              edit EMOS_TIME_STEP_H '0018'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0021
+              edit EMOS_TIME_STEP_H '0021'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0024
+              edit EMOS_TIME_STEP_H '0024'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0027
+              edit EMOS_TIME_STEP_H '0027'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0030
+              edit EMOS_TIME_STEP_H '0030'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0033
+              edit EMOS_TIME_STEP_H '0033'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0036
+              edit EMOS_TIME_STEP_H '0036'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0039
+              edit EMOS_TIME_STEP_H '0039'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0042
+              edit EMOS_TIME_STEP_H '0042'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0045
+              edit EMOS_TIME_STEP_H '0045'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0048
+              edit EMOS_TIME_STEP_H '0048'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0051
+              edit EMOS_TIME_STEP_H '0051'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0054
+              edit EMOS_TIME_STEP_H '0054'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0057
+              edit EMOS_TIME_STEP_H '0057'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0060
+              edit EMOS_TIME_STEP_H '0060'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0063
+              edit EMOS_TIME_STEP_H '0063'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0066
+              edit EMOS_TIME_STEP_H '0066'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0069
+              edit EMOS_TIME_STEP_H '0069'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0072
+              edit EMOS_TIME_STEP_H '0072'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0075
+              edit EMOS_TIME_STEP_H '0075'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0078
+              edit EMOS_TIME_STEP_H '0078'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0081
+              edit EMOS_TIME_STEP_H '0081'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0084
+              edit EMOS_TIME_STEP_H '0084'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0087
+              edit EMOS_TIME_STEP_H '0087'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0090
+              edit EMOS_TIME_STEP_H '0090'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0093
+              edit EMOS_TIME_STEP_H '0093'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0096
+              edit EMOS_TIME_STEP_H '0096'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0099
+              edit EMOS_TIME_STEP_H '0099'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0102
+              edit EMOS_TIME_STEP_H '0102'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0105
+              edit EMOS_TIME_STEP_H '0105'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0108
+              edit EMOS_TIME_STEP_H '0108'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0111
+              edit EMOS_TIME_STEP_H '0111'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0114
+              edit EMOS_TIME_STEP_H '0114'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0117
+              edit EMOS_TIME_STEP_H '0117'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0120
+              edit EMOS_TIME_STEP_H '0120'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0123
+              edit EMOS_TIME_STEP_H '0123'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0126
+              edit EMOS_TIME_STEP_H '0126'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0129
+              edit EMOS_TIME_STEP_H '0129'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0132
+              edit EMOS_TIME_STEP_H '0132'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0135
+              edit EMOS_TIME_STEP_H '0135'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0138
+              edit EMOS_TIME_STEP_H '0138'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0141
+              edit EMOS_TIME_STEP_H '0141'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0144
+              edit EMOS_TIME_STEP_H '0144'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0150
+              edit EMOS_TIME_STEP_H '0150'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0156
+              edit EMOS_TIME_STEP_H '0156'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0162
+              edit EMOS_TIME_STEP_H '0162'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0168
+              edit EMOS_TIME_STEP_H '0168'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0174
+              edit EMOS_TIME_STEP_H '0174'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0180
+              edit EMOS_TIME_STEP_H '0180'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0186
+              edit EMOS_TIME_STEP_H '0186'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0192
+              edit EMOS_TIME_STEP_H '0192'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0198
+              edit EMOS_TIME_STEP_H '0198'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0204
+              edit EMOS_TIME_STEP_H '0204'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0210
+              edit EMOS_TIME_STEP_H '0210'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0216
+              edit EMOS_TIME_STEP_H '0216'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0222
+              edit EMOS_TIME_STEP_H '0222'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0228
+              edit EMOS_TIME_STEP_H '0228'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0234
+              edit EMOS_TIME_STEP_H '0234'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0240
+              edit EMOS_TIME_STEP_H '0240'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+          endfamily
+          family wave
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            edit PGNPES '2'
+            edit URL 'GWAEF/12'
+            inlimit /emc_36r1/limits:prodwave
+            family 0000
+              edit EMOS_TIME_STEP_H '0000'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0003
+              edit EMOS_TIME_STEP_H '0003'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0006
+              edit EMOS_TIME_STEP_H '0006'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0009
+              edit EMOS_TIME_STEP_H '0009'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0012
+              edit EMOS_TIME_STEP_H '0012'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0015
+              edit EMOS_TIME_STEP_H '0015'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0018
+              edit EMOS_TIME_STEP_H '0018'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0021
+              edit EMOS_TIME_STEP_H '0021'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0024
+              edit EMOS_TIME_STEP_H '0024'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0027
+              edit EMOS_TIME_STEP_H '0027'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0030
+              edit EMOS_TIME_STEP_H '0030'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0033
+              edit EMOS_TIME_STEP_H '0033'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0036
+              edit EMOS_TIME_STEP_H '0036'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0039
+              edit EMOS_TIME_STEP_H '0039'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0042
+              edit EMOS_TIME_STEP_H '0042'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0045
+              edit EMOS_TIME_STEP_H '0045'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0048
+              edit EMOS_TIME_STEP_H '0048'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0051
+              edit EMOS_TIME_STEP_H '0051'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0054
+              edit EMOS_TIME_STEP_H '0054'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0057
+              edit EMOS_TIME_STEP_H '0057'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0060
+              edit EMOS_TIME_STEP_H '0060'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0063
+              edit EMOS_TIME_STEP_H '0063'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0066
+              edit EMOS_TIME_STEP_H '0066'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0069
+              edit EMOS_TIME_STEP_H '0069'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0072
+              edit EMOS_TIME_STEP_H '0072'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0075
+              edit EMOS_TIME_STEP_H '0075'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0078
+              edit EMOS_TIME_STEP_H '0078'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0081
+              edit EMOS_TIME_STEP_H '0081'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0084
+              edit EMOS_TIME_STEP_H '0084'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0087
+              edit EMOS_TIME_STEP_H '0087'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0090
+              edit EMOS_TIME_STEP_H '0090'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0093
+              edit EMOS_TIME_STEP_H '0093'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0096
+              edit EMOS_TIME_STEP_H '0096'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0099
+              edit EMOS_TIME_STEP_H '0099'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0102
+              edit EMOS_TIME_STEP_H '0102'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0105
+              edit EMOS_TIME_STEP_H '0105'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0108
+              edit EMOS_TIME_STEP_H '0108'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0111
+              edit EMOS_TIME_STEP_H '0111'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0114
+              edit EMOS_TIME_STEP_H '0114'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0117
+              edit EMOS_TIME_STEP_H '0117'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0120
+              edit EMOS_TIME_STEP_H '0120'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0123
+              edit EMOS_TIME_STEP_H '0123'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0126
+              edit EMOS_TIME_STEP_H '0126'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0129
+              edit EMOS_TIME_STEP_H '0129'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0132
+              edit EMOS_TIME_STEP_H '0132'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0135
+              edit EMOS_TIME_STEP_H '0135'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0138
+              edit EMOS_TIME_STEP_H '0138'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0141
+              edit EMOS_TIME_STEP_H '0141'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0144
+              edit EMOS_TIME_STEP_H '0144'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0150
+              edit EMOS_TIME_STEP_H '0150'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0156
+              edit EMOS_TIME_STEP_H '0156'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0162
+              edit EMOS_TIME_STEP_H '0162'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0168
+              edit EMOS_TIME_STEP_H '0168'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0174
+              edit EMOS_TIME_STEP_H '0174'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0180
+              edit EMOS_TIME_STEP_H '0180'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0186
+              edit EMOS_TIME_STEP_H '0186'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0192
+              edit EMOS_TIME_STEP_H '0192'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0198
+              edit EMOS_TIME_STEP_H '0198'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0204
+              edit EMOS_TIME_STEP_H '0204'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0210
+              edit EMOS_TIME_STEP_H '0210'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0216
+              edit EMOS_TIME_STEP_H '0216'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0222
+              edit EMOS_TIME_STEP_H '0222'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0228
+              edit EMOS_TIME_STEP_H '0228'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0234
+              edit EMOS_TIME_STEP_H '0234'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0240
+              edit EMOS_TIME_STEP_H '0240'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+          endfamily
+          family getreq
+            trigger ../fc/pf eq active or ../fc/pf/01 eq complete
+            edit EMOS_TYPE 'cm'
+            edit EMOS_DOMAIN 'G'
+            edit EMOS_PROJECT '12'
+            edit PROD_TASK '1'
+            edit SMSTRIES '1'
+            edit EMOS_STREAM 'ENFO'
+            task collectreq
+              edit QUEUE 'diss'
+              edit USER 'emos'
+              edit WSHOST 'diss'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit LOGDIR '/diss/log'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit EMOS_BASE '12'
+            task eps
+              late -s +00:03 -c +00:10
+              trigger collectreq eq complete
+              label info ""
+              event 1 
+            task collectwave
+              trigger collectreq eq complete
+              edit QUEUE 'diss'
+              edit USER 'emos'
+              edit WSHOST 'diss'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit LOGDIR '/diss/log'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit EMOS_STREAM 'WAEF'
+              edit EMOS_BASE '12'
+            task wave_eps
+              late -s +00:03 -c +00:10
+              trigger collectwave eq complete
+              edit EMOS_STREAM 'WAEF'
+              edit USER_PRIORITY '89'
+              label info ""
+              event 1 
+            task collectbitmap
+              trigger collectwave eq complete
+              edit QUEUE 'diss'
+              edit USER 'emos'
+              edit WSHOST 'diss'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit LOGDIR '/diss/log'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit SMSOUT '/vol/emos_nc/output'
+            task bitmap
+              late -s +00:03 -c +00:10
+              trigger collectbitmap eq complete and ( eps:001 or eps eq complete)
+              event 1 
+          endfamily
+          task enfo_tc
+            late -s +00:05 -c +00:15
+            trigger ( ./getreq/eps:001 or ./getreq/eps eq complete) and ../postproc/tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TYPE 'tf'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '1'
+          task oper_tc
+            late -s +00:05 -c +00:15
+            trigger ./enfo_tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TYPE 'tf'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '1'
+            edit EMOS_STREAM 'OPER'
+          task prod_wparam
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and /e_36r1/main/12/prod/240/prod_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TYPE 'wp'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '52'
+          task enfo_postproc
+            late -s +00:05 -c +00:15
+            trigger ../postproc eq complete and ( ../../legA/prod/getreq/eps eq complete) and ../../legA/postproc/efi eq complete and ../../legA/postproc/clusters eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'ep'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '21'
+          task waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '1'
+        endfamily
+        family prod2diss
+          edit USER_PRIORITY '90'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'ef'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+          edit SMSURL 'GENFO/12'
+          task operation_is_late
+            event yes
+          family eps
+            family 0000
+              edit EMOS_TIME_STEP_H '0000'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0000/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0003
+              edit EMOS_TIME_STEP_H '0003'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0003/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0000/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0006
+              edit EMOS_TIME_STEP_H '0006'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0006/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0003/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0009
+              edit EMOS_TIME_STEP_H '0009'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0009/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0006/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0012
+              edit EMOS_TIME_STEP_H '0012'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0012/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0009/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0015
+              edit EMOS_TIME_STEP_H '0015'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0015/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0012/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0018
+              edit EMOS_TIME_STEP_H '0018'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0018/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0015/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0021
+              edit EMOS_TIME_STEP_H '0021'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0021/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0018/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0024
+              edit EMOS_TIME_STEP_H '0024'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0024/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0021/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0027
+              edit EMOS_TIME_STEP_H '0027'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0027/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0024/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0030
+              edit EMOS_TIME_STEP_H '0030'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0030/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0027/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0033
+              edit EMOS_TIME_STEP_H '0033'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0033/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0030/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0036
+              edit EMOS_TIME_STEP_H '0036'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0036/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0033/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0039
+              edit EMOS_TIME_STEP_H '0039'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0039/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0036/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0042
+              edit EMOS_TIME_STEP_H '0042'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0042/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0039/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0045
+              edit EMOS_TIME_STEP_H '0045'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0045/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0042/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0048
+              edit EMOS_TIME_STEP_H '0048'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0048/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0045/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0051
+              edit EMOS_TIME_STEP_H '0051'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0051/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0048/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0054
+              edit EMOS_TIME_STEP_H '0054'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0054/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0051/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0057
+              edit EMOS_TIME_STEP_H '0057'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0057/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0054/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0060
+              edit EMOS_TIME_STEP_H '0060'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0060/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0057/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0063
+              edit EMOS_TIME_STEP_H '0063'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0063/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0060/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0066
+              edit EMOS_TIME_STEP_H '0066'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0066/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0063/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0069
+              edit EMOS_TIME_STEP_H '0069'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0069/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0066/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0072
+              edit EMOS_TIME_STEP_H '0072'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0072/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0069/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0075
+              edit EMOS_TIME_STEP_H '0075'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0075/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0072/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0078
+              edit EMOS_TIME_STEP_H '0078'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0078/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0075/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0081
+              edit EMOS_TIME_STEP_H '0081'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0081/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0078/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0084
+              edit EMOS_TIME_STEP_H '0084'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0084/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0081/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0087
+              edit EMOS_TIME_STEP_H '0087'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0087/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0084/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0090
+              edit EMOS_TIME_STEP_H '0090'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0090/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0087/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0093
+              edit EMOS_TIME_STEP_H '0093'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0093/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0090/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0096
+              edit EMOS_TIME_STEP_H '0096'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0096/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0093/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0099
+              edit EMOS_TIME_STEP_H '0099'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0099/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0096/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0102
+              edit EMOS_TIME_STEP_H '0102'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0102/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0099/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0105
+              edit EMOS_TIME_STEP_H '0105'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0105/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0102/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0108
+              edit EMOS_TIME_STEP_H '0108'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0108/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0105/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0111
+              edit EMOS_TIME_STEP_H '0111'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0111/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0108/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0114
+              edit EMOS_TIME_STEP_H '0114'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0114/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0111/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0117
+              edit EMOS_TIME_STEP_H '0117'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0117/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0114/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0120
+              edit EMOS_TIME_STEP_H '0120'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0120/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0117/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0123
+              edit EMOS_TIME_STEP_H '0123'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0123/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0120/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0126
+              edit EMOS_TIME_STEP_H '0126'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0126/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0123/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0129
+              edit EMOS_TIME_STEP_H '0129'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0129/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0126/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0132
+              edit EMOS_TIME_STEP_H '0132'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0132/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0129/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0135
+              edit EMOS_TIME_STEP_H '0135'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0135/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0132/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0138
+              edit EMOS_TIME_STEP_H '0138'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0138/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0135/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0141
+              edit EMOS_TIME_STEP_H '0141'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0141/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0138/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0144
+              edit EMOS_TIME_STEP_H '0144'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0144/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0141/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0150
+              edit EMOS_TIME_STEP_H '0150'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0150/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0144/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0156
+              edit EMOS_TIME_STEP_H '0156'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0156/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0150/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0162
+              edit EMOS_TIME_STEP_H '0162'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0162/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0156/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0168
+              edit EMOS_TIME_STEP_H '0168'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0168/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0162/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0174
+              edit EMOS_TIME_STEP_H '0174'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0174/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0168/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0180
+              edit EMOS_TIME_STEP_H '0180'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0180/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0174/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0186
+              edit EMOS_TIME_STEP_H '0186'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0186/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0180/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0192
+              edit EMOS_TIME_STEP_H '0192'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0192/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0186/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0198
+              edit EMOS_TIME_STEP_H '0198'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0198/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0192/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0204
+              edit EMOS_TIME_STEP_H '0204'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0204/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0198/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0210
+              edit EMOS_TIME_STEP_H '0210'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0210/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0204/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0216
+              edit EMOS_TIME_STEP_H '0216'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0216/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0210/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0222
+              edit EMOS_TIME_STEP_H '0222'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0222/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0216/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0228
+              edit EMOS_TIME_STEP_H '0228'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0228/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0222/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0234
+              edit EMOS_TIME_STEP_H '0234'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0234/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0228/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0240
+              edit EMOS_TIME_STEP_H '0240'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0240/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0234/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            task check
+              trigger ./0240 eq complete
+          endfamily
+          family wave
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TYPE 'we'
+            edit SMSURL 'GWAEF/12'
+            family 0000
+              trigger ../../prod/wave/0000/prodwave eq complete
+              edit EMOS_TIME_STEP_H '0000'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0003
+              trigger ../../prod/wave/0003/prodwave eq complete and ( ./0000 eq complete)
+              edit EMOS_TIME_STEP_H '0003'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0006
+              trigger ../../prod/wave/0006/prodwave eq complete and ( ./0003 eq complete)
+              edit EMOS_TIME_STEP_H '0006'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0009
+              trigger ../../prod/wave/0009/prodwave eq complete and ( ./0006 eq complete)
+              edit EMOS_TIME_STEP_H '0009'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0012
+              trigger ../../prod/wave/0012/prodwave eq complete and ( ./0009 eq complete)
+              edit EMOS_TIME_STEP_H '0012'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0015
+              trigger ../../prod/wave/0015/prodwave eq complete and ( ./0012 eq complete)
+              edit EMOS_TIME_STEP_H '0015'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0018
+              trigger ../../prod/wave/0018/prodwave eq complete and ( ./0015 eq complete)
+              edit EMOS_TIME_STEP_H '0018'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0021
+              trigger ../../prod/wave/0021/prodwave eq complete and ( ./0018 eq complete)
+              edit EMOS_TIME_STEP_H '0021'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0024
+              trigger ../../prod/wave/0024/prodwave eq complete and ( ./0021 eq complete)
+              edit EMOS_TIME_STEP_H '0024'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0027
+              trigger ../../prod/wave/0027/prodwave eq complete and ( ./0024 eq complete)
+              edit EMOS_TIME_STEP_H '0027'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0030
+              trigger ../../prod/wave/0030/prodwave eq complete and ( ./0027 eq complete)
+              edit EMOS_TIME_STEP_H '0030'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0033
+              trigger ../../prod/wave/0033/prodwave eq complete and ( ./0030 eq complete)
+              edit EMOS_TIME_STEP_H '0033'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0036
+              trigger ../../prod/wave/0036/prodwave eq complete and ( ./0033 eq complete)
+              edit EMOS_TIME_STEP_H '0036'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0039
+              trigger ../../prod/wave/0039/prodwave eq complete and ( ./0036 eq complete)
+              edit EMOS_TIME_STEP_H '0039'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0042
+              trigger ../../prod/wave/0042/prodwave eq complete and ( ./0039 eq complete)
+              edit EMOS_TIME_STEP_H '0042'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0045
+              trigger ../../prod/wave/0045/prodwave eq complete and ( ./0042 eq complete)
+              edit EMOS_TIME_STEP_H '0045'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0048
+              trigger ../../prod/wave/0048/prodwave eq complete and ( ./0045 eq complete)
+              edit EMOS_TIME_STEP_H '0048'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0051
+              trigger ../../prod/wave/0051/prodwave eq complete and ( ./0048 eq complete)
+              edit EMOS_TIME_STEP_H '0051'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0054
+              trigger ../../prod/wave/0054/prodwave eq complete and ( ./0051 eq complete)
+              edit EMOS_TIME_STEP_H '0054'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0057
+              trigger ../../prod/wave/0057/prodwave eq complete and ( ./0054 eq complete)
+              edit EMOS_TIME_STEP_H '0057'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0060
+              trigger ../../prod/wave/0060/prodwave eq complete and ( ./0057 eq complete)
+              edit EMOS_TIME_STEP_H '0060'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0063
+              trigger ../../prod/wave/0063/prodwave eq complete and ( ./0060 eq complete)
+              edit EMOS_TIME_STEP_H '0063'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0066
+              trigger ../../prod/wave/0066/prodwave eq complete and ( ./0063 eq complete)
+              edit EMOS_TIME_STEP_H '0066'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0069
+              trigger ../../prod/wave/0069/prodwave eq complete and ( ./0066 eq complete)
+              edit EMOS_TIME_STEP_H '0069'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0072
+              trigger ../../prod/wave/0072/prodwave eq complete and ( ./0069 eq complete)
+              edit EMOS_TIME_STEP_H '0072'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0075
+              trigger ../../prod/wave/0075/prodwave eq complete and ( ./0072 eq complete)
+              edit EMOS_TIME_STEP_H '0075'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0078
+              trigger ../../prod/wave/0078/prodwave eq complete and ( ./0075 eq complete)
+              edit EMOS_TIME_STEP_H '0078'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0081
+              trigger ../../prod/wave/0081/prodwave eq complete and ( ./0078 eq complete)
+              edit EMOS_TIME_STEP_H '0081'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0084
+              trigger ../../prod/wave/0084/prodwave eq complete and ( ./0081 eq complete)
+              edit EMOS_TIME_STEP_H '0084'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0087
+              trigger ../../prod/wave/0087/prodwave eq complete and ( ./0084 eq complete)
+              edit EMOS_TIME_STEP_H '0087'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0090
+              trigger ../../prod/wave/0090/prodwave eq complete and ( ./0087 eq complete)
+              edit EMOS_TIME_STEP_H '0090'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0093
+              trigger ../../prod/wave/0093/prodwave eq complete and ( ./0090 eq complete)
+              edit EMOS_TIME_STEP_H '0093'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0096
+              trigger ../../prod/wave/0096/prodwave eq complete and ( ./0093 eq complete)
+              edit EMOS_TIME_STEP_H '0096'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0099
+              trigger ../../prod/wave/0099/prodwave eq complete and ( ./0096 eq complete)
+              edit EMOS_TIME_STEP_H '0099'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0102
+              trigger ../../prod/wave/0102/prodwave eq complete and ( ./0099 eq complete)
+              edit EMOS_TIME_STEP_H '0102'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0105
+              trigger ../../prod/wave/0105/prodwave eq complete and ( ./0102 eq complete)
+              edit EMOS_TIME_STEP_H '0105'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0108
+              trigger ../../prod/wave/0108/prodwave eq complete and ( ./0105 eq complete)
+              edit EMOS_TIME_STEP_H '0108'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0111
+              trigger ../../prod/wave/0111/prodwave eq complete and ( ./0108 eq complete)
+              edit EMOS_TIME_STEP_H '0111'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0114
+              trigger ../../prod/wave/0114/prodwave eq complete and ( ./0111 eq complete)
+              edit EMOS_TIME_STEP_H '0114'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0117
+              trigger ../../prod/wave/0117/prodwave eq complete and ( ./0114 eq complete)
+              edit EMOS_TIME_STEP_H '0117'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0120
+              trigger ../../prod/wave/0120/prodwave eq complete and ( ./0117 eq complete)
+              edit EMOS_TIME_STEP_H '0120'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0123
+              trigger ../../prod/wave/0123/prodwave eq complete and ( ./0120 eq complete)
+              edit EMOS_TIME_STEP_H '0123'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0126
+              trigger ../../prod/wave/0126/prodwave eq complete and ( ./0123 eq complete)
+              edit EMOS_TIME_STEP_H '0126'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0129
+              trigger ../../prod/wave/0129/prodwave eq complete and ( ./0126 eq complete)
+              edit EMOS_TIME_STEP_H '0129'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0132
+              trigger ../../prod/wave/0132/prodwave eq complete and ( ./0129 eq complete)
+              edit EMOS_TIME_STEP_H '0132'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0135
+              trigger ../../prod/wave/0135/prodwave eq complete and ( ./0132 eq complete)
+              edit EMOS_TIME_STEP_H '0135'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0138
+              trigger ../../prod/wave/0138/prodwave eq complete and ( ./0135 eq complete)
+              edit EMOS_TIME_STEP_H '0138'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0141
+              trigger ../../prod/wave/0141/prodwave eq complete and ( ./0138 eq complete)
+              edit EMOS_TIME_STEP_H '0141'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0144
+              trigger ../../prod/wave/0144/prodwave eq complete and ( ./0141 eq complete)
+              edit EMOS_TIME_STEP_H '0144'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0150
+              trigger ../../prod/wave/0150/prodwave eq complete and ( ./0144 eq complete)
+              edit EMOS_TIME_STEP_H '0150'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0156
+              trigger ../../prod/wave/0156/prodwave eq complete and ( ./0150 eq complete)
+              edit EMOS_TIME_STEP_H '0156'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0162
+              trigger ../../prod/wave/0162/prodwave eq complete and ( ./0156 eq complete)
+              edit EMOS_TIME_STEP_H '0162'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0168
+              trigger ../../prod/wave/0168/prodwave eq complete and ( ./0162 eq complete)
+              edit EMOS_TIME_STEP_H '0168'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0174
+              trigger ../../prod/wave/0174/prodwave eq complete and ( ./0168 eq complete)
+              edit EMOS_TIME_STEP_H '0174'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0180
+              trigger ../../prod/wave/0180/prodwave eq complete and ( ./0174 eq complete)
+              edit EMOS_TIME_STEP_H '0180'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0186
+              trigger ../../prod/wave/0186/prodwave eq complete and ( ./0180 eq complete)
+              edit EMOS_TIME_STEP_H '0186'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0192
+              trigger ../../prod/wave/0192/prodwave eq complete and ( ./0186 eq complete)
+              edit EMOS_TIME_STEP_H '0192'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0198
+              trigger ../../prod/wave/0198/prodwave eq complete and ( ./0192 eq complete)
+              edit EMOS_TIME_STEP_H '0198'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0204
+              trigger ../../prod/wave/0204/prodwave eq complete and ( ./0198 eq complete)
+              edit EMOS_TIME_STEP_H '0204'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0210
+              trigger ../../prod/wave/0210/prodwave eq complete and ( ./0204 eq complete)
+              edit EMOS_TIME_STEP_H '0210'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0216
+              trigger ../../prod/wave/0216/prodwave eq complete and ( ./0210 eq complete)
+              edit EMOS_TIME_STEP_H '0216'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0222
+              trigger ../../prod/wave/0222/prodwave eq complete and ( ./0216 eq complete)
+              edit EMOS_TIME_STEP_H '0222'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0228
+              trigger ../../prod/wave/0228/prodwave eq complete and ( ./0222 eq complete)
+              edit EMOS_TIME_STEP_H '0228'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0234
+              trigger ../../prod/wave/0234/prodwave eq complete and ( ./0228 eq complete)
+              edit EMOS_TIME_STEP_H '0234'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0240
+              trigger ../../prod/wave/0240/prodwave eq complete and ( ./0234 eq complete)
+              edit EMOS_TIME_STEP_H '0240'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            task check
+              trigger ./0240 eq complete
+          endfamily
+          task diss_wparam
+            late -s +00:05 -c +00:15
+            trigger ../prod/prod_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'wp'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/waef_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/enfo_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'ep'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_enfotc
+            late -s +00:05 -c +00:15
+            trigger ../prod/enfo_tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'tf'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_opertc
+            late -s +00:05 -c +00:15
+            trigger ../prod/oper_tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'tf'
+            edit EMOS_STREAM 'DA'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+        endfamily
+      endfamily
+      family legB
+        complete /emc_36r1/main/ref/12/events:240
+        edit EPSLEG '2'
+        family fc
+          edit FCMEM '2240'
+          edit FCSTACK '700'
+          edit FCMRFS '0'
+          edit PRIORITY '71'
+          edit USER_PRIORITY '71'
+          edit N_PERT_AN '10'
+          edit SSTLEN '144'
+          edit EPSINISTEP_PREVIOUS '216'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          edit TSTEP '2700'
+          edit EPSFCRES '639'
+          edit RESOL '639'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit CPUTIME '1000'
+          edit MEM '960'
+          edit THREADS '8'
+          edit NPES '8'
+          edit EPSLEG '2'
+          edit PERSST 'true'
+          edit SSTINT '1'
+          task wavfcdata
+            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+            edit EPSCOUPLE '1'
+          task getpersSST
+            trigger ../../legA/fc/inidata eq complete and ../../legA/fc/getpersSST eq complete
+            edit EPSCOUPLE '1'
+            edit EPS_INI_STREAM 'DA'
+            edit EPSFCRES '319'
+            edit RESOL '319'
+          family pf
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger ./getpersSST eq complete and ./wavfcdata eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTYPE 'pf'
+            edit EMOS_TYPE 'pf'
+            edit USER_PRIORITY '71'
+            edit PRIORITY '71'
+            edit FCNPES '32'
+            edit FCCHUNK '1'
+            edit OCTOTAL '5'
+            edit FCTOTAL '51'
+            edit FCLENGTH1 '216'
+            edit DAILY '0'
+            edit RUNVARFC '1'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSFCRES '319'
+            edit EPSWAMRESOL 'global50'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit EPSINISTEP '360'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '2'
+            edit CLASS 'od'
+            edit THREADS '2'
+            inlimit /emc_36r1/limits:pftotal
+            meter step -1 144 144
+            family 01
+              trigger ../../../legA/fc/pf/01 eq complete
+              edit EPSMEMBER '1'
+              edit MEMBER '1'
+              edit SUBFSFAMILY '/pf001'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 02
+              trigger ../../../legA/fc/pf/02 eq complete
+              edit EPSMEMBER '2'
+              edit MEMBER '2'
+              edit SUBFSFAMILY '/pf002'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 03
+              trigger ../../../legA/fc/pf/03 eq complete
+              edit EPSMEMBER '3'
+              edit MEMBER '3'
+              edit SUBFSFAMILY '/pf003'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 04
+              trigger ../../../legA/fc/pf/04 eq complete
+              edit EPSMEMBER '4'
+              edit MEMBER '4'
+              edit SUBFSFAMILY '/pf004'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 05
+              trigger ../../../legA/fc/pf/05 eq complete
+              edit EPSMEMBER '5'
+              edit MEMBER '5'
+              edit SUBFSFAMILY '/pf005'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 06
+              trigger ../../../legA/fc/pf/06 eq complete
+              edit EPSMEMBER '6'
+              edit MEMBER '6'
+              edit SUBFSFAMILY '/pf006'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 07
+              trigger ../../../legA/fc/pf/07 eq complete
+              edit EPSMEMBER '7'
+              edit MEMBER '7'
+              edit SUBFSFAMILY '/pf007'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 08
+              trigger ../../../legA/fc/pf/08 eq complete
+              edit EPSMEMBER '8'
+              edit MEMBER '8'
+              edit SUBFSFAMILY '/pf008'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 09
+              trigger ../../../legA/fc/pf/09 eq complete
+              edit EPSMEMBER '9'
+              edit MEMBER '9'
+              edit SUBFSFAMILY '/pf009'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 10
+              trigger ../../../legA/fc/pf/10 eq complete
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              edit SUBFSFAMILY '/pf010'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 11
+              trigger ../../../legA/fc/pf/11 eq complete
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              edit SUBFSFAMILY '/pf011'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 12
+              trigger ../../../legA/fc/pf/12 eq complete
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              edit SUBFSFAMILY '/pf012'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 13
+              trigger ../../../legA/fc/pf/13 eq complete
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              edit SUBFSFAMILY '/pf013'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 14
+              trigger ../../../legA/fc/pf/14 eq complete
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              edit SUBFSFAMILY '/pf014'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 15
+              trigger ../../../legA/fc/pf/15 eq complete
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              edit SUBFSFAMILY '/pf015'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 16
+              trigger ../../../legA/fc/pf/16 eq complete
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              edit SUBFSFAMILY '/pf016'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 17
+              trigger ../../../legA/fc/pf/17 eq complete
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              edit SUBFSFAMILY '/pf017'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 18
+              trigger ../../../legA/fc/pf/18 eq complete
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              edit SUBFSFAMILY '/pf018'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 19
+              trigger ../../../legA/fc/pf/19 eq complete
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              edit SUBFSFAMILY '/pf019'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 20
+              trigger ../../../legA/fc/pf/20 eq complete
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              edit SUBFSFAMILY '/pf020'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 21
+              trigger ../../../legA/fc/pf/21 eq complete
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              edit SUBFSFAMILY '/pf021'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 22
+              trigger ../../../legA/fc/pf/22 eq complete
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              edit SUBFSFAMILY '/pf022'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 23
+              trigger ../../../legA/fc/pf/23 eq complete
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              edit SUBFSFAMILY '/pf023'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 24
+              trigger ../../../legA/fc/pf/24 eq complete
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              edit SUBFSFAMILY '/pf024'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 25
+              trigger ../../../legA/fc/pf/25 eq complete
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              edit SUBFSFAMILY '/pf025'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 26
+              trigger ../../../legA/fc/pf/26 eq complete
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              edit SUBFSFAMILY '/pf026'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 27
+              trigger ../../../legA/fc/pf/27 eq complete
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              edit SUBFSFAMILY '/pf027'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 28
+              trigger ../../../legA/fc/pf/28 eq complete
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              edit SUBFSFAMILY '/pf028'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 29
+              trigger ../../../legA/fc/pf/29 eq complete
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              edit SUBFSFAMILY '/pf029'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 30
+              trigger ../../../legA/fc/pf/30 eq complete
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              edit SUBFSFAMILY '/pf030'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 31
+              trigger ../../../legA/fc/pf/31 eq complete
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              edit SUBFSFAMILY '/pf031'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 32
+              trigger ../../../legA/fc/pf/32 eq complete
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              edit SUBFSFAMILY '/pf032'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 33
+              trigger ../../../legA/fc/pf/33 eq complete
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              edit SUBFSFAMILY '/pf033'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 34
+              trigger ../../../legA/fc/pf/34 eq complete
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              edit SUBFSFAMILY '/pf034'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 35
+              trigger ../../../legA/fc/pf/35 eq complete
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              edit SUBFSFAMILY '/pf035'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 36
+              trigger ../../../legA/fc/pf/36 eq complete
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              edit SUBFSFAMILY '/pf036'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 37
+              trigger ../../../legA/fc/pf/37 eq complete
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              edit SUBFSFAMILY '/pf037'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 38
+              trigger ../../../legA/fc/pf/38 eq complete
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              edit SUBFSFAMILY '/pf038'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 39
+              trigger ../../../legA/fc/pf/39 eq complete
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              edit SUBFSFAMILY '/pf039'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 40
+              trigger ../../../legA/fc/pf/40 eq complete
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              edit SUBFSFAMILY '/pf040'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 41
+              trigger ../../../legA/fc/pf/41 eq complete
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              edit SUBFSFAMILY '/pf041'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 42
+              trigger ../../../legA/fc/pf/42 eq complete
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              edit SUBFSFAMILY '/pf042'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 43
+              trigger ../../../legA/fc/pf/43 eq complete
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              edit SUBFSFAMILY '/pf043'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 44
+              trigger ../../../legA/fc/pf/44 eq complete
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              edit SUBFSFAMILY '/pf044'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 45
+              trigger ../../../legA/fc/pf/45 eq complete
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              edit SUBFSFAMILY '/pf045'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 46
+              trigger ../../../legA/fc/pf/46 eq complete
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              edit SUBFSFAMILY '/pf046'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 47
+              trigger ../../../legA/fc/pf/47 eq complete
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              edit SUBFSFAMILY '/pf047'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 48
+              trigger ../../../legA/fc/pf/48 eq complete
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              edit SUBFSFAMILY '/pf048'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 49
+              trigger ../../../legA/fc/pf/49 eq complete
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              edit SUBFSFAMILY '/pf049'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 50
+              trigger ../../../legA/fc/pf/50 eq complete
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              edit SUBFSFAMILY '/pf050'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+          endfamily
+          family cf
+            trigger ../../legA/fc/cf eq complete and not /emc_36r1/main/ref/12/events:cpl and ./getpersSST eq complete and ./wavfcdata eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit MEMBER '0'
+            edit EPSMEMBER '0'
+            edit SUBFSFAMILY '/cf000'
+            edit EPSTYPE 'cf'
+            edit EMOS_TYPE 'cf'
+            edit USER_PRIORITY '72'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSFCRES '319'
+            edit EPSWAMRESOL 'global50'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit EPSINISTEP '360'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '2'
+            edit CLASS 'od'
+            edit SMSTRIES '1'
+            edit RUNCOUPLE '0'
+            task getvarepsdata
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '2700'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSLEG '2'
+              edit EPSINISTEP '216'
+              edit EPSFCRES '639'
+              edit EPSFCRESN '319'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '2700'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '216'
+              edit EPSFCRES '319'
+              edit NPES '24'
+              edit FCNPES '24'
+              edit THREADS '2'
+              edit CLASS 'od'
+            task modeleps
+              trigger intHtoL eq complete and getvarepsdata eq complete
+              edit FCNPES '32'
+              edit THREADS '4'
+              edit SMSTRIES '1'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSLEG '2'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '144'
+              edit EPSINISTEP_PREVIOUS '216'
+              edit FCLENGTH '144'
+              edit TSTEP '2700'
+              edit CLASS 'od'
+              meter step -1 144 144
+          endfamily
+          family reservation
+            trigger ./pf/46/intHtoL eq complete and ./pf/47/intHtoL eq complete and ./pf/48/intHtoL eq complete and ./pf/49/intHtoL eq complete and ./pf/50/intHtoL eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reset_class
+              late -s +00:02 -c +00:02
+              edit RESERVATION_DEFINITION 'default'
+              label info ""
+            task reset_cpu
+              late -s +00:02 -c +00:02
+              edit RESERVED_CPUS '0'
+              label info ""
+          endfamily
+        endfamily
+        family postproc
+          trigger ./fc/pf eq complete and ./fc/cf eq complete
+          edit STEPS '252/360/12/24 360/360/12/120'
+          inlimit /emc_36r1/limits:postproc
+          family ensms
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger ../fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            family limits
+              limit fdb 1
+              limit gen 8
+            endfamily
+            task ensms
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit ENS_MARS 'false'
+              event stage
+            family 300
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '246'
+              edit STEP2 '300'
+              edit BY '6'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 360
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '306'
+              edit STEP2 '360'
+              edit BY '6'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+          endfamily
+          family prob
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger ( /emc_36r1/main/12/legB/fc eq complete) and ( /emc_36r1/main/12/legA/postproc/prob eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            edit STEP1 '252'
+            edit STEP2 '360'
+            edit BY '12'
+            family 24
+              edit STEP1 '240'
+              edit STEP2 '360'
+              edit BY '24'
+              task t850
+              task rain
+              task ff
+            endfamily
+            family 12
+              edit STEP1 '252'
+              edit STEP2 '348'
+              edit BY '24'
+              task t850
+              task rain
+              task ff
+            endfamily
+            task 2t
+            task swh
+            task mwp
+            task 10fg
+              trigger ../dp eq complete
+            task prob_fdb
+              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
+          endfamily
+          family dp
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '246:360:6'
+            inlimit /emc_36r1/limits:dp
+            family dp
+              trigger ./cf eq complete and ./pf eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit OVERLAP '1'
+              edit STEPS '216:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                complete /emc_36r1/main/ref/12/events:cf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+                family 05
+                  edit EPSMEMBER '5'
+                  edit MEMBER '5'
+                  edit SUBFSFAMILY '/pf005'
+                  task derived_param
+                endfamily
+                family 06
+                  edit EPSMEMBER '6'
+                  edit MEMBER '6'
+                  edit SUBFSFAMILY '/pf006'
+                  task derived_param
+                endfamily
+                family 07
+                  edit EPSMEMBER '7'
+                  edit MEMBER '7'
+                  edit SUBFSFAMILY '/pf007'
+                  task derived_param
+                endfamily
+                family 08
+                  edit EPSMEMBER '8'
+                  edit MEMBER '8'
+                  edit SUBFSFAMILY '/pf008'
+                  task derived_param
+                endfamily
+                family 09
+                  edit EPSMEMBER '9'
+                  edit MEMBER '9'
+                  edit SUBFSFAMILY '/pf009'
+                  task derived_param
+                endfamily
+                family 10
+                  edit EPSMEMBER '10'
+                  edit MEMBER '10'
+                  edit SUBFSFAMILY '/pf010'
+                  task derived_param
+                endfamily
+                family 11
+                  edit EPSMEMBER '11'
+                  edit MEMBER '11'
+                  edit SUBFSFAMILY '/pf011'
+                  task derived_param
+                endfamily
+                family 12
+                  edit EPSMEMBER '12'
+                  edit MEMBER '12'
+                  edit SUBFSFAMILY '/pf012'
+                  task derived_param
+                endfamily
+                family 13
+                  edit EPSMEMBER '13'
+                  edit MEMBER '13'
+                  edit SUBFSFAMILY '/pf013'
+                  task derived_param
+                endfamily
+                family 14
+                  edit EPSMEMBER '14'
+                  edit MEMBER '14'
+                  edit SUBFSFAMILY '/pf014'
+                  task derived_param
+                endfamily
+                family 15
+                  edit EPSMEMBER '15'
+                  edit MEMBER '15'
+                  edit SUBFSFAMILY '/pf015'
+                  task derived_param
+                endfamily
+                family 16
+                  edit EPSMEMBER '16'
+                  edit MEMBER '16'
+                  edit SUBFSFAMILY '/pf016'
+                  task derived_param
+                endfamily
+                family 17
+                  edit EPSMEMBER '17'
+                  edit MEMBER '17'
+                  edit SUBFSFAMILY '/pf017'
+                  task derived_param
+                endfamily
+                family 18
+                  edit EPSMEMBER '18'
+                  edit MEMBER '18'
+                  edit SUBFSFAMILY '/pf018'
+                  task derived_param
+                endfamily
+                family 19
+                  edit EPSMEMBER '19'
+                  edit MEMBER '19'
+                  edit SUBFSFAMILY '/pf019'
+                  task derived_param
+                endfamily
+                family 20
+                  edit EPSMEMBER '20'
+                  edit MEMBER '20'
+                  edit SUBFSFAMILY '/pf020'
+                  task derived_param
+                endfamily
+                family 21
+                  edit EPSMEMBER '21'
+                  edit MEMBER '21'
+                  edit SUBFSFAMILY '/pf021'
+                  task derived_param
+                endfamily
+                family 22
+                  edit EPSMEMBER '22'
+                  edit MEMBER '22'
+                  edit SUBFSFAMILY '/pf022'
+                  task derived_param
+                endfamily
+                family 23
+                  edit EPSMEMBER '23'
+                  edit MEMBER '23'
+                  edit SUBFSFAMILY '/pf023'
+                  task derived_param
+                endfamily
+                family 24
+                  edit EPSMEMBER '24'
+                  edit MEMBER '24'
+                  edit SUBFSFAMILY '/pf024'
+                  task derived_param
+                endfamily
+                family 25
+                  edit EPSMEMBER '25'
+                  edit MEMBER '25'
+                  edit SUBFSFAMILY '/pf025'
+                  task derived_param
+                endfamily
+                family 26
+                  edit EPSMEMBER '26'
+                  edit MEMBER '26'
+                  edit SUBFSFAMILY '/pf026'
+                  task derived_param
+                endfamily
+                family 27
+                  edit EPSMEMBER '27'
+                  edit MEMBER '27'
+                  edit SUBFSFAMILY '/pf027'
+                  task derived_param
+                endfamily
+                family 28
+                  edit EPSMEMBER '28'
+                  edit MEMBER '28'
+                  edit SUBFSFAMILY '/pf028'
+                  task derived_param
+                endfamily
+                family 29
+                  edit EPSMEMBER '29'
+                  edit MEMBER '29'
+                  edit SUBFSFAMILY '/pf029'
+                  task derived_param
+                endfamily
+                family 30
+                  edit EPSMEMBER '30'
+                  edit MEMBER '30'
+                  edit SUBFSFAMILY '/pf030'
+                  task derived_param
+                endfamily
+                family 31
+                  edit EPSMEMBER '31'
+                  edit MEMBER '31'
+                  edit SUBFSFAMILY '/pf031'
+                  task derived_param
+                endfamily
+                family 32
+                  edit EPSMEMBER '32'
+                  edit MEMBER '32'
+                  edit SUBFSFAMILY '/pf032'
+                  task derived_param
+                endfamily
+                family 33
+                  edit EPSMEMBER '33'
+                  edit MEMBER '33'
+                  edit SUBFSFAMILY '/pf033'
+                  task derived_param
+                endfamily
+                family 34
+                  edit EPSMEMBER '34'
+                  edit MEMBER '34'
+                  edit SUBFSFAMILY '/pf034'
+                  task derived_param
+                endfamily
+                family 35
+                  edit EPSMEMBER '35'
+                  edit MEMBER '35'
+                  edit SUBFSFAMILY '/pf035'
+                  task derived_param
+                endfamily
+                family 36
+                  edit EPSMEMBER '36'
+                  edit MEMBER '36'
+                  edit SUBFSFAMILY '/pf036'
+                  task derived_param
+                endfamily
+                family 37
+                  edit EPSMEMBER '37'
+                  edit MEMBER '37'
+                  edit SUBFSFAMILY '/pf037'
+                  task derived_param
+                endfamily
+                family 38
+                  edit EPSMEMBER '38'
+                  edit MEMBER '38'
+                  edit SUBFSFAMILY '/pf038'
+                  task derived_param
+                endfamily
+                family 39
+                  edit EPSMEMBER '39'
+                  edit MEMBER '39'
+                  edit SUBFSFAMILY '/pf039'
+                  task derived_param
+                endfamily
+                family 40
+                  edit EPSMEMBER '40'
+                  edit MEMBER '40'
+                  edit SUBFSFAMILY '/pf040'
+                  task derived_param
+                endfamily
+                family 41
+                  edit EPSMEMBER '41'
+                  edit MEMBER '41'
+                  edit SUBFSFAMILY '/pf041'
+                  task derived_param
+                endfamily
+                family 42
+                  edit EPSMEMBER '42'
+                  edit MEMBER '42'
+                  edit SUBFSFAMILY '/pf042'
+                  task derived_param
+                endfamily
+                family 43
+                  edit EPSMEMBER '43'
+                  edit MEMBER '43'
+                  edit SUBFSFAMILY '/pf043'
+                  task derived_param
+                endfamily
+                family 44
+                  edit EPSMEMBER '44'
+                  edit MEMBER '44'
+                  edit SUBFSFAMILY '/pf044'
+                  task derived_param
+                endfamily
+                family 45
+                  edit EPSMEMBER '45'
+                  edit MEMBER '45'
+                  edit SUBFSFAMILY '/pf045'
+                  task derived_param
+                endfamily
+                family 46
+                  edit EPSMEMBER '46'
+                  edit MEMBER '46'
+                  edit SUBFSFAMILY '/pf046'
+                  task derived_param
+                endfamily
+                family 47
+                  edit EPSMEMBER '47'
+                  edit MEMBER '47'
+                  edit SUBFSFAMILY '/pf047'
+                  task derived_param
+                endfamily
+                family 48
+                  edit EPSMEMBER '48'
+                  edit MEMBER '48'
+                  edit SUBFSFAMILY '/pf048'
+                  task derived_param
+                endfamily
+                family 49
+                  edit EPSMEMBER '49'
+                  edit MEMBER '49'
+                  edit SUBFSFAMILY '/pf049'
+                  task derived_param
+                endfamily
+                family 50
+                  edit EPSMEMBER '50'
+                  edit MEMBER '50'
+                  edit SUBFSFAMILY '/pf050'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family cf
+              trigger ../../fc/cf eq complete
+              edit EMOS_TYPE 'cf'
+              task derived_param
+                edit MEMBER 'off'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/12/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                trigger ../../../fc/pf/01 eq complete
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task derived_param
+              endfamily
+              family 02
+                trigger ../../../fc/pf/02 eq complete
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task derived_param
+              endfamily
+              family 03
+                trigger ../../../fc/pf/03 eq complete
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task derived_param
+              endfamily
+              family 04
+                trigger ../../../fc/pf/04 eq complete
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task derived_param
+              endfamily
+              family 05
+                trigger ../../../fc/pf/05 eq complete
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task derived_param
+              endfamily
+              family 06
+                trigger ../../../fc/pf/06 eq complete
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task derived_param
+              endfamily
+              family 07
+                trigger ../../../fc/pf/07 eq complete
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task derived_param
+              endfamily
+              family 08
+                trigger ../../../fc/pf/08 eq complete
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task derived_param
+              endfamily
+              family 09
+                trigger ../../../fc/pf/09 eq complete
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task derived_param
+              endfamily
+              family 10
+                trigger ../../../fc/pf/10 eq complete
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task derived_param
+              endfamily
+              family 11
+                trigger ../../../fc/pf/11 eq complete
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task derived_param
+              endfamily
+              family 12
+                trigger ../../../fc/pf/12 eq complete
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task derived_param
+              endfamily
+              family 13
+                trigger ../../../fc/pf/13 eq complete
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task derived_param
+              endfamily
+              family 14
+                trigger ../../../fc/pf/14 eq complete
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task derived_param
+              endfamily
+              family 15
+                trigger ../../../fc/pf/15 eq complete
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task derived_param
+              endfamily
+              family 16
+                trigger ../../../fc/pf/16 eq complete
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task derived_param
+              endfamily
+              family 17
+                trigger ../../../fc/pf/17 eq complete
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task derived_param
+              endfamily
+              family 18
+                trigger ../../../fc/pf/18 eq complete
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task derived_param
+              endfamily
+              family 19
+                trigger ../../../fc/pf/19 eq complete
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task derived_param
+              endfamily
+              family 20
+                trigger ../../../fc/pf/20 eq complete
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task derived_param
+              endfamily
+              family 21
+                trigger ../../../fc/pf/21 eq complete
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task derived_param
+              endfamily
+              family 22
+                trigger ../../../fc/pf/22 eq complete
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task derived_param
+              endfamily
+              family 23
+                trigger ../../../fc/pf/23 eq complete
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task derived_param
+              endfamily
+              family 24
+                trigger ../../../fc/pf/24 eq complete
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task derived_param
+              endfamily
+              family 25
+                trigger ../../../fc/pf/25 eq complete
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task derived_param
+              endfamily
+              family 26
+                trigger ../../../fc/pf/26 eq complete
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task derived_param
+              endfamily
+              family 27
+                trigger ../../../fc/pf/27 eq complete
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task derived_param
+              endfamily
+              family 28
+                trigger ../../../fc/pf/28 eq complete
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task derived_param
+              endfamily
+              family 29
+                trigger ../../../fc/pf/29 eq complete
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task derived_param
+              endfamily
+              family 30
+                trigger ../../../fc/pf/30 eq complete
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task derived_param
+              endfamily
+              family 31
+                trigger ../../../fc/pf/31 eq complete
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task derived_param
+              endfamily
+              family 32
+                trigger ../../../fc/pf/32 eq complete
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task derived_param
+              endfamily
+              family 33
+                trigger ../../../fc/pf/33 eq complete
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task derived_param
+              endfamily
+              family 34
+                trigger ../../../fc/pf/34 eq complete
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task derived_param
+              endfamily
+              family 35
+                trigger ../../../fc/pf/35 eq complete
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task derived_param
+              endfamily
+              family 36
+                trigger ../../../fc/pf/36 eq complete
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task derived_param
+              endfamily
+              family 37
+                trigger ../../../fc/pf/37 eq complete
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task derived_param
+              endfamily
+              family 38
+                trigger ../../../fc/pf/38 eq complete
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task derived_param
+              endfamily
+              family 39
+                trigger ../../../fc/pf/39 eq complete
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task derived_param
+              endfamily
+              family 40
+                trigger ../../../fc/pf/40 eq complete
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task derived_param
+              endfamily
+              family 41
+                trigger ../../../fc/pf/41 eq complete
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task derived_param
+              endfamily
+              family 42
+                trigger ../../../fc/pf/42 eq complete
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task derived_param
+              endfamily
+              family 43
+                trigger ../../../fc/pf/43 eq complete
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task derived_param
+              endfamily
+              family 44
+                trigger ../../../fc/pf/44 eq complete
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task derived_param
+              endfamily
+              family 45
+                trigger ../../../fc/pf/45 eq complete
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task derived_param
+              endfamily
+              family 46
+                trigger ../../../fc/pf/46 eq complete
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task derived_param
+              endfamily
+              family 47
+                trigger ../../../fc/pf/47 eq complete
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task derived_param
+              endfamily
+              family 48
+                trigger ../../../fc/pf/48 eq complete
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task derived_param
+              endfamily
+              family 49
+                trigger ../../../fc/pf/49 eq complete
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task derived_param
+              endfamily
+              family 50
+                trigger ../../../fc/pf/50 eq complete
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task derived_param
+              endfamily
+            endfamily
+          endfamily
+          family extra
+            trigger ./dp eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '246:360:6'
+            inlimit /emc_36r1/limits:extra
+            family cf
+              edit EMOS_TYPE 'cf'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '360'
+                edit FCLENGTH0 '240'
+                edit RUNVARFC '1'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/12/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 05
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 06
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 07
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 08
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 09
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 10
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 11
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 12
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 13
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 14
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 15
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 16
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 17
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 18
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 19
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 20
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 21
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 22
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 23
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 24
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 25
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 26
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 27
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 28
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 29
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 30
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 31
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 32
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 33
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 34
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 35
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 36
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 37
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 38
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 39
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 40
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 41
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 42
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 43
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 44
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 45
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 46
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 47
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 48
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 49
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 50
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+            endfamily
+          endfamily
+          family calibrate
+            complete /emc_36r1/main/ref/12/events:cf
+            trigger /emc_36r1/main/12/ref/an eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
+            family onws
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              inlimit /limits:linux_cluster
+              task feedupcal
+              task upcal
+                trigger feedupcal eq complete
+              task revertupcal
+            endfamily
+          endfamily
+          family efi
+            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
+            trigger /emc_36r1/main/12/legB/postproc/dp eq complete
+            edit HC_VERSION '0046'
+            edit HC_EXPVER '0046'
+            edit REF_VERSION '0046'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            edit NC_DAYS '31'
+            edit EPSLEG '2'
+            inlimit /emc_36r1/limits:efi
+            task stage
+              edit NC_DAYS '31'
+            family 228_324
+              trigger ./stage eq complete
+              edit ACC '96'
+              edit EFI_STEP1 '228'
+              edit EFI_STEP2 '324'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 168_336
+              trigger ./stage eq complete
+              edit ACC '168'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '336'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 000_024
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 024_048
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 048_072
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 072_096
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 096_120
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 120_144
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 108_156
+              trigger ./stage eq complete
+              edit ACC '48'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '156'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 156_228
+              trigger ./stage eq complete
+              edit ACC '72'
+              edit EFI_STEP1 '156'
+              edit EFI_STEP2 '228'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 000_168
+              trigger ./stage eq complete
+              edit ACC '168'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 012_036
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 036_060
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 060_084
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 084_108
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 108_132
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+          endfamily
+          task efi2fdb
+            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
+            trigger ./efi eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            inlimit /emc_36r1/main/ref:mutex
+            event none
+        endfamily
+        family prod
+          edit MEM '3000'
+          edit ACCOUNT 'oeenfopg'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'cp'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '90'
+          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
+          edit SMSURL 'sub=fixed/'
+          inlimit /limits:prod
+          family eps
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            inlimit /emc_36r1/limits:prodeps
+            family 0246
+              edit EMOS_TIME_STEP_H '0246'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0252
+              edit EMOS_TIME_STEP_H '0252'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0258
+              edit EMOS_TIME_STEP_H '0258'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0264
+              edit EMOS_TIME_STEP_H '0264'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0270
+              edit EMOS_TIME_STEP_H '0270'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0276
+              edit EMOS_TIME_STEP_H '0276'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0282
+              edit EMOS_TIME_STEP_H '0282'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0288
+              edit EMOS_TIME_STEP_H '0288'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0294
+              edit EMOS_TIME_STEP_H '0294'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0300
+              edit EMOS_TIME_STEP_H '0300'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0306
+              edit EMOS_TIME_STEP_H '0306'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0312
+              edit EMOS_TIME_STEP_H '0312'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0318
+              edit EMOS_TIME_STEP_H '0318'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0324
+              edit EMOS_TIME_STEP_H '0324'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0330
+              edit EMOS_TIME_STEP_H '0330'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0336
+              edit EMOS_TIME_STEP_H '0336'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0342
+              edit EMOS_TIME_STEP_H '0342'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0348
+              edit EMOS_TIME_STEP_H '0348'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0354
+              edit EMOS_TIME_STEP_H '0354'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0360
+              edit EMOS_TIME_STEP_H '0360'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+          endfamily
+          family wave
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            edit PGNPES '2'
+            edit URL 'GWAEF/12'
+            inlimit /emc_36r1/limits:prodwave
+            family 0246
+              edit EMOS_TIME_STEP_H '0246'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0252
+              edit EMOS_TIME_STEP_H '0252'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0258
+              edit EMOS_TIME_STEP_H '0258'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0264
+              edit EMOS_TIME_STEP_H '0264'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0270
+              edit EMOS_TIME_STEP_H '0270'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0276
+              edit EMOS_TIME_STEP_H '0276'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0282
+              edit EMOS_TIME_STEP_H '0282'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0288
+              edit EMOS_TIME_STEP_H '0288'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0294
+              edit EMOS_TIME_STEP_H '0294'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0300
+              edit EMOS_TIME_STEP_H '0300'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0306
+              edit EMOS_TIME_STEP_H '0306'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0312
+              edit EMOS_TIME_STEP_H '0312'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0318
+              edit EMOS_TIME_STEP_H '0318'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0324
+              edit EMOS_TIME_STEP_H '0324'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0330
+              edit EMOS_TIME_STEP_H '0330'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0336
+              edit EMOS_TIME_STEP_H '0336'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0342
+              edit EMOS_TIME_STEP_H '0342'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0348
+              edit EMOS_TIME_STEP_H '0348'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0354
+              edit EMOS_TIME_STEP_H '0354'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0360
+              edit EMOS_TIME_STEP_H '0360'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+          endfamily
+          task prod_wparam
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and ../../legA/prod/prod_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TYPE 'wp'
+            edit EMOS_TIME_STEP_H '0360'
+            edit PGNPES '52'
+          task enfo_postproc
+            late -s +00:05 -c +00:15
+            trigger ../postproc/prob eq complete and ../postproc/ensms eq complete and ( ../../legA/prod/getreq/eps eq complete)
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'ep'
+            edit EMOS_TIME_STEP_H '0360'
+            edit PGNPES '21'
+          task waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TIME_STEP_H '0360'
+            edit PGNPES '1'
+        endfamily
+        family prod2diss
+          edit USER_PRIORITY '90'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'ef'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+          edit SMSURL 'GENFO/12'
+          family eps
+            family 0246
+              edit EMOS_TIME_STEP_H '0246'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0246/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../../../../legA/prod2diss/eps//0240/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0252
+              edit EMOS_TIME_STEP_H '0252'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0252/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0246/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0258
+              edit EMOS_TIME_STEP_H '0258'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0258/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0252/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0264
+              edit EMOS_TIME_STEP_H '0264'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0264/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0258/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0270
+              edit EMOS_TIME_STEP_H '0270'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0270/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0264/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0276
+              edit EMOS_TIME_STEP_H '0276'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0276/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0270/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0282
+              edit EMOS_TIME_STEP_H '0282'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0282/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0276/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0288
+              edit EMOS_TIME_STEP_H '0288'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0288/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0282/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0294
+              edit EMOS_TIME_STEP_H '0294'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0294/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0288/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0300
+              edit EMOS_TIME_STEP_H '0300'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0300/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0294/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0306
+              edit EMOS_TIME_STEP_H '0306'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0306/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0300/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0312
+              edit EMOS_TIME_STEP_H '0312'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0312/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0306/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0318
+              edit EMOS_TIME_STEP_H '0318'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0318/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0312/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0324
+              edit EMOS_TIME_STEP_H '0324'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0324/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0318/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0330
+              edit EMOS_TIME_STEP_H '0330'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0330/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0324/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0336
+              edit EMOS_TIME_STEP_H '0336'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0336/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0330/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0342
+              edit EMOS_TIME_STEP_H '0342'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0342/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0336/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0348
+              edit EMOS_TIME_STEP_H '0348'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0348/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0342/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0354
+              edit EMOS_TIME_STEP_H '0354'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0354/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0348/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0360
+              edit EMOS_TIME_STEP_H '0360'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0360/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0354/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            task check
+              trigger ./0360 eq complete
+          endfamily
+          family wave
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TYPE 'we'
+            edit SMSURL 'GWAEF/12'
+            family 0246
+              trigger ../../prod/wave/0246/prodwave eq complete and ( ../../../legA/prod2diss/wave/0240 eq complete)
+              edit EMOS_TIME_STEP_H '0246'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0252
+              trigger ../../prod/wave/0252/prodwave eq complete and ( ./0246 eq complete)
+              edit EMOS_TIME_STEP_H '0252'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0258
+              trigger ../../prod/wave/0258/prodwave eq complete and ( ./0252 eq complete)
+              edit EMOS_TIME_STEP_H '0258'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0264
+              trigger ../../prod/wave/0264/prodwave eq complete and ( ./0258 eq complete)
+              edit EMOS_TIME_STEP_H '0264'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0270
+              trigger ../../prod/wave/0270/prodwave eq complete and ( ./0264 eq complete)
+              edit EMOS_TIME_STEP_H '0270'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0276
+              trigger ../../prod/wave/0276/prodwave eq complete and ( ./0270 eq complete)
+              edit EMOS_TIME_STEP_H '0276'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0282
+              trigger ../../prod/wave/0282/prodwave eq complete and ( ./0276 eq complete)
+              edit EMOS_TIME_STEP_H '0282'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0288
+              trigger ../../prod/wave/0288/prodwave eq complete and ( ./0282 eq complete)
+              edit EMOS_TIME_STEP_H '0288'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0294
+              trigger ../../prod/wave/0294/prodwave eq complete and ( ./0288 eq complete)
+              edit EMOS_TIME_STEP_H '0294'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0300
+              trigger ../../prod/wave/0300/prodwave eq complete and ( ./0294 eq complete)
+              edit EMOS_TIME_STEP_H '0300'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0306
+              trigger ../../prod/wave/0306/prodwave eq complete and ( ./0300 eq complete)
+              edit EMOS_TIME_STEP_H '0306'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0312
+              trigger ../../prod/wave/0312/prodwave eq complete and ( ./0306 eq complete)
+              edit EMOS_TIME_STEP_H '0312'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0318
+              trigger ../../prod/wave/0318/prodwave eq complete and ( ./0312 eq complete)
+              edit EMOS_TIME_STEP_H '0318'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0324
+              trigger ../../prod/wave/0324/prodwave eq complete and ( ./0318 eq complete)
+              edit EMOS_TIME_STEP_H '0324'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0330
+              trigger ../../prod/wave/0330/prodwave eq complete and ( ./0324 eq complete)
+              edit EMOS_TIME_STEP_H '0330'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0336
+              trigger ../../prod/wave/0336/prodwave eq complete and ( ./0330 eq complete)
+              edit EMOS_TIME_STEP_H '0336'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0342
+              trigger ../../prod/wave/0342/prodwave eq complete and ( ./0336 eq complete)
+              edit EMOS_TIME_STEP_H '0342'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0348
+              trigger ../../prod/wave/0348/prodwave eq complete and ( ./0342 eq complete)
+              edit EMOS_TIME_STEP_H '0348'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0354
+              trigger ../../prod/wave/0354/prodwave eq complete and ( ./0348 eq complete)
+              edit EMOS_TIME_STEP_H '0354'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0360
+              trigger ../../prod/wave/0360/prodwave eq complete and ( ./0354 eq complete)
+              edit EMOS_TIME_STEP_H '0360'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            task check
+              trigger ./0360 eq complete
+          endfamily
+          task diss_wparam
+            late -s +00:05 -c +00:15
+            trigger ../prod/prod_wparam eq complete and ../../legA/prod2diss/diss_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TIME_STEP_H '0360'
+            edit EMOS_TYPE 'wp'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/waef_postproc eq complete and ../../legA/prod2diss/diss_waef_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0360'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/enfo_postproc eq complete and ../../legA/prod2diss/diss_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0360'
+            edit EMOS_TYPE 'ep'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+        endfamily
+      endfamily
+    endfamily
+    family 00
+      trigger ( ./make eq complete) and ( ./inistage eq complete)
+      edit DELTA_DAY '1'
+      edit EMOS_BASE '00'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+      family ref
+        trigger ../make eq complete and ( /emc_36r1/main:YMD le /e_36r1/main:YMD)
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit QUEUE 'emos-exp'
+        limit mutex 1
+        task an
+          trigger /e_36r1/main/00/an eq complete
+        task anfc
+          complete ( ( /e_36r1/main/00/an/surf_anal/slwet eq complete and ( /e_36r1/main/00/an/4dvar/ifstraj:finalwave or /e_36r1/main/00/an/4dvar eq complete)) or /e_36r1/main/00/an eq complete)
+          trigger 0 eq 1
+        task model_active
+          trigger /e_36r1/main/00/fc/model eq active or /e_36r1/main/00/fc/model eq complete
+        task an_active
+          trigger /e_36r1/main/00/an/4dvar/uptraj_0 eq active or /e_36r1/main/00/an/4dvar/uptraj_0 eq complete
+        task model
+          trigger /e_36r1/main/00/fc/model eq complete
+        family oceini
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+          inlimit /emc_36r1/limits:marsret
+          time 23:45
+          task dummy
+        endfamily
+        task dc
+          trigger /e_36r1/main/12dc/fc/model:step ge 12 or /e_36r1/main/12dc/fc/model eq complete
+        task obs
+          trigger /e_36r1/main/00/obs/get/get_stor eq complete
+      endfamily
+      family sv
+        trigger ./ref/dc eq complete and ./ref/an_active eq complete
+        edit EVOLVE 'no'
+        edit FASTEX 'no'
+        edit EPSTYPE 'sv'
+        edit FCMEM '2000'
+        edit FCSTACK '400'
+        edit FCMRFS '100'
+        edit FCLENGTH '48'
+        edit EPSSVTCSUB '1'
+        edit EPSSVOP '1'
+        edit NPES '16'
+        edit EPSSVTSTEP '900'
+        task getini
+          edit LINIENDA '0'
+          edit INIDATEENDA '0'
+          edit EPSCOUPLE '0'
+          edit N_PERT_AN '10'
+          edit EPSCOUPL_A '0'
+          edit EPSCOUPL_B '0'
+          edit EPSCOUPL_C '0'
+        task inidata_sv
+          trigger getini eq complete
+          edit THREADS '8'
+        task targets
+          late -s +00:03 -c +00:10
+          trigger ../ref/obs eq complete
+          edit EPSTCBB '1'
+          label da_info ""
+          label dcda_info ""
+          event sv
+        task svsh
+          trigger inidata_sv eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit THREADS '8'
+          edit USER_PRIORITY '73'
+        task svnh
+          trigger inidata_sv eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit THREADS '8'
+          edit USER_PRIORITY '74'
+        task subspace
+          trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+        task sv1
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '1'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+          edit USER_PRIORITY '72'
+        task sv2
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '2'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+          edit USER_PRIORITY '71'
+        task sv3
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '3'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task sv4
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '4'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task sv5
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '5'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task sv6
+          trigger ( targets eq complete or targets:sv) and subspace eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          edit MEMBER '6'
+          edit EPSTROP '1'
+          edit EPSSVDIAB 'true'
+          edit THREADS '8'
+        task getsvevo
+          event ecfs
+        task getsvs
+          trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit EPSTROP '1'
+        task sv_value
+          trigger getsvs eq complete
+          inlimit /emc_36r1/main/ref:mutex
+        task svnhevo
+          trigger svnh eq complete and ../legA/fc eq complete
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit STACK '350'
+          edit HEMISPHERE 'n'
+          edit EVOLVE 'yes'
+          edit ANNPES '8'
+          edit CPUTIME '120000'
+        task svshevo
+          trigger svsh eq complete and ../legA/fc eq complete
+          edit NPES '24'
+          edit THREADS '8'
+          edit MEM '1300'
+          edit MRF '10'
+          edit STACK '450'
+          edit EVOLVE 'yes'
+          edit ANNPES '8'
+          edit CPUTIME '120000'
+        task clean
+          trigger ../legA/fc eq complete and svnhevo eq complete and svshevo eq complete
+        task dcopy
+          trigger clean eq complete
+          edit SMSFILES '/home/ma/emos/def/o/system'
+      endfamily
+      family legA
+        edit EPSLEG '1'
+        family fc
+          trigger /emc_36r1/main/00/ref/anfc eq complete
+          edit FCMEM '2240'
+          edit FCSTACK '700'
+          edit FCMRFS '0'
+          edit PRIORITY '72'
+          edit USER_PRIORITY '72'
+          edit N_PERT_AN '10'
+          edit SSTLEN '240'
+          edit EPSINISTEP_PREVIOUS '0'
+          edit EPSWAMNFRE '30'
+          edit EPSWAMNANG '24'
+          edit TSTEP '1200'
+          edit EPSFCRES '639'
+          edit RESOL '639'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit CPUTIME '1000'
+          edit MEM '960'
+          edit THREADS '8'
+          edit NPES '8'
+          edit EPSLEG '1'
+          edit PERSST 'true'
+          edit SSTINT '1'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata
+            trigger getini eq complete
+            edit THREADS '8'
+          task getae
+            event 1 
+          task rot
+            trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+            edit EPSTROP '1'
+          family pert_ic
+            trigger rot eq complete and inidata eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+            inlimit /emc_36r1/limits:pertic
+            family 00
+              task pertinic
+                edit MEMBER '0'
+            endfamily
+            family 01
+              task pertinic
+                edit MEMBER '1'
+            endfamily
+            family 02
+              task pertinic
+                edit MEMBER '2'
+            endfamily
+            family 03
+              task pertinic
+                edit MEMBER '3'
+            endfamily
+            family 04
+              task pertinic
+                edit MEMBER '4'
+            endfamily
+            family 05
+              task pertinic
+                edit MEMBER '5'
+            endfamily
+            family 06
+              task pertinic
+                edit MEMBER '6'
+            endfamily
+            family 07
+              task pertinic
+                edit MEMBER '7'
+            endfamily
+            family 08
+              task pertinic
+                edit MEMBER '8'
+            endfamily
+            family 09
+              task pertinic
+                edit MEMBER '9'
+            endfamily
+            family 10
+              task pertinic
+                edit MEMBER '10'
+            endfamily
+            family 11
+              task pertinic
+                edit MEMBER '11'
+            endfamily
+            family 12
+              task pertinic
+                edit MEMBER '12'
+            endfamily
+            family 13
+              task pertinic
+                edit MEMBER '13'
+            endfamily
+            family 14
+              task pertinic
+                edit MEMBER '14'
+            endfamily
+            family 15
+              task pertinic
+                edit MEMBER '15'
+            endfamily
+            family 16
+              task pertinic
+                edit MEMBER '16'
+            endfamily
+            family 17
+              task pertinic
+                edit MEMBER '17'
+            endfamily
+            family 18
+              task pertinic
+                edit MEMBER '18'
+            endfamily
+            family 19
+              task pertinic
+                edit MEMBER '19'
+            endfamily
+            family 20
+              task pertinic
+                edit MEMBER '20'
+            endfamily
+            family 21
+              task pertinic
+                edit MEMBER '21'
+            endfamily
+            family 22
+              task pertinic
+                edit MEMBER '22'
+            endfamily
+            family 23
+              task pertinic
+                edit MEMBER '23'
+            endfamily
+            family 24
+              task pertinic
+                edit MEMBER '24'
+            endfamily
+            family 25
+              task pertinic
+                edit MEMBER '25'
+            endfamily
+            family 26
+              task pertinic
+                edit MEMBER '26'
+            endfamily
+            family 27
+              task pertinic
+                edit MEMBER '27'
+            endfamily
+            family 28
+              task pertinic
+                edit MEMBER '28'
+            endfamily
+            family 29
+              task pertinic
+                edit MEMBER '29'
+            endfamily
+            family 30
+              task pertinic
+                edit MEMBER '30'
+            endfamily
+            family 31
+              task pertinic
+                edit MEMBER '31'
+            endfamily
+            family 32
+              task pertinic
+                edit MEMBER '32'
+            endfamily
+            family 33
+              task pertinic
+                edit MEMBER '33'
+            endfamily
+            family 34
+              task pertinic
+                edit MEMBER '34'
+            endfamily
+            family 35
+              task pertinic
+                edit MEMBER '35'
+            endfamily
+            family 36
+              task pertinic
+                edit MEMBER '36'
+            endfamily
+            family 37
+              task pertinic
+                edit MEMBER '37'
+            endfamily
+            family 38
+              task pertinic
+                edit MEMBER '38'
+            endfamily
+            family 39
+              task pertinic
+                edit MEMBER '39'
+            endfamily
+            family 40
+              task pertinic
+                edit MEMBER '40'
+            endfamily
+            family 41
+              task pertinic
+                edit MEMBER '41'
+            endfamily
+            family 42
+              task pertinic
+                edit MEMBER '42'
+            endfamily
+            family 43
+              task pertinic
+                edit MEMBER '43'
+            endfamily
+            family 44
+              task pertinic
+                edit MEMBER '44'
+            endfamily
+            family 45
+              task pertinic
+                edit MEMBER '45'
+            endfamily
+            family 46
+              task pertinic
+                edit MEMBER '46'
+            endfamily
+            family 47
+              task pertinic
+                edit MEMBER '47'
+            endfamily
+            family 48
+              task pertinic
+                edit MEMBER '48'
+            endfamily
+            family 49
+              task pertinic
+                edit MEMBER '49'
+            endfamily
+            family 50
+              task pertinic
+                edit MEMBER '50'
+            endfamily
+          endfamily
+          task cp_pert
+            trigger pert_ic eq complete
+            event 1 
+          task wavini
+            trigger /emc_36r1/main/00/ref/an eq complete
+            edit FSFAMILY 'mc'
+          family cv
+            trigger ./pert_ic/00 eq complete and ./inidata eq complete and ./wavini eq complete and /emc_36r1/main/00/ref/model_active eq complete
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit EPSFCRES '639'
+            edit TSTEP '1200'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit CLASS 'od'
+            edit PERSST 'no'
+            edit EPSTYPE 'cv'
+            edit EMOS_TYPE 'cv'
+            edit EPSNLEGS '1'
+            edit EPSLEG '1'
+            edit EPSINISTEP '360'
+            edit FCLENGTH '360'
+            edit USER_PRIORITY '73'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            inlimit /emc_36r1/limits:pftotal
+            family control_1
+              edit MEMBER '1'
+              edit EPSMEMBER '1'
+              edit SUBFSFAMILY '/cv001'
+              task getiniLeg
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit FCNPES '32'
+                edit THREADS '4'
+                meter step -1 360 360
+              task derived_param
+                trigger modeleps eq complete
+                edit STEPS '0:144:3 144:360:6'
+            endfamily
+            family control_2
+              edit MEMBER '2'
+              edit EPSMEMBER '2'
+              edit SUBFSFAMILY '/cv002'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              task getiniLeg
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task intHtoL
+                trigger getiniLeg eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '1200'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                meter step -1 360 360
+              task derived_param
+                trigger modeleps eq complete
+                edit STEPS '0:144:3 144:360:6'
+            endfamily
+          endfamily
+          task wavfcdata
+            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+            edit EPSCOUPLE '1'
+          task getpersSST
+            trigger ./inidata eq complete
+            edit EPSCOUPLE '1'
+            edit EPS_INI_STREAM 'DA'
+            edit EPSFCRES '639'
+          family pf
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete and ../../ref/model_active eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTYPE 'pf'
+            edit EMOS_TYPE 'pf'
+            edit USER_PRIORITY '72'
+            edit PRIORITY '72'
+            edit FCNPES '64'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit EPSFCRES '639'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit EPSINISTEP '216'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '1'
+            edit CLASS 'od'
+            inlimit /emc_36r1/limits:pftotal
+            meter step -1 240 240
+            family 01
+              edit EPSMEMBER '1'
+              edit MEMBER '1'
+              edit SUBFSFAMILY '/pf001'
+              task getiniLeg
+                trigger ../../pert_ic/01/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 02
+              edit EPSMEMBER '2'
+              edit MEMBER '2'
+              edit SUBFSFAMILY '/pf002'
+              task getiniLeg
+                trigger ../../pert_ic/02/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 03
+              edit EPSMEMBER '3'
+              edit MEMBER '3'
+              edit SUBFSFAMILY '/pf003'
+              task getiniLeg
+                trigger ../../pert_ic/03/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 04
+              edit EPSMEMBER '4'
+              edit MEMBER '4'
+              edit SUBFSFAMILY '/pf004'
+              task getiniLeg
+                trigger ../../pert_ic/04/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 05
+              edit EPSMEMBER '5'
+              edit MEMBER '5'
+              edit SUBFSFAMILY '/pf005'
+              task getiniLeg
+                trigger ../../pert_ic/05/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 06
+              edit EPSMEMBER '6'
+              edit MEMBER '6'
+              edit SUBFSFAMILY '/pf006'
+              task getiniLeg
+                trigger ../../pert_ic/06/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 07
+              edit EPSMEMBER '7'
+              edit MEMBER '7'
+              edit SUBFSFAMILY '/pf007'
+              task getiniLeg
+                trigger ../../pert_ic/07/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 08
+              edit EPSMEMBER '8'
+              edit MEMBER '8'
+              edit SUBFSFAMILY '/pf008'
+              task getiniLeg
+                trigger ../../pert_ic/08/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 09
+              edit EPSMEMBER '9'
+              edit MEMBER '9'
+              edit SUBFSFAMILY '/pf009'
+              task getiniLeg
+                trigger ../../pert_ic/09/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 10
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              edit SUBFSFAMILY '/pf010'
+              task getiniLeg
+                trigger ../../pert_ic/10/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 11
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              edit SUBFSFAMILY '/pf011'
+              task getiniLeg
+                trigger ../../pert_ic/11/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 12
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              edit SUBFSFAMILY '/pf012'
+              task getiniLeg
+                trigger ../../pert_ic/12/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 13
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              edit SUBFSFAMILY '/pf013'
+              task getiniLeg
+                trigger ../../pert_ic/13/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 14
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              edit SUBFSFAMILY '/pf014'
+              task getiniLeg
+                trigger ../../pert_ic/14/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 15
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              edit SUBFSFAMILY '/pf015'
+              task getiniLeg
+                trigger ../../pert_ic/15/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 16
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              edit SUBFSFAMILY '/pf016'
+              task getiniLeg
+                trigger ../../pert_ic/16/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 17
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              edit SUBFSFAMILY '/pf017'
+              task getiniLeg
+                trigger ../../pert_ic/17/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 18
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              edit SUBFSFAMILY '/pf018'
+              task getiniLeg
+                trigger ../../pert_ic/18/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 19
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              edit SUBFSFAMILY '/pf019'
+              task getiniLeg
+                trigger ../../pert_ic/19/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 20
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              edit SUBFSFAMILY '/pf020'
+              task getiniLeg
+                trigger ../../pert_ic/20/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 21
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              edit SUBFSFAMILY '/pf021'
+              task getiniLeg
+                trigger ../../pert_ic/21/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 22
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              edit SUBFSFAMILY '/pf022'
+              task getiniLeg
+                trigger ../../pert_ic/22/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 23
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              edit SUBFSFAMILY '/pf023'
+              task getiniLeg
+                trigger ../../pert_ic/23/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 24
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              edit SUBFSFAMILY '/pf024'
+              task getiniLeg
+                trigger ../../pert_ic/24/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 25
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              edit SUBFSFAMILY '/pf025'
+              task getiniLeg
+                trigger ../../pert_ic/25/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 26
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              edit SUBFSFAMILY '/pf026'
+              task getiniLeg
+                trigger ../../pert_ic/26/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 27
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              edit SUBFSFAMILY '/pf027'
+              task getiniLeg
+                trigger ../../pert_ic/27/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 28
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              edit SUBFSFAMILY '/pf028'
+              task getiniLeg
+                trigger ../../pert_ic/28/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 29
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              edit SUBFSFAMILY '/pf029'
+              task getiniLeg
+                trigger ../../pert_ic/29/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 30
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              edit SUBFSFAMILY '/pf030'
+              task getiniLeg
+                trigger ../../pert_ic/30/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 31
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              edit SUBFSFAMILY '/pf031'
+              task getiniLeg
+                trigger ../../pert_ic/31/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 32
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              edit SUBFSFAMILY '/pf032'
+              task getiniLeg
+                trigger ../../pert_ic/32/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 33
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              edit SUBFSFAMILY '/pf033'
+              task getiniLeg
+                trigger ../../pert_ic/33/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 34
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              edit SUBFSFAMILY '/pf034'
+              task getiniLeg
+                trigger ../../pert_ic/34/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 35
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              edit SUBFSFAMILY '/pf035'
+              task getiniLeg
+                trigger ../../pert_ic/35/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 36
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              edit SUBFSFAMILY '/pf036'
+              task getiniLeg
+                trigger ../../pert_ic/36/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 37
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              edit SUBFSFAMILY '/pf037'
+              task getiniLeg
+                trigger ../../pert_ic/37/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 38
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              edit SUBFSFAMILY '/pf038'
+              task getiniLeg
+                trigger ../../pert_ic/38/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 39
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              edit SUBFSFAMILY '/pf039'
+              task getiniLeg
+                trigger ../../pert_ic/39/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 40
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              edit SUBFSFAMILY '/pf040'
+              task getiniLeg
+                trigger ../../pert_ic/40/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 41
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              edit SUBFSFAMILY '/pf041'
+              task getiniLeg
+                trigger ../../pert_ic/41/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 42
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              edit SUBFSFAMILY '/pf042'
+              task getiniLeg
+                trigger ../../pert_ic/42/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 43
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              edit SUBFSFAMILY '/pf043'
+              task getiniLeg
+                trigger ../../pert_ic/43/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 44
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              edit SUBFSFAMILY '/pf044'
+              task getiniLeg
+                trigger ../../pert_ic/44/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 45
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              edit SUBFSFAMILY '/pf045'
+              task getiniLeg
+                trigger ../../pert_ic/45/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 46
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              edit SUBFSFAMILY '/pf046'
+              task getiniLeg
+                trigger ../../pert_ic/46/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 47
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              edit SUBFSFAMILY '/pf047'
+              task getiniLeg
+                trigger ../../pert_ic/47/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 48
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              edit SUBFSFAMILY '/pf048'
+              task getiniLeg
+                trigger ../../pert_ic/48/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 49
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              edit SUBFSFAMILY '/pf049'
+              task getiniLeg
+                trigger ../../pert_ic/49/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+            family 50
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              edit SUBFSFAMILY '/pf050'
+              task getiniLeg
+                trigger ../../pert_ic/50/pertinic eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:modelepsA
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family cf
+            trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete and /emc_36r1/main/00/ref/model_active eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit MEMBER '0'
+            edit EPSMEMBER '0'
+            edit SUBFSFAMILY '/cf000'
+            edit EPSTYPE 'cf'
+            edit EMOS_TYPE 'cf'
+            edit USER_PRIORITY '73'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMRESOL 'global50'
+            edit EPSFCRES '639'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit EPSINISTEP '216'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '1'
+            edit CLASS 'od'
+            task getiniLeg
+              trigger ../inidata eq complete and ../wavini eq complete
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task modeleps
+              trigger getiniLeg eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSLEG '1'
+              edit EPSFCRES '639'
+              edit EPSINISTEP '216'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit CLASS 'od'
+              edit FCNPES '32'
+              edit THREADS '4'
+              meter step -1 240 240
+          endfamily
+          family reservation1
+            trigger ./pf/01/modeleps eq active or ./pf/01/modeleps eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reserve_cpu
+              late -s +00:02 -c +00:02
+              edit RESERVED_CPUS '10880'
+              edit RESERVE_FOR '40'
+              label info ""
+            task rm_res
+              late -s +00:02 -c +00:02
+              trigger ./reserve_cpu eq complete
+              edit RESERVATION_LABEL 'emos00'
+              label info ""
+          endfamily
+          family reservation2
+            trigger ( ./pf/46/modeleps eq active or ./pf/46/modeleps eq complete) and ( ./pf/47/modeleps eq active or ./pf/47/modeleps eq complete) and ( ./pf/48/modeleps eq active or ./pf/48/modeleps eq complete) and ( ./pf/49/modeleps eq active or ./pf/49/modeleps eq complete) and ( ./pf/50/modeleps eq active or ./pf/50/modeleps eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reset_class
+              late -s +00:02 -c +00:02
+              edit RESERVATION_DEFINITION 'default'
+              label info ""
+            task ms_cpu
+              late -s +00:02 -c +00:02
+              edit MS_CPUS '$((64*80))'
+              label info ""
+            task reserve_cpu
+              late -s +00:02 -c +00:02
+              complete /emc_36r1/main/ref/00/events:768
+              edit RESERVED_CPUS '6400'
+              edit RESERVE_FOR '40'
+              label info ""
+            task reserve_cpu1
+              late -s +00:02 -c +00:02
+              complete ( /emc_36r1/main/ref/00/events eq complete) and ( not /emc_36r1/main/ref/00/events:768)
+              edit RESERVED_CPUS '6400'
+              edit RESERVE_FOR '100'
+              label info ""
+          endfamily
+          family reservation3
+            trigger ( ./pf eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reserve_cpu
+              late -s +00:02 -c +00:02
+              complete /emc_36r1/main/ref/00/events:768
+              edit RESERVED_CPUS '3200'
+              edit RESERVE_FOR '30'
+              label info ""
+            task reserve_cpu1
+              late -s +00:02 -c +00:02
+              complete ( /emc_36r1/main/ref/00/events eq complete) and ( not /emc_36r1/main/ref/00/events:768)
+              edit RESERVED_CPUS '3200'
+              edit RESERVE_FOR '80'
+              label info ""
+          endfamily
+        endfamily
+        family fax
+          trigger /emc_36r1/main/00/ref/an eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+          task ena4
+            trigger ../postproc/clusters eq complete and ../postproc/ensms eq complete
+            edit ANALYSIS 'NO'
+          task plume
+            trigger ../postproc/prob eq complete and /emc_36r1/main/00/ref/model eq complete
+            edit ANALYSIS 'YES'
+          task fax
+            trigger plume eq complete and ena4 eq complete
+            edit SMSTRIES '1'
+          task manfax
+            trigger plume eq complete and ena4 eq complete
+            edit SMSTRIES '1'
+            edit COUNTRY ''
+          task faxcheck
+            trigger fax eq complete
+          task faxcheck2
+            trigger fax eq complete
+            time 08:00
+        endfamily
+        family postproc
+          trigger ./fc ne queued
+          edit STEPS '24/240/12/24 168/168/12/48 240/240/12/72 240/240/12/120'
+          inlimit /emc_36r1/limits:postproc
+          family prepare
+            complete /emc_36r1/main/ref/00/events:cf
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            family all
+              complete ../../fc eq complete and ./query eq active
+              trigger ../../fc eq complete and ( ./query eq queued or ./query eq complete)
+              edit KIND 'all'
+              edit STEP '-1'
+              family t850
+                edit PARAM 'T'
+                edit LEVEL '850'
+                task pp_prep
+              endfamily
+              family t500
+                edit PARAM 'T'
+                edit LEVEL '500'
+                task pp_prep
+              endfamily
+              family z1000
+                edit PARAM 'Z'
+                edit LEVEL '1000'
+                task pp_prep
+              endfamily
+              family z500
+                edit PARAM 'Z'
+                edit LEVEL '500'
+                task pp_prep
+              endfamily
+            endfamily
+            family query
+              complete ../../fc eq complete and ../../fc/pf:step le 0
+              trigger ( ( ../../fc/pf:step ge 0) and ( ../../fc/cf/modeleps:step ge 0)) or ( ../../fc/pf eq complete and ../../fc/cf eq complete)
+              edit KIND 'query'
+              family t850
+                edit PARAM 'T'
+                edit LEVEL '850'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+              family t500
+                edit PARAM 'T'
+                edit LEVEL '500'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+              family z1000
+                edit PARAM 'Z'
+                edit LEVEL '1000'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+              family z500
+                edit PARAM 'Z'
+                edit LEVEL '500'
+                task pp_prep
+                  meter step -1 240 240
+              endfamily
+            endfamily
+          endfamily
+          family ensms
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger ( ../fc eq complete) and ( ./prepare eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            family limits
+              limit fdb 1
+              limit gen 8
+            endfamily
+            task ensms
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit ENS_MARS 'false'
+              event stage
+            family 048
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '003'
+              edit STEP2 '048'
+              edit BY '3'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 096
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '051'
+              edit STEP2 '096'
+              edit BY '3'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 144
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '099'
+              edit STEP2 '144'
+              edit BY '3'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 240
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '150'
+              edit STEP2 '240'
+              edit BY '6'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+          endfamily
+          family prob
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger /emc_36r1/main/00/legA/fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            edit STEP1 '12'
+            edit STEP2 '240'
+            edit BY '12'
+            family 24
+              edit STEP1 '24'
+              edit STEP2 '240'
+              edit BY '24'
+              family t850
+                trigger ../../prepare/all/t850 eq complete
+                family 120_240
+                  edit STEPS '120 240'
+                  task t850
+                    event 1 
+                endfamily
+                family 120_168
+                  trigger ./120_240/t850:1 or ./120_240 eq complete
+                  edit STEPS '120 168'
+                  task t850
+                    event 1 
+                endfamily
+                family 168_240
+                  trigger ./120_240/t850:1 or ./120_240 eq complete
+                  edit STEPS '168 240'
+                  task t850
+                    event 1 
+                endfamily
+              endfamily
+              task rain
+              task ff
+            endfamily
+            family 12
+              edit STEP1 '12'
+              edit STEP2 '228'
+              edit BY '24'
+              task t850
+                trigger ../../prepare/all/t850 eq complete
+              task rain
+              task ff
+            endfamily
+            task 2t
+            task swh
+            task mwp
+            task 10fg
+              trigger ../dp eq complete
+            task prob_fdb
+              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
+          endfamily
+          family tc
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger ../fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
+            edit TCINIEXPVER '0046'
+            family obsdata
+              trigger ( /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete)
+              task retrieve
+                late -c +00:10
+                trigger ( /emc_36r1/main/00/sv/targets eq complete or /emc_36r1/main/00/sv/targets:sv)
+                label info ""
+                event notc
+              task obs
+                trigger retrieve eq complete
+            endfamily
+            family stage
+              trigger ( /emc_36r1/main/00/legA/fc eq complete)
+              task an
+              task fc
+              task pf
+              task cf
+            endfamily
+            family tracking
+              trigger obsdata/obs eq complete and stage eq complete
+              inlimit /emc_36r1/limits:tc
+              family 1
+                edit MEMBER '1'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 2
+                edit MEMBER '2'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 3
+                edit MEMBER '3'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 4
+                edit MEMBER '4'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 5
+                edit MEMBER '5'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 6
+                edit MEMBER '6'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 7
+                edit MEMBER '7'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 8
+                edit MEMBER '8'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 9
+                edit MEMBER '9'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 10
+                edit MEMBER '10'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 11
+                edit MEMBER '11'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 12
+                edit MEMBER '12'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 13
+                edit MEMBER '13'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 14
+                edit MEMBER '14'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 15
+                edit MEMBER '15'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 16
+                edit MEMBER '16'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 17
+                edit MEMBER '17'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 18
+                edit MEMBER '18'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 19
+                edit MEMBER '19'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 20
+                edit MEMBER '20'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 21
+                edit MEMBER '21'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 22
+                edit MEMBER '22'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 23
+                edit MEMBER '23'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 24
+                edit MEMBER '24'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 25
+                edit MEMBER '25'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 26
+                edit MEMBER '26'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 27
+                edit MEMBER '27'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 28
+                edit MEMBER '28'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 29
+                edit MEMBER '29'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 30
+                edit MEMBER '30'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 31
+                edit MEMBER '31'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 32
+                edit MEMBER '32'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 33
+                edit MEMBER '33'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 34
+                edit MEMBER '34'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 35
+                edit MEMBER '35'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 36
+                edit MEMBER '36'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 37
+                edit MEMBER '37'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 38
+                edit MEMBER '38'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 39
+                edit MEMBER '39'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 40
+                edit MEMBER '40'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 41
+                edit MEMBER '41'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 42
+                edit MEMBER '42'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 43
+                edit MEMBER '43'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 44
+                edit MEMBER '44'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 45
+                edit MEMBER '45'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 46
+                edit MEMBER '46'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 47
+                edit MEMBER '47'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 48
+                edit MEMBER '48'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 49
+                edit MEMBER '49'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family 50
+                edit MEMBER '50'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family cf
+                edit MEMBER '51'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+              family oper
+                edit MEMBER '52'
+                edit SLEEP '1'
+                task get_data
+                task hilo
+                  trigger get_data eq complete
+                task tracking
+                  trigger hilo eq complete
+              endfamily
+            endfamily
+            family post_process
+              task to_bufr
+                trigger ../tracking eq complete
+            endfamily
+          endfamily
+          family calibrate
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger /emc_36r1/main/00/ref/an eq complete and ../fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
+            family onsc
+              edit QUEUE 'ns'
+              edit QUEUE_EPILOG 'ns'
+              edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+              edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+              inlimit /limits:c1b
+              task feedupcal
+              task upcal
+                trigger feedupcal eq complete
+                edit Z500_EXPVER '0001'
+                edit METVIEW 'metview'
+              task revertupcal
+            endfamily
+          endfamily
+          family clusters
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger ./calibrate/onsc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/clusters'
+            edit USER_PRIORITY '81'
+            edit QUEUE 'ns'
+            edit QUEUE_EPILOG 'ns'
+            edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+            edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+            inlimit /limits:c1b
+            task cthresh
+            task cluster
+              trigger cthresh eq complete and /emc_36r1/main/00/ref/model eq complete
+              edit USER_PRIORITY '76'
+            task tubcon
+              trigger /emc_36r1/main/00/ref/model eq complete
+            task tubgen
+              late -c +00:20
+              trigger tubcon eq complete
+          endfamily
+          family efi
+            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
+            trigger /emc_36r1/main/00/legA/postproc/dp eq complete
+            edit HC_VERSION '0046'
+            edit HC_EXPVER '0046'
+            edit REF_VERSION '0046'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            edit NC_DAYS '31'
+            edit EPSLEG '1'
+            inlimit /emc_36r1/limits:efi
+            task stage
+              edit NC_DAYS '31'
+            family 000_120
+              trigger ./stage eq complete
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 024_144
+              trigger ./stage eq complete
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 000_240
+              trigger ./stage eq complete
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 000_024
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 024_048
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 048_072
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 072_096
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+            family 096_120
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+            endfamily
+          endfamily
+          task efi2fdb
+            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
+            trigger ./efi eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            inlimit /emc_36r1/main/ref:mutex
+            event none
+          family dp
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '0:144:3 144:240:6'
+            inlimit /emc_36r1/limits:dp
+            family cf
+              trigger ../../fc/cf eq complete
+              edit EMOS_TYPE 'cf'
+              task derived_param
+                edit MEMBER 'off'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/00/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                trigger ../../../fc/pf/01 eq complete
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task derived_param
+              endfamily
+              family 02
+                trigger ../../../fc/pf/02 eq complete
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task derived_param
+              endfamily
+              family 03
+                trigger ../../../fc/pf/03 eq complete
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task derived_param
+              endfamily
+              family 04
+                trigger ../../../fc/pf/04 eq complete
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task derived_param
+              endfamily
+              family 05
+                trigger ../../../fc/pf/05 eq complete
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task derived_param
+              endfamily
+              family 06
+                trigger ../../../fc/pf/06 eq complete
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task derived_param
+              endfamily
+              family 07
+                trigger ../../../fc/pf/07 eq complete
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task derived_param
+              endfamily
+              family 08
+                trigger ../../../fc/pf/08 eq complete
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task derived_param
+              endfamily
+              family 09
+                trigger ../../../fc/pf/09 eq complete
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task derived_param
+              endfamily
+              family 10
+                trigger ../../../fc/pf/10 eq complete
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task derived_param
+              endfamily
+              family 11
+                trigger ../../../fc/pf/11 eq complete
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task derived_param
+              endfamily
+              family 12
+                trigger ../../../fc/pf/12 eq complete
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task derived_param
+              endfamily
+              family 13
+                trigger ../../../fc/pf/13 eq complete
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task derived_param
+              endfamily
+              family 14
+                trigger ../../../fc/pf/14 eq complete
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task derived_param
+              endfamily
+              family 15
+                trigger ../../../fc/pf/15 eq complete
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task derived_param
+              endfamily
+              family 16
+                trigger ../../../fc/pf/16 eq complete
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task derived_param
+              endfamily
+              family 17
+                trigger ../../../fc/pf/17 eq complete
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task derived_param
+              endfamily
+              family 18
+                trigger ../../../fc/pf/18 eq complete
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task derived_param
+              endfamily
+              family 19
+                trigger ../../../fc/pf/19 eq complete
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task derived_param
+              endfamily
+              family 20
+                trigger ../../../fc/pf/20 eq complete
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task derived_param
+              endfamily
+              family 21
+                trigger ../../../fc/pf/21 eq complete
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task derived_param
+              endfamily
+              family 22
+                trigger ../../../fc/pf/22 eq complete
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task derived_param
+              endfamily
+              family 23
+                trigger ../../../fc/pf/23 eq complete
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task derived_param
+              endfamily
+              family 24
+                trigger ../../../fc/pf/24 eq complete
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task derived_param
+              endfamily
+              family 25
+                trigger ../../../fc/pf/25 eq complete
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task derived_param
+              endfamily
+              family 26
+                trigger ../../../fc/pf/26 eq complete
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task derived_param
+              endfamily
+              family 27
+                trigger ../../../fc/pf/27 eq complete
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task derived_param
+              endfamily
+              family 28
+                trigger ../../../fc/pf/28 eq complete
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task derived_param
+              endfamily
+              family 29
+                trigger ../../../fc/pf/29 eq complete
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task derived_param
+              endfamily
+              family 30
+                trigger ../../../fc/pf/30 eq complete
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task derived_param
+              endfamily
+              family 31
+                trigger ../../../fc/pf/31 eq complete
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task derived_param
+              endfamily
+              family 32
+                trigger ../../../fc/pf/32 eq complete
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task derived_param
+              endfamily
+              family 33
+                trigger ../../../fc/pf/33 eq complete
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task derived_param
+              endfamily
+              family 34
+                trigger ../../../fc/pf/34 eq complete
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task derived_param
+              endfamily
+              family 35
+                trigger ../../../fc/pf/35 eq complete
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task derived_param
+              endfamily
+              family 36
+                trigger ../../../fc/pf/36 eq complete
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task derived_param
+              endfamily
+              family 37
+                trigger ../../../fc/pf/37 eq complete
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task derived_param
+              endfamily
+              family 38
+                trigger ../../../fc/pf/38 eq complete
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task derived_param
+              endfamily
+              family 39
+                trigger ../../../fc/pf/39 eq complete
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task derived_param
+              endfamily
+              family 40
+                trigger ../../../fc/pf/40 eq complete
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task derived_param
+              endfamily
+              family 41
+                trigger ../../../fc/pf/41 eq complete
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task derived_param
+              endfamily
+              family 42
+                trigger ../../../fc/pf/42 eq complete
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task derived_param
+              endfamily
+              family 43
+                trigger ../../../fc/pf/43 eq complete
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task derived_param
+              endfamily
+              family 44
+                trigger ../../../fc/pf/44 eq complete
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task derived_param
+              endfamily
+              family 45
+                trigger ../../../fc/pf/45 eq complete
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task derived_param
+              endfamily
+              family 46
+                trigger ../../../fc/pf/46 eq complete
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task derived_param
+              endfamily
+              family 47
+                trigger ../../../fc/pf/47 eq complete
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task derived_param
+              endfamily
+              family 48
+                trigger ../../../fc/pf/48 eq complete
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task derived_param
+              endfamily
+              family 49
+                trigger ../../../fc/pf/49 eq complete
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task derived_param
+              endfamily
+              family 50
+                trigger ../../../fc/pf/50 eq complete
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task derived_param
+              endfamily
+            endfamily
+          endfamily
+          family extra
+            trigger ./dp eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '0:144:3 144:240:6'
+            inlimit /emc_36r1/limits:extra
+            family cf
+              edit EMOS_TYPE 'cf'
+              task extrafields
+                edit EPSFCRES '639'
+                edit FCLENGTH '240'
+                edit FCLENGTH0 '0'
+                edit RUNVARFC '1'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/00/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 05
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 06
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 07
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 08
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 09
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 10
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 11
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 12
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 13
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 14
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 15
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 16
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 17
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 18
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 19
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 20
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 21
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 22
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 23
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 24
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 25
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 26
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 27
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 28
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 29
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 30
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 31
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 32
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 33
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 34
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 35
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 36
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 37
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 38
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 39
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 40
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 41
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 42
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 43
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 44
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 45
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 46
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 47
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 48
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 49
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family 50
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family prod
+          edit MEM '3000'
+          edit ACCOUNT 'oeenfopg'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'cp'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '90'
+          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
+          edit SMSURL 'sub=fixed/'
+          inlimit /limits:prod
+          family eps
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            inlimit /emc_36r1/limits:prodeps
+            family 0000
+              edit EMOS_TIME_STEP_H '0000'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0003
+              edit EMOS_TIME_STEP_H '0003'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0006
+              edit EMOS_TIME_STEP_H '0006'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0009
+              edit EMOS_TIME_STEP_H '0009'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0012
+              edit EMOS_TIME_STEP_H '0012'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0015
+              edit EMOS_TIME_STEP_H '0015'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0018
+              edit EMOS_TIME_STEP_H '0018'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0021
+              edit EMOS_TIME_STEP_H '0021'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0024
+              edit EMOS_TIME_STEP_H '0024'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0027
+              edit EMOS_TIME_STEP_H '0027'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0030
+              edit EMOS_TIME_STEP_H '0030'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0033
+              edit EMOS_TIME_STEP_H '0033'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0036
+              edit EMOS_TIME_STEP_H '0036'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0039
+              edit EMOS_TIME_STEP_H '0039'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0042
+              edit EMOS_TIME_STEP_H '0042'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0045
+              edit EMOS_TIME_STEP_H '0045'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0048
+              edit EMOS_TIME_STEP_H '0048'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0051
+              edit EMOS_TIME_STEP_H '0051'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0054
+              edit EMOS_TIME_STEP_H '0054'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0057
+              edit EMOS_TIME_STEP_H '0057'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0060
+              edit EMOS_TIME_STEP_H '0060'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0063
+              edit EMOS_TIME_STEP_H '0063'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0066
+              edit EMOS_TIME_STEP_H '0066'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0069
+              edit EMOS_TIME_STEP_H '0069'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0072
+              edit EMOS_TIME_STEP_H '0072'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0075
+              edit EMOS_TIME_STEP_H '0075'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0078
+              edit EMOS_TIME_STEP_H '0078'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0081
+              edit EMOS_TIME_STEP_H '0081'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0084
+              edit EMOS_TIME_STEP_H '0084'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0087
+              edit EMOS_TIME_STEP_H '0087'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0090
+              edit EMOS_TIME_STEP_H '0090'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0093
+              edit EMOS_TIME_STEP_H '0093'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0096
+              edit EMOS_TIME_STEP_H '0096'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0099
+              edit EMOS_TIME_STEP_H '0099'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0102
+              edit EMOS_TIME_STEP_H '0102'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0105
+              edit EMOS_TIME_STEP_H '0105'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0108
+              edit EMOS_TIME_STEP_H '0108'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0111
+              edit EMOS_TIME_STEP_H '0111'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0114
+              edit EMOS_TIME_STEP_H '0114'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0117
+              edit EMOS_TIME_STEP_H '0117'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0120
+              edit EMOS_TIME_STEP_H '0120'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0123
+              edit EMOS_TIME_STEP_H '0123'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0126
+              edit EMOS_TIME_STEP_H '0126'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0129
+              edit EMOS_TIME_STEP_H '0129'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0132
+              edit EMOS_TIME_STEP_H '0132'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0135
+              edit EMOS_TIME_STEP_H '0135'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0138
+              edit EMOS_TIME_STEP_H '0138'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0141
+              edit EMOS_TIME_STEP_H '0141'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0144
+              edit EMOS_TIME_STEP_H '0144'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0150
+              edit EMOS_TIME_STEP_H '0150'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0156
+              edit EMOS_TIME_STEP_H '0156'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0162
+              edit EMOS_TIME_STEP_H '0162'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0168
+              edit EMOS_TIME_STEP_H '0168'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0174
+              edit EMOS_TIME_STEP_H '0174'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0180
+              edit EMOS_TIME_STEP_H '0180'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0186
+              edit EMOS_TIME_STEP_H '0186'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0192
+              edit EMOS_TIME_STEP_H '0192'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0198
+              edit EMOS_TIME_STEP_H '0198'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0204
+              edit EMOS_TIME_STEP_H '0204'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0210
+              edit EMOS_TIME_STEP_H '0210'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0216
+              edit EMOS_TIME_STEP_H '0216'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0222
+              edit EMOS_TIME_STEP_H '0222'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0228
+              edit EMOS_TIME_STEP_H '0228'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0234
+              edit EMOS_TIME_STEP_H '0234'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0240
+              edit EMOS_TIME_STEP_H '0240'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+          endfamily
+          family wave
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            edit PGNPES '2'
+            edit URL 'GWAEF/00'
+            inlimit /emc_36r1/limits:prodwave
+            family 0000
+              edit EMOS_TIME_STEP_H '0000'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0003
+              edit EMOS_TIME_STEP_H '0003'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0006
+              edit EMOS_TIME_STEP_H '0006'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0009
+              edit EMOS_TIME_STEP_H '0009'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0012
+              edit EMOS_TIME_STEP_H '0012'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0015
+              edit EMOS_TIME_STEP_H '0015'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0018
+              edit EMOS_TIME_STEP_H '0018'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0021
+              edit EMOS_TIME_STEP_H '0021'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0024
+              edit EMOS_TIME_STEP_H '0024'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0027
+              edit EMOS_TIME_STEP_H '0027'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0030
+              edit EMOS_TIME_STEP_H '0030'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0033
+              edit EMOS_TIME_STEP_H '0033'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0036
+              edit EMOS_TIME_STEP_H '0036'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0039
+              edit EMOS_TIME_STEP_H '0039'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0042
+              edit EMOS_TIME_STEP_H '0042'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0045
+              edit EMOS_TIME_STEP_H '0045'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0048
+              edit EMOS_TIME_STEP_H '0048'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0051
+              edit EMOS_TIME_STEP_H '0051'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0054
+              edit EMOS_TIME_STEP_H '0054'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0057
+              edit EMOS_TIME_STEP_H '0057'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0060
+              edit EMOS_TIME_STEP_H '0060'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0063
+              edit EMOS_TIME_STEP_H '0063'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0066
+              edit EMOS_TIME_STEP_H '0066'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0069
+              edit EMOS_TIME_STEP_H '0069'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0072
+              edit EMOS_TIME_STEP_H '0072'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0075
+              edit EMOS_TIME_STEP_H '0075'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0078
+              edit EMOS_TIME_STEP_H '0078'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0081
+              edit EMOS_TIME_STEP_H '0081'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0084
+              edit EMOS_TIME_STEP_H '0084'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0087
+              edit EMOS_TIME_STEP_H '0087'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0090
+              edit EMOS_TIME_STEP_H '0090'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0093
+              edit EMOS_TIME_STEP_H '0093'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0096
+              edit EMOS_TIME_STEP_H '0096'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0099
+              edit EMOS_TIME_STEP_H '0099'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0102
+              edit EMOS_TIME_STEP_H '0102'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0105
+              edit EMOS_TIME_STEP_H '0105'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0108
+              edit EMOS_TIME_STEP_H '0108'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0111
+              edit EMOS_TIME_STEP_H '0111'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0114
+              edit EMOS_TIME_STEP_H '0114'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0117
+              edit EMOS_TIME_STEP_H '0117'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0120
+              edit EMOS_TIME_STEP_H '0120'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0123
+              edit EMOS_TIME_STEP_H '0123'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0126
+              edit EMOS_TIME_STEP_H '0126'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0129
+              edit EMOS_TIME_STEP_H '0129'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0132
+              edit EMOS_TIME_STEP_H '0132'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0135
+              edit EMOS_TIME_STEP_H '0135'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0138
+              edit EMOS_TIME_STEP_H '0138'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0141
+              edit EMOS_TIME_STEP_H '0141'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0144
+              edit EMOS_TIME_STEP_H '0144'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0150
+              edit EMOS_TIME_STEP_H '0150'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0156
+              edit EMOS_TIME_STEP_H '0156'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0162
+              edit EMOS_TIME_STEP_H '0162'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0168
+              edit EMOS_TIME_STEP_H '0168'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0174
+              edit EMOS_TIME_STEP_H '0174'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0180
+              edit EMOS_TIME_STEP_H '0180'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0186
+              edit EMOS_TIME_STEP_H '0186'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0192
+              edit EMOS_TIME_STEP_H '0192'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0198
+              edit EMOS_TIME_STEP_H '0198'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0204
+              edit EMOS_TIME_STEP_H '0204'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0210
+              edit EMOS_TIME_STEP_H '0210'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0216
+              edit EMOS_TIME_STEP_H '0216'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0222
+              edit EMOS_TIME_STEP_H '0222'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0228
+              edit EMOS_TIME_STEP_H '0228'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0234
+              edit EMOS_TIME_STEP_H '0234'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0240
+              edit EMOS_TIME_STEP_H '0240'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+          endfamily
+          family getreq
+            trigger ../fc/pf eq active or ../fc/pf/01 eq complete
+            edit EMOS_TYPE 'cm'
+            edit EMOS_DOMAIN 'G'
+            edit EMOS_PROJECT '12'
+            edit PROD_TASK '1'
+            edit SMSTRIES '1'
+            edit EMOS_STREAM 'ENFO'
+            task collectreq
+              edit QUEUE 'diss'
+              edit USER 'emos'
+              edit WSHOST 'diss'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit LOGDIR '/diss/log'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit EMOS_BASE '00'
+            task eps
+              late -s +00:03 -c +00:10
+              trigger collectreq eq complete
+              label info ""
+              event 1 
+            task collectwave
+              trigger collectreq eq complete
+              edit QUEUE 'diss'
+              edit USER 'emos'
+              edit WSHOST 'diss'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit LOGDIR '/diss/log'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit EMOS_STREAM 'WAEF'
+              edit EMOS_BASE '00'
+            task wave_eps
+              late -s +00:03 -c +00:10
+              trigger collectwave eq complete
+              edit EMOS_STREAM 'WAEF'
+              edit USER_PRIORITY '89'
+              label info ""
+              event 1 
+            task collectbitmap
+              trigger collectwave eq complete
+              edit QUEUE 'diss'
+              edit USER 'emos'
+              edit WSHOST 'diss'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit LOGDIR '/diss/log'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit SMSOUT '/vol/emos_nc/output'
+            task bitmap
+              late -s +00:03 -c +00:10
+              trigger collectbitmap eq complete and ( eps:001 or eps eq complete)
+              event 1 
+          endfamily
+          task enfo_tc
+            late -s +00:05 -c +00:15
+            trigger ( ./getreq/eps:001 or ./getreq/eps eq complete) and ../postproc/tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TYPE 'tf'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '1'
+          task oper_tc
+            late -s +00:05 -c +00:15
+            trigger ./enfo_tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TYPE 'tf'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '1'
+            edit EMOS_STREAM 'OPER'
+          task prod_wparam
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and /e_36r1/main/00/prod/240/prod_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TYPE 'wp'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '52'
+          task enfo_postproc
+            late -s +00:05 -c +00:15
+            trigger ../postproc eq complete and ( ../../legA/prod/getreq/eps eq complete) and ../../legA/postproc/efi eq complete and ../../legA/postproc/clusters eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'ep'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '21'
+          task waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TIME_STEP_H '0240'
+            edit PGNPES '1'
+        endfamily
+        family prod2diss
+          edit USER_PRIORITY '90'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'ef'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+          edit SMSURL 'GENFO/00'
+          task operation_is_late
+            event yes
+          family eps
+            family 0000
+              edit EMOS_TIME_STEP_H '0000'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0000/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0003
+              edit EMOS_TIME_STEP_H '0003'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0003/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0000/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0006
+              edit EMOS_TIME_STEP_H '0006'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0006/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0003/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0009
+              edit EMOS_TIME_STEP_H '0009'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0009/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0006/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0012
+              edit EMOS_TIME_STEP_H '0012'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0012/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0009/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0015
+              edit EMOS_TIME_STEP_H '0015'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0015/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0012/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0018
+              edit EMOS_TIME_STEP_H '0018'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0018/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0015/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0021
+              edit EMOS_TIME_STEP_H '0021'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0021/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0018/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0024
+              edit EMOS_TIME_STEP_H '0024'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0024/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0021/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0027
+              edit EMOS_TIME_STEP_H '0027'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0027/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0024/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0030
+              edit EMOS_TIME_STEP_H '0030'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0030/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0027/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0033
+              edit EMOS_TIME_STEP_H '0033'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0033/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0030/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0036
+              edit EMOS_TIME_STEP_H '0036'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0036/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0033/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0039
+              edit EMOS_TIME_STEP_H '0039'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0039/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0036/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0042
+              edit EMOS_TIME_STEP_H '0042'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0042/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0039/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0045
+              edit EMOS_TIME_STEP_H '0045'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0045/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0042/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0048
+              edit EMOS_TIME_STEP_H '0048'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0048/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0045/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0051
+              edit EMOS_TIME_STEP_H '0051'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0051/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0048/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0054
+              edit EMOS_TIME_STEP_H '0054'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0054/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0051/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0057
+              edit EMOS_TIME_STEP_H '0057'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0057/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0054/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0060
+              edit EMOS_TIME_STEP_H '0060'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0060/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0057/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0063
+              edit EMOS_TIME_STEP_H '0063'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0063/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0060/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0066
+              edit EMOS_TIME_STEP_H '0066'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0066/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0063/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0069
+              edit EMOS_TIME_STEP_H '0069'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0069/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0066/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0072
+              edit EMOS_TIME_STEP_H '0072'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0072/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0069/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0075
+              edit EMOS_TIME_STEP_H '0075'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0075/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0072/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0078
+              edit EMOS_TIME_STEP_H '0078'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0078/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0075/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0081
+              edit EMOS_TIME_STEP_H '0081'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0081/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0078/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0084
+              edit EMOS_TIME_STEP_H '0084'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0084/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0081/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0087
+              edit EMOS_TIME_STEP_H '0087'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0087/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0084/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0090
+              edit EMOS_TIME_STEP_H '0090'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0090/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0087/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0093
+              edit EMOS_TIME_STEP_H '0093'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0093/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0090/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0096
+              edit EMOS_TIME_STEP_H '0096'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0096/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0093/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0099
+              edit EMOS_TIME_STEP_H '0099'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0099/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0096/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0102
+              edit EMOS_TIME_STEP_H '0102'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0102/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0099/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0105
+              edit EMOS_TIME_STEP_H '0105'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0105/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0102/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0108
+              edit EMOS_TIME_STEP_H '0108'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0108/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0105/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0111
+              edit EMOS_TIME_STEP_H '0111'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0111/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0108/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0114
+              edit EMOS_TIME_STEP_H '0114'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0114/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0111/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0117
+              edit EMOS_TIME_STEP_H '0117'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0117/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0114/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0120
+              edit EMOS_TIME_STEP_H '0120'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0120/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0117/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0123
+              edit EMOS_TIME_STEP_H '0123'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0123/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0120/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0126
+              edit EMOS_TIME_STEP_H '0126'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0126/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0123/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0129
+              edit EMOS_TIME_STEP_H '0129'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0129/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0126/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0132
+              edit EMOS_TIME_STEP_H '0132'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0132/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0129/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0135
+              edit EMOS_TIME_STEP_H '0135'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0135/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0132/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0138
+              edit EMOS_TIME_STEP_H '0138'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0138/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0135/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0141
+              edit EMOS_TIME_STEP_H '0141'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0141/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0138/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0144
+              edit EMOS_TIME_STEP_H '0144'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0144/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0141/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0150
+              edit EMOS_TIME_STEP_H '0150'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0150/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0144/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0156
+              edit EMOS_TIME_STEP_H '0156'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0156/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0150/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0162
+              edit EMOS_TIME_STEP_H '0162'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0162/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0156/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0168
+              edit EMOS_TIME_STEP_H '0168'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0168/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0162/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0174
+              edit EMOS_TIME_STEP_H '0174'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0174/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0168/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0180
+              edit EMOS_TIME_STEP_H '0180'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0180/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0174/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0186
+              edit EMOS_TIME_STEP_H '0186'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0186/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0180/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0192
+              edit EMOS_TIME_STEP_H '0192'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0192/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0186/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0198
+              edit EMOS_TIME_STEP_H '0198'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0198/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0192/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0204
+              edit EMOS_TIME_STEP_H '0204'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0204/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0198/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0210
+              edit EMOS_TIME_STEP_H '0210'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0210/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0204/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0216
+              edit EMOS_TIME_STEP_H '0216'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0216/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0210/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0222
+              edit EMOS_TIME_STEP_H '0222'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0222/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0216/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0228
+              edit EMOS_TIME_STEP_H '0228'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0228/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0222/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0234
+              edit EMOS_TIME_STEP_H '0234'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0234/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0228/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0240
+              edit EMOS_TIME_STEP_H '0240'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0240/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0234/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            task check
+              trigger ./0240 eq complete
+          endfamily
+          family wave
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TYPE 'we'
+            edit SMSURL 'GWAEF/00'
+            family 0000
+              trigger ../../prod/wave/0000/prodwave eq complete
+              edit EMOS_TIME_STEP_H '0000'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0003
+              trigger ../../prod/wave/0003/prodwave eq complete and ( ./0000 eq complete)
+              edit EMOS_TIME_STEP_H '0003'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0006
+              trigger ../../prod/wave/0006/prodwave eq complete and ( ./0003 eq complete)
+              edit EMOS_TIME_STEP_H '0006'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0009
+              trigger ../../prod/wave/0009/prodwave eq complete and ( ./0006 eq complete)
+              edit EMOS_TIME_STEP_H '0009'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0012
+              trigger ../../prod/wave/0012/prodwave eq complete and ( ./0009 eq complete)
+              edit EMOS_TIME_STEP_H '0012'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0015
+              trigger ../../prod/wave/0015/prodwave eq complete and ( ./0012 eq complete)
+              edit EMOS_TIME_STEP_H '0015'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0018
+              trigger ../../prod/wave/0018/prodwave eq complete and ( ./0015 eq complete)
+              edit EMOS_TIME_STEP_H '0018'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0021
+              trigger ../../prod/wave/0021/prodwave eq complete and ( ./0018 eq complete)
+              edit EMOS_TIME_STEP_H '0021'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0024
+              trigger ../../prod/wave/0024/prodwave eq complete and ( ./0021 eq complete)
+              edit EMOS_TIME_STEP_H '0024'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0027
+              trigger ../../prod/wave/0027/prodwave eq complete and ( ./0024 eq complete)
+              edit EMOS_TIME_STEP_H '0027'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0030
+              trigger ../../prod/wave/0030/prodwave eq complete and ( ./0027 eq complete)
+              edit EMOS_TIME_STEP_H '0030'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0033
+              trigger ../../prod/wave/0033/prodwave eq complete and ( ./0030 eq complete)
+              edit EMOS_TIME_STEP_H '0033'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0036
+              trigger ../../prod/wave/0036/prodwave eq complete and ( ./0033 eq complete)
+              edit EMOS_TIME_STEP_H '0036'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0039
+              trigger ../../prod/wave/0039/prodwave eq complete and ( ./0036 eq complete)
+              edit EMOS_TIME_STEP_H '0039'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0042
+              trigger ../../prod/wave/0042/prodwave eq complete and ( ./0039 eq complete)
+              edit EMOS_TIME_STEP_H '0042'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0045
+              trigger ../../prod/wave/0045/prodwave eq complete and ( ./0042 eq complete)
+              edit EMOS_TIME_STEP_H '0045'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0048
+              trigger ../../prod/wave/0048/prodwave eq complete and ( ./0045 eq complete)
+              edit EMOS_TIME_STEP_H '0048'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0051
+              trigger ../../prod/wave/0051/prodwave eq complete and ( ./0048 eq complete)
+              edit EMOS_TIME_STEP_H '0051'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0054
+              trigger ../../prod/wave/0054/prodwave eq complete and ( ./0051 eq complete)
+              edit EMOS_TIME_STEP_H '0054'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0057
+              trigger ../../prod/wave/0057/prodwave eq complete and ( ./0054 eq complete)
+              edit EMOS_TIME_STEP_H '0057'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0060
+              trigger ../../prod/wave/0060/prodwave eq complete and ( ./0057 eq complete)
+              edit EMOS_TIME_STEP_H '0060'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0063
+              trigger ../../prod/wave/0063/prodwave eq complete and ( ./0060 eq complete)
+              edit EMOS_TIME_STEP_H '0063'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0066
+              trigger ../../prod/wave/0066/prodwave eq complete and ( ./0063 eq complete)
+              edit EMOS_TIME_STEP_H '0066'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0069
+              trigger ../../prod/wave/0069/prodwave eq complete and ( ./0066 eq complete)
+              edit EMOS_TIME_STEP_H '0069'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0072
+              trigger ../../prod/wave/0072/prodwave eq complete and ( ./0069 eq complete)
+              edit EMOS_TIME_STEP_H '0072'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0075
+              trigger ../../prod/wave/0075/prodwave eq complete and ( ./0072 eq complete)
+              edit EMOS_TIME_STEP_H '0075'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0078
+              trigger ../../prod/wave/0078/prodwave eq complete and ( ./0075 eq complete)
+              edit EMOS_TIME_STEP_H '0078'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0081
+              trigger ../../prod/wave/0081/prodwave eq complete and ( ./0078 eq complete)
+              edit EMOS_TIME_STEP_H '0081'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0084
+              trigger ../../prod/wave/0084/prodwave eq complete and ( ./0081 eq complete)
+              edit EMOS_TIME_STEP_H '0084'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0087
+              trigger ../../prod/wave/0087/prodwave eq complete and ( ./0084 eq complete)
+              edit EMOS_TIME_STEP_H '0087'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0090
+              trigger ../../prod/wave/0090/prodwave eq complete and ( ./0087 eq complete)
+              edit EMOS_TIME_STEP_H '0090'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0093
+              trigger ../../prod/wave/0093/prodwave eq complete and ( ./0090 eq complete)
+              edit EMOS_TIME_STEP_H '0093'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0096
+              trigger ../../prod/wave/0096/prodwave eq complete and ( ./0093 eq complete)
+              edit EMOS_TIME_STEP_H '0096'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0099
+              trigger ../../prod/wave/0099/prodwave eq complete and ( ./0096 eq complete)
+              edit EMOS_TIME_STEP_H '0099'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0102
+              trigger ../../prod/wave/0102/prodwave eq complete and ( ./0099 eq complete)
+              edit EMOS_TIME_STEP_H '0102'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0105
+              trigger ../../prod/wave/0105/prodwave eq complete and ( ./0102 eq complete)
+              edit EMOS_TIME_STEP_H '0105'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0108
+              trigger ../../prod/wave/0108/prodwave eq complete and ( ./0105 eq complete)
+              edit EMOS_TIME_STEP_H '0108'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0111
+              trigger ../../prod/wave/0111/prodwave eq complete and ( ./0108 eq complete)
+              edit EMOS_TIME_STEP_H '0111'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0114
+              trigger ../../prod/wave/0114/prodwave eq complete and ( ./0111 eq complete)
+              edit EMOS_TIME_STEP_H '0114'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0117
+              trigger ../../prod/wave/0117/prodwave eq complete and ( ./0114 eq complete)
+              edit EMOS_TIME_STEP_H '0117'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0120
+              trigger ../../prod/wave/0120/prodwave eq complete and ( ./0117 eq complete)
+              edit EMOS_TIME_STEP_H '0120'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0123
+              trigger ../../prod/wave/0123/prodwave eq complete and ( ./0120 eq complete)
+              edit EMOS_TIME_STEP_H '0123'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0126
+              trigger ../../prod/wave/0126/prodwave eq complete and ( ./0123 eq complete)
+              edit EMOS_TIME_STEP_H '0126'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0129
+              trigger ../../prod/wave/0129/prodwave eq complete and ( ./0126 eq complete)
+              edit EMOS_TIME_STEP_H '0129'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0132
+              trigger ../../prod/wave/0132/prodwave eq complete and ( ./0129 eq complete)
+              edit EMOS_TIME_STEP_H '0132'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0135
+              trigger ../../prod/wave/0135/prodwave eq complete and ( ./0132 eq complete)
+              edit EMOS_TIME_STEP_H '0135'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0138
+              trigger ../../prod/wave/0138/prodwave eq complete and ( ./0135 eq complete)
+              edit EMOS_TIME_STEP_H '0138'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0141
+              trigger ../../prod/wave/0141/prodwave eq complete and ( ./0138 eq complete)
+              edit EMOS_TIME_STEP_H '0141'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0144
+              trigger ../../prod/wave/0144/prodwave eq complete and ( ./0141 eq complete)
+              edit EMOS_TIME_STEP_H '0144'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0150
+              trigger ../../prod/wave/0150/prodwave eq complete and ( ./0144 eq complete)
+              edit EMOS_TIME_STEP_H '0150'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0156
+              trigger ../../prod/wave/0156/prodwave eq complete and ( ./0150 eq complete)
+              edit EMOS_TIME_STEP_H '0156'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0162
+              trigger ../../prod/wave/0162/prodwave eq complete and ( ./0156 eq complete)
+              edit EMOS_TIME_STEP_H '0162'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0168
+              trigger ../../prod/wave/0168/prodwave eq complete and ( ./0162 eq complete)
+              edit EMOS_TIME_STEP_H '0168'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0174
+              trigger ../../prod/wave/0174/prodwave eq complete and ( ./0168 eq complete)
+              edit EMOS_TIME_STEP_H '0174'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0180
+              trigger ../../prod/wave/0180/prodwave eq complete and ( ./0174 eq complete)
+              edit EMOS_TIME_STEP_H '0180'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0186
+              trigger ../../prod/wave/0186/prodwave eq complete and ( ./0180 eq complete)
+              edit EMOS_TIME_STEP_H '0186'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0192
+              trigger ../../prod/wave/0192/prodwave eq complete and ( ./0186 eq complete)
+              edit EMOS_TIME_STEP_H '0192'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0198
+              trigger ../../prod/wave/0198/prodwave eq complete and ( ./0192 eq complete)
+              edit EMOS_TIME_STEP_H '0198'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0204
+              trigger ../../prod/wave/0204/prodwave eq complete and ( ./0198 eq complete)
+              edit EMOS_TIME_STEP_H '0204'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0210
+              trigger ../../prod/wave/0210/prodwave eq complete and ( ./0204 eq complete)
+              edit EMOS_TIME_STEP_H '0210'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0216
+              trigger ../../prod/wave/0216/prodwave eq complete and ( ./0210 eq complete)
+              edit EMOS_TIME_STEP_H '0216'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0222
+              trigger ../../prod/wave/0222/prodwave eq complete and ( ./0216 eq complete)
+              edit EMOS_TIME_STEP_H '0222'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0228
+              trigger ../../prod/wave/0228/prodwave eq complete and ( ./0222 eq complete)
+              edit EMOS_TIME_STEP_H '0228'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0234
+              trigger ../../prod/wave/0234/prodwave eq complete and ( ./0228 eq complete)
+              edit EMOS_TIME_STEP_H '0234'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0240
+              trigger ../../prod/wave/0240/prodwave eq complete and ( ./0234 eq complete)
+              edit EMOS_TIME_STEP_H '0240'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            task check
+              trigger ./0240 eq complete
+          endfamily
+          task diss_wparam
+            late -s +00:05 -c +00:15
+            trigger ../prod/prod_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'wp'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/waef_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/enfo_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'ep'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_enfotc
+            late -s +00:05 -c +00:15
+            trigger ../prod/enfo_tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'tf'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_opertc
+            late -s +00:05 -c +00:15
+            trigger ../prod/oper_tc eq complete
+            edit PROD_TASK 't'
+            edit EMOS_TIME_STEP_H '0240'
+            edit EMOS_TYPE 'tf'
+            edit EMOS_STREAM 'DA'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+        endfamily
+      endfamily
+      family legB
+        complete /emc_36r1/main/ref/00/events:240
+        edit EPSLEG '2'
+        family fc
+          complete /emc_36r1/main/ref/00/events:cpl and /emc_36r1/main/00/legBcpl/fc eq complete
+          trigger /emc_36r1/main/ref/00/events eq complete and not /emc_36r1/main/ref/00/events:cpl
+          edit FCMEM '2240'
+          edit FCSTACK '700'
+          edit FCMRFS '0'
+          edit PRIORITY '71'
+          edit USER_PRIORITY '71'
+          edit N_PERT_AN '10'
+          edit SSTLEN '144'
+          edit EPSINISTEP_PREVIOUS '216'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          edit TSTEP '2700'
+          edit EPSFCRES '639'
+          edit RESOL '639'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit CPUTIME '1000'
+          edit MEM '960'
+          edit THREADS '8'
+          edit NPES '8'
+          edit EPSLEG '2'
+          edit PERSST 'true'
+          edit SSTINT '1'
+          task wavfcdata
+            trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+            edit EPSCOUPLE '1'
+          task getpersSST
+            trigger ../../legA/fc/inidata eq complete and ../../legA/fc/getpersSST eq complete
+            edit EPSCOUPLE '1'
+            edit EPS_INI_STREAM 'DA'
+            edit EPSFCRES '319'
+            edit RESOL '319'
+          family pf
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger ./getpersSST eq complete and ./wavfcdata eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTYPE 'pf'
+            edit EMOS_TYPE 'pf'
+            edit USER_PRIORITY '71'
+            edit PRIORITY '71'
+            edit FCNPES '32'
+            edit FCCHUNK '1'
+            edit OCTOTAL '5'
+            edit FCTOTAL '51'
+            edit FCLENGTH1 '216'
+            edit DAILY '0'
+            edit RUNVARFC '1'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSFCRES '319'
+            edit EPSWAMRESOL 'global50'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit EPSINISTEP '360'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '2'
+            edit CLASS 'od'
+            edit THREADS '2'
+            inlimit /emc_36r1/limits:pftotal
+            meter step -1 144 144
+            family 01
+              trigger ../../../legA/fc/pf/01 eq complete
+              edit EPSMEMBER '1'
+              edit MEMBER '1'
+              edit SUBFSFAMILY '/pf001'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 02
+              trigger ../../../legA/fc/pf/02 eq complete
+              edit EPSMEMBER '2'
+              edit MEMBER '2'
+              edit SUBFSFAMILY '/pf002'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 03
+              trigger ../../../legA/fc/pf/03 eq complete
+              edit EPSMEMBER '3'
+              edit MEMBER '3'
+              edit SUBFSFAMILY '/pf003'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 04
+              trigger ../../../legA/fc/pf/04 eq complete
+              edit EPSMEMBER '4'
+              edit MEMBER '4'
+              edit SUBFSFAMILY '/pf004'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 05
+              trigger ../../../legA/fc/pf/05 eq complete
+              edit EPSMEMBER '5'
+              edit MEMBER '5'
+              edit SUBFSFAMILY '/pf005'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 06
+              trigger ../../../legA/fc/pf/06 eq complete
+              edit EPSMEMBER '6'
+              edit MEMBER '6'
+              edit SUBFSFAMILY '/pf006'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 07
+              trigger ../../../legA/fc/pf/07 eq complete
+              edit EPSMEMBER '7'
+              edit MEMBER '7'
+              edit SUBFSFAMILY '/pf007'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 08
+              trigger ../../../legA/fc/pf/08 eq complete
+              edit EPSMEMBER '8'
+              edit MEMBER '8'
+              edit SUBFSFAMILY '/pf008'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 09
+              trigger ../../../legA/fc/pf/09 eq complete
+              edit EPSMEMBER '9'
+              edit MEMBER '9'
+              edit SUBFSFAMILY '/pf009'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 10
+              trigger ../../../legA/fc/pf/10 eq complete
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              edit SUBFSFAMILY '/pf010'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 11
+              trigger ../../../legA/fc/pf/11 eq complete
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              edit SUBFSFAMILY '/pf011'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 12
+              trigger ../../../legA/fc/pf/12 eq complete
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              edit SUBFSFAMILY '/pf012'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 13
+              trigger ../../../legA/fc/pf/13 eq complete
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              edit SUBFSFAMILY '/pf013'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 14
+              trigger ../../../legA/fc/pf/14 eq complete
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              edit SUBFSFAMILY '/pf014'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 15
+              trigger ../../../legA/fc/pf/15 eq complete
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              edit SUBFSFAMILY '/pf015'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 16
+              trigger ../../../legA/fc/pf/16 eq complete
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              edit SUBFSFAMILY '/pf016'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 17
+              trigger ../../../legA/fc/pf/17 eq complete
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              edit SUBFSFAMILY '/pf017'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 18
+              trigger ../../../legA/fc/pf/18 eq complete
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              edit SUBFSFAMILY '/pf018'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 19
+              trigger ../../../legA/fc/pf/19 eq complete
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              edit SUBFSFAMILY '/pf019'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 20
+              trigger ../../../legA/fc/pf/20 eq complete
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              edit SUBFSFAMILY '/pf020'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 21
+              trigger ../../../legA/fc/pf/21 eq complete
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              edit SUBFSFAMILY '/pf021'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 22
+              trigger ../../../legA/fc/pf/22 eq complete
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              edit SUBFSFAMILY '/pf022'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 23
+              trigger ../../../legA/fc/pf/23 eq complete
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              edit SUBFSFAMILY '/pf023'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 24
+              trigger ../../../legA/fc/pf/24 eq complete
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              edit SUBFSFAMILY '/pf024'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 25
+              trigger ../../../legA/fc/pf/25 eq complete
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              edit SUBFSFAMILY '/pf025'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 26
+              trigger ../../../legA/fc/pf/26 eq complete
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              edit SUBFSFAMILY '/pf026'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 27
+              trigger ../../../legA/fc/pf/27 eq complete
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              edit SUBFSFAMILY '/pf027'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 28
+              trigger ../../../legA/fc/pf/28 eq complete
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              edit SUBFSFAMILY '/pf028'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 29
+              trigger ../../../legA/fc/pf/29 eq complete
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              edit SUBFSFAMILY '/pf029'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 30
+              trigger ../../../legA/fc/pf/30 eq complete
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              edit SUBFSFAMILY '/pf030'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 31
+              trigger ../../../legA/fc/pf/31 eq complete
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              edit SUBFSFAMILY '/pf031'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 32
+              trigger ../../../legA/fc/pf/32 eq complete
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              edit SUBFSFAMILY '/pf032'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 33
+              trigger ../../../legA/fc/pf/33 eq complete
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              edit SUBFSFAMILY '/pf033'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 34
+              trigger ../../../legA/fc/pf/34 eq complete
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              edit SUBFSFAMILY '/pf034'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 35
+              trigger ../../../legA/fc/pf/35 eq complete
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              edit SUBFSFAMILY '/pf035'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 36
+              trigger ../../../legA/fc/pf/36 eq complete
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              edit SUBFSFAMILY '/pf036'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 37
+              trigger ../../../legA/fc/pf/37 eq complete
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              edit SUBFSFAMILY '/pf037'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 38
+              trigger ../../../legA/fc/pf/38 eq complete
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              edit SUBFSFAMILY '/pf038'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 39
+              trigger ../../../legA/fc/pf/39 eq complete
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              edit SUBFSFAMILY '/pf039'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 40
+              trigger ../../../legA/fc/pf/40 eq complete
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              edit SUBFSFAMILY '/pf040'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 41
+              trigger ../../../legA/fc/pf/41 eq complete
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              edit SUBFSFAMILY '/pf041'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 42
+              trigger ../../../legA/fc/pf/42 eq complete
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              edit SUBFSFAMILY '/pf042'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 43
+              trigger ../../../legA/fc/pf/43 eq complete
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              edit SUBFSFAMILY '/pf043'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 44
+              trigger ../../../legA/fc/pf/44 eq complete
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              edit SUBFSFAMILY '/pf044'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 45
+              trigger ../../../legA/fc/pf/45 eq complete
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              edit SUBFSFAMILY '/pf045'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 46
+              trigger ../../../legA/fc/pf/46 eq complete
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              edit SUBFSFAMILY '/pf046'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 47
+              trigger ../../../legA/fc/pf/47 eq complete
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              edit SUBFSFAMILY '/pf047'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 48
+              trigger ../../../legA/fc/pf/48 eq complete
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              edit SUBFSFAMILY '/pf048'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 49
+              trigger ../../../legA/fc/pf/49 eq complete
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              edit SUBFSFAMILY '/pf049'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 50
+              trigger ../../../legA/fc/pf/50 eq complete
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              edit SUBFSFAMILY '/pf050'
+              edit SMSTRIES '1'
+              task getvarepsdata
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger intHtoL eq complete and getvarepsdata eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '144'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+          endfamily
+          family cf
+            complete /emc_36r1/main/00/legBcpl/fc/cf/modeleps:step ge 144
+            trigger ../../legA/fc/cf eq complete and not /emc_36r1/main/ref/00/events:cpl and ./getpersSST eq complete and ./wavfcdata eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit MEMBER '0'
+            edit EPSMEMBER '0'
+            edit SUBFSFAMILY '/cf000'
+            edit EPSTYPE 'cf'
+            edit EMOS_TYPE 'cf'
+            edit USER_PRIORITY '72'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSFCRES '319'
+            edit EPSWAMRESOL 'global50'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit EPSINISTEP '360'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '2'
+            edit CLASS 'od'
+            edit SMSTRIES '1'
+            edit RUNCOUPLE '0'
+            task getvarepsdata
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '2700'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSLEG '2'
+              edit EPSINISTEP '216'
+              edit EPSFCRES '639'
+              edit EPSFCRESN '319'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '2700'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '216'
+              edit EPSFCRES '319'
+              edit NPES '24'
+              edit FCNPES '24'
+              edit THREADS '2'
+              edit CLASS 'od'
+            task modeleps
+              trigger intHtoL eq complete and getvarepsdata eq complete
+              edit FCNPES '32'
+              edit THREADS '4'
+              edit SMSTRIES '1'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSLEG '2'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '144'
+              edit EPSINISTEP_PREVIOUS '216'
+              edit FCLENGTH '144'
+              edit TSTEP '2700'
+              edit CLASS 'od'
+              meter step -1 144 144
+          endfamily
+        endfamily
+        family postproc
+          trigger ./fc/pf eq complete and ./fc/cf eq complete
+          edit STEPS '252/360/12/24 360/360/12/120'
+          inlimit /emc_36r1/limits:postproc
+          family ensms
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger ../fc eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            family limits
+              limit fdb 1
+              limit gen 8
+            endfamily
+            task ensms
+              edit ENS_M 'false'
+              edit ENS_S 'false'
+              edit ENS_MARS 'false'
+              event stage
+            family 300
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '246'
+              edit STEP2 '300'
+              edit BY '6'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+            family 360
+              trigger ./ensms:stage or ./ensms eq complete
+              edit STEP1 '306'
+              edit STEP2 '360'
+              edit BY '6'
+              edit STEPS '0'
+              family T
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'T'
+                inlimit ../limits:gen
+                family 850
+                  task ensms
+                    edit LIST_LEV '850'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              family Z
+                edit ENS_M 'false'
+                edit ENS_S 'false'
+                edit LIST_PARAM 'Z'
+                inlimit ../limits:gen
+                family 1000
+                  task ensms
+                    edit LIST_LEV '1000'
+                endfamily
+                family 500
+                  task ensms
+                    edit LIST_LEV '500'
+                endfamily
+              endfamily
+              task ensms
+                trigger T eq complete and Z eq complete
+                edit ENS_MARS 'false'
+                inlimit ../limits:fdb
+            endfamily
+          endfamily
+          family prob
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger ( /emc_36r1/main/00/legB/fc eq complete) and ( /emc_36r1/main/00/legA/postproc/prob eq complete)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            edit STEP1 '252'
+            edit STEP2 '360'
+            edit BY '12'
+            family 24
+              edit STEP1 '240'
+              edit STEP2 '360'
+              edit BY '24'
+              task t850
+              task rain
+              task ff
+            endfamily
+            family 12
+              edit STEP1 '252'
+              edit STEP2 '348'
+              edit BY '24'
+              task t850
+              task rain
+              task ff
+            endfamily
+            task 2t
+            task swh
+            task mwp
+            task 10fg
+              trigger ../dp eq complete
+            task prob_fdb
+              trigger ./2t eq complete and swh eq complete and mwp eq complete and ./10fg eq complete and ./12 eq complete and ./24 eq complete
+          endfamily
+          family dp
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '246:360:6'
+            inlimit /emc_36r1/limits:dp
+            family dp
+              trigger ./cf eq complete and ./pf eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit OVERLAP '1'
+              edit STEPS '216:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                complete /emc_36r1/main/ref/00/events:cf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+                family 05
+                  edit EPSMEMBER '5'
+                  edit MEMBER '5'
+                  edit SUBFSFAMILY '/pf005'
+                  task derived_param
+                endfamily
+                family 06
+                  edit EPSMEMBER '6'
+                  edit MEMBER '6'
+                  edit SUBFSFAMILY '/pf006'
+                  task derived_param
+                endfamily
+                family 07
+                  edit EPSMEMBER '7'
+                  edit MEMBER '7'
+                  edit SUBFSFAMILY '/pf007'
+                  task derived_param
+                endfamily
+                family 08
+                  edit EPSMEMBER '8'
+                  edit MEMBER '8'
+                  edit SUBFSFAMILY '/pf008'
+                  task derived_param
+                endfamily
+                family 09
+                  edit EPSMEMBER '9'
+                  edit MEMBER '9'
+                  edit SUBFSFAMILY '/pf009'
+                  task derived_param
+                endfamily
+                family 10
+                  edit EPSMEMBER '10'
+                  edit MEMBER '10'
+                  edit SUBFSFAMILY '/pf010'
+                  task derived_param
+                endfamily
+                family 11
+                  edit EPSMEMBER '11'
+                  edit MEMBER '11'
+                  edit SUBFSFAMILY '/pf011'
+                  task derived_param
+                endfamily
+                family 12
+                  edit EPSMEMBER '12'
+                  edit MEMBER '12'
+                  edit SUBFSFAMILY '/pf012'
+                  task derived_param
+                endfamily
+                family 13
+                  edit EPSMEMBER '13'
+                  edit MEMBER '13'
+                  edit SUBFSFAMILY '/pf013'
+                  task derived_param
+                endfamily
+                family 14
+                  edit EPSMEMBER '14'
+                  edit MEMBER '14'
+                  edit SUBFSFAMILY '/pf014'
+                  task derived_param
+                endfamily
+                family 15
+                  edit EPSMEMBER '15'
+                  edit MEMBER '15'
+                  edit SUBFSFAMILY '/pf015'
+                  task derived_param
+                endfamily
+                family 16
+                  edit EPSMEMBER '16'
+                  edit MEMBER '16'
+                  edit SUBFSFAMILY '/pf016'
+                  task derived_param
+                endfamily
+                family 17
+                  edit EPSMEMBER '17'
+                  edit MEMBER '17'
+                  edit SUBFSFAMILY '/pf017'
+                  task derived_param
+                endfamily
+                family 18
+                  edit EPSMEMBER '18'
+                  edit MEMBER '18'
+                  edit SUBFSFAMILY '/pf018'
+                  task derived_param
+                endfamily
+                family 19
+                  edit EPSMEMBER '19'
+                  edit MEMBER '19'
+                  edit SUBFSFAMILY '/pf019'
+                  task derived_param
+                endfamily
+                family 20
+                  edit EPSMEMBER '20'
+                  edit MEMBER '20'
+                  edit SUBFSFAMILY '/pf020'
+                  task derived_param
+                endfamily
+                family 21
+                  edit EPSMEMBER '21'
+                  edit MEMBER '21'
+                  edit SUBFSFAMILY '/pf021'
+                  task derived_param
+                endfamily
+                family 22
+                  edit EPSMEMBER '22'
+                  edit MEMBER '22'
+                  edit SUBFSFAMILY '/pf022'
+                  task derived_param
+                endfamily
+                family 23
+                  edit EPSMEMBER '23'
+                  edit MEMBER '23'
+                  edit SUBFSFAMILY '/pf023'
+                  task derived_param
+                endfamily
+                family 24
+                  edit EPSMEMBER '24'
+                  edit MEMBER '24'
+                  edit SUBFSFAMILY '/pf024'
+                  task derived_param
+                endfamily
+                family 25
+                  edit EPSMEMBER '25'
+                  edit MEMBER '25'
+                  edit SUBFSFAMILY '/pf025'
+                  task derived_param
+                endfamily
+                family 26
+                  edit EPSMEMBER '26'
+                  edit MEMBER '26'
+                  edit SUBFSFAMILY '/pf026'
+                  task derived_param
+                endfamily
+                family 27
+                  edit EPSMEMBER '27'
+                  edit MEMBER '27'
+                  edit SUBFSFAMILY '/pf027'
+                  task derived_param
+                endfamily
+                family 28
+                  edit EPSMEMBER '28'
+                  edit MEMBER '28'
+                  edit SUBFSFAMILY '/pf028'
+                  task derived_param
+                endfamily
+                family 29
+                  edit EPSMEMBER '29'
+                  edit MEMBER '29'
+                  edit SUBFSFAMILY '/pf029'
+                  task derived_param
+                endfamily
+                family 30
+                  edit EPSMEMBER '30'
+                  edit MEMBER '30'
+                  edit SUBFSFAMILY '/pf030'
+                  task derived_param
+                endfamily
+                family 31
+                  edit EPSMEMBER '31'
+                  edit MEMBER '31'
+                  edit SUBFSFAMILY '/pf031'
+                  task derived_param
+                endfamily
+                family 32
+                  edit EPSMEMBER '32'
+                  edit MEMBER '32'
+                  edit SUBFSFAMILY '/pf032'
+                  task derived_param
+                endfamily
+                family 33
+                  edit EPSMEMBER '33'
+                  edit MEMBER '33'
+                  edit SUBFSFAMILY '/pf033'
+                  task derived_param
+                endfamily
+                family 34
+                  edit EPSMEMBER '34'
+                  edit MEMBER '34'
+                  edit SUBFSFAMILY '/pf034'
+                  task derived_param
+                endfamily
+                family 35
+                  edit EPSMEMBER '35'
+                  edit MEMBER '35'
+                  edit SUBFSFAMILY '/pf035'
+                  task derived_param
+                endfamily
+                family 36
+                  edit EPSMEMBER '36'
+                  edit MEMBER '36'
+                  edit SUBFSFAMILY '/pf036'
+                  task derived_param
+                endfamily
+                family 37
+                  edit EPSMEMBER '37'
+                  edit MEMBER '37'
+                  edit SUBFSFAMILY '/pf037'
+                  task derived_param
+                endfamily
+                family 38
+                  edit EPSMEMBER '38'
+                  edit MEMBER '38'
+                  edit SUBFSFAMILY '/pf038'
+                  task derived_param
+                endfamily
+                family 39
+                  edit EPSMEMBER '39'
+                  edit MEMBER '39'
+                  edit SUBFSFAMILY '/pf039'
+                  task derived_param
+                endfamily
+                family 40
+                  edit EPSMEMBER '40'
+                  edit MEMBER '40'
+                  edit SUBFSFAMILY '/pf040'
+                  task derived_param
+                endfamily
+                family 41
+                  edit EPSMEMBER '41'
+                  edit MEMBER '41'
+                  edit SUBFSFAMILY '/pf041'
+                  task derived_param
+                endfamily
+                family 42
+                  edit EPSMEMBER '42'
+                  edit MEMBER '42'
+                  edit SUBFSFAMILY '/pf042'
+                  task derived_param
+                endfamily
+                family 43
+                  edit EPSMEMBER '43'
+                  edit MEMBER '43'
+                  edit SUBFSFAMILY '/pf043'
+                  task derived_param
+                endfamily
+                family 44
+                  edit EPSMEMBER '44'
+                  edit MEMBER '44'
+                  edit SUBFSFAMILY '/pf044'
+                  task derived_param
+                endfamily
+                family 45
+                  edit EPSMEMBER '45'
+                  edit MEMBER '45'
+                  edit SUBFSFAMILY '/pf045'
+                  task derived_param
+                endfamily
+                family 46
+                  edit EPSMEMBER '46'
+                  edit MEMBER '46'
+                  edit SUBFSFAMILY '/pf046'
+                  task derived_param
+                endfamily
+                family 47
+                  edit EPSMEMBER '47'
+                  edit MEMBER '47'
+                  edit SUBFSFAMILY '/pf047'
+                  task derived_param
+                endfamily
+                family 48
+                  edit EPSMEMBER '48'
+                  edit MEMBER '48'
+                  edit SUBFSFAMILY '/pf048'
+                  task derived_param
+                endfamily
+                family 49
+                  edit EPSMEMBER '49'
+                  edit MEMBER '49'
+                  edit SUBFSFAMILY '/pf049'
+                  task derived_param
+                endfamily
+                family 50
+                  edit EPSMEMBER '50'
+                  edit MEMBER '50'
+                  edit SUBFSFAMILY '/pf050'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family cf
+              trigger ../../fc/cf eq complete
+              edit EMOS_TYPE 'cf'
+              task derived_param
+                edit MEMBER 'off'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/00/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                trigger ../../../fc/pf/01 eq complete
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task derived_param
+              endfamily
+              family 02
+                trigger ../../../fc/pf/02 eq complete
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task derived_param
+              endfamily
+              family 03
+                trigger ../../../fc/pf/03 eq complete
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task derived_param
+              endfamily
+              family 04
+                trigger ../../../fc/pf/04 eq complete
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task derived_param
+              endfamily
+              family 05
+                trigger ../../../fc/pf/05 eq complete
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task derived_param
+              endfamily
+              family 06
+                trigger ../../../fc/pf/06 eq complete
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task derived_param
+              endfamily
+              family 07
+                trigger ../../../fc/pf/07 eq complete
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task derived_param
+              endfamily
+              family 08
+                trigger ../../../fc/pf/08 eq complete
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task derived_param
+              endfamily
+              family 09
+                trigger ../../../fc/pf/09 eq complete
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task derived_param
+              endfamily
+              family 10
+                trigger ../../../fc/pf/10 eq complete
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task derived_param
+              endfamily
+              family 11
+                trigger ../../../fc/pf/11 eq complete
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task derived_param
+              endfamily
+              family 12
+                trigger ../../../fc/pf/12 eq complete
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task derived_param
+              endfamily
+              family 13
+                trigger ../../../fc/pf/13 eq complete
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task derived_param
+              endfamily
+              family 14
+                trigger ../../../fc/pf/14 eq complete
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task derived_param
+              endfamily
+              family 15
+                trigger ../../../fc/pf/15 eq complete
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task derived_param
+              endfamily
+              family 16
+                trigger ../../../fc/pf/16 eq complete
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task derived_param
+              endfamily
+              family 17
+                trigger ../../../fc/pf/17 eq complete
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task derived_param
+              endfamily
+              family 18
+                trigger ../../../fc/pf/18 eq complete
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task derived_param
+              endfamily
+              family 19
+                trigger ../../../fc/pf/19 eq complete
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task derived_param
+              endfamily
+              family 20
+                trigger ../../../fc/pf/20 eq complete
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task derived_param
+              endfamily
+              family 21
+                trigger ../../../fc/pf/21 eq complete
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task derived_param
+              endfamily
+              family 22
+                trigger ../../../fc/pf/22 eq complete
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task derived_param
+              endfamily
+              family 23
+                trigger ../../../fc/pf/23 eq complete
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task derived_param
+              endfamily
+              family 24
+                trigger ../../../fc/pf/24 eq complete
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task derived_param
+              endfamily
+              family 25
+                trigger ../../../fc/pf/25 eq complete
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task derived_param
+              endfamily
+              family 26
+                trigger ../../../fc/pf/26 eq complete
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task derived_param
+              endfamily
+              family 27
+                trigger ../../../fc/pf/27 eq complete
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task derived_param
+              endfamily
+              family 28
+                trigger ../../../fc/pf/28 eq complete
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task derived_param
+              endfamily
+              family 29
+                trigger ../../../fc/pf/29 eq complete
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task derived_param
+              endfamily
+              family 30
+                trigger ../../../fc/pf/30 eq complete
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task derived_param
+              endfamily
+              family 31
+                trigger ../../../fc/pf/31 eq complete
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task derived_param
+              endfamily
+              family 32
+                trigger ../../../fc/pf/32 eq complete
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task derived_param
+              endfamily
+              family 33
+                trigger ../../../fc/pf/33 eq complete
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task derived_param
+              endfamily
+              family 34
+                trigger ../../../fc/pf/34 eq complete
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task derived_param
+              endfamily
+              family 35
+                trigger ../../../fc/pf/35 eq complete
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task derived_param
+              endfamily
+              family 36
+                trigger ../../../fc/pf/36 eq complete
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task derived_param
+              endfamily
+              family 37
+                trigger ../../../fc/pf/37 eq complete
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task derived_param
+              endfamily
+              family 38
+                trigger ../../../fc/pf/38 eq complete
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task derived_param
+              endfamily
+              family 39
+                trigger ../../../fc/pf/39 eq complete
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task derived_param
+              endfamily
+              family 40
+                trigger ../../../fc/pf/40 eq complete
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task derived_param
+              endfamily
+              family 41
+                trigger ../../../fc/pf/41 eq complete
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task derived_param
+              endfamily
+              family 42
+                trigger ../../../fc/pf/42 eq complete
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task derived_param
+              endfamily
+              family 43
+                trigger ../../../fc/pf/43 eq complete
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task derived_param
+              endfamily
+              family 44
+                trigger ../../../fc/pf/44 eq complete
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task derived_param
+              endfamily
+              family 45
+                trigger ../../../fc/pf/45 eq complete
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task derived_param
+              endfamily
+              family 46
+                trigger ../../../fc/pf/46 eq complete
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task derived_param
+              endfamily
+              family 47
+                trigger ../../../fc/pf/47 eq complete
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task derived_param
+              endfamily
+              family 48
+                trigger ../../../fc/pf/48 eq complete
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task derived_param
+              endfamily
+              family 49
+                trigger ../../../fc/pf/49 eq complete
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task derived_param
+              endfamily
+              family 50
+                trigger ../../../fc/pf/50 eq complete
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task derived_param
+              endfamily
+            endfamily
+          endfamily
+          family extra
+            trigger ./dp eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit STEPS '246:360:6'
+            inlimit /emc_36r1/limits:extra
+            family cf
+              edit EMOS_TYPE 'cf'
+              task extrafields
+                edit EPSFCRES '319'
+                edit FCLENGTH '360'
+                edit FCLENGTH0 '240'
+                edit RUNVARFC '1'
+            endfamily
+            family pf
+              complete /emc_36r1/main/ref/00/events:cf
+              edit EMOS_TYPE 'pf'
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 05
+                edit EPSMEMBER '5'
+                edit MEMBER '5'
+                edit SUBFSFAMILY '/pf005'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 06
+                edit EPSMEMBER '6'
+                edit MEMBER '6'
+                edit SUBFSFAMILY '/pf006'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 07
+                edit EPSMEMBER '7'
+                edit MEMBER '7'
+                edit SUBFSFAMILY '/pf007'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 08
+                edit EPSMEMBER '8'
+                edit MEMBER '8'
+                edit SUBFSFAMILY '/pf008'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 09
+                edit EPSMEMBER '9'
+                edit MEMBER '9'
+                edit SUBFSFAMILY '/pf009'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 10
+                edit EPSMEMBER '10'
+                edit MEMBER '10'
+                edit SUBFSFAMILY '/pf010'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 11
+                edit EPSMEMBER '11'
+                edit MEMBER '11'
+                edit SUBFSFAMILY '/pf011'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 12
+                edit EPSMEMBER '12'
+                edit MEMBER '12'
+                edit SUBFSFAMILY '/pf012'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 13
+                edit EPSMEMBER '13'
+                edit MEMBER '13'
+                edit SUBFSFAMILY '/pf013'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 14
+                edit EPSMEMBER '14'
+                edit MEMBER '14'
+                edit SUBFSFAMILY '/pf014'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 15
+                edit EPSMEMBER '15'
+                edit MEMBER '15'
+                edit SUBFSFAMILY '/pf015'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 16
+                edit EPSMEMBER '16'
+                edit MEMBER '16'
+                edit SUBFSFAMILY '/pf016'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 17
+                edit EPSMEMBER '17'
+                edit MEMBER '17'
+                edit SUBFSFAMILY '/pf017'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 18
+                edit EPSMEMBER '18'
+                edit MEMBER '18'
+                edit SUBFSFAMILY '/pf018'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 19
+                edit EPSMEMBER '19'
+                edit MEMBER '19'
+                edit SUBFSFAMILY '/pf019'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 20
+                edit EPSMEMBER '20'
+                edit MEMBER '20'
+                edit SUBFSFAMILY '/pf020'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 21
+                edit EPSMEMBER '21'
+                edit MEMBER '21'
+                edit SUBFSFAMILY '/pf021'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 22
+                edit EPSMEMBER '22'
+                edit MEMBER '22'
+                edit SUBFSFAMILY '/pf022'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 23
+                edit EPSMEMBER '23'
+                edit MEMBER '23'
+                edit SUBFSFAMILY '/pf023'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 24
+                edit EPSMEMBER '24'
+                edit MEMBER '24'
+                edit SUBFSFAMILY '/pf024'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 25
+                edit EPSMEMBER '25'
+                edit MEMBER '25'
+                edit SUBFSFAMILY '/pf025'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 26
+                edit EPSMEMBER '26'
+                edit MEMBER '26'
+                edit SUBFSFAMILY '/pf026'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 27
+                edit EPSMEMBER '27'
+                edit MEMBER '27'
+                edit SUBFSFAMILY '/pf027'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 28
+                edit EPSMEMBER '28'
+                edit MEMBER '28'
+                edit SUBFSFAMILY '/pf028'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 29
+                edit EPSMEMBER '29'
+                edit MEMBER '29'
+                edit SUBFSFAMILY '/pf029'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 30
+                edit EPSMEMBER '30'
+                edit MEMBER '30'
+                edit SUBFSFAMILY '/pf030'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 31
+                edit EPSMEMBER '31'
+                edit MEMBER '31'
+                edit SUBFSFAMILY '/pf031'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 32
+                edit EPSMEMBER '32'
+                edit MEMBER '32'
+                edit SUBFSFAMILY '/pf032'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 33
+                edit EPSMEMBER '33'
+                edit MEMBER '33'
+                edit SUBFSFAMILY '/pf033'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 34
+                edit EPSMEMBER '34'
+                edit MEMBER '34'
+                edit SUBFSFAMILY '/pf034'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 35
+                edit EPSMEMBER '35'
+                edit MEMBER '35'
+                edit SUBFSFAMILY '/pf035'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 36
+                edit EPSMEMBER '36'
+                edit MEMBER '36'
+                edit SUBFSFAMILY '/pf036'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 37
+                edit EPSMEMBER '37'
+                edit MEMBER '37'
+                edit SUBFSFAMILY '/pf037'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 38
+                edit EPSMEMBER '38'
+                edit MEMBER '38'
+                edit SUBFSFAMILY '/pf038'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 39
+                edit EPSMEMBER '39'
+                edit MEMBER '39'
+                edit SUBFSFAMILY '/pf039'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 40
+                edit EPSMEMBER '40'
+                edit MEMBER '40'
+                edit SUBFSFAMILY '/pf040'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 41
+                edit EPSMEMBER '41'
+                edit MEMBER '41'
+                edit SUBFSFAMILY '/pf041'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 42
+                edit EPSMEMBER '42'
+                edit MEMBER '42'
+                edit SUBFSFAMILY '/pf042'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 43
+                edit EPSMEMBER '43'
+                edit MEMBER '43'
+                edit SUBFSFAMILY '/pf043'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 44
+                edit EPSMEMBER '44'
+                edit MEMBER '44'
+                edit SUBFSFAMILY '/pf044'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 45
+                edit EPSMEMBER '45'
+                edit MEMBER '45'
+                edit SUBFSFAMILY '/pf045'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 46
+                edit EPSMEMBER '46'
+                edit MEMBER '46'
+                edit SUBFSFAMILY '/pf046'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 47
+                edit EPSMEMBER '47'
+                edit MEMBER '47'
+                edit SUBFSFAMILY '/pf047'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 48
+                edit EPSMEMBER '48'
+                edit MEMBER '48'
+                edit SUBFSFAMILY '/pf048'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 49
+                edit EPSMEMBER '49'
+                edit MEMBER '49'
+                edit SUBFSFAMILY '/pf049'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+              family 50
+                edit EPSMEMBER '50'
+                edit MEMBER '50'
+                edit SUBFSFAMILY '/pf050'
+                task extrafields
+                  edit EPSFCRES '319'
+                  edit FCLENGTH '360'
+                  edit FCLENGTH0 '240'
+                  edit RUNVARFC '1'
+              endfamily
+            endfamily
+          endfamily
+          family calibrate
+            complete /emc_36r1/main/ref/00/events:cf
+            trigger /emc_36r1/main/00/ref/an eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/calibrate'
+            family onws
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              inlimit /limits:linux_cluster
+              task feedupcal
+              task upcal
+                trigger feedupcal eq complete
+              task revertupcal
+            endfamily
+          endfamily
+          family efi
+            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
+            trigger /emc_36r1/main/00/legB/postproc/dp eq complete
+            edit HC_VERSION '0046'
+            edit HC_EXPVER '0046'
+            edit REF_VERSION '0046'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            edit NC_DAYS '31'
+            edit EPSLEG '2'
+            inlimit /emc_36r1/limits:efi
+            task stage
+              edit NC_DAYS '31'
+            family 240_336
+              trigger ./stage eq complete
+              edit ACC '96'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '336'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 168_336
+              trigger ./stage eq complete
+              edit ACC '168'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '336'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 012_036
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 036_060
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 060_084
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 084_108
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 108_132
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 120_144
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 120_168
+              trigger ./stage eq complete
+              edit ACC '48'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 168_240
+              trigger ./stage eq complete
+              edit ACC '72'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 000_168
+              trigger ./stage eq complete
+              edit ACC '168'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task extindex
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task extindex
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task extindex
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task extindex
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 000_024
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 024_048
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 048_072
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 072_096
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+            family 096_120
+              trigger ./stage eq complete
+              edit ACC '24'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task extindex
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task extindex
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task extindex
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task extindex
+              endfamily
+            endfamily
+          endfamily
+          task efi2fdb
+            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
+            trigger ./efi eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            inlimit /emc_36r1/main/ref:mutex
+            event none
+        endfamily
+        family prod
+          edit MEM '3000'
+          edit ACCOUNT 'oeenfopg'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'cp'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit USER_PRIORITY '90'
+          edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
+          edit SMSURL 'sub=fixed/'
+          inlimit /limits:prod
+          family eps
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            inlimit /emc_36r1/limits:prodeps
+            family 0246
+              edit EMOS_TIME_STEP_H '0246'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0252
+              edit EMOS_TIME_STEP_H '0252'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0258
+              edit EMOS_TIME_STEP_H '0258'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0264
+              edit EMOS_TIME_STEP_H '0264'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0270
+              edit EMOS_TIME_STEP_H '0270'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0276
+              edit EMOS_TIME_STEP_H '0276'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0282
+              edit EMOS_TIME_STEP_H '0282'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0288
+              edit EMOS_TIME_STEP_H '0288'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0294
+              edit EMOS_TIME_STEP_H '0294'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0300
+              edit EMOS_TIME_STEP_H '0300'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0306
+              edit EMOS_TIME_STEP_H '0306'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0312
+              edit EMOS_TIME_STEP_H '0312'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0318
+              edit EMOS_TIME_STEP_H '0318'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0324
+              edit EMOS_TIME_STEP_H '0324'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0330
+              edit EMOS_TIME_STEP_H '0330'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0336
+              edit EMOS_TIME_STEP_H '0336'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0342
+              edit EMOS_TIME_STEP_H '0342'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0348
+              edit EMOS_TIME_STEP_H '0348'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0354
+              edit EMOS_TIME_STEP_H '0354'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+            family 0360
+              edit EMOS_TIME_STEP_H '0360'
+              task prodgen
+                late -s +00:05 -c +00:15
+            endfamily
+          endfamily
+          family wave
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ( ../../legA/prod/getreq/bitmap:001 or ../../legA/prod/getreq/bitmap eq complete) and ../postproc/dp eq complete
+            edit PGNPES '2'
+            edit URL 'GWAEF/00'
+            inlimit /emc_36r1/limits:prodwave
+            family 0246
+              edit EMOS_TIME_STEP_H '0246'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0252
+              edit EMOS_TIME_STEP_H '0252'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0258
+              edit EMOS_TIME_STEP_H '0258'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0264
+              edit EMOS_TIME_STEP_H '0264'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0270
+              edit EMOS_TIME_STEP_H '0270'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0276
+              edit EMOS_TIME_STEP_H '0276'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0282
+              edit EMOS_TIME_STEP_H '0282'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0288
+              edit EMOS_TIME_STEP_H '0288'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0294
+              edit EMOS_TIME_STEP_H '0294'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0300
+              edit EMOS_TIME_STEP_H '0300'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0306
+              edit EMOS_TIME_STEP_H '0306'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0312
+              edit EMOS_TIME_STEP_H '0312'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0318
+              edit EMOS_TIME_STEP_H '0318'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0324
+              edit EMOS_TIME_STEP_H '0324'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0330
+              edit EMOS_TIME_STEP_H '0330'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0336
+              edit EMOS_TIME_STEP_H '0336'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0342
+              edit EMOS_TIME_STEP_H '0342'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0348
+              edit EMOS_TIME_STEP_H '0348'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0354
+              edit EMOS_TIME_STEP_H '0354'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+            family 0360
+              edit EMOS_TIME_STEP_H '0360'
+              task prodwave
+                late -s +00:05 -c +00:15
+                edit EMOS_STREAM 'WE'
+                edit EMOS_TYPE 'we'
+            endfamily
+          endfamily
+          task prod_wparam
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/eps eq complete) and ../postproc/dp eq complete and ../../legA/prod/prod_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TYPE 'wp'
+            edit EMOS_TIME_STEP_H '0360'
+            edit PGNPES '52'
+          task enfo_postproc
+            late -s +00:05 -c +00:15
+            trigger ../postproc/prob eq complete and ../postproc/ensms eq complete and ( ../../legA/prod/getreq/eps eq complete)
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'ep'
+            edit EMOS_TIME_STEP_H '0360'
+            edit PGNPES '21'
+          task waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ( ../../legA/prod/getreq/wave_eps:001 or ../../legA/prod/getreq/wave_eps eq complete) and ../postproc/prob eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TIME_STEP_H '0360'
+            edit PGNPES '1'
+        endfamily
+        family prod2diss
+          edit USER_PRIORITY '90'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/prod'
+          edit EMOS_DOMAIN 'G'
+          edit EMOS_TYPE 'ef'
+          edit EMOS_PROJECT '12'
+          edit PROD_TASK '1'
+          edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+          edit SMSURL 'GENFO/00'
+          family eps
+            family 0246
+              edit EMOS_TIME_STEP_H '0246'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0246/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../../../../legA/prod2diss/eps//0240/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0252
+              edit EMOS_TIME_STEP_H '0252'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0252/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0246/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0258
+              edit EMOS_TIME_STEP_H '0258'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0258/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0252/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0264
+              edit EMOS_TIME_STEP_H '0264'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0264/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0258/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0270
+              edit EMOS_TIME_STEP_H '0270'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0270/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0264/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0276
+              edit EMOS_TIME_STEP_H '0276'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0276/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0270/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0282
+              edit EMOS_TIME_STEP_H '0282'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0282/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0276/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0288
+              edit EMOS_TIME_STEP_H '0288'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0288/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0282/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0294
+              edit EMOS_TIME_STEP_H '0294'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0294/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0288/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0300
+              edit EMOS_TIME_STEP_H '0300'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0300/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0294/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0306
+              edit EMOS_TIME_STEP_H '0306'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0306/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0300/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0312
+              edit EMOS_TIME_STEP_H '0312'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0312/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0306/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0318
+              edit EMOS_TIME_STEP_H '0318'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0318/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0312/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0324
+              edit EMOS_TIME_STEP_H '0324'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0324/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0318/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0330
+              edit EMOS_TIME_STEP_H '0330'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0330/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0324/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0336
+              edit EMOS_TIME_STEP_H '0336'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0336/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0330/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0342
+              edit EMOS_TIME_STEP_H '0342'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0342/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0336/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0348
+              edit EMOS_TIME_STEP_H '0348'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0348/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0342/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0354
+              edit EMOS_TIME_STEP_H '0354'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0354/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0348/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            family 0360
+              edit EMOS_TIME_STEP_H '0360'
+              task pdb
+                late -s +00:05 -c +00:15
+                trigger ../../../prod/eps/0360/prodgen eq complete
+                inlimit /emc_36r1/limits:pdb
+                inlimit /limits:pdb
+                label info ""
+                event 1 
+              task q2diss
+                late -s +00:05 -c +00:15
+                trigger ./pdb eq complete and ( not ../../../../legA/prod2diss/operation_is_late:yes or ../0354/q2diss eq complete)
+                inlimit /emc_36r1/limits:q2diss
+                inlimit /limits:q2diss
+                label info ""
+                event 1 
+            endfamily
+            task check
+              trigger ./0360 eq complete
+          endfamily
+          family wave
+            edit EMOS_STREAM 'WE'
+            edit EMOS_TYPE 'we'
+            edit SMSURL 'GWAEF/00'
+            family 0246
+              trigger ../../prod/wave/0246/prodwave eq complete and ( ../../../legA/prod2diss/wave/0240 eq complete)
+              edit EMOS_TIME_STEP_H '0246'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0252
+              trigger ../../prod/wave/0252/prodwave eq complete and ( ./0246 eq complete)
+              edit EMOS_TIME_STEP_H '0252'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0258
+              trigger ../../prod/wave/0258/prodwave eq complete and ( ./0252 eq complete)
+              edit EMOS_TIME_STEP_H '0258'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0264
+              trigger ../../prod/wave/0264/prodwave eq complete and ( ./0258 eq complete)
+              edit EMOS_TIME_STEP_H '0264'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0270
+              trigger ../../prod/wave/0270/prodwave eq complete and ( ./0264 eq complete)
+              edit EMOS_TIME_STEP_H '0270'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0276
+              trigger ../../prod/wave/0276/prodwave eq complete and ( ./0270 eq complete)
+              edit EMOS_TIME_STEP_H '0276'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0282
+              trigger ../../prod/wave/0282/prodwave eq complete and ( ./0276 eq complete)
+              edit EMOS_TIME_STEP_H '0282'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0288
+              trigger ../../prod/wave/0288/prodwave eq complete and ( ./0282 eq complete)
+              edit EMOS_TIME_STEP_H '0288'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0294
+              trigger ../../prod/wave/0294/prodwave eq complete and ( ./0288 eq complete)
+              edit EMOS_TIME_STEP_H '0294'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0300
+              trigger ../../prod/wave/0300/prodwave eq complete and ( ./0294 eq complete)
+              edit EMOS_TIME_STEP_H '0300'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0306
+              trigger ../../prod/wave/0306/prodwave eq complete and ( ./0300 eq complete)
+              edit EMOS_TIME_STEP_H '0306'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0312
+              trigger ../../prod/wave/0312/prodwave eq complete and ( ./0306 eq complete)
+              edit EMOS_TIME_STEP_H '0312'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0318
+              trigger ../../prod/wave/0318/prodwave eq complete and ( ./0312 eq complete)
+              edit EMOS_TIME_STEP_H '0318'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0324
+              trigger ../../prod/wave/0324/prodwave eq complete and ( ./0318 eq complete)
+              edit EMOS_TIME_STEP_H '0324'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0330
+              trigger ../../prod/wave/0330/prodwave eq complete and ( ./0324 eq complete)
+              edit EMOS_TIME_STEP_H '0330'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0336
+              trigger ../../prod/wave/0336/prodwave eq complete and ( ./0330 eq complete)
+              edit EMOS_TIME_STEP_H '0336'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0342
+              trigger ../../prod/wave/0342/prodwave eq complete and ( ./0336 eq complete)
+              edit EMOS_TIME_STEP_H '0342'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0348
+              trigger ../../prod/wave/0348/prodwave eq complete and ( ./0342 eq complete)
+              edit EMOS_TIME_STEP_H '0348'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0354
+              trigger ../../prod/wave/0354/prodwave eq complete and ( ./0348 eq complete)
+              edit EMOS_TIME_STEP_H '0354'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            family 0360
+              trigger ../../prod/wave/0360/prodwave eq complete and ( ./0354 eq complete)
+              edit EMOS_TIME_STEP_H '0360'
+              task diss
+                late -s +00:05 -c +00:15
+                inlimit /emc_36r1/limits:w2diss
+                inlimit /limits:q2diss
+                label info ""
+                event pdb
+            endfamily
+            task check
+              trigger ./0360 eq complete
+          endfamily
+          task diss_wparam
+            late -s +00:05 -c +00:15
+            trigger ../prod/prod_wparam eq complete and ../../legA/prod2diss/diss_wparam eq complete
+            edit PROD_TASK 'w'
+            edit EMOS_TIME_STEP_H '0360'
+            edit EMOS_TYPE 'wp'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_waef_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/waef_postproc eq complete and ../../legA/prod2diss/diss_waef_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0360'
+            edit EMOS_TYPE 'pw'
+            edit EMOS_STREAM 'WE'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+          task diss_postproc
+            late -s +00:05 -c +00:15
+            trigger ../prod/enfo_postproc eq complete and ../../legA/prod2diss/diss_postproc eq complete
+            edit PROD_TASK 'p'
+            edit EMOS_TIME_STEP_H '0360'
+            edit EMOS_TYPE 'ep'
+            inlimit /emc_36r1/limits:q2diss
+            inlimit /limits:q2diss
+            label info ""
+            event pdb
+        endfamily
+      endfamily
+      family legBcpl
+        complete /emc_36r1/main/ref/00/events:240 or /emc_36r1/main/ref/00/events:360
+        trigger /emc_36r1/main/ref/00/events eq complete and /emc_36r1/main/ref/00/events:cpl and /emc_36r1/main/00/ref/oceini eq complete
+        edit EPSLEG '2'
+        edit EPSCOUPLE '1'
+        edit RUNCOUPLE '1'
+        edit OC_DELAY_START '0'
+        family fc
+          edit FCMEM '2240'
+          edit FCSTACK '700'
+          edit FCMRFS '0'
+          edit PRIORITY '71'
+          edit USER_PRIORITY '71'
+          edit N_PERT_AN '10'
+          edit SSTLEN '144'
+          edit EPSINISTEP_PREVIOUS '216'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          edit TSTEP '2700'
+          edit EPSFCRES '639'
+          edit RESOL '639'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+          edit CPUTIME '1000'
+          edit MEM '960'
+          edit THREADS '8'
+          edit NPES '8'
+          edit EPSLEG '2'
+          family pf
+            complete /emc_36r1/main/ref/00/events:cf
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTYPE 'pf'
+            edit EMOS_TYPE 'pf'
+            edit USER_PRIORITY '71'
+            edit PRIORITY '71'
+            edit FCNPES '32'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSFCRES '319'
+            edit EPSWAMRESOL 'global50'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit EPSINISTEP '360'
+            edit FCLENGTH '240'
+            edit TSTEP '1200'
+            edit EPSLEG '2'
+            edit CLASS 'od'
+            edit THREADS '2'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:pftotal
+            meter step -1 144 144
+            family 01
+              edit EPSMEMBER '1'
+              edit MEMBER '1'
+              edit SUBFSFAMILY '/pf001'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/01/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/01 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 02
+              edit EPSMEMBER '2'
+              edit MEMBER '2'
+              edit SUBFSFAMILY '/pf002'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/02/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/02 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 03
+              edit EPSMEMBER '3'
+              edit MEMBER '3'
+              edit SUBFSFAMILY '/pf003'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/03/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/03 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 04
+              edit EPSMEMBER '4'
+              edit MEMBER '4'
+              edit SUBFSFAMILY '/pf004'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/04/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/04 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 05
+              edit EPSMEMBER '5'
+              edit MEMBER '5'
+              edit SUBFSFAMILY '/pf005'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc1'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/05/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/05 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 06
+              edit EPSMEMBER '6'
+              edit MEMBER '6'
+              edit SUBFSFAMILY '/pf006'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc1'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/06/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/06 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 07
+              edit EPSMEMBER '7'
+              edit MEMBER '7'
+              edit SUBFSFAMILY '/pf007'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc1'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/07/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/07 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 08
+              edit EPSMEMBER '8'
+              edit MEMBER '8'
+              edit SUBFSFAMILY '/pf008'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc1'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/08/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/08 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 09
+              edit EPSMEMBER '9'
+              edit MEMBER '9'
+              edit SUBFSFAMILY '/pf009'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc1'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/09/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/09 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 10
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              edit SUBFSFAMILY '/pf010'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc2'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/10/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/10 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 11
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              edit SUBFSFAMILY '/pf011'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc2'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/11/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/11 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 12
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              edit SUBFSFAMILY '/pf012'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc2'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/12/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/12 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 13
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              edit SUBFSFAMILY '/pf013'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc2'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/13/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/13 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 14
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              edit SUBFSFAMILY '/pf014'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc2'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/14/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/14 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 15
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              edit SUBFSFAMILY '/pf015'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc3'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/15/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/15 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 16
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              edit SUBFSFAMILY '/pf016'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc3'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/16/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/16 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 17
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              edit SUBFSFAMILY '/pf017'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc3'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/17/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/17 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 18
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              edit SUBFSFAMILY '/pf018'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc3'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/18/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/18 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 19
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              edit SUBFSFAMILY '/pf019'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc3'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/19/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/19 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 20
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              edit SUBFSFAMILY '/pf020'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc4'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/20/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/20 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 21
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              edit SUBFSFAMILY '/pf021'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc4'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/21/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/21 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 22
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              edit SUBFSFAMILY '/pf022'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc4'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/22/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/22 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 23
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              edit SUBFSFAMILY '/pf023'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc4'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/23/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/23 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 24
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              edit SUBFSFAMILY '/pf024'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc4'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/24/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/24 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 25
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              edit SUBFSFAMILY '/pf025'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc5'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/25/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/25 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 26
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              edit SUBFSFAMILY '/pf026'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc5'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/26/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/26 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 27
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              edit SUBFSFAMILY '/pf027'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc5'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/27/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/27 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 28
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              edit SUBFSFAMILY '/pf028'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc5'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/28/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/28 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 29
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              edit SUBFSFAMILY '/pf029'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc5'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/29/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/29 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 30
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              edit SUBFSFAMILY '/pf030'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc6'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/30/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/30 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 31
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              edit SUBFSFAMILY '/pf031'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc6'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/31/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/31 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 32
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              edit SUBFSFAMILY '/pf032'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc6'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/32/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/32 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 33
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              edit SUBFSFAMILY '/pf033'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc6'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/33/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/33 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 34
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              edit SUBFSFAMILY '/pf034'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc6'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/34/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/34 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 35
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              edit SUBFSFAMILY '/pf035'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc7'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/35/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/35 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 36
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              edit SUBFSFAMILY '/pf036'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc7'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/36/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/36 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 37
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              edit SUBFSFAMILY '/pf037'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc7'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/37/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/37 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 38
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              edit SUBFSFAMILY '/pf038'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc7'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/38/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/38 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 39
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              edit SUBFSFAMILY '/pf039'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc7'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/39/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/39 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 40
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              edit SUBFSFAMILY '/pf040'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc8'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/40/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/40 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 41
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              edit SUBFSFAMILY '/pf041'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc8'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/41/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/41 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 42
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              edit SUBFSFAMILY '/pf042'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc8'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/42/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/42 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 43
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              edit SUBFSFAMILY '/pf043'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc8'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/43/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/43 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 44
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              edit SUBFSFAMILY '/pf044'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc8'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/44/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/44 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 45
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              edit SUBFSFAMILY '/pf045'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc9'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/45/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/45 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 46
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              edit SUBFSFAMILY '/pf046'
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc9'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/46/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/46 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 47
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              edit SUBFSFAMILY '/pf047'
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc9'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/47/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/47 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 48
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              edit SUBFSFAMILY '/pf048'
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc9'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/48/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/48 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 49
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              edit SUBFSFAMILY '/pf049'
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc9'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/49/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/49 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+            family 50
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              edit SUBFSFAMILY '/pf050'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc10'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger /emc_36r1/main/00/legA/fc/pf/50/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:modelepsB
+              endfamily
+              task getvarepsdata
+                trigger ../../../../legA/fc/pf/50 eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '144'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                edit SMSTRIES '1'
+                inlimit /emc_36r1/limits:modelepsB
+                meter step -1 144 144
+            endfamily
+          endfamily
+          family cf
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit MEMBER '0'
+            edit EPSMEMBER '0'
+            edit SUBFSFAMILY '/cf000'
+            edit EPSTYPE 'cf'
+            edit EMOS_TYPE 'cf'
+            edit USER_PRIORITY '72'
+            edit EPSNLEGS '3'
+            edit EPSFCLEV '62'
+            edit EPSWAMNSTPW '1'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSFCRES '319'
+            edit EPSWAMRESOL 'global50'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit EPSINISTEP '360'
+            edit TSTEP '1200'
+            edit EPSLEG '2'
+            edit CLASS 'od'
+            edit OCGROUP 'an0'
+            edit FCGROUP 'fc0'
+            edit FCCHUNK '1'
+            edit OCTOTAL '5'
+            edit FCTOTAL '51'
+            edit FCLENGTH '144'
+            edit FCLENGTH1 '216'
+            edit DAILY '0'
+            edit RUNVARFC '1'
+            family ocean
+              edit RUNACAN '0'
+              edit RUNVARFC '1'
+              edit RUNCOUPLE '0'
+              edit ACAN_LAG '-12'
+              edit EPSLEG '1'
+              task oceini
+                edit STREAM 'ocea'
+              task linkoce
+                trigger oceini eq complete
+              task addforce
+                trigger /emc_36r1/main/00/legA/fc/cf/modeleps eq complete
+              task runhope
+                trigger linkoce eq complete and addforce eq complete
+                edit FCLENGTH '216'
+                edit THREADS '16'
+                inlimit /emc_36r1/limits:modelepsB
+            endfamily
+            task getvarepsdata
+              trigger ../../../legA/fc/cf eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '2700'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSLEG '2'
+              edit EPSINISTEP '216'
+              edit EPSFCRES '639'
+              edit EPSFCRESN '319'
+              edit CLASS 'od'
+            task intHtoL
+              trigger getvarepsdata eq complete
+              edit MEM '1300'
+              edit MRF '10'
+              edit CPUTIME '1000'
+              edit STACK '450'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit TSTEP '2700'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '216'
+              edit EPSFCRES '319'
+              edit NPES '24'
+              edit FCNPES '24'
+              edit THREADS '2'
+              edit CLASS 'od'
+            task modeleps
+              trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSLEG '2'
+              edit EPSFCRES '319'
+              edit EPSINISTEP '360'
+              edit EPSINISTEP_PREVIOUS '216'
+              edit FCLENGTH '144'
+              edit EPSFCLENGTH_A '240'
+              edit MEM '3200'
+              edit MRF '10'
+              edit STACK '350'
+              edit FCCHUNK '1'
+              edit SMSTRIES '1'
+              edit NPES '1'
+              edit THREADS '64'
+              edit FCNPES '1'
+              edit TSTEP '2700'
+              edit CLASS 'od'
+              inlimit /emc_36r1/limits:modelepsB
+              meter step -1 144 144
+          endfamily
+          family reservation
+            trigger ./pf/46/intHtoL eq complete and ./pf/47/intHtoL eq complete and ./pf/48/intHtoL eq complete and ./pf/49/intHtoL eq complete and ./pf/50/intHtoL eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles'
+            inlimit /emc_36r1/limits:reservation
+            task reset_class
+              late -s +00:02 -c +00:02
+              edit RESERVATION_DEFINITION 'default'
+              label info ""
+            task reset_cpu
+              late -s +00:02 -c +00:02
+              complete /emc_36r1/main/ref/00/events:768
+              edit RESERVED_CPUS '0'
+              label info ""
+          endfamily
+        endfamily
+      endfamily
+      family legC
+        trigger /emc_36r1/main/ref/00/events eq complete and /emc_36r1/main/ref/00/events:768
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:35
+      trigger logfilestore eq complete and /emc_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete and /emc_36r1/main/ref/dummy eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+  family hc2
+    repeat date YMD 20091008 20121212 7
+    edit ACCOUNT 'oeenfo'
+    edit LOGTASK 'hc2'
+    edit QUEUE 'ns'
+    edit QUEUE_EPILOG 'ns'
+    edit ENSEMBLES '4'
+    edit ENS_SIZE '4'
+    edit RUNHINDCAST '1'
+    edit STREAM 'ENFH'
+    edit EMOS_STREAM 'ENFH'
+    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+    edit EMOS_BASE '00'
+    edit INICLASS 'EI'
+    edit INIEXPVER '0001'
+    edit INILEVELS '60'
+    edit DELETE_FAMILY 'true'
+    family back
+      trigger /emc_36r1/main/make eq complete
+      inlimit /emc_36r1/limits:hind
+      task stage_hc
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+      task rmfdb
+        trigger ./stage_hc eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+      task lock_fam
+        trigger 0 eq 1
+      task lock_1701
+        complete ./18 eq complete
+        trigger 0 eq 1
+      family 18
+        trigger ./rmfdb eq complete
+        edit DELTA_YEAR '-18'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                    edit SMSPASS 'stripped'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 17
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-17'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 16
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-16'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 15
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-15'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 14
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-14'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 13
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-13'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 12
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-12'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 11
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-11'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 10
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-10'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 09
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-09'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 08
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-08'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 07
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-07'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 06
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-06'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 05
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-05'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 04
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-04'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 03
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-03'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 02
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-02'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+      family 01
+        trigger ./lock_1701 eq complete and ./rmfdb eq complete
+        edit DELTA_YEAR '-01'
+        family m2
+          edit DELTA_DAY '-2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '3000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit FCNPES '16'
+          edit EPSSVTSTEP '900'
+          edit MEM '1600'
+          edit MRF '10'
+          edit NPES '16'
+          edit THREADS '4'
+          edit CPUTIME '12000'
+          edit STACK '350'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit CPUTIME '1000'
+            edit STACK '450'
+          task svsh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            edit MEMBER '0'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnhevo
+            trigger svnh eq complete
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit CPUTIME '120000'
+          task svshevo
+            trigger svsh eq complete
+            edit EVOLVE 'yes'
+          task svsave
+            trigger svshevo eq complete and svnhevo eq complete
+          task clean
+            trigger svnhevo eq complete and svshevo eq complete and svsave eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc'
+        endfamily
+        family sv
+          edit EVOLVE 'no'
+          edit FASTEX 'no'
+          edit EPSTYPE 'sv'
+          edit FCMEM '2000'
+          edit FCSTACK '400'
+          edit FCMRFS '100'
+          edit FCLENGTH '48'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          edit NPES '16'
+          edit EPSSVTSTEP '900'
+          task getini
+            edit LINIENDA '0'
+            edit INIDATEENDA '0'
+            edit EPSCOUPLE '0'
+            edit N_PERT_AN '10'
+            edit EPSCOUPL_A '0'
+            edit EPSCOUPL_B '0'
+            edit EPSCOUPL_C '0'
+          task inidata_sv
+            trigger getini eq complete
+            edit THREADS '8'
+          task targets
+            late -s +00:03 -c +00:10
+            edit EPSTCBB '1'
+            label da_info ""
+            label dcda_info ""
+            event sv
+          task svsh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '73'
+            inlimit /emc_36r1/limits:pesh 2
+          task svnh
+            trigger inidata_sv eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit THREADS '8'
+            edit USER_PRIORITY '74'
+            inlimit /emc_36r1/limits:pesh 2
+          task subspace
+            trigger svnh eq complete and svsh eq complete and ( targets eq complete or targets:sv)
+          task sv1
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '72'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv2
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            edit USER_PRIORITY '71'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv3
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv4
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv5
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task sv6
+            trigger ( targets eq complete or targets:sv) and subspace eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit CPUTIME '12000'
+            edit STACK '350'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit EPSSVDIAB 'true'
+            edit THREADS '8'
+            inlimit /emc_36r1/limits:pesh 2
+          task getsvevo
+            event ecfs
+          task getsvs
+            trigger getsvevo eq complete and svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and ../m2 eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit EPSTROP '1'
+          task svnhevo
+            trigger svnh eq complete and ../legA/fc eq complete
+            edit MEM '1600'
+            edit MRF '10'
+            edit NPES '16'
+            edit THREADS '4'
+            edit STACK '350'
+            edit HEMISPHERE 'n'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+          task svshevo
+            trigger svsh eq complete and ../legA/fc eq complete
+            edit NPES '24'
+            edit THREADS '8'
+            edit MEM '1300'
+            edit MRF '10'
+            edit STACK '450'
+            edit EVOLVE 'yes'
+            edit ANNPES '8'
+            edit CPUTIME '120000'
+            inlimit /emc_36r1/limits:pesh 2
+        endfamily
+        family legA
+          family fc
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '240'
+            edit EPSINISTEP_PREVIOUS '0'
+            edit EPSWAMNFRE '30'
+            edit EPSWAMNANG '24'
+            edit TSTEP '1200'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '1'
+            task getini
+              edit LINIENDA '0'
+              edit INIDATEENDA '0'
+              edit EPSCOUPLE '0'
+              edit N_PERT_AN '10'
+              edit EPSCOUPL_A '0'
+              edit EPSCOUPL_B '0'
+              edit EPSCOUPL_C '0'
+            task inidata
+              trigger getini eq complete
+              edit THREADS '8'
+            task getae
+              event 1 
+            task rot
+              trigger ../../sv/getsvs eq complete and ( getae:1 or getae eq complete)
+              edit EPSTROP '1'
+            family pert_ic
+              trigger rot eq complete and inidata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTROP '1'
+              inlimit /emc_36r1/limits:pertic
+              family 00
+                task pertinic
+                  edit MEMBER '0'
+              endfamily
+              family 01
+                task pertinic
+                  edit MEMBER '1'
+              endfamily
+              family 02
+                task pertinic
+                  edit MEMBER '2'
+              endfamily
+              family 03
+                task pertinic
+                  edit MEMBER '3'
+              endfamily
+              family 04
+                task pertinic
+                  edit MEMBER '4'
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+              event 1 
+            task wavini
+              edit FSFAMILY 'mc'
+              edit PERSST 'true'
+              edit SSTINT '1'
+            task wavfcdata
+              trigger ./getpersSST eq complete and ../../legA/fc/wavini eq complete
+              edit EPSCOUPLE '1'
+            task getpersSST
+              trigger ./inidata eq complete
+              edit EPSCOUPLE '1'
+              edit EPS_INI_STREAM 'DA'
+              edit EPSFCRES '639'
+            family pf
+              trigger ./getpersSST eq complete and ./wavfcdata eq complete and wavini eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              meter step -1 240 240
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                task getiniLeg
+                  trigger ../../pert_ic/01/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                task getiniLeg
+                  trigger ../../pert_ic/02/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                task getiniLeg
+                  trigger ../../pert_ic/03/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                task getiniLeg
+                  trigger ../../pert_ic/04/pertinic eq complete
+                  edit LINIENDA '0'
+                  edit INIDATEENDA '0'
+                  edit EPSCOUPLE '0'
+                  edit N_PERT_AN '10'
+                  edit EPSCOUPL_A '0'
+                  edit EPSCOUPL_B '0'
+                  edit EPSCOUPL_C '0'
+                task modeleps
+                  trigger getiniLeg eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '30'
+                  edit EPSWAMNANG '24'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '639'
+                  edit EPSINISTEP '216'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '240'
+                  edit TSTEP '1200'
+                  edit CLASS 'od'
+                  edit THREADS '4'
+                  inlimit /emc_36r1/limits:pesh 6
+                  meter step -1 240 240
+              endfamily
+            endfamily
+            family cf
+              trigger ./pert_ic/00/pertinic eq complete and ./getpersSST eq complete and ./wavfcdata eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSWAMRESOL 'global50'
+              edit EPSFCRES '639'
+              edit EPSWAMNFRE '30'
+              edit EPSWAMNANG '24'
+              edit EPSINISTEP '216'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '1'
+              edit CLASS 'od'
+              task getiniLeg
+                trigger ../inidata eq complete and ../wavini eq complete
+                edit LINIENDA '0'
+                edit INIDATEENDA '0'
+                edit EPSCOUPLE '0'
+                edit N_PERT_AN '10'
+                edit EPSCOUPL_A '0'
+                edit EPSCOUPL_B '0'
+                edit EPSCOUPL_C '0'
+              task modeleps
+                trigger getiniLeg eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSLEG '1'
+                edit EPSFCRES '639'
+                edit EPSINISTEP '216'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit FCLENGTH '240'
+                edit TSTEP '1200'
+                edit CLASS 'od'
+                edit FCNPES '32'
+                edit THREADS '4'
+                inlimit /emc_36r1/limits:pesh 6
+                meter step -1 240 240
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../fc eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:dp
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '0:240:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                task extrafields
+                  edit EPSFCRES '639'
+                  edit FCLENGTH '240'
+                  edit FCLENGTH0 '0'
+                  edit RUNVARFC '1'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task extrafields
+                    edit EPSFCRES '639'
+                    edit FCLENGTH '240'
+                    edit FCLENGTH0 '0'
+                    edit RUNVARFC '1'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family legBcpl
+          trigger ./legA eq complete
+          family fc
+            edit EPSCOUPLE '1'
+            edit FCMEM '2240'
+            edit FCSTACK '700'
+            edit FCMRFS '0'
+            edit PRIORITY '67'
+            edit USER_PRIORITY '67'
+            edit N_PERT_AN '10'
+            edit SSTLEN '144'
+            edit EPSINISTEP_PREVIOUS '216'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            edit TSTEP '2700'
+            edit EPSFCRES '639'
+            edit RESOL '639'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+            edit CPUTIME '1000'
+            edit MEM '960'
+            edit THREADS '8'
+            edit NPES '8'
+            edit EPSLEG '2'
+            family pf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit EPSTYPE 'pf'
+              edit EMOS_TYPE 'pf'
+              edit USER_PRIORITY '67'
+              edit PRIORITY '67'
+              edit FCNPES '32'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit FCLENGTH '240'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit THREADS '2'
+              edit RUNVARFC '1'
+              meter step -1 552 552
+              family 01
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                edit SUBFSFAMILY '/pf001'
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/01/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/01 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 02
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                edit SUBFSFAMILY '/pf002'
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/02/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/02 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 03
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                edit SUBFSFAMILY '/pf003'
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/03/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/03 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+              family 04
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                edit SUBFSFAMILY '/pf004'
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit FCLENGTH '144'
+                edit FCLENGTH1 '216'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                family ocean
+                  edit RUNACAN '0'
+                  edit RUNVARFC '1'
+                  edit RUNCOUPLE '0'
+                  edit ACAN_LAG '-12'
+                  edit EPSLEG '1'
+                  task oceini
+                    edit STREAM 'ocea'
+                  task linkoce
+                    trigger oceini eq complete
+                  task addforce
+                    trigger ../../../../../legA/fc/pf/04/modeleps eq complete
+                  task runhope
+                    trigger linkoce eq complete and addforce eq complete
+                    edit FCLENGTH '216'
+                    edit THREADS '16'
+                    inlimit /emc_36r1/limits:pesh
+                endfamily
+                task getvarepsdata
+                  trigger ../../../../legA/fc/pf/04 eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '639'
+                  edit EPSFCRESN '319'
+                  edit CLASS 'od'
+                task intHtoL
+                  trigger getvarepsdata eq complete
+                  edit MEM '1300'
+                  edit MRF '10'
+                  edit CPUTIME '1000'
+                  edit STACK '450'
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit EPSWAMRESOL 'global50'
+                  edit TSTEP '2700'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '319'
+                  edit NPES '24'
+                  edit FCNPES '24'
+                  edit THREADS '2'
+                  edit CLASS 'od'
+                task modeleps
+                  trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                  edit EPSNLEGS '3'
+                  edit EPSFCLEV '62'
+                  edit EPSWAMNSTPW '1'
+                  edit EPSWAMRESOL 'global50'
+                  edit EPSWAMNFRE '25'
+                  edit EPSWAMNANG '12'
+                  edit EPSLEG '2'
+                  edit EPSFCRES '319'
+                  edit EPSINISTEP '360'
+                  edit EPSINISTEP_PREVIOUS '216'
+                  edit FCLENGTH '552'
+                  edit EPSFCLENGTH_A '240'
+                  edit MEM '3200'
+                  edit MRF '10'
+                  edit STACK '350'
+                  edit FCCHUNK '1'
+                  edit NPES '1'
+                  edit THREADS '64'
+                  edit FCNPES '1'
+                  edit TSTEP '2700'
+                  edit CLASS 'od'
+                  edit SMSTRIES '1'
+                  inlimit /emc_36r1/limits:pesh
+                  meter step -1 552 552
+              endfamily
+            endfamily
+            family cf
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit MEMBER '0'
+              edit EPSMEMBER '0'
+              edit SUBFSFAMILY '/cf000'
+              edit EPSTYPE 'cf'
+              edit EMOS_TYPE 'cf'
+              edit USER_PRIORITY '78'
+              edit EPSNLEGS '3'
+              edit EPSFCLEV '62'
+              edit EPSWAMNSTPW '1'
+              edit EPSINISTEP_PREVIOUS '0'
+              edit EPSFCRES '319'
+              edit EPSWAMRESOL 'global50'
+              edit EPSWAMNFRE '25'
+              edit EPSWAMNANG '12'
+              edit EPSINISTEP '552'
+              edit TSTEP '1200'
+              edit EPSLEG '2'
+              edit CLASS 'od'
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit FCLENGTH '144'
+              edit FCLENGTH1 '216'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              family ocean
+                edit RUNACAN '0'
+                edit RUNVARFC '1'
+                edit RUNCOUPLE '0'
+                edit ACAN_LAG '-12'
+                edit EPSLEG '1'
+                task oceini
+                  edit STREAM 'ocea'
+                task linkoce
+                  trigger oceini eq complete
+                task addforce
+                  trigger ../../../../legA/fc/cf/modeleps eq complete
+                task runhope
+                  trigger linkoce eq complete and addforce eq complete
+                  edit FCLENGTH '216'
+                  edit THREADS '16'
+                  inlimit /emc_36r1/limits:pesh
+              endfamily
+              task getvarepsdata
+                trigger ../../../legA/fc/cf eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '639'
+                edit EPSFCRESN '319'
+                edit CLASS 'od'
+              task intHtoL
+                trigger getvarepsdata eq complete
+                edit MEM '1300'
+                edit MRF '10'
+                edit CPUTIME '1000'
+                edit STACK '450'
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSINISTEP_PREVIOUS '0'
+                edit EPSWAMRESOL 'global50'
+                edit TSTEP '2700'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSINISTEP '216'
+                edit EPSFCRES '319'
+                edit NPES '24'
+                edit FCNPES '24'
+                edit THREADS '2'
+                edit CLASS 'od'
+              task modeleps
+                trigger ./intHtoL eq complete and ./getvarepsdata eq complete and ./ocean eq complete
+                edit EPSNLEGS '3'
+                edit EPSFCLEV '62'
+                edit EPSWAMNSTPW '1'
+                edit EPSWAMRESOL 'global50'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSLEG '2'
+                edit EPSFCRES '319'
+                edit EPSINISTEP '360'
+                edit EPSINISTEP_PREVIOUS '216'
+                edit FCLENGTH '552'
+                edit EPSFCLENGTH_A '240'
+                edit MEM '3200'
+                edit MRF '10'
+                edit STACK '350'
+                edit FCCHUNK '1'
+                edit SMSTRIES '1'
+                edit NPES '1'
+                edit THREADS '64'
+                edit FCNPES '1'
+                edit TSTEP '2700'
+                edit CLASS 'od'
+                inlimit /emc_36r1/limits:pesh
+                meter step -1 552 552
+            endfamily
+          endfamily
+          family postproc
+            trigger ./fc eq complete
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              trigger ../../legA/postproc/dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:dp
+              family dp
+                trigger ./cf eq complete and ./pf eq complete
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+                edit OVERLAP '1'
+                edit STEPS '216:240:6'
+                inlimit /emc_36r1/limits:dp
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derived_param
+                    edit MEMBER 'off'
+                endfamily
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 01
+                    edit EPSMEMBER '1'
+                    edit MEMBER '1'
+                    edit SUBFSFAMILY '/pf001'
+                    task derived_param
+                  endfamily
+                  family 02
+                    edit EPSMEMBER '2'
+                    edit MEMBER '2'
+                    edit SUBFSFAMILY '/pf002'
+                    task derived_param
+                  endfamily
+                  family 03
+                    edit EPSMEMBER '3'
+                    edit MEMBER '3'
+                    edit SUBFSFAMILY '/pf003'
+                    task derived_param
+                  endfamily
+                  family 04
+                    edit EPSMEMBER '4'
+                    edit MEMBER '4'
+                    edit SUBFSFAMILY '/pf004'
+                    task derived_param
+                  endfamily
+                endfamily
+              endfamily
+              family cf
+                trigger ../../fc/cf eq complete
+                edit EMOS_TYPE 'cf'
+                task derived_param
+                  edit MEMBER 'off'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  trigger ../../../fc/pf/01 eq complete
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  task derived_param
+                endfamily
+                family 02
+                  trigger ../../../fc/pf/02 eq complete
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  task derived_param
+                endfamily
+                family 03
+                  trigger ../../../fc/pf/03 eq complete
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  task derived_param
+                endfamily
+                family 04
+                  trigger ../../../fc/pf/04 eq complete
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  task derived_param
+                endfamily
+              endfamily
+            endfamily
+            family extra
+              trigger ./dp eq complete
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/fc'
+              edit STEPS '246:768:6'
+              inlimit /emc_36r1/limits:extra
+              family cf
+                edit EMOS_TYPE 'cf'
+                edit EPSFCRES '319'
+                task extrafields
+                  edit FCLENGTH '768'
+                  edit FCLENGTH0 '240'
+                task wm_sfc
+                  trigger extrafields eq complete
+                  edit FCLENGTH '768'
+                task wm_ua
+                  trigger extrafields eq complete and wm_sfc eq complete
+                  edit FCLENGTH '768'
+              endfamily
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 01
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  edit SUBFSFAMILY '/pf001'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 02
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  edit SUBFSFAMILY '/pf002'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 03
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  edit SUBFSFAMILY '/pf003'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+                family 04
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  edit SUBFSFAMILY '/pf004'
+                  edit EPSFCRES '319'
+                  task extrafields
+                    edit FCLENGTH '768'
+                    edit FCLENGTH0 '240'
+                  task wm_sfc
+                    trigger extrafields eq complete
+                    edit FCLENGTH '768'
+                  task wm_ua
+                    trigger extrafields eq complete and wm_sfc eq complete
+                    edit FCLENGTH '768'
+                endfamily
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        task save_logs
+          trigger m2 eq complete and sv eq complete and legA eq complete and legBcpl eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit SCHOST 'localhost'
+      endfamily
+    endfamily
+    family arch
+      edit EMOS_TYPE 'an'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+      edit FSFAMILY 'mars'
+      edit OVERLAP '0'
+      edit YMD '20100114'
+      limit mutex 1
+      inlimit /emc_36r1/limits:mars
+      inlimit /limits:mars
+      family 18
+        trigger ( ../back/18 eq complete)
+        edit DELTA_YEAR '-18'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/18/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 17
+        trigger ( ../back/17 eq complete)
+        edit DELTA_YEAR '-17'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/17/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 16
+        trigger ( ../back/16 eq complete)
+        edit DELTA_YEAR '-16'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/16/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 15
+        trigger ( ../back/15 eq complete)
+        edit DELTA_YEAR '-15'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/15/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 14
+        trigger ( ../back/14 eq complete)
+        edit DELTA_YEAR '-14'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/14/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 13
+        trigger ( ../back/13 eq complete)
+        edit DELTA_YEAR '-13'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/13/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 12
+        trigger ( ../back/12 eq complete)
+        edit DELTA_YEAR '-12'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/12/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 11
+        trigger ( ../back/11 eq complete)
+        edit DELTA_YEAR '-11'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/11/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 10
+        trigger ( ../back/10 eq complete)
+        edit DELTA_YEAR '-10'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/10/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 09
+        trigger ( ../back/09 eq complete)
+        edit DELTA_YEAR '-09'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/09/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 08
+        trigger ( ../back/08 eq complete)
+        edit DELTA_YEAR '-08'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/08/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 07
+        trigger ( ../back/07 eq complete)
+        edit DELTA_YEAR '-07'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/07/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 06
+        trigger ( ../back/06 eq complete)
+        edit DELTA_YEAR '-06'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/06/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 05
+        trigger ( ../back/05 eq complete)
+        edit DELTA_YEAR '-05'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/05/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 04
+        trigger ( ../back/04 eq complete)
+        edit DELTA_YEAR '-04'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/04/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 03
+        trigger ( ../back/03 eq complete)
+        edit DELTA_YEAR '-03'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/03/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 02
+        trigger ( ../back/02 eq complete)
+        edit DELTA_YEAR '-02'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/02/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+      family 01
+        trigger ( ../back/01 eq complete)
+        edit DELTA_YEAR '-01'
+        family legA
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf144
+              edit STEPS '0/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/144/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '150/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf072
+              edit STEPS '0/to/072/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                edit STEPS '006/to/072/by/6'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '078/to/144/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit RUNVARFC '1'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '006/to/144/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legB
+          edit EPSLEG '2'
+          edit EPSWAMNFRE '25'
+          edit EPSWAMNANG '12'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                edit EMOS_TYPE 'pf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 240
+                  edit STEPS '216/222/228/234/240'
+                  edit OVERLAP '1'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 360
+                  edit STEPS '246/to/360/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '240/to/360'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            task cfml
+              edit STEPS '216'
+            family cf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family pf240
+              edit STEPS '216/228/240'
+              edit OVERLAP '1'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf300
+              edit STEPS '246/to/300/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf360
+              edit STEPS '306/to/360/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            task pfml
+              edit STEPS '360'
+            task accum
+              edit STEPS '240'
+              edit OVERLAP '1'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family coupled
+            edit EPSLEG '2'
+            edit OCLEG '2'
+            edit OCEPS '2'
+            edit FCCHUNK '1'
+            edit FCLENGTH '360'
+            edit FCLENGTH0 '216'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+        endfamily
+        family legC
+          edit EPSLEG '3'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit EMOS_TYPE 'an'
+          edit EPSFCRES '255'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family cf
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            edit EMOS_TYPE 'pf'
+            family cf408
+              edit STEPS '366/to/408/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf480
+              edit STEPS '414/to/480/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf600
+              edit STEPS '486/to/600/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf768
+              edit STEPS '606/to/768/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'ENWH'
+                edit EMOS_STREAM 'ENWH'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family postproc
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            edit FCCHUNK '1'
+            edit FCLENGTH '768'
+            inlimit /emc_36r1/limits:postproc
+            family dp
+              edit RUNVARFC '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              edit EMOS_TYPE 'pf'
+              edit STEPS '366/to/768/by/6'
+              family cf
+                edit EMOS_TYPE 'cf'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+                task extra_arc
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit STEPS '360/to/768'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family extra
+              trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
+              edit RUNVARFC '1'
+              task wm_sfc_arc
+                label files ""
+                label info ""
+                event fdb
+              task wm_ua_arc
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family nino
+              edit FCCHUNK '1'
+              edit OCTOTAL '5'
+              edit FCTOTAL '51'
+              edit DAILY '0'
+              edit RUNVARFC '1'
+              edit FCLENGTH1 '360'
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit FCLENGTH '768'
+              edit EPSCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              limit semaphore 10
+              inlimit /limits:linux_cluster
+              inlimit semaphore
+              family 00
+                edit OCGROUP 'an00'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '0'
+                edit MEMBER '0'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 01
+                edit OCGROUP 'an1'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '1'
+                edit MEMBER '1'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 02
+                edit OCGROUP 'an2'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '2'
+                edit MEMBER '2'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 03
+                edit OCGROUP 'an3'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '3'
+                edit MEMBER '3'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+              family 04
+                edit OCGROUP 'an4'
+                edit FCGROUP 'fc0'
+                edit EPSMEMBER '4'
+                edit MEMBER '4'
+                task nino_daily
+                task tcyc
+                  trigger nino_daily eq complete or nino_daily eq aborted
+              endfamily
+            endfamily
+            task tcyctoecfs
+              trigger nino eq complete
+              edit QUEUE 'emos-e'
+              edit QUEUE_EPILOG 'emos-exp'
+              edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+              edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit LOGDIR '/vol/emos_nc/output'
+              edit SMSOUT '/vol/emos_nc/output'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit EPSCOUPLE '1'
+              edit FCLENGTH '768'
+              inlimit /limits:linux_cluster
+          endfamily
+        endfamily
+        task hc_clean
+          trigger legA eq complete and legB eq complete and legC eq complete
+        task save_logs
+          trigger legA eq complete and legB eq complete and legC eq complete and hc_clean eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+      endfamily
+    endfamily
+    family efi
+      trigger ./back eq complete
+      edit MAXDAY '15'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+      inlimit /emc_36r1/limits:efih
+      family stage
+        edit RETRIEVE 'stage'
+        edit RF_NAME 'all'
+        task prep
+      endfamily
+      family op
+        trigger ./stage eq complete
+        family prep
+          family stage
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit ACC '24'
+            edit EFI_STEP1 '00'
+            edit EFI_STEP2 '24'
+            edit RETRIEVE 'stage'
+            inlimit /limits:linux_cluster
+            family all
+              edit RF_NAME 'all'
+              task prep
+            endfamily
+          endfamily
+          family d0105_24
+            edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
+            edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
+            edit ACC '24'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family d0610_24
+            edit EFI_STEP1 '108 120 132 144 168 192 216'
+            edit EFI_STEP2 '132 144 156 168 192 216 240'
+            edit ACC '24'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family nop
+        trigger ./stage eq complete
+        family prep
+          family stage
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit ACC '24'
+            edit EFI_STEP1 '00'
+            edit EFI_STEP2 '24'
+            edit RETRIEVE 'stage'
+            inlimit /limits:linux_cluster
+            family all
+              edit RF_NAME 'all'
+              task prep
+            endfamily
+          endfamily
+          family d0105_24
+            edit EFI_STEP1 '000 012 024 036 048 060 072 084 096'
+            edit EFI_STEP2 '024 036 048 060 072 084 096 108 120'
+            edit ACC '24'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+          family d0610_24
+            edit EFI_STEP1 '108 120 132 144 168 192 216'
+            edit EFI_STEP2 '132 144 156 168 192 216 240'
+            edit ACC '24'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+          family d1115_24
+            edit EFI_STEP1 '240 264 288 312 336'
+            edit EFI_STEP2 '264 288 312 336 360'
+            edit ACC '24'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+          family d0102_06
+            edit EFI_STEP1 '006 012 018 024 030 036 042 048'
+            edit EFI_STEP2 '006 012 018 024 030 036 042 048'
+            edit ACC '0'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+          family d0304_06
+            edit EFI_STEP1 '054 060 066 072 078 084 090 096'
+            edit EFI_STEP2 '054 060 066 072 078 084 090 096'
+            edit ACC '0'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+          family d0506_06
+            edit EFI_STEP1 '102 108 114 120 126 132 138 144'
+            edit EFI_STEP2 '102 108 114 120 126 132 138 144'
+            edit ACC '0'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+          family d0708_06
+            edit EFI_STEP1 '150 156 162 168 174 180 186 192'
+            edit EFI_STEP2 '150 156 162 168 174 180 186 192'
+            edit ACC '0'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+          family d0910_06
+            edit EFI_STEP1 '198 204 210 216 222 228 234 240'
+            edit EFI_STEP2 '198 204 210 216 222 228 234 240'
+            edit ACC '0'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+    family adm
+      task hindsync
+        trigger ../back eq complete and ../arch eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+        edit NH_WEEKS_KEPT '3'
+        edit BACKUP_HCFDB '0'
+      family fri
+        complete ./fri/compl eq complete and ./fri/dummy eq queued
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+        task dummy
+          cron -w 5 09:00
+        task compl
+          complete ./dummy eq active or ./dummy eq submitted
+          trigger 1 eq 0
+      endfamily
+      family 1to2
+        edit ORIG_FDB_ROOT 'undef'
+        edit DEST_FDB_ROOT 'undef'
+        edit SMSINCLUDE '/home/ma/emos/def/o/include'
+        family chver
+          repeat integer DELTA_YEAR -18 -1
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+          edit VERSION '9906'
+          edit VERSION_TO '9936'
+          edit CHVER_FDB_ROOT '/ma_fdb'
+          edit GENERAT '1'
+          edit CLEANER '0'
+          family enfh
+            edit CHVER_STREAM 'enfh'
+            family 0
+              edit CHVER_TYPE ':0000:[0:]:'
+              task chver
+                label info ""
+            endfamily
+            family 1
+              edit CHVER_TYPE ':0000:1:'
+              task chver
+                label info ""
+            endfamily
+            family 2
+              edit CHVER_TYPE ':0000:2:'
+              task chver
+                label info ""
+            endfamily
+            family 3
+              edit CHVER_TYPE ':0000:3:'
+              task chver
+                label info ""
+            endfamily
+            family 4
+              edit CHVER_TYPE ':0000:4:'
+              task chver
+                label info ""
+            endfamily
+          endfamily
+          family enwh
+            edit CHVER_STREAM 'enwh'
+            task chver
+              label info ""
+          endfamily
+          family efho
+            edit CHVER_STREAM 'efho'
+            task chver
+              label info ""
+          endfamily
+          family ewho
+            edit CHVER_STREAM 'ewho'
+            task chver
+              label info ""
+          endfamily
+          task save_logs
+            trigger enfh eq complete and enwh eq complete and efho eq complete and ewho eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1'
+            edit SCHOST 'localhost'
+        endfamily
+        family arch
+          trigger ./chver:DELTA_YEAR gt ./arch:DELTA_YEAR or ./chver eq complete
+          repeat integer DELTA_YEAR -18 -1
+          edit EMOS_TYPE 'an'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit VERSION '9936'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family legA
+            family cf
+              edit EMOS_TYPE 'cf'
+              edit NUMBER '0'
+              family cf144
+                edit STEPS '0/to/144/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  edit STEPS '006/to/144/by/6'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf240
+                edit STEPS '150/to/240/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family pf
+              edit EMOS_TYPE 'pf'
+              family pf072
+                edit STEPS '0/to/072/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  edit STEPS '006/to/072/by/6'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf144
+                edit STEPS '078/to/144/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf192
+                edit STEPS '150/to/192/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf240
+                edit STEPS '198/to/240/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfml
+                  edit STEPS '216'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family postproc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit RUNVARFC '1'
+              inlimit /emc_36r1/limits:postproc
+              family dp
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 144
+                    edit STEPS '006/to/144/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 240
+                    edit STEPS '150/to/240/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '0/to/240'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  family 144
+                    edit STEPS '006/to/144/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 240
+                    edit STEPS '150/to/240/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '0/to/240'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+              endfamily
+            endfamily
+            family coupled
+              trigger ./cf eq complete and ./pf eq complete
+              edit EPSLEG '1'
+              edit OCLEG '1'
+              edit OCEPS '1'
+              edit FCCHUNK '1'
+              edit FCLENGTH '240'
+              edit FCLENGTH0 '0'
+              edit OCEPSTOT '3'
+              edit FCTOTAL '51'
+              edit RUNVARFC '1'
+              edit EPSCOUPLE '1'
+              edit RUNCOUPLE '0'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              inlimit /emc_36r1/lag/ref/00:mutex
+              task preparcoce
+              task arcfc
+                trigger preparcoce eq complete
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family legB
+            edit EPSLEG '2'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            inlimit /emc_36r1/limits:mars
+            inlimit /limits:mars
+            family postproc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              inlimit /emc_36r1/limits:postproc
+              family dp
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 240
+                    edit STEPS '216/222/228/234/240'
+                    edit OVERLAP '1'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 360
+                    edit STEPS '246/to/360/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '240/to/360'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  family 240
+                    edit STEPS '216/222/228/234/240'
+                    edit OVERLAP '1'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 360
+                    edit STEPS '246/to/360/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '240/to/360'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+              endfamily
+            endfamily
+            family cf
+              edit EMOS_TYPE 'cf'
+              edit NUMBER '0'
+              task cfml
+                edit STEPS '216'
+              family cf240
+                edit STEPS '216/228/240'
+                edit OVERLAP '1'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf300
+                edit STEPS '246/to/300/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf360
+                edit STEPS '306/to/360/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task accum
+                edit STEPS '240'
+                edit OVERLAP '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf
+              edit EMOS_TYPE 'pf'
+              family pf240
+                edit STEPS '216/228/240'
+                edit OVERLAP '1'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf300
+                edit STEPS '246/to/300/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf360
+                edit STEPS '306/to/360/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task pfml
+                edit STEPS '360'
+              task accum
+                edit STEPS '240'
+                edit OVERLAP '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family coupled
+              edit EPSLEG '2'
+              edit OCLEG '2'
+              edit OCEPS '2'
+              edit FCCHUNK '1'
+              edit FCLENGTH '360'
+              edit FCLENGTH0 '216'
+              edit OCEPSTOT '3'
+              edit FCTOTAL '51'
+              edit RUNVARFC '1'
+              edit EPSCOUPLE '1'
+              edit RUNCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              inlimit /emc_36r1/lag/ref/00:mutex
+              task preparcoce
+              task arcfc
+                trigger preparcoce eq complete
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family legC
+            edit EPSLEG '3'
+            edit FSFAMILY 'mars'
+            edit OVERLAP '0'
+            edit EMOS_TYPE 'an'
+            edit EPSFCRES '255'
+            inlimit /emc_36r1/limits:mars
+            inlimit /limits:mars
+            family cf
+              edit EMOS_TYPE 'cf'
+              edit NUMBER '0'
+              family cf408
+                edit STEPS '366/to/408/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf480
+                edit STEPS '414/to/480/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf600
+                edit STEPS '486/to/600/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf768
+                edit STEPS '606/to/768/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family pf
+              edit EMOS_TYPE 'pf'
+              family cf408
+                edit STEPS '366/to/408/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf480
+                edit STEPS '414/to/480/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf600
+                edit STEPS '486/to/600/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf768
+                edit STEPS '606/to/768/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family postproc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit FCCHUNK '1'
+              edit FCLENGTH '768'
+              inlimit /emc_36r1/limits:postproc
+              family dp
+                trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+                edit RUNVARFC '1'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+                edit EMOS_TYPE 'pf'
+                edit STEPS '366/to/768/by/6'
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                  task extra_arc
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit STEPS '360/to/768'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family pf
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                  task extra_arc
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit STEPS '360/to/768'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+              endfamily
+              family extra
+                trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
+                edit RUNVARFC '1'
+                task wm_sfc_arc
+                  label files ""
+                  label info ""
+                  event fdb
+                task wm_ua_arc
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family nino
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                edit FCLENGTH1 '360'
+                edit QUEUE 'emos-e'
+                edit QUEUE_EPILOG 'emos-exp'
+                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                edit LOGDIR '/vol/emos_nc/output'
+                edit SMSOUT '/vol/emos_nc/output'
+                edit FCLENGTH '768'
+                edit EPSCOUPLE '1'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                limit semaphore 10
+                inlimit /limits:linux_cluster
+                inlimit semaphore
+                family 00
+                  edit OCGROUP 'an00'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '0'
+                  edit MEMBER '0'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 01
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 02
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 03
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 04
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+              endfamily
+              task tcyctoecfs
+                trigger nino eq complete
+                edit QUEUE 'emos-e'
+                edit QUEUE_EPILOG 'emos-exp'
+                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                edit LOGDIR '/vol/emos_nc/output'
+                edit SMSOUT '/vol/emos_nc/output'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                edit EPSCOUPLE '1'
+                edit FCLENGTH '768'
+                inlimit /limits:linux_cluster
+            endfamily
+          endfamily
+          task save_logs
+            trigger legA eq complete and legB eq complete and legC eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1'
+            edit SCHOST 'localhost'
+        endfamily
+        family clean
+          task chver
+            trigger ../arch eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            edit GENERAT '0'
+            edit CLEANER '1'
+        endfamily
+      endfamily
+      family eto1
+        trigger ./1to2 eq complete
+        edit ORIG_FDB_ROOT 'undef'
+        edit DEST_FDB_ROOT 'undef'
+        family chver
+          repeat integer DELTA_YEAR -18 -1
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+          edit VERSION '0046'
+          edit VERSION_TO '9906'
+          edit CHVER_FDB_ROOT '/ma_fdb'
+          edit GENERAT '1'
+          edit CLEANER '0'
+          family enfh
+            edit CHVER_STREAM 'enfh'
+            family 0
+              edit CHVER_TYPE ':0000:[0:]:'
+              task chver
+                label info ""
+            endfamily
+            family 1
+              edit CHVER_TYPE ':0000:1:'
+              task chver
+                label info ""
+            endfamily
+            family 2
+              edit CHVER_TYPE ':0000:2:'
+              task chver
+                label info ""
+            endfamily
+            family 3
+              edit CHVER_TYPE ':0000:3:'
+              task chver
+                label info ""
+            endfamily
+            family 4
+              edit CHVER_TYPE ':0000:4:'
+              task chver
+                label info ""
+            endfamily
+          endfamily
+          family enwh
+            edit CHVER_STREAM 'enwh'
+            task chver
+              label info ""
+          endfamily
+          family efho
+            edit CHVER_STREAM 'efho'
+            task chver
+              label info ""
+          endfamily
+          family ewho
+            edit CHVER_STREAM 'ewho'
+            task chver
+              label info ""
+          endfamily
+          task save_logs
+            trigger enfh eq complete and enwh eq complete and efho eq complete and ewho eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1'
+            edit SCHOST 'localhost'
+        endfamily
+        family arch
+          trigger ./chver:DELTA_YEAR gt ./arch:DELTA_YEAR or ./chver eq complete
+          repeat integer DELTA_YEAR -18 -1
+          edit EMOS_TYPE 'an'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          edit FSFAMILY 'mars'
+          edit OVERLAP '0'
+          edit VERSION '9906'
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family legA
+            family cf
+              edit EMOS_TYPE 'cf'
+              edit NUMBER '0'
+              family cf144
+                edit STEPS '0/to/144/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  edit STEPS '006/to/144/by/6'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf240
+                edit STEPS '150/to/240/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family pf
+              edit EMOS_TYPE 'pf'
+              family pf072
+                edit STEPS '0/to/072/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  edit STEPS '006/to/072/by/6'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf144
+                edit STEPS '078/to/144/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf192
+                edit STEPS '150/to/192/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf240
+                edit STEPS '198/to/240/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfml
+                  edit STEPS '216'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family postproc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit RUNVARFC '1'
+              inlimit /emc_36r1/limits:postproc
+              family dp
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 144
+                    edit STEPS '006/to/144/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 240
+                    edit STEPS '150/to/240/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '0/to/240'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  family 144
+                    edit STEPS '006/to/144/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 240
+                    edit STEPS '150/to/240/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '0/to/240'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+              endfamily
+            endfamily
+            family coupled
+              trigger ./cf eq complete and ./pf eq complete
+              edit EPSLEG '1'
+              edit OCLEG '1'
+              edit OCEPS '1'
+              edit FCCHUNK '1'
+              edit FCLENGTH '240'
+              edit FCLENGTH0 '0'
+              edit OCEPSTOT '3'
+              edit FCTOTAL '51'
+              edit RUNVARFC '1'
+              edit EPSCOUPLE '1'
+              edit RUNCOUPLE '0'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              inlimit /emc_36r1/lag/ref/00:mutex
+              task preparcoce
+              task arcfc
+                trigger preparcoce eq complete
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family legB
+            edit EPSLEG '2'
+            edit EPSWAMNFRE '25'
+            edit EPSWAMNANG '12'
+            inlimit /emc_36r1/limits:mars
+            inlimit /limits:mars
+            family postproc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              inlimit /emc_36r1/limits:postproc
+              family dp
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+                family pf
+                  edit EMOS_TYPE 'pf'
+                  family 240
+                    edit STEPS '216/222/228/234/240'
+                    edit OVERLAP '1'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 360
+                    edit STEPS '246/to/360/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '240/to/360'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  family 240
+                    edit STEPS '216/222/228/234/240'
+                    edit OVERLAP '1'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  family 360
+                    edit STEPS '246/to/360/by/6'
+                    task derivedp
+                      label files ""
+                      label info ""
+                      event fdb
+                  endfamily
+                  task extra_arc
+                    edit STEPS '240/to/360'
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit RUNVARFC '1'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+              endfamily
+            endfamily
+            family cf
+              edit EMOS_TYPE 'cf'
+              edit NUMBER '0'
+              task cfml
+                edit STEPS '216'
+              family cf240
+                edit STEPS '216/228/240'
+                edit OVERLAP '1'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf300
+                edit STEPS '246/to/300/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf360
+                edit STEPS '306/to/360/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task accum
+                edit STEPS '240'
+                edit OVERLAP '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf
+              edit EMOS_TYPE 'pf'
+              family pf240
+                edit STEPS '216/228/240'
+                edit OVERLAP '1'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf300
+                edit STEPS '246/to/300/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf360
+                edit STEPS '306/to/360/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task pfml
+                edit STEPS '360'
+              task accum
+                edit STEPS '240'
+                edit OVERLAP '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family coupled
+              edit EPSLEG '2'
+              edit OCLEG '2'
+              edit OCEPS '2'
+              edit FCCHUNK '1'
+              edit FCLENGTH '360'
+              edit FCLENGTH0 '216'
+              edit OCEPSTOT '3'
+              edit FCTOTAL '51'
+              edit RUNVARFC '1'
+              edit EPSCOUPLE '1'
+              edit RUNCOUPLE '1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              inlimit /emc_36r1/lag/ref/00:mutex
+              task preparcoce
+              task arcfc
+                trigger preparcoce eq complete
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family legC
+            edit EPSLEG '3'
+            edit FSFAMILY 'mars'
+            edit OVERLAP '0'
+            edit EMOS_TYPE 'an'
+            edit EPSFCRES '255'
+            inlimit /emc_36r1/limits:mars
+            inlimit /limits:mars
+            family cf
+              edit EMOS_TYPE 'cf'
+              edit NUMBER '0'
+              family cf408
+                edit STEPS '366/to/408/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf480
+                edit STEPS '414/to/480/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf600
+                edit STEPS '486/to/600/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf768
+                edit STEPS '606/to/768/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family pf
+              edit EMOS_TYPE 'pf'
+              family cf408
+                edit STEPS '366/to/408/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf480
+                edit STEPS '414/to/480/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf600
+                edit STEPS '486/to/600/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family pf768
+                edit STEPS '606/to/768/by/6'
+                task pfpl
+                  inlimit /emc_36r1/limits:pl
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfsfc
+                  trigger ../../postproc/dp eq complete
+                  inlimit /emc_36r1/limits:sfc
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfil
+                  label files ""
+                  label info ""
+                  event fdb
+                task pfwv
+                  edit STREAM 'ENWH'
+                  edit EMOS_STREAM 'ENWH'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family postproc
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+              edit FCCHUNK '1'
+              edit FCLENGTH '768'
+              inlimit /emc_36r1/limits:postproc
+              family dp
+                trigger /emc_36r1/00/legC/postproc/dp eq complete and /emc_36r1/00/legC/postproc/extra eq complete
+                edit RUNVARFC '1'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+                edit EMOS_TYPE 'pf'
+                edit STEPS '366/to/768/by/6'
+                family cf
+                  edit EMOS_TYPE 'cf'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                  task extra_arc
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit STEPS '360/to/768'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family pf
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                  task extra_arc
+                    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                    edit STEPS '360/to/768'
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+              endfamily
+              family extra
+                trigger /emc_36r1/hc2/back/01/legBcpl/postproc/extra eq complete
+                edit RUNVARFC '1'
+                task wm_sfc_arc
+                  label files ""
+                  label info ""
+                  event fdb
+                task wm_ua_arc
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family nino
+                edit FCCHUNK '1'
+                edit OCTOTAL '5'
+                edit FCTOTAL '51'
+                edit DAILY '0'
+                edit RUNVARFC '1'
+                edit FCLENGTH1 '360'
+                edit QUEUE 'emos-e'
+                edit QUEUE_EPILOG 'emos-exp'
+                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                edit LOGDIR '/vol/emos_nc/output'
+                edit SMSOUT '/vol/emos_nc/output'
+                edit FCLENGTH '768'
+                edit EPSCOUPLE '1'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                limit semaphore 10
+                inlimit /limits:linux_cluster
+                inlimit semaphore
+                family 00
+                  edit OCGROUP 'an00'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '0'
+                  edit MEMBER '0'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 01
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '1'
+                  edit MEMBER '1'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 02
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '2'
+                  edit MEMBER '2'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 03
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '3'
+                  edit MEMBER '3'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+                family 04
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc0'
+                  edit EPSMEMBER '4'
+                  edit MEMBER '4'
+                  task nino_daily
+                  task tcyc
+                    trigger nino_daily eq complete or nino_daily eq aborted
+                endfamily
+              endfamily
+              task tcyctoecfs
+                trigger nino eq complete
+                edit QUEUE 'emos-e'
+                edit QUEUE_EPILOG 'emos-exp'
+                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                edit LOGDIR '/vol/emos_nc/output'
+                edit SMSOUT '/vol/emos_nc/output'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                edit EPSCOUPLE '1'
+                edit FCLENGTH '768'
+                inlimit /limits:linux_cluster
+            endfamily
+          endfamily
+          task save_logs
+            trigger legA eq complete and legB eq complete and legC eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1'
+            edit SCHOST 'localhost'
+        endfamily
+        family clean
+          task chver
+            trigger ../arch eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            edit GENERAT '0'
+            edit CLEANER '1'
+        endfamily
+      endfamily
+    endfamily
+    task stage_pp
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      late -s +00:05 -c +00:25
+      trigger logfilestore eq complete and back eq complete and arch eq complete and efi eq complete and adm eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+  family lag
+    repeat date YMD 20091003 20121212 1
+    edit EMOS_TYPE 'an'
+    edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+    edit FSFAMILY 'mars'
+    edit OVERLAP '0'
+    edit LOGTASK 'lag'
+    edit MARS_DB 'marsod'
+    family ref
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+      family 12
+        edit EMOS_BASE '12'
+        limit mutex 1
+        task events
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+          edit HINDCAST '1'
+          edit ONLY_CF '0'
+          event noefi
+          event 240 
+          event 360 
+          event cpl
+          event 768 
+          event cf
+      endfamily
+      family 00
+        edit DELTA_DAY '1'
+        edit EMOS_BASE '00'
+        limit mutex 1
+        task events
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+          edit HINDCAST '1'
+          edit ONLY_CF '0'
+          event noefi
+          event 240 
+          event 360 
+          event cpl
+          event 768 
+          event cf
+      endfamily
+      task smove
+        trigger /emc_36r1/lag/12 eq complete
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/system'
+      family loop
+        task dummy
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit WSHOST 'localhost'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          time 12:45
+      endfamily
+      family warn
+        trigger ./loop eq complete
+        task dummy
+          complete /emc_36r1/lag/logfiles eq complete
+          time 16:00
+      endfamily
+      task checkarchive
+        trigger /emc_36r1/main/make eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1'
+        edit FSFAMILY 'mars'
+        edit EMOS_TYPE 'an'
+        edit OSTREAM 'WEOV EFOV'
+        edit HSTREAM 'EFHO EFHS ENFH ENWH EWHO'
+        inlimit /limits:linux_cluster
+        label info "none"
+    endfamily
+    family 12
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD)
+      edit DELTA_DAY '0'
+      edit EMOS_BASE '12'
+      family legA
+        trigger /emc_36r1/lag/ref/12/events eq complete
+        edit EPSWAMNFRE '30'
+        edit EPSWAMNANG '24'
+        family init
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/ref/an eq complete)
+          edit FSFAMILY 'mc'
+          task rmfdb
+        endfamily
+        family tc
+          complete /emc_36r1/lag/ref/12/events:cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/postproc/tc eq complete)
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          edit FSFAMILY 'mc'
+          task clean
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
+          task to_ecfs
+            label files ""
+            label info ""
+            event fdb
+          task to_mars
+            trigger to_ecfs eq complete
+        endfamily
+        family archive
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/postproc eq complete) and /emc_36r1/lag/ref/12/events eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                complete /emc_36r1/lag/ref/12/events:cf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '0/to/144/by/3'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '0/to/144/by/3'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family cluster
+              complete /emc_36r1/lag/ref/12/events:cf
+              edit STEPS '72/84/96/108/120/132/144/156/168'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family a
+                edit DOMAIN 'a'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family b
+                trigger ./a eq complete
+                edit DOMAIN 'b'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family c
+                trigger ./b eq complete
+                edit DOMAIN 'c'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family d
+                trigger ./c eq complete
+                edit DOMAIN 'd'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family e
+                trigger ./d eq complete
+                edit DOMAIN 'e'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family ensms
+              complete /emc_36r1/lag/ref/12/events:cf
+              edit STEPS '3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+              task mean
+                edit TYPE 'em'
+                label files ""
+                label info ""
+                event fdb
+              task stdev
+                edit TYPE 'es'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family prob
+              complete /emc_36r1/lag/ref/12/events:cf
+              family 2t
+                edit PARAM '2t'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family swp_mwp
+                edit PARAM 'swp_mwp'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family 10fg
+                edit PARAM '10fg'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family ff
+                edit PARAM 'ff'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family rain
+                edit PARAM 'rain'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family t850
+                edit PARAM 't850'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family efi
+              complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/postproc eq complete)
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family 2t
+                edit RF_NAME '2t'
+                task efi
+                  label info ""
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task efi
+                  label info ""
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task efi
+                  label info ""
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task efi
+                  label info ""
+              endfamily
+            endfamily
+          endfamily
+          family cf
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc/cf eq complete)
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf036
+              edit STEPS '0/to/36/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf072
+              edit STEPS '39/to/72/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf108
+              edit STEPS '075/to/108/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf144
+              edit STEPS '111/to/144/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf180
+              edit STEPS '150/to/180/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '186/to/240/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family cv
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc/cv eq complete)
+            edit EMOS_TYPE 'cv'
+            edit NUMBER '1/2'
+            family cv036
+              edit STEPS '0/to/036/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv072
+              edit STEPS '039/to/072/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv108
+              edit STEPS '075/to/108/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv144
+              edit STEPS '111/to/144/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv180
+              edit STEPS '150/to/180/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv240
+              edit STEPS '186/to/240/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv300
+              edit STEPS '246/to/300/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv360
+              edit STEPS '306/to/360/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            complete /emc_36r1/lag/ref/12/events:cf
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/lag/ref/12/events eq complete)
+            edit EMOS_TYPE 'pf'
+            family pf024
+              edit STEPS '0/to/024/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf048
+              edit STEPS '027/to/048/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf072
+              edit STEPS '051/to/072/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf096
+              edit STEPS '075/to/096/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf120
+              edit STEPS '099/to/120/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '123/to/144/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family icp
+            complete /emc_36r1/lag/ref/12/events:cf
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc eq complete)
+            edit ARCHTYPE 'icp'
+            task ml
+              edit FCLENGTH '240'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          task flush
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legA/fc eq complete)
+            edit STREAM 'enfo'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family ecfs
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/sv eq complete and /emc_36r1/main/12/legA/fc eq complete)
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit FSFAMILY 'mc'
+          task svsave
+          task save
+        endfamily
+      endfamily
+      family legB
+        complete /emc_36r1/lag/ref/12/events:240
+        edit EPSLEG '2'
+        edit EPSWAMNFRE '25'
+        edit EPSWAMNANG '12'
+        inlimit /emc_36r1/limits:mars
+        inlimit /limits:mars
+        family postproc
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legB/postproc eq complete) and /emc_36r1/lag/ref/12/events eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+          inlimit /emc_36r1/limits:postproc
+          family ensms
+            complete /emc_36r1/lag/ref/12/events:cf
+            family 360
+              edit STEPS '246/to/360/by/6'
+              task mean
+                edit TYPE 'em'
+                label files ""
+                label info ""
+                event fdb
+              task stdev
+                edit TYPE 'es'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family prob
+            complete /emc_36r1/lag/ref/12/events:cf
+            family 2t
+              edit PARAM '2t'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family swp_mwp
+              edit PARAM 'swp_mwp'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family 10fg
+              edit PARAM '10fg'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family ff
+              edit PARAM 'ff'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family rain
+              edit PARAM 'rain'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family t850
+              edit PARAM 't850'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family dp
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+            family pf
+              complete /emc_36r1/lag/ref/12/events:cf
+              edit EMOS_TYPE 'pf'
+              family 240
+                edit STEPS '216/222/228/234/240'
+                edit OVERLAP '1'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family 360
+                edit STEPS '246/to/360/by/6'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task extra_arc
+                edit STEPS '240/to/360'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                edit RUNVARFC '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf
+              edit EMOS_TYPE 'cf'
+              family 240
+                edit STEPS '216/222/228/234/240'
+                edit OVERLAP '1'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family 360
+                edit STEPS '246/to/360/by/6'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task extra_arc
+                edit STEPS '240/to/360'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                edit RUNVARFC '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family efi
+            complete ( /emc_36r1/main/ref/12/events:cf) or ( /emc_36r1/main/ref/12/events:noefi)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+        endfamily
+        family cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legB/fc/cf eq complete)
+          edit EMOS_TYPE 'cf'
+          edit NUMBER '0'
+          family cf240
+            edit STEPS '216/228/240'
+            edit OVERLAP '1'
+            task cfml
+              label files ""
+              label info ""
+              event fdb
+            task cfpl
+              label files ""
+              label info ""
+              event fdb
+            task cfsfc
+              label files ""
+              label info ""
+              event fdb
+            task cfil
+              label files ""
+              label info ""
+              event fdb
+            task cfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family cf300
+            edit STEPS '246/to/300/by/6'
+            task cfml
+              label files ""
+              label info ""
+              event fdb
+            task cfpl
+              label files ""
+              label info ""
+              event fdb
+            task cfsfc
+              label files ""
+              label info ""
+              event fdb
+            task cfil
+              label files ""
+              label info ""
+              event fdb
+            task cfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family cf360
+            edit STEPS '306/to/360/by/6'
+            task cfml
+              label files ""
+              label info ""
+              event fdb
+            task cfpl
+              label files ""
+              label info ""
+              event fdb
+            task cfsfc
+              label files ""
+              label info ""
+              event fdb
+            task cfil
+              label files ""
+              label info ""
+              event fdb
+            task cfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          task accum
+            edit STEPS '240'
+            edit OVERLAP '1'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family pf
+          complete /emc_36r1/lag/ref/12/events:cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/12/legB/fc/pf eq complete and /emc_36r1/lag/ref/12/events eq complete)
+          edit EMOS_TYPE 'pf'
+          family pf240
+            edit STEPS '216/228/240'
+            edit OVERLAP '1'
+            task pfpl
+              inlimit /emc_36r1/limits:pl
+              label files ""
+              label info ""
+              event fdb
+            task pfsfc
+              trigger ../../postproc/dp eq complete
+              inlimit /emc_36r1/limits:sfc
+              label files ""
+              label info ""
+              event fdb
+            task pfil
+              label files ""
+              label info ""
+              event fdb
+            task pfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf300
+            edit STEPS '246/to/300/by/6'
+            task pfpl
+              inlimit /emc_36r1/limits:pl
+              label files ""
+              label info ""
+              event fdb
+            task pfsfc
+              trigger ../../postproc/dp eq complete
+              inlimit /emc_36r1/limits:sfc
+              label files ""
+              label info ""
+              event fdb
+            task pfil
+              label files ""
+              label info ""
+              event fdb
+            task pfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf360
+            edit STEPS '306/to/360/by/6'
+            task pfpl
+              inlimit /emc_36r1/limits:pl
+              label files ""
+              label info ""
+              event fdb
+            task pfsfc
+              trigger ../../postproc/dp eq complete
+              inlimit /emc_36r1/limits:sfc
+              label files ""
+              label info ""
+              event fdb
+            task pfil
+              label files ""
+              label info ""
+              event fdb
+            task pfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          task pfml
+            edit STEPS '360'
+          task accum
+            edit STEPS '240'
+            edit OVERLAP '1'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+      endfamily
+    endfamily
+    family 00
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD)
+      edit DELTA_DAY '1'
+      edit EMOS_BASE '00'
+      edit QUEUE 'os'
+      family legA
+        trigger /emc_36r1/lag/ref/00/events eq complete
+        edit EPSWAMNFRE '30'
+        edit EPSWAMNANG '24'
+        family init
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/ref/an eq complete)
+          edit FSFAMILY 'mc'
+          task rmfdb
+        endfamily
+        family tc
+          complete /emc_36r1/lag/ref/00/events:cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/postproc/tc eq complete)
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          edit FSFAMILY 'mc'
+          task clean
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
+          task to_ecfs
+            label files ""
+            label info ""
+            event fdb
+          task to_mars
+            trigger to_ecfs eq complete
+        endfamily
+        family archive
+          inlimit /emc_36r1/limits:mars
+          inlimit /limits:mars
+          family postproc
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/postproc eq complete) and /emc_36r1/lag/ref/00/events eq complete
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            family dp
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family pf
+                complete /emc_36r1/lag/ref/00/events:cf
+                edit EMOS_TYPE 'pf'
+                family 144
+                  edit STEPS '0/to/144/by/3'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family cf
+                edit EMOS_TYPE 'cf'
+                family 144
+                  edit STEPS '0/to/144/by/3'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                family 240
+                  edit STEPS '150/to/240/by/6'
+                  task derivedp
+                    label files ""
+                    label info ""
+                    event fdb
+                endfamily
+                task extra_arc
+                  edit STEPS '0/to/240'
+                  edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                  edit RUNVARFC '1'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family cluster
+              complete /emc_36r1/lag/ref/00/events:cf
+              edit STEPS '72/84/96/108/120/132/144/156/168'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family a
+                edit DOMAIN 'a'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family b
+                trigger ./a eq complete
+                edit DOMAIN 'b'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family c
+                trigger ./b eq complete
+                edit DOMAIN 'c'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family d
+                trigger ./c eq complete
+                edit DOMAIN 'd'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family e
+                trigger ./d eq complete
+                edit DOMAIN 'e'
+                task cmpl
+                  edit TYPE 'cm'
+                  label files ""
+                  label info ""
+                  event fdb
+                task cspl
+                  edit TYPE 'cs'
+                  label files ""
+                  label info ""
+                  event fdb
+                task tube
+                  edit STEPS '48/72/96/120/144/168/192/216/240'
+                  edit REFERENCE '96/144/168/192/240'
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family reord
+              complete /emc_36r1/lag/ref/00/events:cf
+              edit EPSCOUPLE '1'
+              edit EMOS_TYPE 'pf'
+              edit FCLENGTH0 '0'
+              edit FCLENGTH '240'
+              edit EPSFCRES '639'
+              edit FCCHUNK '1'
+              edit STEP1 '0'
+              edit STEP2 '240'
+              edit STEPS '-1'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+              limit reord 1
+              inlimit reord
+              label info ""
+              family 130
+                edit GENERATE '1'
+                edit ARCHIVE '0'
+                edit PARAMS '130.128'
+                task reord
+                  label info ""
+              endfamily
+              family 228
+                edit GENERATE '1'
+                edit ARCHIVE '0'
+                edit PARAMS '228.128'
+                task reord
+                  label info ""
+              endfamily
+              family 207
+                edit GENERATE '1'
+                edit ARCHIVE '0'
+                edit PARAMS '207.128'
+                task reord
+                  label info ""
+              endfamily
+              family 167
+                edit GENERATE '1'
+                edit ARCHIVE '0'
+                edit PARAMS '167.128'
+                task reord
+                  label info ""
+              endfamily
+              family 164
+                edit GENERATE '1'
+                edit ARCHIVE '0'
+                edit PARAMS '164.128'
+                task reord
+                  label info ""
+              endfamily
+              family arch
+                trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
+                edit GENERATE '0'
+                edit ARCHIVE '1'
+                inlimit /emc_36r1/lag/ref/00:mutex
+                task reord
+                  label info ""
+              endfamily
+            endfamily
+            family ensms
+              complete /emc_36r1/lag/ref/00/events:cf
+              edit STEPS '3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/75/78/81/84/87/90/93/96/99/102/105/108/111/114/117/120/123/126/129/132/135/138/141/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+              task mean
+                edit TYPE 'em'
+                label files ""
+                label info ""
+                event fdb
+              task stdev
+                edit TYPE 'es'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family prob
+              complete /emc_36r1/lag/ref/00/events:cf
+              family 2t
+                edit PARAM '2t'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family swp_mwp
+                edit PARAM 'swp_mwp'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family 10fg
+                edit PARAM '10fg'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family ff
+                edit PARAM 'ff'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family rain
+                edit PARAM 'rain'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family t850
+                edit PARAM 't850'
+                task arc_prob
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+            endfamily
+            family efi
+              complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/postproc eq complete)
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+              family 2t
+                edit RF_NAME '2t'
+                task efi
+                  label info ""
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task efi
+                  label info ""
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task efi
+                  label info ""
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task efi
+                  label info ""
+              endfamily
+            endfamily
+          endfamily
+          family coupled
+            complete ( /emc_36r1/lag/ref/00/events:cf or /emc_36r1/lag/ref/00/events:360) or ( /emc_36r1/lag/ref/00/events eq complete and not /emc_36r1/lag/ref/00/events:cpl)
+            trigger ./cf eq complete and ./pf eq complete
+            edit EPSLEG '1'
+            edit OCLEG '1'
+            edit OCEPS '1'
+            edit FCCHUNK '1'
+            edit FCLENGTH '240'
+            edit FCLENGTH0 '0'
+            edit OCEPSTOT '3'
+            edit FCTOTAL '51'
+            edit RUNVARFC '1'
+            edit EPSCOUPLE '1'
+            edit RUNCOUPLE '0'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+            inlimit /emc_36r1/lag/ref/00:mutex
+            task preparcoce
+            task arcfc
+              trigger preparcoce eq complete
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family cf
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc/cf eq complete)
+            edit EMOS_TYPE 'cf'
+            edit NUMBER '0'
+            family cf036
+              edit STEPS '0/to/36/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf072
+              edit STEPS '39/to/72/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf108
+              edit STEPS '075/to/108/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf144
+              edit STEPS '111/to/144/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf180
+              edit STEPS '150/to/180/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf240
+              edit STEPS '186/to/240/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family cv
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc/cv eq complete)
+            edit EMOS_TYPE 'cv'
+            edit NUMBER '1/2'
+            family cv036
+              edit STEPS '0/to/036/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv072
+              edit STEPS '039/to/072/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv108
+              edit STEPS '075/to/108/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv144
+              edit STEPS '111/to/144/by/3'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv180
+              edit STEPS '150/to/180/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv240
+              edit STEPS '186/to/240/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv300
+              edit STEPS '246/to/300/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cv360
+              edit STEPS '306/to/360/by/6'
+              task cfml
+                label files ""
+                label info ""
+                event fdb
+              task cfpl
+                label files ""
+                label info ""
+                event fdb
+              task cfsfc
+                trigger ../../postproc/dp eq complete
+                label files ""
+                label info ""
+                event fdb
+              task cfil
+                label files ""
+                label info ""
+                event fdb
+              task cfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task derivedp
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family pf
+            complete /emc_36r1/lag/ref/00/events:cf
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/lag/ref/00/events eq complete)
+            edit EMOS_TYPE 'pf'
+            family pf024
+              edit STEPS '0/to/024/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf048
+              edit STEPS '027/to/048/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf072
+              edit STEPS '051/to/072/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf096
+              edit STEPS '075/to/096/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf120
+              edit STEPS '099/to/120/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf144
+              edit STEPS '123/to/144/by/3'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf192
+              edit STEPS '150/to/192/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family pf240
+              edit STEPS '198/to/240/by/6'
+              task pfpl
+                inlimit /emc_36r1/limits:pl
+                label files ""
+                label info ""
+                event fdb
+              task pfsfc
+                trigger ../../postproc/dp eq complete
+                inlimit /emc_36r1/limits:sfc
+                label files ""
+                label info ""
+                event fdb
+              task pfil
+                label files ""
+                label info ""
+                event fdb
+              task pfwv
+                edit STREAM 'WAEF'
+                edit EMOS_STREAM 'WAEF'
+                label files ""
+                label info ""
+                event fdb
+              task pfml
+                edit STEPS '216'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family icp
+            complete /emc_36r1/lag/ref/00/events:cf
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc eq complete)
+            edit ARCHTYPE 'icp'
+            task ml
+              edit FCLENGTH '240'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          task flush
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legA/fc eq complete)
+            edit STREAM 'enfo'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family ecfs
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/sv eq complete and /emc_36r1/main/00/legA/fc eq complete)
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/sv'
+          edit FSFAMILY 'mc'
+          task svsave
+          task save
+        endfamily
+      endfamily
+      family legB
+        complete /emc_36r1/lag/ref/00/events:240
+        edit EPSLEG '2'
+        edit EPSWAMNFRE '25'
+        edit EPSWAMNANG '12'
+        inlimit /emc_36r1/limits:mars
+        inlimit /limits:mars
+        family postproc
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legB/postproc eq complete) and /emc_36r1/lag/ref/00/events eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+          inlimit /emc_36r1/limits:postproc
+          family ensms
+            complete /emc_36r1/lag/ref/00/events:cf
+            family 360
+              edit STEPS '246/to/360/by/6'
+              task mean
+                edit TYPE 'em'
+                label files ""
+                label info ""
+                event fdb
+              task stdev
+                edit TYPE 'es'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family prob
+            complete /emc_36r1/lag/ref/00/events:cf
+            family 2t
+              edit PARAM '2t'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family swp_mwp
+              edit PARAM 'swp_mwp'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family 10fg
+              edit PARAM '10fg'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family ff
+              edit PARAM 'ff'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family rain
+              edit PARAM 'rain'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family t850
+              edit PARAM 't850'
+              task arc_prob
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family dp
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+            family pf
+              complete /emc_36r1/lag/ref/00/events:cf
+              edit EMOS_TYPE 'pf'
+              family 240
+                edit STEPS '216/222/228/234/240'
+                edit OVERLAP '1'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family 360
+                edit STEPS '246/to/360/by/6'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task extra_arc
+                edit STEPS '240/to/360'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                edit RUNVARFC '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+            family cf
+              edit EMOS_TYPE 'cf'
+              family 240
+                edit STEPS '216/222/228/234/240'
+                edit OVERLAP '1'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              family 360
+                edit STEPS '246/to/360/by/6'
+                task derivedp
+                  label files ""
+                  label info ""
+                  event fdb
+              endfamily
+              task extra_arc
+                edit STEPS '240/to/360'
+                edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+                edit RUNVARFC '1'
+                label files ""
+                label info ""
+                event fdb
+            endfamily
+          endfamily
+          family efi
+            complete ( /emc_36r1/main/ref/00/events:cf) or ( /emc_36r1/main/ref/00/events:noefi)
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+            family 2t
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task efi
+                label info ""
+            endfamily
+          endfamily
+          family reord
+            complete /emc_36r1/lag/ref/00/events:cf
+            edit EPSCOUPLE '1'
+            edit EMOS_TYPE 'pf'
+            edit FCLENGTH0 '240'
+            edit FCLENGTH '360'
+            edit EPSFCRES '639'
+            edit FCCHUNK '1'
+            edit STEP1 '240'
+            edit STEP2 '360'
+            edit STEPS '-1'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg'
+            limit reord 1
+            inlimit reord
+            label info ""
+            family 130
+              edit GENERATE '1'
+              edit ARCHIVE '0'
+              edit PARAMS '130.128'
+              task reord
+                label info ""
+            endfamily
+            family 228
+              edit GENERATE '1'
+              edit ARCHIVE '0'
+              edit PARAMS '228.128'
+              task reord
+                label info ""
+            endfamily
+            family 207
+              edit GENERATE '1'
+              edit ARCHIVE '0'
+              edit PARAMS '207.128'
+              task reord
+                label info ""
+            endfamily
+            family 167
+              edit GENERATE '1'
+              edit ARCHIVE '0'
+              edit PARAMS '167.128'
+              task reord
+                label info ""
+            endfamily
+            family 164
+              edit GENERATE '1'
+              edit ARCHIVE '0'
+              edit PARAMS '164.128'
+              task reord
+                label info ""
+            endfamily
+            family arch
+              trigger ./130 eq complete and ./228 eq complete and ./207 eq complete and ./167 eq complete and ./164 eq complete
+              edit GENERATE '0'
+              edit ARCHIVE '1'
+              inlimit /emc_36r1/lag/ref/00:mutex
+              task reord
+                label info ""
+            endfamily
+          endfamily
+        endfamily
+        family cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legB/fc/cf eq complete)
+          edit EMOS_TYPE 'cf'
+          edit NUMBER '0'
+          family cf240
+            edit STEPS '216/228/240'
+            edit OVERLAP '1'
+            task cfml
+              label files ""
+              label info ""
+              event fdb
+            task cfpl
+              label files ""
+              label info ""
+              event fdb
+            task cfsfc
+              label files ""
+              label info ""
+              event fdb
+            task cfil
+              label files ""
+              label info ""
+              event fdb
+            task cfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family cf300
+            edit STEPS '246/to/300/by/6'
+            task cfml
+              label files ""
+              label info ""
+              event fdb
+            task cfpl
+              label files ""
+              label info ""
+              event fdb
+            task cfsfc
+              label files ""
+              label info ""
+              event fdb
+            task cfil
+              label files ""
+              label info ""
+              event fdb
+            task cfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family cf360
+            edit STEPS '306/to/360/by/6'
+            task cfml
+              label files ""
+              label info ""
+              event fdb
+            task cfpl
+              label files ""
+              label info ""
+              event fdb
+            task cfsfc
+              label files ""
+              label info ""
+              event fdb
+            task cfil
+              label files ""
+              label info ""
+              event fdb
+            task cfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          task accum
+            edit STEPS '240'
+            edit OVERLAP '1'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family pf
+          complete /emc_36r1/lag/ref/00/events:cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/lag:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/lag:YMD and /emc_36r1/main/00/legB/fc/pf eq complete and /emc_36r1/lag/ref/00/events eq complete)
+          edit EMOS_TYPE 'pf'
+          family pf240
+            edit STEPS '216/228/240'
+            edit OVERLAP '1'
+            task pfpl
+              inlimit /emc_36r1/limits:pl
+              label files ""
+              label info ""
+              event fdb
+            task pfsfc
+              trigger ../../postproc/dp eq complete
+              inlimit /emc_36r1/limits:sfc
+              label files ""
+              label info ""
+              event fdb
+            task pfil
+              label files ""
+              label info ""
+              event fdb
+            task pfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf300
+            edit STEPS '246/to/300/by/6'
+            task pfpl
+              inlimit /emc_36r1/limits:pl
+              label files ""
+              label info ""
+              event fdb
+            task pfsfc
+              trigger ../../postproc/dp eq complete
+              inlimit /emc_36r1/limits:sfc
+              label files ""
+              label info ""
+              event fdb
+            task pfil
+              label files ""
+              label info ""
+              event fdb
+            task pfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          family pf360
+            edit STEPS '306/to/360/by/6'
+            task pfpl
+              inlimit /emc_36r1/limits:pl
+              label files ""
+              label info ""
+              event fdb
+            task pfsfc
+              trigger ../../postproc/dp eq complete
+              inlimit /emc_36r1/limits:sfc
+              label files ""
+              label info ""
+              event fdb
+            task pfil
+              label files ""
+              label info ""
+              event fdb
+            task pfwv
+              edit STREAM 'WAEF'
+              edit EMOS_STREAM 'WAEF'
+              label files ""
+              label info ""
+              event fdb
+          endfamily
+          task pfml
+            edit STEPS '360'
+          task accum
+            edit STEPS '240'
+            edit OVERLAP '1'
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+        family coupled
+          complete /emc_36r1/lag/ref/00/events:cf or /emc_36r1/lag/ref/00/events:360 or ( /emc_36r1/lag/ref/00/events eq complete and not /emc_36r1/lag/ref/00/events:cpl)
+          trigger /emc_36r1/lag/00/legA/archive/coupled eq complete
+          edit EPSLEG '2'
+          edit OCLEG '2'
+          edit OCEPS '2'
+          edit FCCHUNK '1'
+          edit FCLENGTH '360'
+          edit FCLENGTH0 '216'
+          edit OCEPSTOT '3'
+          edit FCTOTAL '51'
+          edit RUNVARFC '1'
+          edit EPSCOUPLE '1'
+          edit RUNCOUPLE '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+          inlimit /emc_36r1/lag/ref/00:mutex
+          task preparcoce
+          task arcfc
+            trigger preparcoce eq complete
+            label files ""
+            label info ""
+            event fdb
+        endfamily
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'lag'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1'
+    task logfiles
+      late -s +00:05 -c +00:35
+      trigger /emc_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete and logfilestore eq complete and ./ref/loop eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'lag'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1'
+  endfamily
+  family pop
+    repeat date YMD 20091003 20121212 1
+    edit SMSURLBASE 'http://intra.ecmwf.int/plots/d/intra/'
+    edit SMSURL 'sub=fixed/'
+    edit VERSION '0046'
+    edit STREAM 'EF'
+    edit EMOS_STREAM 'EF'
+    edit SMSFILES '/home/ma/emos/def/emc_36r1'
+    edit LOGTASK 'pop'
+    edit SUITE_START '20091124'
+    family 12
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/ref/model eq complete)
+      edit DELTA_DAY '0'
+      edit EMOS_BASE '12'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/pop'
+      task events
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+        edit HINDCAST '1'
+        edit ONLY_CF '0'
+        event noefi
+        event 240 
+        event 360 
+        event cpl
+        event 768 
+        event cf
+      family data
+        trigger events eq complete
+        family metgram
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete)
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit QUEUE 'emos'
+          edit SMSTRIES '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
+          inlimit /limits:linux_cluster
+          family 240
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/legA/fc/cf eq complete)
+            edit KIND '10_days'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family 360
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
+            edit KIND '15_days'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family wave
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/pf eq complete and /emc_36r1/main/12/legA/fc/cf eq complete)
+            edit KIND '10_days_wave'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family 15d
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
+            edit KIND '15_days_pf'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family efi
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
+            edit KIND 'efi'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '10'
+              edit REMOTE_KEEP_DAYS '10'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+        endfamily
+        family distribution
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data'
+          edit DISTRIB_FDB '/leda/fdb1'
+          inlimit /limits:linux_cluster
+          task ff
+            edit PARAMETER 'ff'
+            edit STEP_LIST '84 108 132 156 180'
+            edit RANK '9999'
+          task 2t
+            edit PARAMETER '2t'
+            edit STEP_LIST '84 108 132 156 180'
+            edit RANK '9998'
+          task tp
+            edit PARAMETER 'tp'
+            edit STEP_LIST '102 126 150 174 198'
+            edit RANK '9997'
+          task tp5
+            edit PARAMETER 'tp5'
+            edit STEP_LIST '174'
+            edit RANK '9996'
+          task tp10
+            edit PARAMETER 'tp10'
+            edit STEP_LIST '240'
+            edit RANK '9995'
+          task cleanup
+            trigger ff eq complete and ./2t eq complete and tp eq complete and tp5 eq complete and tp10 eq complete
+        endfamily
+        family fields
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc eq complete and /emc_36r1/main/12/legA/postproc eq complete)
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/fields'
+          inlimit /limits:linux_cluster
+          inlimit /emc_36r1/limits:webplots
+          task efi
+            complete ( /emc_36r1/pop/12/events:cf) or ( /emc_36r1/pop/12/events:noefi)
+            trigger /emc_36r1/pop/12/events eq complete
+            event none
+          task globalefi
+            complete ( /emc_36r1/pop/12/events:cf) or ( /emc_36r1/pop/12/events:noefi)
+            trigger /emc_36r1/pop/12/events eq complete
+            event none
+          family legA
+            task proba
+              complete /emc_36r1/pop/12/events:cf
+              trigger /emc_36r1/pop/12/events eq complete
+              edit RANGE 'legA'
+              edit PLOT_STEPS_RANGE '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
+              edit PLOT_STEPS '12/to/240/by/12'
+          endfamily
+          family legB
+            task proba
+              complete /emc_36r1/pop/12/events:cf
+              trigger /emc_36r1/pop/12/events eq complete
+              edit RANGE 'legB'
+              edit PLOT_STEPS '252/to/360/by/12'
+              edit PLOT_STEPS_RANGE '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
+          endfamily
+          task proba_mean
+            complete /emc_36r1/pop/12/events:cf
+            trigger /emc_36r1/pop/12/events eq complete
+            edit PLOT_STEPS_MEAN '240-360'
+          task lsmoro
+            edit STEP_LIST '0/to/144/by/12'
+        endfamily
+        family tc
+          complete /emc_36r1/pop/12/events:cf
+          trigger ( /emc_36r1/pop/12/events eq complete) and ( ( /emc_36r1/lag:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/lag:YMD eq /emc_36r1/pop:YMD and /emc_36r1/lag/12/legA/tc eq complete))
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
+          inlimit /limits:linux_cluster
+          task cleanup
+          task check_data
+          family post_process
+            task strike_prob
+              trigger ../check_data eq complete
+          endfamily
+          family diagnostics
+            trigger post_process eq complete
+            task det_errors
+            task spreadskill
+            task reliability
+          endfamily
+          family store
+            trigger ( /emc_36r1/pop/12/data/tc/diagnostics eq complete)
+            task to_ecfs_pop
+          endfamily
+        endfamily
+        family tcyc
+          complete /emc_36r1/pop/12/events:cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/fc eq complete)
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FCCHUNK '1'
+          edit OCTOTAL '5'
+          edit FCTOTAL '51'
+          edit FCLENGTH1 '216'
+          edit DAILY '0'
+          edit RUNVARFC '1'
+          edit FCLENGTH '360'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+          edit EPSCOUPLE '1'
+          edit RADIUS '500'
+          limit semaphore 8
+          inlimit /limits:linux_cluster
+          inlimit semaphore
+          task genes_stage
+            edit DELTA_DAY '1'
+          family genesis
+            trigger genes_stage eq complete
+            family da
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER 'da'
+              edit MEMBER 'da'
+              task tcyc
+            endfamily
+            family 00
+              edit OCGROUP 'an00'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '00'
+              edit MEMBER '00'
+              task tcyc
+            endfamily
+            family 01
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '01'
+              edit MEMBER '01'
+              task tcyc
+            endfamily
+            family 02
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '02'
+              edit MEMBER '02'
+              task tcyc
+            endfamily
+            family 03
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '03'
+              edit MEMBER '03'
+              task tcyc
+            endfamily
+            family 04
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '04'
+              edit MEMBER '04'
+              task tcyc
+            endfamily
+            family 05
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '05'
+              edit MEMBER '05'
+              task tcyc
+            endfamily
+            family 06
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '06'
+              edit MEMBER '06'
+              task tcyc
+            endfamily
+            family 07
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '07'
+              edit MEMBER '07'
+              task tcyc
+            endfamily
+            family 08
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '08'
+              edit MEMBER '08'
+              task tcyc
+            endfamily
+            family 09
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '09'
+              edit MEMBER '09'
+              task tcyc
+            endfamily
+            family 10
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              task tcyc
+            endfamily
+            family 11
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              task tcyc
+            endfamily
+            family 12
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              task tcyc
+            endfamily
+            family 13
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              task tcyc
+            endfamily
+            family 14
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              task tcyc
+            endfamily
+            family 15
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              task tcyc
+            endfamily
+            family 16
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              task tcyc
+            endfamily
+            family 17
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              task tcyc
+            endfamily
+            family 18
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              task tcyc
+            endfamily
+            family 19
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              task tcyc
+            endfamily
+            family 20
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              task tcyc
+            endfamily
+            family 21
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              task tcyc
+            endfamily
+            family 22
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              task tcyc
+            endfamily
+            family 23
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              task tcyc
+            endfamily
+            family 24
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              task tcyc
+            endfamily
+            family 25
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              task tcyc
+            endfamily
+            family 26
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              task tcyc
+            endfamily
+            family 27
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              task tcyc
+            endfamily
+            family 28
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              task tcyc
+            endfamily
+            family 29
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              task tcyc
+            endfamily
+            family 30
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              task tcyc
+            endfamily
+            family 31
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              task tcyc
+            endfamily
+            family 32
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              task tcyc
+            endfamily
+            family 33
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              task tcyc
+            endfamily
+            family 34
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              task tcyc
+            endfamily
+            family 35
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              task tcyc
+            endfamily
+            family 36
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              task tcyc
+            endfamily
+            family 37
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              task tcyc
+            endfamily
+            family 38
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              task tcyc
+            endfamily
+            family 39
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              task tcyc
+            endfamily
+            family 40
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              task tcyc
+            endfamily
+            family 41
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              task tcyc
+            endfamily
+            family 42
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              task tcyc
+            endfamily
+            family 43
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              task tcyc
+            endfamily
+            family 44
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              task tcyc
+            endfamily
+            family 45
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              task tcyc
+            endfamily
+            family 46
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              task tcyc
+            endfamily
+            family 47
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              task tcyc
+            endfamily
+            family 48
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              task tcyc
+            endfamily
+            family 49
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              task tcyc
+            endfamily
+            family 50
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc10'
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              task tcyc
+            endfamily
+          endfamily
+          task tcyctoecfs
+            trigger genesis eq complete
+        endfamily
+      endfamily
+      family web
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
+        inlimit /limits:linux_cluster
+        inlimit /emc_36r1/limits:webplots
+        family pf
+          complete /emc_36r1/pop/12/events:cf
+          trigger /emc_36r1/pop/12/events eq complete
+          task plumes
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/fc/cf eq complete and /emc_36r1/main/12/legA/fc/pf eq complete)
+          family classic
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/clusters eq complete)
+            edit ANALYSIS 'NO'
+            task clplot
+            task pltube
+            task enplot
+              edit STEPS '12 24 36 48 60 72 84 96 108 120 132 144 156 168 180 192'
+              edit PRINTSTEPS '60 84 108 132 156 180'
+          endfamily
+          family efi
+            complete /emc_36r1/pop/12/events:noefi
+            trigger ../../data/fields eq complete
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
+            inlimit /limits:linux_cluster
+            inlimit /emc_36r1/limits:webplots
+            family efi_tpi
+              task w_efi
+                edit PARAMETER 'tpi'
+            endfamily
+            family efi_10wsi
+              task w_efi
+                edit PARAMETER '10wsi'
+            endfamily
+            family efi_2ti
+              task w_efi
+                edit PARAMETER '2ti'
+            endfamily
+            family efi_10fgi
+              task w_efi
+                edit PARAMETER '10fgi'
+            endfamily
+            task globalefi
+              edit UPDATE_WEB_NOW 'yes'
+          endfamily
+          family proba
+            trigger ../../data/fields eq complete
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
+            edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia,Africa,Global'
+            inlimit /limits:linux_cluster
+            inlimit /emc_36r1/limits:webplots
+            family members
+              family legA
+                edit PLOT_STEPS '12/to/240/by/12'
+                edit STEP_RANGE 'legA'
+                task pb_2t
+                task pb_ff
+                task pb_tp
+                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
+                task w_proba_gusts
+                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
+                task pb_tpr
+                task pb_mwp
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+                task pb_swh
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+              endfamily
+              family legB
+                trigger ( ./legA eq complete)
+                edit PLOT_STEPS '252/to/360/by/12'
+                edit STEP_RANGE 'legB'
+                edit UPDATE_WEB_NOW 'yes'
+                task pb_2t
+                task pb_ff
+                task pb_tp
+                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
+                task w_proba_gusts
+                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
+                task pb_mwp
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+                task pb_swh
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+              endfamily
+              family means
+                trigger ( ./legA eq complete)
+                edit UPDATE_WEB_NOW 'yes'
+                task long_pb_2t
+                task long_pb_tpr
+                task long_w_proba_gusts
+                task long_pb_mwp
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+                task long_pb_swh
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+              endfamily
+            endfamily
+            family additional
+              edit PLOT_STEPS '12/to/156/by/12'
+              edit STEP_RANGE 'legA'
+              task w_proba_rain
+              family wmo_waves
+                edit PLOT_STEPS '12/to/168/by/12'
+                edit PLOT_AREAS 'Global'
+                edit PLOT_GRID '2.5/2.5'
+                task pb_swh
+              endfamily
+            endfamily
+          endfamily
+          family ensm
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legB/postproc/ensms eq complete and /emc_36r1/main/12/legA/postproc/ensms eq complete)
+            task fields_ensm
+              event 30 
+            task plot_ensm_Z
+              complete fields_ensm eq complete and not fields_ensm:30
+              trigger fields_ensm eq complete and fields_ensm:30
+            task plot_ensm_T
+              complete fields_ensm eq complete and not fields_ensm:30
+              trigger fields_ensm eq complete and fields_ensm:30
+            task cleanup_ensm
+              trigger plot_ensm_Z eq complete and plot_ensm_T eq complete
+              edit SMSPASS 'stripped'
+          endfamily
+          family tc
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/tc'
+            inlimit /limits:linux_cluster
+            family plotting
+              trigger ( /emc_36r1/pop/12/data/tc/post_process eq complete)
+              task spm
+              task epsgram
+              task tstorm
+              task tstorm_web
+                trigger tstorm eq complete
+            endfamily
+            task tc2web
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and ./plotting eq complete and /emc_36r1/pop/12/data/tc/diagnostics eq complete)
+              edit WSHOST 'linux_cluster'
+          endfamily
+          family special
+            family swdfp
+              edit WSHOST 'linux_cluster'
+              edit QUEUE 'serial'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/swdfp'
+              edit PLOTDOM '-45/-10/6/62'
+              edit UPDATE_WEB_NOW 'yes'
+              time 01:30
+              family efi
+                trigger /emc_36r1/pop/12/data/fields eq complete
+                edit QUEUE 'emos-e'
+                edit QUEUE_EPILOG 'emos-exp'
+                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                edit LOGDIR '/vol/emos_nc/output'
+                edit SMSOUT '/vol/emos_nc/output'
+                inlimit /limits:linux_cluster
+                family swdfp_tpi
+                  task w_efi
+                    edit PARAMETER 'tpi'
+                endfamily
+                family swdfp_10wsi
+                  task w_efi
+                    edit PARAMETER '10wsi'
+                endfamily
+                family swdfp_2ti
+                  task w_efi
+                    edit PARAMETER '2ti'
+                endfamily
+                family swdfp_10fgi
+                  task w_efi
+                    edit PARAMETER '10fgi'
+                endfamily
+              endfamily
+              family proba
+                trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/prob eq complete)
+                edit PLOT_LOCATION '/webplots_e/data/swdfp/proba'
+                edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+                task swdfp_proba
+                task swdfp_tp
+                  trigger ./swdfp_proba eq complete
+                task swdfp_ff
+                  trigger ./swdfp_proba eq complete
+                task swdfp_tp24
+                  trigger ./swdfp_proba eq complete
+                  edit STEPS '24/48/72/96/120'
+                task swdfp_proba_clean
+                  trigger ./swdfp_tp eq complete and ./swdfp_ff eq complete and ./swdfp_tp24 eq complete
+              endfamily
+              task swdfp_epsgram
+                trigger /emc_36r1/pop/12/data/metgram eq complete
+            endfamily
+          endfamily
+        endfamily
+        family verification
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit DATEMASK '11.*.*'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/verification'
+          inlimit /limits:linux_cluster
+          task w_probas
+          task w_costloss
+          task w_timeseries
+        endfamily
+        task web_update
+          trigger pf/proba/members/legA eq complete and pf/proba/additional eq complete and pf/plumes eq complete and pf/classic eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit PACKAGES 'esuite'
+          edit UPDATE_STREAM 'enfo'
+          inlimit /emc_36r1/limits:webplots
+      endfamily
+      family paper
+        trigger web/web_update eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/plot'
+        inlimit /limits:linux_cluster
+        task epsgram
+          trigger ../data/metgram eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/paper'
+        family enplot
+          complete /emc_36r1/pop/12/events:cf
+          trigger ( /emc_36r1/pop/12/events eq complete) and ( ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/clusters eq complete))
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit ANALYSIS 'NO'
+          task sthemi
+        endfamily
+        family tube
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/clusters eq complete)
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          inlimit /limits:linux_cluster
+          task ptubfr
+          task tubfrfax
+            trigger ptubfr eq complete
+            edit QUEUE 'emos'
+          task tubukfax
+            trigger ptubuk eq complete
+            edit QUEUE 'emos'
+          task ptubuk
+            trigger ptubfr eq complete
+        endfamily
+        family prob
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/12/legA/postproc/prob eq complete)
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit ANALYSIS 'YES'
+          inlimit /emc_36r1/limits:webplots
+          task clplot
+            trigger ../enplot eq complete
+          task s144
+            trigger clplot eq complete
+            edit STEPS '144'
+          task plumea
+          task pb
+        endfamily
+      endfamily
+      task cleanup
+        trigger paper eq complete and web eq complete
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        inlimit /limits:linux_cluster
+        inlimit /emc_36r1/limits:webplots
+    endfamily
+    family 00
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/ref/model eq complete)
+      edit DELTA_DAY '1'
+      edit EMOS_BASE '00'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/pop'
+      task events
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/ref'
+        edit HINDCAST '1'
+        edit ONLY_CF '0'
+        event noefi
+        event 240 
+        event 360 
+        event cpl
+        event 768 
+        event cf
+      family data
+        trigger events eq complete
+        family metgram
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete)
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit QUEUE 'emos'
+          edit SMSTRIES '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
+          inlimit /limits:linux_cluster
+          family 240
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete)
+            edit KIND '10_days'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family 360
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
+            edit KIND '15_days'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family wave
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/pf eq complete and /emc_36r1/main/00/legA/fc/cf eq complete)
+            edit KIND '10_days_wave'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family 15d
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
+            edit KIND '15_days_pf'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family 15dclim
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/fc/pf eq complete and /emc_36r1/main/00/legB/fc/cf eq complete and /emc_36r1/00/efi/swarm/sync_climate eq complete)
+            edit KIND 'clim_15_days'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '2'
+              edit REMOTE_KEEP_DAYS '2'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+          family efi
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
+            edit KIND 'efi'
+            edit RHOST 'epsgrams'
+            edit RDIR '/webapps/epsgrams/data/'
+            task gclean
+              edit KEEP_DAYS '10'
+              edit REMOTE_KEEP_DAYS '10'
+            task gdb
+              trigger gclean eq complete
+              edit NEW_DAILY '1'
+              label files ""
+              label info ""
+              label local "-"
+              label remote "-"
+              event fdb
+              event 1 
+            task glink
+              trigger gdb eq complete
+          endfamily
+        endfamily
+        family distribution
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data'
+          edit DISTRIB_FDB '/leda/fdb1'
+          inlimit /limits:linux_cluster
+          task ff
+            edit PARAMETER 'ff'
+            edit STEP_LIST '84 108 132 156 180'
+            edit RANK '9999'
+          task 2t
+            edit PARAMETER '2t'
+            edit STEP_LIST '84 108 132 156 180'
+            edit RANK '9998'
+          task tp
+            edit PARAMETER 'tp'
+            edit STEP_LIST '102 126 150 174 198'
+            edit RANK '9997'
+          task tp5
+            edit PARAMETER 'tp5'
+            edit STEP_LIST '174'
+            edit RANK '9996'
+          task tp10
+            edit PARAMETER 'tp10'
+            edit STEP_LIST '240'
+            edit RANK '9995'
+          task cleanup
+            trigger ff eq complete and ./2t eq complete and tp eq complete and tp5 eq complete and tp10 eq complete
+        endfamily
+        family fields
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete and /emc_36r1/main/00/legA/postproc eq complete)
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/fields'
+          inlimit /limits:linux_cluster
+          inlimit /emc_36r1/limits:webplots
+          task efi
+            complete ( /emc_36r1/pop/00/events:cf) or ( /emc_36r1/pop/00/events:noefi)
+            trigger /emc_36r1/pop/00/events eq complete
+            event none
+          task globalefi
+            complete ( /emc_36r1/pop/00/events:cf) or ( /emc_36r1/pop/00/events:noefi)
+            trigger /emc_36r1/pop/00/events eq complete
+            event none
+          family legA
+            task proba
+              complete /emc_36r1/pop/00/events:cf
+              trigger /emc_36r1/pop/00/events eq complete
+              edit RANGE 'legA'
+              edit PLOT_STEPS_RANGE '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
+              edit PLOT_STEPS '12/to/240/by/12'
+          endfamily
+          family legB
+            task proba
+              complete /emc_36r1/pop/00/events:cf
+              trigger /emc_36r1/pop/00/events eq complete
+              edit RANGE 'legB'
+              edit PLOT_STEPS '252/to/360/by/12'
+              edit PLOT_STEPS_RANGE '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
+          endfamily
+          task proba_mean
+            complete /emc_36r1/pop/00/events:cf
+            trigger /emc_36r1/pop/00/events eq complete
+            edit PLOT_STEPS_MEAN '240-360'
+          task lsmoro
+            edit STEP_LIST '0/to/144/by/12'
+        endfamily
+        family tc
+          complete /emc_36r1/pop/00/events:cf
+          trigger ( /emc_36r1/pop/00/events eq complete) and ( ( /emc_36r1/lag:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/lag:YMD eq /emc_36r1/pop:YMD and /emc_36r1/lag/00/legA/tc eq complete))
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/tc'
+          inlimit /limits:linux_cluster
+          task cleanup
+          task check_data
+            trigger /emc_36r1/pop/12/data/tc eq complete
+          family post_process
+            task strike_prob
+              trigger ../check_data eq complete
+          endfamily
+          family diagnostics
+            trigger post_process eq complete
+            task det_errors
+            task spreadskill
+            task reliability
+          endfamily
+          family store
+            trigger ( /emc_36r1/pop/00/data/tc/diagnostics eq complete)
+            task to_ecfs_pop
+          endfamily
+        endfamily
+        family tcyc
+          complete /emc_36r1/pop/00/events:cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/fc eq complete)
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FCCHUNK '1'
+          edit OCTOTAL '5'
+          edit FCTOTAL '51'
+          edit FCLENGTH1 '216'
+          edit DAILY '0'
+          edit RUNVARFC '1'
+          edit FCLENGTH '360'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive/leg'
+          edit EPSCOUPLE '1'
+          edit RADIUS '500'
+          limit semaphore 5
+          inlimit /limits:linux_cluster
+          inlimit semaphore
+          task genes_stage
+            edit DELTA_DAY '2'
+          family genesis
+            trigger genes_stage eq complete
+            family da
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER 'da'
+              edit MEMBER 'da'
+              task tcyc
+            endfamily
+            family 00
+              edit OCGROUP 'an00'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '00'
+              edit MEMBER '00'
+              task tcyc
+            endfamily
+            family 01
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '01'
+              edit MEMBER '01'
+              task tcyc
+            endfamily
+            family 02
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '02'
+              edit MEMBER '02'
+              task tcyc
+            endfamily
+            family 03
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '03'
+              edit MEMBER '03'
+              task tcyc
+            endfamily
+            family 04
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc0'
+              edit EPSMEMBER '04'
+              edit MEMBER '04'
+              task tcyc
+            endfamily
+            family 05
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '05'
+              edit MEMBER '05'
+              task tcyc
+            endfamily
+            family 06
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '06'
+              edit MEMBER '06'
+              task tcyc
+            endfamily
+            family 07
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '07'
+              edit MEMBER '07'
+              task tcyc
+            endfamily
+            family 08
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '08'
+              edit MEMBER '08'
+              task tcyc
+            endfamily
+            family 09
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc1'
+              edit EPSMEMBER '09'
+              edit MEMBER '09'
+              task tcyc
+            endfamily
+            family 10
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '10'
+              edit MEMBER '10'
+              task tcyc
+            endfamily
+            family 11
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '11'
+              edit MEMBER '11'
+              task tcyc
+            endfamily
+            family 12
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '12'
+              edit MEMBER '12'
+              task tcyc
+            endfamily
+            family 13
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '13'
+              edit MEMBER '13'
+              task tcyc
+            endfamily
+            family 14
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc2'
+              edit EPSMEMBER '14'
+              edit MEMBER '14'
+              task tcyc
+            endfamily
+            family 15
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '15'
+              edit MEMBER '15'
+              task tcyc
+            endfamily
+            family 16
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '16'
+              edit MEMBER '16'
+              task tcyc
+            endfamily
+            family 17
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '17'
+              edit MEMBER '17'
+              task tcyc
+            endfamily
+            family 18
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '18'
+              edit MEMBER '18'
+              task tcyc
+            endfamily
+            family 19
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc3'
+              edit EPSMEMBER '19'
+              edit MEMBER '19'
+              task tcyc
+            endfamily
+            family 20
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '20'
+              edit MEMBER '20'
+              task tcyc
+            endfamily
+            family 21
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '21'
+              edit MEMBER '21'
+              task tcyc
+            endfamily
+            family 22
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '22'
+              edit MEMBER '22'
+              task tcyc
+            endfamily
+            family 23
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '23'
+              edit MEMBER '23'
+              task tcyc
+            endfamily
+            family 24
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc4'
+              edit EPSMEMBER '24'
+              edit MEMBER '24'
+              task tcyc
+            endfamily
+            family 25
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '25'
+              edit MEMBER '25'
+              task tcyc
+            endfamily
+            family 26
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '26'
+              edit MEMBER '26'
+              task tcyc
+            endfamily
+            family 27
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '27'
+              edit MEMBER '27'
+              task tcyc
+            endfamily
+            family 28
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '28'
+              edit MEMBER '28'
+              task tcyc
+            endfamily
+            family 29
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc5'
+              edit EPSMEMBER '29'
+              edit MEMBER '29'
+              task tcyc
+            endfamily
+            family 30
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '30'
+              edit MEMBER '30'
+              task tcyc
+            endfamily
+            family 31
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '31'
+              edit MEMBER '31'
+              task tcyc
+            endfamily
+            family 32
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '32'
+              edit MEMBER '32'
+              task tcyc
+            endfamily
+            family 33
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '33'
+              edit MEMBER '33'
+              task tcyc
+            endfamily
+            family 34
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc6'
+              edit EPSMEMBER '34'
+              edit MEMBER '34'
+              task tcyc
+            endfamily
+            family 35
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '35'
+              edit MEMBER '35'
+              task tcyc
+            endfamily
+            family 36
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '36'
+              edit MEMBER '36'
+              task tcyc
+            endfamily
+            family 37
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '37'
+              edit MEMBER '37'
+              task tcyc
+            endfamily
+            family 38
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '38'
+              edit MEMBER '38'
+              task tcyc
+            endfamily
+            family 39
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc7'
+              edit EPSMEMBER '39'
+              edit MEMBER '39'
+              task tcyc
+            endfamily
+            family 40
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '40'
+              edit MEMBER '40'
+              task tcyc
+            endfamily
+            family 41
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '41'
+              edit MEMBER '41'
+              task tcyc
+            endfamily
+            family 42
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '42'
+              edit MEMBER '42'
+              task tcyc
+            endfamily
+            family 43
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '43'
+              edit MEMBER '43'
+              task tcyc
+            endfamily
+            family 44
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc8'
+              edit EPSMEMBER '44'
+              edit MEMBER '44'
+              task tcyc
+            endfamily
+            family 45
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '45'
+              edit MEMBER '45'
+              task tcyc
+            endfamily
+            family 46
+              edit OCGROUP 'an1'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '46'
+              edit MEMBER '46'
+              task tcyc
+            endfamily
+            family 47
+              edit OCGROUP 'an2'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '47'
+              edit MEMBER '47'
+              task tcyc
+            endfamily
+            family 48
+              edit OCGROUP 'an3'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '48'
+              edit MEMBER '48'
+              task tcyc
+            endfamily
+            family 49
+              edit OCGROUP 'an4'
+              edit FCGROUP 'fc9'
+              edit EPSMEMBER '49'
+              edit MEMBER '49'
+              task tcyc
+            endfamily
+            family 50
+              edit OCGROUP 'an0'
+              edit FCGROUP 'fc10'
+              edit EPSMEMBER '50'
+              edit MEMBER '50'
+              task tcyc
+            endfamily
+          endfamily
+          task tcyctoecfs
+            trigger genesis eq complete
+        endfamily
+        family mjo
+          complete /emc_36r1/lag/ref/00/events:cf
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc eq complete)
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit FCLENGTH '360'
+          edit ERA40END '2002033000'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+          edit RUNVARFC '1'
+          inlimit /limits:linux_cluster
+          family stage
+            edit RETRIEVE 'stage'
+            edit DELTA_DAY '2'
+            task chi200
+            task olr
+            task u200
+            task u850
+          endfamily
+          family process
+            task chi200
+            task olr
+            task u850
+            task u200
+          endfamily
+          family ncep
+            trigger ./process eq complete
+            task olr_to_ncep
+            task u200_to_ncep
+            task u850_to_ncep
+          endfamily
+          task ncep_daily
+            trigger ./ncep eq complete
+          task ceof
+            trigger process eq complete
+          task mjo_migrate
+            complete /emc_36r1/pop/00/events:768
+            trigger process eq complete and ceof eq complete and ncep_daily eq complete
+          task mjo_clean
+            complete /emc_36r1/pop/00/events:768
+            trigger process eq complete and ncep eq complete and ncep_daily eq complete and ceof eq complete and mjo_migrate eq complete
+        endfamily
+      endfamily
+      family web
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
+        inlimit /limits:linux_cluster
+        inlimit /emc_36r1/limits:webplots
+        family pf
+          complete /emc_36r1/pop/00/events:cf
+          trigger /emc_36r1/pop/00/events eq complete
+          task plumes
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/fc/cf eq complete and /emc_36r1/main/00/legA/fc/pf eq complete)
+          family classic
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/clusters eq complete)
+            edit ANALYSIS 'NO'
+            task clplot
+            task pltube
+            task enplot
+              edit STEPS '12 24 36 48 60 72 84 96 108 120 132 144 156 168 180 192'
+              edit PRINTSTEPS '60 84 108 132 156 180'
+          endfamily
+          family efi
+            complete /emc_36r1/pop/00/events:noefi
+            trigger ../../data/fields eq complete
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
+            inlimit /limits:linux_cluster
+            inlimit /emc_36r1/limits:webplots
+            family efi_tpi
+              task w_efi
+                edit PARAMETER 'tpi'
+            endfamily
+            family efi_10wsi
+              task w_efi
+                edit PARAMETER '10wsi'
+            endfamily
+            family efi_2ti
+              task w_efi
+                edit PARAMETER '2ti'
+            endfamily
+            family efi_10fgi
+              task w_efi
+                edit PARAMETER '10fgi'
+            endfamily
+            task globalefi
+              edit UPDATE_WEB_NOW 'yes'
+          endfamily
+          family proba
+            trigger ../../data/fields eq complete
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'plots-medium'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web'
+            edit PLOT_AREAS 'Europe,North_America,Asia,South_Atlantic,South_Pacific,Australia,Africa,Global'
+            inlimit /limits:linux_cluster
+            inlimit /emc_36r1/limits:webplots
+            family members
+              family legA
+                edit PLOT_STEPS '12/to/240/by/12'
+                edit STEP_RANGE 'legA'
+                task pb_2t
+                task pb_ff
+                task pb_tp
+                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
+                task w_proba_gusts
+                  edit PLOT_STEPS '00-24/12-36/24-48/36-60/48-72/60-84/72-96/84-108/96-120/108-132/120-144/132-156/144-168/156-180/168-192/180-204/192-216/204-228/216-240'
+                task pb_tpr
+                task pb_mwp
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+                task pb_swh
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+              endfamily
+              family legB
+                trigger ( ./legA eq complete)
+                edit PLOT_STEPS '252/to/360/by/12'
+                edit STEP_RANGE 'legB'
+                edit UPDATE_WEB_NOW 'yes'
+                task pb_2t
+                task pb_ff
+                task pb_tp
+                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
+                task w_proba_gusts
+                  edit PLOT_STEPS '228-252/240-264/252-276/264-288/276-300/288-312/300-324/312-336/324-348/336-360'
+                task pb_mwp
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+                task pb_swh
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+              endfamily
+              family means
+                trigger ( ./legA eq complete)
+                edit UPDATE_WEB_NOW 'yes'
+                task long_pb_2t
+                task long_pb_tpr
+                task long_w_proba_gusts
+                task long_pb_mwp
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+                task long_pb_swh
+                  edit PLOT_AREAS 'Global,Europe,Pacific,Indian,North_Atlantic,South_Atlantic'
+              endfamily
+            endfamily
+            family additional
+              edit PLOT_STEPS '12/to/156/by/12'
+              edit STEP_RANGE 'legA'
+              task w_proba_rain
+              family wmo_waves
+                edit PLOT_STEPS '12/to/168/by/12'
+                edit PLOT_AREAS 'Global'
+                edit PLOT_GRID '2.5/2.5'
+                task pb_swh
+              endfamily
+            endfamily
+          endfamily
+          family ensm
+            trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legB/postproc/ensms eq complete and /emc_36r1/main/00/legA/postproc/ensms eq complete)
+            task fields_ensm
+              event 30 
+            task plot_ensm_Z
+              complete fields_ensm eq complete and not fields_ensm:30
+              trigger fields_ensm eq complete and fields_ensm:30
+            task plot_ensm_T
+              complete fields_ensm eq complete and not fields_ensm:30
+              trigger fields_ensm eq complete and fields_ensm:30
+            task cleanup_ensm
+              trigger plot_ensm_Z eq complete and plot_ensm_T eq complete
+          endfamily
+          family tc
+            edit WSHOST 'linux_cluster'
+            edit QUEUE 'emos-e'
+            edit QUEUE_EPILOG 'emos-exp'
+            edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+            edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+            edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+            edit LOGDIR '/vol/emos_nc/output'
+            edit SMSOUT '/vol/emos_nc/output'
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/tc'
+            inlimit /limits:linux_cluster
+            family plotting
+              trigger ( /emc_36r1/pop/00/data/tc/post_process eq complete)
+              task spm
+              task epsgram
+              task tstorm
+              task tstorm_web
+                trigger tstorm eq complete
+            endfamily
+            task tc2web
+              trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and ./plotting eq complete and /emc_36r1/pop/00/data/tc/diagnostics eq complete)
+              edit WSHOST 'linux_cluster'
+          endfamily
+          family special
+            family swdfp
+              edit WSHOST 'linux_cluster'
+              edit QUEUE 'serial'
+              edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/swdfp'
+              edit PLOTDOM '-45/-10/6/62'
+              edit UPDATE_WEB_NOW 'yes'
+              time 10:30
+              family efi
+                trigger /emc_36r1/pop/00/data/fields eq complete
+                edit QUEUE 'emos-e'
+                edit QUEUE_EPILOG 'emos-exp'
+                edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+                edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                edit LOGDIR '/vol/emos_nc/output'
+                edit SMSOUT '/vol/emos_nc/output'
+                inlimit /limits:linux_cluster
+                family swdfp_tpi
+                  task w_efi
+                    edit PARAMETER 'tpi'
+                endfamily
+                family swdfp_10wsi
+                  task w_efi
+                    edit PARAMETER '10wsi'
+                endfamily
+                family swdfp_2ti
+                  task w_efi
+                    edit PARAMETER '2ti'
+                endfamily
+                family swdfp_10fgi
+                  task w_efi
+                    edit PARAMETER '10fgi'
+                endfamily
+              endfamily
+              family proba
+                trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/prob eq complete)
+                edit PLOT_LOCATION '/webplots_e/data/swdfp/proba'
+                edit STEPS '06/12/18/24/30/36/42/48/54/60/66/72/84/96/108/120/132/144'
+                task swdfp_proba
+                task swdfp_tp
+                  trigger ./swdfp_proba eq complete
+                task swdfp_ff
+                  trigger ./swdfp_proba eq complete
+                task swdfp_tp24
+                  trigger ./swdfp_proba eq complete
+                  edit STEPS '24/48/72/96/120'
+                task swdfp_proba_clean
+                  trigger ./swdfp_tp eq complete and ./swdfp_ff eq complete and ./swdfp_tp24 eq complete
+              endfamily
+              task swdfp_epsgram
+                trigger /emc_36r1/pop/00/data/metgram eq complete
+            endfamily
+          endfamily
+        endfamily
+        family verification
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit DATEMASK '11.*.*'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/web/verification'
+          inlimit /limits:linux_cluster
+          task w_probas
+          task w_costloss
+          task w_timeseries
+        endfamily
+        task web_update
+          trigger pf/proba/members/legA eq complete and pf/proba/additional eq complete and pf/plumes eq complete and pf/classic eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit PACKAGES 'esuite'
+          edit UPDATE_STREAM 'enfo'
+          inlimit /emc_36r1/limits:webplots
+      endfamily
+      family paper
+        trigger web/web_update eq complete
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/plot'
+        inlimit /limits:linux_cluster
+        task epsgram
+          trigger ../data/metgram eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/paper'
+        family enplot
+          complete /emc_36r1/pop/00/events:cf
+          trigger ( /emc_36r1/pop/00/events eq complete) and ( ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/clusters eq complete))
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit ANALYSIS 'NO'
+          task sthemi
+        endfamily
+        family tube
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/clusters eq complete)
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          inlimit /limits:linux_cluster
+          task ptubfr
+          task tubfrfax
+            trigger ptubfr eq complete
+            edit QUEUE 'emos'
+          task tubukfax
+            trigger ptubuk eq complete
+            edit QUEUE 'emos'
+          task ptubuk
+            trigger ptubfr eq complete
+        endfamily
+        family prob
+          trigger ( /emc_36r1/main:YMD gt /emc_36r1/pop:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/pop:YMD and /emc_36r1/main/00/legA/postproc/prob eq complete)
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'plots-medium'
+          edit ANALYSIS 'YES'
+          inlimit /emc_36r1/limits:webplots
+          task clplot
+            trigger ../enplot eq complete
+          task s144
+            trigger clplot eq complete
+            edit STEPS '144'
+          task plumea
+          task pb
+        endfamily
+      endfamily
+      task cleanup
+        trigger paper eq complete and web eq complete
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'plots-medium'
+        inlimit /limits:linux_cluster
+        inlimit /emc_36r1/limits:webplots
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      trigger ../main/make eq complete and ./12 eq complete and ./00 eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1'
+  endfamily
+  family msjobs
+    complete ( /emc_36r1/msjobs:YMD le /emc_36r1/main:YMD) and /emc_36r1/main/logfiles eq active
+    repeat date YMD 20091003 20121212 1
+    edit QUEUE 'emos'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit WSHOST 'ecgate'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit SMSOUT '/vol/emos_nc/output'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit STREAM 'EF'
+    edit EMOS_STREAM 'EF'
+    edit SMSURLBASE 'http://ecgate.ecmwf.int:9080'
+    edit SMSURL 'do/events'
+    edit SMSFILES '/home/ma/emos/def/emc_36r1'
+    edit DELTA_DAY '-1'
+    edit LOGTASK 'msjobs'
+    family 12
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete and /emc_36r1/main/12/legA/postproc/clusters eq complete and /emc_36r1/main/12/ref/model eq complete)
+      edit EMOS_BASE '12'
+      edit DELTA_DAY '-1'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs'
+      edit SMSTRIES '1'
+      family ms036
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '036'
+        edit MSJ_DIR 'ef12h036'
+        task ms_ec
+      endfamily
+      family ms072
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '072'
+        edit MSJ_DIR 'ef12h072'
+        task ms_ec
+      endfamily
+      family ms120
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '120'
+        edit MSJ_DIR 'ef12h120'
+        task ms_ec
+      endfamily
+      family ms144
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '144'
+        edit MSJ_DIR 'ef12h144'
+        task ms_ec
+      endfamily
+      family ms240
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'ef12h240'
+        task ms_ec
+      endfamily
+      family ms360
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legB/fc eq complete)
+        edit EMOS_TIME_STEP_H '360'
+        edit MSJ_DIR 'ef12h360'
+        task ms_ec
+      endfamily
+      family ms240post
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'ef12h240post'
+        task ms_ec
+      endfamily
+      family ms360post
+        edit EMOS_TIME_STEP_H '360'
+        edit MSJ_DIR 'ef12h360post'
+        task ms_ec
+      endfamily
+      family ms240metgram
+        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/12/data/metgram/240/gdb eq complete)
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'ef12h240metgram'
+        task ms_ec
+      endfamily
+      family ms360metgram
+        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/12/data/metgram/15d/gdb eq complete)
+        edit EMOS_TIME_STEP_H '360'
+        edit MSJ_DIR 'ef12h360metgram'
+        task ms_ec
+      endfamily
+      family ems240
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/12/legA/prod2diss eq complete)
+        edit EMOS_TIME_STEP '240'
+        edit MSJ_DIR 'eef12h240'
+        task ms_ec
+      endfamily
+    endfamily
+    family 00
+      trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete and /emc_36r1/main/00/legA/postproc/clusters eq complete and /emc_36r1/main/00/ref/model eq complete)
+      edit EMOS_BASE '00'
+      edit DELTA_DAY '0'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1/msjobs'
+      edit SMSTRIES '1'
+      family ms036
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '036'
+        edit MSJ_DIR 'ef00h036'
+        task ms_ec
+      endfamily
+      family ms072
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '072'
+        edit MSJ_DIR 'ef00h072'
+        task ms_ec
+      endfamily
+      family ms120
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '120'
+        edit MSJ_DIR 'ef00h120'
+        task ms_ec
+      endfamily
+      family ms144
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '144'
+        edit MSJ_DIR 'ef00h144'
+        task ms_ec
+      endfamily
+      family ms240
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/fc eq complete)
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'ef00h240'
+        task ms_ec
+      endfamily
+      family ms360
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legB/fc eq complete)
+        edit EMOS_TIME_STEP_H '360'
+        edit MSJ_DIR 'ef00h360'
+        task ms_ec
+      endfamily
+      family ms240post
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'ef00h240post'
+        task ms_ec
+      endfamily
+      family ms360post
+        edit EMOS_TIME_STEP_H '360'
+        edit MSJ_DIR 'ef00h360post'
+        task ms_ec
+      endfamily
+      family ms240metgram
+        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/00/data/metgram/240/gdb eq complete)
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'ef00h240metgram'
+        task ms_ec
+      endfamily
+      family ms360metgram
+        trigger ( /emc_36r1/pop:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/pop:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/pop/00/data/metgram/15d/gdb eq complete)
+        edit EMOS_TIME_STEP_H '360'
+        edit MSJ_DIR 'ef00h360metgram'
+        task ms_ec
+      endfamily
+      family ems240
+        trigger ( /emc_36r1/main:YMD gt /emc_36r1/msjobs:YMD) or ( /emc_36r1/main:YMD eq /emc_36r1/msjobs:YMD and /emc_36r1/main/00/legA/prod2diss eq complete)
+        edit EMOS_TIME_STEP '240'
+        edit MSJ_DIR 'eef00h240'
+        task ms_ec
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      inlimit /limits:linux_cluster
+    task logfiles
+      trigger ./00 eq complete and ./12 eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      inlimit /limits:linux_cluster
+      time 13:15
+  endfamily
+  family verify
+    trigger ./00:YMD gt ./verify:YMD or ( ./00:YMD eq ./verify:YMD and ./00/ref/tue eq complete)
+    repeat date YMD 20091007 20121212 7
+    edit ACCOUNT 'oeenfo'
+    edit WSHOST 'linux_cluster'
+    edit UPDATE_WEB_NOW 'yes'
+    edit EMOS_BASE '00'
+    edit QUEUE 'emos-e'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit SMSOUT '/vol/emos_nc/output'
+    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/leg/verify'
+    edit FSFAMILY 'assim'
+    edit FCTOTAL '51'
+    edit DELTA_DAY '-27'
+    edit RUNHINDCAST '1'
+    edit RUNVARFC '1'
+    edit EMOS_TYPE '00'
+    edit LOGTASK '00'
+    inlimit /limits:linux_cluster
+    family init
+      task list_verif
+      task getana
+        trigger list_verif eq complete
+      task getmofc
+        trigger getana eq complete
+    endfamily
+    family anomaly
+      trigger init eq complete
+      family temp
+        edit VAR 'TEMP'
+        task stats_verif
+        task plot_verif
+          trigger stats_verif eq complete
+      endfamily
+      family rain
+        trigger temp eq complete
+        edit VAR 'RAIN'
+        task stats_verif
+        task plot_verif
+          trigger stats_verif eq complete
+      endfamily
+      family mslp
+        trigger rain eq complete
+        edit VAR 'MSLP'
+        task stats_verif
+        task plot_verif
+          trigger stats_verif eq complete
+      endfamily
+      family 2mtm
+        trigger mslp eq complete
+        edit VAR '2MTM'
+        task stats_verif
+        task plot_verif
+          trigger stats_verif eq complete
+      endfamily
+      family z500
+        trigger ./2mtm eq complete
+        task flowz500_verif
+      endfamily
+      task webvanomaly
+        trigger ./z500 eq complete
+        edit FSFAMILY 'mofc'
+        edit QUEUE 'plots-medium'
+    endfamily
+    family scores
+      trigger anomaly eq complete
+      task mofcdaily_verif
+      task mofcweekly_verif
+        trigger mofcdaily_verif eq complete
+      task alldaily
+        trigger mofcweekly_verif eq complete
+      task allweekly
+        trigger alldaily eq complete
+      task sctoweb
+        trigger allweekly eq complete
+        edit FSFAMILY 'mofc'
+    endfamily
+    family probability
+      trigger scores eq complete
+      family rain
+        edit VAR 'RAIN'
+        task table
+        task stats
+          trigger ./table eq complete
+        task stats1
+          trigger ./stats eq complete
+        task plot_relia
+          trigger ./stats1 eq complete
+        task plot_roc
+          trigger ./plot_relia eq complete
+        task plot_rocmap
+          trigger ./plot_roc eq complete
+        task plot_rpssmap
+          trigger ./plot_rocmap eq complete
+        task plot_value
+          trigger ./plot_rpssmap eq complete
+      endfamily
+      family temp
+        trigger ./rain eq complete
+        edit VAR 'TEMP'
+        task table
+        task stats
+          trigger ./table eq complete
+        task stats1
+          trigger ./stats eq complete
+        task plot_relia
+          trigger ./stats1 eq complete
+        task plot_roc
+          trigger ./plot_relia eq complete
+        task plot_rocmap
+          trigger ./plot_roc eq complete
+        task plot_rpssmap
+          trigger ./plot_rocmap eq complete
+        task plot_value
+          trigger ./plot_rpssmap eq complete
+      endfamily
+      family mslp
+        trigger ./temp eq complete
+        edit VAR 'MSLP'
+        task table
+        task stats
+          trigger ./table eq complete
+        task stats1
+          trigger ./stats eq complete
+        task plot_relia
+          trigger ./stats1 eq complete
+        task plot_roc
+          trigger ./plot_relia eq complete
+        task plot_rocmap
+          trigger ./plot_roc eq complete
+        task plot_rpssmap
+          trigger ./plot_rocmap eq complete
+        task plot_value
+          trigger ./plot_rpssmap eq complete
+      endfamily
+      family 2mtm
+        trigger ./mslp eq complete
+        edit VAR '2MTM'
+        task table
+        task stats
+          trigger ./table eq complete
+        task stats1
+          trigger ./stats eq complete
+        task plot_relia
+          trigger ./stats1 eq complete
+        task plot_roc
+          trigger ./plot_relia eq complete
+        task plot_rocmap
+          trigger ./plot_roc eq complete
+        task plot_rpssmap
+          trigger ./plot_rocmap eq complete
+        task plot_value
+          trigger ./plot_rpssmap eq complete
+      endfamily
+      family pbtoweb
+        trigger ./2mtm eq complete
+        edit FSFAMILY 'mofc'
+        task reliability
+        task roc
+          trigger ./reliability eq complete
+        task rocmap
+          trigger ./roc eq complete
+        task rpssmap
+          trigger ./rocmap eq complete
+        task value
+          trigger ./rpssmap eq complete
+      endfamily
+    endfamily
+    task clean_verif
+      trigger init eq complete and anomaly eq complete and scores eq complete and probability eq complete
+      edit DELTA_DAY '-14'
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      edit FSFAMILY 'mc'
+    task logfiles
+      late -s +00:05 -c +00:35
+      trigger logfilestore eq complete and init eq complete and anomaly eq complete and scores eq complete and probability eq complete and clean_verif eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FSFAMILY 'mc'
+      edit SMSFILES '/home/ma/emos/def/emc_36r1'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+  family efi_next
+    edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi'
+    edit EVERSION '0046'
+    edit IMPL_DATE '2012121212'
+    edit EMOS_BASE '00'
+    edit MARS_DB 'marsod'
+    edit EMOS_TYPE 'undef'
+    edit EPS_VERSION '0046'
+    edit VERSION '9939'
+    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+    edit SMSURL 'GENFO/00'
+    edit UPDATE_WEB_NOW 'yes'
+    edit MARS_NEW '0'
+    edit QUEUE 'ns'
+    edit QUEUE_EPILOG 'ns'
+    edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/s1b/emos_esuite/emos_data/9946/log'
+    edit SMSOUT '/s1b/emos_esuite/emos_data/9946/log'
+    limit ext 45
+    inlimit /limits:c1b
+    inlimit ext
+    family mn
+      trigger ./mn:YMD lt ./clim:YMD
+      repeat date YMD 20080221 20121212 1
+      family deps
+        edit SSMFILES '/home/ma/emos/def/emc_36r1'
+        family 00
+          trigger ( ( ( /emc_36r1/main/00/legA/postproc eq complete) and ( /emc_36r1/main/00/legB/postproc eq complete)) and ( /emc_36r1/main:YMD eq ../../mn:YMD)) or ( /emc_36r1/main:YMD gt ../../mn:YMD)
+          task dummy
+            complete 1 eq 1
+        endfamily
+        family 12
+          trigger ( ( ( /emc_36r1/main/12/legA/postproc eq complete) and ( /emc_36r1/main/12/legB/postproc eq complete)) and ( /emc_36r1/main:YMD eq ../../mn:YMD)) or ( /emc_36r1/main:YMD gt ../../mn:YMD)
+          task dummy
+            complete 1 eq 1
+        endfamily
+      endfamily
+      family 12
+        trigger ./deps/12 eq complete
+        edit EMOS_BASE '12'
+        family op
+          edit EPSLEG '1'
+          task stage
+          family 024
+            family 012_036
+              edit ACC '024'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_060
+              edit ACC '024'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_084
+              edit ACC '024'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_108
+              edit ACC '024'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_132
+              edit ACC '024'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '024'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '024'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '024'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            trigger ./024 eq complete
+            family 000_120
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_144
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            trigger ./024 eq complete
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family nop
+          edit EPSLEG '2'
+          task stage
+          family 024
+            family 012_036
+              edit ACC '024'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '036'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_060
+              edit ACC '024'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '060'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_084
+              edit ACC '024'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '084'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_108
+              edit ACC '024'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '108'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_132
+              edit ACC '024'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '132'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 132_156
+              edit ACC '024'
+              edit EFI_STEP1 '132'
+              edit EFI_STEP2 '156'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 156_180
+              edit ACC '024'
+              edit EFI_STEP1 '156'
+              edit EFI_STEP2 '180'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 180_204
+              edit ACC '024'
+              edit EFI_STEP1 '180'
+              edit EFI_STEP2 '204'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 204_228
+              edit ACC '024'
+              edit EFI_STEP1 '204'
+              edit EFI_STEP2 '228'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '24'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '24'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '24'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 240_264
+              edit ACC '24'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '264'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 264_288
+              edit ACC '24'
+              edit EFI_STEP1 '264'
+              edit EFI_STEP2 '288'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 288_312
+              edit ACC '24'
+              edit EFI_STEP1 '288'
+              edit EFI_STEP2 '312'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 312_336
+              edit ACC '24'
+              edit EFI_STEP1 '312'
+              edit EFI_STEP2 '336'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 336_360
+              edit ACC '24'
+              edit EFI_STEP1 '336'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 072
+            family 012_084
+              edit ACC '072'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '084'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_108
+              edit ACC '072'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '108'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_132
+              edit ACC '072'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '132'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_156
+              edit ACC '072'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '156'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_180
+              edit ACC '072'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '180'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 132_204
+              edit ACC '072'
+              edit EFI_STEP1 '132'
+              edit EFI_STEP2 '204'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 156_228
+              edit ACC '072'
+              edit EFI_STEP1 '156'
+              edit EFI_STEP2 '228'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            family 012_132
+              edit ACC '120'
+              edit EFI_STEP1 '012'
+              edit EFI_STEP2 '132'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 036_156
+              edit ACC '120'
+              edit EFI_STEP1 '036'
+              edit EFI_STEP2 '156'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 060_180
+              edit ACC '120'
+              edit EFI_STEP1 '060'
+              edit EFI_STEP2 '180'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 084_204
+              edit ACC '120'
+              edit EFI_STEP1 '084'
+              edit EFI_STEP2 '204'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 108_228
+              edit ACC '120'
+              edit EFI_STEP1 '108'
+              edit EFI_STEP2 '228'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 240_360
+              edit ACC '120'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 360
+            family 000_360
+              edit ACC '360'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_op
+          trigger op eq complete
+          edit EPSLEG '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_nop
+          trigger nop eq complete
+          edit EPSLEG '2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmin
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family ts
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family hsttmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'hsstmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family data
+          trigger arch_op eq complete and arch_nop eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efidata
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efidata
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efidata
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efidata
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efidata
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efidata
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efidata
+          endfamily
+          family hsstmax
+            edit PARAM 'hsstmax'
+            task efidata
+              edit PARAM 'hsttmax'
+          endfamily
+        endfamily
+        family plot
+          trigger data eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSURLBASE 'http://intra.ecmwf.int/plots'
+          edit SMSURL 'd/inspect/esuite/esuite_33r1/medium/eps/efi/'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+          edit METVIEW 'metview_new'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efiplot
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efiplot
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efiplot
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efiplot
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efiplot
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efiplot
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efiplot
+          endfamily
+          family hsstmax
+            edit PARAM 'hsstmax'
+            task efiplot
+              edit PARAM 'hsstmax'
+          endfamily
+          family hsttmax
+            edit PARAM 'hsttmax'
+            task efiplot
+          endfamily
+        endfamily
+      endfamily
+      family 00
+        trigger ( ./deps/00 eq complete or ./deps/00 eq unknown) and ( ./12 eq complete or ./12 eq unknown)
+        edit EMOS_BASE '00'
+        edit DELTA_DAY '1'
+        edit STEP1 '-1'
+        family op
+          edit EPSLEG '1'
+          task stage
+          family 024
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '024'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '024'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '024'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            trigger ./024 eq complete
+            family 000_120
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_144
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            trigger ./024 eq complete
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family nop
+          edit EPSLEG '2'
+          task stage
+          family 024
+            family 000_024
+              edit ACC '024'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '024'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_048
+              edit ACC '024'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '048'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_072
+              edit ACC '024'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '072'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_096
+              edit ACC '024'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '096'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_120
+              edit ACC '024'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '120'
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family reproc
+              family 120_144
+                edit ACC '024'
+                edit EFI_STEP1 '120'
+                edit EFI_STEP2 '144'
+                family tp
+                  edit RF_NAME 'tp'
+                  task extindex
+                endfamily
+              endfamily
+              family 144_168
+                edit ACC '024'
+                edit EFI_STEP1 '144'
+                edit EFI_STEP2 '168'
+                family tp
+                  edit RF_NAME 'tp'
+                  task extindex
+                endfamily
+              endfamily
+            endfamily
+            family 120_144
+              edit ACC '024'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 144_168
+              edit ACC '024'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '168'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10fg
+                edit RF_NAME '10fg'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmin
+                edit RF_NAME '2tmin'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2tmax
+                edit RF_NAME '2tmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family hsttmax
+                edit RF_NAME 'hsttmax'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family ts
+                edit RF_NAME 'ts'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 168_192
+              edit ACC '24'
+              edit EFI_STEP1 '168'
+              edit EFI_STEP2 '192'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 192_216
+              edit ACC '24'
+              edit EFI_STEP1 '192'
+              edit EFI_STEP2 '216'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 216_240
+              edit ACC '24'
+              edit EFI_STEP1 '216'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 240_264
+              edit ACC '24'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '264'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 264_288
+              edit ACC '24'
+              edit EFI_STEP1 '264'
+              edit EFI_STEP2 '288'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 288_312
+              edit ACC '24'
+              edit EFI_STEP1 '288'
+              edit EFI_STEP2 '312'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 312_336
+              edit ACC '24'
+              edit EFI_STEP1 '312'
+              edit EFI_STEP2 '336'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+            family 336_360
+              edit ACC '24'
+              edit EFI_STEP1 '336'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+              endfamily
+            endfamily
+          endfamily
+          family 072
+            family 000_072
+              edit ACC '072'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '072'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_096
+              edit ACC '072'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '096'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_120
+              edit ACC '072'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '120'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_144
+              edit ACC '072'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '144'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_168
+              edit ACC '072'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 120_192
+              edit ACC '072'
+              edit EFI_STEP1 '120'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 144_216
+              edit ACC '072'
+              edit EFI_STEP1 '144'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 120
+            family 000_120
+              edit ACC '120'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '120'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 024_144
+              edit ACC '120'
+              edit EFI_STEP1 '024'
+              edit EFI_STEP2 '144'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 048_168
+              edit ACC '120'
+              edit EFI_STEP1 '048'
+              edit EFI_STEP2 '168'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 072_192
+              edit ACC '120'
+              edit EFI_STEP1 '072'
+              edit EFI_STEP2 '192'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 096_216
+              edit ACC '120'
+              edit EFI_STEP1 '096'
+              edit EFI_STEP2 '216'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+            family 240_360
+              edit ACC '120'
+              edit EFI_STEP1 '240'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 240
+            family 000_240
+              edit ACC '240'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '240'
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+          family 360
+            family 000_360
+              edit ACC '360'
+              edit EFI_STEP1 '000'
+              edit EFI_STEP2 '360'
+              family tp
+                edit RF_NAME 'tp'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 2t
+                edit RF_NAME '2t'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+              family 10ff
+                edit RF_NAME '10ff'
+                task prepeps
+                task extindex
+                  trigger ./prepeps eq complete
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_op
+          trigger op eq complete
+          edit EPSLEG '1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family arch_nop
+          trigger nop eq complete
+          edit EPSLEG '2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+          task efi2fdb
+            edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+            event none
+          family arch
+            trigger ./efi2fdb eq complete
+            family 2t
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2t'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10ff
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10ff'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 10fg
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '10fg'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family tp
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'tp'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmin
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmin'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family 2tmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME '2tmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family ts
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'ts'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+            family hsttmax
+              edit step1 '24'
+              edit step2 '24'
+              edit RF_NAME 'hsstmax'
+              task efi
+                label info ""
+              family sot
+                edit EFI_TYPE 'sot'
+                task efi
+              endfamily
+            endfamily
+          endfamily
+        endfamily
+        family data
+          trigger arch_op eq complete and arch_nop eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efidata
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efidata
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efidata
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efidata
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efidata
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efidata
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efidata
+          endfamily
+          family hsstmax
+            edit PARAM 'hsstmax'
+            task efidata
+          endfamily
+        endfamily
+        family plot
+          trigger data eq complete
+          edit WSHOST 'linux_cluster'
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit SMSURLBASE 'http://intra.ecmwf.int/plots'
+          edit SMSURL 'd/inspect/esuite/esuite_33r1/medium/eps/efi/'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/smsfiles/web'
+          edit METVIEW 'metview_new'
+          inlimit /limits:linux_cluster
+          family 2t
+            edit PARAM '2t'
+            task efiplot
+          endfamily
+          family 2tmin
+            edit PARAM '2tmin'
+            task efiplot
+          endfamily
+          family 2tmax
+            edit PARAM '2tmax'
+            task efiplot
+          endfamily
+          family tp
+            edit PARAM 'tp'
+            task efiplot
+          endfamily
+          family 10ff
+            edit PARAM '10ff'
+            task efiplot
+          endfamily
+          family 10fg
+            edit PARAM '10fg'
+            task efiplot
+          endfamily
+          family sf
+            edit PARAM 'sf'
+            task efiplot
+          endfamily
+          family hsstmax
+            edit PARAM 'hsstmax'
+            task efiplot
+              edit PARAM 'hsttmax'
+          endfamily
+          family hsttmax
+            edit PARAM 'hsttmax'
+            task efiplot
+              edit PARAM 'hsstmax'
+          endfamily
+        endfamily
+      endfamily
+      task efi_cleaner
+        trigger ( ./12 eq complete or ./12 eq unknown) and ( ./00 eq complete or ./00 eq unknown)
+    endfamily
+    family hind
+      repeat date YMD 20080717 20121212 7
+      edit DELTA_DAY '0'
+      family stage
+        edit RF_NAME 'all'
+        edit RETRIEVE 'stage'
+        task prep
+      endfamily
+      family op
+        trigger ./stage eq complete
+        edit EPSLEG '1'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          trigger ./024 eq complete
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          trigger ./024 eq complete
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family nop
+        trigger ./stage eq complete
+        edit EPSLEG '2'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 240_264
+            edit ACC '024'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '264'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 264_288
+            edit ACC '024'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '288'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 288_312
+            edit ACC '024'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '312'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 312_336
+            edit ACC '024'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+          family 336_360
+            edit ACC '024'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '360'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 000
+          family 006_006
+            edit ACC '000'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '006'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 012_012
+            edit ACC '000'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '012'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 018_018
+            edit ACC '000'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '018'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 024_024
+            edit ACC '000'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '024'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 030_030
+            edit ACC '000'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '030'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 036_036
+            edit ACC '000'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '036'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 042_042
+            edit ACC '000'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '042'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 048_048
+            edit ACC '000'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '048'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 054_054
+            edit ACC '000'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '054'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 060_060
+            edit ACC '000'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '060'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 066_066
+            edit ACC '000'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '066'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 072_072
+            edit ACC '000'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '072'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 078_078
+            edit ACC '000'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '078'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 084_084
+            edit ACC '000'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '084'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 090_090
+            edit ACC '000'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '090'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 096_096
+            edit ACC '000'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '096'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 102_102
+            edit ACC '000'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '102'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 108_108
+            edit ACC '000'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '108'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 114_114
+            edit ACC '000'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '114'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_120
+            edit ACC '000'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '120'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 126_126
+            edit ACC '000'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '126'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 132_132
+            edit ACC '000'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '132'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 138_138
+            edit ACC '000'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '138'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 144_144
+            edit ACC '000'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '144'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 150_150
+            edit ACC '000'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '150'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 156_156
+            edit ACC '000'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '156'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 162_162
+            edit ACC '000'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '162'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 168_168
+            edit ACC '000'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '168'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 174_174
+            edit ACC '000'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '174'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 180_180
+            edit ACC '000'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '180'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 186_186
+            edit ACC '000'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '186'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 192_192
+            edit ACC '000'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '192'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 198_198
+            edit ACC '000'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '198'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 204_204
+            edit ACC '000'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '204'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 210_210
+            edit ACC '000'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '210'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 216_216
+            edit ACC '000'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '216'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 222_222
+            edit ACC '000'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '222'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 228_228
+            edit ACC '000'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '228'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 234_234
+            edit ACC '000'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '234'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 240_240
+            edit ACC '000'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '240'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 252_252
+            edit ACC '000'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '252'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 264_264
+            edit ACC '000'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '264'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 276_276
+            edit ACC '000'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '276'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 288_288
+            edit ACC '000'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '288'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 300_300
+            edit ACC '000'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '300'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 312_312
+            edit ACC '000'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '312'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 324_324
+            edit ACC '000'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '324'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 336_336
+            edit ACC '000'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '336'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 348_348
+            edit ACC '000'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '348'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+          family 360_360
+            edit ACC '000'
+            edit EFI_STEP1 '360'
+            edit EFI_STEP2 '360'
+            family 850t
+              edit RF_NAME '850t'
+              task prep
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 006
+          family 000_006
+            edit ACC '006'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '006'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 006_012
+            edit ACC '006'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 012_018
+            edit ACC '006'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '018'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 018_024
+            edit ACC '006'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 024_030
+            edit ACC '006'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '030'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 030_036
+            edit ACC '006'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 036_042
+            edit ACC '006'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '042'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 042_048
+            edit ACC '006'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 048_054
+            edit ACC '006'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '054'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 054_060
+            edit ACC '006'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 060_066
+            edit ACC '006'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '066'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 066_072
+            edit ACC '006'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 072_078
+            edit ACC '006'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '078'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 078_084
+            edit ACC '006'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 084_090
+            edit ACC '006'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '090'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 090_096
+            edit ACC '006'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 096_102
+            edit ACC '006'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '102'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 102_108
+            edit ACC '006'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 108_114
+            edit ACC '006'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '114'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 114_120
+            edit ACC '006'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 120_126
+            edit ACC '006'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '126'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 126_132
+            edit ACC '006'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 132_138
+            edit ACC '006'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '138'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 138_144
+            edit ACC '006'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 144_150
+            edit ACC '006'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '150'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 150_156
+            edit ACC '006'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 156_162
+            edit ACC '006'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '162'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 162_168
+            edit ACC '006'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 168_174
+            edit ACC '006'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '174'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 174_180
+            edit ACC '006'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 180_186
+            edit ACC '006'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '186'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 186_192
+            edit ACC '006'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 192_198
+            edit ACC '006'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '198'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 198_204
+            edit ACC '006'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 204_210
+            edit ACC '006'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '210'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 210_216
+            edit ACC '006'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 216_222
+            edit ACC '006'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '222'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 222_228
+            edit ACC '006'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 228_234
+            edit ACC '006'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '234'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+          family 234_240
+            edit ACC '006'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 012
+          family 000_012
+            edit ACC '012'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 012_024
+            edit ACC '012'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 024_036
+            edit ACC '012'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 036_048
+            edit ACC '012'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 048_060
+            edit ACC '012'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 060_072
+            edit ACC '012'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 072_084
+            edit ACC '012'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 084_096
+            edit ACC '012'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 096_108
+            edit ACC '012'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 108_120
+            edit ACC '012'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 120_132
+            edit ACC '012'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 132_144
+            edit ACC '012'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 144_156
+            edit ACC '012'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 156_168
+            edit ACC '012'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 168_180
+            edit ACC '012'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 180_192
+            edit ACC '012'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 192_204
+            edit ACC '012'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 204_216
+            edit ACC '012'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 216_228
+            edit ACC '012'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 228_240
+            edit ACC '012'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 240_252
+            edit ACC '012'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '252'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 252_264
+            edit ACC '012'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '264'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 264_276
+            edit ACC '012'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '276'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 276_288
+            edit ACC '012'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '288'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 288_300
+            edit ACC '012'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '300'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 300_312
+            edit ACC '012'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '312'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 312_324
+            edit ACC '012'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '324'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 324_336
+            edit ACC '012'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '336'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 336_348
+            edit ACC '012'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '348'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+          family 348_360
+            edit ACC '012'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 072
+          trigger ./024 eq complete
+          family 000_072
+            edit ACC '072'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 024_096
+            edit ACC '072'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 048_120
+            edit ACC '072'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 072_144
+            edit ACC '072'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 096_168
+            edit ACC '072'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_192
+            edit ACC '072'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 144_216
+            edit ACC '072'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 168_240
+            edit ACC '072'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          trigger ./024 eq complete
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 048_168
+            edit ACC '120'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 072_192
+            edit ACC '120'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 096_216
+            edit ACC '120'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_240
+            edit ACC '120'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 240_360
+            edit ACC '120'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          trigger ./024 eq complete
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+          family 120_360
+            edit ACC '240'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+        family 360
+          trigger ./024 eq complete
+          family 000_360
+            edit ACC '360'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family check_nrt
+        complete ./check_nrt/go eq complete
+        edit REFPATH '/mofc/hc2'
+        family catchup
+          task check_nrt
+            event ok
+        endfamily
+        family rt
+          trigger catchup eq complete
+          task check_nrt
+            event ok
+            cron -w 1 06:30
+        endfamily
+        task go
+          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
+          trigger 0 eq 1
+      endfamily
+    endfamily
+    family clim
+      repeat date YMD 20080717 20121212 7
+      edit DELTA_DAY '-7'
+      family deps
+        trigger ../hind:YMD gt ../clim:YMD
+        task dummy
+          complete 1 eq 1
+      endfamily
+      family op
+        trigger deps eq complete
+        edit EPSLEG '1'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family op2fdb
+        trigger op eq complete
+        edit EPSLEG '1'
+        task efi2fdb
+          edit KIND 'clim1'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+      endfamily
+      family nop
+        trigger deps eq complete
+        edit EPSLEG '2'
+        family 024
+          family 000_024
+            edit ACC '024'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '024'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_036
+            edit ACC '024'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '036'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_048
+            edit ACC '024'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '048'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_060
+            edit ACC '024'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '060'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_072
+            edit ACC '024'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '072'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_084
+            edit ACC '024'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '084'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_096
+            edit ACC '024'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '096'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_108
+            edit ACC '024'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '108'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_120
+            edit ACC '024'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '120'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_132
+            edit ACC '024'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '132'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_144
+            edit ACC '024'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '144'
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_168
+            edit ACC '024'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '168'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_192
+            edit ACC '024'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '192'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_216
+            edit ACC '024'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '216'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_240
+            edit ACC '024'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_264
+            edit ACC '024'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '264'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 264_288
+            edit ACC '024'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '288'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 288_312
+            edit ACC '024'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '312'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 312_336
+            edit ACC '024'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '336'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+          family 336_360
+            edit ACC '024'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '360'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+            family hsttmax
+              edit RF_NAME 'hsttmax'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 000
+          family 006_006
+            edit ACC '000'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '006'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_012
+            edit ACC '000'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '012'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 018_018
+            edit ACC '000'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '018'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_024
+            edit ACC '000'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '024'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 030_030
+            edit ACC '000'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '030'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_036
+            edit ACC '000'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '036'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 042_042
+            edit ACC '000'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '042'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_048
+            edit ACC '000'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '048'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 054_054
+            edit ACC '000'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '054'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_060
+            edit ACC '000'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '060'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 066_066
+            edit ACC '000'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '066'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_072
+            edit ACC '000'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '072'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 078_078
+            edit ACC '000'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '078'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_084
+            edit ACC '000'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '084'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 090_090
+            edit ACC '000'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '090'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_096
+            edit ACC '000'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '096'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 102_102
+            edit ACC '000'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '102'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_108
+            edit ACC '000'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '108'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 114_114
+            edit ACC '000'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '114'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_120
+            edit ACC '000'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '120'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 126_126
+            edit ACC '000'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '126'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 132_132
+            edit ACC '000'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '132'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 138_138
+            edit ACC '000'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '138'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_144
+            edit ACC '000'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '144'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 150_150
+            edit ACC '000'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '150'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 156_156
+            edit ACC '000'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '156'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 162_162
+            edit ACC '000'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '162'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_168
+            edit ACC '000'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '168'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 174_174
+            edit ACC '000'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '174'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 180_180
+            edit ACC '000'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '180'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 186_186
+            edit ACC '000'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '186'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_192
+            edit ACC '000'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '192'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 198_198
+            edit ACC '000'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '198'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 204_204
+            edit ACC '000'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '204'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 210_210
+            edit ACC '000'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '210'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_216
+            edit ACC '000'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '216'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 222_222
+            edit ACC '000'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '222'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 228_228
+            edit ACC '000'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '228'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 234_234
+            edit ACC '000'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '234'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_240
+            edit ACC '000'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '240'
+            family 10dd
+              edit RF_NAME '10dd'
+              task prep_sort
+            endfamily
+            family tcc
+              edit RF_NAME 'tcc'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 252_252
+            edit ACC '000'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '252'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 264_264
+            edit ACC '000'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '264'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 276_276
+            edit ACC '000'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '276'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 288_288
+            edit ACC '000'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '288'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 300_300
+            edit ACC '000'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '300'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 312_312
+            edit ACC '000'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '312'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 324_324
+            edit ACC '000'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '324'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 336_336
+            edit ACC '000'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '336'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 348_348
+            edit ACC '000'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '348'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+          family 360_360
+            edit ACC '000'
+            edit EFI_STEP1 '360'
+            edit EFI_STEP2 '360'
+            family 850t
+              edit RF_NAME '850t'
+              task prep_sort
+            endfamily
+            family 500z
+              edit RF_NAME '500z'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 006
+          family 000_006
+            edit ACC '006'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '006'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 006_012
+            edit ACC '006'
+            edit EFI_STEP1 '006'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_018
+            edit ACC '006'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '018'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 018_024
+            edit ACC '006'
+            edit EFI_STEP1 '018'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_030
+            edit ACC '006'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '030'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 030_036
+            edit ACC '006'
+            edit EFI_STEP1 '030'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_042
+            edit ACC '006'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '042'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 042_048
+            edit ACC '006'
+            edit EFI_STEP1 '042'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_054
+            edit ACC '006'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '054'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 054_060
+            edit ACC '006'
+            edit EFI_STEP1 '054'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_066
+            edit ACC '006'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '066'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 066_072
+            edit ACC '006'
+            edit EFI_STEP1 '066'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_078
+            edit ACC '006'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '078'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 078_084
+            edit ACC '006'
+            edit EFI_STEP1 '078'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_090
+            edit ACC '006'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '090'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 090_096
+            edit ACC '006'
+            edit EFI_STEP1 '090'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_102
+            edit ACC '006'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '102'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 102_108
+            edit ACC '006'
+            edit EFI_STEP1 '102'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_114
+            edit ACC '006'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '114'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 114_120
+            edit ACC '006'
+            edit EFI_STEP1 '114'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_126
+            edit ACC '006'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '126'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 126_132
+            edit ACC '006'
+            edit EFI_STEP1 '126'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 132_138
+            edit ACC '006'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '138'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 138_144
+            edit ACC '006'
+            edit EFI_STEP1 '138'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_150
+            edit ACC '006'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '150'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 150_156
+            edit ACC '006'
+            edit EFI_STEP1 '150'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 156_162
+            edit ACC '006'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '162'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 162_168
+            edit ACC '006'
+            edit EFI_STEP1 '162'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_174
+            edit ACC '006'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '174'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 174_180
+            edit ACC '006'
+            edit EFI_STEP1 '174'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 180_186
+            edit ACC '006'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '186'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 186_192
+            edit ACC '006'
+            edit EFI_STEP1 '186'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_198
+            edit ACC '006'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '198'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 198_204
+            edit ACC '006'
+            edit EFI_STEP1 '198'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 204_210
+            edit ACC '006'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '210'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 210_216
+            edit ACC '006'
+            edit EFI_STEP1 '210'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_222
+            edit ACC '006'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '222'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 222_228
+            edit ACC '006'
+            edit EFI_STEP1 '222'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 228_234
+            edit ACC '006'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '234'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+          family 234_240
+            edit ACC '006'
+            edit EFI_STEP1 '234'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family ts
+              edit RF_NAME 'ts'
+              task prep_sort
+            endfamily
+            family 10fg
+              edit RF_NAME '10fg'
+              task prep_sort
+            endfamily
+            family 2tmin
+              edit RF_NAME '2tmin'
+              task prep_sort
+            endfamily
+            family 2tmax
+              edit RF_NAME '2tmax'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 012
+          family 000_012
+            edit ACC '012'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '012'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 012_024
+            edit ACC '012'
+            edit EFI_STEP1 '012'
+            edit EFI_STEP2 '024'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_036
+            edit ACC '012'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '036'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 036_048
+            edit ACC '012'
+            edit EFI_STEP1 '036'
+            edit EFI_STEP2 '048'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_060
+            edit ACC '012'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '060'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 060_072
+            edit ACC '012'
+            edit EFI_STEP1 '060'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_084
+            edit ACC '012'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '084'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 084_096
+            edit ACC '012'
+            edit EFI_STEP1 '084'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_108
+            edit ACC '012'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '108'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 108_120
+            edit ACC '012'
+            edit EFI_STEP1 '108'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_132
+            edit ACC '012'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '132'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 132_144
+            edit ACC '012'
+            edit EFI_STEP1 '132'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_156
+            edit ACC '012'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '156'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 156_168
+            edit ACC '012'
+            edit EFI_STEP1 '156'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_180
+            edit ACC '012'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '180'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 180_192
+            edit ACC '012'
+            edit EFI_STEP1 '180'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 192_204
+            edit ACC '012'
+            edit EFI_STEP1 '192'
+            edit EFI_STEP2 '204'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 204_216
+            edit ACC '012'
+            edit EFI_STEP1 '204'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 216_228
+            edit ACC '012'
+            edit EFI_STEP1 '216'
+            edit EFI_STEP2 '228'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 228_240
+            edit ACC '012'
+            edit EFI_STEP1 '228'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_252
+            edit ACC '012'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '252'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 252_264
+            edit ACC '012'
+            edit EFI_STEP1 '252'
+            edit EFI_STEP2 '264'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 264_276
+            edit ACC '012'
+            edit EFI_STEP1 '264'
+            edit EFI_STEP2 '276'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 276_288
+            edit ACC '012'
+            edit EFI_STEP1 '276'
+            edit EFI_STEP2 '288'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 288_300
+            edit ACC '012'
+            edit EFI_STEP1 '288'
+            edit EFI_STEP2 '300'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 300_312
+            edit ACC '012'
+            edit EFI_STEP1 '300'
+            edit EFI_STEP2 '312'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 312_324
+            edit ACC '012'
+            edit EFI_STEP1 '312'
+            edit EFI_STEP2 '324'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 324_336
+            edit ACC '012'
+            edit EFI_STEP1 '324'
+            edit EFI_STEP2 '336'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 336_348
+            edit ACC '012'
+            edit EFI_STEP1 '336'
+            edit EFI_STEP2 '348'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+          family 348_360
+            edit ACC '012'
+            edit EFI_STEP1 '348'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 072
+          family 000_072
+            edit ACC '072'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '072'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_096
+            edit ACC '072'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '096'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_120
+            edit ACC '072'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '120'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_144
+            edit ACC '072'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '144'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_168
+            edit ACC '072'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_192
+            edit ACC '072'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 144_216
+            edit ACC '072'
+            edit EFI_STEP1 '144'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 168_240
+            edit ACC '072'
+            edit EFI_STEP1 '168'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 120
+          family 000_120
+            edit ACC '120'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '120'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 024_144
+            edit ACC '120'
+            edit EFI_STEP1 '024'
+            edit EFI_STEP2 '144'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 048_168
+            edit ACC '120'
+            edit EFI_STEP1 '048'
+            edit EFI_STEP2 '168'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 072_192
+            edit ACC '120'
+            edit EFI_STEP1 '072'
+            edit EFI_STEP2 '192'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 096_216
+            edit ACC '120'
+            edit EFI_STEP1 '096'
+            edit EFI_STEP2 '216'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_240
+            edit ACC '120'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '240'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 240_360
+            edit ACC '120'
+            edit EFI_STEP1 '240'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 240
+          family 000_240
+            edit ACC '240'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '240'
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+          family 120_360
+            edit ACC '240'
+            edit EFI_STEP1 '120'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+        family 360
+          family 000_360
+            edit ACC '360'
+            edit EFI_STEP1 '000'
+            edit EFI_STEP2 '360'
+            family tp
+              edit RF_NAME 'tp'
+              task prep_sort
+            endfamily
+            family 2t
+              edit RF_NAME '2t'
+              task prep_sort
+            endfamily
+            family 10ff
+              edit RF_NAME '10ff'
+              task prep_sort
+            endfamily
+          endfamily
+        endfamily
+      endfamily
+      family nop2fdb
+        trigger nop eq complete and ./op2fdb eq complete
+        edit EPSLEG '2'
+        task efi2fdb
+          edit KIND 'clim2'
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/mc/efi_hdc'
+      endfamily
+      family arch_nop
+        trigger nop2fdb eq complete
+        edit EPSLEG '2'
+        edit SMSFILES '/home/ma/emos/def/emc_36r1/archive'
+        family 2t
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '2t'
+          task eficlim
+            label info ""
+        endfamily
+        family 10ff
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '10ff'
+          task eficlim
+            label info ""
+        endfamily
+        family 10fg
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '10fg'
+          task eficlim
+            label info ""
+        endfamily
+        family tp
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'tp'
+          task eficlim
+            label info ""
+        endfamily
+        family 2tmin
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '2tmin'
+          task eficlim
+            label info ""
+        endfamily
+        family 2tmax
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '2tmax'
+          task eficlim
+            label info ""
+        endfamily
+        family ts
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'ts'
+          task eficlim
+            label info ""
+        endfamily
+        family hsttmax
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'hsttmax'
+          task eficlim
+            label info ""
+        endfamily
+        family 10dd
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '10dd'
+          task eficlim
+            label info ""
+        endfamily
+        family 850t
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '850t'
+          task eficlim
+            label info ""
+        endfamily
+        family 500z
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME '500z'
+          task eficlim
+            label info ""
+        endfamily
+        family 2tmean
+          edit step2 '24'
+          edit RF_NAME '2t'
+          edit step1 '0'
+          task eficlim
+            label info ""
+        endfamily
+        family 10ffmean
+          edit step2 '24'
+          edit RF_NAME '10ff'
+          edit step1 '0'
+          task eficlim
+            label info ""
+        endfamily
+        family tcc
+          edit step1 '24'
+          edit step2 '24'
+          edit RF_NAME 'tcc'
+          task eficlim
+            label info ""
+        endfamily
+        family tccmean
+          edit step2 '24'
+          edit RF_NAME 'tcc'
+          edit step1 '0'
+          task eficlim
+            label info ""
+        endfamily
+      endfamily
+      family gdb
+        trigger ( op eq complete and nop eq complete) and ( arch_nop eq complete)
+        edit RHOST 'epsgrams'
+        edit RDIR '/webapps/epsgrams/data/'
+        edit KIND 'clim_15_days'
+        edit WSHOST 'linux_cluster'
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        inlimit /limits:linux_cluster
+        task sync_climate
+        task gclean
+          trigger sync_climate eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
+          edit KEEP_DAYS '14'
+          edit REMOTE_KEEP_DAYS '14'
+        task gdb
+          trigger gclean eq complete and ( /emc_36r1/main:YMD ge /emc_36r1/efi_next/mn:YMD and /emc_36r1/main/00 eq complete)
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
+          label files "="
+          label info "="
+          label local "="
+          label remote "="
+          event fdb
+          event 1 
+        task glink
+          trigger gdb eq complete
+          edit SMSFILES '/home/ma/emos/def/emc_36r1/pop/data/epsgrams/grams'
+      endfamily
+      family check_nrt
+        complete ./check_nrt/go eq complete
+        edit REFPATH '/mofc/hc2'
+        family catchup
+          task check_nrt
+            event ok
+        endfamily
+        family rt
+          trigger catchup eq complete
+          task check_nrt
+            event ok
+            cron -w 3 06:30
+        endfamily
+        task go
+          complete ./rt/check_nrt:ok or ./catchup/check_nrt:ok
+          trigger 0 eq 1
+      endfamily
+      task efi_cleaner
+        trigger ( arch_nop eq complete or arch_nop eq unknown) and ( op eq complete or op eq unknown) and ( nop eq complete or nop eq unknown) and ( op2fdb eq complete or op2fdb eq unknown) and ( nop2fdb eq complete or nop2fdb eq unknown)
+        edit DELTA_DAY '-43'
+    endfamily
+  endfamily
+endsuite
+suite elaw_36r1
+  edit SUITE_TYPE 'law'
+  edit USER 'emos'
+  edit SCHOST 'c1b'
+  edit STHOST '/s1b'
+  edit STHOST_BKUP '/s1a'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit VERSION '0046'
+  edit INIEXPVER '0001'
+  edit WVINIEXPVER 'false'
+  edit INIWDEXPVER '0046'
+  edit INIWDCLASS 'od'
+  edit FIRST_DAY '1'
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit REINITIALIZE 'false'
+  edit DATEMASK '*.*.*'
+  edit YMD '20091016'
+  edit USE_YMD 'true'
+  edit FSFAMILY 'euroshelf'
+  edit VERIF_WAIT '10'
+  edit MARS_DB 'marsod'
+  edit VERIFY 'verify'
+  edit SUITE_START '2009101612'
+  edit SMSTRIES '2'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/elaw_36r1'
+  edit SMSINCLUDE '/home/ma/emos/def/elaw_36r1/include'
+  edit RESERVATION_ON '1'
+  edit QUEUE 'os'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit.36r1 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+  edit ANTIME '12'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '12'
+  edit EMOS_PROJECT '00'
+  edit EMOS_TIME_STEP_H '0000'
+  edit PGEN_BINDIR '/home/ma/emos/bin/diss'
+  edit PGEN_OBJDIR '/home/ma/emos/bin/diss'
+  edit DISS_REQDB_ROOT '/diss/requirements'
+  edit DISS_BINDIR '/diss/bin/DISS'
+  edit ANNPES '1'
+  edit FCNPES '128'
+  edit EMOS_DOMAIN 'M'
+  edit PROD_TASK '1'
+  edit EMOS_TYPE 'fc'
+  edit DATA_COV 'no'
+  edit EMOS_STREAM 'WV'
+  edit STREAM 'DA'
+  edit INISTREAM 'wave'
+  edit ACCOUNT 'oewave'
+  edit WAMLEN '10'
+  edit WAM1ST 'no'
+  edit GRID '0.25/0.25'
+  edit RET_GRID '1.5/1.5'
+  edit SMSLOGHOST 'c1b'
+  edit SMSLOGPORT '9316'
+  edit SLEEPTIME '1'
+  inlimit /limits:c1b
+  clock hybrid 
+  family limits
+    limit mars 2
+    limit prod 5
+    limit pdb 5
+    limit q2diss 5
+    limit prodcheck 1
+  endfamily
+  family main
+    trigger /elaw_36r1/main:YMD le /e_36r1/main:YMD
+    repeat date YMD 20091016 20121212 1
+    edit LOGTASK 'main'
+    family make
+      task setup
+      task wconst
+        trigger setup eq complete
+      task wavini
+        trigger wconst eq complete
+      family prod
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod/make'
+        edit EMOS_DOMAIN 'g'
+        edit EMOS_TYPE 'fc'
+        edit EMOS_STREAM 'OPER'
+        task wparam
+          edit EMOS_TYPE 'wp'
+        task tf
+          edit EMOS_TYPE 'tf'
+        task sortreq
+        task bitmap
+        task clima
+        task disssch
+        task tools
+        task oper
+        task wave
+          edit EMOS_STREAM 'WAVE'
+      endfamily
+    endfamily
+    family 12
+      trigger make eq complete
+      edit EMOS_BASE '12'
+      edit EMOS_PROJECT '12'
+      edit DELTA_DAY '0'
+      family ref
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        task model
+          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/12/fc/model eq complete)
+        task prod
+          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/12/getreq eq complete)
+        task sst
+          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/12/an/surf_anal/sst eq complete)
+      endfamily
+      family euroshelf
+        trigger ref/model eq complete
+        edit EMOS_DOMAIN 'M'
+        edit GRID '0.25/0.25'
+        edit RET_GRID '0.25/0.25'
+        edit WAMLEN '5'
+        task wamobs
+        task wamwind
+        task wamwave
+          trigger /elaw_36r1/main/12/ref/sst eq complete
+        task wamrun
+          trigger wamobs eq complete and wamwind eq complete and wamwave eq complete
+          edit USER_PRIORITY '80'
+          edit SMSTRIES '1'
+          edit THREADS '2'
+      endfamily
+      family getreq
+        trigger ref/prod eq complete
+        edit EMOS_TYPE 'fc'
+        edit EMOS_DOMAIN 'M'
+        edit FSFAMILY 'ppdi'
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'WAVE'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger req:001 or req eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete
+          label info ""
+          event 1 
+      endfamily
+      family prod
+        edit ACCOUNT 'oewavepg'
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit PGNPES '1'
+        edit EMOS_TIME_STEP_H '0000'
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSURL 'MWAVE/12'
+        edit DELTA_DAY '-1'
+        inlimit /limits:prod
+        inlimit /elaw_36r1/limits:prod
+        family 06
+          edit SMSURL 'MWAVE/06'
+          family an
+            trigger /elaw_36r1/main/12/euroshelf/wamrun eq complete and ( /elaw_36r1/main/12/getreq/bitmap:001 or /elaw_36r1/main/12/getreq/bitmap eq complete) and ( /elaw_36r1/main/12/getreq/req:001 or /elaw_36r1/main/12/getreq/req eq complete)
+            edit EMOS_TYPE 'an'
+            edit EMOS_BASE '06'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+        endfamily
+        family 12
+          edit EMOS_TYPE 'fc'
+          edit PROD_TASK '1'
+          edit DELTA_DAY '0'
+          family an
+            trigger /elaw_36r1/main/12/euroshelf/wamrun eq complete and /elaw_36r1/main/12/prod/06/an/prodgen eq complete
+            edit EMOS_TYPE 'an'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 003
+            trigger ../12/an/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0003'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 006
+            trigger ./003/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0006'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 009
+            trigger ./006/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0009'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 012
+            trigger ./009/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0012'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 015
+            trigger ./012/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0015'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 018
+            trigger ./015/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0018'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 021
+            trigger ./018/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0021'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 024
+            trigger ./021/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0024'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 027
+            trigger ./024/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0027'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 030
+            trigger ./027/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0030'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 033
+            trigger ./030/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0033'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 036
+            trigger ./033/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0036'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 039
+            trigger ./036/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0039'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 042
+            trigger ./039/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0042'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 045
+            trigger ./042/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0045'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 048
+            trigger ./045/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0048'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 051
+            trigger ./048/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0051'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 054
+            trigger ./051/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0054'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 057
+            trigger ./054/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0057'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 060
+            trigger ./057/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0060'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 063
+            trigger ./060/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0063'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 066
+            trigger ./063/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0066'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 069
+            trigger ./066/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0069'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 072
+            trigger ./069/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0072'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 075
+            trigger ./072/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0075'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 078
+            trigger ./075/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0078'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 081
+            trigger ./078/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0081'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 084
+            trigger ./081/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0084'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 087
+            trigger ./084/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0087'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 090
+            trigger ./087/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0090'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 093
+            trigger ./090/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0093'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 096
+            trigger ./093/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0096'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 099
+            trigger ./096/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0099'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 102
+            trigger ./099/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0102'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 105
+            trigger ./102/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0105'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 108
+            trigger ./105/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0108'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 111
+            trigger ./108/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0111'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 114
+            trigger ./111/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0114'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 117
+            trigger ./114/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0117'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 120
+            trigger ./117/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0120'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURL 'MWAVE/12'
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_TIME_STEP_H '0000'
+        inlimit /elaw_36r1/limits:pdb
+        inlimit /limits:pdb
+        family 06
+          edit EMOS_TYPE 'an'
+          edit SMSURL 'MWAVE/06'
+          family an
+            trigger /elaw_36r1/main/12/prod/06/an/prodgen eq complete
+            edit EMOS_TYPE 'an'
+            edit EMOS_BASE '06'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+        endfamily
+        family 12
+          edit EMOS_BASE '12'
+          edit EMOS_TYPE 'fc'
+          family an
+            trigger /elaw_36r1/main/12/prod/12/an/prodgen eq complete
+            edit EMOS_TYPE 'an'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 003
+            trigger /elaw_36r1/main/12/prod/12/003/prodgen eq complete and ( ./an/diss:pdb or ./an/diss eq complete)
+            edit EMOS_TIME_STEP_H '0003'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 006
+            trigger /elaw_36r1/main/12/prod/12/006/prodgen eq complete and ( ./003/diss:pdb or ./003/diss eq complete)
+            edit EMOS_TIME_STEP_H '0006'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 009
+            trigger /elaw_36r1/main/12/prod/12/009/prodgen eq complete and ( ./006/diss:pdb or ./006/diss eq complete)
+            edit EMOS_TIME_STEP_H '0009'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 012
+            trigger /elaw_36r1/main/12/prod/12/012/prodgen eq complete and ( ./009/diss:pdb or ./009/diss eq complete)
+            edit EMOS_TIME_STEP_H '0012'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 015
+            trigger /elaw_36r1/main/12/prod/12/015/prodgen eq complete and ( ./012/diss:pdb or ./012/diss eq complete)
+            edit EMOS_TIME_STEP_H '0015'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 018
+            trigger /elaw_36r1/main/12/prod/12/018/prodgen eq complete and ( ./015/diss:pdb or ./015/diss eq complete)
+            edit EMOS_TIME_STEP_H '0018'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 021
+            trigger /elaw_36r1/main/12/prod/12/021/prodgen eq complete and ( ./018/diss:pdb or ./018/diss eq complete)
+            edit EMOS_TIME_STEP_H '0021'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 024
+            trigger /elaw_36r1/main/12/prod/12/024/prodgen eq complete and ( ./021/diss:pdb or ./021/diss eq complete)
+            edit EMOS_TIME_STEP_H '0024'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 027
+            trigger /elaw_36r1/main/12/prod/12/027/prodgen eq complete and ( ./024/diss:pdb or ./024/diss eq complete)
+            edit EMOS_TIME_STEP_H '0027'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 030
+            trigger /elaw_36r1/main/12/prod/12/030/prodgen eq complete and ( ./027/diss:pdb or ./027/diss eq complete)
+            edit EMOS_TIME_STEP_H '0030'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 033
+            trigger /elaw_36r1/main/12/prod/12/033/prodgen eq complete and ( ./030/diss:pdb or ./030/diss eq complete)
+            edit EMOS_TIME_STEP_H '0033'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 036
+            trigger /elaw_36r1/main/12/prod/12/036/prodgen eq complete and ( ./033/diss:pdb or ./033/diss eq complete)
+            edit EMOS_TIME_STEP_H '0036'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 039
+            trigger /elaw_36r1/main/12/prod/12/039/prodgen eq complete and ( ./036/diss:pdb or ./036/diss eq complete)
+            edit EMOS_TIME_STEP_H '0039'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 042
+            trigger /elaw_36r1/main/12/prod/12/042/prodgen eq complete and ( ./039/diss:pdb or ./039/diss eq complete)
+            edit EMOS_TIME_STEP_H '0042'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 045
+            trigger /elaw_36r1/main/12/prod/12/045/prodgen eq complete and ( ./042/diss:pdb or ./042/diss eq complete)
+            edit EMOS_TIME_STEP_H '0045'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 048
+            trigger /elaw_36r1/main/12/prod/12/048/prodgen eq complete and ( ./045/diss:pdb or ./045/diss eq complete)
+            edit EMOS_TIME_STEP_H '0048'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 051
+            trigger /elaw_36r1/main/12/prod/12/051/prodgen eq complete and ( ./048/diss:pdb or ./048/diss eq complete)
+            edit EMOS_TIME_STEP_H '0051'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 054
+            trigger /elaw_36r1/main/12/prod/12/054/prodgen eq complete and ( ./051/diss:pdb or ./051/diss eq complete)
+            edit EMOS_TIME_STEP_H '0054'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 057
+            trigger /elaw_36r1/main/12/prod/12/057/prodgen eq complete and ( ./054/diss:pdb or ./054/diss eq complete)
+            edit EMOS_TIME_STEP_H '0057'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 060
+            trigger /elaw_36r1/main/12/prod/12/060/prodgen eq complete and ( ./057/diss:pdb or ./057/diss eq complete)
+            edit EMOS_TIME_STEP_H '0060'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 063
+            trigger /elaw_36r1/main/12/prod/12/063/prodgen eq complete and ( ./060/diss:pdb or ./060/diss eq complete)
+            edit EMOS_TIME_STEP_H '0063'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 066
+            trigger /elaw_36r1/main/12/prod/12/066/prodgen eq complete and ( ./063/diss:pdb or ./063/diss eq complete)
+            edit EMOS_TIME_STEP_H '0066'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 069
+            trigger /elaw_36r1/main/12/prod/12/069/prodgen eq complete and ( ./066/diss:pdb or ./066/diss eq complete)
+            edit EMOS_TIME_STEP_H '0069'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 072
+            trigger /elaw_36r1/main/12/prod/12/072/prodgen eq complete and ( ./069/diss:pdb or ./069/diss eq complete)
+            edit EMOS_TIME_STEP_H '0072'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 075
+            trigger /elaw_36r1/main/12/prod/12/075/prodgen eq complete and ( ./072/diss:pdb or ./072/diss eq complete)
+            edit EMOS_TIME_STEP_H '0075'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 078
+            trigger /elaw_36r1/main/12/prod/12/078/prodgen eq complete and ( ./075/diss:pdb or ./075/diss eq complete)
+            edit EMOS_TIME_STEP_H '0078'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 081
+            trigger /elaw_36r1/main/12/prod/12/081/prodgen eq complete and ( ./078/diss:pdb or ./078/diss eq complete)
+            edit EMOS_TIME_STEP_H '0081'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 084
+            trigger /elaw_36r1/main/12/prod/12/084/prodgen eq complete and ( ./081/diss:pdb or ./081/diss eq complete)
+            edit EMOS_TIME_STEP_H '0084'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 087
+            trigger /elaw_36r1/main/12/prod/12/087/prodgen eq complete and ( ./084/diss:pdb or ./084/diss eq complete)
+            edit EMOS_TIME_STEP_H '0087'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 090
+            trigger /elaw_36r1/main/12/prod/12/090/prodgen eq complete and ( ./087/diss:pdb or ./087/diss eq complete)
+            edit EMOS_TIME_STEP_H '0090'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 093
+            trigger /elaw_36r1/main/12/prod/12/093/prodgen eq complete and ( ./090/diss:pdb or ./090/diss eq complete)
+            edit EMOS_TIME_STEP_H '0093'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 096
+            trigger /elaw_36r1/main/12/prod/12/096/prodgen eq complete and ( ./093/diss:pdb or ./093/diss eq complete)
+            edit EMOS_TIME_STEP_H '0096'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 099
+            trigger /elaw_36r1/main/12/prod/12/099/prodgen eq complete and ( ./096/diss:pdb or ./096/diss eq complete)
+            edit EMOS_TIME_STEP_H '0099'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 102
+            trigger /elaw_36r1/main/12/prod/12/102/prodgen eq complete and ( ./099/diss:pdb or ./099/diss eq complete)
+            edit EMOS_TIME_STEP_H '0102'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 105
+            trigger /elaw_36r1/main/12/prod/12/105/prodgen eq complete and ( ./102/diss:pdb or ./102/diss eq complete)
+            edit EMOS_TIME_STEP_H '0105'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 108
+            trigger /elaw_36r1/main/12/prod/12/108/prodgen eq complete and ( ./105/diss:pdb or ./105/diss eq complete)
+            edit EMOS_TIME_STEP_H '0108'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 111
+            trigger /elaw_36r1/main/12/prod/12/111/prodgen eq complete and ( ./108/diss:pdb or ./108/diss eq complete)
+            edit EMOS_TIME_STEP_H '0111'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 114
+            trigger /elaw_36r1/main/12/prod/12/114/prodgen eq complete and ( ./111/diss:pdb or ./111/diss eq complete)
+            edit EMOS_TIME_STEP_H '0114'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 117
+            trigger /elaw_36r1/main/12/prod/12/117/prodgen eq complete and ( ./114/diss:pdb or ./114/diss eq complete)
+            edit EMOS_TIME_STEP_H '0117'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 120
+            trigger /elaw_36r1/main/12/prod/12/120/prodgen eq complete and ( ./117/diss:pdb or ./117/diss eq complete)
+            edit EMOS_TIME_STEP_H '0120'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+        endfamily
+        task check
+          trigger ./12 eq complete
+        family reservation
+          trigger ./12 eq complete
+          edit SMSFILES '/home/ma/emos/def/elaw_36r1/smsfiles'
+          task loadl_cycle_limit
+            edit LOADL_CYCLE '65'
+            label info ""
+        endfamily
+      endfamily
+    endfamily
+    family 00
+      trigger ./make eq complete and ./12 eq complete
+      edit EMOS_BASE '00'
+      edit EMOS_PROJECT '00'
+      edit DELTA_DAY '1'
+      edit RESERVATION_ON '1'
+      edit QUEUE 'os'
+      family ref
+        edit QUEUE 'emos-e'
+        edit QUEUE_EPILOG 'emos-exp'
+        edit WSHOST 'localhost'
+        edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+        edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+        edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+        edit LOGDIR '/vol/emos_nc/output'
+        edit SMSOUT '/vol/emos_nc/output'
+        task model
+          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/00/fc/model eq complete)
+        task prod
+          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/00/getreq eq complete)
+        task sst
+          trigger ( /e_36r1/main:YMD gt /elaw_36r1/main:YMD) or ( /e_36r1/main:YMD eq /elaw_36r1/main:YMD and /e_36r1/main/00/an/surf_anal/sst eq complete)
+      endfamily
+      family euroshelf
+        trigger ref/model eq complete
+        edit EMOS_DOMAIN 'M'
+        edit GRID '0.25/0.25'
+        edit RET_GRID '0.25/0.25'
+        edit WAMLEN '5'
+        task wamobs
+        task wamwind
+        task wamwave
+          trigger ( /elaw_36r1/main/00/ref/sst eq complete) and ( /elaw_36r1/main/12/euroshelf eq complete)
+        task wamrun
+          trigger wamobs eq complete and wamwind eq complete and wamwave eq complete
+          edit USER_PRIORITY '80'
+          edit SMSTRIES '1'
+          edit THREADS '2'
+      endfamily
+      family getreq
+        trigger ref/prod eq complete
+        edit EMOS_TYPE 'fc'
+        edit EMOS_DOMAIN 'M'
+        edit FSFAMILY 'ppdi'
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
+        edit SMSTRIES '1'
+        edit EMOS_STREAM 'WAVE'
+        task collectreq
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task req
+          late -s +00:03 -c +00:10
+          trigger collectreq eq complete
+          label info ""
+          event 1 
+        task collectbitmap
+          trigger req:001 or req eq complete
+          edit QUEUE 'diss'
+          edit USER 'emos'
+          edit WSHOST 'diss'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit LOGDIR '/diss/log'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSOUT '/vol/emos_nc/output'
+        task bitmap
+          late -s +00:03 -c +00:10
+          trigger collectbitmap eq complete
+          label info ""
+          event 1 
+      endfamily
+      family prod
+        edit ACCOUNT 'oewavepg'
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit PROD_TASK '1'
+        edit PGNPES '1'
+        edit EMOS_TIME_STEP_H '0000'
+        edit USER_PRIORITY '90'
+        edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/summary'
+        edit SMSURL 'MWAVE/00'
+        inlimit /limits:prod
+        inlimit /elaw_36r1/limits:prod
+        family 18
+          edit DELTA_DAY '0'
+          edit SMSURL 'MWAVE/18'
+          family an
+            trigger /elaw_36r1/main/00/euroshelf/wamrun eq complete and ( /elaw_36r1/main/00/getreq/bitmap:001 or /elaw_36r1/main/00/getreq/bitmap eq complete) and ( /elaw_36r1/main/00/getreq/req:001 or /elaw_36r1/main/00/getreq/req eq complete)
+            edit EMOS_TYPE 'an'
+            edit EMOS_BASE '18'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+        endfamily
+        family 00
+          edit EMOS_TYPE 'fc'
+          edit PROD_TASK '1'
+          edit DELTA_DAY '1'
+          family an
+            trigger /elaw_36r1/main/00/euroshelf/wamrun eq complete and /elaw_36r1/main/00/prod/18/an/prodgen eq complete
+            edit EMOS_TYPE 'an'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 003
+            trigger ../00/an/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0003'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 006
+            trigger ./003/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0006'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 009
+            trigger ./006/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0009'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 012
+            trigger ./009/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0012'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 015
+            trigger ./012/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0015'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 018
+            trigger ./015/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0018'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 021
+            trigger ./018/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0021'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 024
+            trigger ./021/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0024'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 027
+            trigger ./024/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0027'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 030
+            trigger ./027/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0030'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 033
+            trigger ./030/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0033'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 036
+            trigger ./033/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0036'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 039
+            trigger ./036/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0039'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 042
+            trigger ./039/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0042'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 045
+            trigger ./042/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0045'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 048
+            trigger ./045/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0048'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 051
+            trigger ./048/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0051'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 054
+            trigger ./051/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0054'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 057
+            trigger ./054/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0057'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 060
+            trigger ./057/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0060'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 063
+            trigger ./060/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0063'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 066
+            trigger ./063/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0066'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 069
+            trigger ./066/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0069'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 072
+            trigger ./069/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0072'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 075
+            trigger ./072/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0075'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 078
+            trigger ./075/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0078'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 081
+            trigger ./078/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0081'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 084
+            trigger ./081/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0084'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 087
+            trigger ./084/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0087'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 090
+            trigger ./087/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0090'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 093
+            trigger ./090/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0093'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 096
+            trigger ./093/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0096'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 099
+            trigger ./096/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0099'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 102
+            trigger ./099/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0102'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 105
+            trigger ./102/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0105'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 108
+            trigger ./105/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0108'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 111
+            trigger ./108/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0111'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 114
+            trigger ./111/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0114'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 117
+            trigger ./114/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0117'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+          family 120
+            trigger ./117/prodgen eq complete
+            edit EMOS_TIME_STEP_H '0120'
+            task prodgen
+              late -s +00:05 -c +00:15
+          endfamily
+        endfamily
+      endfamily
+      family prod2diss
+        edit USER_PRIORITY '90'
+        edit SMSURL 'MWAVE/00'
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/prod'
+        edit EMOS_TYPE 'fc'
+        edit FSFAMILY 'ppdi'
+        edit EMOS_TIME_STEP_H '0000'
+        inlimit /elaw_36r1/limits:pdb
+        inlimit /limits:pdb
+        family 18
+          edit DELTA_DAY '0'
+          edit EMOS_TYPE 'an'
+          edit SMSURL 'MWAVE/18'
+          family an
+            trigger /elaw_36r1/main/00/prod/18/an/prodgen eq complete
+            edit EMOS_TYPE 'an'
+            edit EMOS_BASE '18'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+        endfamily
+        family 00
+          edit EMOS_BASE '00'
+          edit EMOS_TYPE 'fc'
+          family an
+            trigger /elaw_36r1/main/00/prod/00/an/prodgen eq complete
+            edit EMOS_TYPE 'an'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 003
+            trigger /elaw_36r1/main/00/prod/00/003/prodgen eq complete and ( ./an/diss:pdb or ./an/diss eq complete)
+            edit EMOS_TIME_STEP_H '0003'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 006
+            trigger /elaw_36r1/main/00/prod/00/006/prodgen eq complete and ( ./003/diss:pdb or ./003/diss eq complete)
+            edit EMOS_TIME_STEP_H '0006'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 009
+            trigger /elaw_36r1/main/00/prod/00/009/prodgen eq complete and ( ./006/diss:pdb or ./006/diss eq complete)
+            edit EMOS_TIME_STEP_H '0009'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 012
+            trigger /elaw_36r1/main/00/prod/00/012/prodgen eq complete and ( ./009/diss:pdb or ./009/diss eq complete)
+            edit EMOS_TIME_STEP_H '0012'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 015
+            trigger /elaw_36r1/main/00/prod/00/015/prodgen eq complete and ( ./012/diss:pdb or ./012/diss eq complete)
+            edit EMOS_TIME_STEP_H '0015'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 018
+            trigger /elaw_36r1/main/00/prod/00/018/prodgen eq complete and ( ./015/diss:pdb or ./015/diss eq complete)
+            edit EMOS_TIME_STEP_H '0018'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 021
+            trigger /elaw_36r1/main/00/prod/00/021/prodgen eq complete and ( ./018/diss:pdb or ./018/diss eq complete)
+            edit EMOS_TIME_STEP_H '0021'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 024
+            trigger /elaw_36r1/main/00/prod/00/024/prodgen eq complete and ( ./021/diss:pdb or ./021/diss eq complete)
+            edit EMOS_TIME_STEP_H '0024'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 027
+            trigger /elaw_36r1/main/00/prod/00/027/prodgen eq complete and ( ./024/diss:pdb or ./024/diss eq complete)
+            edit EMOS_TIME_STEP_H '0027'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 030
+            trigger /elaw_36r1/main/00/prod/00/030/prodgen eq complete and ( ./027/diss:pdb or ./027/diss eq complete)
+            edit EMOS_TIME_STEP_H '0030'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 033
+            trigger /elaw_36r1/main/00/prod/00/033/prodgen eq complete and ( ./030/diss:pdb or ./030/diss eq complete)
+            edit EMOS_TIME_STEP_H '0033'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 036
+            trigger /elaw_36r1/main/00/prod/00/036/prodgen eq complete and ( ./033/diss:pdb or ./033/diss eq complete)
+            edit EMOS_TIME_STEP_H '0036'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 039
+            trigger /elaw_36r1/main/00/prod/00/039/prodgen eq complete and ( ./036/diss:pdb or ./036/diss eq complete)
+            edit EMOS_TIME_STEP_H '0039'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 042
+            trigger /elaw_36r1/main/00/prod/00/042/prodgen eq complete and ( ./039/diss:pdb or ./039/diss eq complete)
+            edit EMOS_TIME_STEP_H '0042'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 045
+            trigger /elaw_36r1/main/00/prod/00/045/prodgen eq complete and ( ./042/diss:pdb or ./042/diss eq complete)
+            edit EMOS_TIME_STEP_H '0045'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 048
+            trigger /elaw_36r1/main/00/prod/00/048/prodgen eq complete and ( ./045/diss:pdb or ./045/diss eq complete)
+            edit EMOS_TIME_STEP_H '0048'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 051
+            trigger /elaw_36r1/main/00/prod/00/051/prodgen eq complete and ( ./048/diss:pdb or ./048/diss eq complete)
+            edit EMOS_TIME_STEP_H '0051'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 054
+            trigger /elaw_36r1/main/00/prod/00/054/prodgen eq complete and ( ./051/diss:pdb or ./051/diss eq complete)
+            edit EMOS_TIME_STEP_H '0054'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 057
+            trigger /elaw_36r1/main/00/prod/00/057/prodgen eq complete and ( ./054/diss:pdb or ./054/diss eq complete)
+            edit EMOS_TIME_STEP_H '0057'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 060
+            trigger /elaw_36r1/main/00/prod/00/060/prodgen eq complete and ( ./057/diss:pdb or ./057/diss eq complete)
+            edit EMOS_TIME_STEP_H '0060'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 063
+            trigger /elaw_36r1/main/00/prod/00/063/prodgen eq complete and ( ./060/diss:pdb or ./060/diss eq complete)
+            edit EMOS_TIME_STEP_H '0063'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 066
+            trigger /elaw_36r1/main/00/prod/00/066/prodgen eq complete and ( ./063/diss:pdb or ./063/diss eq complete)
+            edit EMOS_TIME_STEP_H '0066'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 069
+            trigger /elaw_36r1/main/00/prod/00/069/prodgen eq complete and ( ./066/diss:pdb or ./066/diss eq complete)
+            edit EMOS_TIME_STEP_H '0069'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 072
+            trigger /elaw_36r1/main/00/prod/00/072/prodgen eq complete and ( ./069/diss:pdb or ./069/diss eq complete)
+            edit EMOS_TIME_STEP_H '0072'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 075
+            trigger /elaw_36r1/main/00/prod/00/075/prodgen eq complete and ( ./072/diss:pdb or ./072/diss eq complete)
+            edit EMOS_TIME_STEP_H '0075'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 078
+            trigger /elaw_36r1/main/00/prod/00/078/prodgen eq complete and ( ./075/diss:pdb or ./075/diss eq complete)
+            edit EMOS_TIME_STEP_H '0078'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 081
+            trigger /elaw_36r1/main/00/prod/00/081/prodgen eq complete and ( ./078/diss:pdb or ./078/diss eq complete)
+            edit EMOS_TIME_STEP_H '0081'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 084
+            trigger /elaw_36r1/main/00/prod/00/084/prodgen eq complete and ( ./081/diss:pdb or ./081/diss eq complete)
+            edit EMOS_TIME_STEP_H '0084'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 087
+            trigger /elaw_36r1/main/00/prod/00/087/prodgen eq complete and ( ./084/diss:pdb or ./084/diss eq complete)
+            edit EMOS_TIME_STEP_H '0087'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 090
+            trigger /elaw_36r1/main/00/prod/00/090/prodgen eq complete and ( ./087/diss:pdb or ./087/diss eq complete)
+            edit EMOS_TIME_STEP_H '0090'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 093
+            trigger /elaw_36r1/main/00/prod/00/093/prodgen eq complete and ( ./090/diss:pdb or ./090/diss eq complete)
+            edit EMOS_TIME_STEP_H '0093'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 096
+            trigger /elaw_36r1/main/00/prod/00/096/prodgen eq complete and ( ./093/diss:pdb or ./093/diss eq complete)
+            edit EMOS_TIME_STEP_H '0096'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 099
+            trigger /elaw_36r1/main/00/prod/00/099/prodgen eq complete and ( ./096/diss:pdb or ./096/diss eq complete)
+            edit EMOS_TIME_STEP_H '0099'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 102
+            trigger /elaw_36r1/main/00/prod/00/102/prodgen eq complete and ( ./099/diss:pdb or ./099/diss eq complete)
+            edit EMOS_TIME_STEP_H '0102'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 105
+            trigger /elaw_36r1/main/00/prod/00/105/prodgen eq complete and ( ./102/diss:pdb or ./102/diss eq complete)
+            edit EMOS_TIME_STEP_H '0105'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 108
+            trigger /elaw_36r1/main/00/prod/00/108/prodgen eq complete and ( ./105/diss:pdb or ./105/diss eq complete)
+            edit EMOS_TIME_STEP_H '0108'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 111
+            trigger /elaw_36r1/main/00/prod/00/111/prodgen eq complete and ( ./108/diss:pdb or ./108/diss eq complete)
+            edit EMOS_TIME_STEP_H '0111'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 114
+            trigger /elaw_36r1/main/00/prod/00/114/prodgen eq complete and ( ./111/diss:pdb or ./111/diss eq complete)
+            edit EMOS_TIME_STEP_H '0114'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 117
+            trigger /elaw_36r1/main/00/prod/00/117/prodgen eq complete and ( ./114/diss:pdb or ./114/diss eq complete)
+            edit EMOS_TIME_STEP_H '0117'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+          family 120
+            trigger /elaw_36r1/main/00/prod/00/120/prodgen eq complete and ( ./117/diss:pdb or ./117/diss eq complete)
+            edit EMOS_TIME_STEP_H '0120'
+            task diss
+              late -s +00:05 -c +00:15
+              label info ""
+              event pdb
+          endfamily
+        endfamily
+        task check
+          trigger ./00 eq complete
+        family reservation
+          trigger ./00 eq complete
+          edit SMSFILES '/home/ma/emos/def/elaw_36r1/smsfiles'
+          task loadl_cycle_limit
+            edit LOADL_CYCLE '65'
+            label info ""
+        endfamily
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'main'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger make eq complete and ./12 eq complete and ./00 eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'main'
+      inlimit /limits:linux_cluster
+  endfamily
+  family lag
+    trigger /elaw_36r1/main/make eq complete
+    repeat date YMD 20091016 20121212 1
+    edit LOGTASK 'lag'
+    edit MARS_DB 'marsod'
+    family 12
+      edit EMOS_BASE '12'
+      edit EMOS_PROJECT '12'
+      edit DELTA_DAY '0'
+      task wavesave
+        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/12/euroshelf/wamrun eq complete)
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/euroshelf'
+      family euroshelf
+        trigger ./wavesave eq complete
+        task buoycol
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task monthly
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit DATEMASK '04.*.*'
+          inlimit /limits:linux_cluster
+        task uracol
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task fc_plot
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task uraplot
+          trigger uracol eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task windplot
+          trigger uracol eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task uraesf
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task urascat
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit DATEMASK '03.*.*'
+          inlimit /limits:linux_cluster
+      endfamily
+      family archive
+        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/12/euroshelf/wamrun eq complete)
+        edit FSFAMILY 'mars'
+        inlimit /elaw_36r1/limits:mars
+        inlimit /limits:mars
+        task medite_06
+          edit EMOS_BASE '06'
+          label files ""
+          label info ""
+          event fdb
+        task medite_12
+          edit EMOS_BASE '12'
+          label files ""
+          label info ""
+          event fdb
+        task fc12m
+          label files ""
+          label info ""
+          event fdb
+        task flush
+          edit STREAM 'wave'
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family clean
+        trigger /elaw_36r1/main/make eq complete and euroshelf eq complete and archive eq complete
+        task clold
+        task clean_ws
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+      endfamily
+    endfamily
+    family 00
+      edit EMOS_BASE '00'
+      edit EMOS_PROJECT '00'
+      edit DELTA_DAY '1'
+      edit QUEUE 'os'
+      task wavesave
+        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/00/euroshelf/wamrun eq complete)
+        edit SMSFILES '/home/ma/emos/def/elaw_36r1/euroshelf'
+      family euroshelf
+        trigger ./wavesave eq complete
+        task buoycol
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task monthly
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit DATEMASK '04.*.*'
+          inlimit /limits:linux_cluster
+        task uracol
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task fc_plot
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task uraplot
+          trigger uracol eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task windplot
+          trigger uracol eq complete
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task uraesf
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+        task urascat
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          edit DATEMASK '03.*.*'
+          inlimit /limits:linux_cluster
+      endfamily
+      family archive
+        trigger ( /elaw_36r1/main:YMD gt /elaw_36r1/lag:YMD) or ( /elaw_36r1/main:YMD eq /elaw_36r1/lag:YMD and /elaw_36r1/main/00/euroshelf/wamrun eq complete)
+        edit FSFAMILY 'mars'
+        inlimit /elaw_36r1/limits:mars
+        inlimit /limits:mars
+        task medite_18
+          edit DELTA_DAY '0'
+          edit EMOS_BASE '18'
+          label files ""
+          label info ""
+          event fdb
+        task medite_00
+          edit EMOS_BASE '00'
+          label files ""
+          label info ""
+          event fdb
+        task fc12m
+          label files ""
+          label info ""
+          event fdb
+        task flush
+          edit STREAM 'wave'
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family clean
+        trigger /elaw_36r1/main/make eq complete and euroshelf eq complete and archive eq complete
+        task clold
+        task clean_ws
+          edit QUEUE 'emos-e'
+          edit QUEUE_EPILOG 'emos-exp'
+          edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+          edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit LOGDIR '/vol/emos_nc/output'
+          edit SMSOUT '/vol/emos_nc/output'
+          inlimit /limits:linux_cluster
+      endfamily
+    endfamily
+    task checkarchive
+      trigger /elaw_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FSFAMILY 'mars'
+      edit EMOS_TYPE 'an'
+      inlimit /limits:linux_cluster
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+      edit LOGTASK 'lag'
+    task logfiles
+      late -s +00:05 -c +00:15
+      trigger /elaw_36r1/main/make eq complete and ./12 eq complete and ./00 eq complete and checkarchive eq complete and logfilestore eq complete
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      edit LOGTASK 'lag'
+      inlimit /limits:linux_cluster
+  endfamily
+endsuite
+suite ema_36r1
+  edit USER 'emos'
+  edit SCHOST 'c1b'
+  edit STHOST '/s1b'
+  edit STHOST_BKUP '/s1a'
+  edit SCHOST_BKP 'c1a'
+  edit WSHOST 'linux_cluster'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit SMSLOGHOST 'c1b'
+  edit SMSLOGPORT '9316'
+  edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+  edit SMSURL 'USA/GMAED/12'
+  edit VERSION '0046'
+  edit FIRST_DAY '1'
+  edit SMSTRIES '2'
+  edit DELTA_DAY '0'
+  edit EMOS_BASE '12'
+  edit EMOS_TIME_STEP_H '0000'
+  edit FSFAMILY ''
+  edit EPSTYPE 'fc'
+  edit MEMBER '0'
+  edit INIMA ''
+  edit INIMACONS '0'
+  edit INILEVELS '91'
+  edit VERIFY 'verify'
+  edit PERIOD_4D '12'
+  edit WINDOW_LENGTH_4D '12'
+  edit WINDOW_OFFSET_4D '9'
+  edit ANNPES '48'
+  edit ANMEM '3584'
+  edit ANSTACK '700'
+  edit ANMRFS '160'
+  edit FCNPES '92'
+  edit FCMEM '3584'
+  edit FCSTACK '690'
+  edit FCMRFS '32'
+  edit ININPES '48'
+  edit REINITIALIZE 'false'
+  edit DATEMASK '*.*.*'
+  edit YMD 'dummy'
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/ema_36r1'
+  edit SMSINCLUDE '/home/ma/emos/def/ema_36r1/include'
+  edit ACCOUNT 'oemaed'
+  edit STREAM 'MAED'
+  edit EMOS_STREAM 'MAED'
+  edit MARS_DB 'marsod'
+  edit SUITE_START '20040814'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit.36r1 %USER% %SCHOST% %SMSJOB% %SMSJOBOUT% '
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/s1b/emos_esuite/emos_data/0046/log'
+  edit SMSOUT '/s1b/emos_esuite/emos_data/0046/log'
+  edit INIEXPVER '0046'
+  edit SLEEPTIME '1'
+  inlimit /limits:c1b
+  clock hybrid -86400
+  family limits
+    limit inidata 1
+    limit mars 3
+    limit prod 5
+    limit pdb 5
+    limit q2diss 5
+  endfamily
+  family make
+    task setup
+    task links
+      trigger setup eq complete
+      edit FSFAMILY 'fc'
+      edit WSHOST 'bee01'
+    task datalinks
+      trigger setup eq complete and links eq complete
+      edit FSFAMILY 'fc'
+    task ifs
+      trigger links eq complete and datalinks eq complete
+      edit FSFAMILY 'fc'
+    task wamabs
+      trigger links eq complete and datalinks eq complete
+    task wconst
+      trigger wamabs eq complete
+    task ma_bin
+      trigger links eq complete and datalinks eq complete
+    task ma_tools
+      trigger links eq complete and datalinks eq complete
+    task prepdata
+      trigger links eq complete and datalinks eq complete
+  endfamily
+  family init
+    trigger /pp1/main/extractions/ma eq complete and make eq complete and /ema_36r1:ECF_DATE le /o/main:YMD
+    task ma_clean
+      edit FSFAMILY 'gfc'
+    task rmfdb
+      trigger ma_clean eq complete
+      edit FSFAMILY 'mars'
+    task flush
+      trigger ma_clean eq complete
+      edit STREAM 'MAED'
+      edit EMOS_TYPE 'an'
+      edit FSFAMILY 'mars'
+      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
+      label files ""
+      label info ""
+      event fdb
+    task ma_stage
+      trigger ma_clean eq complete
+      edit DATEMASK '01.*.*'
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      inlimit /limits:linux_cluster
+    task ma_generate
+      trigger ma_stage eq complete and ma_clean eq complete
+    task getini
+      trigger ma_generate eq complete
+      edit INIMA 'mfr ncep ukm dwd '
+      edit FSFAMILY 'gfc'
+    task wavini
+      trigger ma_stage eq complete and ma_clean eq complete
+      edit FSFAMILY 'gfc'
+  endfamily
+  family dwd
+    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
+    edit INIMA 'dwd'
+    edit INIMACONS '0'
+    family fc
+      edit FCLENGTH '240'
+      edit FCMEM '2000'
+      edit FCSTACK '700'
+      edit FCMRFS '0'
+      edit FSFAMILY 'gfc'
+      task inidata
+        edit THREADS '4'
+        inlimit /ema_36r1/limits:inidata
+      task getfcdata
+        trigger inidata eq complete
+        edit FSFAMILY 'fc'
+      task getpersSST
+        trigger getfcdata eq complete
+        edit FSFAMILY 'fc'
+        edit SSTLEN '240'
+        edit SSTINT '1'
+        edit THREADS '2'
+        edit NPES '4'
+        edit MEM '1000'
+        edit CPUTIME '960'
+      task model
+        trigger getpersSST eq complete
+        edit PERSST 'true'
+        edit FSFAMILY 'fc'
+        edit FCLENGTH '240'
+        meter step -1 240 240
+    endfamily
+    family archive
+      trigger fc/inidata eq complete
+      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
+      edit EMOS_TYPE 'an'
+      edit FSFAMILY 'mars'
+      task ma_anml
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+      task sp2fdb
+        trigger ../fc/model:step ge 0 or ../fc/model eq complete
+        edit EMOS_TYPE 'fc'
+        edit STEPS '0'
+        label files ""
+        label info ""
+        event fdb
+      family fc000
+        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
+        edit STEPS '0'
+        task fcml
+          label files ""
+          label info ""
+          event fdb
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc024
+        trigger ../fc/model:step ge 24 or ../fc/model eq complete
+        edit STEPS '3/6/9/12/15/18/21/24'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc036
+        trigger ../fc/model:step ge 36 or ../fc/model eq complete
+        edit STEPS '27/30/33/36'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc060
+        trigger ../fc/model:step ge 60 or ../fc/model eq complete
+        edit STEPS '39/42/45/48/51/54/57/60'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc072
+        trigger ../fc/model:step ge 72 or ../fc/model eq complete
+        edit STEPS '63/66/69/72'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc120
+        trigger ../fc/model:step ge 120 or ../fc/model eq complete
+        edit STEPS '78/84/90/96/102/108/114/120'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc180
+        trigger ../fc/model:step ge 180 or ../fc/model eq complete
+        edit STEPS '126/132/138/144/150/156/162/168/174/180'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc240
+        trigger ../fc/model:step ge 240 or ../fc/model eq complete
+        edit STEPS '186/192/198/204/210/216/222/228/234/240'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcextra
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      task fc12g
+        trigger ../fc/model eq complete
+        edit STREAM 'MAED'
+        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+        edit STEPS_SPECTRAL ''
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+    endfamily
+  endfamily
+  family ukm
+    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
+    edit INIMA 'ukm'
+    edit INIMACONS '0'
+    family fc
+      edit FCLENGTH '240'
+      edit FCMEM '2000'
+      edit FCSTACK '700'
+      edit FCMRFS '0'
+      edit FSFAMILY 'gfc'
+      task inidata
+        edit THREADS '4'
+        inlimit /ema_36r1/limits:inidata
+      task getfcdata
+        trigger inidata eq complete
+        edit FSFAMILY 'fc'
+      task getpersSST
+        trigger getfcdata eq complete
+        edit FSFAMILY 'fc'
+        edit SSTLEN '240'
+        edit SSTINT '1'
+        edit THREADS '2'
+        edit NPES '4'
+        edit MEM '1000'
+        edit CPUTIME '960'
+      task model
+        trigger getpersSST eq complete
+        edit PERSST 'true'
+        edit FSFAMILY 'fc'
+        edit FCLENGTH '240'
+        meter step -1 240 240
+    endfamily
+    family archive
+      trigger fc/inidata eq complete
+      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
+      edit EMOS_TYPE 'an'
+      edit FSFAMILY 'mars'
+      task ma_anml
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+      task sp2fdb
+        trigger ../fc/model:step ge 0 or ../fc/model eq complete
+        edit EMOS_TYPE 'fc'
+        edit STEPS '0'
+        label files ""
+        label info ""
+        event fdb
+      family fc000
+        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
+        edit STEPS '0'
+        task fcml
+          label files ""
+          label info ""
+          event fdb
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc024
+        trigger ../fc/model:step ge 24 or ../fc/model eq complete
+        edit STEPS '3/6/9/12/15/18/21/24'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc036
+        trigger ../fc/model:step ge 36 or ../fc/model eq complete
+        edit STEPS '27/30/33/36'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc060
+        trigger ../fc/model:step ge 60 or ../fc/model eq complete
+        edit STEPS '39/42/45/48/51/54/57/60'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc072
+        trigger ../fc/model:step ge 72 or ../fc/model eq complete
+        edit STEPS '63/66/69/72'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc120
+        trigger ../fc/model:step ge 120 or ../fc/model eq complete
+        edit STEPS '78/84/90/96/102/108/114/120'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc180
+        trigger ../fc/model:step ge 180 or ../fc/model eq complete
+        edit STEPS '126/132/138/144/150/156/162/168/174/180'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc240
+        trigger ../fc/model:step ge 240 or ../fc/model eq complete
+        edit STEPS '186/192/198/204/210/216/222/228/234/240'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcextra
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      task fc12g
+        trigger ../fc/model eq complete
+        edit STREAM 'MAED'
+        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+        edit STEPS_SPECTRAL ''
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+    endfamily
+  endfamily
+  family ncep
+    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
+    edit INIMA 'ncep'
+    edit INIMACONS '0'
+    family fc
+      edit FCLENGTH '240'
+      edit FCMEM '2000'
+      edit FCSTACK '700'
+      edit FCMRFS '0'
+      edit FSFAMILY 'gfc'
+      task inidata
+        edit THREADS '4'
+        inlimit /ema_36r1/limits:inidata
+      task getfcdata
+        trigger inidata eq complete
+        edit FSFAMILY 'fc'
+      task getpersSST
+        trigger getfcdata eq complete
+        edit FSFAMILY 'fc'
+        edit SSTLEN '240'
+        edit SSTINT '1'
+        edit THREADS '2'
+        edit NPES '4'
+        edit MEM '1000'
+        edit CPUTIME '960'
+      task model
+        trigger getpersSST eq complete
+        edit PERSST 'true'
+        edit FSFAMILY 'fc'
+        edit FCLENGTH '240'
+        meter step -1 240 240
+      task derived_param
+        trigger model eq complete
+        edit MEMBER 'off'
+        edit SMSFILES '/home/ma/emos/def/ema_36r1/mc/fc'
+        edit STEPS '0/12/24/36/48/60/72/84/96/108/120/132/144/156/168/180/192/204/216/228/240'
+        edit EMOS_TYPE 'fc'
+    endfamily
+    family archive
+      trigger fc/inidata eq complete
+      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
+      edit EMOS_TYPE 'an'
+      edit FSFAMILY 'mars'
+      task ma_anml
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+      task sp2fdb
+        trigger ../fc/model:step ge 0 or ../fc/model eq complete
+        edit EMOS_TYPE 'fc'
+        edit STEPS '0'
+        label files ""
+        label info ""
+        event fdb
+      family fc000
+        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
+        edit STEPS '0'
+        task fcml
+          label files ""
+          label info ""
+          event fdb
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc024
+        trigger ../fc/model:step ge 24 or ../fc/model eq complete
+        edit STEPS '3/6/9/12/15/18/21/24'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc036
+        trigger ../fc/model:step ge 36 or ../fc/model eq complete
+        edit STEPS '27/30/33/36'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc060
+        trigger ../fc/model:step ge 60 or ../fc/model eq complete
+        edit STEPS '39/42/45/48/51/54/57/60'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc072
+        trigger ../fc/model:step ge 72 or ../fc/model eq complete
+        edit STEPS '63/66/69/72'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc120
+        trigger ../fc/model:step ge 120 or ../fc/model eq complete
+        edit STEPS '78/84/90/96/102/108/114/120'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc180
+        trigger ../fc/model:step ge 180 or ../fc/model eq complete
+        edit STEPS '126/132/138/144/150/156/162/168/174/180'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc240
+        trigger ../fc/model:step ge 240 or ../fc/model eq complete
+        edit STEPS '186/192/198/204/210/216/222/228/234/240'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcextra
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      task fc12g
+        trigger ../fc/model eq complete
+        edit STREAM 'MAED'
+        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+        edit STEPS_SPECTRAL ''
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+    endfamily
+  endfamily
+  family mfr
+    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
+    edit INIMA 'mfr'
+    edit INIMACONS '0'
+    family fc
+      edit FCLENGTH '240'
+      edit FCMEM '2000'
+      edit FCSTACK '700'
+      edit FCMRFS '0'
+      edit FSFAMILY 'gfc'
+      task inidata
+        edit THREADS '4'
+        inlimit /ema_36r1/limits:inidata
+      task getfcdata
+        trigger inidata eq complete
+        edit FSFAMILY 'fc'
+      task getpersSST
+        trigger getfcdata eq complete
+        edit FSFAMILY 'fc'
+        edit SSTLEN '240'
+        edit SSTINT '1'
+        edit THREADS '2'
+        edit NPES '4'
+        edit MEM '1000'
+        edit CPUTIME '960'
+      task model
+        trigger getpersSST eq complete
+        edit PERSST 'true'
+        edit FSFAMILY 'fc'
+        edit FCLENGTH '240'
+        meter step -1 240 240
+    endfamily
+    family archive
+      trigger fc/inidata eq complete
+      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
+      edit EMOS_TYPE 'an'
+      edit FSFAMILY 'mars'
+      task ma_anml
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+      task sp2fdb
+        trigger ../fc/model:step ge 0 or ../fc/model eq complete
+        edit EMOS_TYPE 'fc'
+        edit STEPS '0'
+        label files ""
+        label info ""
+        event fdb
+      family fc000
+        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
+        edit STEPS '0'
+        task fcml
+          label files ""
+          label info ""
+          event fdb
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc024
+        trigger ../fc/model:step ge 24 or ../fc/model eq complete
+        edit STEPS '3/6/9/12/15/18/21/24'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc036
+        trigger ../fc/model:step ge 36 or ../fc/model eq complete
+        edit STEPS '27/30/33/36'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc060
+        trigger ../fc/model:step ge 60 or ../fc/model eq complete
+        edit STEPS '39/42/45/48/51/54/57/60'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc072
+        trigger ../fc/model:step ge 72 or ../fc/model eq complete
+        edit STEPS '63/66/69/72'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc120
+        trigger ../fc/model:step ge 120 or ../fc/model eq complete
+        edit STEPS '78/84/90/96/102/108/114/120'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc180
+        trigger ../fc/model:step ge 180 or ../fc/model eq complete
+        edit STEPS '126/132/138/144/150/156/162/168/174/180'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc240
+        trigger ../fc/model:step ge 240 or ../fc/model eq complete
+        edit STEPS '186/192/198/204/210/216/222/228/234/240'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcextra
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      task fc12g
+        trigger ../fc/model eq complete
+        edit STREAM 'MAED'
+        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+        edit STEPS_SPECTRAL ''
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+    endfamily
+  endfamily
+  family consensus
+    trigger init/getini eq complete and init/wavini eq complete and /ema_36r1/make eq complete
+    edit INIMA 'mfr ncep ukm dwd '
+    edit INIMACONS '1'
+    family fc
+      edit FCLENGTH '240'
+      edit FCMEM '2000'
+      edit FCSTACK '700'
+      edit FCMRFS '0'
+      edit FSFAMILY 'gfc'
+      task inidata
+        edit THREADS '4'
+        inlimit /ema_36r1/limits:inidata
+      task getfcdata
+        trigger inidata eq complete
+        edit FSFAMILY 'fc'
+      task getpersSST
+        trigger getfcdata eq complete
+        edit FSFAMILY 'fc'
+        edit SSTLEN '240'
+        edit SSTINT '1'
+        edit THREADS '2'
+        edit NPES '4'
+        edit MEM '1000'
+        edit CPUTIME '960'
+      task model
+        trigger getpersSST eq complete
+        edit PERSST 'true'
+        edit FSFAMILY 'fc'
+        edit FCLENGTH '240'
+        meter step -1 240 240
+    endfamily
+    family archive
+      trigger fc/inidata eq complete
+      edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
+      edit EMOS_TYPE 'an'
+      edit FSFAMILY 'mars'
+      task ma_anml
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+      task sp2fdb
+        trigger ../fc/model:step ge 0 or ../fc/model eq complete
+        edit EMOS_TYPE 'fc'
+        edit STEPS '0'
+        label files ""
+        label info ""
+        event fdb
+      family fc000
+        trigger sp2fdb eq complete and ( ../fc/model:step ge 0 or ../fc/model eq complete)
+        edit STEPS '0'
+        task fcml
+          label files ""
+          label info ""
+          event fdb
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc024
+        trigger ../fc/model:step ge 24 or ../fc/model eq complete
+        edit STEPS '3/6/9/12/15/18/21/24'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc036
+        trigger ../fc/model:step ge 36 or ../fc/model eq complete
+        edit STEPS '27/30/33/36'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc060
+        trigger ../fc/model:step ge 60 or ../fc/model eq complete
+        edit STEPS '39/42/45/48/51/54/57/60'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc072
+        trigger ../fc/model:step ge 72 or ../fc/model eq complete
+        edit STEPS '63/66/69/72'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc120
+        trigger ../fc/model:step ge 120 or ../fc/model eq complete
+        edit STEPS '78/84/90/96/102/108/114/120'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc180
+        trigger ../fc/model:step ge 180 or ../fc/model eq complete
+        edit STEPS '126/132/138/144/150/156/162/168/174/180'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      family fc240
+        trigger ../fc/model:step ge 240 or ../fc/model eq complete
+        edit STEPS '186/192/198/204/210/216/222/228/234/240'
+        task fcsfc
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcpl
+          trigger fcsfc:fdb or fcsfc eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcil
+          trigger fcpl:fdb or fcpl eq complete
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+        task fcextra
+          inlimit /ema_36r1/limits:mars
+          inlimit /limits:mars
+          label files ""
+          label info ""
+          event fdb
+      endfamily
+      task fc12g
+        trigger ../fc/model eq complete
+        edit STREAM 'MAED'
+        edit STEPS '0/3/6/9/12/15/18/21/24/27/30/33/36/39/42/45/48/51/54/57/60/63/66/69/72/78/84/90/96/102/108/114/120/126/132/138/144/150/156/162/168/174/180/186/192/198/204/210/216/222/228/234/240'
+        edit STEPS_SPECTRAL ''
+        inlimit /ema_36r1/limits:mars
+        inlimit /limits:mars
+        label files ""
+        label info ""
+        event fdb
+    endfamily
+  endfamily
+  family verify
+    trigger dwd eq complete and ukm eq complete and ncep eq complete and mfr eq complete and consensus eq complete
+    edit QUEUE 'emos-e'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit SMSOUT '/vol/emos_nc/output'
+    edit SMSFILES '/home/ma/emos/def/ema_36r1/verif'
+    inlimit /limits:linux_cluster
+    task vmaprep
+    family washington
+      trigger vmaprep eq complete
+      edit CENTRE 'washington'
+      edit CENTRE_STREAM 'ma_washington_36r1'
+      task vmacrd
+        edit DATEMASK '28.*.*'
+      task vmali1
+      task vmali2
+      task vmaup1
+        trigger vmali1 eq complete
+      task vmaup2
+        trigger vmaup1 eq complete and vmali2 eq complete
+      task vmacrmv
+        edit DATEMASK '28.*.*'
+      task vmamemv
+        trigger vmaup2 eq complete
+        edit DATEMASK '01.*.*'
+      task vmaupmv
+        trigger vmamemv eq complete
+        edit DATEMASK '01.*.*'
+      task vmacrmb
+        edit DATEMASK '28.*.*'
+      task vmamemb
+        trigger vmaup2 eq complete
+        edit DATEMASK '10.*.*'
+      task vmaupmb
+        trigger vmamemb eq complete
+        edit DATEMASK '10.*.*'
+    endfamily
+    family bracknell
+      trigger vmaprep eq complete
+      edit CENTRE 'bracknell'
+      edit CENTRE_STREAM 'ma_bracknell_36r1'
+      task vmacrd
+        edit DATEMASK '28.*.*'
+      task vmali1
+      task vmali2
+      task vmaup1
+        trigger vmali1 eq complete
+      task vmaup2
+        trigger vmaup1 eq complete and vmali2 eq complete
+      task vmacrmv
+        edit DATEMASK '28.*.*'
+      task vmamemv
+        trigger vmaup2 eq complete
+        edit DATEMASK '01.*.*'
+      task vmaupmv
+        trigger vmamemv eq complete
+        edit DATEMASK '01.*.*'
+      task vmacrmb
+        edit DATEMASK '28.*.*'
+      task vmamemb
+        trigger vmaup2 eq complete
+        edit DATEMASK '10.*.*'
+      task vmaupmb
+        trigger vmamemb eq complete
+        edit DATEMASK '10.*.*'
+    endfamily
+    family offenbach
+      trigger vmaprep eq complete
+      edit CENTRE 'offenbach'
+      edit CENTRE_STREAM 'ma_offenbach_36r1'
+      task vmacrd
+        edit DATEMASK '28.*.*'
+      task vmali1
+      task vmali2
+      task vmaup1
+        trigger vmali1 eq complete
+      task vmaup2
+        trigger vmaup1 eq complete and vmali2 eq complete
+      task vmacrmv
+        edit DATEMASK '28.*.*'
+      task vmamemv
+        trigger vmaup2 eq complete
+        edit DATEMASK '01.*.*'
+      task vmaupmv
+        trigger vmamemv eq complete
+        edit DATEMASK '01.*.*'
+      task vmacrmb
+        edit DATEMASK '28.*.*'
+      task vmamemb
+        trigger vmaup2 eq complete
+        edit DATEMASK '10.*.*'
+      task vmaupmb
+        trigger vmamemb eq complete
+        edit DATEMASK '10.*.*'
+    endfamily
+    family toulouse
+      trigger vmaprep eq complete
+      edit CENTRE 'toulouse'
+      edit CENTRE_STREAM 'ma_toulouse_36r1'
+      task vmacrd
+        edit DATEMASK '28.*.*'
+      task vmali1
+      task vmali2
+      task vmaup1
+        trigger vmali1 eq complete
+      task vmaup2
+        trigger vmaup1 eq complete and vmali2 eq complete
+      task vmacrmv
+        edit DATEMASK '28.*.*'
+      task vmamemv
+        trigger vmaup2 eq complete
+        edit DATEMASK '01.*.*'
+      task vmaupmv
+        trigger vmamemv eq complete
+        edit DATEMASK '01.*.*'
+      task vmacrmb
+        edit DATEMASK '28.*.*'
+      task vmamemb
+        trigger vmaup2 eq complete
+        edit DATEMASK '10.*.*'
+      task vmaupmb
+        trigger vmamemb eq complete
+        edit DATEMASK '10.*.*'
+    endfamily
+    family consensus
+      trigger vmaprep eq complete
+      edit CENTRE 'consensus'
+      edit CENTRE_STREAM 'ma_consensus_36r1'
+      task vmacrd
+        edit DATEMASK '28.*.*'
+      task vmali1
+      task vmali2
+      task vmaup1
+        trigger vmali1 eq complete
+      task vmaup2
+        trigger vmaup1 eq complete and vmali2 eq complete
+      task vmacrmv
+        edit DATEMASK '28.*.*'
+      task vmamemv
+        trigger vmaup2 eq complete
+        edit DATEMASK '01.*.*'
+      task vmaupmv
+        trigger vmamemv eq complete
+        edit DATEMASK '01.*.*'
+      task vmacrmb
+        edit DATEMASK '28.*.*'
+      task vmamemb
+        trigger vmaup2 eq complete
+        edit DATEMASK '10.*.*'
+      task vmaupmb
+        trigger vmamemb eq complete
+        edit DATEMASK '10.*.*'
+    endfamily
+  endfamily
+  family trans
+    complete /ema_36r1/ncep eq complete and /ema_36r1/ncep/fc/model:step lt 240
+    trigger /ema_36r1/ncep/fc eq complete and /ema_36r1/consensus/fc eq complete
+    edit EMOS_TYPE 'fc'
+    edit SMSFILES '/home/ma/emos/def/ema_36r1/archive'
+    edit FSFAMILY 'ppdi'
+    edit SMSTRIES '1'
+    edit EMOS_STREAM 'MAED'
+    edit SMSURLBASE 'http://diss.ecmwf.int/do/monitoring/arrival'
+    edit SMSURL 'USA/GMAED/12'
+    edit SCHEDULE_DISS_TIME '0'
+    inlimit /ema_36r1/limits:prod
+    family 000
+      edit STEP '000'
+      task trans_ma
+    endfamily
+    family 012
+      trigger ./000 eq complete
+      edit STEP '012'
+      task trans_ma
+    endfamily
+    family 024
+      trigger ./012 eq complete
+      edit STEP '024'
+      task trans_ma
+    endfamily
+    family 036
+      trigger ./024 eq complete
+      edit STEP '036'
+      task trans_ma
+    endfamily
+    family 048
+      trigger ./036 eq complete
+      edit STEP '048'
+      task trans_ma
+    endfamily
+    family 060
+      trigger ./048 eq complete
+      edit STEP '060'
+      task trans_ma
+    endfamily
+    family 072
+      trigger ./060 eq complete
+      edit STEP '072'
+      task trans_ma
+    endfamily
+    family 084
+      trigger ./072 eq complete
+      edit STEP '084'
+      task trans_ma
+    endfamily
+    family 096
+      trigger ./084 eq complete
+      edit STEP '096'
+      task trans_ma
+    endfamily
+    family 108
+      trigger ./096 eq complete
+      edit STEP '108'
+      task trans_ma
+    endfamily
+    family 120
+      trigger ./108 eq complete
+      edit STEP '120'
+      task trans_ma
+    endfamily
+    family 132
+      trigger ./120 eq complete
+      edit STEP '132'
+      task trans_ma
+    endfamily
+    family 144
+      trigger ./132 eq complete
+      edit STEP '144'
+      task trans_ma
+    endfamily
+    family 156
+      trigger ./144 eq complete
+      edit STEP '156'
+      task trans_ma
+    endfamily
+    family 168
+      trigger ./156 eq complete
+      edit STEP '168'
+      task trans_ma
+    endfamily
+    family 180
+      trigger ./168 eq complete
+      edit STEP '180'
+      task trans_ma
+    endfamily
+    family 192
+      trigger ./180 eq complete
+      edit STEP '192'
+      task trans_ma
+    endfamily
+    family 204
+      trigger ./192 eq complete
+      edit STEP '204'
+      task trans_ma
+    endfamily
+    family 216
+      trigger ./204 eq complete
+      edit STEP '216'
+      task trans_ma
+    endfamily
+    family 228
+      trigger ./216 eq complete
+      edit STEP '228'
+      task trans_ma
+    endfamily
+    family 240
+      trigger ./228 eq complete
+      edit STEP '240'
+      task trans_ma
+    endfamily
+  endfamily
+  family pop
+    edit QUEUE 'emos-e'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit SMSOUT '/vol/emos_nc/output'
+    edit SMSFILES '/home/ma/emos/def/ema_36r1/plot'
+    inlimit /limits:linux_cluster
+    family 12
+      trigger /ema_36r1/dwd eq complete and /ema_36r1/ukm eq complete and /ema_36r1/ncep eq complete and /ema_36r1/mfr eq complete and /ema_36r1/consensus eq complete
+      edit EMOS_BASE '12'
+      family paper
+        task ma_plot
+      endfamily
+    endfamily
+  endfamily
+  family msjobs
+    edit QUEUE 'emos'
+    edit QUEUE_EPILOG 'emos-exp'
+    edit WSHOST 'ecgate'
+    edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+    edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+    edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+    edit SMSOUT '/vol/emos_nc/output'
+    edit LOGDIR '/vol/emos_nc/output'
+    edit VERSION '0046'
+    edit STREAM 'MA'
+    edit EMOS_STREAM 'MA'
+    edit SMSTRYNO '1'
+    edit SMSURLBASE 'http://ecgate.ecmwf.int:9080'
+    edit SMSURL 'do/events'
+    family 12
+      trigger ../trans eq complete
+      edit SMSFILES '/home/ma/emos/def/ema_36r1/msjobs'
+      family msma
+        edit EMOS_TIME_STEP_H '240'
+        edit MSJ_DIR 'ma12h240'
+        task ms_ec
+      endfamily
+    endfamily
+  endfamily
+  family check
+    task checkarchive
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit FSFAMILY 'mars'
+      edit EMOS_TYPE 'an'
+      inlimit /limits:linux_cluster
+      label info ""
+  endfamily
+  family save
+    edit SMSFILES '/home/ma/emos/def/ema_36r1/restart'
+    task logfilestore
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+  endfamily
+  family log
+    trigger make eq complete and init eq complete and dwd eq complete and ukm eq complete and ncep eq complete and mfr eq complete and consensus eq complete and verify eq complete and trans eq complete and pop eq complete and msjobs eq complete and check eq complete and save eq complete
+    edit SMSFILES '/home/ma/emos/def/ema_36r1/restart'
+    task logfiles
+      late -s +00:05 -c +00:15
+      edit QUEUE 'emos-e'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+      time 14:00
+  endfamily
+endsuite
+suite ejason2_val
+  edit SMSHOME '/vol/emos_nc/output'
+  edit SMSFILES '/home/ma/emos/def/ejason2_val/smsfiles'
+  edit SMSINCLUDE '/home/ma/emos/def/ejason2_val/include'
+  edit MEM '2500'
+  edit USER 'emos'
+  edit SCHOST 'c1b'
+  edit SCHOST_BKUP 'c1a'
+  edit WSHOST 'linux_cluster'
+  edit ACCOUNT 'oesu'
+  edit WSLOGDIR '/vol/emos_nc/output'
+  edit SCLOGDIR '/s1b/emos_esuite/emos_data/9002/log'
+  edit SMSLOGHOST 'c1b'
+  edit SMSLOGPORT '9316'
+  edit SMSURLBASE 'http://www.cnes.fr/web'
+  edit SMSURL '1441-jason.php'
+  edit QUEUE 'ns'
+  edit QUEUE_EPILOG 'ns'
+  edit SMSCMD 'smssubmit %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+  edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+  edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %SCHOST% %SMSRID% %SMSJOB%'
+  edit LOGDIR '/s1b/emos_esuite/emos_data/9002/log'
+  edit SMSOUT '/s1b/emos_esuite/emos_data/9002/log'
+  edit VERSION '5'
+  edit EXPVER '9002'
+  edit GRID '400'
+  edit HOMEDIR '/s1b/emos_esuite/emos_data/jasonII'
+  edit SLEEPTIME '1'
+  inlimit /limits:c1b
+  clock hybrid 
+  family limits
+    limit limiter 1
+    limit c1b 7
+    limit swarm 7
+  endfamily
+  family main
+    repeat date YMD 20071231 20091231 1
+    edit LOGTASK 'main'
+    edit CALL_ECPDS 'false'
+    edit DESTINATION 'EMI'
+    edit ECPDS_STREAM 'JSN2'
+    family make
+      task common
+      task local
+        trigger common eq complete
+      task purge
+    endfamily
+    task cleaner
+      trigger make eq complete
+      edit KEEP_DAYS '2'
+    task stage
+    family prod
+      trigger make eq complete
+      inlimit /ejason2_val/limits:limiter
+      family 15P
+        edit LABELS '15P'
+        edit EMOS_CYCLE '12'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
+      endfamily
+      family 18P
+        edit LABELS '18P'
+        edit EMOS_CYCLE '12'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
+      endfamily
+      family 21P
+        edit LABELS '21P'
+        edit EMOS_CYCLE '12'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
+      endfamily
+      family 24P
+        edit LABELS '24P'
+        edit EMOS_CYCLE '12'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/12/fc/model eq complete )
+      endfamily
+      family 03P
+        edit LABELS '03P'
+        edit DELTA_DAY '1'
+        edit EMOS_CYCLE '00'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
+      endfamily
+      family 06P
+        edit LABELS '06P'
+        edit DELTA_DAY '1'
+        edit EMOS_CYCLE '00'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
+      endfamily
+      family 09P
+        edit LABELS '09P'
+        edit DELTA_DAY '1'
+        edit EMOS_CYCLE '00'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
+      endfamily
+      family 12P
+        edit LABELS '12P'
+        edit DELTA_DAY '1'
+        edit EMOS_CYCLE '00'
+        task jason2_val
+          trigger ( /ejason2_val/main:YMD lt /o/main:YMD) or ( /ejason2_val/main:YMD eq /o/main:YMD and /o/main/00/fc/model eq complete )
+        task arch_val
+          trigger ( ./jason2_val eq complete) and ( ../03P eq complete) and ( ../06P eq complete) and ( ../09P eq complete) and ( ../24P eq complete) and ( ../15P eq complete) and ( ../18P eq complete) and ( ../21P eq complete)
+          edit DELTA_DAY '0'
+      endfamily
+    endfamily
+    task logfilestore
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit KEEPLOGS 'no'
+      edit LOGSTOECFS 'no'
+      edit MOVE_TO_ECFS 'yes'
+    task logfiles
+      trigger ( prod eq complete) and ( logfilestore eq complete)
+      edit QUEUE 'emos'
+      edit QUEUE_EPILOG 'emos-exp'
+      edit WSHOST 'localhost'
+      edit SMSCMD 'smssubmit %USER% %WSHOST% %SMSJOB% %SMSJOBOUT%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+      edit SMSSTATUSCMD '/home/ma/emos/bin/smsstatus %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit LOGDIR '/vol/emos_nc/output'
+      edit SMSOUT '/vol/emos_nc/output'
+      edit MOVE_TO_ECFS 'no'
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/test_auto_add_extern.def 5.13.0-1/libs/node/test/parser/data/single_defs/test_auto_add_extern.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/test_auto_add_extern.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/test_auto_add_extern.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,48 @@
+#
+# test auto add extern for triggers and inlimits
+#
+extern /a/b/c/d         
+extern /a/b/c/d/e:event        
+extern /a/b/c/d/e:meter       
+extern /made/up/redundant/extren     # REDUNDANT extern, should get removed after auto_add_extren(true)
+extern /made/up/redundant/extren     # Duplicates should be ignored.
+
+extern /limits:c1a
+extern /limits:c1a                   # Duplicates should be ignored
+extern fred
+extern limits:hpcd
+extern /suiteName:sg1
+extern /obs/limits:hpcd
+
+extern /extern/f1/parent_variable:var1
+extern /extern/f1/parent_variable:var2
+
+# Expect 10 unique externs
+# expect:  extern /made/up/redundant/extren  to be removed
+# Also because we have defined externs , expect no warnings:
+
+suite extern
+   family f1
+      task p
+            trigger /a/b/c/d == complete          # extern path
+      task q
+            trigger /a/b/c/d/e:event == set       # extern event path
+      task r
+            trigger /a/b/c/d/e:meter le 30        # extern meter path   
+      task parent_variable
+            trigger :var1 == 1 and :var2 == 2
+    endfamily
+    
+    
+    inlimit /limits:c1a
+    inlimit fred
+    family anon    
+         inlimit limits:hpcd       
+      task t1
+         inlimit /suiteName:sg1            
+      task t2
+            inlimit /obs/limits:hpcd       
+      task t3
+            inlimit /limits:c1a            
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/test_complete.def 5.13.0-1/libs/node/test/parser/data/single_defs/test_complete.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/test_complete.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/test_complete.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+   suite complete
+      edit SMSHOME data/SMSHOME
+      edit SMSINCLUDE $SMSHOME/includes
+      edit SLEEPTIME 1
+      family family
+         complete /complete/family/check:nofiles
+         repeat integer VAR 0 3
+         task check
+            event 1 nofiles
+         task t1
+            trigger check == complete
+        task t2
+            trigger t2 == complete
+      endfamily
+   endsuite
+
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/test_repeat.def 5.13.0-1/libs/node/test/parser/data/single_defs/test_repeat.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/test_repeat.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/test_repeat.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite s1
+  # clock real 300 -c 60
+  family daily
+    repeat date YMD 20101215 20101217 1
+    task t1
+      time 10:30
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/node/test/parser/data/single_defs/test_time_why.def 5.13.0-1/libs/node/test/parser/data/single_defs/test_time_why.def
--- 5.12.4-1/libs/node/test/parser/data/single_defs/test_time_why.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/node/test/parser/data/single_defs/test_time_why.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+# Definition of the suite test
+suite test
+ family f2
+     edit SLEEP 20
+     task t1
+         date 5.*.*
+         time 00:30 23:30 00:30
+     task t2
+         day tuesday
+         day wednesday
+         day monday
+         day sunday
+         time 09:00
+    task t21
+         day tuesday
+         day wednesday
+         day monday
+         day sunday
+         today 09:00
+     task t3
+         date 1.*.*
+         time 08:00
+     task t4
+         date 6.*.*
+         date 7.*.*
+         date 8.*.*
+         date 5.*.*
+         time 09:02
+     task t5
+         time 08:00
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/.gitignore 5.13.0-1/libs/pyext/.gitignore
--- 5.12.4-1/libs/pyext/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/.gitignore	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+/build
+/setup.py
+/timestamp
diff -pruN 5.12.4-1/libs/pyext/CMakeLists.txt 5.13.0-1/libs/pyext/CMakeLists.txt
--- 5.12.4-1/libs/pyext/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,262 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+### ecflow python bindings
+# NOTES:
+# 1/ Building multiple python3 versions not supported, since find_python(..) caches variables, Hack: clear cached variable.
+#    https://gitlab.kitware.com/cmake/cmake/issues/19820
+#
+# 2/
+# To see the python link line: Do python-config  --ldflags, i.e
+#   > /usr/local/apps/python/2.7.8-01/bin/python-config  --ldflags
+#   > -lpthread -ldl -lutil -lm -lpython2.7 -Xlinker -export-dynamic
+#
+# However on cct we get:
+#   > /usr/local/apps/python/2.7.5-01/bin/python-config --ldflags
+#   > -L/usr/local/apps/python/2.7.5-01/lib/python2.7/config -lpthread -ldl -lutil -lm -lpython2.7 -Xlinker -export-dynamic
+#
+# cct is correct as it has the "-L" but on other machines we rely on /usr/lib/libpython2.7.so.1.0 being there!
+# lxop-test does not have /usr/lib/libpython2.7.so.1.0 so ecbuild fails
+#
+# For problems with the python build, please look in <build-dir>/ecbuild.log, typically non developmental python
+# installs may not include python libs or includes
+# For ubuntoo to install we need:
+#    sudo apt-get install libpython-dev
+#
+
+# =============================================================================
+# Configure __init__.py to add __version__
+# =============================================================================
+set(INIT_PY_IN  "${CMAKE_CURRENT_SOURCE_DIR}/ecflow/__init__.py.in")
+set(INIT_PY_OUT "${CMAKE_CURRENT_SOURCE_DIR}/ecflow/__init__.py")
+configure_file(${INIT_PY_IN} ${INIT_PY_OUT} )
+
+
+# =============================================================================
+# Configure setup.py. Note used locally. Uses existing libraries
+# =============================================================================
+set(SETUP_PY_IN  "${CMAKE_CURRENT_SOURCE_DIR}/setup.py.in")
+set(SETUP_PY_OUT "${CMAKE_CURRENT_SOURCE_DIR}/setup.py")
+configure_file(${SETUP_PY_IN} ${SETUP_PY_OUT} )
+
+# ==============================================================================
+# source files (paths relative to dirs python2/python3)
+# ==============================================================================
+set(srcs
+  # Headers
+  ../src/ecflow/python/BoostPythonUtil.hpp
+  ../src/ecflow/python/ClientDoc.hpp
+  ../src/ecflow/python/DefsDoc.hpp
+  ../src/ecflow/python/Edit.hpp
+  ../src/ecflow/python/GlossaryDoc.hpp
+  ../src/ecflow/python/NodeAttrDoc.hpp
+  ../src/ecflow/python/NodeUtil.hpp
+  ../src/ecflow/python/Trigger.hpp
+  # Sources
+  ../src/ecflow/python/BoostPythonUtil.cpp
+  ../src/ecflow/python/ClientDoc.cpp
+  ../src/ecflow/python/DefsDoc.cpp
+  ../src/ecflow/python/EcfExt.cpp
+  ../src/ecflow/python/Edit.cpp
+  ../src/ecflow/python/ExportClient.cpp
+  ../src/ecflow/python/ExportCore.cpp
+  ../src/ecflow/python/ExportDefs.cpp
+  ../src/ecflow/python/ExportNode.cpp
+  ../src/ecflow/python/ExportNodeAttr.cpp
+  ../src/ecflow/python/ExportSuiteAndFamily.cpp
+  ../src/ecflow/python/ExportTask.cpp
+  ../src/ecflow/python/GlossaryDoc.cpp
+  ../src/ecflow/python/NodeAttrDoc.cpp
+  ../src/ecflow/python/NodeUtil.cpp
+  ../src/ecflow/python/Trigger.cpp
+)
+
+# =====================================================================
+# tests
+# =====================================================================
+set(u_tests
+  py_u_test_add
+  py_u_test_collection
+  py_u_test_cron
+  py_u_test_defs_constructor
+  py_u_test_get_attr
+  py_u_test_manual
+  py_u_test_late
+  py_u_test_replace_node
+  py_u_test_tutorial
+  py_u_TestAddDelete
+  py_u_TestAddDeleteFunc
+  py_u_TestAddNodeFunc
+  py_u_TestAutoAddExtern
+  py_u_TestAviso
+  py_u_TestCopy
+  py_u_TestDefs
+  py_u_TestDefsCheck
+  py_u_TestDerivable
+  py_u_TestEcf
+  py_u_TestError
+  py_u_TestFind
+  py_u_TestFlag
+  py_u_TestGetAllTasks
+  py_u_TestJobGeneration
+  py_u_TestMirror
+  py_u_TestParent
+  py_u_TestRemove
+  py_u_TestRepeatArithmetic
+  py_u_TestSimulator
+  py_u_TestTraversal
+  py_u_TestUserManual
+  py_u_TestWith
+  py_u_sort
+)
+
+set(s_tests
+  s_TestClientApi
+  s_TestPythonChildApi
+)
+
+
+message( STATUS "====================================================================================================================" )
+message( STATUS "PYTHON2" )
+message( STATUS "====================================================================================================================" )
+if(${CMAKE_VERSION} VERSION_LESS "3.12.0") 
+  # We only support python2 extension for cmake less 3.12.0
+  # cmake 3.12.0 or greater allows multiple boost python libs & hence multiple extensions to be built
+  # Using -DPYTHON_EXECUTABLE=/usr/local/apps/python3/3.6.5-01/bin/python3 is not sufficient as the wrong(python2) libs are found
+  ecbuild_find_python( VERSION 2.6 REQUIRED )  
+  message( STATUS "  PYTHON_FOUND                      : ${PYTHON_FOUND}" )
+  message( STATUS "  PYTHONINTERP_FOUND                : ${PYTHONINTERP_FOUND}" )
+  message( STATUS "  PYTHONLIBS_FOUND                  : ${PYTHONLIBS_FOUND}" )
+  message( STATUS "  PYTHON_VERSION_STRING             : ${PYTHON_VERSION_STRING}" )
+  message( STATUS "  PYTHON_VERSION_MAJOR              : ${PYTHON_VERSION_MAJOR}" )
+  message( STATUS "  PYTHON_VERSION_MINOR              : ${PYTHON_VERSION_MINOR}" )
+  message( STATUS "  PYTHON_VERSION_PATCH              : ${PYTHON_VERSION_PATCH}" )
+  message( STATUS "  PYTHON_CONFIG_EXECUTABLE          : ${PYTHON_CONFIG_EXECUTABLE}" )
+  message( STATUS "  PYTHON_EXECUTABLE                 : ${PYTHON_EXECUTABLE}" )
+  message( STATUS "  PYTHON_INCLUDE_DIRS               : ${PYTHON_INCLUDE_DIRS}" )
+  message( STATUS "  PYTHON_LIBRARIES                  : ${PYTHON_LIBRARIES}" )
+  if (${PYTHON_VERSION_MAJOR} EQUAL 3)
+    ecbuild_error("Need cmake version >= 3.12.0 to build ecflow python3 extension, current cmake version is ${CMAKE_VERSION}")
+  endif()
+
+  find_package( Boost ${ECFLOW_BOOST_VERSION} REQUIRED COMPONENTS python )
+  add_subdirectory( python2 )
+else()
+  # ======================================================================================
+  # Attempt to build both python2 *AND/OR* python3 ecflow extension, depending on what is found
+  # this assumes cmake 3.12.0 min, which added support for boost python2 and python3
+  # * NOTICE* that we do *NOT* use REQUIRED when searching for boost python libs
+  # ======================================================================================
+  find_package(Python2 COMPONENTS Interpreter Development)
+  if (Python2_FOUND)
+    message( STATUS "  Python2_Interpreter_FOUND         : ${Python2_Interpreter_FOUND}" )
+    message( STATUS "  Python2_EXECUTABLE                : ${Python2_EXECUTABLE}" )
+    message( STATUS "  Python2_STDLIB                    : ${Python2_STDLIB}    Standard platform independent installation directory" )
+    message( STATUS "  Python2_STDARCH                   : ${Python2_STDARCH}   Standard platform dependent installation directory." )
+    message( STATUS "  Python2_Development_FOUND         : ${Python2_Development_FOUND}" )
+    message( STATUS "  Python2_INCLUDE_DIRS              : ${Python2_INCLUDE_DIRS}" )
+    message( STATUS "  Python2_LIBRARIES                 : ${Python2_LIBRARIES}" )
+    message( STATUS "  Python2_LIBRARY_DIRS              : ${Python2_LIBRARY_DIRS}" )
+    message( STATUS "  Python2_VERSION                   : ${Python2_VERSION}" )
+    message( STATUS "  Python2_VERSION_MAJOR             : ${Python2_VERSION_MAJOR}" )
+    message( STATUS "  Python2_VERSION_MINOR             : ${Python2_VERSION_MINOR}" )
+    message( STATUS "  Python2_VERSION_PATCH             : ${Python2_VERSION_PATCH}" )
+    # *****************************************************************************************
+    # Although we have found python2 it could be that *ONLY* python3 was module loaded
+    # Otherwise will build for python2 and test with python3 interpreter
+    # *****************************************************************************************
+    if ( Python2_LIBRARIES )
+      ecbuild_find_python( VERSION 2.6 REQUIRED ) # if not included iterpreter not found ?
+      if ( ${PYTHON_VERSION_MAJOR} EQUAL 2)
+        message( STATUS "  PYTHON_FOUND                      : ${PYTHON_FOUND}" )
+        message( STATUS "  PYTHONINTERP_FOUND                : ${PYTHONINTERP_FOUND}" )
+        message( STATUS "  PYTHONLIBS_FOUND                  : ${PYTHONLIBS_FOUND}" )
+        message( STATUS "  PYTHON_VERSION_STRING             : ${PYTHON_VERSION_STRING}" )
+        message( STATUS "  PYTHON_VERSION_MAJOR              : ${PYTHON_VERSION_MAJOR}" )
+        message( STATUS "  PYTHON_VERSION_MINOR              : ${PYTHON_VERSION_MINOR}" )
+        message( STATUS "  PYTHON_VERSION_PATCH              : ${PYTHON_VERSION_PATCH}" )
+        message( STATUS "  PYTHON_CONFIG_EXECUTABLE          : ${PYTHON_CONFIG_EXECUTABLE}" )
+        message( STATUS "  PYTHON_EXECUTABLE                 : ${PYTHON_EXECUTABLE}" )
+        message( STATUS "  PYTHON_INCLUDE_DIRS               : ${PYTHON_INCLUDE_DIRS}" )
+        message( STATUS "  PYTHON_LIBRARIES                  : ${PYTHON_LIBRARIES}" )
+
+        if ( Boost_MINOR_VERSION GREATER 66 )
+          # cmake 3.15
+          # see: https://gitlab.kitware.com/cmake/cmake/issues/19656
+          # INTERFACE_LIBRARY targets may only have whitelisted properties."
+          set(ECFLOW_BOOST_PYTHON_COMPONENT python${Python2_VERSION_MAJOR}${Python2_VERSION_MINOR})
+        else()
+          set(ECFLOW_BOOST_PYTHON_COMPONENT python)
+        endif()
+        find_package( Boost ${ECFLOW_BOOST_VERSION} COMPONENTS ${ECFLOW_BOOST_PYTHON_COMPONENT} )
+
+        if (Boost_PYTHON_FOUND OR Boost_PYTHON${Python2_VERSION_MAJOR}${Python2_VERSION_MINOR}_FOUND)
+          # Indicate that both Python and Boost.Python have been found
+          set(ECF_PYTHON_FOUND "ECF_PYTHON_FOUND")
+          add_subdirectory( python2 )
+        else()
+          message( STATUS "  Boost python2 libraries *NOT* found" )
+        endif()
+      endif()
+    else()
+      message( STATUS "  Python2 libraries *NOT* found" )
+    endif()
+  endif()
+
+  message( STATUS "====================================================================================================================" )
+  message( STATUS "PYTHON3" )
+  message( STATUS "====================================================================================================================" )
+  # The python must include the Development packages. As the headers in these packages is used by boost python.
+  find_package(Python3 COMPONENTS Interpreter Development)
+  if (Python3_FOUND)
+    message( STATUS "  Python3_Interpreter_FOUND         : ${Python3_Interpreter_FOUND}" )
+    message( STATUS "  Python3_EXECUTABLE                : ${Python3_EXECUTABLE}" )
+    message( STATUS "  Python3_STDLIB                    : ${Python3_STDLIB}    Standard platform independent installation directory" )
+    message( STATUS "  Python3_STDARCH                   : ${Python3_STDARCH}   Standard platform dependent installation directory." )
+    message( STATUS "  Python3_Development_FOUND         : ${Python3_Development_FOUND}" )
+    message( STATUS "  Python3_INCLUDE_DIRS              : ${Python3_INCLUDE_DIRS}" )
+    message( STATUS "  Python3_LIBRARIES                 : ${Python3_LIBRARIES}" )
+    message( STATUS "  Python3_LIBRARY_DIRS              : ${Python3_LIBRARY_DIRS}" )
+    message( STATUS "  Python3_VERSION                   : ${Python3_VERSION}" )
+    message( STATUS "  Python3_VERSION_MAJOR             : ${Python3_VERSION_MAJOR}" )
+    message( STATUS "  Python3_VERSION_MINOR             : ${Python3_VERSION_MINOR}" )
+    message( STATUS "  Python3_VERSION_PATCH             : ${Python3_VERSION_PATCH}" )
+
+    # Set (deprecated) FindPython variables
+    # These need to be available, as they are used by `ecbuild_add_test(... TYPE PYTHON ...)`
+    set(PYTHONINTERP_FOUND "${Python3_Interpreter_FOUND}")
+    set(PYTHON_EXECUTABLE "${Python3_EXECUTABLE}")
+
+    if ( Boost_MINOR_VERSION GREATER 66 )
+      # cmake 3.15
+      # see: https://gitlab.kitware.com/cmake/cmake/issues/19656
+      # INTERFACE_LIBRARY targets may only have whitelisted properties.
+      set(ECFLOW_BOOST_PYTHON_COMPONENT python${Python3_VERSION_MAJOR}${Python3_VERSION_MINOR})
+    else()
+      set(ECFLOW_BOOST_PYTHON_COMPONENT python3)
+    endif()
+    find_package( Boost ${ECFLOW_BOOST_VERSION} COMPONENTS ${ECFLOW_BOOST_PYTHON_COMPONENT} )
+
+    if (Boost_PYTHON3_FOUND OR Boost_PYTHON${Python3_VERSION_MAJOR}${Python3_VERSION_MINOR}_FOUND)
+      # Indicate that both Python and Boost.Python have been found
+      set(ECF_PYTHON_FOUND "ECF_PYTHON_FOUND")
+      add_subdirectory( python3 )
+    else()
+      message( STATUS "  Boost python3 libraries *NOT* found" )
+    endif()
+  endif()
+  
+  if (NOT ECF_PYTHON_FOUND)
+    ecbuild_error("ecflow python extension is enabled, but python2/python3 libraries or python boost libraries not found")
+  endif()
+endif()
+message( STATUS "====================================================================================================================" )
+message( STATUS "END PYTHON" )
+message( STATUS "====================================================================================================================" )
diff -pruN 5.12.4-1/libs/pyext/ecflow/__init__.py 5.13.0-1/libs/pyext/ecflow/__init__.py
--- 5.12.4-1/libs/pyext/ecflow/__init__.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/ecflow/__init__.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+from .ecflow import *
+
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $ 
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0 
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+# In applying this licence, ECMWF does not waive the privileges and immunities 
+# granted to it by virtue of its status as an intergovernmental organisation 
+# nor does it submit to any jurisdiction.  
+
+"""
+The ecFlow python module
+"""
+
+__version__ = '5.13.0'
+
+# http://stackoverflow.com/questions/13040646/how-do-i-create-documentation-with-pydoc
diff -pruN 5.12.4-1/libs/pyext/ecflow/__init__.py.in 5.13.0-1/libs/pyext/ecflow/__init__.py.in
--- 5.12.4-1/libs/pyext/ecflow/__init__.py.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/ecflow/__init__.py.in	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+from .ecflow import *
+
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $ 
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0 
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+# In applying this licence, ECMWF does not waive the privileges and immunities 
+# granted to it by virtue of its status as an intergovernmental organisation 
+# nor does it submit to any jurisdiction.  
+
+"""
+The ecFlow python module
+"""
+
+__version__ = '@ecflow_VERSION@'
+
+# http://stackoverflow.com/questions/13040646/how-do-i-create-documentation-with-pydoc
diff -pruN 5.12.4-1/libs/pyext/migrate/abort_and_label_bug.def 5.13.0-1/libs/pyext/migrate/abort_and_label_bug.def
--- 5.12.4-1/libs/pyext/migrate/abort_and_label_bug.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/abort_and_label_bug.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,93 @@
+# 3.1.7
+defs_state MIGRATE state>:aborted flag:late,message state_change:983039 modify_change:1018
+  edit SLEEP '10'
+suite suite #  begun:1 state:aborted dur:01:29:57 flag:message,no_reque
+  defstatus suspended
+  edit ECF_EXTN '.sms'
+  clock real 
+  calendar initTime:2013-Sep-10 12:37:03 suiteTime:2013-Sep-10 15:56:00 duration:03:18:57 initLocalTime:2013-Sep-10 12:37:03 lastTime:2013-Sep-10 15:56:00 calendarIncrement:00:01:00
+  family family # state:aborted dur:02:18:57 flag:message
+    task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/task.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
+      edit VARIABLE 'VALUE'
+    task rescue # passwd:Bs7hroqB abort<:   Script for /suite/family/rescue cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/rescue.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
+      late -s +00:05 -c 00:05
+      complete task eq complete
+      trigger task == aborted
+    task step # passwd:4N9cOzVA abort<:   Script for /suite/family/step cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/step.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
+      trigger task:step le step:STEP
+      trigger -o task eq complete
+      repeat integer STEP 0 100
+    family loop_in_time # state:complete
+      defstatus complete
+      time 12:00
+      task hold # state:complete
+        complete 1==1
+        trigger 1==0
+    endfamily
+  endfamily
+  task household # passwd:31NZt9lV abort<:   Script for /suite/household cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/household.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:22:57 flag:task_aborted,no_script
+    cron 00:00 23:59 01:00 # nextTimeSlot/13:00
+  task monthly # state:queued
+    date 1.*.*
+  family remote # state:aborted dur:01:29:57 flag:message,no_reque suspended:1
+    edit ECF_TRIES '1'
+    family c2a # state:aborted dur:01:29:57 flag:no_reque
+      edit LOGDIR '/s2o1/emos_esuite/emos_data/log'
+      task sub # passwd:gyBC8q.O abort<: PID(28027)  path(/suite/remote/c2a/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos c2a /vol/emos_nc/output/suite/remote/c2a/sub.job1 /s2o1/emos_esuite/emos_data/log/suite/remote/c2a/sub.1 ]>abort try:1 state:aborted dur:01:29:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'c2a'
+    endfamily
+    family ecgate # state:aborted dur:02:02:57 flag:no_reque
+      task sub # passwd:6pIZXvrl abort<: PID(32480)  path(/suite/remote/ecgate/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos ecgate /vol/emos_nc/output/suite/remote/ecgate/sub.job1 /vol/emos_nc/output/suite/remote/ecgate/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'ecgate'
+    endfamily
+    family ibis # state:aborted dur:02:02:57 flag:no_reque
+      task sub # passwd:AEX5NtyU abort<: PID(32532)  path(/suite/remote/ibis/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos ibis /vol/emos_nc/output/suite/remote/ibis/sub.job1 /vol/emos_nc/output/suite/remote/ibis/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'ibis'
+    endfamily
+    family bilbo # state:aborted dur:02:02:57 flag:no_reque
+      task sub # passwd:30IPtlxu abort<: PID(32543)  path(/suite/remote/bilbo/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos bilbo /vol/emos_nc/output/suite/remote/bilbo/sub.job1 /vol/emos_nc/output/suite/remote/bilbo/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'bilbo'
+    endfamily
+  endfamily
+  family catchup2rt # state:aborted dur:03:18:57 flag:message suspended:1
+    task doer # passwd:OXQkmELW abort<:   Script for /suite/catchup2rt/doer cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/catchup2rt/doer.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:1 state:aborted dur:03:18:57 flag:task_aborted,no_script,message,no_reque
+      complete timer eq complete
+      trigger 1==0
+  endfamily
+endsuite
+#
+# Label that spans multiple lines
+suite made_up
+    label info "110 nodes for 1 minutes in 55 minutes, emos12Aeda"
+    label info1 "((11*10*64)) for 30"
+    label info2 ""
+    label info3 "have you? set START_LOBSVR=1 in the task, once, to launch the logserver,
+setup ssh login
+created remote /tmp/map/cray"
+  zombie ecf:fob:label:3600 
+endsuite
diff -pruN 5.12.4-1/libs/pyext/migrate/aborted_reason_bug.def 5.13.0-1/libs/pyext/migrate/aborted_reason_bug.def
--- 5.12.4-1/libs/pyext/migrate/aborted_reason_bug.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/aborted_reason_bug.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,82 @@
+# 3.1.7
+defs_state MIGRATE state>:aborted flag:late,message state_change:983039 modify_change:1018
+  edit SLEEP '10'
+suite suite #  begun:1 state:aborted dur:01:29:57 flag:message,no_reque
+  defstatus suspended
+  edit ECF_EXTN '.sms'
+  clock real 
+  calendar initTime:2013-Sep-10 12:37:03 suiteTime:2013-Sep-10 15:56:00 duration:03:18:57 initLocalTime:2013-Sep-10 12:37:03 lastTime:2013-Sep-10 15:56:00 calendarIncrement:00:01:00
+  family family # state:aborted dur:02:18:57 flag:message
+    task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/task.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
+      edit VARIABLE 'VALUE'
+    task rescue # passwd:Bs7hroqB abort<:   Script for /suite/family/rescue cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/rescue.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
+      late -s +00:05 -c 00:05
+      complete task eq complete
+      trigger task == aborted
+    task step # passwd:4N9cOzVA abort<:   Script for /suite/family/step cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/family/step.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script
+      trigger task:step le step:STEP
+      trigger -o task eq complete
+      repeat integer STEP 0 100
+    family loop_in_time # state:complete
+      defstatus complete
+      time 12:00
+      task hold # state:complete
+        complete 1==1
+        trigger 1==0
+    endfamily
+  endfamily
+  task household # passwd:31NZt9lV abort<:   Script for /suite/household cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/household.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:2 state:aborted dur:02:22:57 flag:task_aborted,no_script
+    cron 00:00 23:59 01:00 # nextTimeSlot/13:00
+  task monthly # state:queued
+    date 1.*.*
+  family remote # state:aborted dur:01:29:57 flag:message,no_reque suspended:1
+    edit ECF_TRIES '1'
+    family c2a # state:aborted dur:01:29:57 flag:no_reque
+      edit LOGDIR '/s2o1/emos_esuite/emos_data/log'
+      task sub # passwd:gyBC8q.O abort<: PID(28027)  path(/suite/remote/c2a/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos c2a /vol/emos_nc/output/suite/remote/c2a/sub.job1 /s2o1/emos_esuite/emos_data/log/suite/remote/c2a/sub.1 ]>abort try:1 state:aborted dur:01:29:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'c2a'
+    endfamily
+    family ecgate # state:aborted dur:02:02:57 flag:no_reque
+      task sub # passwd:6pIZXvrl abort<: PID(32480)  path(/suite/remote/ecgate/sub)  exited with status 255 [ /home/ma/emos/bin/smssubmit.cray emos ecgate /vol/emos_nc/output/suite/remote/ecgate/sub.job1 /vol/emos_nc/output/suite/remote/ecgate/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'ecgate'
+    endfamily
+    family ibis # state:aborted dur:02:02:57 flag:no_reque
+      task sub # passwd:AEX5NtyU abort<: PID(32532)  path(/suite/remote/ibis/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos ibis /vol/emos_nc/output/suite/remote/ibis/sub.job1 /vol/emos_nc/output/suite/remote/ibis/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'ibis'
+    endfamily
+    family bilbo # state:aborted dur:02:02:57 flag:no_reque
+      task sub # passwd:30IPtlxu abort<: PID(32543)  path(/suite/remote/bilbo/sub)  exited with status 1 [ /home/ma/emos/bin/smssubmit.cray emos bilbo /vol/emos_nc/output/suite/remote/bilbo/sub.job1 /vol/emos_nc/output/suite/remote/bilbo/sub.1 ]>abort try:1 state:aborted dur:02:02:57 flag:task_aborted,ecfcmd_failed,message,no_reque
+        edit SCHOST 'bilbo'
+    endfamily
+  endfamily
+  family catchup2rt # state:aborted dur:03:18:57 flag:message suspended:1
+    task doer # passwd:OXQkmELW abort<:   Script for /suite/catchup2rt/doer cannot be found:
+   ECF_SCRIPT(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/suite/catchup2rt/doer.sms) does not exist:
+   Variable ECF_FETCH not defined:
+   Variable ECF_FILES not defined:
+   Search of directory ECF_HOME(/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME) failed:
+>abort try:1 state:aborted dur:03:18:57 flag:task_aborted,no_script,message,no_reque
+      complete timer eq complete
+      trigger 1==0
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/pyext/migrate/ecflow_migrate.py 5.13.0-1/libs/pyext/migrate/ecflow_migrate.py
--- 5.12.4-1/libs/pyext/migrate/ecflow_migrate.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/ecflow_migrate.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,421 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# 
+# Handle bugs, produced by old versions of ecflow_client --migrate
+#   - Mostly to do with handling newlines
+#
+
+import os          # for getenv
+import shutil      # used to remove directory tree
+#import argparse   # requires python 2.7
+import getopt, sys # for argument parsing  
+
+class Migrator(object):
+    def __init__(self, list_of_input_lines):
+        self.list_of_input_lines =  list_of_input_lines
+        self.list_of_output_lines = []
+        
+    def _migration_hook(self,default_version_number):
+        """Derived suite should override this function to perform the migration
+        """
+        return False;
+    
+    def output_lines(self):
+        return self.list_of_output_lines
+    
+    def migrate(self, default_version_number):
+        """Template/skeleton function, which will call the hooks
+        """
+        version = self.version_number_as_integer(default_version_number) 
+        if version >= default_version_number:
+            self.list_of_output_lines = self.list_of_input_lines
+            return False
+
+        self.list_of_output_lines = [] 
+        migrated = self._migration_hook(default_version_number)
+        if migrated : 
+            self.list_of_input_lines = self.list_of_output_lines   # preserve this migration
+            print("Applying ", type(self).__name__)  
+        else:
+            self.list_of_output_lines = self.list_of_input_lines   
+        return migrated         
+
+    def version_number_as_integer(self,default_version):
+        """Determine the version number used in ecflow_client --migrate
+           This should be in the very first line
+           # 3.1.8
+        """
+        if len(self.list_of_input_lines) > 0:
+            tokens = self.list_of_input_lines[0].split()
+            if len(tokens) > 1:
+                # print(tokens)
+                version = (int)(tokens[1].replace(".",""))
+                # print("******************* found version " , str(version))
+                return version;
+        return default_version
+    
+    
+class MigrateForTaskAbort(Migrator):
+    """Fix bug where the task abort states(i.e a string) will contain new lines and hence
+       spill over the next line, and affecting the parser. This will move the abort string
+       into the same line, and remove the interleaving new lines
+    """
+    def __init__(self, list_of_input_lines):
+        Migrator.__init__(self, list_of_input_lines)
+ 
+    def _migration_hook(self,default_version_number):
+        """
+        The correct format is: where abort state is on the same line
+        task task # passwd:jxX0gIbR abort<: reason for abort >abort:
+        ensure_start_abort_and_end_abort_on_sameline
+        """
+        migrated = False
+        start_line_append = ""
+        for line in self.list_of_input_lines:
+            # process line
+            end_abort_pos = line.find(">abort")
+            task_pos = line.find("task")
+            if task_pos != -1:
+                start_abort_pos = line.find("abort<:")
+                if start_abort_pos != -1 and end_abort_pos != -1:
+                    # start and end found on same line. This is the correct format
+                    start_line_append = ""
+                
+                if start_abort_pos != -1 and end_abort_pos == -1:
+                    # print("start abort found with no end abort")
+                    start_line_append = line
+                    start_line_append = start_line_append.rstrip('\n')
+                    start_line_append += " "
+                    migrated = True
+                    continue
+    
+            if len(start_line_append) > 0:
+                start_line_append += line
+                if end_abort_pos != -1:
+                    self.list_of_output_lines.append(start_line_append) # preserve'\n' for this case                   
+                    # print(start_line_append)
+                    start_line_append = "";
+                else:
+                    start_line_append = start_line_append.rstrip('\n')
+                    start_line_append += " "
+    
+                continue;
+                  
+            self.list_of_output_lines.append(line)
+           
+        return migrated  
+    
+    
+class MigrateForLabel(Migrator):
+    """Fix bug where label value has new lines, and hence spills over to next line
+       This will remove place newline back onto the same line
+    """
+    def __init__(self, list_of_input_lines):
+        Migrator.__init__(self, list_of_input_lines)
+ 
+    def _migration_hook(self,default_version_number):
+        """
+        The correct format is where label in on the same line
+            label name "value" # "new value"
+        However if the value or new value has new line it can mess up the parsing
+            label info "have you? set START_LOBSVR=1 in the task, once, to launch the logserver,
+    setup ssh login
+    created remote /tmp/map/cray"
+        """
+        #count = 0;
+        no_of_label_quotes = 0
+        migrated = False
+        start_line_append = ""
+        for line in self.list_of_input_lines:
+            #count =  count + 1
+            #print(str(count) , ": " , line)
+            #if count == 383119:
+            #    print("debug mee")
+            if len(start_line_append) > 0:
+                no_of_label_quotes += line.count('"')
+                start_line_append += line
+                if no_of_label_quotes % 2 == 0:
+                    # even number of quotes
+                    self.list_of_output_lines.append(start_line_append) # preserve last '\n'  
+                    start_line_append = ""
+                    no_of_label_quotes = 0 
+                else:
+                    start_line_append = start_line_append.rstrip('\n')
+                continue            
+            else:
+            
+                # process line
+                tokens = line.split()
+                if len(tokens) >0 and tokens[0] == "label":
+                    no_of_label_quotes = line.count('"')
+                    if no_of_label_quotes % 2 != 0 : 
+                        start_line_append = line
+                        start_line_append = start_line_append.rstrip('\n')
+                        migrated = True
+                        continue
+                  
+            self.list_of_output_lines.append(line)
+           
+        return migrated
+     
+class MigrateForVariable(Migrator):
+    """Fix bug where variable value has new lines, and hence spills over to next line
+       This will remove place newline back onto the same line
+    """
+    def __init__(self, list_of_input_lines):
+        Migrator.__init__(self, list_of_input_lines)
+ 
+    def _migration_hook(self,default_version_number):
+        """
+        The correct format is where variable in on the same line
+            edit EMOS_TYPE '  family prod_wparam
+  endfamily
+'         
+        """
+        #count = 0;
+        no_of_label_quotes = 0
+        migrated = False
+        start_line_append = ""
+        for line in self.list_of_input_lines:
+            #count =  count + 1
+            #print(str(count) , ": " , line)
+            #if count == 383119:
+            #    print("debug mee")
+            if len(start_line_append) > 0:
+                no_of_label_quotes += line.count("'")
+                start_line_append += line
+                if no_of_label_quotes % 2 == 0:
+                    # even number of quotes
+                    self.list_of_output_lines.append(start_line_append) # preserve last '\n'  
+                    start_line_append = ""
+                    no_of_label_quotes = 0 
+                else:
+                    start_line_append = start_line_append.rstrip('\n')
+                continue            
+            else:
+            
+                # process line, avoid ECF_URL_CMD as that could by error have uneven number of "'' i.e
+                #   edit ECF_URL_CMD '${BROWSER:=firefox} -new-tab %URL%'
+                # hence we use 
+                #    if no_of_label_quotes == 1: 
+                # instead of
+                #    if no_of_label_quotes % 2 == 0:
+                tokens = line.split()
+                if len(tokens) >= 3 and tokens[0] == "edit":
+                    no_of_label_quotes = line.count("'")
+                    if no_of_label_quotes == 1: 
+                        start_line_append = line
+                        start_line_append = start_line_append.rstrip('\n')
+                        migrated = True
+                        continue
+                  
+            self.list_of_output_lines.append(line)
+           
+        return migrated
+     
+     
+class MigrateForHistory(Migrator):
+    """Fix bug where history spans multiple lines.  
+       See File: history_bug.def
+    """
+    def __init__(self, list_of_input_lines):
+        Migrator.__init__(self, list_of_input_lines)
+ 
+    def _migration_hook(self,default_version_number):
+        """
+        The history should all be on one line
+            defs_state MIGRATE state>:queued flag:message state_change:1500811 modify_change:48
+            edit ECF_LOG '/vol/emos_nc/output/ecflow/vali.21801.ecf.log'
+            edit SMSNAME '0'
+            history /s2s_devel/ecmf/back MSG:[15:53:06 21.10.2014] --replace=/s2s_devel/ecmf/back s2s_devel.def parent  :emos
+            history /s2s_devel/ecmf/enfh MSG:[13:45:53 12.11.2014] -alter change label last_run 20140929
+            20141002
+            20141016
+            20141023 /s2s_devel/ecmf/enfh/  :emos    MSG:[14:05:53 14.11.2014] --requeue force /s2s_devel/ecmf/enfh  :emos
+            history /s2s_devel/ecmf/enfh/back MSG:[13:38:30 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emos
+            suite limits #  begun:1 state:complete flag:message suspended:1
+            endsuite
+        """
+        migrated = False
+        history_started = False
+        for line in self.list_of_input_lines:
+            # process line
+            tokens = line.split()
+            if len(tokens) >= 2 and tokens[0] == "suite":
+                history_started = False
+
+            if not history_started and len(tokens) >= 2 and tokens[0] == "history":
+                history_started = True
+ 
+            if history_started:
+                # append to previous line
+                if len(tokens) >= 1 and tokens[0] != "history":
+                    # get last line of output lines, string the new line and append
+                    self.list_of_output_lines[-1] = self.list_of_output_lines[-1].rstrip()
+                    self.list_of_output_lines[-1] = self.list_of_output_lines[-1] + line
+                    migrated = True
+                    continue;
+                  
+            self.list_of_output_lines.append(line)
+           
+        return migrated  
+    
+    
+def do_migrate(defs_file):
+    
+    migration_count = 0
+    fileName, fileExtension = os.path.splitext(defs_file)
+    output_file_name = fileName + ".mig";
+    
+    input_file_object = open(defs_file,'r')
+    output_file_object = open(output_file_name,'w')
+    try:
+        list_of_input_lines = input_file_object.readlines()  # preserves new lines, we want this
+        
+        list_of_output_lines = []
+        abort_migrator = MigrateForTaskAbort(list_of_input_lines)
+        if abort_migrator.migrate(401):
+            migration_count += 1
+            # did migration, update input lines for next migration
+            list_of_input_lines = abort_migrator.output_lines()
+        list_of_output_lines = abort_migrator.output_lines()
+         
+         
+        label_migrator = MigrateForLabel(list_of_input_lines)
+        if label_migrator.migrate(319):
+            migration_count += 1
+            # did migration, update input lines for next migration
+            list_of_input_lines = label_migrator.output_lines()
+        list_of_output_lines = label_migrator.output_lines()
+
+
+        variable_migrator = MigrateForVariable(list_of_input_lines)
+        if variable_migrator.migrate(401):
+            migration_count += 1
+            # did migration, update input lines for next migration
+            list_of_input_lines = variable_migrator.output_lines()
+        list_of_output_lines = variable_migrator.output_lines()
+        
+        
+        variable_migrator = MigrateForHistory(list_of_input_lines)
+        if variable_migrator.migrate(406):
+            migration_count += 1
+            # did migration, update input lines for next migration
+            list_of_input_lines = variable_migrator.output_lines()
+        list_of_output_lines = variable_migrator.output_lines()
+            
+        output_file_object.writelines(list_of_output_lines)
+    finally:
+        input_file_object.close()
+        output_file_object.close()
+        
+    return migration_count 
+
+def usage():
+    DESC = """\nThis python file is used to *FIX* migration bugs, when migrating from one release of ecflow to another.
+
+ Migration may be required when the release number changes:
+ <release-number>.<major>.<minor>
+    6.1.7   ->  7.0.0
+ as the checkpoint files *may* not be compatible. 
+        
+ This can be *checked* before hand. By attempting to load the check pt into the new server. 
+ On the old server run:
+    ecflow_client --check_pt  # this will write out a checkpt file  
+ Now copy this file to a separate directory, and start the *new* server using the same port number
+ If no errors are reported, you do not need to migrate.  
+ If loading the checkpt file into the new server fails for any reason then
+ then please follow these steps.
+
+ Steps for Old server:
+   o shutdown
+        # ecflow_client --shutdown
+   o suspend all suites
+        # CL="ecflow_client --port=32222 --host=vsms1"
+        # for s in $($CL --suites); do $CL --suspend=/$s; done
+   o wait for active/submitted tasks to complete
+   o halt the server
+        # ecflow_client --halt=yes
+   o Use --migrate to dump state and structure to a file
+        # ecflow_client --migrate > all_suites.def
+   o terminate server *or* leave server running but start new server on different machine
+     to avoid port number clash.
+   o remove checkpt and backup checkpt files, to prevent new server from loading them
+     *Only* applicable if starting new server on same machine
+   o Run this script 
+     python ecflow_migrate.py -d all_suites.def
+     This will fix any issues associated with reloading this defs into the new server.
+     It write a file called 'all_suites.mig', which we will need to load into the new server. 
+     See below.
+
+ Steps for New server:
+   o start server
+   o load the migration file
+       # ecflow_client --load all_suites.mig
+   o set server running:
+       # ecflow_client --restart
+   o resume suspended suites
+       # CL="ecflow_client --port=32222 --host=vsms1"
+       # for s in $($CL --suites); do $CL --resume=/$s; done
+
+
+ There could be bugs with *old* "ecflow_client --migrate > all_suites.def"
+ This file, will fix any bugs associated --migrate, so that the subsequent
+ load with  *new* client (ecflow_client --load all_suites.mig) will work
+
+ Usage:
+    python ecflow_migrate.py --defs_file <filename>
+    python ecflow_migrate.py --d <filename>
+    python ecflow_migrate.py --defs_file all_suites.def 
+    
+    The fixed definition is written as filename.mig, i.e. all_suites.mig
+    """
+    return DESC;
+    
+    
+if __name__ == "__main__":
+    
+#     PARSER = argparse.ArgumentParser(description=usage(),  
+#                                      formatter_class=argparse.RawDescriptionHelpFormatter)
+#     PARSER.add_argument('defs_file',  help="The definition file to *fix* for migration")
+#     ARGS = PARSER.parse_args()
+#     ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
+#     print(ARGS)    
+#     do_migrate( ARGS.defs_file )
+    
+    try:
+        opts, args = getopt.getopt(sys.argv[1:], "hd", ["help", "defs_file="])
+    except getopt.GetoptError as err:
+        # print("help information and exit:")
+        print(err) # will print something like "option -a not recognised"
+        print(usage())
+        sys.exit(2)
+        
+    defs_file = None
+    for o, a in opts:
+        if o in ("-h", "--help"):
+            print(usage())
+            sys.exit()
+        elif o in ("-d", "--defs_file"):
+            defs_file = a
+        else:
+            assert False, "un-handled option"
+    
+    if defs_file is None:
+        print("Please enter path to the defs file i.e ecflow_migrate --d ./defs_file.def")
+        sys.exit(1)
+        
+    defs_file = os.path.expandvars(defs_file); # expand references to any environment variables
+    do_migrate( defs_file )
diff -pruN 5.12.4-1/libs/pyext/migrate/history_bug.def 5.13.0-1/libs/pyext/migrate/history_bug.def
--- 5.12.4-1/libs/pyext/migrate/history_bug.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/history_bug.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,18 @@
+# 4.0.1
+defs_state MIGRATE state>:queued flag:message state_change:1500811 modify_change:48
+  edit ECF_LOG '/vol/emos_nc/output/ecflow/vali.21801.ecf.log'
+  edit SMSNAME '0'
+  history /s2s_devel/ecmf/back MSG:[15:53:06 21.10.2014] --replace=/s2s_devel/ecmf/back s2s_devel.def parent  :emos
+  history /s2s_devel/ecmf/enfh MSG:[13:45:53 12.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[13:45:53 12.11.2014] --alter change label next_run 99999999 /s2s_devel/ecmf/enfh/  :emosMSG:[16:54:11 12.11.2014] --alter change label last_run 20140929
+20141002
+20141016
+20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[16:54:11 12.11.2014] --alter change label next_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[16:58:54 12.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[16:58:54 12.11.2014] --alter change label next_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[17:01:39 12.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh/  :emosMSG:[17:01:39 12.11.2014] --alter change label next_run 20141027 /s2s_devel/ecmf/enfh/  :emosMSG:[14:17:38 13.11.2014] --resume  :marmMSG:[14:27:42 13.11.2014] --resume  :marmMSG:[14:44:53 13.11.2014] --resume  :marmMSG:[16:36:20 13.11.2014] --resume  :marmMSG:[16:42:34 13.11.2014] --resume  :marmMSG:[10:54:42 14.11.2014] --resume  :marmMSG:[11:07:40 14.11.2014] --alter change label next_run 20141030 /s2s_devel/ecmf/enfh  :emosMSG:[11:07:40 14.11.2014] --alter change label last_run 20141023 /s2s_devel/ecmf/enfh  :emosMSG:[11:07:40 14.11.2014] --requeue force /s2s_devel/ecmf/enfh  :emosMSG:[11:29:28 14.11.2014] --resume  :marmMSG:[11:46:15 14.11.2014] --resume  :marmMSG:[14:05:53 14.11.2014] --requeue force /s2s_devel/ecmf/enfh  :emos
+  history /s2s_devel/ecmf/enfh/back MSG:[13:38:30 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[15:14:11 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[15:15:54 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[15:18:10 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[16:21:22 11.11.2014] --requeue force /s2s_devel/ecmf/enfh/back  :marmMSG:[16:28:32 11.11.2014] --alter change event doIt set /s2s_devel/ecmf/enfh/back  :emosMSG:[17:01:18 13.11.2014] --replace=/s2s_devel/ecmf/enfh/back s2s_devel.def parent  :emosMSG:[10:53:07 14.11.2014] --replace=/s2s_devel/ecmf/enfh/back s2s_devel.def parent  :emos
+suite limits #  begun:1 state:complete flag:message suspended:1
+  defstatus complete
+  limit archive 3
+  calendar initTime:2014-Feb-20 09:26:31 suiteTime:2014-Sep-24 13:36:00 duration:6484:09:29 initLocalTime:2014-Feb-20 09:26:31 lastTime:2014-Nov-17 13:36:00 calendarIncrement:00:01:00
+endsuite
+suite tigge_lam #  begun:1 state:queued dur:9742:11:35 flag:message,no_reque suspended:1
+  defstatus suspended
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/migrate/label_bug.def 5.13.0-1/libs/pyext/migrate/label_bug.def
--- 5.12.4-1/libs/pyext/migrate/label_bug.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/label_bug.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+# 3.1.7
+defs_state MIGRATE state>:aborted flag:late,message state_change:2058963 modify_change:1954
+  edit ECF_INCLUDE '/tmp/map/work/p4/merlin/workspace/MyProject/Pyext/test/data/CUSTOMER/ECF_HOME/includes'
+  history /test MSG:[11:40:24 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:41:01 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:51:53 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:52:53 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:53:24 20.9.2013] --replace=/test <empty> parent  :mapMSG:[11:54:51 20.9.2013] --replace=/test <empty> parent  :map
+suite made_up
+    label info ""
+    label info "have you? set START_LOBSVR=1 in the task, once, to launch the logserver,
+setup ssh login
+created remote /tmp/map/cray"
+  zombie ecf:fob:label:3600 
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/migrate/no_migration.def 5.13.0-1/libs/pyext/migrate/no_migration.def
--- 5.12.4-1/libs/pyext/migrate/no_migration.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/no_migration.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+# 3.1.7
+defs_state MIGRATE state>:aborted flag:late,message state_change:983039 modify_change:1018
+  edit SLEEP '10'
+suite suite #  begun:1 state:aborted dur:01:29:57 flag:message,no_reque
+   task a
+   task b
+endsuite
+suite made_up
+   task a
+   task b
+endsuite
diff -pruN 5.12.4-1/libs/pyext/migrate/py_u_TestMigrate.py 5.13.0-1/libs/pyext/migrate/py_u_TestMigrate.py
--- 5.12.4-1/libs/pyext/migrate/py_u_TestMigrate.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/py_u_TestMigrate.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,192 @@
+
+import os
+import ecflow_migrate
+import unittest
+import filecmp
+
+def get_parent_dir(file_path):
+    return os.path.dirname(file_path)
+
+def get_root_source_dir():
+    cwd = os.getcwd()
+    #print("get_root_source_dir from: " + cwd)
+    while (1):
+        # Get to directory that has ecflow
+        head, tail = os.path.split(cwd)
+        #print("   head:" + head)
+        #print("   tail:" + tail)
+        if tail.find("ecflow") != -1 :
+            
+            # bjam, already at the source directory
+            if os.path.exists(cwd + "/Jamroot.jam"): 
+                print("   Found Jamroot.jam in " + cwd)
+                return cwd
+        
+        if tail != "pyext" and tail != "migrate":
+            # in cmake, we may be in the build directory, hence we need to determine source directory
+            file = cwd + "/CTestTestfile.cmake"
+            #print("   searching for " + file)
+            if os.path.exists(file):
+                # determine path by looking into this file:
+                for line in open(file):
+                    ## Source directory: /tmp/ma0/workspace/ecflow/ACore
+                    if line.find("Source directory"):
+                        tokens = line.split()
+                        if len(tokens) == 4:
+                            #print("   returning root_source_dir:", tokens[3])
+                            return tokens[3]
+                raise RuntimeError("ERROR could not find Source directory in CTestTestfile.cmake")
+            else:
+                raise RuntimeError("ERROR could not find file CTestTestfile.cmake in " + cwd)
+                
+        cwd = head
+    return cwd
+
+
+
+# These tests the migration for  ecflow < 318 to ecflow 318
+#
+# In ecflow_client --migrate, we can get abort reason to span multiple line, hence messing up load
+#
+class TestMigrate318(unittest.TestCase):
+    def setUp(self):
+        # perform setup actions if any
+        self.workspace_dir = get_root_source_dir()
+        #print("setup : " + self.workspace_dir)
+        
+    def tearDown(self):
+        # Perform clean -up actions if any
+        pass
+    
+    def locate(self,file):
+        return self.workspace_dir + "/libs/pyext/" + file
+    
+    def testMigrateVersionNumber(self):
+        list_of_defs_lines =[ "# 3.1.2"]
+  
+        mig = ecflow_migrate.Migrator(list_of_defs_lines)
+        self.assertEqual(mig.version_number_as_integer(0), 312,"expected version 3.1.2")
+  
+        list_of_defs_lines =[ "# "]
+        mig = ecflow_migrate.Migrator(list_of_defs_lines)
+        self.assertEqual(mig.version_number_as_integer(10), 10,"Expected 10, since valid version not provided")
+  
+    def test_no_migration(self):
+        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/no_migration.def"))
+        self.assertEqual(migration_count,0,"Expected no migration")
+        self.assertTrue(filecmp.cmp(self.locate("migrate/no_migration.def"),self.locate("migrate/no_migration.mig")))
+        # remove the generated file
+        try: os.remove(self.locate("migrate/no_migration.mig"))
+        except: pass
+   
+# ==============================================================================================
+    # Test for abort bug
+       
+    def test_normal_abort_case(self):
+        list_of_defs_lines = [ "# 3.1.2", "task task abort<: aa >abort\n" ]      
+        abort_migrator = ecflow_migrate.MigrateForTaskAbort(list_of_defs_lines)
+        abort_migrator.migrate(318)
+          
+        expected_output_lines = ["# 3.1.2", "task task abort<: aa >abort\n"]
+        self.assertEqual(abort_migrator.output_lines(),expected_output_lines)
+    
+    def test_task_abort_reason_bug_simple(self):
+        list_of_defs_lines = ["# 3.1.2", "task task abort<: aa\n",">abort\n" ] 
+        abort_migrator = ecflow_migrate.MigrateForTaskAbort(list_of_defs_lines)
+        abort_migrator.migrate(318)
+       
+        expected_output_lines = ["# 3.1.2","task task abort<: aa >abort\n"]
+        self.assertEqual(abort_migrator.output_lines(),expected_output_lines)
+   
+    def test_task_abort_reason_bug(self):
+        # In ecflow_client --migrate, we can get abort reason to span multiple line, hence messing up load
+        list_of_defs_lines = ["# 3.1.2","task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found:\n",
+                              "line2\n", "line3\n",">abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script\n" ]
+           
+        abort_migrator = ecflow_migrate.MigrateForTaskAbort(list_of_defs_lines)
+        abort_migrator.migrate(318)
+            
+        expected_output_lines = ["# 3.1.2","task task # passwd:jxX0gIbR abort<:   Script for /suite/family/task cannot be found: line2 line3 >abort try:2 state:aborted dur:02:19:57 flag:task_aborted,no_script\n"]
+        self.assertEqual(abort_migrator.output_lines(),expected_output_lines)
+            
+    def test_migrate_abort_file(self):
+        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/aborted_reason_bug.def"))
+        self.assertEqual(migration_count,1,"Expected defs file to be migrated")
+                   
+        # remove the generated file
+        try: os.remove(self.locate("migrate/aborted_reason_bug.mig"))
+        except: pass
+           
+# ===============================================================================================
+   
+    def test_normal_label(self):
+        list_of_defs_lines = ["# 3.1.2","label name \"value\"\n" ]      
+  
+        migrator = ecflow_migrate.MigrateForLabel(list_of_defs_lines)
+        migrator.migrate(319)
+      
+        expected_output_lines = ["# 3.1.2","label name \"value\"\n" ]
+        self.assertEqual(migrator.output_lines(),expected_output_lines)
+   
+    def test_label_over_multiple_lines(self):
+        list_of_defs_lines = ["# 3.1.2","label name \"value1\n", "value2\n", "value3\"\n" ]  
+          
+        migrator = ecflow_migrate.MigrateForLabel(list_of_defs_lines)
+        migrator.migrate(319)
+      
+        expected_output_lines = ["# 3.1.2","label name \"value1value2value3\"\n" ]
+        self.assertEqual(migrator.output_lines(),expected_output_lines)
+          
+    def test_label_over_multiple_lines_with_state(self):
+        list_of_defs_lines = ["# 3.1.2","label name \"value1\n", "value2\n", "value3\" # \"value4\n", "value5\"\n" ]  
+          
+        migrator = ecflow_migrate.MigrateForLabel(list_of_defs_lines)
+        migrator.migrate(319)
+      
+        expected_output_lines = ["# 3.1.2","label name \"value1value2value3\" # \"value4value5\"\n" ]
+        self.assertEqual(migrator.output_lines(),expected_output_lines)
+   
+   
+    def test_migrate_label_file(self):
+        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/label_bug.def"))
+        self.assertEqual(migration_count,1,"Expected defs file to be migrated")
+                   
+        # remove the generated file
+        try: os.remove(self.locate("migrate/label_bug.mig"))
+        except: pass
+  
+    def test_migrate_variable_file(self):
+        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/variable_bug.def"))
+        self.assertEqual(migration_count,1,"Expected defs file to be migrated")
+                   
+        # remove the generated file
+        try: os.remove(self.locate("migrate/variable_bug.mig"))
+        except: pass
+   
+# ====================================================================================================
+# test both together
+   
+    def test_migrate_abort_and_label(self):
+        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/abort_and_label_bug.def"))
+        self.assertEqual(migration_count,2,"Expected 2 migrations, one for abort and one for label")
+                   
+        # remove the generated file
+        try: os.remove(self.locate("migrate/abort_and_label_bug.mig"))
+        except: pass
+           
+#====================================================================================================
+#test history
+ 
+    def test_migrate_history(self):
+        print("test_migrate_history")
+        migration_count = ecflow_migrate.do_migrate(self.locate("migrate/history_bug.def"))
+        self.assertEqual(migration_count,1,"Expected 1 migrations,for history")
+                 
+        # remove the generated file
+        try: os.remove(self.locate("migrate/history_bug.mig"))
+        except: pass
+
+#run the tests 
+if __name__  == '__main__':
+    #print("Current working directory: " + os.getcwd())
+    unittest.main()
diff -pruN 5.12.4-1/libs/pyext/migrate/variable_bug.def 5.13.0-1/libs/pyext/migrate/variable_bug.def
--- 5.12.4-1/libs/pyext/migrate/variable_bug.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/migrate/variable_bug.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+# 3.0.0
+suite s
+   task q2diss
+      defstatus complete
+      late -s +00:05 -c +00:15
+      trigger pdb==complete 
+      edit ECF_URL_CMD '${BROWSER:=firefox} -new-tab %URL%'
+      edit EMOS_TYPE '  family prod_wparam
+  endfamily
+'
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/python2/CMakeLists.txt 5.13.0-1/libs/pyext/python2/CMakeLists.txt
--- 5.12.4-1/libs/pyext/python2/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/python2/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,176 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+ecbuild_add_library(
+  TARGET
+    ecflow2
+  NOINSTALL
+  TYPE MODULE
+  SOURCES
+    ${srcs}
+  PRIVATE_INCLUDES
+    ../src
+  PUBLIC_LIBS
+    ecflow_all
+    libsimulator
+    Python2::Python
+    Boost::${ECFLOW_BOOST_PYTHON_COMPONENT}
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+  CXXFLAGS
+    $<$<CXX_COMPILER_ID:Clang>:-Wno-macro-redefined>
+)
+
+target_clangformat(ecflow2)
+
+#
+# Override default behaviour that add RPATHS during install
+# The only thing that seem to work is set INSTALL_RPATH to ""
+# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
+# had no effect
+#         
+# by default cmake add prefix 'lib', we don't want this hence disable
+#
+# To avoid duplicate target names we chose to name the targets: ecflow2/ecflow3.
+# however test and user code  depend on name 'ecflow', hence we rename the output to 'cflow'
+set_target_properties(ecflow3
+  PROPERTIES
+    OUTPUT_NAME "ecflow"
+    PREFIX ""
+    INSTALL_RPATH ""
+)
+
+# =====================================================================
+# tests
+
+foreach( test ${u_tests} )
+  ecbuild_add_test(
+    TARGET
+      py2_${test}
+    LABELS
+      python nightly
+    TYPE PYTHON
+    ARGS
+      ${CMAKE_CURRENT_SOURCE_DIR}/../test/${test}.py
+    ENVIRONMENT
+      "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
+    TEST_DEPENDS
+      u_base
+  )
+endforeach()
+
+
+if ( ENABLE_ALL_TESTS AND ENABLE_SERVER)
+
+  foreach( test ${s_tests} )
+    ecbuild_add_test(
+      TARGET
+        py2_${test}
+      LABELS
+        python nightly
+      TYPE PYTHON
+      ARGS
+        ${CMAKE_CURRENT_SOURCE_DIR}/../test/${test}.py
+      ENVIRONMENT
+        "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
+      TEST_DEPENDS
+        u_base
+    )
+  endforeach()
+  
+  set_property(TEST py2_s_TestClientApi      APPEND PROPERTY DEPENDS s_test)
+  set_property(TEST py2_s_TestPythonChildApi APPEND PROPERTY DEPENDS py_s_TestClientApi)
+endif()
+
+
+# ==========================================================================
+# install
+#    -DCMAKE_PYTHON_INSTALL_TYPE = [ local | setup | not defined ]
+#
+#    local | not defined : this will install to:
+#                          $INSTALL_PREFIX/$release.$major.$minor/lib/python2.7/site-packages/ecflow/
+#    setup               : experimental only,python way of installing
+#
+#    -DCMAKE_PYTHON_INSTALL_PREFIX should *only* used when using python setup.py (CMAKE_PYTHON_INSTALL_TYPE=setup)
+#    *AND* for testing python install to local directory
+#
+# Note:  To install only the python module
+#       cd  buildir
+#       cmake -DCMAKE_INSTALL_PREFIX=$INSTALL_DIR -DCOMPONENT=python -P cmake_install.cmake -- make install
+# ==========================================================================
+
+if( CMAKE_PYTHON_INSTALL_TYPE MATCHES  "local"  OR NOT DEFINED CMAKE_PYTHON_INSTALL_TYPE )
+
+  message(STATUS "python install *LOCAL* +++ lib/python${PYTHON_VERSION_MAJOR}.${PYTHON_VERSION_MINOR}/site-packages/ecflow +++++++")
+  if( NOT INSTALL_PYTHON2_DIR )
+    set(PYTHON_SITE "lib/python${PYTHON_VERSION_MAJOR}.${PYTHON_VERSION_MINOR}/site-packages" )
+  else()
+    # Resolve ${VAR} in the value provided
+    string(CONFIGURE "${INSTALL_PYTHON2_DIR}" PYTHON_SITE)
+  endif()
+  set(PYTHON_DEST "${PYTHON_SITE}/ecflow" )
+
+  install(
+    TARGETS
+      ecflow2
+    DESTINATION
+      ${PYTHON_DEST}
+    RENAME
+      ecflow.so
+    COMPONENT
+      python
+  )
+  install(
+    FILES
+      ../ecflow/__init__.py
+      ../samples/api/ecf.py
+      ../samples/api/sms2ecf.py
+    DESTINATION
+      ${PYTHON_DEST}
+    COMPONENT
+      python
+  )
+
+else()
+
+  message( STATUS "python found,  CMAKE_PYTHON_INSTALL_TYPE=${CMAKE_PYTHON_INSTALL_TYPE}")
+
+  # -------------------------------------------------------------------------------------
+  # Install using setup.py
+  # See: http://bloerg.net/2012/11/10/cmake-and-distutils.html
+  # -------------------------------------------------------------------------------------
+  message(STATUS "python install using *setup.py* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
+  message(STATUS "CMAKE_CURRENT_SOURCE_DIR=${CMAKE_CURRENT_SOURCE_DIR}")
+  message(STATUS "CMAKE_BINARY_DIR=${CMAKE_BINARY_DIR}")
+  message(STATUS "CMAKE_PYTHON_INSTALL_PREFIX : ${CMAKE_PYTHON_INSTALL_PREFIX}" )
+
+  set(SETUP_PY_IN "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py.in")
+  set(SETUP_PY    "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py")
+  set(DEPS        "${CMAKE_CURRENT_SOURCE_DIR}/../ecflow/__init__.py")
+  set(OUTPUT      "${CMAKE_CURRENT_SOURCE_DIR}/timestamp")
+
+  configure_file(${SETUP_PY_IN} ${SETUP_PY} )
+
+  add_custom_command(
+    OUTPUT ${OUTPUT}
+    COMMAND ${PYTHON} ${SETUP_PY} build
+    COMMAND ${CMAKE_COMMAND} -E touch ${OUTPUT}
+    DEPENDS ${DEPS}
+  )
+  add_custom_target(target ALL DEPENDS ${OUTPUT})
+
+  install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} build_ext)")
+
+  if( DEFINED CMAKE_PYTHON_INSTALL_PREFIX )
+    message(STATUS "custom/*test* python install prefix defined CMAKE_PYTHON_INSTALL_PREFIX=${CMAKE_PYTHON_INSTALL_PREFIX}")
+    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install -f --prefix=${CMAKE_PYTHON_INSTALL_PREFIX})")
+  else()
+    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install)")
+  endif()
+endif()
diff -pruN 5.12.4-1/libs/pyext/python3/CMakeLists.txt 5.13.0-1/libs/pyext/python3/CMakeLists.txt
--- 5.12.4-1/libs/pyext/python3/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/python3/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,187 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+#
+#   Important!
+#
+# Notice that ecflow Python module is linked with `Python3::Module` CMake imported target,
+# to enable a loose linkage with Python development libraries -- this is necessary in some
+# platforms, such as conda-forge+macOS.
+#
+# In practice, this implies that `-undefined` and `-dynamic_lookup` linkage flags are used
+# and the Python development libraries are not linked directly into the ecflow Python module.
+#
+
+ecbuild_add_library(
+  TARGET
+    ecflow3
+  NOINSTALL
+  TYPE MODULE
+  SOURCES
+    ${srcs}
+  PRIVATE_INCLUDES
+    ../src
+  PUBLIC_LIBS
+    ecflow_all
+    libsimulator
+    Python3::Module
+    Boost::${ECFLOW_BOOST_PYTHON_COMPONENT}
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+  CXXFLAGS
+    $<$<CXX_COMPILER_ID:Clang>:-Wno-macro-redefined>
+)
+
+target_clangformat(ecflow3)
+
+#
+# Override default behaviour that add RPATHS during install
+# The only thing that seem to work is set INSTALL_RPATH to ""
+# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
+# had no effect
+#         
+# by default cmake add prefix 'lib', we don't want this hence disable
+#
+# To avoid duplicate target names we chose to name the targets: ecflow2/ecflow3.
+# however test and user code  depend on name 'ecflow', hence we rename the output to 'cflow'
+set_target_properties(ecflow3
+  PROPERTIES
+    OUTPUT_NAME "ecflow"
+    PREFIX ""
+    INSTALL_RPATH ""
+)
+
+# =====================================================================
+# tests
+
+foreach( test ${u_tests} )
+  ecbuild_add_test(
+    TARGET
+      py3_${test}
+    LABELS
+      python nightly
+    TYPE PYTHON
+    ARGS
+      ${CMAKE_CURRENT_SOURCE_DIR}/../test/${test}.py
+    ENVIRONMENT
+      "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
+    TEST_DEPENDS
+      u_base
+  )
+endforeach()
+
+
+if ( ENABLE_ALL_TESTS AND ENABLE_SERVER)
+
+  foreach( test ${s_tests} )
+    ecbuild_add_test(
+      TARGET
+        py3_${test}
+      LABELS
+        python nightly
+      TYPE PYTHON
+      ARGS
+        ${CMAKE_CURRENT_SOURCE_DIR}/../test/py_${test}.py
+      ENVIRONMENT
+        "PYTHONPATH=${CMAKE_CURRENT_BINARY_DIR}"
+      TEST_DEPENDS
+        u_base
+    )
+  endforeach()
+  
+  set_property(TEST py3_s_TestClientApi      APPEND PROPERTY DEPENDS s_test)
+  set_property(TEST py3_s_TestPythonChildApi APPEND PROPERTY DEPENDS py3_s_TestClientApi)
+endif()
+
+
+# ==========================================================================
+# install
+#    -DCMAKE_PYTHON_INSTALL_TYPE = [ local | setup | not defined ]
+#
+#    local | not defined : this will install to:
+#                          $INSTALL_PREFIX/$release.$major.$minor/lib/python2.7/site-packages/ecflow/
+#    setup               : experimental only,python way of installing
+#
+#    -DCMAKE_PYTHON_INSTALL_PREFIX should *only* used when using python setup.py (CMAKE_PYTHON_INSTALL_TYPE=setup)
+#    *AND* for testing python install to local directory
+#
+# Note:  To install only the python module
+#       cd  buildir
+#       cmake -DCMAKE_INSTALL_PREFIX=$INSTALL_DIR -DCOMPONENT=python -P cmake_install.cmake -- make install
+# ==========================================================================
+
+if( CMAKE_PYTHON_INSTALL_TYPE MATCHES  "local"  OR NOT DEFINED CMAKE_PYTHON_INSTALL_TYPE )
+
+  message(STATUS "python install *LOCAL* +++ lib/python${Python3_VERSION_MAJOR}.${Python3_VERSION_MINOR}/site-packages/ecflow +++++++")
+  if( NOT INSTALL_PYTHON3_DIR )
+    set(PYTHON_SITE "lib/python${Python3_VERSION_MAJOR}.${Python3_VERSION_MINOR}/site-packages" )
+  else()
+    # Resolve ${VAR} in the value provided
+    string(CONFIGURE "${INSTALL_PYTHON3_DIR}" PYTHON_SITE)
+  endif()
+  set(PYTHON_DEST "${PYTHON_SITE}/ecflow" )
+
+  install(
+    TARGETS
+      ecflow3
+    DESTINATION
+      ${PYTHON_DEST}
+    RENAME
+      ecflow.so
+    COMPONENT
+      python
+  )
+  install(
+    FILES
+      ../ecflow/__init__.py
+      ../samples/api/ecf.py
+      ../samples/api/sms2ecf.py
+    DESTINATION
+      ${PYTHON_DEST}
+    COMPONENT
+      python
+  )
+
+else()
+
+  message( STATUS "python found,  CMAKE_PYTHON_INSTALL_TYPE=${CMAKE_PYTHON_INSTALL_TYPE}")
+
+  # -------------------------------------------------------------------------------------
+  # Install using setup.py
+  # See: http://bloerg.net/2012/11/10/cmake-and-distutils.html
+  # -------------------------------------------------------------------------------------
+  message(STATUS "python install using *setup.py* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
+  message(STATUS "CMAKE_CURRENT_SOURCE_DIR=${CMAKE_CURRENT_SOURCE_DIR}")
+  message(STATUS "CMAKE_BINARY_DIR=${CMAKE_BINARY_DIR}")
+  message(STATUS "CMAKE_PYTHON_INSTALL_PREFIX : ${CMAKE_PYTHON_INSTALL_PREFIX}" )
+
+  set(SETUP_PY_IN "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py.in")
+  set(SETUP_PY    "${CMAKE_CURRENT_SOURCE_DIR}/../setup.py")
+  set(DEPS        "${CMAKE_CURRENT_SOURCE_DIR}/../ecflow/__init__.py")
+  set(OUTPUT      "${CMAKE_CURRENT_SOURCE_DIR}/timestamp")
+
+  configure_file(${SETUP_PY_IN} ${SETUP_PY} )
+
+  add_custom_command(
+    OUTPUT ${OUTPUT}
+    COMMAND ${PYTHON} ${SETUP_PY} build
+    COMMAND ${CMAKE_COMMAND} -E touch ${OUTPUT}
+    DEPENDS ${DEPS}
+  )
+  add_custom_target(target ALL DEPENDS ${OUTPUT})
+
+  install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} build_ext)")
+
+  if( DEFINED CMAKE_PYTHON_INSTALL_PREFIX )
+    message(STATUS "custom/*test* python install prefix defined CMAKE_PYTHON_INSTALL_PREFIX=${CMAKE_PYTHON_INSTALL_PREFIX}")
+    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install -f --prefix=${CMAKE_PYTHON_INSTALL_PREFIX})")
+  else()
+    install(CODE "execute_process(COMMAND ${PYTHON} ${SETUP_PY} install)")
+  endif()
+endif()
diff -pruN 5.12.4-1/libs/pyext/samples/ListVariables.py 5.13.0-1/libs/pyext/samples/ListVariables.py
--- 5.12.4-1/libs/pyext/samples/ListVariables.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/ListVariables.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,66 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+import ecflow
+import argparse # for argument parsing  
+import sys   
+
+if __name__ == "__main__":
+    
+    DESC = """Will list variables for any node
+              Usage:
+                Example1: List all the server variables
+                   ListVariables.py --host cca --port 4141 --path /
+                   
+                Example2: List the variables for the given node
+                   ListVariables.py --host cca --port 4141 --path /path/to/node
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--host', default="localhost",   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default="3141",   
+                        help="The port on the host, defaults to 3141")
+    PARSER.add_argument('--path', default="/",   
+                        help="The path to the node. i.e /suite/family/task")
+    ARGS = PARSER.parse_args()
+    #print ARGS    
+    
+    # ===========================================================================
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    try:
+        CL.ping() 
+
+        # get the incremental changes, and merge with defs stored on the Client 
+        CL.sync_local()
+        
+        # check to see if definition exists in the server
+        defs = CL.get_defs()
+        if len(defs) == 0 :
+            print("No suites found, exiting...")
+            sys.exit(0) 
+            
+        # print defs;
+        if ARGS.path == "/":
+            for var in defs.server_variables:  print("edit " + var.name() + " '" + var.value() + "'")
+            for var in defs.user_variables:    print("edit " + var.name() + " '" + var.value() + "'")
+        else:
+            node = defs.find_abs_node(ARGS.path)
+            if node is None:  
+                print("No node found at path " + ARGS.path)
+            else:
+                for var in node.variables:     print("edit " + var.name() + " '" + var.value() + "'")
+
+    except RuntimeError as ex:
+        print("Error: " + str(ex))
+        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/libs/pyext/samples/TestBench.py 5.13.0-1/libs/pyext/samples/TestBench.py
--- 5.12.4-1/libs/pyext/samples/TestBench.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/TestBench.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,258 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# =============================================================================
+# Code for testing *any* definition
+#   Since any ad hoc definition will reference local directories in the
+#   ECF_ variables, we need to remove them and inject our own.
+#
+#   This script is re-runnable, and hence will delete suites in the server
+#   matching those in the input definition. Hence it is best to use this 
+#   script with a *test* server to avoid accidentally deleting existing suites 
+#   of the same name.
+# =============================================================================
+import ecflow
+import os       # for getenv
+import sys
+import shutil   # used to remove directory tree
+import argparse # for argument parsing     
+
+def get_root_source_dir():
+    cwd = os.getcwd()
+    #print "get_root_source_dir from: " + cwd
+    while (1):
+        # Get to directory that has ecflow
+        head, tail = os.path.split(cwd)
+        #print "   head:" + head
+        #print "   tail:" + tail
+        if tail.find("ecflow") != -1 :
+            
+            # bjam, already at the source directory
+            if os.path.exists(cwd + "/Jamroot.jam"): 
+                print("   Found Jamroot.jam in " + cwd)
+                return cwd
+        
+        if tail != "pyext" and tail != "migrate":
+            # in cmake, we may be in the build directory, hence we need to determine source directory
+            file = cwd + "/CTestTestfile.cmake"
+            #print "   searching for " + file
+            if os.path.exists(file):
+                # determine path by looking into this file:
+                with open(file) as fp:
+                    for line in fp:
+                        ## Source directory: /tmp/ma0/workspace/ecflow/Acore
+                        if line.find("Source directory"):
+                            tokens = line.split()
+                            if len(tokens) == 4:
+                                #print "   returning root_source_dir:", tokens[3]
+                                return tokens[3]
+                raise RuntimeError("ERROR could not find Source directory in CTestTestfile.cmake")
+            else:
+                raise RuntimeError("ERROR could not find file CTestTestfile.cmake in " + cwd)
+                
+        cwd = head
+    return cwd
+
+    
+def delete_variables_affecting_job_generation(node): 
+    """delete customer related ECF variables, these will point to directories
+       that don't exist. Its ok we will regenerate our own local ones"""
+    var = node.find_variable("ECF_HOME")
+    if not var.empty() :  
+        node.delete_variable("ECF_HOME")    
+    var = node.find_variable("ECF_FILES")
+    if not var.empty() :  
+        node.delete_variable("ECF_FILES")    
+    var = node.find_variable("ECF_INCLUDE")
+    if not var.empty() :  
+        node.delete_variable("ECF_INCLUDE")    
+    var = node.find_variable("ECF_JOB_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_JOB_CMD")    
+    var = node.find_variable("ECF_KILL_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_KILL_CMD")    
+    var = node.find_variable("ECF_STATUS_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_STATUS_CMD")    
+    var = node.find_variable("ECF_OUT")
+    if not var.empty() :  
+        node.delete_variable("ECF_OUT")
+    var = node.find_variable("ECF_MICRO")
+    if not var.empty() :  
+        node.delete_variable("ECF_MICRO")   # generation depend on % 
+         
+      
+def traverse_container(node_container):
+    """Recursively traverse definition node hierarchy and delete
+       the variables that affect job generation.
+    """
+    delete_variables_affecting_job_generation(node_container)
+    for node in node_container.nodes:
+        delete_variables_affecting_job_generation(node)
+        if not isinstance(node, ecflow.Task):
+            traverse_container(node)  
+    
+if __name__ == "__main__":
+    
+    DESC = """Will allow any definition to be loaded and played on the server
+            This is done by:
+            o Remove existing ECF_ variables that affect job generation. 
+              i.e variables that refer to customer specific directories are removed
+            o Allows ECF_HOME to specified, defaults to ./CUSTOMER/ECF_HOME
+            o Generates the scripts(.ecf files) automatically based on the definition.
+              i.e if a task has events,meters,labels then the client request for these are
+              automatically injected in the generated .ecf script files
+            o Will clear out existing data both on disk and on the server to allow 
+              multiple re-runs of this script. ** If this is an issue please use
+              a test server **
+            o All suites are put into a suspended state. This allows the GUI to resume them
+            o The server is restarted and suites are begun
+            This programs assumes that ecflow module is accessible
+
+            example:
+                python libs/pyext/samples/TestBench.py --port=3141 --verbose=True ANode/parser/test/data/good_defs/trigger/late.def
+            """    
+            
+    print("####################################################################")
+    print("Running ecflow version " + ecflow.Client().version()  + " debug build(" + str(ecflow.debug_build()) +")")
+    if 'PYTHONPATH' in os.environ:
+        print("PYTHONPATH: " + str(os.environ['PYTHONPATH'].split(os.pathsep)))
+    print("sys.path:   " + str(sys.path))
+    print("####################################################################")
+ 
+    default_port = "3141"
+    if "ECF_PORT" in os.environ:
+         default_port = os.environ["ECF_PORT"]
+ 
+    default_host = "localhost"
+    if "ECF_HOST" in os.environ:
+        default_host  = os.environ["ECF_HOST"]
+
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('defs_file', 
+                        help="The definition file")
+    PARSER.add_argument('--host', default=default_host,   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default=default_port,   
+                        help="The port on the host, defaults to 3141")
+    PARSER.add_argument('--path', default="/",   
+                        help="replace only the node path in the suite")
+    PARSER.add_argument('--ecf_home', default=os.getcwd() + "/CUSTOMER/ECF_HOME",
+                        help="Directory to be used for generated scripts(ECF_HOME), defaults to ./CUSTOMER/ECF_HOME")
+    PARSER.add_argument('--verbose', nargs='?', default=False, const=True, type=bool,
+                        help="Show verbose output")
+    ARGS = PARSER.parse_args()
+    ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
+    print(ARGS  )  
+    
+    # If running on local work space, use /libs/pyext/test/data/CUSTOMER/ECF_HOME as ecf_home
+    using_workspace = False;
+    ecflow_source_dir = ""
+    try:
+        ecflow_source_dir = get_root_source_dir();
+        ARGS.ecf_home = ecflow_source_dir + "/libs/pyext/test/data/CUSTOMER/ECF_HOME"
+        using_workspace = True
+        if ARGS.verbose:
+            print("Workspace is defined ecflow_source_dir: ",ecflow_source_dir)
+                
+    except:
+        pass
+    
+    if ARGS.verbose:
+        print("Using ECF_HOME=" + ARGS.ecf_home)
+         
+    try:
+        if ARGS.verbose: 
+            print("\nloading the definition from the input arguments(" + ARGS.defs_file + ")\n")
+        DEFS = ecflow.Defs(ARGS.defs_file)
+    except RuntimeError as ex:
+        print("   ecflow.Defs(" + ARGS.defs_file + ") failed:\n" + str(ex))
+        sys.exit(1)
+    
+    if ARGS.verbose: 
+        print("remove test data associated with the DEFS, so we start fresh, Allows rerun")
+    for suite in DEFS.suites:
+        dir_to_remove = ARGS.ecf_home + suite.get_abs_node_path()
+        if ARGS.verbose: 
+            print("   Deleting directory: " + dir_to_remove + "\n")
+        shutil.rmtree(dir_to_remove, True)  
+        
+    if ARGS.verbose: 
+        print("remove remote reference to ECF_HOME and ECF_INCLUDE, since we inject or own\n")
+    for suite in DEFS.suites:
+        traverse_container(suite)
+  
+    DEFS.add_variable("ECF_HOME", ARGS.ecf_home)
+    
+    if using_workspace: 
+        path_to_ecflow_client = ecflow.File.find_client()
+        if os.path.exists( path_to_ecflow_client ):
+            DEFS.add_variable("ECF_CLIENT_EXE_PATH", path_to_ecflow_client )
+            if ARGS.verbose: print("Adding ECF_CLIENT_EXE_PATH:",path_to_ecflow_client)
+
+    DEFS.add_variable("SLEEP", "10")  # not strictly required since default is 1 second
+    DEFS.add_variable("ECF_INCLUDE", ARGS.ecf_home + "/includes")
+
+    for suite in DEFS.suites:
+        suite.add_defstatus(ecflow.DState.suspended)
+    
+    if ARGS.verbose: 
+        #ecflow.PrintStyle.set_style(ecflow.Style.STATE)
+        print(DEFS)
+
+    if ARGS.verbose: 
+        print("Generating script files(.ecf) from the definition")
+    DEFS.generate_scripts()
+
+    if ARGS.verbose: 
+        print("\nchecking script file generation, pre-processing & variable substitution\n")
+    msg = DEFS.check_job_creation()       
+    assert len(msg) == 0, msg
+    
+    # ===========================================================================
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    try:
+        if ARGS.verbose: 
+            print("check server " + ARGS.host + ":" + ARGS.port + " is running")
+        CL.ping() 
+
+        if ARGS.verbose: 
+            print("Server is already running. re-start the server")
+        CL.restart_server() 
+
+        if ARGS.verbose: 
+            print("Remove suites associated with this DEFS, allows rerun *******************************************")
+        for suite in DEFS.suites:
+            try:
+                CL.delete(suite.get_abs_node_path(), True)
+            except RuntimeError as ex:
+                pass # For first run this will fail, hence ignore
+        
+        if ARGS.verbose: 
+            print("Load the definition into " + ARGS.host + ":" + ARGS.port)
+        if ARGS.path == "/":
+            CL.load(DEFS) 
+        else:
+            CL.replace(ARGS.path, DEFS)
+
+        if ARGS.verbose: 
+            print("Begin all suites. They should be suspended.")
+        print("Loaded suites:")
+        for suite in DEFS.suites:
+            CL.begin_suite(suite.name())
+            print("   " + suite.name())
+        print("into server " + ARGS.host  + ":" + ARGS.port + ", please view the playable suites in the GUI")
+    except RuntimeError as ex:
+        print("Error: " + str(ex))
diff -pruN 5.12.4-1/libs/pyext/samples/TestBenchConfluence.py 5.13.0-1/libs/pyext/samples/TestBenchConfluence.py
--- 5.12.4-1/libs/pyext/samples/TestBenchConfluence.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/TestBenchConfluence.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,193 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# =============================================================================
+# Code for testing *any* definition
+#   Since any ad hoc definition will reference local directories in the
+#   ECF_ variables, we need to remove them and inject our own.
+#
+#   This script is re-runnable, and hence will delete suites in the server
+#   matching those in the input definition. Hence it is best to use this 
+#   script with a *test* server to avoid accidentally deleting existing suites 
+#   of the same name.
+# =============================================================================
+import ecflow
+import os       # for getenv
+import shutil   # used to remove directory tree
+import argparse # for argument parsing     
+
+def delete_variables_affecting_job_generation(node): 
+    """delete customer related ECF variables, these will point to directories
+       that don't exist. Its ok we will regenerate our own local ones"""
+    var = node.find_variable("ECF_HOME")
+    if not var.empty() :  
+        node.delete_variable("ECF_HOME")    
+    var = node.find_variable("ECF_FILES")
+    if not var.empty() :  
+        node.delete_variable("ECF_FILES")    
+    var = node.find_variable("ECF_INCLUDE")
+    if not var.empty() :  
+        node.delete_variable("ECF_INCLUDE")    
+    var = node.find_variable("ECF_JOB_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_JOB_CMD")    
+    var = node.find_variable("ECF_KILL_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_KILL_CMD")    
+    var = node.find_variable("ECF_STATUS_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_STATUS_CMD")    
+    var = node.find_variable("ECF_OUT")
+    if not var.empty() :  
+        node.delete_variable("ECF_OUT")    
+      
+def traverse_container(node_container):
+    """Recursively traverse definition node hierarchy and delete
+       the variables that affect job generation.
+    """
+    delete_variables_affecting_job_generation(node_container)
+    for node in node_container.nodes:
+        delete_variables_affecting_job_generation(node)
+        if not isinstance(node, ecflow.Task):
+            traverse_container(node)  
+    
+if __name__ == "__main__":
+    
+    default_port = "3141"
+    if "ECF_PORT" in os.environ:
+        default_port = os.environ["ECF_PORT"]
+
+    default_host = "localhost"
+    if "ECF_HOST" in os.environ:
+        default_host  = os.environ["ECF_HOST"]
+
+    DESC = """Will allow any definition to be loaded and played on the server
+            This is done by:
+            o Remove existing ECF_ variables that affect job generation. 
+              i.e. variables that refer to customer specific directories are removed
+            o Allows ECF_HOME to specified, defaults to cwd + /CUSTOMER/ECF_HOME
+            o Generates the scripts(.ecf files) automatically based on the definition.
+              i.e. if a task has events,meters,labels then the client request for these are
+              automatically injected in the generated .ecf script files
+            o Will clear out existing data both on disk and on the server to allow 
+              multiple re-runs of this script. ** If this is an issue please use
+              a test server **
+            o All suites are put into a suspended state. This allows the GUI to resume them
+            o The server is restarted and suites are begun
+            This programs assumes that ecflow module is accessible.
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('defs_file', 
+                        help="The definition file")
+    PARSER.add_argument('--host', default=default_host,   
+                        help="The name of the host machine, defaults to ECF_HOST otherwise 'localhost'")
+    PARSER.add_argument('--port', default=default_port,   
+                        help="The port on the host, defaults to ECF_PORT otherwise uses 3141")
+    PARSER.add_argument('--path', default="/",   
+                        help="replace only the node path in the suite")
+    PARSER.add_argument('--ecf_home', default=os.getcwd() + "/CUSTOMER/ECF_HOME",
+                        help="Directory to be used for generated scripts(ECF_HOME), defaults to ./CUSTOMER/ECF_HOME")
+    PARSER.add_argument('--verbose', nargs='?', default=False, const=True, type=bool,
+                        help="Show verbose output")
+    ARGS = PARSER.parse_args()
+    ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
+    print(ARGS) 
+    
+    # If running on local work space, use /libs/pyext/test/data/CUSTOMER/ECF_HOME as ecf_home
+    if ARGS.verbose:
+        print("Using ECF_HOME=" + ARGS.ecf_home)
+         
+    if ARGS.verbose: 
+        print("\nloading the definition from the input arguments(" + ARGS.defs_file + ")\n")
+    try:
+        DEFS = ecflow.Defs(ARGS.defs_file)
+    except RuntimeError as ex:
+        print("   ecflow.Defs(" + ARGS.defs_file + ") failed:\n" + str(ex))
+        sys.exit(1)
+    
+    if ARGS.verbose: 
+        print("remove test data associated with the DEFS, so we start fresh, Allows rerun")
+    for suite in DEFS.suites:
+        dir_to_remove = ARGS.ecf_home + suite.get_abs_node_path()
+        if ARGS.verbose: 
+            print("   Deleting directory: " + dir_to_remove + "\n")
+        shutil.rmtree(dir_to_remove, True)  
+        
+    if ARGS.verbose: 
+        print("remove remote reference to ECF_HOME and ECF_INCLUDE, since we inject or own\n")
+    for suite in DEFS.suites:
+        traverse_container(suite)
+  
+    if ARGS.verbose: 
+        print("add variables required for script generation, for all suites\n")
+    DEFS.add_variable("ECF_HOME", ARGS.ecf_home)
+    DEFS.add_variable("SLEEP", "10")  # not strictly required since default is 1 second
+    DEFS.add_variable("ECF_INCLUDE", ARGS.ecf_home + "/includes")
+
+
+    if ARGS.verbose: 
+        print("Place all suites into suspended state, so they can be started by the GUI\n")  
+    for suite in DEFS.suites:
+        suite.add_defstatus(ecflow.DState.suspended)
+    
+    if ARGS.verbose: 
+        #ecflow.PrintStyle.set_style(ecflow.Style.STATE)
+        print(DEFS)
+
+    if ARGS.verbose: 
+        print("Generating script files(.ecf) from the definition")
+    DEFS.generate_scripts()
+
+    if ARGS.verbose: 
+        print("\nchecking script file generation, pre-processing & variable substitution\n")
+    msg = DEFS.check_job_creation()       
+    assert len(msg) == 0, msg
+
+    # ===========================================================================
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    try:
+        if ARGS.verbose: 
+            print("check server " + ARGS.host + ":" + ARGS.port + " is running")
+        CL.ping() 
+
+        if ARGS.verbose: 
+            print("Server is already running. re-start the server")
+        CL.restart_server() 
+
+        if ARGS.verbose: 
+            print("Remove suites associated with this DEFS, allows rerun *******************************************")
+        for suite in DEFS.suites:
+            try:
+                CL.delete(suite.get_abs_node_path(), True)
+            except RuntimeError as ex:
+                pass # For first run this will fail, hence ignore
+        
+        if ARGS.verbose: 
+            print("Load the definition into " + ARGS.host + ":" + ARGS.port)
+        if ARGS.path == "/":
+            CL.load(DEFS) 
+        else:
+            CL.replace(ARGS.path, DEFS)
+
+        if ARGS.verbose: 
+            print("Begin all suites. They should be suspended.")
+        print("Loaded suites:")
+        for suite in DEFS.suites:
+            CL.begin_suite(suite.name())
+            print("   " + suite.name())
+        print("into server " + ARGS.host \
+                             + ":" + ARGS.port + ", please view the playable suites in the GUI")
+    except RuntimeError as ex:
+        print("Error: " + str(ex))
diff -pruN 5.12.4-1/libs/pyext/samples/TestGui.py 5.13.0-1/libs/pyext/samples/TestGui.py
--- 5.12.4-1/libs/pyext/samples/TestGui.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/TestGui.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1507 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+import argparse # for argument parsing  
+import time
+import os
+import sys
+import pwd
+from datetime import datetime
+from socket import gethostname 
+import shutil   # used to remove directory tree
+
+# ecflow_test_util, see File ecflow_test_util.py
+import ecflow
+from ecflow import Defs, Clock, DState,  Style, State, RepeatDate, PrintStyle, File, Client, SState, \
+                   CheckPt, Cron, Late, debug_build, Flag, FlagType
+
+class Tester(object) : 
+    def __init__(self,ci,args):
+        self.ci_ = ci
+        self.port_ = self.ci_.get_port()
+        self.ARGS_ = args
+        
+    def clean_up_server(self):
+        self.log_msg("   clean_up server, clear log, remove check-pt, and white list file" )
+        self.ci_.clear_log()    
+        try: os.remove(self.checkpt_file_path())
+        except: pass
+        try: os.remove(self.backup_checkpt_file_path())
+        except: pass
+        try: os.remove(self.white_list_file_path())  
+        except: pass
+    
+    def clean_up_data(self):
+        self.log_msg("   Attempting to Removing ECF_HOME " + self.ecf_home())
+        try: 
+            shutil.rmtree(self.ecf_home(),True)   # True means ignore errors
+            shutil.rmtree("test_gui",True)   # True means ignore errors 
+            print("   Remove OK") 
+        except: 
+            print("   Remove Failed") 
+            pass
+        
+    def ecf_home(self): 
+        # debug_build() is defined for ecflow. Used in test to distinguish debug/release ecflow
+        # Vary ECF_HOME based on debug/release/port allowing multiple invocations of these tests
+        if debug_build():
+            return os.getcwd() + "/test_gui/data/ecf_home_debug_" + str(self.port_)
+        return os.getcwd() + "/test_gui/data/ecf_home_release_" + str(self.port_)
+
+    def ecf_includes(self) :  return os.getcwd() + "/libs/pyext/test/data/includes"
+    def log_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.log"
+    def checkpt_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.check"
+    def backup_checkpt_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.check.b"
+    def white_list_file_path(self): return "./" + gethostname() + "." + self.port_ + ".ecf.lists"
+
+    def path_to_ecflow_client(self):
+        if self.ARGS_.ecflow_client != "":
+            return self.ARGS_.ecflow_client
+        # to use the local build, in preference, to release version of ecflow
+        path_to_client = File.find_client() # version used by the ecflow module, may not exist anymore
+        if os.path.exists(path_to_client):
+            return path_to_client
+        path_to_client = "/usr/local/apps/ecflow/" + self.ci_.version() + "/bin/ecflow_client"
+        if os.path.exists(path_to_client):
+            return path_to_client
+        return "ecflow_client" # fall back, just search on $PATH *IN* the shell where the server was started
+     
+    def create_defs(self,name=""):
+        defs = Defs()
+        suite_name = name
+        if len(suite_name) == 0: suite_name = "s1"
+        suite = defs.add_suite(suite_name);
+        
+        ecfhome = self.ecf_home()
+        suite.add_variable("ECF_HOME", ecfhome)
+        suite.add_variable("ECF_CLIENT_EXE_PATH", self.path_to_ecflow_client())
+        suite.add_variable("SLEEP", "1");  # not strictly required since default is 1 second
+        suite.add_variable("ECF_INCLUDE", self.ecf_includes());
+    
+        family = suite.add_family("f1")
+        family.add_task("t1")
+        family.add_task("t2")
+        return defs;        
+        
+    def sync_local(self,sleep_time=4):
+        """Delay added so that we can see the change in the GUI.
+           The GUI refresh rate should be set to 1 second
+           """
+        self.ci_.sync_local()
+        if self.ARGS_.sync_sleep != 0 and sleep_time != 0:
+            time.sleep(self.ARGS_.sync_sleep)
+     
+    def log_msg(self,msg):
+        print(msg)
+        self.ci_.log_msg("======================== " + msg + " ========================")
+    
+    def test_version(self):
+        self.log_msg("test_version Client_version(" + self.ci_.version() + ") server version(" + self.ci_.server_version() + ")")
+        
+    def test_client_get_server_defs(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        self.ci_.load(self.create_defs(test))  
+        self.sync_local()  
+        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite of name " + test + ":\n" + str(self.ci_.get_defs())
+        
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+        self.sync_local()  
+    
+    def test_client_restart_server(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        self.ci_.restart_server()
+        self.sync_local()
+        assert self.ci_.get_defs().get_server_state() == SState.RUNNING, "Expected server to be running"
+        
+        paths = list(self.ci_.changed_node_paths)
+        #for path in self.ci_.changed_node_paths:
+        #    print("   changed node path " + path);
+        assert len(paths) == 1, "expected changed node to be the root node"
+        assert paths[0] == "/", "Expected root path but found " + str(paths[0])
+    
+    def test_client_halt_server(self):
+        self.log_msg(sys._getframe().f_code.co_name)
+        self.ci_.halt_server()
+        self.sync_local()
+        assert self.ci_.get_defs().get_server_state() == SState.HALTED, "Expected server to be halted"
+        
+        paths = list(self.ci_.changed_node_paths)
+        #for path in self.ci_.changed_node_paths:
+        #    print("   changed node path " + path);
+        assert len(paths) == 1, "expected changed node to be the root node"
+        assert paths[0] == "/", "Expected root path but found " + str(paths[0])
+        self.ci_.restart_server()   
+    
+    def test_client_shutdown_server(self):
+        self.log_msg(sys._getframe().f_code.co_name)
+        self.ci_.shutdown_server()
+        self.sync_local()
+        assert self.ci_.get_defs().get_server_state() == SState.SHUTDOWN, "Expected server to be shutdown"
+        
+        paths = list(self.ci_.changed_node_paths)
+        #for path in self.ci_.changed_node_paths:
+        #    print("   changed node path " + path);
+        assert len(paths) == 1, "expected changed node to be the root node"
+        assert paths[0] == "/", "Expected root path but found " + str(paths[0])
+    
+    def test_client_load_in_memory_defs(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        self.ci_.load(self.create_defs(test))  
+        self.sync_local() 
+        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite of name " + test + ":\n" + str(self.ci_.get_defs())              
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def test_client_load_from_disk(self):            
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test);
+        defs_file = test + ".def"
+        defs.save_as_defs(defs_file)     
+        assert os.path.exists(defs_file), "Expected file " + defs_file + " to exist after defs.save_as_defs()"
+        self.ci_.load(defs_file) # open and parse defs file, and load into server.\n"
+            
+        # check load worked
+        self.sync_local() 
+        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite of name " + test + ":\n" + str(self.ci_.get_defs())
+        os.remove(defs_file)
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def test_client_checkpt(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        try:    
+            os.remove(self.checkpt_file_path())
+            os.remove(self.backup_checkpt_file_path())
+        except: pass
+        
+        self.ci_.load(self.create_defs(test))  
+        self.sync_local() 
+        self.ci_.checkpt()
+        assert os.path.exists(self.checkpt_file_path()), "Expected check pt file " + self.checkpt_file_path() + " to exist after self.ci_.checkpt()"
+        assert os.path.exists(self.backup_checkpt_file_path()) == False, "Expected back up check pt file to *NOT* exist"
+        
+        self.ci_.checkpt()   # second check pt should cause backup check pt to be written
+        assert os.path.exists(self.backup_checkpt_file_path()), "Expected back up check pt file to exist after second self.ci_.checkpt()"
+    
+        self.ci_.checkpt(CheckPt.NEVER)         # switch of check pointing
+        self.ci_.checkpt(CheckPt.ALWAYS)        # always check point, at any state change
+        self.ci_.checkpt(CheckPt.ON_TIME)       # Check point periodically, by interval set in server
+        self.ci_.checkpt(CheckPt.ON_TIME, 200)  # Check point periodically, by interval set in server
+        self.ci_.checkpt(CheckPt.UNDEFINED, 0, 35)  # Change check point save time alarm
+    
+        os.remove(self.checkpt_file_path())
+        os.remove(self.backup_checkpt_file_path())
+        
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def test_client_restore_from_checkpt(self):          
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        try:    
+            os.remove(self.checkpt_file_path())
+            os.remove(self.backup_checkpt_file_path())
+        except: pass
+        
+        self.ci_.load(self.create_defs(test))  
+        self.sync_local()  
+        self.ci_.checkpt()
+        self.ci_.delete_all() 
+        
+        self.sync_local() 
+        assert len(list(self.ci_.get_defs().suites)) == 0, "Expected all suites to be delete:\n"
+        
+        self.ci_.halt_server()  # server must be halted, otherwise restore_from_checkpt will throw
+        self.ci_.restore_from_checkpt()
+        
+        self.sync_local() 
+        assert self.ci_.get_defs().find_suite(test) is not None, "Expected to find suite " + test + " after restore from checkpt:\n" + str(self.ci_.get_defs())
+    
+        os.remove(self.checkpt_file_path())
+        self.ci_.restart_server()   
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def get_username(self): return pwd.getpwuid(os.getuid())[ 0 ]
+    
+    def test_client_reload_wl_file(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        
+        expected = False
+        try:    self.ci_.reload_wl_file();            
+        except: expected = True
+        assert expected, "Expected reload to fail when no white list specified"
+        
+        # create a white list file
+        wl_file = open(self.white_list_file_path(), 'w')
+        wl_file.write("#\n")
+        wl_file.write("4.4.14   #   comment\n\n")
+        wl_file.write("# These user have read and write access to the server\n")
+        wl_file.write(self.get_username() + "\n")  # add current user otherwise remaining test's, wont have access from server anymore
+        wl_file.write("axel  # admin\n")
+        wl_file.write("john  # admin\n\n")
+        wl_file.write("# Read only users\n")
+        wl_file.write("-fred   # needs read access only\n")
+        wl_file.write("-joe90  # needs read access only\n")
+        wl_file.close();
+        
+        self.ci_.reload_wl_file();  
+        os.remove(self.white_list_file_path())          
+    
+    def generate_scripts_and_load_defs(self,defs):
+        defs.generate_scripts();
+        msg = defs.check_job_creation()       
+        assert len(msg) == 0, msg
+        
+        self.ci_.restart_server()
+        self.ci_.load(defs)           
+        self.sync_local() # clear changed_node_paths 
+
+    def create_and_load_defs(self,test,add_defstatus = True):
+        self.log_msg(test)
+        defs = self.create_defs(test)  
+        suite = defs.find_suite(test)
+        if add_defstatus :
+            suite.add_defstatus(DState.suspended)
+    
+        self.generate_scripts_and_load_defs(defs);
+        self.ci_.begin_suite(test)
+
+    def test_client_run(self):            
+        test = sys._getframe().f_code.co_name # returns function name
+        self.create_and_load_defs(test)
+        
+        self.ci_.run("/" + test, False)
+        
+        count = 0
+        while 1:
+            count += 1
+            self.sync_local(0) # get the changes, synced with local defs
+            suite = self.ci_.get_defs().find_suite(test)
+            assert suite is not None, "Expected to find suite " + test + ":\n" + str(self.ci_.get_defs())
+            if suite.get_state() == State.complete:
+                break;
+            time.sleep(3)
+            if count > 20:
+                assert False, "test_client_run aborted after " + str(count) + " loops:\n" + str(self.ci_.get_defs())
+            
+        self.ci_.log_msg("Looped " + str(count) + " times")
+        
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def test_client_run_with_multiple_paths(self):            
+        test = sys._getframe().f_code.co_name # returns function name
+        self.create_and_load_defs(test)
+
+        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2"]
+        self.ci_.run( path_list, False)
+    
+        count = 0
+        while 1:
+            count += 1
+            self.sync_local(0) # get the changes, synced with local defs
+            suite = self.ci_.get_defs().find_suite(test)
+            assert suite is not None, "Expected to find suite " + tests + ":\n" + str(self.ci_.get_defs())
+            if suite.get_state() == State.complete:
+                break;
+            time.sleep(3)
+            if count > 20:
+                assert False, test + " aborted after " + str(count) + " loops:\n" + str(self.ci_.get_defs())
+            
+        self.ci_.log_msg("Looped " + str(count) + " times")
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this   
+    
+    def test_client_requeue(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.create_and_load_defs(test)
+        
+        self.ci_.force_state_recursive("/" + test,State.unknown)
+        self.sync_local();
+        suite = self.ci_.get_defs().find_suite(test)
+        assert suite.get_state() == State.unknown, "Expected to find suite with state unknown"
+    
+        self.ci_.requeue("/" + test)
+        self.sync_local();
+        suite = self.ci_.get_defs().find_suite(test)
+        assert suite.get_state() == State.queued, "Expected to find suite with state queued"
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def test_client_requeue_with_multiple_paths(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.create_and_load_defs(test)
+
+        self.ci_.force_state_recursive("/" + test,State.unknown)
+        self.sync_local();
+        task1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
+        task2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
+        assert task1.get_state() == State.unknown, "Expected to find t1 with state unknown"
+        assert task2.get_state() == State.unknown, "Expected to find t2 with state unknown"
+    
+        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]
+        self.ci_.requeue( path_list)
+        self.sync_local();
+        task1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
+        task2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
+        assert task1.get_state() == State.queued, "Expected to find task t1 with state queued"
+        assert task2.get_state() == State.queued, "Expected to find task t2 with state queued"
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def test_client_free_dep(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+           
+        # add a real clock, since we are adding date dependencies
+        # Note: adding a future time dependency on a task, will cause it to requeue, when complete
+        # Hence even when we free these dependency they get requeued.
+        # So we use todays date.
+        ltime = time.localtime();
+        day = ltime.tm_mday
+        month = ltime.tm_mon
+        year = ltime.tm_year
+        
+        defs = Defs()
+        suite = defs.add_suite(test);
+        suite.add_clock(Clock(False)) # true means hybrid, False means real
+        ecfhome = self.ecf_home();
+        suite.add_variable("ECF_HOME", ecfhome);
+        suite.add_variable("ECF_CLIENT_EXE_PATH", self.path_to_ecflow_client());
+        suite.add_variable("SLEEPTIME", "1");
+        suite.add_variable("ECF_INCLUDE", self.ecf_includes());
+        family = suite.add_family("f1")
+        family.add_task("t1").add_time("00:01")
+        family.add_task("t2").add_date(day,month,year)
+        family.add_task("t3").add_trigger("1 == 0")
+        t4 = family.add_task("t4")
+        t4.add_time("00:01")
+        t4.add_date(day,month,year)
+        t4.add_trigger("1 == 0")
+    
+        self.generate_scripts_and_load_defs(defs);
+        self.ci_.begin_suite(test)
+        
+        t1_path = "/" + test + "/f1/t1"
+        t2_path = "/" + test + "/f1/t2"
+        t3_path = "/" + test + "/f1/t3"
+        t4_path = "/" + test + "/f1/t4"
+        while 1:
+            self.sync_local(0)
+            t1 = self.ci_.get_defs().find_abs_node(t1_path)
+            t2 = self.ci_.get_defs().find_abs_node(t2_path)
+            t3 = self.ci_.get_defs().find_abs_node(t3_path)
+            t4 = self.ci_.get_defs().find_abs_node(t4_path)
+     
+            if t1.get_state() == State.queued: self.ci_.free_time_dep(t1_path)
+            if t2.get_state() == State.queued: self.ci_.free_date_dep(t2_path)
+            if t3.get_state() == State.queued: self.ci_.free_trigger_dep(t3_path)
+            if t4.get_state() == State.queued: self.ci_.free_all_dep(t4_path)
+    
+            suite = self.ci_.get_defs().find_suite(test)
+            if suite.get_state() == State.complete:
+                break;
+            time.sleep(3)       
+                
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+
+    
+    def test_client_check(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        
+        defs = Defs()
+        defs.add_extern("/a/b/c/d")
+        defs.add_extern("/a/b/c/d/e:event")
+        defs.add_extern("/a/b/c/d/e:meter")
+        defs.add_extern("/made/up/redundant/extren")
+        defs.add_extern("/made/up/redundant/extren")
+        defs.add_extern("/limits:c1a")
+        defs.add_extern("/limits:c1a")
+        defs.add_extern("fred")
+        defs.add_extern("limits:hpcd")
+        defs.add_extern("/suiteName:sg1")
+        defs.add_extern("/obs/limits:hpcd")
+        suite = defs.add_suite(test)
+        family_f1 = suite.add_family("f1")
+        family_f1.add_task("p").add_trigger("/a/b/c/d == complete")      # extern path
+        family_f1.add_task("q").add_trigger("/a/b/c/d/e:event == set")   # extern event path
+        family_f1.add_task("r").add_trigger("/a/b/c/d/e:meter le 30")    # extern meter path
+    
+        suite.add_inlimit("c1a","/limits")
+        suite.add_inlimit("fred")
+        
+        family_anon = suite.add_family("anon")
+        family_anon.add_inlimit("hpcd","limits")
+        family_anon.add_task("t1").add_inlimit("sg1","/suiteName")
+        family_anon.add_task("t2").add_inlimit("hpcd","/obs/limits")
+        family_anon.add_task("t3").add_inlimit("c1a","/limits")
+     
+        # CLIENT side check
+        client_check = defs.check()
+        assert len(client_check) == 0, "Expected clean defs check due to externs but found:\n" + client_check + "\n" + str(defs)
+    
+        # SERVER side check
+        self.ci_.load(defs)
+        self.sync_local()  
+        server_check = self.ci_.check("") # empty string means check the whole defs, otherwise a node path can be specified.
+        server_check = self.ci_.check("/" + test)  
+        # print server_check
+        assert len(server_check) > 0, "Expected defs to fail, since no externs in server "
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+        
+    def test_client_suites(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        no_of_suites = len(self.ci_.suites())
+    
+        defs = self.create_defs("test_client_suites")
+        self.ci_.load(defs)  
+        assert len(self.ci_.suites()) == no_of_suites + 1 ,"expected " + str(no_of_suites + 1) + " suites"
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+        
+    def test_client_ch_suites(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        
+        defs = Defs()
+        for i in range(1,7): defs.add_suite(test + str(i))
+        self.ci_.load(defs)
+        self.sync_local()  
+        
+        suite_names = [ test + '1', test + '2', test + '3' ]
+        self.ci_.ch_register(True,suite_names)      # register interest in suites s1,s2,s3 and any new suites
+        self.ci_.ch_register(False,[ test + "1"])   # register interest in suites s1 
+        self.sync_local();
+        
+        self.ci_.ch_suites()  # writes to standard out, list of suites and handles
+        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
+        self.sync_local();    
+    
+    def test_client_ch_register(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg("test_client_ch_register")
+        
+        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        except: pass              # Drop throws if no handle registered
+        
+        defs = Defs()
+        for i in range(1,7): defs.add_suite( test + str(i))
+        self.ci_.load(defs)
+        self.sync_local();
+        
+        suite_names = [ test + '1', test + '2', test + '3' ]
+        self.ci_.ch_register(True, suite_names)    # register interest in suites s1,s2,s3 and any new suites
+        self.ci_.ch_register(False,suite_names)    # register interest in suites s1,s2,s3 only
+        self.sync_local();
+        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
+                
+    def test_client_ch_drop(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        
+        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        except: pass              # Drop throws if no handle registered
+        
+        defs = Defs()
+        for i in range(1,7): defs.add_suite(test + str(i))
+        self.ci_.load(defs)
+        self.sync_local()  
+        
+        try:
+            # register interest in suites s1,s2,s3 and any new suites
+            suite_names = [ test + '1', test + '2', test + '3' ]
+            self.ci_.ch_register(True, suite_names)    
+            self.sync_local();
+        finally:  
+            self.ci_.ch_drop()  # drop using handle stored in self.ci_., from last register
+        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
+              
+    def test_client_ch_drop_user(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        except: pass              # Drop throws if no handle registered
+        
+        defs = Defs()
+        for i in range(1,7): defs.add_suite(test + str(i))
+        self.ci_.load(defs)
+        self.sync_local()  
+        
+        try:
+            # register interest in suites s1,s2,s3 and any new suites
+            suite_names = [ test + '1', test + '2', test + '3' ]
+            self.ci_.ch_register(True, suite_names)
+            self.sync_local();
+        except RuntimeError as e:
+            print(str(e))
+        
+        self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
+                
+    def test_client_ch_add(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        except: pass              # Drop throws if no handle registered
+        
+        defs = Defs()
+        for i in range(1,7): defs.add_suite(test + str(i))
+        self.ci_.load(defs)
+        self.sync_local()  
+        
+        try:
+            suite_names = []
+            self.ci_.ch_register(True,suite_names)        # register interest in any new suites
+            suite_names = [ test + '1', test + '2' ]
+            self.ci_.ch_add(suite_names)                  # add suites s1,s2 to the last added handle
+            suite_names = [ test + '3', test + '4' ]
+            self.ci_.ch_add( self.ci_.ch_handle(),suite_names)  # add suites s3,s4 using last handle
+            self.sync_local();
+        except RuntimeError as e:
+            print(str(e))
+            
+        self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
+                
+    def test_client_ch_auto_add(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        except: pass              # Drop throws if no handle registered
+        
+        defs = Defs()
+        for i in range(1,7): defs.add_suite(test + str(i))
+        self.ci_.load(defs)
+        self.sync_local()  
+        
+        try:
+            suite_names = [ test + '1', test + '2', test + '3' ]
+            self.ci_.ch_register(True,suite_names)     # register interest in suites s1,s2,s3 and any new suites
+            self.ci_.ch_auto_add( False )              # disable adding newly created suites to last registered handle
+            self.ci_.ch_auto_add( True )               # enable adding newly created suites to last registered handle
+            self.ci_.ch_auto_add( self.ci_.ch_handle(), False ) # disable adding newly created suites to handle
+            self.sync_local();
+        except RuntimeError as e:
+            print(str(e))
+            
+        self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
+               
+    def test_client_ch_remove(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        try: self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        except: pass              # Drop throws if no handle registered
+        
+        defs = Defs()
+        for i in range(1,7): defs.add_suite(test + str(i))
+        self.ci_.load(defs)
+        self.sync_local()  
+        
+        try:
+            suite_names = [ test + '1', test + '2', test + '3' ]
+            self.ci_.ch_register(True,suite_names)     # register interest in suites s1,s2,s3 and any new suites
+            suite_names = [ test + '1' ]
+            self.ci_.ch_remove( suite_names )          # remove suites s1 from the last added handle\n"
+            suite_names = [  test + '2'  ]
+            self.ci_.ch_remove( self.ci_.ch_handle(), suite_names )  # remove suites s2 from the last added handle\n"
+            self.sync_local();
+        except RuntimeError as e:
+            print(str(e))
+            
+        self.ci_.ch_drop_user("")  # drop all handle associated with current user
+        for i in range(1,7):  self.ci_.delete("/" + test + str(i)  ) # stop  downstream test from re-starting this
+               
+    def test_client_get_file(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.create_and_load_defs(test,False)
+  
+        while 1:
+            if self.ci_.news_local():
+                self.sync_local(0) # get the changes, synced with local defs
+                suite = self.ci_.get_defs().find_suite(test)
+                assert suite is not None, "Expected to find suite"
+                if suite.get_state() == State.complete:
+                    break;
+            time.sleep(3)
+        try:
+            for file_t in [ 'script', 'job', 'jobout', 'manual' ]:
+                the_returned_file = self.ci_.get_file('/' + test +'/f1/t1',file_t)  # make a request to the server
+                assert len(the_returned_file) > 0,"Expected self.ci_.get_file(/" + test + "/f1/t1," + file_t + ") to return something"
+        except RuntimeError as e:
+            print(str(e))
+    
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+        
+    def test_client_alter_add(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        self.ci_.load(self.create_defs(test))   
+        self.sync_local()  
+    
+        t1 = "/" + test + "/f1/t1"
+        self.ci_.alter(t1,"add","variable","var","var_name")
+        self.ci_.alter(t1,"add","time","+00:30")
+        self.ci_.alter(t1,"add","time","01:30")
+        self.ci_.alter(t1,"add","time","01:30 20:00 00:30")
+        self.ci_.alter(t1,"add","today","+00:30")
+        self.ci_.alter(t1,"add","today","01:30")
+        self.ci_.alter(t1,"add","today","01:30 20:00 00:30")
+        self.ci_.alter(t1,"add","date","01.01.2001")
+        self.ci_.alter(t1,"add","date","*.01.2001")
+        self.ci_.alter(t1,"add","date","*.*.2001")
+        self.ci_.alter(t1,"add","date","*.*.*")
+        self.ci_.alter(t1,"add","day","sunday")
+        self.ci_.alter(t1,"add","day","monday")
+        self.ci_.alter(t1,"add","day","tuesday")
+        self.ci_.alter(t1,"add","day","wednesday")
+        self.ci_.alter(t1,"add","day","thursday")
+        self.ci_.alter(t1,"add","day","friday")
+        self.ci_.alter(t1,"add","day","saturday")
+        self.ci_.alter(t1,"add","late","late -s +00:15 -a 20:00 -c +02:00")
+    
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.variables))) == 1 ,"Expected 1 variable :\n" + str(self.ci_.get_defs())
+        assert( len(list(task_t1.times))) == 3 ,"Expected 3 time :\n" + str(self.ci_.get_defs())
+        assert( len(list(task_t1.todays))) == 3 ,"Expected 3 today's :\n" + str(self.ci_.get_defs())
+        assert( len(list(task_t1.dates))) == 4 ,"Expected 4 dates :\n" + str(self.ci_.get_defs())
+        assert( len(list(task_t1.days))) == 7 ,"Expected 7 days :\n" + str(self.ci_.get_defs())
+        assert str(task_t1.get_late()) == "late -s +00:15 -a 20:00 -c +02:00", "Expected late 'late -s +00:15 -a 20:00 -c +02:00'" + str(self.ci_.get_defs())
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+               
+    def test_client_alter_delete(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        defs = self.create_defs(test)  
+         
+        t1 = "/" + test + "/f1/t1"
+        task_t1 = defs.find_abs_node(t1)
+        task_t1.add_variable("var","value")
+        task_t1.add_variable("var1","value")
+        task_t1.add_time("00:30")
+        task_t1.add_time("00:31")
+        task_t1.add_today("00:30")
+        task_t1.add_today("00:31")
+        task_t1.add_date(1,1,2001)
+        task_t1.add_date(1,1,2002)
+        task_t1.add_day("sunday")
+        task_t1.add_day("monday")
+        cron = Cron()
+        cron.set_week_days( [0,1,2,3,4,5,6] )
+        cron.set_time_series( "+00:30" )
+        task_t1.add_cron(cron)
+        task_t1.add_cron(cron)
+        task_t1.add_event("event")
+        task_t1.add_event("event1")
+        task_t1.add_meter("meter",0,100,100)
+        task_t1.add_meter("meter1",0,100,100)
+        task_t1.add_label("label","name")
+        task_t1.add_label("label1","name")
+        task_t1.add_limit("limit",10)
+        task_t1.add_limit("limit1",10)
+        task_t1.add_inlimit( "limit",t1,2)
+        task_t1.add_inlimit( "limit1",t1,2)
+        task_t1.add_trigger( "t2 == active" )
+        task_t1.add_complete( "t2 == complete" )
+        
+        assert task_t1.get_late() is None, "expected no late" 
+        late = Late()
+        late.submitted(20, 10)
+        late.active(20, 10)
+        late.complete(20, 10, True)
+        task_t1.add_late(late)
+        assert task_t1.get_late() is not None, "expected late" 
+        
+        t2 = "/" + test + "/f1/t2"
+        task_t2 = defs.find_abs_node(t2)
+        task_t2.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
+        
+        self.ci_.load(defs)   
+        self.sync_local()  
+    
+        self.ci_.alter(t1,"delete","variable","var")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.variables))) == 1 ,"Expected 1 variable :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","variable")  # delete all variables
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.variables))) == 0 ,"Expected 0 variable :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","time","00:30")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.times))) == 1 ,"Expected 1 time :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","time")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.times))) == 0 ,"Expected 0 time :\n" + str(self.ci_.get_defs())
+        
+        self.ci_.alter(t1,"delete","today","00:30")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.todays))) == 1 ,"Expected 1 today :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","today")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.todays))) == 0 ,"Expected 0 today :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","date","01.01.2001")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.dates))) == 1 ,"Expected 1 date :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","date")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.dates))) == 0 ,"Expected 0 date :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","day","sunday")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.days))) == 1 ,"Expected 1 day :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","day")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.days))) == 0 ,"Expected 0 day :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","event","event")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.events))) == 1 ,"Expected 1 event :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","event")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.events))) == 0 ,"Expected 0 event :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","meter","meter")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.meters))) == 1 ,"Expected 1 meter :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","meter")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.meters))) == 0 ,"Expected 0 meter :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","label","label")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.labels))) == 1 ,"Expected 1 label :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","label")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.labels))) == 0 ,"Expected 0 label :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","limit","limit")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.limits))) == 1 ,"Expected 1 limit :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","limit")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.limits))) == 0 ,"Expected 0 limit :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","inlimit","limit")
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.inlimits))) == 1 ,"Expected 1 inlimit :\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","inlimit")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.inlimits))) == 0 ,"Expected 0 inlimit :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","cron")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert( len(list(task_t1.crons))) == 0 ,"Expected 0 crons :\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t1,"delete","late")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert task_t1.get_late() is None, "expected no late after delete" 
+    
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert task_t1.get_trigger() is not None, "Expected trigger:\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","trigger")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert task_t1.get_trigger() is None, "Expected trigger to be deleted:\n" + str(self.ci_.get_defs())
+    
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert task_t1.get_complete() is not None, "Expected complete:\n" + str(self.ci_.get_defs())
+        self.ci_.alter(t1,"delete","complete")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        assert task_t1.get_complete() is None, "Expected complete to be deleted:\n" + str(self.ci_.get_defs())
+    
+        self.ci_.alter(t2,"delete","repeat")   
+        self.sync_local()
+        task_t2 = self.ci_.get_defs().find_abs_node(t2)
+        repeat = task_t2.get_repeat()
+        assert repeat.empty(), "Expected repeat to be deleted:\n" + str(self.ci_.get_defs())
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+     
+    def test_client_alter_change(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)   
+        t1 = "/" + test + "/f1/t1"
+        repeat_date_path = "/" + test + "/f1/repeat_date"
+        
+        task_t1 = defs.find_abs_node(t1)
+        task_t1.add_variable("var","value")
+        task_t1.add_variable("var1","value")
+        task_t1.add_event("event")
+        task_t1.add_event("event1")
+        task_t1.add_meter("meter",0,100,100)
+        task_t1.add_meter("meter1",0,100,100)
+        task_t1.add_label("label","name")
+        task_t1.add_label("label1","name1")
+        task_t1.add_limit("limit",10)
+        task_t1.add_limit("limit1",10)
+        task_t1.add_inlimit( "limit",t1,2)
+        task_t1.add_inlimit( "limit1",t1,2)
+        task_t1.add_trigger( "t2 == active" )
+        task_t1.add_complete( "t2 == complete" )
+        late = Late()
+        late.submitted(20, 10)
+        late.active(20, 10)
+        late.complete(20, 10, True)
+        task_t1.add_late(late)
+                
+        f1 = defs.find_abs_node("/" + test + "/f1")
+        repeat_date = f1.add_task("repeat_date")
+        repeat_date.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
+               
+        self.ci_.load(defs)   
+        self.sync_local()  
+    
+        self.ci_.alter(t1,"change","late","-s +10:00")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        variable = task_t1.get_late()
+        assert str(task_t1.get_late()) == "late -s +10:00", "Expected alter of late to be 'late -s +10:00' but found " + str(task_t1.get_late())
+    
+        self.ci_.alter(t1,"change","variable","var","changed_var")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        variable = task_t1.find_variable("var")
+        assert variable.value() == "changed_var", "Expected alter of variable to be 'change_var' but found " + variable.value()
+    
+        self.ci_.alter(t1,"change","meter","meter","10")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        meter = task_t1.find_meter("meter")
+        assert meter.value() == 10, "Expected alter of meter to be 10 but found " + str(meter.value())
+    
+        self.ci_.alter(t1,"change","event","event","set")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        event = task_t1.find_event("event")
+        assert event.value() == True, "Expected alter of event to be set but found " + str(event.value())
+    
+        self.ci_.alter(t1,"change","trigger","t2 == aborted")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        trigger = task_t1.get_trigger()
+        assert trigger.get_expression() == "t2 == aborted", "Expected alter of trigger to be 't2 == aborted' but found " + trigger.get_expression()
+    
+        self.ci_.alter(t1,"change","trigger","/test_client_alter_change/f1/t2 == complete")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        trigger = task_t1.get_trigger()
+        assert trigger.get_expression() == "/test_client_alter_change/f1/t2 == complete", "Expected alter of trigger to be '/test_client_alter_change/f1/t2 == complete' but found " + trigger.get_expression()
+    
+        self.ci_.alter(t1,"change","complete","t2 == aborted")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        complete = task_t1.get_complete()
+        assert complete.get_expression() == "t2 == aborted", "Expected alter of complete to be 't2 == aborted' but found " + complete.get_expression()
+    
+        self.ci_.alter(t1,"change","complete","/test_client_alter_change/f1/t2 == active")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        complete = task_t1.get_complete()
+        assert complete.get_expression() == "/test_client_alter_change/f1/t2 == active", "Expected alter of complete to be '/test_client_alter_change/f1/t2 == active' but found " + complete.get_expression()
+    
+        self.ci_.alter(t1,"change","limit_max","limit", "2")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        limit = task_t1.find_limit("limit")
+        assert limit is not None, "Expected to find limit"
+        assert limit.limit() == 2, "Expected alter of limit_max to be 2 but found " + str(limit.limit())
+    
+        self.ci_.alter(t1,"change","limit_value","limit", "2")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        limit = task_t1.find_limit("limit")
+        assert limit is not None, "Expected to find limit"
+        assert limit.value() == 2, "Expected alter of limit_value to be 2 but found " + str(limit.value())
+    
+        self.ci_.alter(t1,"change","label","label","new-value")   
+        self.sync_local()
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        label = task_t1.find_label("label")
+        assert label.new_value() == "new-value", "Expected alter of label to be 'new-value' but found " + label.new_value()
+        
+        self.ci_.alter(repeat_date_path,"change","repeat","20100113")   
+        self.sync_local()
+        task = self.ci_.get_defs().find_abs_node(repeat_date_path)
+        repeat = task.get_repeat()
+        assert repeat.value() == 20100113, "Expected alter of repeat to be 20100113 but found " + str(repeat.value())
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+     
+    def test_client_alter_flag(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)  
+         
+        t1 = "/" + test + "/f1/t1"
+        task_t1 = defs.find_abs_node(t1)
+               
+        self.ci_.load(defs)   
+        self.sync_local()  
+    
+        flag = Flag()
+        flag_list = flag.list() # flag_list is of type FlagTypeVec
+        for flg in flag_list: 
+            self.ci_.alter(t1,"set_flag",flag.type_to_string(flg) )   
+            self.sync_local()
+            task_t1 = self.ci_.get_defs().find_abs_node(t1)
+            task_flag = task_t1.get_flag()
+            assert task_flag.is_set( flg ),"expected flag %r to be set" % task_flag.type_to_string(flg)
+    
+            # alter itself causes the flag message to be set, and preserved
+            if flg == FlagType.message: continue 
+            
+            self.ci_.alter(t1,"clear_flag",flag.type_to_string(flg) )   
+            self.sync_local()
+            task_t1 = self.ci_.get_defs().find_abs_node(t1)
+            task_flag = task_t1.get_flag()
+            assert not task_flag.is_set( flg ),"expected flag %r NOT to be set" % task_flag.type_to_string(flg)
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+    
+    def test_client_force(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test) 
+         
+        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]       
+        t1 = path_list[0]      
+        for path in path_list:
+            task = defs.find_abs_node(path)
+            assert task is not None, "Expected to find task at path " + path
+            task.add_event("event")
+    
+        self.ci_.load(defs)   
+        self.sync_local()  
+        
+        state_list = [ State.unknown, State.active, State.complete, State.submitted, State.aborted, State.queued ]
+        for state in state_list:
+            self.ci_.force_state(t1,state) 
+            self.sync_local()
+            task = self.ci_.get_defs().find_abs_node(t1)
+            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())      
+        for state in state_list:
+            self.ci_.force_state( path_list,state) 
+            self.sync_local()
+            for path in path_list:
+                task = self.ci_.get_defs().find_abs_node(path)
+                assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())     
+     
+        for state in state_list:
+            self.ci_.force_state_recursive("/" + test,state) 
+            self.sync_local()
+            task = self.ci_.get_defs().find_abs_node(t1)
+            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())
+        suite_paths = [ "/" + test ]
+        for state in state_list:
+            self.ci_.force_state_recursive( suite_paths,state) 
+            self.sync_local()
+            task = self.ci_.get_defs().find_abs_node(t1)
+            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())           
+        
+        event_states = [ "set", "clear" ]
+        for ev_state in event_states:
+            for path in path_list:
+                self.ci_.force_event(path + ":event" , ev_state)
+                self.sync_local()
+                task = self.ci_.get_defs().find_abs_node(path)
+                event_fnd = False
+                for event in task.events:
+                    event_fnd = True
+                    if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
+                    else:                   assert event.value() == False ," Expected event value to be clear"
+                assert event_fnd == True," Expected event to be found"
+    
+        event_path_list = [ "/" + test + "/f1/t1:event", "/" + test + "/f1/t2:event" ]       
+        event_states = [ "set", "clear" ]
+        for ev_state in event_states:
+            self.ci_.force_event( event_path_list , ev_state)
+            self.sync_local()
+            for path in path_list:
+                task = self.ci_.get_defs().find_abs_node(path)
+                event_fnd = False
+                for event in task.events:
+                    event_fnd = True
+                    if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
+                    else:                   assert event.value() == False ," Expected event value to be clear"
+                assert event_fnd == True," Expected event to be found"
+    
+        self.ci_.suspend("/" + test  ) # stop  downstream test from re-starting this
+          
+    def test_client_replace(self,on_disk):
+        test = sys._getframe().f_code.co_name # returns function name
+        if on_disk:
+            test = test + "on_disk"
+        self.log_msg(test)
+        self.ci_.log_msg(str(on_disk))
+         
+        # Create and load the following defs
+        # s1
+        #   f1
+        #     t1
+        #     t2
+        self.ci_.load(self.create_defs(test))  
+        self.sync_local()  
+        
+        #===============================================================================
+        # Example of using replace to ADD a *NEW* node hierarchy to an existing suite
+        # we should end up with:
+        # s1
+        #   f1
+        #     t1
+        #     t2
+        #   f2
+        #     t1
+        client_def = self.create_defs(test)
+        client_def.find_suite(test).add_family("f2").add_task("t1")
+        if on_disk:
+            client_def.save_as_defs(test + ".def")
+            client_def = test + ".def"
+        
+        self.ci_.replace("/" + test + "/f2",client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
+        self.sync_local()  
+        assert self.ci_.get_defs().find_abs_node("/" + test + "/f2/t1") is not None, "Expected to find task /" + test + "/f2/t1\n" + str(self.ci_.get_defs())
+    
+        # Example of using replace to *REMOVE* node hierarchy to an existing suite, could have used delete
+        assert self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1") is not None, "Expected to find task /" + test + "/f1/t1\n" + str(self.ci_.get_defs())
+        assert self.ci_.get_defs().find_abs_node("/" + test + "/f2/t1") is not None, "Expected to find task /" + test + "/f2/t1\n" + str(self.ci_.get_defs())
+        client_def = Defs()
+        client_def.add_suite(test)    # should only have the suite
+        if on_disk:
+            client_def.save_as_defs(test + ".def")
+            client_def = test + ".def"
+    
+        self.ci_.replace("/" + test,client_def)   
+        self.sync_local()  
+        assert self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1") is None, "Expected NOT to find task /" + test + "/f1/t1\n" + str(self.ci_.get_defs())
+        assert self.ci_.get_defs().find_abs_node("/" + test + "/f2/t1") is None, "Expected NOT to find task /" + test + "/f2/t1\n" + str(self.ci_.get_defs())
+    
+        #===============================================================================
+        # Example of using replace to add a *NEW* suite
+        test2 = test + "2";
+        client_def = Defs();
+        client_def.add_suite(test2)
+        if on_disk:
+            client_def.save_as_defs(test + ".def")
+            client_def = test + ".def"
+    
+        self.ci_.replace("/" + test2,client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
+        self.sync_local()  
+        suite = self.ci_.get_defs().find_suite(test2)
+        assert suite is not None ,"Expected to find suite :" + test2 + "\n" + str(self.ci_.get_defs())
+               
+        # replace added suite s2 with a new s2 which has a task, 
+        # s2 must exist on the client defs
+        client_def = Defs();
+        client_def.add_suite(test2).add_task("t1")
+        if on_disk:
+            client_def.save_as_defs(test + ".def")
+            client_def = test + ".def"
+    
+        self.ci_.replace("/" + test2,client_def) 
+        self.sync_local()  
+            
+        assert self.ci_.get_defs().find_abs_node("/" + test2 + "/t1") is not None, "Expected to find task /" + test2 + "/t1\n" + str(self.ci_.get_defs())
+        if on_disk:
+            os.remove(client_def)
+    
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
+        self.ci_.suspend("/" + test2  ) # stop  downstream test from re-starting this
+        self.sync_local()  
+    
+    def test_client_suspend(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        
+        defs = self.create_defs(test)  
+        defs.find_suite(test).add_variable("ECF_DUMMY_TASK","")
+            
+        self.ci_.load(defs)  
+        self.sync_local()  
+        self.ci_.begin_suite(test)  
+        
+        self.ci_.suspend("/" + test )  
+               
+        self.sync_local();
+        suite = self.ci_.get_defs().find_suite(test)
+        assert suite.is_suspended(), "Expected to find suite suspended"
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
+        
+    def test_client_suspend_multiple_paths(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)  
+        suite = defs.find_suite(test)
+        suite.add_variable("ECF_DUMMY_TASK","")
+        
+        self.ci_.load(defs)  
+        self.ci_.begin_suite(test)  
+        self.sync_local()  
+        
+        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]
+        self.ci_.suspend( path_list )  
+               
+        self.sync_local();
+        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
+        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
+        assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
+        assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
+                
+    def test_client_resume(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)  
+        defs.find_suite(test).add_variable("ECF_DUMMY_TASK","")
+            
+        self.ci_.load(defs)  
+        self.ci_.begin_suite(test)  
+        self.sync_local()  
+        
+        self.ci_.suspend("/" + test )  
+        self.sync_local();
+        suite = self.ci_.get_defs().find_suite(test)
+        assert suite.is_suspended(), "Expected to find suite suspended"
+        
+        self.ci_.resume("/" + test )  
+        self.sync_local();
+        suite = self.ci_.get_defs().find_suite(test)
+        assert suite.is_suspended() == False, "Expected to find suite resumed"
+    
+        # suspend to stop down stream tests from restarting this test
+        self.ci_.suspend("/" + test )  
+    
+    def test_client_resume_multiple_paths(self):
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)  
+        defs.find_suite(test).add_variable("ECF_DUMMY_TASK","")
+            
+        self.ci_.load(defs)  
+        self.ci_.begin_suite(test)  
+        self.sync_local()  
+        
+        path_list = [ "/" + test + "/f1/t1", "/" + test + "/f1/t2" ]
+        self.ci_.suspend( path_list )  
+      
+        self.sync_local();
+        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
+        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
+        assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
+        assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
+    
+        self.ci_.resume( path_list )  
+        self.sync_local();
+        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
+        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
+        assert task_t1.is_suspended() == False, "Expected to find task t1 to be resumed"
+        assert task_t2.is_suspended() == False, "Expected to find task t2 to be resumed"
+        
+         # suspend to stop down stream tests from restarting this test
+        self.ci_.suspend("/" + test )  
+      
+    def test_client_delete_node(self): 
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)
+        
+        task_vec = defs.get_all_tasks();
+        assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
+    
+        self.ci_.load(defs)  
+        self.sync_local();
+        for task in task_vec:
+            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
+            assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(self.ci_.get_defs()) 
+    
+        for task in task_vec:
+            self.ci_.delete(task.get_abs_node_path())
+    
+        self.sync_local();
+        for task in task_vec:
+            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
+            assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(self.ci_.get_defs())   
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
+        
+    def test_client_delete_node_multiple_paths(self): 
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)
+        
+        task_vec = defs.get_all_tasks();
+        assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
+    
+        paths = []
+        for task in task_vec:
+            paths.append(task.get_abs_node_path()) 
+     
+        self.ci_.load(defs)  
+        
+        self.sync_local();
+        for task in task_vec:
+            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
+            assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(self.ci_.get_defs()) 
+    
+        self.ci_.delete(paths)
+    
+        self.sync_local();
+        for task in task_vec:
+            node = self.ci_.get_defs().find_abs_node(task.get_abs_node_path()) 
+            assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(self.ci_.get_defs())   
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this    
+    
+    def test_client_check_defstatus(self):            
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        defs = self.create_defs(test)  
+        
+        # stop defs from running when begin is called.
+        defs.find_suite(test).add_defstatus(DState.suspended)
+    
+        t1 = "/" + test + "/f1/t1"
+        t2 = "/" + test + "/f1/t2"
+        task_t1 = defs.find_abs_node(t1)
+        task_t1.add_defstatus(DState.suspended)
+        
+        self.generate_scripts_and_load_defs(defs);
+        self.ci_.begin_suite(test)
+         
+        self.sync_local() # get the changes, synced with local defs
+        #print self.ci_.get_defs();
+        task_t1 = self.ci_.get_defs().find_abs_node(t1)
+        task_t2 = self.ci_.get_defs().find_abs_node(t2)
+        assert task_t1 is not None,"Could not find t1"
+        assert task_t2 is not None,"Could not find t2"
+      
+        assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
+        assert task_t2.get_state() == State.queued, "Expected state queued " + str(task_t2.get_state())
+    
+        assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_state())
+        assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_state())
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
+       
+    def test_ECFLOW_189(self):
+        # Bug, when a node is resumed it ignored holding dependencies higher up the tree.
+        # i.e Previously when we resumed a node, it ignored trigger/time/node state, dependencies higher up the tree
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        self.generate_scripts_and_load_defs(self.create_defs(test));
+        
+        self.ci_.suspend("/" + test  )
+        self.ci_.suspend("/" + test + "/f1/t1")
+        self.ci_.suspend("/" + test + "/f1/t2")
+            
+        self.ci_.begin_suite(test)
+        
+        self.sync_local() # get the changes, synced with local defs
+        #print self.ci_.get_defs();
+        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
+        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
+        assert task_t1 is not None,"Could not find /" + test + "/f1/t1"
+        assert task_t2 is not None,"Could not find /" + test + "/f1/t2"
+      
+        assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
+        assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
+        assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_dstate())
+        assert task_t2.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t2.get_dstate())
+    
+        # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
+        self.ci_.resume("/" + test + "/f1/t1")
+        self.ci_.resume("/" + test + "/f1/t2")
+         
+        self.sync_local() # get the changes, synced with local defs
+        #print self.ci_.get_defs();
+        task_t1 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t1")
+        task_t2 = self.ci_.get_defs().find_abs_node("/" + test + "/f1/t2")
+        assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
+        assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
+        assert task_t1.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t1.get_dstate())
+        assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_dstate())
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
+    
+    def test_ECFLOW_199(self):
+        # Test ClientInvoker::changed_node_paths
+        test = sys._getframe().f_code.co_name # returns function name
+        self.log_msg(test)
+        self.generate_scripts_and_load_defs(self.create_defs(test));
+        
+        self.ci_.suspend("/" + test  )
+        self.ci_.suspend("/" + test + "/f1/t1")
+        self.ci_.suspend("/" + test + "/f1/t2")
+        self.sync_local() # get the changes, synced with local defs
+    
+        self.ci_.begin_suite(test)
+        
+        self.sync_local() # get the changes, synced with local defs
+        #print self.ci_.get_defs();
+        assert len(list(self.ci_.changed_node_paths)) == 0, "Expected first call to sync_local, to have no changed paths but found " + str(len(list(self.ci_.changed_node_paths)))
+        
+        # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
+        self.ci_.resume("/" + test + "/f1/t1")
+        self.sync_local() 
+        if len(list(self.ci_.changed_node_paths)) != 1:
+            for path in self.ci_.changed_node_paths:
+                print("   changed node path " + path);
+            assert False, "Expected 1 changed path but found " + str(len(list(self.ci_.changed_node_paths)))
+    
+        self.ci_.resume("/" + test + "/f1/t2")
+        self.sync_local() 
+        if len(list(self.ci_.changed_node_paths)) != 1:
+            for path in self.ci_.changed_node_paths:
+                print("   changed node path " + path);
+            assert False, "Expected 1 changed path but found " + str(len(list(self.ci_.changed_node_paths)))
+            
+        self.ci_.suspend("/" + test  )  # stop  downstream test from re-starting this
+
+    
+    def test_gui(self):   
+        self.ci_.delete_all() # start fresh
+        self.test_version()
+        PrintStyle.set_style( Style.STATE ) # show node state 
+        self.test_client_get_server_defs()             
+                 
+        self.test_client_restart_server()             
+        self.test_client_halt_server()             
+        self.test_client_shutdown_server()   
+             
+        self.test_client_load_in_memory_defs()             
+        self.test_client_load_from_disk()             
+        self.test_client_checkpt()             
+        self.test_client_restore_from_checkpt()             
+                  
+        self.test_client_reload_wl_file()             
+          
+        self.test_client_run()  
+        self.test_client_run_with_multiple_paths()     
+        self.test_client_requeue()             
+        self.test_client_requeue_with_multiple_paths()             
+        self.test_client_free_dep()              
+         
+        self.test_client_suites()
+        self.test_client_ch_suites()  
+        self.test_client_ch_register()             
+        self.test_client_ch_drop()             
+        self.test_client_ch_drop_user()             
+        self.test_client_ch_add()             
+        self.test_client_ch_auto_add()             
+        self.test_client_ch_remove()             
+                    
+        self.test_client_get_file()             
+        self.test_client_alter_add() 
+        self.test_client_alter_delete() 
+        self.test_client_alter_change() 
+        self.test_client_alter_flag() 
+       
+        self.test_client_force()             
+        self.test_client_replace(False)             
+        self.test_client_replace(True)             
+         
+        self.test_client_suspend()             
+        self.test_client_suspend_multiple_paths()             
+        self.test_client_resume()             
+        self.test_client_resume_multiple_paths()             
+        self.test_client_delete_node()             
+        self.test_client_delete_node_multiple_paths()             
+         
+        self.test_client_check()  
+        self.test_client_check_defstatus()  
+         
+        self.test_ECFLOW_189()         
+        self.test_ECFLOW_199()         
+
+if __name__ == "__main__":
+    
+    DESC = """Will run various tests on the server. These will be used to test the GUI
+              This assumes that gui has been set to sync every second, as this will allows changes
+              in the server to be reflected in the GUI.
+              The test will sleep for sync_sleep seconds, after each change to the server.
+              This should allow GUI (1 second poll), to see the effects of this test.
+              To debug this tests, just set sync_sleep = 0, this will also preserve the test data.
+                 - Test data is created in directory: test_gui, this will deleted at the end of the test.
+                 - Assumes includes head.h and tail.h are in CWD + /libs/pyext/test/data/includes
+                 - We will look for the ecflow_client in the embedded child commands in the generated scripts, 
+                   o first look in the current cmake build tree of the ecflow module(this may no longer exist)
+                   o Next will use /usr/local/apps/ecflow/ with same version as this ecflow python api *IF* it exists
+                   o Finally use 'ecflow_client' hence will expect to find it on $PATH, *ON* the server environment
+                   To override this use --ecflow_client=/path/to/your/ecflow_client
+              Usage:
+                   TestGui.py --host <hostname> --port <portname> --time <sec> --sync_sleep <sec> --ecflow_client <path>
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--host', default="localhost",   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default="3141",   
+                        help="The port on the host, defaults to 3141")
+    PARSER.add_argument('--time', default=0,   
+                        help="How long to run the tests in seconds. default is 0, which is one test loop")
+    PARSER.add_argument('--sync_sleep', type=int,default=4,   
+                        help="Time to wait after sync_local. Allow GUI to refresh. Set to 0 for debug.")
+    PARSER.add_argument('--ecflow_client',default="",   
+                        help="Path to ecflow_client.")
+    ARGS = PARSER.parse_args()
+    print ARGS   
+    if ARGS.ecflow_client != "":
+        if not os.path.exists(ARGS.ecflow_client):
+            print("Could not find ecflow_client on path ",ARGS.ecflow_client)
+            sys.exit(1)
+     
+    # ===========================================================================
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    tester = Tester(CL,ARGS)
+    try:
+        CL.ping() 
+        tester.clean_up_data()
+        tester.clean_up_server()
+        
+        count = 1
+        start_time = time.time()
+        while True:
+            tester.test_gui()
+            elapsed = int(time.time() - start_time)
+            print "======================================================"
+            print "elapsed time :",elapsed, "s loop:",count
+            print "======================================================"
+            count += 1
+            if elapsed > int(ARGS.time):
+                break
+                
+    except RuntimeError, ex:
+        print "Error: " + str(ex)
+        print "Check host and port number are correct."
+
+    # When debugging keep test data.
+    if ARGS.sync_sleep != 0:
+        tester.clean_up_server()
+        tester.clean_up_data()
diff -pruN 5.12.4-1/libs/pyext/samples/TestJobGenPerf.py 5.13.0-1/libs/pyext/samples/TestJobGenPerf.py
--- 5.12.4-1/libs/pyext/samples/TestJobGenPerf.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/TestJobGenPerf.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,155 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# =============================================================================
+# Code for testing *any* definition
+#   Since any ad hoc definition will reference local directories in the
+#   ECF_ variables, we need to remove them and inject our own.
+#
+#   This test was created aid the performance testing of job generation
+#   It is tied to ANode/parser/test/TestJobGenPerf.cpp
+# =============================================================================
+import ecflow
+import os       # for getenv
+import sys
+import shutil   # used to remove directory tree
+import argparse # for argument parsing     
+
+def delete_variables_affecting_job_generation(node): 
+    """delete customer related ECF variables, these will point to directories
+       that don't exist. Its ok we will regenerate our own local ones"""
+    var = node.find_variable("ECF_HOME")
+    if not var.empty() :  
+        node.delete_variable("ECF_HOME")    
+    var = node.find_variable("ECF_FILES")
+    if not var.empty() :  
+        node.delete_variable("ECF_FILES")    
+    var = node.find_variable("ECF_INCLUDE")
+    if not var.empty() :  
+        node.delete_variable("ECF_INCLUDE")    
+    var = node.find_variable("ECF_JOB_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_JOB_CMD")    
+    var = node.find_variable("ECF_KILL_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_KILL_CMD")    
+    var = node.find_variable("ECF_STATUS_CMD")
+    if not var.empty() :  
+        node.delete_variable("ECF_STATUS_CMD")    
+    var = node.find_variable("ECF_OUT")
+    if not var.empty() :  
+        node.delete_variable("ECF_OUT")    
+      
+def traverse_container(node_container):
+    """Recursively traverse definition node hierarchy and delete
+       the variables that affect job generation.
+    """
+    delete_variables_affecting_job_generation(node_container)
+    for node in node_container.nodes:
+        delete_variables_affecting_job_generation(node)
+        if not isinstance(node, ecflow.Task):
+            traverse_container(node)  
+    
+if __name__ == "__main__":
+    
+    DESC = """Will allow any definition to be loaded and played on the server
+            This is done by:
+            o Remove existing ECF_ variables that affect job generation. 
+              i.e variables that refer to customer specific directories are removed
+            o Allows ECF_HOME to specified, defaults to ./CUSTOMER/ECF_HOME
+            o Generates the scripts(.ecf files) automatically based on the definition.
+              i.e if a task has events,meters,labels then the client request for these are
+              automatically injected in the generated .ecf script files
+            o Will clear out existing data both on disk and on the server to allow 
+              multiple re-runs of this script. ** If this is an issue please use
+              a test server **
+            This programs assumes that ecflow module is accessible.
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('defs_file', 
+                        help="The definition file")
+    PARSER.add_argument('--ecf_home', default="/var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf/ECF_HOME",
+                        help="Directory to be used for generated scripts(ECF_HOME), defaults to /var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf/ECF_HOME")
+    PARSER.add_argument('--verbose', nargs='?', default=False, const=True, type=bool,
+                        help="Show verbose output")
+    ARGS = PARSER.parse_args()
+    ARGS.defs_file = os.path.expandvars(ARGS.defs_file) # expand references to any environment variables
+    print(ARGS)    
+    
+    # If running on local work space, use /libs/pyext/test/data/CUSTOMER/ECF_HOME as ecf_home
+    if not ARGS.ecf_home:
+        if os.getenv("WK") is None:
+            print("No ecf_home specified. Please specify a writable directory")
+            sys.exit(1)
+        ARGS.ecf_home = "/var/tmp/ma0/ECFLOW_TEST/TestJobGenPerf/ECF_HOME"
+        if ARGS.verbose:
+            print("Workspace is defined") 
+            print("using /Client/bin/gcc\-4.5/debug/ecflow_client")
+
+    print("Using ECF_HOME=" + ARGS.ecf_home)
+    print("removing directory " + ARGS.ecf_home)
+    try:
+        shutil.rmtree(ARGS.ecf_home)   
+    except:
+        pass   
+        
+    if not os.path.exists(ARGS.ecf_home): 
+        print(ARGS.ecf_home + " directory does not exist, creating")
+        os.makedirs(ARGS.ecf_home)
+
+    print("\nloading the definition from the input arguments(" + ARGS.defs_file + ")\n")
+    
+    try:
+        DEFS = ecflow.Defs(ARGS.defs_file)
+    except RuntimeError as ex:
+        print("   ecflow.Defs(" + ARGS.defs_file + ") failed:\n" + str(ex))
+        sys.exit(1)
+    
+    if ARGS.verbose: 
+        print("remove test data associated with the DEFS, so we start fresh, Allows rerun")
+    for suite in DEFS.suites:
+        dir_to_remove = ARGS.ecf_home + suite.get_abs_node_path()
+        if ARGS.verbose: 
+            print("   Deleting directory: " + dir_to_remove + "\n")
+        shutil.rmtree(dir_to_remove, True)  
+        
+    if ARGS.verbose: 
+        print("remove remote reference to ECF_HOME and ECF_INCLUDE, since we inject or own\n")
+    for suite in DEFS.suites:
+        print("add variables required for script generation, for all suites\n")
+        traverse_container(suite)
+  
+        suite.add_variable("ECF_HOME", ARGS.ecf_home)
+        suite.add_variable("ECF_INCLUDE", ARGS.ecf_home + "/includes")
+        suite.add_variable("ECF_CLIENT_EXE_PATH", os.getenv("WK") + "/Client/bin/gcc\-4.8/debug/ecflow_client")
+        suite.add_variable("SLEEP", "10")  # not strictly required since default is 1 second
+
+
+    
+    # ecflow.PrintStyle.set_style(ecflow.Style.STATE)
+    #if ARGS.verbose: 
+    #print DEFS
+    DEFS.generate_scripts()
+
+    if ARGS.verbose: 
+        print("\nchecking script file generation, pre-processing & variable substitution\n")
+    JOB_CTRL = ecflow.JobCreationCtrl()
+    DEFS.check_job_creation(JOB_CTRL)       
+    assert len(JOB_CTRL.get_error_msg()) == 0, JOB_CTRL.get_error_msg()
+    
+    
+    newDefs = ARGS.ecf_home + "/../" + os.path.basename(ARGS.defs_file)
+    print("Saving modified defs as " + newDefs) 
+    DEFS.save_as_defs(newDefs)
diff -pruN 5.12.4-1/libs/pyext/samples/TestServerGetDefs.py 5.13.0-1/libs/pyext/samples/TestServerGetDefs.py
--- 5.12.4-1/libs/pyext/samples/TestServerGetDefs.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/TestServerGetDefs.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# This test is a simple client that, repeatedly calls gets defs
+# This is used to stress test the server to determine how many defs
+# can be called before the server gets overloaded
+
+import datetime
+import time, sys
+from ecflow import Client   
+      
+def main(ci,inc = 2):
+    while True:
+        start_time = datetime.datetime.now()
+        try:
+            ci.get_server_defs() 
+        except RuntimeError as e : 
+            print("Error:" + str(e))
+
+        print("get_server_defs took: " + str(datetime.datetime.now() - start_time))
+        time.sleep(inc)
+
+if __name__ == "__main__":
+
+    numargs = len(sys.argv) - 1
+    #print "numargs = " + str(numargs)
+    #i = 0;
+    #while i < len(sys.argv):
+        #print "arg " + str(i) + ": " + sys.argv[i]
+        #i =  i + 1
+        
+    if  numargs > 3:
+        print("usage: " + sys.argv[0] + " host port  seconds_delay")
+        sys.exit(1)
+        
+    port = "3142"
+    host = "localhost"
+    inc  = 1
+    if numargs >= 1:  host = sys.argv[1];
+    if numargs >= 2:  port = sys.argv[2]
+    if numargs >= 3:  inc = int(sys.argv[3])
+        
+    #print "host(" + host + ") port(" + port + ") delay between get_server_defs(" + str(inc)   +")"
+
+    ci = Client(host,port)
+    ci.ping()    
+
+    main(ci,inc)
+    
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/samples/TestSyncLocalPerf.py 5.13.0-1/libs/pyext/samples/TestSyncLocalPerf.py
--- 5.12.4-1/libs/pyext/samples/TestSyncLocalPerf.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/TestSyncLocalPerf.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,65 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import time
+import argparse # for argument parsing  
+from ecflow import Client, debug_build
+
+def timing_decorator(function_to_time):
+    def scafold(*function_args):
+        # function_args is a tuple, the second argument is the suite name
+        start = time.time()
+        function_return = function_to_time(*function_args)
+        end = time.time()
+        print('%s function took %0.3f ms for %s' % (function_to_time.__name__, (end-start)*1000.0, function_args[1]))
+        return function_return
+    return scafold
+
+@timing_decorator
+def sync_local(ci,suite_name):
+    ci.sync_local()
+
+if __name__ == "__main__":
+    
+    DESC = """This test is use to show the performance of sync local on the given server
+              It should show that it is quicker to register and then sync_local()
+              as this limits the amount of data that needs to be down loaded from the
+              server.
+              Usage:
+                   TestSyncLocalPerf.py --host <hostname> --port <portname>  
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--host', default="localhost",   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default="3141",   
+                        help="The port on the host, defaults to 3141")
+    ARGS = PARSER.parse_args()
+    print(ARGS)   
+     
+    print("####################################################################")
+    print(("Test performance of sync local using " + Client().version() + " debug build(" + str(debug_build()) +")"))
+    print("####################################################################")
+
+    CL = Client(ARGS.host, ARGS.port)
+    sync_local(CL,"* All suites *")   # timing for downloading all suites
+    print("")
+
+    suites = CL.get_defs().suites
+    for suite in suites:
+        CL.ch_register(False,[suite.name()])
+        
+        sync_local(CL,suite.name()) # time this
+        
+        CL.ch_drop()  # drop the last registered handle
+            
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/samples/add_stdexept_include.py 5.13.0-1/libs/pyext/samples/add_stdexept_include.py
--- 5.12.4-1/libs/pyext/samples/add_stdexept_include.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/add_stdexept_include.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+# find all cpp file that have std::runtime_error.
+# if these file dont have #include <stdexcept> add it as the first include
+
+import os,fnmatch
+
+def all_files(root, patterns='*', single_level=False, yield_folders=False):
+    """Expand patterns from semi-colon separated string to list"""
+    patterns = patterns.split(';')
+    for path, subdirs, files in os.walk(root):
+        if yield_folders:
+            files.extend(subdirs)
+        files.sort()
+        for name in files:
+            for pattern in patterns:
+                if fnmatch.fnmatch(name,pattern):
+                    yield os.path.join(path, name)
+                    break
+        if single_level:
+            break    
+        
+for cpp_file in all_files('.', '*.cpp'):
+    if 'cereal' in cpp_file:
+        continue
+    #print(cpp_file)
+    file_obj = open(cpp_file,'r')
+    try:
+        list_of_all_lines = file_obj.readlines()
+        
+        has_runtime_error = False
+        has_correct_include = False
+        for line in list_of_all_lines:
+            if 'std::runtime_error' in line:
+                has_runtime_error = True
+            if '#include <stdexcept>' in line:
+                has_correct_include = True
+                
+        if has_runtime_error:
+            #print(cpp_file, " uses std::runtime_error ", has_correct_include )
+            if not has_correct_include:
+                print(cpp_file," modifying")
+                # add #include <stdexcept>
+                added_include = False
+                new_list = []
+                for line in list_of_all_lines:
+                    if not added_include and '#include' in line:
+                        new_list.append('#include <stdexcept>\n')
+                        added_include = True
+                    new_list.append(line)
+                    
+                changed_file = open(cpp_file,'w')
+                changed_file.writelines(new_list)
+                changed_file.close()
+    finally:
+        file_obj.close()
+        
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/samples/api/README 5.13.0-1/libs/pyext/samples/api/README
--- 5.12.4-1/libs/pyext/samples/api/README	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/api/README	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2 @@
+This folder contains an example of extending the ecflow python API.
+It adds another convenience layer, that is used by operations.
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/samples/api/ecf.py 5.13.0-1/libs/pyext/samples/api/ecf.py
--- 5.12.4-1/libs/pyext/samples/api/ecf.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/api/ecf.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2603 @@
+#!/usr/bin/env python
+# coding=utf-8
+# This software is provided under the ECMWF standard software license agreement.
+# file deepcode ignore PythonConstantBinaryExpression: legacy
+""" a layer over raw ecflow api
+
+use 'export ECF_DEBUG_LEVEL=10' to remove warning message related to
+variables overwrite
+
+specialisation module for ecFlow nodes/attributes:
+initially it was simple derivation
+then it is composition
+
+
+https://pypi.python.org/pypi/anytree
+pip install anytree --user
+
+20180126 https://www.python.org/dev/peps/pep-0343/
+"""
+from __future__ import print_function    # (at top of module)
+import sys
+import pwd
+import os
+import unittest
+try:
+    import ecflow
+except ImportError:
+    loc = "/usr/local/apps/ecflow/current/lib/python2.7/site-packages/ecflow"
+    sys.path.append(loc)  # centre
+    loc = "/usr/local/lib/python2.7/site-packages"
+    sys.path.append(loc)  # elearning
+    import ecflow
+ecflow.Ecf.set_debug_level(3)
+global DEFS
+
+DEFS = ecflow.Defs()
+# DEBUG = True
+DEBUG = False
+DECORATE = "ALL"
+# DECORATE = "ONLY_TRIGGER"
+# DECORATE = "NO_TRIGGER"
+# DECORATE = "ONLY_EVENT"
+# DECORATE = "NO_ATTRIBUTE"
+
+USE_TIME = True
+USE_LATE = False
+USE_TRIGGER = True
+USE_LIMIT = True
+CPUTIME = True
+USE_VERIFY = True
+
+
+class DefError(Exception):
+    pass
+
+
+if DECORATE == "NO_TRIGGER":
+    USE_TRIGGER = False
+    USE_LIMIT = True
+    USE_EVENT = True
+elif DECORATE == "ALL":
+    USE_TRIGGER = True
+    USE_LIMIT = True
+    USE_EVENT = True
+else:
+    raise DefError
+
+
+def get_username():
+    return pwd.getpwuid(os.getuid())[0]
+
+
+def get_uid():
+    return pwd.getpwnam(get_username()).pw_uid
+
+
+home = os.getenv("HOME") + "/ecflow_server"
+user = os.getenv("USER")
+
+ECF_PORT = os.getenv("ECF_PORT", 1500 +
+                     int(pwd.getpwnam(get_username()).pw_uid))
+ECF_HOME = os.getenv("ECF_HOME", "localhost")
+CLIENT = ecflow.Client(ECF_HOME + ":%s" % ECF_PORT)  # PYTHON CLIENT
+deployed = []
+
+
+def deploy(script, pathname, extn=".ecf"):
+    if pathname in deployed:
+        return  # create once
+    else:
+        deployed.append(pathname)
+    if extn in pathname:  # surround .ecf with head, tail:
+        script = "%include <head.h>\n" + script + "\n%include <tail.h>"
+    with open(pathname, 'w') as destination:  # overwrite!
+        print(script, file=destination)
+        print("#MSG: created", pathname)
+# deploy("echo acq %TASK%", files + acq + extn)  # create wrapper
+# deploy("ecflow_client --label info %TASK%", files + post + extn)
+
+
+###################################################################################################
+head_h = """#!%SHELL:/bin/bash%
+#set -e # stop the shell on first error
+#set -u # fail when using an undefined variable
+#set -x # echo script lines as they are executed
+
+# Defines the variables that are needed for any communication with ECF
+export ECF_PORT=%ECF_PORT%    # The server port number
+export ECF_HOST=%ECF_HOST%    # where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+export ECF_RID=$$             # record the process id. Also used for
+                              # zombie detection
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%   # if server is SSL make sure client is
+fi
+
+# Define the path where to find ecflow_client
+# make sure client and server use the *same* version.
+# Important when there are multiple versions of ecFlow
+export PATH=/usr/local/apps/ecflow/%ECF_VERSION%/bin:$PATH
+export PATH=$PATH:/usr/local/apps/ecflow/bin:/usr/local/bin
+
+# Define a error handler
+ERROR() {
+   set +e                      # Clear -e flag, so we don't fail
+   wait                        # wait for background process to stop
+   ecflow_client --abort=trap  # Notify ecFlow that something went
+                               # wrong, using 'trap' as the reason
+   trap 0                      # Remove the trap
+   exit 0                      # End the script
+}
+
+# Tell ecFlow we have started
+ecflow_client --init=$$
+set -eux
+"""
+
+tail_h = """
+set +x
+wait           # wait for background process to stop
+ecflow_client --complete  # Notify ecFlow of a normal end
+trap 0                    # Remove all traps
+exit 0                    # End the shell
+"""
+
+
+def create_head_and_tail(ecf_home=None, head="head.h", tail="tail.h"):
+    if ecf_home is None:
+        HOME = os.getenv("HOME")
+        ecf_home = HOME + "/ecflow_server/include/"
+
+    if not os.path.exist(head):
+        with open(ecf_home + head, 'w') as fip:
+            write(head_h, file=fip)
+
+    if not os.path.exist(tail):
+        with open(ecf_home + tail, 'w') as fip:
+            write(tail_h, file=fip)
+
+
+class CWN(object):
+    """ CWN is for current working node
+    so that new attributes and node are attached to it,
+    when there is wish not to use .add() FP syntax """
+
+    __CDP = False
+    __CWN = []
+
+    @classmethod
+    def cdp(cls, active=False):
+        CWN.__CDP = active
+        if active and CWN.is_empty():
+            return
+        if DEBUG:
+            print("#DBG: CWN reset")
+        CWN.__CWN = []
+
+    @classmethod
+    def is_empty(cls):
+        return len(CWN.__CWN) == 0
+
+    @classmethod
+    def pop(cls):
+        if CWN.is_empty():
+            return
+        if DEBUG:
+            print("#BDG: pop")
+        CWN.__CWN.pop()
+
+    @classmethod
+    def last(cls):
+        if CWN.is_empty():
+            return None
+        return CWN.__CWN[-1]
+
+    def __init__(self, item=None):
+
+        def name(item):
+            if DEBUG:
+                if type(item) in (Event, Meter, Label):
+                    print("#BDG:", type(item), "%s" % item.real)
+                elif type(item) in (Clock, ):
+                    print("#BDG:", type(item), "%s" % item.real)
+                else:
+                    print("#BDG:", type(item), item.real.name())
+
+        if item is None or not CWN.__CDP:
+            # print("#BDG: no item")
+            return
+
+        if type(item) == Suite and CWN.is_empty():
+            DEFS.add_suite(item.real)
+            CWN.__CWN.append(item)
+            print("#BDG: append suite", item.name())
+            return
+
+        if id(item) == id(CWN.last()):  # __eq__ is used for trigger str
+            return
+
+        if type(item) == Suite:
+            if not CWN.is_empty():
+                print("#WAR: changing CWN from", CWN.__CWN.name(), "to",
+                      item.name())
+            CWN.__CWN.append(item)
+        elif item is None:
+            pass
+        elif item.real is None:
+            pass
+        elif CWN.is_empty():
+            raise DefError("#ERR: no node!")
+        else:
+            if type(CWN.last()) == Task and type(item) in (Task, Family):
+                CWN.pop()
+            # print("#DBG:", CWN.last().name(), type(item))
+            name(item)
+            item.add_to(CWN.last())
+            if type(item) in (Task, Family):
+                # print("#DBG: append", item.name(), type(item))
+                CWN.__CWN.append(item)
+            # else: print("#DBG: add", type(item), "to", CWN.last().name())
+
+
+def obsolete():
+    if 1:
+        return
+    raise DefError
+
+
+def raise_int(arg):
+    if 0:
+        return
+    if "/none" in arg:
+        raise DefError("None!!!", arg)
+    if arg in ("1==0", "0==1", "1==1", "0==0"):
+        return
+    if arg[0] in ("0", "1", "2", "3", "4", "5", "6", "7", "8", "9"):
+        raise DefError("please add ./", arg)
+
+
+def set_raw_mode(kind=True):
+    import sms2ecf
+    sms2ecf.RAW_MODE = kind
+
+
+LINKTASK = False  # FD
+# LINKTASK = True  # RD mode v we turn task into families,
+# with a leaf a task matching script name
+
+
+def linktask(name, real="get", add=None, fam=None, task=True):
+    """ give a change to avoid UNIX links time consuming for maintenance, update
+    perforce git
+    name: original name
+    real: script/task wrapper name
+    add: attributes that shall be added to the leaf task,
+         eg Label, Event, Meter
+    """
+    if fam is None:
+        fam = name
+    try:
+        import parameters as ip
+        # if ip.USER == "rdx": global LINKTASK; LINKTASK = True  # acceptance
+        # if ip.USER == "emos": global LINKTASK; LINKTASK = False  # acceptance
+    except ImportError:
+        pass
+    if LINKTASK:
+        return Task(name)  # RD???
+    return Family(fam).add(
+        Task(real).add(add, If(task, Edit("TASK", name))))
+
+
+def translate(name, value=None):
+    """ Translate from sms to ecflow """
+    try:
+        import sms2ecf
+    except ImportError:
+        return name, value
+
+    def is_sms():
+        if sys.argv[-1] in ("sms", "ligarius"):
+            sms2ecf.ECF_MODE = "sms"
+            return True
+        return sms2ecf.ECF_MODE == "sms"
+    if is_sms():
+        sms2ecf.ECF_MODE = "sms"
+        return sms2ecf.translate(name, value)
+    return name, value
+
+
+# USE_EXTERN = 1
+# NO_EXTERN_ALONE = 0 # set to 1 for test/activate
+
+
+class Extern(object):
+    """ extern may be collected and added as soon as Defs is created """
+
+    def __init__(self, path):
+        # if type(path) not in (tuple, list, str): raise DefError(type(path))
+
+        if type(path) in (tuple, list):
+            for ppp in path:
+                Extern(ppp)
+
+        elif isinstance(path, str):
+            if DEBUG:
+                print("#MSG: extern", path)
+            if ".Extern" in path:
+                raise Exception
+            if ":" in path:
+                # define parent so user does not have to
+                Extern(path.split(":")[0])
+
+            if path == "":
+                pass
+            elif DEFS is not None:
+                if ".Extern" in path:
+                    raise DefError(type(path))
+                DEFS.add_extern(str(path))
+            else:
+                raise DefError
+
+        elif path is None:
+            pass
+
+        else:
+            raise DefError(type(path), path)
+
+    def add_to(self, node):
+        return None
+
+
+class State(object):
+    """ this class aims at affording a user the possibility to add Triggers as
+    t1 = Task("t1")
+    Task("ts").add(Trigger(t1 == COMPLETE))
+
+    SUBMITTED, ACTIVE, SUSPENDED, ABORTED, QUEUED, COMPLETE, UNKNOWN
+    are instance of this class.
+    """
+
+    def __init__(self, state):
+        """ store the status """
+        self.state = str(state)
+
+    def __str__(self):
+        """ translate into string """
+        return "%s" % self.state
+
+    def __protect(self, num):
+        if type(num[0]) == int:
+            return "./" + num
+        return num
+
+    def __eq__(self, arg):
+        """ when == is used,
+        we should care about task name starting with 0-9"""
+        if type(arg) == str:
+            return self.__protect(arg) + " == " + self.state
+        elif isinstance(arg, Node):
+            return arg.fullname() + " == " + self.state
+        elif isinstance(arg, ecflow.Node):
+            return arg.get_abs_node_path() + " == " + self.state
+        return False
+
+    def __ne__(self, arg):
+        """ aka != """
+        if type(arg) == str:
+            return self.protect(arg) + " != " + self.state
+        elif isinstance(arg, Node):
+            return arg.load.get_abs_node_path() + " != " + self.state
+        return False
+
+    def value(self):
+        """ return state """
+        return self.state
+
+    def eval(self, node):
+        """ return state """
+        return self.state == node.get_state()
+
+
+SUBMITTED = State("submitted")
+ACTIVE = State("active")
+SUSPENDED = State("suspended")
+ABORTED = State("aborted")
+QUEUED = State("queued")
+COMPLETE = State("complete")
+UNKNOWN = State("unknown")
+
+
+class Attribute(object):
+    """ generic attribute to be attached to a node"""
+
+    def __init__(self):
+        self.load = None
+        # CWN(self)
+
+    def __enter__(self):
+        CWN(self)
+
+    def __exit__(self, type, value, traceback):
+        pass
+    # def __exit__(self): pass
+
+    def add_to(self, node):
+        """ use polymorphism to attach attribute to a node"""
+        raise DefError("ERR: virtual class")
+
+    def __get_attr__(self, attr):
+        return getattr(self.load, attr)
+
+    @property
+    def real(self):
+        return self.load
+
+
+class Label(Attribute):
+    """wrap around label"""
+
+    def __init__(self, name, msg=""):
+        self.load = ecflow.Label(name, msg)
+        CWN(self)
+
+    def add_to(self, node):
+        """add_label"""
+        node.load.add_label(self.load)
+        return node
+
+
+class Meter(Attribute):
+    """wrap around meter"""
+
+    def __init__(self, name, beg, end, thr=None):
+        if thr is None:
+            thr = end
+        self.load = ecflow.Meter(name, beg, end, thr)
+        CWN(self)
+
+    def add_to(self, node):
+        """ add_meter"""
+        node.load.add_meter(self.load)
+        return node
+
+
+class Event(Attribute):
+    """ wrap around event"""
+
+    def __init__(self, name="", num=0):
+        if type(name) == str:
+            if " " in name:
+                num, name = name.split(" ")
+        try:
+            if int(num) > 100000:
+                num = ""
+        except:
+            pass
+        self.load = None
+        if type(name) is int and num == 0:
+            num = name
+            name = ""
+
+        if type(name) is int and type(num) == str:
+            self.load = ecflow.Event(name, num)
+        elif type(name) is str and type(num) == int:
+            self.load = ecflow.Event(num, name)
+        elif type(name) is str and type(num) == str:
+            if num == "":
+                self.load = ecflow.Event(name)
+            elif name == "":
+                self.load = ecflow.Event(num)
+            else:
+                self.load = ecflow.Event(int(num), name)  # print("#str str")
+        else:
+            self.load = ecflow.Event(name)
+        CWN(self)
+
+    def add_to(self, node):
+        """ add_event"""
+        for test in node.load.events:
+            if test.name() == self.load.name():
+                if (test.number() == self.load.number() and
+                        test.name() == self.load.name()):
+                    return
+                # else: raise Exception(test.number(), self.load.number(),
+                #                      test.name(), self.load.name())
+        node.load.add_event(self.load.number(), self.load.name())
+        return node
+
+
+class Inlimit(Attribute):
+    """ a class to host a path for a limit
+        silently ignore if USE_LIMIT is False,
+        (in debug mode) """
+
+    def __init__(self, fullpath, tokens=1):
+        self.load = None
+        if USE_LIMIT:
+            try:
+                (path, name) = fullpath.split(":")
+            except ValueError:
+                name = fullpath
+                path = ""
+            if name is None:
+                raise DefError
+            # if '-prod' in name: name = name.split('-')[0]  # vdiss-prod
+            if '-' in name:
+                name = name.replace('-', '_')
+            if "None" in path or "None" in name:
+                raise DefError(path, name, fullpath)
+            if " " in name:
+                name, tokens = name.split(" ")
+            self.load = ecflow.InLimit(name, path, int(tokens))
+            self.path_ = path
+            self.name_ = name
+            self.tokens_ = tokens
+            CWN(self)
+
+    def add_to(self, node):
+        """ add_inlimit"""
+        if not USE_LIMIT:
+            return
+        if self.load is None:
+            raise DefError
+        # if type(node.real) in (ecflow.Task, ecflow.Family):
+        for dup in node.real.inlimits:
+            # print(dup.name, self.load.name())
+            if (dup.name() == self.load.name() and
+                    dup.path_to_node() == self.load.path_to_node()):
+                return None
+        node.load.add_inlimit(self.load)
+        return node
+
+    def value(self):
+        """ get limit fullpath-name """
+        return self.path_ + ":" + self.name_
+
+    def name(self):
+        """ get limit name """
+        return self.name_
+
+
+class InLimit(Inlimit):
+    pass
+
+
+def item_to_string(prev, index, name):
+    """ index not used... """
+    if name is None:
+        return ""
+    if name == "":
+        return prev
+    if "<main>" in name:
+        raise DefError
+    if "==" in name:
+        return name
+    if len(name) > 0:
+        if name[0].isdigit():
+            pre = "./"  # "0123456789":
+            name = pre + name
+    if prev is None or prev == "":
+        if ':' in name or name == "":
+            return name
+        else:
+            return "%s == complete" % name
+    if ' or ' in name:
+        if "complete" in name:
+            return prev + "%s" % name
+        elif ":" in name:
+            return prev + "%s" % name
+        else:
+            return prev + "%s == complete" % name
+    elif ':' in name:  # event: and x:1
+        return prev + " and %s" % name
+    elif 'complete' in name:  # complete: and x == complete
+        return prev + " and %s" % name
+    else:
+        return prev + " and %s == complete" % name
+
+
+class Trigger(Attribute):
+    """ add trigger (string, list of task names, or directly
+           expression and: and'ed (True) or or'ed (False) unk: add or
+           [name]==unknown for RD """
+
+    def __init__(self, expr, unk=False, anded=True):
+        self.expr = ""
+        self.load = None
+        if expr is None or expr == "":
+            return
+        if type(expr) == str:
+            if "%s" in expr:
+                raise DefError("ERR:", expr)
+            if "%d" in expr:
+                raise DefError("ERR:", expr)
+            self.expr = expr
+            try:
+                import parameters as ip
+                dim = len(ip.SELECTION)
+                for ploc in expr.split():
+                    if ploc[0] == '/' and ip.SELECTION != ploc[1:dim + 1]:
+                        if ploc in ("eq", "ne", "==", "!=", "and", "or",
+                                    "active", "complete", "queued", ):
+                            continue
+                        if ploc.isdigit():
+                            continue
+                        # Extern(ploc.replace("==complete", "").replace(")", ""))
+            except AttributeError:
+                pass
+            except ImportError:
+                pass
+            # NO_EXTERN_ALONE = 0 # set to 1 for test/activate
+            return
+        if type(expr) == tuple:
+            prep = list(expr)
+            expr = prep
+
+        if type(expr) == Task:
+            pnode = expr.fullname()
+            if pnode[0] != '/':
+                pnode = expr.name()
+            try:
+                import inc_common as ic
+                if ic.psel() not in pnode:
+                    pnode = expr.name()
+            except ImportError:
+                pass
+            # if 1: raise DefError("really?", pnode)
+            self.expr += item_to_string(None, 0, pnode)
+
+        elif type(expr) in (list, set, tuple):
+            for index, name in enumerate(expr):
+                if name is None:
+                    continue
+                pre = ""
+
+                if name is None:
+                    continue
+                if type(name) in (set, list, tuple):
+                    print("#WAR: please avoid list in list", expr, name)
+                    if 1:
+                        print("#WAR: list in list")
+                    elif 1:
+                        raise DefError(
+                            "please avoid list in list", expr, name)
+                    name = ""
+                    for index, another in enumerate(name):
+                        name += item_to_string(name, index, another)
+                elif type(name) in (Node, Task, Family, Suite):
+                    # if DEBUG: print(name.name())
+                    fullname = name.fullname()
+                    if fullname[0] == '/':
+                        try:
+                            import inc_common as ic
+                            if ic.psel() not in fullname:
+                                fullname = name.name()
+                        except:
+                            print("#WAR: trigger expcept")
+                    name = fullname
+                elif type(name) in (ecflow.Task, ecflow.Family):
+                    name = name.name()
+                elif type(name) == str:
+                    pass
+                else:
+                    raise DefError(type(name), name)
+
+                if "==" in name:
+                    pass
+                elif len(name) > 0:
+                    # if "==" in name: pass
+                    # if "1==0" in name or "0==1" in name or "1==1" in name: pass
+                    if name[0].isdigit():
+                        pre = "./"  # "0123456789":
+
+                self.expr = item_to_string(self.expr, index, name)
+                continue
+
+        elif type(expr) in (ecflow.Expression,
+                            ecflow.PartExpression):
+            self.expr = ecflow.Expression(str(item))
+
+        elif type(expr) in (Family, Task):
+            fullname = expr.fullname()
+            if fullname[0] == '/':
+                try:
+                    import inc_common as ic
+                    if ic.psel() not in fullname:
+                        fullname = name.real.name()
+                except ImportError:
+                    print("#WAR: trigger expcept")
+            self.expr = fullname
+            # check full name is really full name, not /name
+            # print("#REM:", self.expr)
+            if self.expr == "/%s" % expr.name():
+                self.expr = expr.name()
+        else:
+            raise DefError("what? trigger?", type(expr))
+
+        if "YMD+1" in self.expr:
+            raise DefError(self.expr)
+        # self.load = "trigger"  # ecflow.Trigger(self.expr)
+        CWN(self)
+        # NO_EXTERN_ALONE = 0 # set to 1 for test/activate
+
+    def expression(self):
+        return self.expr
+
+    def add_to(self, node):
+        if self.expr is None or self.expr == "" or not USE_TRIGGER:
+            return None
+        if 0 and "/prod/wave" in "%s" % self.expr:
+            raise DefError(self.expr, node.fullname())  # help DEBUG
+
+        if "trigger " in self.expr:
+            raise DefError(self.expr)
+        if "%s" in self.expr:
+            raise DefError(self.expr)
+        if "%d" in self.expr:
+            raise DefError(self.expr)
+        # if "make/nemoconst" in self.expr: raise DefError(self.expr)
+        if node.load.get_trigger() is None:
+            node.load.add_trigger(self.expr)
+        else:
+            node.load.add_part_trigger(ecflow.PartExpression(self.expr, True))
+        return node
+
+
+class TriggerImpossible(Trigger):
+    """attribute to be added to node when it is not expected to run any task"""
+
+    def __init__(self):
+        """ add an 'impossible trigger', for a task not to run """
+        super(TriggerImpossible, self).__init__("1==0")
+
+
+class TriggerAlways(Trigger):
+    """attribute to be added to node when it is not expected to run any task"""
+
+    def __init__(self):
+        """ add an 'impossible trigger', for a task not to run """
+        super(TriggerAlways, self).__init__("1==1")
+
+
+class Complete(Trigger):
+    """ class to host complete expression, added later to a node"""
+
+    def __init__(self, expr, unk=False, anded=False):
+        if sys.version_info.major == 2:
+            super(Complete, self).__init__(expr, unk, anded)
+        else:
+            super().__init__(expr, unk, anded)  # python3
+
+    def add_to(self, node):
+        if USE_TRIGGER and self.expr is not None:
+            if "%s" in self.expr:
+                raise DefError
+            if "%d" in self.expr:
+                raise DefError
+            node.load.add_complete(self.expr)
+        return node
+
+
+class CompleteAlways(Complete):
+    """ attribute """
+
+    def __init__(self):
+        """ always True as soon as evaluated """
+        super(CompleteAlways, self).__init__("1==1")
+
+
+class Clock(Attribute):
+    """ wrapper to add clock """
+
+    def __init__(self, arg="24:00", hybrid=0):
+        self.load = None
+        if arg == "real":
+            self.load = ecflow.Clock(False)
+        elif arg == "hybrid":
+            self.load = ecflow.Clock(True)
+        elif type(arg) == str:
+            hybrid = "hybrid" in arg
+            if "hybrid " in arg:
+                arg = nat(arg, "hybrid")
+                hybrid = 1
+            elif "real " in arg:
+                arg = nat(arg, "real")
+                hybrid = 0
+            if " -s" in arg:
+                arg = arg.replace(" -s", "")
+                sync = True
+            else:
+                sync = False
+            hhh, mmm, sss = [0, 0, 0]
+            if 1:
+                if "." in arg and " " in arg:
+                    ymd, hhh = arg.split(" ")
+                    ddd, mmm, yyy = ymd.split('.')
+                    self.load = ecflow.Clock(int(ddd), int(mmm), int(yyy),
+                                             hybrid)
+                    rel = "+" in hhh
+                    if hhh != "":
+                        self.load.set_gain_in_seconds(int(hhh), rel)
+                elif "+" in arg:
+                    rel = "+" in arg
+                    self.load = ecflow.Clock(hybrid)
+                    self.load.set_gain_in_seconds(int(arg), rel)
+                elif arg is None and hybrid is False:
+                    pass
+                elif arg == "None" and hybrid is False:
+                    pass
+                else:
+                    rel = "+" in arg
+                    from datetime import date
+                    if 0:
+                        ymd = "%s" % date.today()
+                        yyy, mmm, ddd = ymd.split("-")
+                        self.load = ecflow.Clock(
+                            int(ddd), int(mmm), int(yyy), hybrid)
+                    else:
+                        self.load = ecflow.Clock(hybrid)
+                    if arg != "":
+                        self.load.set_gain_in_seconds(int(arg), rel)
+            # except ValueError:
+            #    print("#Value Error", arg, hybrid)
+            #    self.load = ecflow.Clock(hybrid)
+        else:
+            self.load = ecflow.Clock(arg, hybrid)
+
+        if arg is None and hybrid is False:
+            self.load = None
+        CWN(self)
+
+    def add_to(self, node):
+        if type(node) != Suite:
+            print("#WAR: clock can only be attached to suite node,\n",
+                  "#WAR: clock is ignored")
+            return
+        if node.real.get_clock() is None and self.load is not None:
+            node.load.add_clock(self.load)
+        return node
+
+
+class Autocancel(Attribute):
+    """ wrapper to add time """
+
+    def __init__(self, arg):
+        if type(arg) == str:
+            if ':' in arg:  # hh:mm +hh:mm
+                hhh, mmm = arg.split(':')
+                rel = '+' in arg
+                self.load = ecflow.Autocancel(int(hhh), int(mmm), rel)
+            else:
+                self.load = ecflow.Autocancel(int(arg))
+        else:
+            self.load = ecflow.Autocancel(arg)  # days
+
+    def add_to(self, node):
+        node.load.add_autocancel(self.load)
+        return node
+
+
+class AutoCancel(Autocancel):
+    pass
+
+
+class AutoMigrate(Attribute):
+    pass
+
+
+ECG = ".ecg"
+
+
+class Script(Attribute):
+
+    def __init__(self, script, extn=ECG):
+        self._script = script
+        self.extn = extn
+
+    def add_to(self, node):
+        print("#WAR: Script attribute, not yet ... ignored")
+        return node
+
+
+class Verify(Attribute):
+    """ wrapper to add time """
+
+    def __init__(self, arg):
+        if "verify " in arg:
+            arg = nat(arg, "verify")
+        y, z = str(arg).split(":")
+        kinds = {
+            "aborted": ecflow.State.aborted,
+            "complete": ecflow.State.complete,
+            "active": ecflow.State.active,
+            "submitted": ecflow.State.submitted,
+            "unknown": ecflow.State.unknown,
+            "queued": ecflow.State.queued,
+        }
+        self.load = ecflow.Verify(kinds[y], int(z))
+
+    def add_to(self, node):
+        if USE_VERIFY and self.load is not None:
+            node.load.add_verify(self.load)
+        return node
+
+
+class Time(Attribute):
+    """ wrapper to add time """
+
+    def __init__(self, arg):
+        self.load = arg
+
+    def add_to(self, node):
+        if USE_TIME and self.load is not None:
+            node.load.add_time(self.load)
+        return node
+
+
+class Today(Time):
+    """ wrapper to add time """
+
+    def add_to(self, node):
+        if USE_TIME and self.load is not None:
+            node.load.add_today(self.load)
+        return node
+
+
+class Cron(Time):
+    """ wrapper to add time """
+
+    def __init__(self, bes, wdays=None, days=None, months=None):
+        import argparse
+        self.load = ecflow.Cron()
+
+        if not ("-w" in bes or
+                "-m" in bes or
+                "-d" in bes or
+                "-s" in bes):
+            self.load.set_time_series(bes)
+            return
+
+        parser = argparse.ArgumentParser()
+        parser.add_argument("-w", nargs=1, default=None, help="weekdays")
+        parser.add_argument("-m", nargs=1, default=None, help="months")
+        parser.add_argument("-d", nargs=1, default=None, help="days")
+        parser.add_argument("-s", action="store_true", help="sync")
+        parser.add_argument("begin", nargs='+', help="begin")
+        if " -s" in bes:
+            bes = bes.replace(" -s", "")
+            sync = True
+        else:
+            sync = False
+        parsed = parser.parse_args(bes.split())
+
+        if wdays is not None:
+            self.load.set_week_days(wdays)
+        if parsed.w:
+            self.load.set_week_days([
+                int(x) for x in str(parsed.w[0]).split(',')])
+        if days is not None:
+            self.load.set_day_of_month(days)
+        if parsed.d:
+            self.load.set_days_of_month([
+                int(x) for x in parsed.d[0].split(',')])
+        if months is not None:
+            self.load.set_months(month)
+        if parsed.m:
+            self.load.set_months([
+                int(x) for x in parsed.m[0].split(',')])
+        self.load.set_time_series(' '.join(parsed.begin))
+
+    def add_to(self, node):
+        if USE_TIME and self.load is not None:
+            node.load.add_cron(self.load)
+        else:
+            print("#WAR: ignoring: %s" % self.load)
+        return node
+
+
+class Date(Time):
+    """ wrapper to add date """
+
+    def __init__(self, arg, mask=False):
+        super(Date, self).__init__(arg)
+        self.mask = mask
+
+    def add_to(self, node):
+        if USE_TIME and self.load is not None:
+            # ??? emos avoids dates, datasvc would not
+            if self.mask:
+                node.load.add_variable("DATEMASK", self.load)
+            else:
+                ddd, mmm, yyy = self.load.split('.')
+                if ddd == '*':
+                    ddd = 0
+                if mmm == '*':
+                    mmm = 0
+                if yyy == '*':
+                    yyy = 0
+
+                node.load.add_date(int(ddd), int(mmm), int(yyy))
+        return node
+
+
+class Day(Date):
+    """ wrapper to add day """
+
+    def add_to(self, node):
+        if not USE_TIME or self.load is None:
+            return
+        if isinstance(self.load, str):
+            days = {"monday": ecflow.Days.monday,
+                    "sunday": ecflow.Days.sunday,
+                    "tuesday": ecflow.Days.tuesday,
+                    "wednesday": ecflow.Days.wednesday,
+                    "thursday": ecflow.Days.thursday,
+                    "saturday": ecflow.Days.saturday,
+                    "friday": ecflow.Days.friday,
+
+                    "mon": ecflow.Days.monday,
+                    "sun": ecflow.Days.sunday,
+                    "tue": ecflow.Days.tuesday,
+                    "wed": ecflow.Days.wednesday,
+                    "thu": ecflow.Days.thursday,
+                    "sat": ecflow.Days.saturday,
+                    "fri": ecflow.Days.friday, }
+            node.load.add_day(ecflow.Days(days[self.load]))
+        else:
+            node.load.add_day(ecflow.Days(self.load))
+        return node
+
+
+class Defstatus(Attribute):
+    """ add defstatus attribute"""
+
+    def __init__(self, kind):
+        if type(kind) == str:
+            kinds = {"suspended": ecflow.DState.suspended,
+                     # "halted": ecflow.DState.halted, "shutdown": ecflow.DState.shutdown,
+                     "aborted": ecflow.DState.aborted,
+                     "complete": ecflow.DState.complete,
+                     "active": ecflow.DState.active,
+                     "submitted": ecflow.DState.submitted,
+                     "unknown": ecflow.DState.unknown,
+                     "queued": ecflow.DState.queued, }
+            self.load = kinds[kind]
+        elif type(kind) in (ecflow.DState, ):
+            self.load = kind
+        else:
+            raise DefError(type(kind), kind)
+
+    def add_to(self, node):
+        if type(node) in (Suite, Family, Task):
+            node.load.add_defstatus(self.load)
+        else:
+            node.add_defstatus(self.load)
+        return node
+
+
+SORT = False
+SORT = True
+
+
+def sorted_or_not(items, sort=False):
+    if SORT or sort:
+        return sorted(items)
+    return items
+
+
+class Limit(Attribute):
+    """ wrapper to add limit """
+
+    def __init__(self, name=None, size=1, inlimit=0):
+        self.name = name
+        self.size = int(size)
+        self.addi = inlimit
+
+    def add_to(self, node):
+        if USE_LIMIT and self.name is not None:
+            if type(self.name) is dict:
+                for name, size in sorted_or_not(list(self.name.items()),
+                                                sort=not LINKTASK):
+                    size = self.name[name]
+                    node.load.add_limit(name, size)
+                    if self.addi:
+                        node.load.add_inlimit(name)
+                    else:
+                        pass
+            else:
+                node.load.add_limit(self.name, self.size)
+                if self.addi:
+                    node.load.add_inlimit(name)
+        return node
+
+
+class Late(Attribute):
+    """ wrapper around late, to be add'ed to families and tasks """
+
+    def __init__(self, arg):
+        self.load = None
+        if not USE_LATE:
+            # print("#MSG: late is disabled")
+            return
+        sub = False
+        act = False
+        com = False
+        rel = False
+        self.load = ecflow.Late()
+        for item in arg.split(" "):
+            if item == "-s":
+                sub = True
+            elif item == "-c":
+                com = True
+            elif item == "-a":
+                act = True
+            else:
+                hour, mins = item.split(":")
+                rel = "+" in hour
+                if "+" in hour:
+                    hour = hour[1:]
+                if sub:
+                    self._add_sub(hour, mins)
+                elif com:
+                    self._add_com(hour, mins, rel)
+                elif act:
+                    self._add_act(hour, mins)
+                sub = False
+                act = False
+                com = False
+
+    def _add_sub(self, hour, mins):
+        """ submitted"""
+        self.load.submitted(ecflow.TimeSlot(int(hour), int(mins)))
+
+    def _add_com(self, hour, mins, rel):
+        """ complete"""
+        self.load.complete(ecflow.TimeSlot(int(hour), int(mins)), rel)
+
+    def _add_act(self, hour, mins):
+        """ active"""
+        self.load.active(ecflow.TimeSlot(int(hour), int(mins)))
+
+    def add_to(self, node):
+        if USE_LATE and self.load is not None:
+            if type(node) in (ecflow.Family, ecflow.Task):
+                node.add_late(self.real)
+            else:
+                node.real.add_late(self.real)
+        return node
+
+
+def python_true(key, val):
+    if "%s" % val == "True":
+        if key in ("HYPERTHREADING",
+                   "CLIM5YR",
+                   "FLEX_SUBMIT",
+                   "USE_HUGEPAGE"):
+            return  # OK
+        print("#WAR: really???", key, val)
+
+
+class Edit(Attribute):
+    """ dedicated class to enable variable addition with different
+    syntax """
+
+    def __init__(self, name, value=""):
+        self.load = ecflow.Edit(name, value)
+
+    def _set_tvar(self, key, val):
+        """ facilitate to load a ecflow suite to SMS, translating
+        variable names"""
+        keyt, edit = translate(str(key), str(val))
+        # if keyt == "SCHOST" and val == "ccb": raise DefError
+        if self.load is None:
+            self.load = ecflow.Variable(keyt, edit)
+        else:
+            next = self.next
+            self.next = Edit(keyt, edit, next)
+
+    def __init__(self, __a=None, __b=None, __next=None,
+                 *args, **kwargs):
+        self.load = None
+        self.next = __next
+
+        if len(args) > 0:
+            if type(args) == list:
+                for item in args.items():
+                    key = item.name()
+                    val = item.value()
+                    python_true(key, val)
+                    self._set_tvar(item.name(), item.value())
+            elif type(args) == tuple:
+                for key, val in list(args.items()):
+                    python_true(key, val)
+                    self._set_tvar(key, val)
+            else:
+                raise DefError
+        if len(kwargs) > 0:
+            for key in sorted_or_not(list(kwargs.keys())):
+                val = kwargs[key]
+                python_true(key, val)
+                self._set_tvar(key, val)
+        if type(__a) == dict:
+            for key in sorted_or_not(list(__a.keys())):
+                val = __a[key]
+                python_true(key, val)
+                self._set_tvar(key, val)
+        elif type(__a) == tuple:
+            raise DefError
+        elif type(__a) == list:
+            raise DefError
+        elif type(__a) == Variable:
+            self.load = __a
+        elif __a is not None and __b is not None:
+            python_true(__a, __b)
+            self._set_tvar(__a, __b)
+        elif __a is None and __b is None:
+            pass
+        else:
+            raise DefError(__a, __b, __next, args, kwargs)
+
+    def add_to(self, node):
+        if self.load is not None:
+            edit = "%s" % self.load
+            if "CPUTIME" in edit and not CPUTIME:
+                pass
+            if node in (Suite, Family, Task):
+                node.load.add_variable(self.load)
+            else:
+                node.add_variable(self.load)
+            if node.name() == "o" and "QUEUE 'emos" in edit:
+                raise DefError(node.name(), edit)  # intercept, DEBUG
+
+            if 1:  # try:  # Operators' request
+                labels = {"WSHOST": "infopws",
+                          "SCHOST": "infopsc",
+                          "HOST": "infophs", }
+                # if 'seas' in ip.SELECTION: pass
+                for key in list(labels.keys()):
+                    try:
+                        info = labels[key]
+                        msg = ""
+                        find = ""
+                        if "ECF_JOB_CMD" in edit:
+                            find = "%" + key + "%"
+                            info = "infopcmd"
+                            msg = key
+                        elif "ECF_KILL_CMD" in edit:
+                            find = "edit %s " % key
+                        if find != "" and find in edit:
+                            node.real.add_label(info, msg)
+                    except:
+                        print("#WAR: duplicated label", "edit", edit)
+        if self.next is not None:
+            self.next.add_to(node)
+        return node
+
+    def add(self, what):
+        print("#ERR: add???", "%s" % self.load)
+        if type(what) in (Suite, Family, Task):
+            raise DefError(what.fullname())
+        else:
+            raise DefError(type(what))
+
+
+class Variable(Edit):
+    pass
+
+
+class Variables(Edit):
+    pass
+
+
+class Repeat(Attribute):
+    """ repeat date/int/string/enum """
+
+    def __init__(self, name="YMD", start=20120101, end=21010101,
+                 step=1, kind="date"):
+        # print("repeat", name, "#", start, "#", end, "#", step, "#", kind)
+        if len(name) > 4:
+            if (name[:4] == "enum" or
+                name[:4] == "date" or
+                "string " in name or
+                name[:3] == "int" or
+                    "day " in name):
+                pars = name.split(" ")
+                kind = pars[0]
+                name = pars[1]
+                if "enum" in kind or "string" in kind:
+                    start = [i.strip("'").strip('"') for i in pars[2:]]
+                elif "int" in kind or "date" in kind:
+                    start = pars[2]
+                    if len(pars) > 3:
+                        end = pars[3]
+                    if len(pars) > 4:
+                        step = pars[4]
+
+        if kind in ("date", ):
+            self.load = ecflow.RepeatDate(
+                name, int(start), int(end), int(step))
+        elif "int" in kind:
+            self.load = ecflow.RepeatInteger(
+                name, int(start), int(end), int(step))
+        elif kind == "string":
+            if len(start) == 0:
+                raise Exception
+            self.load = ecflow.RepeatString(name, start)
+        elif "enum" in kind:
+            if len(start) == 0:
+                raise Exception
+            self.load = ecflow.RepeatEnumerated(name, start)
+        elif kind == "day":
+            self.load = ecflow.RepeatDay(step)
+        else:
+            self.load = None
+
+    def add_to(self, node):
+        if self.load is not None:
+            node.load.add_repeat(self.load)
+        return node
+
+
+class Zombie(Attribute):
+    """
+ |     ZombieAttr(ZombieType,ChildCmdTypes, ZombieUserActionType, lifetime)
+ |        ZombieType            : Must be one of ZombieType.ecf, ZombieType.path, ZombieType.user
+ |        ChildCmdType          : A list(ChildCmdType) of Child commands. Can be left empty in
+ |                                which case the action affect all child commands
+ |        ZombieUserActionType  : One of [ fob, fail, block, remove, adopt ]
+ |        int lifetime<optional>: Defines the life time in seconds of the zombie in the server.
+ |                                On expiration, zombie is removed automatically
+"""
+
+    def __init__(self, arg="ecf:remove:3600"):
+        if "zombie " in arg:
+            arg = nat(arg, "zombie")
+        typ, act, kid, num = arg.split(":")
+        types = ecflow.ZombieType.names  # ecf user path
+        kids = ecflow.ChildCmdType.names  # complete label init abort event wait
+        acts = ecflow.ZombieUserActionType.names  # adopt remove kill fob fail block
+        when = []
+        if kid == "":
+            pass
+        elif "," in kid:
+            for k in kid.split(","):
+                when.append(kids[k])
+        else:
+            when.append(kids[kid])
+
+        self.load = ecflow.ZombieAttr(types[typ], when, acts[act],
+                                      int(num))
+
+    def add_to(self, node):
+        """add_zombie"""
+        node.load.add_zombie(self.load)
+        return node
+
+
+def If(test=True, then=None, otow=None, *args):
+    """ enable Task("t1").add(If(test=(1==1),
+                                 then=Edit(ONE=1),
+                                 otow=Edit(TWO=2)))
+        appreciate that both branches are evaluated, using this If class
+        ie there is no 'dead code' as it is with python language 'if' structure
+
+        using If to distinguish od/rd mode request that both users share
+        the variables (parameter.py) and ecf.py
+
+        otow: on the other way?
+        """
+    if len(args) > 1:
+        try:
+            print("#ERR:", then.name())
+            print("#ERR:", otow.name())
+        except Exception as exc:
+            print("#ERR:", exc.args)
+        raise DefError("test",
+                       test, "\nthen\n",
+                       then, "\nelse",
+                       otow, "arg", args)
+    if test:
+        return then
+    return otow
+
+
+class Root(object):  # from where Suite and Node derive
+    """ generic tree node """
+
+    def __init__(self):
+        self.load = None  # to be filled with ecFlow item
+        # CWN(self)
+
+    @property
+    def real(self):
+        return self.load
+
+    def __enter__(self):
+        # CWN(self)
+        raise DefError("#ERR: this shall be overwritten by kid")
+
+    def __exit__(self, type, value, traceback):
+        CWN.pop()
+
+    def __get_attr__(self, attr):
+        return getattr(self.load, attr)
+
+    def get_parent(self):
+        return self.load.get_parent()
+
+    def __str__(self):
+        return self.fullname()
+
+    def __repr__(self):
+        return "%s" % self.load
+
+    def is_eq(self, node):
+        return super(self, self.__eq__), (self, node)
+
+    def __eq__(self, node):
+        if isinstance(self.load, ecflow.Node):
+            return "%s == " % self + str(node)
+        return self  # False
+
+    def __ne__(self, node):
+        if isinstance(self.load, ecflow.Node):
+            return "%s != " % self + str(node)
+        return False
+
+    def __and__(self, node):
+        if isinstance(self.load, ecflow.Node):
+            return "%s and " % self + str(node)
+        return False
+
+    def __or__(self, node):
+        if isinstance(self.load, ecflow.Alias):
+            return True
+        if isinstance(self.load, ecflow.Node):
+            return "%s or " % self + str(node)
+        return False
+
+    def get_abs_node_path(self):
+        return self.fullname()
+
+    def fullname(self):
+        """ simple syntax """
+        if isinstance(self.load, ecflow.Node):
+            return self.load.get_abs_node_path()
+        return str(self)
+
+    def repeat(self, name="YMD", start=20120101, end=20321212, step=1,
+               kind="date"):
+        """ add repeat attribute"""
+        if kind in ("date", "integer"):
+            self.add(Repeat(name, start, end, step, kind))
+        elif kind in ("string", "enumerated"):
+            self.add(Repeat(name, start, kind=kind))
+        elif kind == "day":
+            self.add(Repeat(step, kind="day"))
+        else:
+            raise DefError
+        return self
+
+    def defstatus(self, kind):
+        """ add defstatus attribute"""
+        status = kind
+        if type(kind) == str:
+            kinds = {  # "suspended": ecflow.DState.suspended,
+                "halted": ecflow.DState.halted, "shutdown": ecflow.DState.shutdown,
+                "aborted": ecflow.DState.aborted,
+                "complete": ecflow.DState.complete,
+                "active": ecflow.DState.active,
+                "submitted": ecflow.DState.submitted,
+                "unknown": ecflow.DState.unknown,
+                "queued": ecflow.DState.queued, }
+            status = kinds[kind]
+        elif type(kind) == ecflow.DState:
+            pass
+        else:
+            raise DefError("defstatus?")
+        self.load.add_defstatus(status)
+        return self
+
+    def __add__(self, item):
+        self.add(item)
+
+    def append(self, item=None, *args):
+        """ we get compatible with list then """
+        return self.add(item, args)
+
+    def add(self, item=None, *args):
+        """ add a task, a family or an attribute """
+        if DEBUG:
+            print(self.fullname(), item, args)
+
+        if item is not None:
+            if type(item) in (tuple, list):
+                for val in item:
+                    self.add(val)
+            elif type(item) == str:
+                raise DefError(item)
+            elif type(item) == int:
+                pass
+            elif type(item) == dict:
+                if item != {}:
+                    raise DefError(item)
+            else:
+                item.add_to(self)
+
+        if len(args) > 0:
+            assert type(args) in (tuple, list)
+            for val in args:
+                self.add(val)
+            return self
+
+        if not isinstance(self.load, ecflow.Node):
+            raise DefError("please dont", type(self))
+
+        return self
+
+    def limit(self, name=None, size=1, inlimit=0):
+        """ add limit attribute"""
+        if name is None:
+            raise DefError
+        self.load.add_limit(name, size)
+        return self
+
+    def inlimit(self, full_path):
+        """ add inlimit attribute"""
+        if not USE_LIMIT:
+            return self
+
+        try:
+            path, name = full_path.split(":")
+        except ValueError:
+            raise ValueError('invalid limit: {}'.format(full_path))
+
+        self.load.add_inlimit(name, path)
+        return self
+
+    # follow pyflow
+    shape = None
+
+    def draw_tree(self):
+        dot = Dot(fullnames=False)
+        self._tree(dot)
+        return dot
+
+    def _tree(self, dot):
+        try:
+            dot.edge(self.load.get_parent(), self)
+        except:
+            pass
+        if type(self.load) in (Alias, ecflow.Alias):
+            return
+        for n in self.load.nodes:
+            if n.name() != '_':
+                _tree(dot, n)
+
+    def draw_graph(self):
+        dot = Dot()
+        self._graph(dot)
+        dot.save("test.gv")
+        return dot
+
+    def _graph(self, dot):
+        for n in self.load.nodes:
+            if n.name() != '_':
+                _tree(dot, n)
+
+    def to_html(self):
+        # from .html import HTMLWrapper
+        return "%s" % HTMLWrapper("%s" % self)  # .generate_node()))
+
+    def _repr_html_(self):
+        return str(self.to_html())
+
+
+def _tree(dot, node):
+    if type(node) in (ecflow.Node, ecflow.Family, ecflow.Task, ):
+        dot.edge(node.get_parent(), node)
+        for n in node.nodes:
+            if n.name() != '_':
+                _tree(dot, n)
+    elif type(node) in (Node, Family, Task):
+        dot.edge(node.load.parent, node)
+        _tree(dot, node.load)
+    else:
+        raise DefError(type(node))
+
+
+def get_kind(item):
+    if type(item) in (Defs, ecflow.Defs):
+        return "definition"
+    if type(item) in (Suite, ecflow.Suite):
+        return "suite"
+    if type(item) in (Family, ecflow.Family):
+        return "family"
+    if type(item) in (Task, ecflow.Task):
+        return "task"
+    if type(item) in (Alias, ecflow.Alias, ):
+        return "alias"
+    return "ignore"
+
+
+def to_d3js(node):
+    if type(node) == ecflow.Defs:
+        name = 'definition'
+        kids = [to_d3js(item) for item in node.suites]
+        status = "%s" % node.get_state()
+    else:
+        kids = [to_d3js(item) for item in node.nodes]
+        name = node.name()
+        status = "%s" % node.get_state()
+
+    return {'children': [kids],
+            'kind': get_kind(node),
+            'name': '%s' % name,
+            '_status': '%s' % status,
+            'size': len(kids), }
+
+
+def to_pyflow(node, container=None):
+    if container is None:
+        container = dict()
+    if type(node) in (tuple, list):
+        for item in node:
+            container.update(to_pyflow(item, container))
+        return container
+
+    if type(node) in (Alias, ecflow.Alias):
+        return
+    if node.name() not in container.keys():
+        container[node.name()] = dict()
+    # steps follow
+    upd = {
+        'variables': dict(),
+        'events': [(item.number(), item.name()) for item in node.events],
+        'meters': dict(),
+        'labels': dict(),
+        'limits': dict(),
+        'inlimits': dict(),
+    }
+    for item in node.variables:
+        upd['variables'][item.name()] = item.value()
+    for item in node.meters:
+        upd['meters'][item.name()] = [item.min(), item.max()]
+    for item in node.labels:
+        upd['labels'][item.name()] = item.value()
+    for item in node.limits:
+        upd['limits'][item.name()] = item.limit()
+    for item in node.inlimits:
+        arg = item.name()
+        if item.path_to_node() != "":
+            arg = item.path_to_node() + ":" + item.name()
+        if item.tokens() > 1:
+            arg += " %d" % item.tokens()
+        upd['inlimits'][item.name()] = arg
+    for key in upd.keys():
+        if len(upd[key]) == 0:
+            del upd[key]
+    # repeat time date days today
+    if node.get_autocancel():
+        upd['autocancel'] = True
+    if '%s' % node.get_defstatus() != 'queued':
+        upd['defstatus'] = '%s' % node.get_defstatus()
+    if node.get_late() != None:
+        upd['late'] = nat('%s' % node.get_late(), "late")
+    for item in node.nodes:
+        upd.update(to_pyflow(item, container[node.name()]))
+
+    container['%s' % node.name()].update(upd)
+    return container
+
+
+def nat(name, key):
+    res = '%s' % str(name)
+    return res.replace('%s ' % key, '')
+
+
+def to_dict(node, container=None):
+    kids = dict()
+    if isinstance(node, ecflow.Defs):
+        res = {':suites': [], }
+        for item in node.suites:
+            res[':suites'].append(to_dict(item))
+        for item in node.externs:
+            if ':externs' not in res.keys():
+                res[':externs'] = []
+            res[':externs'].append("%s" % item)
+        return res
+
+    if type(node) in (ecflow.Alias, Alias):
+        print("#WAR: aliases are ignored")
+        return dict()
+
+    for item in node.nodes:
+        kids[item.name()] = to_dict(item)
+
+    temp = {'edits': {item.name(): '%s' % item.value()
+                      for item in node.variables},
+            'events': ["%d " % item.number() + '%s' % item.name()
+                       for item in node.events],
+            # 'externs': [],
+            'meters': [
+                {'%s' % item.name(): {
+                    'min': item.min(),
+                    'max': item.max(),  # aka threshold(),
+                    'thr': item.color_change(), }}
+                for item in node.meters],
+            'labels': {item.name(): '%s' % item.value()
+                       for item in node.labels},
+            'limits': {item.name(): item.limit() for item in node.limits},
+            'inlimits': [],
+            'verifies': ["%s" % item for item in node.verifies],
+            'zombies': ["%s" % item for item in node.zombies],
+            'dates': [nat(item, 'date') for item in node.dates],
+            'days': [nat(item, 'day') for item in node.days],
+            'times': [nat(item, 'time') for item in node.times],
+            'crons': [nat(item, 'cron') for item in node.crons],
+            'todays': [nat(item, 'today') for item in node.todays],
+            'trigger': '%s' % node.get_trigger(),
+            'complete': '%s' % node.get_complete(),
+            'children': kids,
+            # 'late': "%s" % node.get_late(),
+            # 'clock': '%s' % node.get_clock(),
+            }
+
+    for item in node.inlimits:
+        arg = item.name()
+        if item.path_to_node() != "":
+            arg = item.path_to_node() + ":" + item.name()
+        if item.tokens() > 1:
+            arg += " %d" % item.tokens()
+        temp['inlimits'].append(arg)
+    out = {':name': '%s' % node.name(),
+           ':kind': '%s' % get_kind(node),
+           ':status': '%s' % node.get_state(), }
+    defstatus = '%s' % node.get_defstatus()
+    if defstatus != 'queued':
+        out[':defstatus'] = "%s" % defstatus
+    if get_kind(node) == "suite":
+        out[':clock'] = nat("%s" % node.get_clock(), "clock")
+    if node.get_late() is not None:
+        out[':late'] = nat("%s" % node.get_late(), "late")
+    rep = node.get_repeat()
+    if not rep.empty():
+        out[':repeat'] = nat("%s" % node.get_repeat(), "repeat")
+
+    # for key in sorted(temp.keys()):
+    for key in temp.keys():
+        if temp[key] == 'None':
+            continue  # WARNING ???
+        out[':' + key] = temp[key]
+
+    return out
+
+
+def to_json(item, pyflow=False):
+    import json
+    if type(item) in (list, tuple):
+        pass
+    elif type(item) != dict:
+        item = to_dict(item, pyflow)
+    return json.dumps(item,
+                      # default= lambda o:
+                      ensure_ascii=True,
+                      skipkeys=True,
+                      sort_keys=True,
+                      indent=2)
+
+
+def json_to_defs(treedict, parent=None):
+    if treedict is None:
+        return
+    res = []
+    if ":externs" in treedict.keys():
+        for item in treedict[":externs"]:
+            res.append("extern %s" % item)
+            # Extern(nat(item, "extern")))
+    elif ":suites" in treedict.keys():
+        for suite in treedict[":suites"]:
+            res.append(from_json(suite))
+    for key in treedict.keys():
+        if key not in (":externs", ":suites"):
+            raise DefError("please use from_json", key)
+    return res
+
+
+def from_json(tree):
+    out = []
+    res = None
+
+    if type(tree) in (tuple, list):
+        if tree == []:
+            return  # IGN
+        if len(tree) == 2:
+            if type(tree[0]) == dict:
+                return from_json(tree[0])
+            return {str(tree[0]): from_json(tree[1])}
+        elif len(tree) == 1:
+            return str(tree[0])
+        raise Exception("#wwwwww", tree, type(tree))
+
+    elif isinstance(tree, str):
+        print("#IGN", tree)
+        return
+
+    elif type(tree) is not dict:
+        raise Exception("#wwwwww", tree, type(tree))
+
+    for k in sorted(tree.keys()):
+        sk = k
+        if sk in (':name', ):
+            res = ITEMS[tree[':kind']](str(tree[':name']))
+
+        elif sk in (':status', ':kind'):
+            continue
+
+        elif sk in (':children', ":kids", ):
+            for kid in sorted(tree[k].keys()):
+                out.append(from_json(tree[k][kid]))
+
+        elif sk in (":suites", ):
+            for item in tree[k]:
+                out.append(from_json(item))
+
+        elif sk in (':defstatus', ':trigger', ':complete', ':clock',
+                    ':late', ':externs', ':repeat',):
+            out.append(ITEMS[k](tree[k]))
+
+        elif sk in (':meters', ):
+            for item in tree[k]:
+                name = item.keys()[0]
+                out.append(ITEMS[k](str(name),
+                                    int(item[name]['min']),
+                                    int(item[name]['max']),
+                                    int(item[name]['thr'])))
+        elif sk in (':edits', ':labels', ':limits', ):
+            for item in sorted(tree[k].keys()):
+                out.append(ITEMS[k](str(item), str(tree[k][item])))
+        elif sk in (':events', ':repeat', ':inlimits', ':crons',
+                    ':verifies', ':dates',
+                    ':times', ':days', ':zombies', ":todays", ):
+            for item in tree[k]:
+                out.append(ITEMS[k](str(item)))
+        # elif ':' in k:
+        #     print(":key",k)
+        #     v = tree[k]
+        #     if type(v) == dict:
+        #         for key in v.keys():
+        #             out.append(ITEMS[k](key, v[key]))
+        #     else:
+        #         for item in v:
+        #             if item != '':
+        #                 out.append(ITEMS[k](item))
+        elif sk in list(ITEMS.keys()):
+            raise Exception
+
+        else:
+            if (type(tree[k]) == dict and
+                len(tree[k]) == 1 and
+                    ['children', ] == list(tree[k].keys())):
+                kids = tree[k]['children']
+                if type(kids) not in (list, tuple):
+                    raise Exception(type(kids))
+                for kid in kids:
+                    if isinstance(kid, str):
+                        out.append((str(k), str(kid)))
+                    elif type(kid) in (dict, ):
+                        for elt in list(kid.keys()):
+                            out.append((str(k), str(elt)))
+                        anot = from_json(kid)
+                        if anot is not None:
+                            out.append(anot)
+
+                return out
+            elif 1:
+                raise Exception(k, tree[k], type(tree[k]),
+                                len(tree[k]),
+                                list(tree[k].keys()))
+            else:
+                out.append(from_json(tree[k]))
+
+    if res is None:
+        return out
+    return res.add(out)
+
+
+class Node(Root):  # from where Task and Family derive
+    """ Node class is shared by family and task """
+
+    def __enter__(self):
+        CWN(self)
+        return self
+
+    # def __exit__(self, exc_type, exc_val, exc_tb): pass  # return self
+
+    def events(self):
+        return [event for event in self.load.events]
+
+    def meters(self):
+        return [meter for meter in self.load.meters]
+
+    def name(self):
+        return self.load.name()
+
+    def find_variable(self, name):
+        if self.load:
+            return self.load.find_variable(name)
+        return None
+    # def event(self, name=1):
+    #     """ add event attribute"""
+    #     if USE_EVENT:
+    #         self.load.add_event(name)
+    #     return self
+
+    # def meter(self, name, start, end, threshold=None):
+    #     """ add meter attribute"""
+    #     if threshold is None:
+    #         threshold = end
+    #     self.load.add_meter(name, start, end, threshold)
+    #     return self
+
+    # def label(self, name, default=""):
+    #     """ add label attribute"""
+    #     self.load.add_label(name, default)
+    #     return self
+
+    # def edit(self, name, value=""):
+    #     """ add variable attribute"""
+    #     self.load.add_variable(name, value)
+    #     return self
+
+    def variable(self, name, value=""):
+        """ add variable attribute """
+        return self.edit(name, value)
+
+    def cron(self, time, dom=False, wdays=False, month=False):
+        """ wrapper for add_cron """
+        cron = ecflow.Cron()
+        cron.set_time_series(time)
+        if wdays is not False:
+            cron.set_week_days(wdays)
+        if month is not False:
+            cron.set_months(month)
+        if dom is not False:
+            cron.set_day_of_month(dom)
+
+        self.load.add_cron(cron)
+        return self
+
+    def complete(self, arg):
+        """ add complete attribute"""
+        if USE_TRIGGER and arg is not None:
+            self.load.add_complete(arg)
+        return self
+
+    def complete_and(self, arg):
+        """ append to existing complete"""
+        if USE_TRIGGER and arg is not None:
+            self.load.add_part_complete(ecflow.PartExpression(arg, True))
+        return self
+
+    def complete_or(self, arg):
+        """ append to existing complete"""
+        if USE_TRIGGER and arg is not None:
+            self.load.add_part_complete(ecflow.PartExpression(arg, False))
+        return self
+
+    def up(self):
+        """ get parent, one level up"""
+        return self.load.get_parent()
+
+
+class Defs(object):
+    """ wrapper for the definition """
+
+    def __init__(self):
+        self.load = ecflow.Defs()
+
+    def __get_attr__(self, attr):
+        return getattr(self.load, attr)
+
+    @property
+    def real(self):
+        return self.load
+
+    def auto_add_externs(self, true):
+        self.load.auto_add_externs(true)
+
+    def check(self):
+        return self.load.check()
+
+    def simulate(self):
+        return self.load.simulate()
+
+    def generate_scripts(self):
+        return self.load.generate_scripts()
+
+    def add_extern(self, path):
+        if type(path) != str:
+            raise DefError(type(path))
+        if ".Extern" in path:
+            raise DefError(type(path))
+        self.load.add_extern(path)  # TODO list
+
+    def save_as_defs(self, fname):
+        self.load.save_as_defs(fname)
+
+    def get_all_tasks(self):
+        return self.load.get_all_tasks()
+
+    def suites(self):
+        return [suite for suite in self.load.suites]
+
+    def add_suite(self, node):
+        if type(node) == Suite:
+            self.load.add_suite(node.load)  # TODO list
+        elif type(node) == ecflow.Suite:
+            self.load.add_suite(node)  # TODO list
+        else:
+            raise DefError("what?")
+
+    def __str__(self):
+        return "%s" % self.load
+
+    __repr__ = __str__
+
+    def __add__(self, item):
+        self.add(item)
+
+    def append(self, item=None, *args):
+        """ get compatible with list """
+        return self.add(item, args)
+
+    def add(self, item):
+        """ add suite """
+        if type(item) == Suite:
+            self.load.add_suite(item.load)
+        elif type(item) == Extern:  # back again
+            path = "%s" % item
+            if type(path) != str:
+                raise DefError(type(path), item)
+            if ".Extern" in path:
+                raise DefError(type(path), path, item)
+            self.load.add_extern(path)
+        elif type(item) in (tuple, list):
+            for one in item:
+                self.add(one)
+        elif item is None:
+            pass
+        elif isinstance(item, str):
+            if "extern " in item:
+                self.load.add_extern(nat(item, "extern"))
+            else:
+                raise DefError("ERR:load add, what?", type(item), item)
+        else:
+            raise DefError("ERR:load add, what?", type(item), item)
+        return self
+
+    def find_abs_node(self, name):
+        return self.load.find_abs_node(name)
+
+    def find_node(self, name):
+        return self.get_abs_node(name)
+
+    def suite(self, name):
+        """ add suite providing its name """
+        suite = Suite(name)
+        self.add(suite)
+        return suite
+
+
+class Client(object):
+    """ wrapper around client """
+
+    def __init__(self, host="localhost", port="31415"):
+        if host is None:
+            host = "localhost"
+        self.clnt = ecflow.Client(host, port)
+        if "@" in host:
+            host, port = host.split("@")
+            self.clnt.set_host_port(host, int(port))
+        else:
+            super(Client, self).__init__()
+            self.clnt.set_host_port(host, int(port))
+        self.host = host
+        self.port = port
+
+    def load(self, defs):
+        if type(defs) == Defs:
+            self.clnt.load(defs.load)
+        elif type(defs) == ecflow.Defs:
+            self.clnt.load(defs)
+        else:
+            raise DefError("defs: really?")
+
+    def get_file(self, node, kind="script"):
+        return self.clnt.get_file(node, kind)
+
+    def replace(self, path, defs=None, parent=True, force=False):
+        if defs is None:
+            self.clnt.replace(path, DEFS, parent, force)
+        elif type(defs) is Defs:
+            self.clnt.replace(path, defs.load, parent, force)
+        else:
+            self.clnt.replace(path, defs, parent, force)
+
+    def suites(self):
+        return self.clnt.suites()
+
+    def begin_suite(self, name):
+        return self.clnt.begin_suite(name)
+
+    def resume(self, path):
+        return self.clnt.resume(path)
+
+    def suspend(self, path):
+        return self.clnt.suspend(path)
+
+    def ping(self):
+        self.clnt.ping()
+
+    def version(self):
+        self.clnt.version()
+
+    def __str__(self):
+        return "ecflow client %s@%s v%s" % (
+            self.host, self.port, self.version())
+
+
+class Suite(Root):
+    """ wrapper for a suite """
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        pass
+
+    def __init__(self, name):
+        self.load = ecflow.Suite(name)
+        CWN(self)
+
+    def name(self):
+        return self.load.name()
+
+    def family(self, name):
+        """ add a family """
+        if "%" in name:
+            raise DefError(name)
+        obsolete()
+        fam = Family(str(name))
+        self.add(fam)
+        return fam
+
+    def task(self, name):
+        """ add a task """
+        if "%" in name:
+            raise DefError(name)
+        obsolete()
+        tsk = Task(name)
+        self.add(tsk)
+        return tsk
+
+    def add_to(self, defs):
+        if type(defs) == ecflow.Defs:
+            defs.add_suite(self.real)
+        else:
+            defs.add_suite(self)
+
+    # def __enter__(self): return self
+
+    # def __exit__(self, *args): pass
+
+
+class Family(Node, Attribute):
+    """ wrapper around family """
+
+    def __init__(self, name):
+        self.load = ecflow.Family(str(name))
+        CWN(self)
+
+    def family(self, name):
+        """ add a family """
+        if "%" in name:
+            raise DefError(name)
+        obsolete()
+        fam = Family(str(name))
+        self.add(fam)
+        return fam
+
+    def task(self, name):
+        """ add a task """
+        if "%" in name:
+            raise DefError(name)
+        obsolete()
+        tsk = Task(name)
+        self.add(tsk)
+        return tsk
+
+    def add_to(self, node):
+        if DEBUG:
+            print("#BDG: add: %s %s" % (node.name(), self.name()))
+        parent = self.load.get_parent()
+        if parent:
+            raise DefError("already attached...",
+                           parent.name(),
+                           node.name(), self.name())
+        if type(node) in (Suite, Family, Task):
+            node.load.add_family(self.load)
+        else:
+            node.add_family(self.load)
+
+    def nodes(self):
+        return [node for node in self.load.nodes]
+
+    # def __enter__(self): return self
+
+    # def __exit__(self, *args): pass
+
+
+class Task(Node, Attribute):
+    """ wrapper around task """
+
+    def __init__(self, name):
+        # super(Task, self).__init__(name)
+        self.load = ecflow.Task(name)
+        CWN(self)
+
+    def add_to(self, node):
+        if type(node) in (Family, Suite):
+            load = self.load  # deep copy
+            if load.get_parent() != None:
+                new = load
+                load = new
+            node.load.add_task(load)
+            return
+        node.add_task(self.load)
+
+    def add_family(self, node):
+        raise DefError(self.name(), node.name(), self.fullname())
+
+    def add_task(self, node):
+        raise DefError(node.name(), self.name())
+
+
+class Alias(Root, ecflow.Alias):  # from where Suite and Node derive
+
+    def __get_attr__(self, attr):
+        return None
+
+    def nodes(self):
+        return None
+
+
+class AttributeList(Attribute):
+
+    def __init__(self, items):
+        self.store = items
+        if (sys.version_info > (3, 0)):
+            super().__init__()
+        else:
+            super(AttributeList, self).__init__()
+
+    def add_to(self, node):
+        for item in self.store:
+            node.add(item)
+        return node
+
+
+def display(defs, fname=None):
+    """ print defs"""
+    if fname is not None:
+        with open(fname, 'w') as fop:
+            fop.write("%s" % defs)
+
+
+class TestEcf(unittest.TestCase):
+    """ a test case aka use-case """
+
+    def test_edge(self):
+        import json
+        s = '{"A": {"children": ["B", {"C": {"children": [{"D": {"children": ["E"]}}, "F"]}}]}}'
+        data = json.loads(s)
+        edges = from_json(data)
+
+        def rec_form(row, fop):
+            if len(row) == 0:
+                return
+            elif len(row) == 1:
+                row = row[0]
+            if len(row) == 2:
+                fop.write('  {0} -> {1};'.format(*row))
+            else:
+                for item in row:
+                    rec_form(item, fop)
+        with open('tree.dot', 'w') as fop:
+            fop.write('\nstrict digraph tree {')
+            print("#s\n", s, "\n", edges)
+            rec_form(edges, fop)
+            fop.write('}')
+        """
+        python ecf.py;  # generate tree.dot
+        cat tree.dot | dot -Tpng -otree.png && xdg-open tree.png
+        cat tree.dot | neato -Tpng -otree.png && xdg-open tree.png
+        cat tree.dot | twopi -Tpng -otree.png && xdg-open tree.png
+        """
+
+    def xtest_xxx(self):
+        """ a test """
+        CWN.cdp(False)
+        suite = Suite("Suite").add(Clock("real"),
+                                   Autocancel(3))
+        suite.add(Defstatus("suspended"))
+        suite.add(AutoRestore(["Family", ]))
+
+        fam = Family("Family")
+        fam.add(AutoArchive(3))
+        # empty, index, name, value
+        fam.add(Queue("param", ["u", "v", "t", "q"]))
+        tsk = Task("Task")
+
+        ft2 = Task("Fam")
+        ft2.add_to(fam)
+
+        tsk.VAR = "VALUE"  # edit VAR "VALUE"
+        tsk.add(Late("-s 00:05 -c 01:00"))
+
+        fam.add(tsk,
+                (Task("1"), Task("2")),
+                [Task("11"), Task("12")],
+                Task("111"), Task("211"),
+                # Task("t2").add(Trigger(tsk == COMPLETE),
+                # Late("-s 00:05 -a 01:00 -c 20:00"),
+                #              Time("01:00")),
+                Task("t21").add(Cron("00:00 23:59 01:00")),
+                # each 1st 5th ... by 0900
+                Task("d").add(Cron("-d 1,5,10,15,20,25 09:00")),
+                Task("t22").add(Today("14:00")),
+                Task("t23").add(Date("1.*.*")),
+                Task("t24").add(Day("monday")),
+                )
+
+        fam.add(
+            Task("t3").add(
+                If(test=(1 == 1),
+                   then=Edit(ADD_ONE=1),
+                   otow=Edit(ADD_TWO=1)),
+
+                If(test=(1 == 0),
+                   then=Edit(ADD_ONE=0),
+                   otow=Edit(ADD_TWO=0)),
+                Trigger(tsk != ABORTED),
+                # Complete(tsk == COMPLETE)),
+            ))  # longer
+
+        fam.add(
+            Task("2t"),
+            # Task("t4").add(                Trigger(tsk.name() != COMPLETE)),
+            Late("-s 00:05 -c 01:00"),
+            Edit(VAR="VALUE"),
+            Task("t5").add(Trigger(["t4", "t3", "t2"])),
+            Task("t6").add(Trigger("2t" == COMPLETE)),
+            Task("t7").add(Trigger("2t eq complete")), )
+
+        tsk.add(Limit("a_limit", 10),
+                Inlimit("a_task:a_limit"),
+                Meter("step", -1, 100),
+                Label("info", "none"),
+                Event(num=1, name="1"),
+                Event("a"),
+                Defstatus("complete"))
+
+        Extern("/oper/main:YMD")
+        tsk.add(Edit({"A": "a", "B": "b"}))  # dict
+        tsk.add(Edit(D="d", E="e"))  # list name=value,
+        tsk.add(Edit("C", "c"))  # name, value
+        suite.add(fam,
+                  Task("t321").add(Trigger("Family/t2 eq complete"),
+                                   # TriggerOr("Family/1 eq complete"),
+                                   ),
+                  Family("main").add(
+                      Repeat("YMD", 20200202, 20320202, 7, "date"),
+                      Task("doer").add(Time("04:55"))))
+
+        fam.family("fam").add(Defstatus("complete"))
+
+        DEFS.add(suite)
+        another = DEFS.suite("suite")
+        another.add(Defstatus("suspended"))
+        another.task("tn")
+        afam = another.family("family")
+        afam.task("t2n")
+
+        display(DEFS, fname="test_ecf.tmp")
+        suite.draw_tree()
+        suite.draw_graph()
+        suite.to_html()
+
+        to_json(suite)
+        print("%s" % suite)  # print name
+        print(suite)  # print name
+        print(repr(suite))  # print content
+        print(DEFS)  # print content
+        cmd = "xdg-open test.gv.pdf;"
+        cmd += "dot -Tps test.gv > test.ps && xdg-open test.ps"
+        os.system(cmd)
+
+    def test_cdp_aka_pyflow(self):
+        CWN.cdp(True)
+        with Suite("test",  # trigger="1==1"
+                   ) as s1:
+            with Family("f1"):
+                with Task("t1"):
+                    Event(num=0, name="0")
+                    Event(num=1, name="1")
+                    Meter("step", -1, 120)
+                    Label("info", "msg")
+                with Task("t2"):
+                    pass
+                with Family("f2"):
+                    with Task("t3"):
+                        pass
+
+                with Task("t321").add(
+                        Trigger("Family/t2 eq complete"),
+                        # TriggerOr("Family/1 eq complete"),
+                        ):
+                    pass
+
+                with Task("t123").add(
+                        Trigger("Family/t1 eq complete"),
+                        Trigger("Family/1 eq complete")):
+                    pass
+            if DEBUG:
+                print("#DBG: up*3")
+            with Family("f22"):
+                Task("t01")
+                if DEBUG:
+                    print("#DBG: up")
+                with Task("t11"):
+                    pass
+        if DEBUG:
+            print("#DBG: up*2")
+        print(s1)
+        print(DEFS)
+        CWN.cdp(False)
+
+# from pyflow, COMPAT
+
+
+def definition_to_html(d):
+    result = []
+    for n in d.split("\n"):
+        result.append(n)
+    return "<pre>%s</pre>" % ("\n".join(result),)
+
+
+class HTMLWrapper(object):
+
+    def __init__(self, defs):
+        self._def = defs
+
+    def _repr_html_(self):
+        return definition_to_html(self._def)
+
+    __str__ = _repr_html_
+
+
+def shapes(node):
+    if type(node) in (ecflow.Task, Task):
+        return "triangle"
+    elif type(node) in (ecflow.Family, Family):
+        return "rect"
+    elif type(node) in (ecflow.Suite, Suite):
+        return "invtriangle"
+    return None
+
+
+class Dot(object):
+    """ follow tracks from pyflow """
+
+    def __init__(self, fullnames=True):
+        try:
+            from graphviz import Digraph
+        except ImportError:
+            raise DefError("pip install --user graphviz # ???")
+        self._dot = Digraph()
+        self._nodes = {}
+        self._fullnames = fullnames
+
+    def edge(self, node1, node2):
+        self._dot.edge(self.node(node1), self.node(node2))
+
+    def node(self, node):
+        if node is None:
+            return '/'
+        full = node.get_abs_node_path()
+        if full not in self._nodes:
+            self._nodes[full] = '%s' % node.name()
+        self._dot.node(self._nodes[full],
+                       # fillcolor="shape",
+                       # fontcolor="blue",
+                       # fontsize=32,
+                       # width=0.5,
+                       # style="filled",
+                       # fixedsize="shape",
+                       # fixedsize="true",
+                       # label="xxx",
+                       shape=shapes(node))
+        return self._nodes[full]
+
+    def save(self, path, view=True):
+        if os.path.exists(path):
+            os.unlink(path)
+        self._dot.render(path, view=view)
+
+    # For jupyter notbeook
+    def _repr_svg_(self):
+        return self._dot._repr_svg_()
+
+
+ITEMS = {'suite': Suite,
+         'family': Family,
+         'task': Task,
+
+         ':state': State,
+         ':repeat': Repeat,
+
+         ':event': Event,
+         ':events': Event,
+
+         ':externs': Extern,
+         ':extern': Extern,
+
+         ':meter': Meter,
+         ':meters': Meter,
+
+         ':label': Label,
+         ':labels': Label,
+
+         ':edit': Edit,
+         ':edits': Edit,
+
+         ':inlimit': Inlimit,
+         ':limit': Limit,
+
+         ':inlimits': Inlimit,
+         ':limits': Limit,
+
+         ':trigger': Trigger,
+         ':complete': Complete,
+         ':defstatus': Defstatus,
+         # ':kids': Limit,
+
+         ':time': Time,
+         ':times': Time,
+         ':cron': Cron,
+         ':crons': Cron,
+         ':date': Date,
+         ':dates': Date,
+         ':day': Day,
+         ':days': Day,
+         ':today': Today,
+         ':todays': Today,
+
+         ':zombies': Zombie,  # ecflow.ZombieAttr,
+         ':zombie': Zombie,  # ecflow.ZombieAttr,
+
+         ':late': Late,
+         ':verifies': Verify,
+         ':clock': Clock,
+         ':autocancel': Autocancel,
+
+         ':suites': Suite,  # dict(),
+         ':suite': Suite,  # dict(),
+         }
+
+
+if __name__ == '__main__':
+    unittest.main()
diff -pruN 5.12.4-1/libs/pyext/samples/api/ls.py 5.13.0-1/libs/pyext/samples/api/ls.py
--- 5.12.4-1/libs/pyext/samples/api/ls.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/api/ls.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,359 @@
+#!/usr/bin/env python3
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+"""
+dump server content, or a suite, line by line, fullname, for eas
+"""
+from __future__ import print_function
+import pwd
+import sys
+import os
+assert sys.version_info >= (3, )
+import ecflow
+
+
+def printer(opt, iterate, full):
+    if opt:
+        for item in iterate:
+            print(full + ":%s" % item)
+
+
+def liner(full, name, fct):
+    try:
+        item = fct()
+        if item:
+            print(full + ":%s " % name + "%s" % item)
+    except:
+        pass
+
+
+def def_port():
+    port = os.getenv("ECF_PORT", None)
+    if port is None: return 1500 + int(pwd.getpwnam(get_username()).pw_uid)
+    else: return int(port)
+
+
+def get_defs(host=None, port=None, path=None):
+    if host is None:
+        host = os.getenv("ECF_HOST", "localhost")
+    if port is None:
+        port = os.getenv("ECF_PORT", def_port())
+
+    client = ecflow.Client(host, port)
+    reg = False
+    if path:
+        if '/' in path and '/' != path:
+            reg = str(path.split('/')[1])
+            client.ch_register(False, [reg, ])
+            print(reg)
+            reg = True
+        elif path == '/': pass
+        else:
+            raise Exception(path)
+    else:
+        raise Exception(path)
+    client.sync_local()
+    if reg:
+        client.ch_drop()
+    return client.get_defs()
+
+
+def print_trigger(full, kind, expr):
+    if not expr:
+        return
+    expr = "'%s'" % expr
+    print(full, kind, expr.replace(
+        " and ", " AND ").replace(
+            " or ", " OR ").replace(
+                " eq ", " == "))
+
+
+class Ls(object):
+
+    def __init__(self, parsed=None):
+        # print(parsed)
+        if parsed is None:
+            parsed.path = '/'
+            parsed.recursive = True
+            parsed.triggers = True
+            parsed.variables = True
+            parsed.status = True
+            parsed.display = True
+
+        if parsed.path is None:
+            parsed.path = '/'
+            if parsed.node != '/':
+                parsed.path = parsed.node
+
+        if parsed.all:
+            parsed.recursive = True
+            parsed.verbose = True
+            parsed.display = True
+            parsed.dates = True
+            parsed.times = True
+            parsed.meters = True
+            parsed.events = True
+            parsed.labels = True
+            parsed.limits = True
+            parsed.inlimits = True
+            parsed.triggers = True
+            # parsed.gvar = True
+            parsed.status = True
+            # parsed.sms = True
+            parsed.variables = True
+
+        self.parsed = parsed
+
+        # path = parsed.path
+        if parsed.path is not None:
+            filename = parsed.path.replace("/", "_") + ".tmp"
+
+        if parsed.sms:
+            user = os.getlogin()
+            log = "set SMS_PROG %s; login %s %s 1;" % (
+                parsed.port, parsed.host, user)
+            grep = "|grep -v 'trigger ( an eq complete or an eq unknown)'"
+            grep = "|grep -v 'fsobs eq complete or fsobs eq unknown'"
+            get = "get %s; show %s %s > %s; " % (
+                parsed.path, parsed.path, grep, filename)
+            cdp = "/usr/local/apps/sms/bin/cdp"
+            cmd = cdp + "<<EOF\n" + log + get + "exit 0\nEOF"
+            print("#cmd:", cmd)
+            os.system(cmd)
+        elif parsed.file:
+            defs = ecflow.Defs(parsed.file)
+            # defs.add(ecflow.Suite("o").add(ecflow.Family("lag")))
+            num = 0
+            for s in defs.suites:
+                name = s.name()
+                num += 1
+            if parsed.path is None and num == 1:
+                parsed.path = "/" + name
+        else:
+            defs = get_defs(parsed.host, parsed.port, parsed.path)
+            defs.auto_add_externs(True)
+            try: defs.save_as_defs(filename)
+            except: print("cannot save", filename)
+
+        # defs = ecflow.Defs(filename)
+        # defs.auto_add_externs(True)
+        for s in defs.suites:
+            # print(s)
+            if s.get_abs_node_path() is None:
+                continue
+            if parsed.path is None:
+                continue
+            if s.get_abs_node_path() in parsed.path or parsed.path == "/":
+                self.process(s, parsed.path)
+
+    def process(self, node, path):
+        full = node.get_abs_node_path()
+        # print(node.name(), path)
+        if ":" in path:
+            top, nam = path.split(":")
+        else:
+            nam = None
+            top = path
+        if top in full:
+            pass
+        elif full in top:
+            rc = None
+            for curr in node.nodes:
+                res = self.process(curr, path)
+                if res is not None:
+                    rc = res
+            return rc
+        else:
+            return None
+
+        status = None        
+        if nam is None or self.parsed.display:
+            if status is None: status = "%s" % node.get_state()
+            if type(node) == ecflow.Task:
+                num = 10
+                kind = "task"
+            elif type(node) == ecflow.Family:
+                num = 11
+                kind = "family"
+            elif type(node) == ecflow.Suite:
+                num = 12
+                kind = "suite"
+            elif type(node) == ecflow.Alias:
+                # return
+                num = 13
+                kind = "alias"
+            else:
+                print(type(node))
+                raise BaseException("node kind?", type(node))
+            print(node.get_abs_node_path(), num, kind, status, end="\n")
+
+        elif self.parsed.display:
+            status = "%s" % node.get_state()
+            nums = {"unknown": 0,
+                    "suspended": 1,
+                    "complete": 2,
+                    "queued": 3,
+                    "submitted": 4,
+                    "active": 5,
+                    "aborted": 6,
+                    "shutdown": 7,
+                    "halted": 8}
+            print(nums[status], status)
+
+        elif self.parsed.status:
+            status = "%s" % node.get_state()
+            print(status)
+
+        else:
+            print()
+        # print(self.parsed)
+        printer(self.parsed.events, node.events, full)
+        printer(self.parsed.meters, node.meters, full)
+        printer(self.parsed.labels, node.labels, full)
+
+        printer(self.parsed.limits, node.limits, full)
+        printer(self.parsed.inlimits, node.inlimits, full)
+
+        printer(self.parsed.dates, node.dates, full)
+        printer(self.parsed.dates, node.days, full)
+
+        printer(self.parsed.times, node.times, full)
+        printer(self.parsed.times, node.crons, full)
+        printer(self.parsed.times, node.todays, full)
+        if self.parsed.triggers:
+            print_trigger(full, ":trigger", node.get_trigger())
+            print_trigger(full, ":complete", node.get_complete())
+        # for item in node.zombies: print(full + ":%s" % item, end="")
+        if self.parsed.variables or ":" in path:
+            item = node.get_repeat()
+            if not item.empty():
+                if nam == item.name() or not nam:
+                    print(full + ":repeat", item.name(), item.value(), "'%s'" % item, end="\n")
+
+            # for item in sorted(node.variables):
+            for item in node.variables:
+                if 1: #  and nam == item.name() or not nam:
+                    if " " in item.value() and not "'" in item.value() and not "\"" in item.value():
+                        print(full + ":%s" % item.name(), "'%s'" % item.value(), end="\n")
+                    else: print(full + ":%s" % item.name(), item.value(), end="\n")
+                    # if self.parsed.verbose: print(" " + item.value())
+                    # else: print()
+                    if nam == item.name():
+                        sys.exit(0)
+
+            gvar = ecflow.VariableList()
+            if self.parsed.gvar:
+                node.get_generated_variables(gvar)
+            for item in gvar:
+                if 1 and nam == item.name() or not nam:
+                    try:
+                        print(full + ":gedit", item.name(), )
+                        if self.parsed.verbose:
+                            print(" %s" % item.value())
+                        else:
+                            print()
+                    except:
+                        pass
+                    if nam == item.name():
+                        sys.exit(0)
+
+        item = node.get_late()
+        if item and self.parsed.verbose:
+            print(full, ":late", item)
+        #item = node.get_defstatus();
+        # if item:
+        #    item = "%s" % item
+        #    if "queued" not in item: print(full, ":defstatus", item)
+        item = node.get_autocancel()
+        if item and self.parsed.verbose:
+            print(full, ":autocancel", item)
+
+        # #liner(full, "late", node.get_late)
+        # liner(full, "clock", node.get_clock)
+        if self.parsed.verbose:
+            liner(full, "defstatus", node.get_defstatus)
+        # liner(full, "autocancel", node.get_autocancel)
+        # liner(full, "complete", node.get_complete)
+        # liner(full, "trigger", node.get_trigger)
+
+        if type(node) == ecflow.Alias:
+            return node
+
+        if self.parsed.recursive:
+            for curr in node.nodes:
+                self.process(curr, path)
+        return node
+
+
+def pars():
+    import argparse
+    parser = argparse.ArgumentParser(add_help=False)
+    # parser.add_argument("-h", default=0, help="help")
+    parser.add_argument("-H", "--host", default="localhost", help="host")
+    parser.add_argument("-p", "--port", default="%d" % def_port(), help="port")
+    parser.add_argument("-a", "--all", action="store_true", help="all")
+    parser.add_argument("-A", "--Alias", action="store_true", help="aliases")
+    parser.add_argument("-f", "--file", default=None, help="file")
+    parser.add_argument("-F", "--force", action="store_true", help="force")
+    # parser.add_argument("-n", "--node", default="/", help="node")
+    parser.add_argument("-N", "--node", default=None, help="node")
+    parser.add_argument("-P", "--path", default=None, help="path")
+    parser.add_argument("-R", "--recursive", action="store_true", help="recursive")
+    parser.add_argument("-v", "--verbose", action="store_true", help="verbose")
+    parser.add_argument("-d", "--display", action="store_true", help="display")
+    parser.add_argument("-D", "--dates", action="store_true", help="Dates")
+    parser.add_argument("-t", "--times", action="store_true", help="times")
+    parser.add_argument("-m", "--meters", action="store_true", help="meters")
+    parser.add_argument("-e", "--events", action="store_true", help="events")
+    parser.add_argument("-l", "--labels", action="store_true", help="labels")
+    parser.add_argument("-L", "--limits", action="store_true", help="limits")
+    parser.add_argument("-i", "--inlimits",
+                        action="store_true", help="inlimits")
+    parser.add_argument("-T", "--triggers",
+                        action="store_true", help="triggers")
+    parser.add_argument("-G", "--gvar", action="store_true", help="gvars")
+    parser.add_argument("-S", "--status", action="store_true", help="Status")
+    parser.add_argument("-s", "--sms", action="store_true", help="sms")
+    parser.add_argument("-V", "--variables", action="store_true", help="variables")
+    parser.add_argument('node', nargs="?", type=str)
+    return parser
+
+
+def get_username():
+    return pwd.getpwuid(os.getuid())[0]
+
+
+if __name__ == "__main__":
+    parsed = pars().parse_args()
+    # print("#", parsed)
+    Ls(parsed)
+
+
+"""
+aaa
+ECF_HOST=localhost ECF_PORT=3141 ./ls.py -Rv --path /eda
+
+./ls.py --host=localhost --port=3141 -n vsms1 -R -v -N /eda
+
+ECF_HOST=vsms1 ECF_PORT=32222 python ls.py /seas_mm/main
+ECF_HOST=vsms1 ECF_PORT=43333 python t3.py e_sapp main
+ecflow_client --port 32222 --host vsms1 --get_state /seas_mm
+ecflow_client --port 32222 --host vsms1 --stats | grep Stat
+cdp -c "od; sms -s " | grep Status
+rcp ls.py emos@ibis:/home/ma/emos/bin/ls.py
+
+ls.py -h vsmsrdna -p 314122 -s -n /map
+python ~/git/suites/o/def/tkinter/ls.py -h vsmsrdna -p 314122 -s -n /map
+
+python ./cli_proc.py -c -r vsms1:32112 o /o eurus:1630
+python ./cli_proc.py -c -r vecfrdda1:11001 dag /dag/gsup eurus:1630
+
+./ls.py -V -t -R -P /USER
+./ls.py -T -R -V -v -t -d -D -e -m -l -P /USER
+/ls.py -T -p $ECF_PORT -h $ECF_HOST -NRVvtdDemlT /
+
+"""
diff -pruN 5.12.4-1/libs/pyext/samples/api/sms2ecf.py 5.13.0-1/libs/pyext/samples/api/sms2ecf.py
--- 5.12.4-1/libs/pyext/samples/api/sms2ecf.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/api/sms2ecf.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,193 @@
+#!/usr/bin/env python
+""" one module to store needed function to translate SMS-ECFLOW suites """
+import sys
+ECF_MODE = "ecflow" # "sms"
+
+# RAW_MODE:
+# False: translate *_CMD (submit, kill, status) variables values for %ECF_ + number args
+# True:  just translate the name, and %ECF_, not arguments number
+
+RAW_MODE = False    
+# ECF_MODE = "sms"
+CDP = "/usr/local/apps/sms/bin/cdp"
+subm = "/home/ma/emos/bin/trimurti"
+kill = subm
+stat = subm
+
+DICT_SMS_ECF = {
+    'SMSNAME': 'ECF_NAME',
+    'SMSNODE': 'ECF_HOST',
+    'SMSPASS': 'ECF_PASS',
+    'SMS_PROG': 'ECF_PORT',
+    'SMSFILES': 'ECF_FILES',
+    'SMSINCLUDE': 'ECF_INCLUDE',
+    'SMSTRIES':   'ECF_TRIES',
+    'SMSTRYNO': 'ECF_TRYNO',
+    'SMSTRIE': 'ECF_TRIE',
+    'SMSHOME': 'ECF_HOME',
+    'SMSRID': 'ECF_RID',
+    'SMSJOB': 'ECF_JOB',
+    'SMSJOBOUT': 'ECF_JOBOUT',
+    'SMSOUT': 'ECF_OUT',
+    'SMSCHECKOLD': 'ECF_CHECKOLD',
+    'SMSCHECK': 'ECF_CHECK',
+    'SMSLOG': 'ECF_LOG',
+    'SMSLIST': 'ECF_LIST',
+    'SMSPASSWD': 'ECF_PASSWD',
+    'SMSSERVER': 'ECF_SERVER',
+    'SMSMICRO': 'ECF_MICRO',
+    'SMSPID': 'ECF_PID',
+    'SMSHOST': 'ECF_HOST',
+    'SMSDATE': 'ECF_DATE',
+    'SMSURL': 'ECF_URL',
+    'SMSURLBASE': 'ECF_URLBASE',
+    'SMSCMD': 'ECF_JOB_CMD',
+    'SMSKILL': 'ECF_KILL_CMD',
+    'SMSSTATUSCMD': 'ECF_STATUS_CMD',
+    'SMSJOBCHECK': 'ECF_CHECK_CMD',
+    'SMSURLCMD': 'ECF_URL_CMD',
+    'SMSWEBACCES': 'ECF_WEBACCES',
+    'SMS_VER': 'ECF_VER',
+    'SMS_VERSION': 'ECF_VERSION',
+    'SMSLOGHOST': 'ECF_LOGHOST',
+    'SMSLOGPORT': 'ECF_LOGPORT',
+    'SMSLOGTIMEOUT': 'ECF_LOGTIMEOUT',
+}
+
+DICT_ECF_SMS = dict((v, k) for k, v in DICT_SMS_ECF.items())
+      
+def translate(name, value=None):
+    """ find and replace submit, kill and status command, according to
+    sms/ecflow mode """
+    value2 = value
+    transl = name
+    smssubmit = "trimurti"
+    ecfsubmit = "/home/ma/emos/bin/ecflow_submit"
+
+    def add_ext(name, value):
+            if "_v2" in value: rc = " %ECF_JOB% %SCHOST% %USER%"
+            elif "kill" in value or "stat" in value:
+                if "WSHOST" in value: rc = RIDCLWS
+                else: rc = RIDCL
+            # if "submit" in value: 
+            #     if "WSHOST" in value: rc = JOBCLWS
+            #     else: rc = JOBCL
+            elif "WSHOST" in value: rc = JOBCLWS
+            else: rc = JOBCL
+
+            if name in  ('ECF_JOB_CMD', 'SMSCMD'):
+                 rc = SUBCMD + " " + rc 
+            elif name in ('ECF_KILL_CMD', 'SMSKILL'):
+                if "submit" in KILLCMD:
+                    rc = KILLCMD + " %s kill" % rc
+                else: rc = KILLCMD + " %s " % rc
+            elif name in ('ECF_STATUS_CMD', 'SMSSTATUS', 
+                           'ECF_CHECK_CMD', 'SMSJOBCHECK'):
+                if "submit" in STATCMD:
+                     rc = STATCMD + " %s status" % rc
+                else: rc = STATCMD + " %s" % rc
+            return rc
+
+    if ECF_MODE == "ecflow" and name in DICT_SMS_ECF:
+        if name in ('SMSCMD', 'SMSKILL', 'SMSSTATUSCMD', 'SMSHOME'):
+            value2 = value.replace('SMS', 'ECF_')
+            value  = value2.replace(smssubmit, ecfsubmit)
+        elif name in ('ECF_JOB_CMD', 'ECF_KILL_CMD', 'ECF_STATUS_CMD'):
+            value2 = value.replace('SMS', 'ECF_')
+            value  = value2.replace(smssubmit, ecfsubmit)
+        transl = DICT_SMS_ECF[name]
+
+    elif ECF_MODE == "sms"  and name in DICT_ECF_SMS:
+        if name in  ('ECF_CMD_CMD', 'ECF_KILL_CMD', 'ECF_STATUS_CMD'):
+            value2 = value.replace('ECF_', 'SMS')  
+        transl = DICT_ECF_SMS[name]
+
+    else: pass
+
+    if ECF_MODE == "sms" and RAW_MODE:
+        value2 = value.replace("ECF_", "SMS")
+        return transl, value2
+ 
+    elif ECF_MODE == "sms" and "CMD" in name and not "submit" in value:
+        if name in ('ECF_JOB_CMD'): name = "SMSCMD"
+        elif name in ('ECF_KILL_CMD'): name = "SMSKILL"
+        elif name in ('ECF_STATUS_CMD'): name = "SMSSTATUS"
+        value2 = value.replace("ECF_", "SMS")
+        value  = value2
+
+    elif ECF_MODE == "sms":
+             SUBCMD  = subm
+             KILLCMD = kill
+             STATCMD = stat
+
+             JOBCL  = ' %USER% %SCHOST% %SMSJOB% %SMSJOBOUT%'
+             RIDCL  = ' %USER% %SCHOST% %SMSRID% %SMSJOB% %SMSJOBOUT%'
+             STATL  = ' %USER% %SCHOST% %SMSRID% %SMSJOB%'
+             STATLWS  = ' %USER% %WSHOST% %SMSRID% %SMSJOB%'
+
+             JOBCLWS = JOBCL.replace("%SC", "%WS")
+             RIDCLWS = RIDCL.replace("%SC", "%WS") # .replace("HOST%", "HOST% %SMSRID%")
+             if name in  ('ECF_JOB_CMD', 'SMSCMD'):
+                 value2 = add_ext(name, value)
+             elif name in ('ECF_KILL_CMD', 'SMSKILL'):
+                 if "submit" in KILLCMD:
+                     value2 = KILLCMD + add_ext(value, value) + " kill"
+                 else: value2 = KILLCMD + add_ext(value, value)
+             elif name in ('ECF_STATUS_CMD', 'SMSSTATUS', 
+                           'ECF_CHECK_CMD', 'SMSJOBCHECK'):
+                 if "submit" in STATCMD:
+                     value2 = STATCMD + add_ext(value, value) + " status"
+                 else: value2 = STATCMD + add_ext(value, value)
+             return transl, value2
+    return transl, value
+
+
+def get(name, host="localhost", port=314159):
+    import os, pwd
+    os.getlogin = lambda: pwd.getpwuid(os.getuid())[0]
+    user = os.getlogin()
+    cmd = "setenv -i HOME USER; set SMS_PROG %d; login %s %s 1; status > /dev/null ; get; show > %s; " % (port, host, user, name)
+    os.system("cdp -c '%s'" % cmd)
+
+def ignore(): pass
+
+ignored = ( "action", "owner", "text", "migrate", "automigrate", "autorestore")
+def sms2ecf(orig, dest):
+   import re
+   with open(dest, 'w') as fop:
+       with open(orig, 'r') as source:
+            try:
+                for line in source:
+                    for key in ignored:
+                        if " %s " % key in line: 
+                            continue                
+                    print(line, file=fop)
+            except:
+                print("oops")
+
+def load(name, host="localhost", port=31415):
+    import ecflow as ec
+    client = ec.Client(host, port)
+    try:
+        client.load(name)
+    except:
+        client.replace("/", name)
+
+if __name__ == "__main__":
+    import sys
+    try:
+        sms  = sys.argv[1]
+        prog = sys.argv[2]
+        ecf  = sys.argv[3]
+        port = sys.argv[4]
+    except:
+        sms  = "localhost"
+        prog = 314159
+        ecf  = "localhost"
+        port = 31415
+
+    before = "from_sms.exp"
+    become = "prep_ecf.exp"
+    get(name=before)
+    sms2ecf(orig=before, dest=become)
+    load(name=become)
diff -pruN 5.12.4-1/libs/pyext/samples/check_modules.py 5.13.0-1/libs/pyext/samples/check_modules.py
--- 5.12.4-1/libs/pyext/samples/check_modules.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/check_modules.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,156 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+"""Check if expected modules are loaded.
+
+Usage:
+ ./check_modules.py --m "module load git module swap PrgEnv-cray PrgEnv-gnu " --f module_list_file
+ ./check_modules.py --m "module swap PrgEnv-cray PrgEnv-gnu" --f module_list_file
+ ./check_modules.py --m "module unload grib_api" --f module_list_file
+ ./check_modules.py --m "module load gnu/4.8.1 module load python/2.7.8-01" --f module_list_file
+ ./check_modules.py --m "module swap PrgEnv-cray PrgEnv-gnu module load cdt/16.03" --f module_list_file
+ ./check_modules.py --m "module swap craype-network-aries craype-network-none module switch fftw/3.3.4.7" --f module_list_file
+
+module_list_file is the output of module list e.g.
+
+Currently Loaded Modulefiles:
+  1) version/3.2.10(default)             7) ecfs/2.2.1-rc2(new:prodn:default)
+  2) verbose/true(default)               8) metview/4.6.4(default)
+  3) mode/64(default)                    9) ecaccess/4.0.2(default)
+  4) gnu/4.8.1(default)                 10) fftw/3.3.4(default)
+  5) python/2.7.8-01(default)           11) emos/437(default)
+  6) sms/4.4.14(default)                12) ecmwf/1.0(default)
+"""
+
+import argparse
+import re
+import sys
+
+def main():
+    PARSER = argparse.ArgumentParser(description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--m', help="Space separated list of module commands")
+    PARSER.add_argument('--f', help="Path to a file that is the output of module list")
+    PARSER.add_argument('--remote_host', help="remote host")
+    ARGS = PARSER.parse_args()
+
+    delimter = "module "
+    module_cmds = [e.strip() for e in ARGS.m.split(delimter) if e.strip() != ""]
+    print("module_cmds ",module_cmds)
+
+    module_actions = ("load", "add", "rm", "unload", "swap", "switch")
+    modules_required = dict()
+    modules_missing = set()
+
+    def set_version(s):
+        print(" set_version ",s)
+        try:
+            mod, version = s.split('/')
+        except ValueError:
+            mod = s
+            version = None
+        modules_required[mod] = version
+        if mod in modules_missing:
+             modules_missing.remove(mod)
+
+    def unset_version(s):
+        # Unloading a specific version has no effect if a different version is loaded!
+        print(" unset_version ",s)
+        try:
+            mod, version = s.split('/')
+            if mod in modules_required and modules_required[mod] == version:
+                modules_required.pop(mod)
+            modules_missing.add(s)
+        except ValueError:
+            if s in modules_required:
+                modules_required.pop(s)
+            modules_missing.add(s)
+
+    print("=========================================================")
+    print("Read input module list->",module_cmds)
+    print("=========================================================")
+    for mod in module_cmds:
+        module_cmd = mod.split()
+        print("module_cmd ",module_cmd)
+        action = module_cmd[0]
+        if action not in module_actions:
+            print("Error: Module command ", module_cmd, " is not correctly formed, second arg must be one of", ', '.join(module_actions))
+            return 1
+        if action in ('load', 'add'):
+            if len(module_cmd) != 2:
+                print("Error: invalid module command '%s'" % ' '.join(module_cmd))
+            set_version(module_cmd[1])
+        if action in ('swap', 'switch'):
+            # Swap takes either 1 or 2 arguments
+            # module swap pkg/version <-- unloads pkg, loads pkg/version
+            # module swap pkg1/v1 pkg2/v2 <-- unloads pkg1/v1, loads pkg2/v2
+            if len(module_cmd) > 3:
+                print("Error: invalid module command '%s'" % ' '.join(module_cmd))
+            if len(module_cmd) == 3:
+                unset_version(module_cmd[1])
+            set_version(module_cmd[-1])
+        if action in ('rm', 'unload'):
+            if len(module_cmd) != 2:
+                print("Error: invalid module command '%s'" % ' '.join(module_cmd))
+            unset_version(module_cmd[1])
+
+    print("=========================================================")
+    print("Read module list file->",ARGS.f)
+    print("=========================================================")
+    modules_loaded = dict()
+    module_list = list()
+    with open(ARGS.f) as module_list_file:
+        for line in module_list_file:
+            #print line
+            line = line.rstrip()
+            if line.find("Currently Loaded") == 0: continue;
+            tokens = re.split(r'\s|\d+\)',line)
+            while '' in tokens: tokens.remove('')
+            #print "tokens",tokens
+            for tok in tokens:
+                #print "tok",tok
+                count = tok.count('/')
+                if count == 1:
+                   mod,version = tok.split('/')
+                   version = version.split("(")[0]
+                   print("->(",mod,",",version,")")
+                   modules_loaded[mod] = version
+                else:
+                   print("->(",tok,",None)")
+                   modules_loaded[tok] = None
+
+    print("=========================================================")
+    print("Checking")
+    print("=========================================================")
+    print("->module_missing:   ",modules_missing)
+    print("->modules_required: ",modules_required)
+    print("->module list:      ",modules_loaded)
+    failed = 0
+    for mod, version in list(modules_required.items()):
+        if version and modules_loaded.get(mod) != version or version is None and mod not in modules_loaded:
+            print("Error: expected module %s/%s not found in module list" % (mod, version))
+            failed = 1
+    for module in modules_missing:
+        print("modules_missing - ", module)
+        if '/' in module:
+            mod, version = module.split('/')
+            if modules_loaded.get(mod) == version:
+                print("Error: unexpected module %s/%s found in module list" % (mod, version))
+                failed = 1
+        else:
+            if module in modules_loaded:
+                print("Error: unexpected module %s found in module list" % module)
+                failed = 1
+    return failed
+
+if __name__ == "__main__":
+    sys.exit(main())
diff -pruN 5.12.4-1/libs/pyext/samples/confluence_add_attachment.py 5.13.0-1/libs/pyext/samples/confluence_add_attachment.py
--- 5.12.4-1/libs/pyext/samples/confluence_add_attachment.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/confluence_add_attachment.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,54 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import unittest
+
+class TestConfluence(unittest.TestCase):
+    def setUp(self):
+        conflunce_base_url = "https://software-test.ecmwf.int/wiki"
+#         conflunce_base_url = "https://confluence.ecmwf.int"
+        user = "deploy"  
+        password = "deploy2013"  
+#         user = "ma0"
+#         password = "chacchok1"
+        
+        import sys
+        sys.path.append("/var/tmp/ma0/workspace/admin/2.0")
+        import rest
+        self.c = rest.Confluence(conflunce_base_url,user,password)
+
+    def test_add_attachment_id(self):
+        title = "Releases"
+        space_key_list = [ "EMOS", "ECFLOW", "MAGP", "METV", "ECCUI", "ECC" ]
+        for space_key in space_key_list:
+            page_id = self.c.get_page_id(space_key,title) 
+            if page_id is None:
+                print("Could not find page id for space_key ",space_key," and title:",title)
+            else:
+                print("space key:",space_key," page id:",page_id)
+
+        comment = "production release"
+        file = "/var/tmp/ma0/workspace/ecflow/libs/pyext/samples/test.tar.gz"
+        for space_key in space_key_list:
+            page_id = self.c.get_page_id(space_key,title) 
+            
+            attachment = self.c.get_attachment_id(page_id,file)
+            if attachment is not None:
+                print("space key:",space_key," allready has an attachment for file ",file)
+            else:
+                self.c.create_attachment(page_id,comment,file)
+
+        
+if __name__ == '__main__':
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/samples/cray.py 5.13.0-1/libs/pyext/samples/cray.py
--- 5.12.4-1/libs/pyext/samples/cray.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/cray.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2189 @@
+#!/usr/bin/env python
+# -*- coding= UTF-8 -*-
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# file deepcode ignore MissingCloseOnSomePath: <comment the reason here>
+
+import sys, os, pwd, getopt
+sys.path.append('/home/ma/emos/def/o/def')
+import inc_emos as ic
+from ecf import *
+import ecf
+from inc_emos import Family, Task, Variables, Time, Meter, Event, Label, Late
+import sms2ecf
+
+# ecf.USE_TRIGGER = 0 # DEBUG MODE: do not load triggers
+
+def get_username():
+    return pwd.getpwuid( os.getuid() )[ 0 ]
+def get_uid():
+    return pwd.getpwnam(get_username()).pw_uid
+
+def create_wrapper(name, content):
+    print("#MSG: creating file %s/" % wdir + name)
+    wrapper = open(wdir + "/%s" % name, 'w')
+    print(content, file=wrapper)
+    wrapper.close()    
+##############################################
+
+# ic.SUBM = "/home/ma/emos/bin/smssubmit.cray"
+# ic.KILL = "/home/ma/emos/bin/smssubmit.cray"
+# ic.STAT = "/home/ma/emos/bin/smssubmit.cray"
+# sms2ecf.subm = "/home/ma/emos/bin/smssubmit.cray"
+# sms2ecf.kill = "/home/ma/emos/bin/smssubmit.cray"
+# sms2ecf.stat = "/home/ma/emos/bin/smssubmit.cray"
+
+def create_task():
+    ### PRODUCER/CONSUMER TASK
+    produce = '''#!/bin/ksh
+%manual
+  start - check - stop logsvr
+%end
+%include <qsub.h>
+%include <trap.h>
+
+step=%BEG:0%
+while [ $step -le %FIN:48% ]; do
+  if [[ %PRODUCE:1% = yes ]]; then
+    xevent p
+  elif [[ %CALL_WAITER:0% != 0 ]]; then
+case %ECF_PROG:0% in 
+0) smswait %TRIGGER:1==1%;;
+*) ecflow_client --wait "%TRIGGER:1==1%";;
+esac
+  fi
+
+  if [[ %CONSUME:no% = yes ]]; then
+    xevent c
+  fi
+
+  xmeter step $step
+  step=$((step + %BY:1%))
+done
+ 
+%include <endt.h>
+'''
+    create_wrapper("produce.sms", produce)
+
+    create_wrapper("consume.sms", produce)
+    ### PURE PYTHON
+
+    head = """import os, time, signal
+import ecflow
+  
+print "PYTHONPATH====================================================="
+print os.environ['PYTHONPATH'].split(os.pathsep)
+ 
+class Client(object):
+    ''' communication with the ecflow server. This will automatically call
+       the child command init()/complete(), for job start/finish. It will also
+       handle exceptions and signals, by calling the abort child command.
+       *ONLY* one instance of this class, should be used. Otherwise zombies will be created.
+    '''
+    def __init__(self):
+      print "Creating Client"
+      self.ci = ecflow.Client()
+      self.ci.set_host_port("$ECF_HOST$","$ECF_PORT$")
+      self.ci.set_child_pid(os.getpid())
+      self.ci.set_child_path("$ECF_NAME$")
+      self.ci.set_child_password("$ECF_PASS$")
+      self.ci.set_child_try_no($ECF_TRYNO$)
+    
+      print "Only wait 20 seconds, if the server cannot be contacted (note default is 24 hours) before failing"
+      self.ci.set_child_timeout(20)
+      self.ci.set_zombie_child_timeout(10)
+     
+      # Abort the task for the following signals
+      signal.signal(signal.SIGINT,  self.signal_handler)
+      signal.signal(signal.SIGHUP,  self.signal_handler)
+      signal.signal(signal.SIGQUIT, self.signal_handler)
+      signal.signal(signal.SIGILL,  self.signal_handler)
+      signal.signal(signal.SIGTRAP, self.signal_handler)
+      signal.signal(signal.SIGIOT,  self.signal_handler)
+      signal.signal(signal.SIGBUS,  self.signal_handler)
+      signal.signal(signal.SIGFPE,  self.signal_handler)
+      signal.signal(signal.SIGUSR1, self.signal_handler)
+      signal.signal(signal.SIGUSR2, self.signal_handler)
+      signal.signal(signal.SIGPIPE, self.signal_handler)
+      signal.signal(signal.SIGTERM, self.signal_handler)
+      signal.signal(signal.SIGXCPU, self.signal_handler)
+      signal.signal(signal.SIGPWR,  self.signal_handler)
+     
+    def signal_handler(self,signum, frame):
+      print 'Aborting: Signal handler called with signal ', signum
+      self.ci.child_abort("Signal handler called with signal " + str(signum));
+     
+    def __enter__(self):
+      self.ci.child_init()
+      return self.ci
+     
+    def __exit__(self,ex_type,value,tb):
+      print "Client:__exit__: ex_type:" + str(ex_type) + " value:" + str(value) + "\\\n" + str(tb)
+      if ex_type is not None:
+         self.ci.child_abort("Aborted with exception type " + str(ex_type) + ":" + str(value))
+         return False
+      self.ci.child_complete()
+      return False
+"""
+    body = """#!/usr/bin/env python
+$include <head.py>
+ 
+if __name__ == "__main__":
+# This will also handle call to sys.exit(), i.e Client.__exit__ will still be called.
+   with Client() as ci:
+   # *******************************************************************************
+   # This is where the main work is done.
+   # *******************************************************************************
+      for i in range(1,100):
+         ci.child_meter('step',i)
+         ci.child_label('info', "value_" + str(i))
+         time.sleep(1)
+       
+      ci.child_event('1')
+      print "Finished event,meter and label child commands"
+ 
+$manual
+   This is the manual section. Instead of calling python from the ECF_JOB_CMD we could alternatively place,
+       #!/bin/env/python
+   on the first line of this file.
+$end
+ 
+$comment
+   Note: We do not need a include a tail.py, the head.py does it all.
+$end
+
+"""
+    create_wrapper("head.py", head)
+    create_wrapper("pure_python.sms", body)
+    ### PYTHON TASK
+    content = """$include <python_header.h>
+# header files are located in the same directory as wrapper (quotes)
+for step in range(0,101):
+    print step
+    xmeter("step", step)
+else:
+    print 'the loop is over'
+xevent("1")
+xlabel("info", "news from pure python world")
+
+$include <python_endt.h>
+"""
+    create_wrapper("python.sms", content)
+
+    content = """#!/usr/bin/env python
+import os
+import sys
+import signal 
+
+ECF_PORT=$ECF_PORT:0$
+XECF="/usr/local/apps/ecflow/current/bin/ecflow_client ";
+# --port=$ECF_PORT:0$ --host=$ECF_HOST:0$ ";
+def SigHandler(signum, frame):
+   print "caught signal " + signum
+   xabort()
+   sys.exit(0);
+   return
+
+print ECF_PORT
+# set -eux ?
+# trap 0 ?
+# time stamp per executed line
+
+import atexit
+early_exit = True
+@atexit.register
+def goodbye():
+  if early_exit: 
+    print "too early"
+    xabort()
+  else: 
+    xcomplete()
+
+# TIME_STAMP
+# http://shop.oreilly.com/product/9780596007973.do # recipie p436
+import syslog, time
+
+class FunctionFileLikeWrapper():
+    def __init__(self, func): self.func = func
+    def write(self, msg): self.func(msg)
+    def flush(self): pass
+
+class TimeStamper(object):
+    msg_format = "[%y%m%d %H:%M:%S]", time.gmtime, "%s: %s"
+    msg_format = "+ %H:%M:%S", time.gmtime, "%s %s"
+
+    def __call__(self, msg):
+        tfmt, tfun, gfmt = self.msg_format
+        return "%s %s\\\n" % (time.strftime(tfmt, tfun()), msg)
+
+class TeeFileLikeWrapper():
+    def __init__(self, *files): self.files = files
+    def write(self, msg): 
+        for f in self.files: f.write(timestamp(msg.strip()))
+
+class FlushingWrapper:
+    def __init__(self, *files): self.files = files
+    def write(self, msg):
+        for f in self.files:
+            f.write(timestamp(msg))
+            # f.write(timestamp(msg.strip()))
+            f.flush()
+
+def logto(*files):
+    # sys.stdout = TeeFileLikeWrapper(*files)
+    sys.stdout = FlushingWrapper(*files)
+
+syslogger = syslog.syslog
+syslogfile = FunctionFileLikeWrapper(syslogger)
+timestamp = TimeStamper()
+logto(sys.stdout, syslogfile, open("log.tmp", "w"))
+# end time stamp
+
+if ECF_PORT > 0:
+  os.environ['ECF_PORT'] = "$ECF_PORT:0$"
+  os.environ['ECF_NAME'] = "$ECF_NAME:0$"
+  os.environ['ECF_HOST'] = "$ECF_HOST:0$"
+  os.environ['ECF_PASS'] = "$ECF_PASS:0$"
+
+  def xinit():
+    os.system(XECF + " --init=" + str(os.getpid()))  
+    print "init"
+  def xabort():
+    os.system(XECF + " --abort")  
+  def xcomplete():
+    os.system(XECF + " --complete")  
+  def xmeter(name, step):
+    os.system(XECF + " --meter=" + name + " " + str(step))  
+  def xevent(name):
+    os.system(XECF + " --event=" + name)  
+  def xlabel(name, msg):
+    os.system(XECF + " --label=" + name + " '%s'" % msg)  
+else:
+  os.environ['SMS_PROG'] = "$SMS_PROG:0$"
+  os.environ['SMSNAME'] = "$SMSNAME:0$"
+  os.environ['SMSNODE'] = "$SMSNODE:0$"
+  os.environ['SMSPASS'] = "$SMSPASS:0$"
+
+  def xinit():
+    os.system('smsinit ' + str(os.getpid()))
+  def xabort():
+    os.system('smsabort')
+  def xcomplete():
+    os.system('smscomplete')
+  def xmeter(name, step):
+    os.system("smsmeter " + name + " " + str(step))
+  def xevent(name):
+    os.system("smsevent " + name)
+  def xlabel(name, msg):
+    os.system("smslabel " + name + " '%s'" % msg)
+
+signal.signal (signal.SIGHUP,  SigHandler)
+signal.signal (signal.SIGINT,  SigHandler)
+signal.signal (signal.SIGQUIT, SigHandler)
+signal.signal (signal.SIGILL,  SigHandler)
+signal.signal (signal.SIGTRAP, SigHandler)
+signal.signal (signal.SIGIOT,  SigHandler)
+signal.signal (signal.SIGBUS,  SigHandler)
+signal.signal (signal.SIGFPE,  SigHandler)
+
+"""
+    create_wrapper("python_header.h", content)
+
+    content = """# os.system('smscomplete')
+early_exit = False
+# xcomplete() # managed with atexit
+# os.system('/usr/local/apps/sms/bin/ecflow/bin/ecf_client --complete')
+"""
+    create_wrapper("python_endt.h", content)
+
+    ### PERL TASK
+    create_wrapper("perl.sms", """#!/usr/bin/perl -w
+^include <perl_header.h>
+# header files are located in the same directory as wrapper (quotes)
+print "Pure perl SMS task";
+for ( my $step=1; $step <= 100 ; $step++ ) {
+   print "this is the number $step\\\n";
+   xmeter("step", $step);
+}
+xevent("1");
+            
+xlabel("info", "news from pure perl world");      
+^include <perl_endt.h>
+""")
+    # create_wrapper("perl.sms", content)
+
+    source = """use strict;
+
+my $xmeter = "smsmeter"; my $arg_m = "";
+my $xlabel = "smslabel"; my $arg_l = "";
+my $xevent = "smsevent"; my $arg_e = "";
+my $xcomplete = "smscomplete"; my $arg_c = "";
+my $xabort = "smsabort";
+
+if (^ECF_PORT:0^ != 0) {
+$ENV{'ECF_PORT'}  = "^ECF_PORT:0^" ;  # ecFlow port number
+$ENV{'ECF_HOST'}  = "^ECF_HOST:0^"  ; # ecFlow host
+$ENV{'ECF_NAME'}  = "^ECF_NAME:0^"  ; # task path into the suite
+$ENV{'ECF_PASS'}  = "^ECF_PASS:0^"  ; # password for the job
+$ENV{'ECF_TRYNO'} = "^ECF_TRYNO:0^" ; # job occurence number
+my $client = "/usr/local/apps/ecflow/current/bin/ecflow_client";
+$xmeter = $client; $arg_m = "--meter";
+$xlabel = $client; $arg_l = "--label";
+$xevent = $client; $arg_e = "--event";
+$xcomplete = $client; $arg_c = "--complete";
+$xabort = $client; 
+
+system($client, "--init", "$$");
+} else {
+  $ENV{'SMS_PROG'} = "^SMS_PROG:0^" ; # SMS Program Number
+  $ENV{'SMSNODE'}  = "^SMSNODE:0^"  ; # SMS host
+  $ENV{'SMSNAME'}  = "^SMSNAME:0^"  ; # task path into the suite
+  $ENV{'SMSPASS'}  = "^SMSPASS:0^"  ; # password for the job occurence
+  $ENV{'SMSTRYNO'} = "^SMSTRYNO:0^" ; # job occurence number
+}
+
+sub xmeter($$){ my ($name, $step) = @_; 
+  system($xmeter, $arg_m, $name, $step); }
+sub xevent($){ my ($name) = @_; 
+  system($xevent, $arg_e, $name); }
+sub xlabel($$){ my ($name, $msg) = @_; 
+  system($xlabel, $arg_l, $name, $msg); }
+sub xabort(){ system($xabort); }
+sub xcomplete(){ system($xcomplete, $arg_c, "$$"); }
+
+print "start";
+eval '
+"""
+    create_wrapper("perl_header.h", source)
+
+    source="""';
+if ($@){
+    print "caught signal: $@\n";
+    xabort();
+    exit;
+  }
+print "the job is now complete\n";
+xcomplete();
+exit;"""
+    create_wrapper("perl_endt.h", source)
+
+    ### LOGER TASK
+    content = """#!/bin/ksh
+%manual
+  start - check - stop logsvr
+%end
+%include <qsub.h>
+%include <trap.h>
+SLEEP=%SLEEP:0%
+KIND=%KIND:start%
+type rsh && RSH=rsh || RSH=ssh
+
+case $HOST in 
+c2a*) rhost=c2a;;
+c2b*) rhost=c2b;;
+xxcct*) rhost=cctdtn1 ; RSH=ssh;;
+cct*) rhost=cct-log ; RSH=ssh;;
+cca*) rhost=cca-log ; RSH=ssh ;;
+xxcca*) rhost=cca-il2 ; RSH=ssh ;;
+xxccb*) rhost=ccb-il2 ; RSH=ssh ;;
+ccb*) rhost=ccb-log ; RSH=ssh ;;
+esac
+
+case $KIND in
+start)
+
+ps -elf | grep logsvr | grep -v grep | grep $USER && \\\
+ps -elf | grep logsvr | grep $USER | grep -v grep | \\\
+awk '{print $1}' | xargs kill -9
+
+case $ARCH in
+cray)  
+  case $HOST in
+  cct*) logsvr=/usr/local/apps/sms/bin/logsvr.sh
+        # /usr/local/apps/emos/bin/logsvr.sh
+        # $RSH $rhost 
+        nohup $logsvr > /tmp/emos_logsvr.tmp 2>&1 &
+        rhost=cct # start on both nodes cctdtn1  + cct (Avi serial jobs)
+        trap 0; xcomplete; exit 0
+  ;;
+  cca*|ccb*) logsvr=/usr/local/apps/emos/bin/logsvr.sh;;
+  *)    exit 1;;
+  esac
+
+  $RSH $rhost nohup $logsvr > /tmp/emos_logsvr.tmp 2>&1 &
+;;
+ibm*) $RSH $rhost nohup $HOME/bin/boot/logsvr.sh > /tmp/emos_logsvr.tmp 2>&1 &
+;;
+*)    nohup logsvr.sh > /tmp/emos_logsvr.tmp 2>&1 &
+;;
+esac
+xlabel info "logserver is started"
+
+;;
+stop)
+pid=$($RSH $rhost ps -elf | grep logsvr | grep $USER | grep -v grep | awk '{print $1}' )
+kill -9 $pid
+xlabel info "logserver is stoped"
+;;
+
+ping)
+case $ARCH in
+cray) ps -elf | grep logsvr | grep $USER # grep -v grep || exit 1
+      xlabel info "???"
+     trap 0; xcomplete; exit 0
+;;
+*) $RSH $rhost ps -elf | grep logsvr | grep -v grep | grep $USER || exit 1 
+;;
+esac
+
+xlabel info "$($RSH $rhost ps -elf | grep logsvr | grep -v grep | grep $USER)"
+;;
+esac
+
+%include <endt.h>
+"""
+    create_wrapper("logsvr.sms", content)
+
+    ### task
+    content = """#!/bin/ksh
+%manual 
+manual - this task is automatically created by cray.py
+%end
+%include <qsub.h>
+if [[ $ARCH = hp* ]]; then export PATH=/usr/local/bin:$PATH; fi
+if [[ $HOST = lxop* ]]; then export PATH=/usr/local/apps/ecflow/current:/usr/local/apps/sms/bin:$PATH; fi
+%include <trap.h>
+SLEEP=%SLEEP:0%
+echo OK
+
+case %ECF_PORT:0% in
+0) base=900000; LOGPORT=%LOGPORT:0%;;
+*) base=1000; LOGPORT=%LOGPORT:0%;;
+esac
+base=1000
+
+case $HOST in
+cc*)xlabel info $(printenv | grep -E '(SUBMIT_|EC_)') ;;
+*) xlabel info OK
+esac
+  
+printenv | sort
+xevent 1
+step=0
+while (( $step <= 12 )); do
+  xmeter step $step
+  ((step = step + 1))
+  sleep $SLEEP
+done
+%include <endt.h>
+"""
+    create_wrapper("test.sms", content)
+
+    content = """#!/bin/ksh
+%manual 
+manual - this task is automatically created by cray.py
+
+expected to run in real-time mode only
+
+%end
+#include <qsub.h>
+#include <step1.h>
+%include <trap.h>
+
+KIND=%KIND:when%
+NOW=$(date +%%H%%M)
+
+case $KIND in 
+when) TIME=0; 
+for when in $(echo %WHENS:0%); do
+  if [[ $((NOW - when)) -le 1 ]]; then break; fi
+  TIME=$when
+done
+for when in $(echo %WHENS:0%); do
+  if   [[ $when -le $NOW ]] then  xmeter time $when; sleep %SLEEP:5%; fi
+  done;; 
+time) TIME=%TIME:0%
+
+main=/sapp/run/ext
+case $TIME in 
+1350) path=$main/DC1/00;;
+0120) path=$main/DC1/12;;
+0205) path=$main/DC1/18;;
+1405) path=$main/DC1/06;;
+1605) path=$main/DA1/12;;
+2205) path=$main/DA1/18;;
+0405) path=$main/DA1/00;;
+1005) path=$main/DA1/06;;
+*) xabort;;
+esac
+
+case %ECF_PORT:0% in
+0) login="set SMS_PROG %SMS_PROG:0%; login %SMSNODE:0% $USER 1"
+   cdp -c "$login; force -r complete $path";;
+*) ecflow_client --force=complete recursive $path;;
+esac
+
+;;
+esac
+%include <endt.h>
+#include <step2.h>
+"""
+
+    create_wrapper("sapp.sms", content)
+
+    content = """
+%manual 
+manual - this task is automatically created by cray.py
+
+expected to run in real-time mode only
+%end
+#include <qsub.h>
+#include <step1.h>
+%include <trap.h>
+
+if [[ $USER == map ]]; then
+cd /tmp/map/work/p4/metapps/suites/o/def
+make etest | grep -v Node::addVariable:
+make teste | grep -v Node::addVariable:
+
+TEST="" make oe edae lawe lbce rd mce mofce
+TEST= "" make e eeda elbc elaw 
+
+fi
+
+cd /home/ma/emos/def/o/def
+# make etest| grep -v Node::addVariable:
+# make teste| grep -v Node::addVariable:
+
+TEST="" make oe edae lawe lbce rd mce mofce| grep -v Node::addVariable:
+TEST="" make e eeda elbc elaw | grep -v Node::addVariable:
+
+make doc
+make covtest
+make cov| grep -v Node::addVariable:
+
+# e o rd
+
+%include <endt.h>
+#include <step2.h>
+"""
+    create_wrapper("maker.sms", content)
+
+    content = """#!/bin/ksh
+%manual 
+manual - this task is automatically created by cray.py
+expected to run in real-time mode only
+%end
+#include <qsub.h>
+#include <step1.h>
+%include <trap.h>
+
+KIND=%KIND:when%
+NOW=$(date +%%H%%M)
+
+YMD=%YMD:20010101%
+BASETIME=%YMD:20010101%%EMOS_BASE:00%
+BASE=%EMOS_BASE:00%
+STREAM=%STREAM:elda%
+MEMBER_FROM=%MEMBER_FROM:%
+MEMBER=%MEMBER:%
+EXPVER_FROM=%EXPVER_FROM:9093%
+EXPVER=%EXPVER:9963%
+
+case $HOST in
+c2*) FDB_ROOT=%STHOST:/s2o1%/ma_fdb;;
+cc*) FDB_ROOT=%STHOST:/sc1%/tcwork/emos/ma_fdb;;
+*) exit 1;;
+esac
+
+cd $FDB_ROOT
+mkdir fix
+cd fix
+scp emos@%SCHOST_BKUP:cca:$FDB_ROOT/:od:$STREAM:g:$EXPVER_FROM:$YMD::/:${EMOS_BASE}00:$MEMBER_FROM:*: .
+
+cat > rules.txt <<EOF
+set expver="$EXPVER";
+write;
+EOF
+
+for f in $(ls :${EMOS_BASE}00:$MEMBER_FROM:*:); do
+  grib_filter -o $f.0001 rules.txt $f
+done
+
+echo "mkdir -p test; for f in $(ls :${EMOS_BASE}00:$MEMBER_FROM:*:); do FDB_ROOT=$(pwd)/test grib2fdb $f; done"
+echo "mv test/*$STREAM:*/* $FDB_ROOT/:od:$STREAM:g:$EXPVER:$YMD::/."
+done
+
+case $KIND in 
+VERSION) echo;;
+MEMBER) echo;;
+*) xabort;;
+esac
+
+;;
+esac
+%include <endt.h>
+#include <step2.h>
+"""
+
+    create_wrapper("safety.sms", content)
+
+def create_de():
+    try:    os.stat(wdir + "/de")
+    except: os.makedirs(wdir + "/de")       
+    task = open(wdir + "/de/setup.ecf", 'w')
+    print('''#!/bin/ksh
+%include <head.h>
+%ecfmicro ~
+~includenopp <scripts/setup.run>
+~ecfmicro %
+%include <tail.h>
+''', file=task)
+
+    task = open(wdir + "/de/model.ecf", 'w')
+    print('''#!/bin/ksh
+# QSUB -lh  %THREADS:1%
+# QSUB -lPv %NPES:1%
+# @ tasks_per_node = 64
+%include <head.h>
+%ecfmicro ~
+~includenopp <scripts/model.run>
+~ecfmicro %
+%include <tail.h>
+''', file=task)
+
+    logdir = "/s2o2/emos_dir"
+    return Family("de").add(
+        Defcomplete(),
+        Repeat("YMD", 20100101, 20121212),
+        Variables(ECF_EXTN= ".ecf",
+                  ACCOUNT= "oesu",
+                  SCHOST= "cca",
+                  ECF_LOGHOST= "cca",
+                  ECF_OUT= logdir,
+                  LOGDIR= logdir,
+                  QUEUE= "ns",
+                  TURTLES= 1000*'I LIKE ',
+                  ),
+        Task("setup"),
+        Task("obs").add(Trigger("setup==complete")),
+        Task("namelist").add(Trigger("obs==complete")),
+        Task("model").add(
+            Variables(NPES= 1,
+                      THREADS= 1,
+                      QUEUE= "np",),
+            Trigger("namelist==complete")),
+        Task("postproc").add(Trigger("model==complete")),
+        )
+
+def create_smhi():
+    submit = open(wdir + "/smhi_run.sh", 'w')
+    print('''#!/bin/ksh
+set -eux
+ECF_NAME=$1
+ECF_PASS=$2
+ECF_JOB=$3
+ECF_JOBOUT=$4
+ECF_HOST=$5
+ECF_PORT=$6
+export ECF_NAME ECF_PASS ECF_HOST ECF_PORT ECF_JOB ECF_JOBOUT
+echo "#MSG: START USER SCRIPT"
+. $ECF_JOB # >> $ECF_JOBOUT 2>&1
+''', file=submit)
+
+    man = open(wdir + "/smhi_man.h", 'w')
+    print('''
+an example for include manual page
+''', file=man)
+    man.close()
+
+    shell = open(wdir + "/smhi.sh", 'w')
+    print('''#!/bin/ksh
+set -eux
+# use ecflow || 
+export PATH=/usr/local/apps/ecflow/current/bin:$PATH
+export SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
+ecflow_client --init=$$
+
+ERROR() {
+  ecflow_client --abort # raison:trap
+  echo "#WAR: TRAPPING ERROR"
+  trap 0  
+  uname -a; date; times
+  sleep 0
+  exit 0
+}
+trap ERROR 0 $SIGNAL_LIST
+
+ecflow_client --event=1
+ecflow_client --meter=step 10
+
+echo "simulates an error"; exit 1
+echo "simulates an early exit: expect this to be trapped and reflected as error"
+exit 0 # test bubbling up an error through ssh
+
+''', file=shell)
+    wrapper = open(wdir + "/smhi_v.sms", 'w')
+    print('''
+%manual
+  example of minimalist script: only variables, wrapper is added at submission time
+%end
+#SET ECF_NAME=%ECF_NAME%
+#SET ECF_HOST=%ECF_HOST%
+#SET ECF_PORT=%ECF_PORT%
+#SET ECF_PASS=%ECF_PASS%
+#SET ECF_JOB=%ECF_JOB%
+#SET ECF_JOBOUT=%ECF_JOBOUT%
+#SET ECF_TRYNO=%ECF_TRYNO%
+#SET SCRIPT_PATH=%SCRIPT_PATH%
+#SET SCRIPT_NAME=%SCRIPT_NAME%
+''', file=wrapper)
+
+    submit = open(wdir + "/smhisubmit.sh", 'w')
+    print('''#!/bin/ksh
+set -eux
+ECF_JOB=$1
+grep "#SET " $ECF_JOB | sed -e "s:#SET ::" > $ECF_JOB.set
+grep "#SET " $ECF_JOB > $ECF_JOB.var
+. $ECF_JOB.set
+echo "#!/bin/ksh" > $ECF_JOB
+cat $ECF_JOB.set $ECF_JOB.var >> $ECF_JOB
+cat >> $ECF_JOB <<\@@
+set -eux
+export ECF_NAME ECF_PASS ECF_HOST ECF_PORT
+export PATH=/usr/local/apps/ecflow/current/bin:$PATH
+export SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
+ERROR() {
+  ecflow_client --abort trap
+  echo "#WAR: TRAPPING ERROR"
+  trap 0 
+  uname -a; date; times
+  exit 1
+}
+trap ERROR 0 $SIGNAL_LIST
+
+if [[ ${USE_SSH_SUB:=0} == 1 ]]; then
+ssh $SCHOST mkdir -p $(dirname $ECF_JOBOUT)
+ssh $SCHOST -R$ECF_PORT:$ECF_HOST:$ECF_PORT ''' + wdir + '''/smhi_run.sh \
+  $ECF_NAME $ECF_PASS $SCRIPT_PATH/$SCRIPT_NAME $ECF_JOBOUT $ECF_HOST $ECF_PORT
+echo "#MSG: ssh exits with $?"
+else
+ecflow_client --init=$$
+
+i=0
+while [[ $i -lt ${STEPS:=1} ]]; do
+  ecflow_client --meter=step $i
+  ((i=i+1))
+done
+
+ecflow_client --event=1
+
+fi
+
+wait
+trap 0
+ecflow_client --complete
+uname -a; date; times
+exit 0
+@@
+
+chmod 755 $ECF_JOB
+$ECF_JOB > $ECF_JOBOUT 2>&1 &
+
+''', file=submit)
+
+    os.system("chmod 755 " + wdir + "/smhisubmit.sh")
+    wrapper = open(wdir + "/smhi.sms", 'w')
+    os.system("chmod 755 " + wdir + "/smhi_run.sh")
+    cmd = "ln -sf %s/test.sms " % wdir + wdir + "/"
+    os.system(cmd + "a.sms")
+    os.system(cmd + "a1.sms")
+    os.system(cmd + "a11.sms")
+    print("##cmd", cmd)
+
+    print('''#!/bin/ksh
+%manual 
+%include <smhi_man.h>
+%end
+set -eux
+# use ecflow ||
+export PATH=/usr/local/apps/ecflow/current/bin:$PATH
+export SIGNAL_LIST='1 2 3 4 5 6 7 8 13 15 24 31'
+ECF_NAME=%ECF_NAME%
+ECF_PASS=%ECF_PASS%
+ECF_HOST=%ECF_HOST%
+ECF_PORT=%ECF_PORT%
+export ECF_NAME ECF_PASS ECF_HOST ECF_PORT
+
+ERROR() {
+  ecflow_client --abort # raise:trap
+  echo "#WAR: TRAPPING ERROR"
+  trap 0  
+  uname -a; date; times; sleep 0
+  exit 1
+}
+
+SLEEP=%SLEEP:0%
+trap ERROR 0 $SIGNAL_LIST
+
+if [[ %USE_SSH_SUB:0% == 1 ]]; then
+ssh %SCHOST% mkdir -p $(dirname %ECF_JOBOUT%)
+ssh %SCHOST% -R%ECF_PORT%:%ECF_HOST%:%ECF_PORT% ''' + wdir + '''/smhi_run.sh \
+  %ECF_NAME% %ECF_PASS% %SCRIPT_PATH%/%SCRIPT_NAME% %ECF_JOBOUT% %ECF_HOST% %ECF_PORT%
+  echo "#MSG: ssh exits with $?"
+else
+ecflow_client --init=$$
+
+i=0
+while [[ $i -lt ${STEPS:=1} ]]; do
+  ecflow_client --meter=step $i
+  ((i=i+1))
+done
+
+ecflow_client --event=1
+
+fi
+
+wait
+trap 0
+ecflow_client --complete
+uname -a; date; times
+exit 0
+''', file=wrapper)
+
+def dummy(): return Task("test")
+
+def logsvr(kind): return Task("logsvr").add(
+    Label("man", "kind may be start, stop, ping"),
+    Label("info", ""),
+    Variables(KIND= kind))
+
+def limits():
+    return (Family("Test").add(Defcomplete(),
+                               Label("info", "test find reg exp, case sens"),
+                               Task("Ecmwf"),
+                               Task("ECMWF"),
+                               Task("ecmwf"),
+                               Task("ecm")),
+            Family("limits").add(
+            Defcomplete(),
+            Limit("lim", 10),
+            Limit("test", 10),
+            Limit("hpc", 10),
+            Limit("cca", 10),
+            Limit("ccb", 10),
+            # Limit("cct", 10),
+            # Limit("c2a", 10),
+            # Limit("c2b", 10),
+            Inlimit(ic.psel() + "/limits:lim")))
+
+def repeat():
+    return Family("repeat").add(
+        Defcomplete(),
+        Family("int").add(
+            Repeat("YMD", 21000101, 21001212, 1, "integer"),
+            dummy()),
+        Family("date").add(
+            Repeat("YMD", 21000101, 21001212, 1, "date"),
+            dummy()),
+        Family("string").add(
+            Repeat("YMD", ["1", "2", "3", "4", "5"], kind="string"),
+            dummy()),
+        Family("enum").add(
+            Repeat("YMD", "1 2 3 4 5".split(), kind="enum"),
+            dummy()),
+        )
+        
+
+def fam_ui():
+    return Family("ui").add(
+        Defcomplete(),
+        repeat(),
+        
+        Variables(VAR= 1),
+
+        Family("limit").add(Limit("mutex", 1),
+                            InLimit("limit:mutex"),
+                            Defstatus("complete"),
+                            dummy()),
+
+        Family("autocancel").add(AutoCancel("+01:00"),
+                                 dummy()),
+
+        dummy().add(Meter("step", -1, 100),
+                          Event(1),
+                          Label("info", ""),
+                          Late("-s 00:10 -c 01:00"),
+                          ),
+
+        Family("complete").add(Complete("test:1"),
+                               Trigger("test==complete")),
+
+        Task("time").add(Time("10:00"),
+                         Today("11:00"),
+                         Cron("12:00 13:00 00:05"),
+                         ),
+        Task("date").add(Date("01.*.*"),)
+        )
+
+def smhi():
+    return Family("smhi").add(
+        Defcomplete(),
+
+        Variables(ECF_FILES= wdir,
+                  QUEUE= "none",
+                  LOGDIR= jdir, # "/vol/lxop_emos_nc/output",
+                  MANPATH= "%ECF_SCRIPT%",
+                  ECF_JOB_CMD= "%ECF_JOB% > %ECF_JOBOUT% 2>&1",
+                  ECF_HOME= jdir, # "/tmp/smhi",
+                  ECF_INCLUDE= wdir,),
+
+        acq(),
+
+        Family("ex1").add(Cron("00:00 23:59 00:03"),
+                          Task("scan").add(Label("info", "one min"),
+                                           Event("1")),
+                          Task("proc").add(Label("info", "one min"),
+                                           Trigger("scan:1"),
+                                           Complete("scan eq complete and not scan:1"))),
+        Family("ex2").add(
+            Task("scan").add(Label("info", "one min"),
+                             Cron("00:00 23:59 00:03"),
+                             Event("1")),
+            Family("consume").add(
+                Label("info", "event is set by scan task"),
+                Event("1"),
+                Cron("00:00 23:59 00:05"),
+                Trigger("consume:1"),                
+                Task("proc1").add(Trigger("1==0", Complete("1==1"))),
+                Task("proc2").add(Trigger("1==0", Complete("1==1"))),
+                )),
+        Family("name").add(
+            Variables(ECF_JOB_CMD= SUBMIT,
+                      ECF_KILL_CMD= KILL,
+                      ECF_STATUS_CMD= STATUS,
+                      ECF_CHECK_CMD= CHECK,
+                      # ECF_EXTN= ".sms",
+                      ACCOUNT=  "UNSET",                      
+                      ECF_INCLUDE= idir,
+                      ECF_HOME= jdir,
+                      ECF_FILES= wdir,
+                      TOPATH= udir + "/logs",
+                      SLEEP=    1,
+                      SCHOST= "ibis",
+                      ECF_TRIES= 1,),
+            Task("a").add(Meter("step", -1, 100), Event("1")),
+            Task("a1").add(Meter("step", -1, 100), Event("1")),
+            Task("a11").add(Meter("step", -1, 100), Event("1")),
+            ),
+        
+        Family("ssh").add(
+            Variables(USE_SSH_SUB= 1,
+                      SCRIPT_PATH= wdir,
+                      SCRIPT_NAME= "smhi.sh"),            
+            smhi_unit("ibis", "ibis", "none", jdir),
+            smhi_unit("pikachu", "pikachu", "none", jdir),
+            ),
+
+        Family("alter").add(
+            Variables(USE_SSH_SUB= 1,
+                      ECF_JOB_CMD= "/home/ma/map/course/cray/smhisubmit.sh %ECF_JOB%",
+                      SCRIPT_PATH= wdir,
+                      SCRIPT_NAME= "smhi.sh"),            
+            smhi_unit_alter("ibis", "ibis", "none", jdir),
+            smhi_unit_alter("pikachu", "pikachu", "none", jdir),
+                          )
+        )        
+                          
+def acq():
+    name = "acq_ex"
+
+    fam = Family(name).add(
+        Defcomplete(),
+        Family("times").add(
+            dummy().add(
+                Time("10:00 20:00 00:30"))),
+        Complete(name + "/data eq complete"),
+        Task("data").add(
+            Event("ready"),
+            Trigger("rt/wait:data"),
+            ),
+        Family("rt").add(
+            Complete("data:ready"),
+            Task("wait").add(
+                Event("data"),
+                # Cron("10:00 12:00 00:05")
+                )),
+        Task("late").add(
+            Time("11:00"),
+                Trigger("not data:ready")))
+    return fam
+
+
+HCRAY="cct"
+
+SUBMIT=ic.SUBM + " %USER% %SCHOST% %ECF_JOB% %ECF_JOBOUT% submit"
+GSUB=SUBMIT.replace("%SCHOST%", "%SCHOST% %ECF_RID%")
+KILL=GSUB.replace(" submit", " kill")
+STATUS=GSUB.replace(" submit", " status")
+CHECK=STATUS
+
+
+def unit(name, schost, queue, rdir, account="", leaf=True, add=None):
+    return Family(name).add(
+        If(account != "",
+           Variables(ACCOUNT= account)),
+        Variables(QUEUE=    queue, 
+                  SCHOST=   schost,
+                  ECF_OUT=  rdir,
+                  LOGDIR=   rdir,),        
+        If (leaf, Task("test").add(
+                add,
+            Event(1),
+            Meter("step", -1, 120, 100),
+            Label("info", "nop"))))
+
+def smhi_nit(name, schost, queue, rdir, account=""):
+    return Family(name).add(
+        If(account != "", Variables(ACCOUNT= account)),
+        Variables(QUEUE=    queue, 
+                  SCHOST=   schost,
+                  ECF_OUT=  rdir,
+                  LOGDIR=   rdir,),        
+        Task("smhi").add(
+            Event(1),
+            Meter("step", -1, 120, 100),
+            Label("info", "nop")))
+
+def smhi_unit(name, schost, queue, rdir, account=""): return None
+
+def smhi_unit_alter(name, schost, queue, rdir, account=""):
+    return Family(name).add(
+        If(account != "", Variables(ACCOUNT= account)),
+        Variables(QUEUE=    queue, 
+                  SCHOST=   schost,
+                  ECF_OUT=  rdir,
+                  LOGDIR=   rdir,),        
+        Task("smhi_v").add(
+            Event(1),
+            Meter("step", -1, 120, 100),
+            Label("info", "nop")))
+
+def turkey_main(day, path):
+    def runs(num, time):
+        return Family('run%d' % num).add(
+               Trigger(path + '/deps/%s eq complete' % time),
+            
+               Family('feed_meb').add(
+                Task('strip_message'),                  
+
+                Task('insert_meb').add(
+                    Trigger('strip_message eq complete'),
+                  ),
+               ),               
+               Family('feed_reb').add(
+                  Task('decode_synop').add(
+                     Trigger('../feed_meb/insert_meb eq complete'),
+                  ),
+                  Task('decode_temp').add(
+                     Trigger('../feed_reb/decode_synop eq complete'),
+                  ),
+                  Task('decode_ship').add(
+                     Trigger('../feed_reb/decode_temp eq complete'),
+                  ),
+                  Task('decode_metar').add(
+                     Trigger('../feed_reb/decode_ship eq complete'),
+                  ),
+               ),               
+               Family('rdb').add(
+                  Task('rdb_synop').add(
+                     Trigger('../feed_reb/decode_synop eq complete'),
+                  ),
+                  Task('rdb_temp').add(
+                     Trigger('../feed_reb/decode_temp eq complete'),
+                  ),
+                  Task('rdb_ship').add(
+                     Trigger('../feed_reb/decode_ship eq complete'),
+                  ),
+                  Task('rdb_metar').add(
+                     Trigger('../feed_reb/decode_metar eq complete'),
+                  ),
+               ),               
+            ),            
+
+    def task_trigger(name, condition):
+        return Task(name).add(Trigger(condition))
+
+    def echos():
+        echo = { 
+            "cleandb" : "0131",
+            "cleanerrdb": "0136",
+            "silmeb": "0141",
+            "silreb": "0146",
+            "run1": "0221",
+            "run2": "0421",
+            "run3":"0621",
+            "run4": '0821',
+            'run5': '1021',
+            'run6': '1321',
+            'run7': '1421',
+            'run8': '1621',
+            'run9': '1821',
+            'run10': '2121',
+            'eksikveritamamla': '2201',
+            'uydutsm': '0201',
+            'model_all_gunluk_tsm': '0131',
+            'radar_lokasyon_tip_tsm': '0501',
+            'retObsAndFtp_for_00': '0231',
+            'retObsAndFtp_for_18': '0241',
+            'retObsAndFtp_for_12': '1541',
+            'retObsAndFtp_for_06': '1101',
+            'retObsAndFtp_for_06gungeri': '0801',
+            'uydureport': '1655',
+            'radarreport': '0701',
+            'backuplog': '2301',
+            'cleanup': '2316'
+            }
+        out = []
+
+        for key in sorted(echo, key=echo.get, reverse=False): # order by value
+            # for key in sorted(echo.keys()): # order by key
+            out.append(task_trigger("echo_%s" % key, 
+                                    path + "/deps/%s" % echo[key] + " eq complete"))
+        return out
+        
+    return Family('main').add(
+            Trigger('deps/0000 eq complete'),
+         
+            Family('clean').add(
+               task_trigger('cleandb',
+                            path + '/deps/0130 eq complete'),
+
+               Task('clean_errdb').add(
+                  Trigger(path + '/deps/0135 eq complete'),
+               ),
+               Task('silmeb').add(
+                  Trigger(path + '/deps/0140 eq complete'),
+               ),
+               Task('silreb').add(
+                  Trigger(path + '/deps/0145 eq complete'),
+               ),
+            ),         
+            runs(1, "0220"),
+            runs(2, "0420"),
+            runs(3, "0620"),
+            runs(4, "0820"),
+            runs(5, "1020"),
+            runs(6, "1320"),
+            runs(7, "1420"),
+            runs(8, "1620"),
+            runs(9, "1820"),
+            runs(10, "2120"),
+            Family('model').add(
+               Task('eksikveritamamla').add(
+                  Trigger(path + '/deps/2200 eq complete'),
+               ),
+            ),            
+            Family('tsmarc').add(
+               Task('uydu_tsm').add(
+                  Trigger(path + '/deps/0200 eq complete'),
+               ),
+               Task('model_all_gunluk_tsm').add(
+                  Trigger(path + '/deps/0130 eq complete'),
+               ),
+               Task('radar_lokasyon_tip_tsm').add(
+                  Trigger(path + '/deps/0500 eq complete'),
+               ),
+            ),            
+            Family('ftpsenddata').add(
+               Task('retObsAndFtp_for_00').add(
+                  Trigger(path + '/deps/0230 eq complete'),
+               ),
+               Task('retObsAndFtp_for_18').add(
+                  Trigger(path + '/deps/0240 eq complete'),
+               ),
+               Task('retObsAndFtp_for_12').add(
+                  Trigger(path + '/deps/1540 eq complete'),
+               ),
+               Task('retObsAndFtp_for_06').add(
+                  Trigger(path + '/deps/1100 eq complete'),
+               ),
+               Task('retObsAndFtp_for_06gungeri').add(
+                  Trigger(path + '/deps/0800 eq complete'),
+               ),
+               Task('uydu_report').add(
+                  Trigger(path + '/deps/1654 eq complete'),
+               ),
+               Task('radar_report').add(
+                  Trigger(path + '/deps/0700 eq complete'),
+               ),
+            ),            
+            Family('cleanup').add(
+               Task('backuplog').add(
+                  Trigger(path + '/deps/2300 eq complete'),
+               ),
+               Task('cleanup').add(
+                  Trigger(path + '/deps/2315 eq complete'),
+               ),
+            ),            
+            Family('echo').add(
+               Variables(
+                  ECF_FILES= '/pp1/bin/dpp_sms/echo',),
+
+               echos(),           
+         ))
+
+
+def turkey_deps(num):
+    def item(hhmm):
+        return  Family(hhmm).add(
+               Complete("./%s/compl eq complete and " % hhmm + 
+                        './%s/dummy eq queued' % hhmm),
+            
+               Task('dummy').add(
+                  Cron('-w %d' % num + ' ' + hhmm[:2] + ":" + hhmm[-2:]),
+               ),
+               Task('compl').add(
+                  Complete("dummy eq active or " +
+                           "dummy eq submitted or " +
+                           'dummy eq complete'),
+                  Trigger('1 eq 0'),
+               ),
+            )
+
+    items = [ "0000",
+"0130",
+"0135",
+"0140",
+"0145",
+"0220",
+"0420",
+"0620",
+"0820",
+"1020",
+"1320",
+"1420",
+"1620",
+"1820",
+"2120",
+"2200",
+"0200",
+"0500",
+"0230",
+"0240",
+"1540",
+"1100",
+"0800",
+"1654",
+"0700",
+"2300",
+"2315",
+"0131",
+"0136",
+"0141",
+"0146",
+"0221",
+"0421",
+"0621",
+"0821",
+"1021",
+"1321",
+"1421",
+"1621",
+"1821",
+"2121",
+"2201",
+"0201",
+"0501",
+"0231",
+"0241",
+"1541",
+"1101",
+"0801",
+"1655",
+"0701",
+"2301",
+"2316", ]
+    def loop_items(): 
+        out = []
+        for hhmm in items: 
+            out.append(item(hhmm))
+        return out 
+
+    return Family('deps').add(
+            Variables(
+               ECF_FILES= '/pp1/bin/dpp_sms/haftalik',),
+            loop_items())
+
+def turkey_loop(suite_name):
+    out = []
+    days = [ "Pazartesi", "Sali", "Carsamba", "Persembe", "Cuma", "Cumartesi", "Pazar"]
+    days = [ "mon", "tue", "wed", "thu", "fri", "sat", "sun"]
+    start = 20120723; end=20301231 # beware addition below does not consider start as a date
+    path = "/%s/weekly/" % suite_name
+
+    for num in range(7): 
+        out.append(Family(days[num]).add(
+                Repeat(kind='date', name='YMD', 
+                       start= start + num, end=end, step=7),
+                turkey_deps(1),
+                turkey_main(days[num], path=path + days[num]),))
+    return out
+
+def turkey(suite_name):
+    return    Family('weekly').add(
+        Label("repeat", "run one family per week day"),
+        Label("time_trigger", "replace time dependencies with trigger"),
+        Label("aborted", "one aborted task requests being fixed within one week"),
+        Defcomplete(),
+        turkey_loop(suite_name),)
+
+##########################################################################
+## PURE
+
+class Languages(object):
+    def __init__(self): pass 
+    def task(self): return None
+    def scripts(self): pass
+
+class Python(Languages):
+    def task(self):
+        return (
+            Task("pure_python").add(
+                Variables(ECF_MICRO= "$",
+                          ECF_INCLUDE= wdir,
+                          SCHOST= "localhost",
+                          ECF_JOB_CMD= "use ecflow; $ECF_JOB$ > $ECF_JOBOUT$ 2>&1 &"),
+        Event("1"),
+        Label("info", ""),
+        Meter("step", -1, 100),
+        # Defstatus("complete"),
+        ),
+
+        Task("python").add(
+        Variables(ECF_MICRO= "$",
+                  ECF_INCLUDE= wdir,
+                  SCHOST= "localhost",
+                  ECF_JOB_CMD= "$ECF_JOB$ > $ECF_JOBOUT$ 2>&1 &"),
+        Event("1"),
+        Label("info", ""),
+        Meter("step", -1, 100),
+        # Defstatus("complete"),
+        ), )
+
+class Perl(object):
+    def task(self):
+        return Task("perl").add(
+            Label("todo", "time-stamp PS4, set eux, exit 0 1,"),
+            Variables(ECF_MICRO= "^",
+                      ECF_INCLUDE= wdir,
+                      SCHOST= "localhost",
+                      ECF_JOB_CMD= "^ECF_JOB^ > ^ECF_JOBOUT^ 2>&1 &"),
+            Event("1"),
+            Label("info", ""),
+            Meter("step", -1, 100),
+            # Defstatus("complete"),
+            )
+
+class Ruby(object):
+    def task(self):
+        return Task("ruby").add(
+            Label("todo", "time-stamp PS4, set eux, exit 0 1,"),
+            Variables(ECF_MICRO= "^",
+                      ECF_INCLUDE= wdir,
+                      SCHOST= "localhost",
+                      ECF_JOB_CMD= "^ECF_JOB^ > ^ECF_JOBOUT^ 2>&1 &"),
+            Event("1"),
+            Label("info", ""),
+            Meter("step", -1, 100),
+            Defstatus("complete"),
+            )
+
+    def scripts(self):
+        head = """#!/usr/bin/env ruby"""
+        tail = """ """
+        body = """ """
+        create_wrapper("head.rb", head)
+        create_wrapper("tail.rb", tail)
+        create_wrapper("ruby.sms", body)
+
+ruby = Ruby()
+perl = Perl()
+pyth = Python()
+
+WDIR= "/scratch/ma/map/sms"
+HLOG= "/home/ma/map/logs"
+
+hosts = {"lxb" : { "COMPILER": "gcc-4.3", # linux64
+                   "SCHOST": "lxb", 
+                   "QUEUE_EPILOG": "serial",
+                   "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                   "QUEUE": "serial",
+                   "WDIR": WDIR, }, 
+         "ibis" : { "COMPILER": "gcc",
+                    "SCHOST": "ibis", 
+                    "WDIR": WDIR, }, 
+         "lxop" : {  "COMPILER": "gcc-4.3",
+                    "SCHOST": "lxop",
+                     "QUEUE": "test", 
+                     "QUEUE_EPILOG": "test",
+                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                     "COMPILE_DIR": "/gpfs/lxop/emos_data/sms", 
+                    "WDIR": "/gpfs/lxop/emos_data/sms", 
+                     }, 
+         "opensuse103": { "COMPILER": "gcc-4.5",
+                         "SCHOST": "opensuse103", 
+                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                         "WDIR": WDIR, }, 
+         "opensuse113": { "COMPILER": "gcc-4.5",
+                         "SCHOST": "opensuse113", 
+                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                         "WDIR": WDIR, }, 
+         "opensuse131": { "COMPILER": "gcc-4.8",
+                         "SCHOST": "opensuse131", 
+                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                         "WDIR": WDIR, }, 
+         "ecgb": { "COMPILER": "gcc-4.4.7", # redhat
+                   "QUEUE": "normal", 
+                   "QUEUE_EPILOG": "normal",
+                   "SCHOST": "ecgb", 
+                     "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                    "WDIR": WDIR, }, 
+         "lxc": { "COMPILER": "gcc-4.4.7", # redhat
+                   "QUEUE": "normal", 
+                   "QUEUE_EPILOG": "normal",
+                   "SCHOST": "lxc", 
+                   "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                   "WDIR": WDIR, }, 
+         "cct": { "COMPILER": "gcc",
+                  "QUEUE_EPILOG": "ns",
+                  "SCHOST": "cct", 
+                  "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                  "COMPILE_DIR": "/home/ma/map/sms", 
+                  "WDIR": "/home/ma/map/sms", }, 
+         "cca": { "COMPILER": "gcc",
+                  "QUEUE_EPILOG": "ns",
+                      "SCHOST": "cca", 
+                       "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                       "WDIR": "/home/ma/map/sms", }, 
+         "ccb": { "COMPILER": "gcc",
+                  "QUEUE_EPILOG": "ns",
+                      "SCHOST": "ccb", 
+                       "LOGDIR": HLOG, "ECF_OUT": HLOG, 
+                      "WDIR": "/home/ma/map/sms", 
+                  "COMPILE_DIR": "/home/ma/map/sms", 
+                  },          }
+
+class Compile(object):
+
+    def __init__(self):
+        pass
+
+    def compile(self, host=None, add=None, but=None):
+        version = "4.4.15"
+        if host is None: dest = list(hosts.keys())
+        else: dest = (host, )
+        out = []
+        for host in sorted(dest):
+            if not but: pass
+            elif host == but or host in but: continue
+            out.append(Family(host).add(
+                    add,
+                    Variables(hosts[host]),
+                    Variables(ECF_FILES= wdir,
+                              VERSION= version,
+                              ECF_INCLUDE= idir,         ),
+                    Task("get"),
+                    Task("make").add(Trigger(["get"])),
+                    Task("install").add(Defcomplete(),
+                                     Trigger(["make"])),
+                    Task("testit").add(Event("cdp"),
+                                       Event("sms"),
+                                       Event("child"),
+                                       Event("xcdp"),
+                                       Trigger(["make"])),
+                    Task("child").add(Defcomplete(),
+                                      Variables(SMS_VERSION= "4.4.15",),
+                                      Label("info", ""),
+                                      Event("1"),
+                                      Meter("step", -1, 100)),
+                    ))
+        return out
+
+    def main(self):
+        self.create_tasks()
+        return Family("sms").add(Family("compile").add(
+            Defstatus("suspended"),
+            # onws("localhost"),
+            Variables(SCHOST= "localhost"),
+            Task("prepare"),
+            self.compile("ibis", add=Trigger("prepare==complete")),
+            Family("remote").add(Trigger("prepare==complete"),
+                                 self.compile(but="ibis"),)))
+
+    def wrap(self, content):
+        return '''#!/bin/ksh
+# generated by cray.py
+%%manual
+  start - check - stop logsvr
+%%end
+%%include <qsub.h>
+%%include <step1.h>
+%%include <trap.h>
+%s 
+%%include <endt.h>
+%%include <step2.h>''' % content
+
+    def create_tasks(self):
+        source = "%SOURCE_DIR:/tmp/map/work/git/sms%"
+        compil = "%COMPILE_DIR:/scratch/ma/map/sms/$ARCH/%/%SCHOST:$HOST%"
+        task = self.wrap("cd %s/sms; make clean; cd ../; tar -czf sms.tgz sms; " % source)
+        create_wrapper("prepare.sms", task)
+        
+        task = self.wrap("comp=%s; " % compil + 
+                         "mkdir -p $comp; cd $comp; scp ibis:%s/sms.tgz .;" % source +
+'''rm -rf sms.tar sms || :
+gzip -d sms.tgz; tar -xf sms.tar''')
+        create_wrapper("get.sms", task)
+
+        task = self.wrap("comp=%s;" % compil + 
+                         '''cd $comp/sms; 
+if [[ $ARCH == cray ]]; then
+module switch PrgEnv-cray PrgEnv-intel
+export CRAYPE_LINK_TYPE=dynamic
+fi
+make %TARGET:linux%''')
+        create_wrapper("make.sms", task)
+
+        task = self.wrap("comp=%s;" % compil +  
+                         '''cd $comp/sms; make tester; 
+mkdir -p %SMSHOME:/tmp/$USER%
+SMS_PROG=900001 sms &
+sleep 10
+xevent sms
+SMS_PROG=900001 smsping localhost || :
+./cdp/cdp -c 'set SMS_PROG 900001; login $HOST $USER 1; terminate -y; exit 0'
+xevent cdp
+DISPLAY=ibis:0.0 ./xcdp/xcdp &
+xevent xcdp
+ln -sf ./cdp/child smsevent
+./smsevent child
+rm -f smsevent''')
+        create_wrapper("testit.sms", task)
+
+        task = self.wrap("xevent 1; xlabel info test; xmeter step 0; xmeter step 100;")
+        create_wrapper("child.sms", task)
+
+##########################################################################
+## BARBER
+
+def call_barber_passerby():
+    # family passby
+    # limit to one at a time entering the
+    # shop to check if there is room to
+    # stay in there
+    return Task("passby").add(
+        Cron("00:00 23:59 00:01"),
+    # this one is regular
+        Variables(ID= 0),
+        Inlimit("limit:passby"))
+    # other frequent passers by can be added here
+# called by client generator task
+
+def call_barber_client(id):
+    return Family(id).add(
+    # to be called by passby to create a new client
+        Task("cut").add(
+            Inlimit("../limit:barbers")),
+    # there may be many barbers in the shop
+    # but one cashier only
+        Task("pay").add(
+            Trigger("./cut == complete"),
+            Inlimit("../limit:barbers"),
+            Inlimit("../limit:cashiers")),
+        Task("leave").add(
+            Trigger("cut==complete and pay==complete"),
+            If(id % 2 == 0,
+               Defcomplete(),
+               Autocancel( "0" ))))
+
+# main definition
+def call_barber_shop():
+    return Family("shop").add(
+        Defstatus("suspended"),
+        Variables(NB_CHAIRS= 4),
+
+        Family("limit").add(
+            Defcomplete(),
+            Limit("passby", 1),
+            Limit("barbers", 1),
+            Limit("cashiers", 1)),
+
+        call_barber_passerby(),)
+
+##########################################################################
+## dinner
+total_number = 5
+life_expectency = 100
+def requeued():
+    return Repeat("iter", 1, life_expectency, kind= "integer")
+    # possibility to requeue the task without duration limit
+    # provided 02:00 is below the task duration:
+    # cron 00:00 23:59 02:00
+
+def triggered(ref, tor=None, tand=None):
+    trg = ""
+    tr2 = ""
+    if tand: trg = " and %s" % tand
+    if tor:  tr2 = " or %s" % tor
+    return Trigger("(%s != active and %s != submitted and %s != aborted" 
+                % (ref, ref, ref) + trg + ")" + tr2)
+
+def philosopher(id, s1, s2, version):
+    return Family("%d" % id).add(
+        Task("eat").add(
+            Inlimit("../limit:"+str(s1)),
+            Inlimit("../limit:"+str(s2)),
+            Event("release")),
+        If( version == "normal",
+                # eat task a3ttribute
+                # TBD triggered("think")
+                ( requeued(),
+
+                  Task("think").add(
+                        requeued(),
+                        triggered( "eat", tor="eat:release or eat==complete")))),
+        If( version == "simple",
+                (Task("release").add(
+                        Trigger("eat:release or eat==complete"),),
+                 requeued())))
+
+def call_dinner():
+    out = Family("dinner").add(
+        Variables(SLEEP= 10),
+        Defstatus("suspended"),
+        )
+    for version in "simple normal".split():
+        # Xcdp would fold parent family when limits change
+        # we prefer to store them in a dedicated family then
+        lim = Family("limit").add(
+                    Defcomplete(),)
+# for num 1 $total_number do num 1 $total_number do
+# $total_number do num 1 $total_number do
+        num = 1
+        while num <= total_number:
+            lim.add(Limit(str(num), 1))
+            num += 1; # endfor
+        ver = Family(version).add(lim)
+        out.add(ver)
+# for num 1 $total_number do num 1 $total_number do
+# $total_number do num 1 $total_number do
+        num = 1
+        while num <= total_number:
+            stick1 = num
+            stick2 = 1 + ((num) % total_number)
+            ver.add(philosopher( num, stick1, stick2, version))
+            num += 1; # endfor
+    return out
+
+##########################################################################
+## CONSUMER
+# /home/ma/map/course/course2011/src/consumer.py
+beg =  0
+fin = 48
+by  =  3
+    
+def not_consumer(): return Variables(CONSUME= "no")
+
+def not_producer(): return Variables(PRODUCE= "no")
+
+def ev():return (Event("p"), Event("c"))
+
+def call_task(name, start, stop, inc):
+    meter = None
+    if start != stop:
+        meter = Meter( "step", -1, int(stop))
+
+    return Task(name).add(
+        ev(),
+        Variables(BEG= start,
+                  FIN= stop,
+                  BY= inc),
+        meter)
+
+def call_consumer(SELECTION):
+    # defstatus suspended # avoid early start
+    def consume1(leap = 1, leap_nb = 3):
+        out = []
+        while leap <= leap_nb:
+            leap_beg = beg + by * (leap - 1)
+            leap_by = by * leap_nb
+            out.append(Family("%d" % leap).add(
+                    call_task( "consume", "'%STEP%'", "'%STEP%'", leap_by).add(
+                        Repeat("STEP", leap_beg, fin, leap_by, kind="integer"),
+                        # same trigger as consume0
+                        # Trigger("(%s and (consume:STEP le %s1/produce:STEP)) or " % (lead, prod) + 
+                        #         "(not %s and (consume:STEP le %s0/produce:step))" % (lead, prod))
+                        Trigger("(consume:STEP le %s1/produce:STEP)" % prod),
+                       )))
+            leap += 1;
+        return out
+
+    def consume2(idx, fin):
+        out = []
+        while idx <= fin:  
+            out.append(Family("%03d" % idx).add(
+                    call_task( "consume", idx, idx, by).add(
+                        Variables(STEP= idx),
+                        # Same trigger as consume0
+                        # Trigger("(%s and (consume:STEP le %s1/produce:STEP)) or " % (lead, prod) +
+                        #         "(not %s and (consume:STEP le %s0/produce:step))" % (lead, prod))))
+                        Trigger("consume:STEP le %s1/produce:STEP" % prod),
+                       )))
+            idx += by
+        return out
+
+    lead = "/%s/consumer/admin/leader:1" % SELECTION
+    prod = "/%s/consumer/produce" % SELECTION
+    if 1: return Family("consumer").add(Defcomplete()) # FIXME
+    return Family("consumer").add(
+        Defcomplete(),
+
+        Variables(SLEEP= 10,
+                  PRODUCE= "no",
+                  CONSUME= "no"),
+
+             Family("limit").add(
+                Defcomplete(),
+                Limit("consume", 7),),
+
+             Family("admin").add(
+                # set manually with Xcdp or alter the event 1 so
+                # that producer 1 becomes leader
+                # default is producer0 leads
+                Task("leader").add(
+                    Event("1"),
+                    Defcomplete())),
+             # text this task is dummy task not designed to run
+
+             # default : task does both :
+                 Variables(PRODUCE= "yes",
+                           CONSUME= "yes"),
+             # this task will do both, ie serial
+
+             call_task( "produce", beg, fin, by).add(
+            Label("info", "do both at once"),),
+             # this will loop inside the task, reporting
+             # its processed step as a meter indication
+
+             Family("produce0").add(
+                not_consumer(),
+                call_task( "produce", beg, fin, by )),
+             # here, choice is to push a new task for each step
+
+             Family("produce1").add(
+                not_consumer(),
+                call_task( "produce", '%STEP%', "%STEP%", by ).add(
+                Repeat("STEP", beg, fin, by , kind="integer"), )),
+             # PRB edit FIN '$((%STEP% + %BY%))'
+
+             Family("consume").add(
+                not_producer(),
+                Inlimit("limit:consume"),
+                Variables(CALL_WAITER= 1,
+                          # $step will be interpreted in the job!
+                          TRIGGER= "../produce:step -gt consume:$step or ../produce eq complete"),
+                call_task( "consume", beg, fin, by ).add(
+                )),
+             
+             Family("consume0or1").add(
+                not_producer(),
+                Inlimit("limit:consume"),
+                call_task( "consume", "%STEP%", "%STEP%", by, ),
+                Repeat( "STEP", beg, fin, by, kind="integer"),
+                Trigger("(%s and (consume0or1:STEP le %s1/produce:STEP)) or "
+                        % (lead, prod) +
+                        "(not %s and (consume0or1:STEP le %s0/produce:step))"
+                        % (lead, prod))),
+
+             Family("consume1").add(
+                not_producer(),
+                Inlimit("limit:consume"),
+                consume1()),
+
+             Family("consume2").add(
+    # loop is "exploded"
+    # consume limit may be changed manually with Xcdp
+    # to reduce or increase the load
+                Inlimit("limit:consume"),
+                not_producer(),
+                consume2(beg, fin)))
+
+##########################################################################
+class Cray(ic.SeedOD):
+    def __init__(self):
+        super(Cray, self).__init__()
+
+    def setup(self, node):
+        account= "UNSET"
+        global user, host
+        if user == "emos" or host in ("ode", "eode", "ecf"):
+            rdir = "/vol/lxop_emos_nc/output"
+            user= "emos"
+            account= "oesu"
+        else: pass
+        self.defs.add_extern("/o/main:YMD")
+
+        node.add(
+            Clock("real"),
+            Defstatus("suspended"),
+            Label("info", "test,logsvr tasks generated by cray.py"),
+            Event("1"),
+            Meter("step", -1, 100),
+            Repeat(kind="day", step=1),
+            limits(),
+
+            Variables(ECF_JOB_CMD= SUBMIT,
+                      ECF_KILL_CMD= KILL,
+                      ECF_STATUS_CMD= STATUS,
+                      ECF_CHECK_CMD= CHECK,
+                      # ECF_EXTN= ".sms",
+                      ACCOUNT=  "UNSET",
+                      SCHOST= "localhost",
+                      ECF_INCLUDE= idir,
+                      ECF_HOME= jdir,
+                      ECF_FILES= wdir,
+                      QUEUE= "ns", USER= user, LOGDIR= "/tmp",
+                      TOPATH= udir + "/logs",
+                      SLEEP=    1,     # x120
+                      ECF_TRIES= 1,),
+
+            Family("looper").add(Time("09:00"),
+                                 Variables(SCHOST= "ibis"),
+                                 dummy()), # .add(Defcomplete())),
+
+            create_de(),
+
+            smhi(),
+
+            Compile().main(),
+
+            Task("dummy").add(Time("16:00"),
+                              Variables(SCHOST= "localhost",
+                                        FAMILY= "unset",
+                                        FAMILY1= "unset"),
+                              Time("17:00"),),
+
+            fam_ui(),
+
+            # turkey(ic.selection()),
+
+            sapp(),
+
+            Family("maker").add(maker(),),
+
+            call_consumer(ic.selection()).add(
+                Label("repeat", "repeat may be attached to a family, or a task, to facilitate requeue or not"),
+                Label("event", "event may be set by the task itself, by a user, by a third party job"),
+                Label("trigger", "can be on the task-family node, or inside a task (wait)"),
+                Label("deadlock", "produce0/produce complete with step=-1"),
+                Label("latency", "between task wrapper creation, and new file visible from the server"),
+                Label("ZZZ", "icon when the job is waiting the trigger condition"),
+                Variables(QUEUE= "ns", USER= user, LOGDIR= "/tmp",
+                          SCHOST="localhost"),),
+
+            call_barber_shop().add(Defstatus("complete"),),
+
+            call_dinner().add(Defstatus("complete"),),
+
+            pyth.task(),
+
+            perl.task(),
+
+            ruby.task(),
+
+            Family("blacklist").add(
+                Event("cca"),
+                Event("ccb"),
+                Event("hps"),
+                
+                Defstatus("complete"))            )
+
+        msg = "have you? setup ssh login, created remote directory" 
+        msg += ", set START_LOGSVR=1 (edit task), once, to launch the logserver"
+        if "eod" in host: user = "emos"
+        print("#MSG: host, user", host, user)
+
+        node = node.family("submit").add(
+            unit("jonas", "ibis", "no", "/tmp/$USER/jobs", add=(Today("07:00"),
+                                                                Today("21:00"))),
+            Variables(USER=     user,
+                      ACCOUNT=  account), # 
+
+            # Time("09:00"),
+
+            self.arg4(),
+            self.burst(),
+            # self.arg3(),
+            # self.prb(),
+
+            )
+
+    def burst(self):
+        sub = "/home/ma/emos/bin/smssubmit "
+        out = []
+        for num in range(0, 10):
+            out.append(Family("%03d" % num).add(Task("test")))
+        
+        return Family("arg3").add(
+            Defstatus("complete"),
+            Variables(SCHOST= "cca-b"),
+            out
+            )
+
+    def arg3(self):
+        sub = "/home/ma/emos/bin/smssubmit "
+        return Family("arg3").add(
+            Defstatus("complete"),
+
+            self.submits(),
+
+            Variables(ECF_JOB_CMD= sub +"%USER% %SCHOST% %ECF_JOB%",
+                      ECF_KILL_CMD= sub + "%USER% %SCHOST% %ECF_JOB% kill",
+                      ECF_STATUS_CMD= sub + "%USER% %SCHOST% %ECF_JOB% status",
+                      ),
+            )
+
+    def arg4(self):
+        return Family("arg4").add(self.submits())
+
+    def prb(self):
+        sub = "/home/ma/emos/bin/smssubmit "
+        return Family("prb").add(
+            Defstatus("complete"),
+            self.submits(),
+            Label("info", "simulate prb at submission with % remaining"),
+            Variables(ECF_JOB_CMD= sub +"%USER% %SCHOST% %ECF_JOB% %STTHOST%%ECF_JOBOUT%",
+                      ECF_KILL_CMD= sub + "%USER% %SCHOST% %ECF_JOB% %STTHOST%%ECF_JOBOUT% kill",
+                      ECF_STATUS_CMD= sub + "%USER% %SCHOST% %ECF_JOB%  %STTHOST%%ECF_JOBOUT% status",
+                      ),                  )
+
+    def submits(self):
+        global host, user
+        def parallel(pes=1, thr=1, hyp="no"):
+            return Family("p%d_%d_%s" %(pes, thr, hyp)).add(
+                Variables(NPES=pes, THREADS=thr,                           
+                          HYPER=hyp), 
+                Task("test").add(Label("info", ""), 
+                                 Meter("step", -1, 120),
+                                 Event(1)))
+        ct1logs= "/sc1/tcwork/emos/logs"
+        # ct1logs = '/home/ma/%s/logs' % user
+        if ecflow: base = 1000
+        else: base = 900000
+        base = 1000
+        if "eod" in host: user = "emos"
+
+        out = [
+
+            unit("cray", HCRAY, "ns", ct1logs, leaf=False).add(
+                unit("ccp", "cca-login1", "ns", ct1logs).add(
+                    Complete(ic.psel() + "/blacklist:cca"),),
+                unit("cca", "cca-login1", "ns",    ct1logs).add(
+                    logsvr("ping"),
+                    Complete(ic.psel() + "/blacklist:cca"),),
+                unit("ccb", "ccb-login1", "ns",    ct1logs).add(
+                    logsvr("ping"),                    ),
+                Family("parallel_a").add(
+                    # Defcomplete(), ###
+                    Complete(ic.psel() + "/blacklist:cca"),
+                    Variables(SCHOST= "cca",
+                              QUEUE= "os",
+                              LOGHOST= "cca-il2",
+                              ECF_OUT= ct1logs,
+                              LOGDIR=  ct1logs,),
+                    parallel(1, 1),
+                    parallel(1, 24),
+                    parallel(2, 12),
+                    parallel(2, 24),
+                    parallel(2, 15),
+                    
+                    parallel(1, 2, "yes"),
+                    parallel(2, 24, "yes"),
+                    parallel(24, 2, "yes"),
+                    parallel(10, 5, "yes"),),
+
+                Family("parallel_b").add(
+                    Complete(ic.psel() + "/blacklist:ccb"),
+                    Variables(SCHOST= "ccb",
+                              QUEUE= "os",
+                              LOGHOST= "ccb-il2",
+                              ECF_OUT= ct1logs,
+                              LOGDIR=  ct1logs,),
+                    parallel(1, 1),
+                    parallel(1, 24),
+                    parallel(2, 12),
+                    parallel(2, 24),
+                    parallel(2, 15),
+                    
+                    parallel(1, 2, "yes"),
+                    parallel(2, 24, "yes"),
+                    parallel(24, 2, "yes"),
+                    parallel(10, 5, "yes"),),
+
+                If(user == "emos",
+                   Variables(LOGHOST= HCRAY,
+                             LOGPORT= base + get_uid()),
+                   Variables(LOGHOST= HCRAY,
+                             LOGPORT= base + get_uid())),
+                )
+            ]      
+
+        lxop_out = "/vol/lxop_emos_nc/output"
+        if user == "emos" or host in ("ode", "eode", "ecf"):
+            ic.SUBM = "/home/ma/emos/bin/trimurtu"
+            sms2ecf.subm = "/home/ma/emos/bin/trimurti"
+
+            out += (
+                Variables(LOGPORT= 9316),
+                unit("cca", "cca", "ns", "/sc1/tcwork/emos_dir", "oesu").add(
+                    Variables(STHOST= "/c1",
+                              LOGHOST= "cca"),
+                    logsvr("ping"),
+                    Complete(ic.psel() + "/blacklist:cca"),),
+
+                unit("ecgb", "ecgb", "emos", "/vol/emos_nc/output"),
+                unit("lxc", "lxc", "emos", "/vol/emos_nc/output"),
+                unit("lxab", "lxab", "serial", "/vol/emos_nc/output"),
+                unit("lxop", "lxop", "emos", lxop_out
+                     ).add(Variables(ECF_OUT= lxop_out,
+                                     ECF_LOGHOST= "lxop",
+                                     ECF_LOGPORT= 9316,
+                                     LOGDIR=  lxop_out, )),
+                unit("sappa", "sappa", "serial", "/vol/emos_nc/output"),
+                unit("sappb", "sappb", "serial", "/vol/emos_nc/output"),
+                unit("opensuse131", "opensuse131", "serial", "/vol/emos_nc/output"),
+                Family("hps").add(
+                    Complete(ic.psel() + "/blacklist:hps"),
+                    unit("acq", "acq", "emos", "/tmp/emos"),
+                    unit("pp1", "pp1", "emos", "/tmp/emos"),
+                    unit("pp2", "pp2", "emos", "/tmp/emos"),
+                    unit("pp3", "pp3", "emos", "/tmp/emos"),
+                    unit("pp4", "pp4", "emos", "/tmp/emos"),
+                    unit("bilbo", "bilbo", "emos", "/tmp/emos"),
+                    unit("hallas", "hallas", "emos", "/tmp/emos"),
+                    # unit("itanium", "itanium", "emos", "/tmp/emos"),),
+                unit("localhost", "localhost", "ns", "/tmp/emos/logs"),
+                unit("ibis", "ibis", "ns", "/tmp/emos/logs"),
+                ))
+        else:
+            rdir = "/tmp"
+            out += (unit("localhost", "localhost", "ns", "/tmp/%s/logs" % user),
+                     unit("lxab", "lxab", "serial", udir + "/logs"),
+                     unit("lxop", "lxop", "emos", udir + "/logs"),
+                     unit("ecgb", "ecgb", "ns", udir + "/logs"),
+                     unit("lxc", "lxc", "ns", udir + "/logs"),         )
+        return out
+
+def maker():
+    return Task("maker").add(
+        Variables(ECF_FILES= wdir,
+                  ECF_INCLUDE= "/home/ma/emos/def/o/include",
+                  WSHOST= "ibis",
+                  USER= "emos",
+                  SCHOST= "ibis",
+                  ECF_OUT= "/vol/lxop_emos_nc/output",),   )
+
+def usage():
+    print('''cray.py -h -u [user] -n [node] -s [suite-name] \
+ -e: ecflow''')
+
+if __name__ == "__main__":
+    global user, udir, ecflow, host
+    suites = { "cray": Cray,
+               "test": Cray,
+           }
+    # suite = "test"; node = "eode"
+    # argv = cli_proc.process(suites, selection=suite, host=node)
+    user = get_username()
+    try: host = sys.argv[-1]
+    except: host= "localhost"
+    ecflow  = False
+    ecflow  = True
+    suite   = None
+    user = get_username()
+    opts, args = getopt.getopt(
+          sys.argv[1:], "hp:u:es:n:p:", 
+          ["help", "port", "user", "ecflow", "suite", "node", "path"])
+    print("#MSG: opts, args", opts, args)
+
+    output = None
+    verbose = False
+    for o, a in opts:
+        if   o in ("-n", "--node"):   host = a
+        elif o in ("-h", "--help"):   usage(); sys.exit()
+        elif o in ("-s", "--suite"):  suite =  a
+        elif o in ("-p", "--path"):   path =  a
+        elif o in ("-e", "--ecflow"): ecflow = True
+        elif o in ("-u", "--user"):
+            user = a
+        elif o in ("-p", "--port"):
+            port = a
+        else: print("#ERR: what?", o, a); assert False, "unhandled option"
+
+    import cli_proc
+
+    if suite is None: 
+        cli_proc.ip.SELECTION = user
+    elif '/' in suite:
+        sel = suite
+        if '/' == suite[0]: sel = sel[1:]
+        if '/' in sel: sel, family = sel.split('/', 1)
+        cli_proc.ip.SELECTION = sel
+    else: cli_proc.ip.SELECTION = suite
+
+    if ecflow and host not in ("ode", "map", "pikachu"):
+        ic.ecf.ECF_MODE = "ecflow"
+    else: 
+        import sms2ecf
+        sms2ecf.ECF_MODE = "sms"
+        ic.ecf.ECF_MODE = "sms"
+
+    print("#MSG: ecflow/sms: ", ic.ecf.ECF_MODE)
+    global wdir, rdir, fdef, jdir
+
+    ########### SETTINGS ################
+    udir = pwd.getpwnam(user).pw_dir
+    wdir = udir + "/course/cray"
+    rdir = "/sc1/tcwork/emos/logs"
+    fdef = wdir + "/cray.def"
+    jdir = "/tmp/%s/cray" % user
+    ddef = udir + "/course/cray"
+    fdef = ddef + "/cray.def"
+    idir = "/home/ma/emos/def/cray/include"
+    if user == "map" or host in ["map", ]:
+        wdir = "/home/ma/map/course/cray"
+    elif user == "emos" or host in ["ode", "od3", "eode"]:
+        jdir="/vol/lxop_emos_nc/output"
+        rdir="/vol/lxop_emos_nc/output"
+        udir="/vol/lxop_emos_nc/output"
+
+    print("##", host, suite)
+    argv = cli_proc.process(suites, selection=suite, host=host, proc=False)
+    try:    os.makedirs(wdir)
+    except: pass # one line on purpose
+    try:    os.makedirs(jdir)
+    except: pass
+
+    create_task()
+    create_smhi()
diff -pruN 5.12.4-1/libs/pyext/samples/def2def.py 5.13.0-1/libs/pyext/samples/def2def.py
--- 5.12.4-1/libs/pyext/samples/def2def.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/def2def.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,387 @@
+#!/usr/bin/env python
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+import sys
+import getopt
+try: import ecflow
+except:
+        sys.path.append("/usr/local/apps/ecflow/current/lib/python2.7/site-packages/ecflow")
+        import ecflow 
+import ecflow  as ec
+import os
+import sys
+""" a simple program to convert an expanded definition file to 
+py script using ecf.py"""
+
+class Indent:
+    """This class manages indentation, for use with context manager
+    It is used to correctly indent the definition node tree hierarchy
+    """
+    _pos = 0
+    _step = 3
+    def __init__(self):
+        Indent._pos += Indent._step
+    def __del__(self):
+        Indent._pos -= Indent._step
+    @classmethod
+    def indent(cls, loc=''):
+        out = ''
+        for i in range(Indent._pos):
+            if loc is None: 
+                out += ' ' 
+            elif type(loc) == str: 
+                loc += ' '
+            else: 
+                loc.write(' ')
+        if type(loc) == str: 
+            return loc
+        return out
+
+def adds(line=0):
+    if line is None: 
+        return ""
+
+    return Indent.indent() + line + "\n"
+
+def add(line, echo=0):
+    if line is None: 
+        return ""
+    elif echo: 
+            return Indent.indent() + line 
+    else: 
+            return Indent.indent() + line + "\n"
+
+class DefFormat(object):
+    def __init__(self, defs): 
+        self.defs = defs
+
+    def process_attr(self, node, end=False):
+        # print node.get_abs_node_path()
+        res = ""
+        ind = Indent()
+        defstatus = node.get_defstatus()
+        if defstatus: 
+            if defstatus != ec.DState.queued:
+                res += add("Defstatus('%s')," % defstatus)
+
+        item = node.get_autocancel()
+        if item: 
+            line = "%s" % item
+            line = line.replace("autocancel ", "")
+            res += add("Autocancel('%s')," % line)
+
+        item = node.get_repeat()
+        if not item.empty(): 
+            line = "%s" % item
+            full = line.split()
+            kind = full[1]
+            name = full[2]
+            try:
+                beg  = full[3]
+                try: end  = full[4]
+                except: end = beg
+                if "#" in end: end = beg
+            except: beg = 1; end = 1
+            by = 1
+            if len(full) == 6: by = full[5]
+
+            if kind in ("integer", "date"):
+                res += add(
+                    "Repeat(kind='%s', name='%s', start=%s, end=%s, step=%s)," 
+                    % ( kind, name, beg, end, by))
+            elif kind in ("day", ):
+                res += add(
+                    "Repeat(kind='%s', name='%s', step=%s)," 
+                    % ( kind, name, by))
+            elif kind in ("string", "enumerated"):
+                line = "%s" % item
+                line = line.replace("repeat %s %s" % (kind, name), "")
+                line.replace('"', '')
+                res += add("Repeat(kind='%s', name='%s', start=%s)," % (
+                        kind, name, line.split()))
+             # FIXME string enum
+
+        item = node.get_late()
+        if item: 
+            line = "%s" % item
+            line = line.replace("late ", "")
+            res +=  add("Late('%s')," % line)
+
+        item = node.get_complete()
+        if item: res += add("Complete('%s')," % item)
+
+        item = node.get_trigger()
+        if item: 
+            res += add("Trigger('%s')," % item)
+
+        for item in node.meters: 
+            line = "%s" % item
+            dummy, name, beg, end, thr = line.split(" ")
+            res += add("Meter('%s', %s, %s, %s)," % (name, beg, end, thr))
+
+        for item in node.events: 
+            line = "%s" % item
+            line = line.replace("event ", "").strip()
+            res += add("Event('%s')," % line)
+
+        for item in node.labels: 
+            res += add("Label('%s', '%s')," % (item.name(), item.value()))
+
+        for item in node.limits: 
+            val = item.value()
+            if val == "0" or val == 0: 
+                val = "1"
+            res += add("Limit('%s', %d)," % (
+                    item.name(), int(val)))
+
+        for item in node.inlimits:
+            line = "%s" % item
+            line = line.replace("inlimit ", "")
+            res += add("InLimit('%s')," % line)
+
+        for item in node.times:  
+            line = "%s" % item
+            line = line.replace("time ", "")
+            res += add("Time('%s')," % line)  
+
+        for item in node.todays: 
+            line = "%s" % item
+            line = line.replace("today ", "")
+            res += add("Today('%s')," % line) 
+
+        for item in node.dates:  
+            line = "%s" % item
+            line = line.replace("date ", "")            
+            res += add("Date('%s')," % line)  
+
+        for item in node.days:   
+            line = "%s" % item
+            line = line.replace("day ", "")            
+            
+            res += add("Day('%s')," % item)   
+        for item in node.crons:  
+            line = "%s" % item
+            line = line.replace("cron ", "")            
+            res += add("Cron('%s')," % line)  
+
+        var = "Variables("
+        vind = Indent()            
+        num = 0
+        for item in node.variables: 
+            sep="'"
+            if sep in item.value(): sep="\""
+            var += ind.indent("\n") + item.name() + \
+                "= %s%s%s," % (sep, item.value(), sep)
+            num += 1
+        del vind        
+        if num: res += add(var + "),")
+
+        del ind
+        if len(res) == 0: 
+            return None
+        return res
+
+    def process(self, node=None, inc=0):
+        STREAM = 1
+        out = ""
+        if node is None:
+            num = 0
+            out += "# ecf.ECF_MODE = 'sms'"
+            out += "suites = []"
+            for suite in self.defs.suites:
+                if STREAM: out += "suite%d = Suite('%s').add(" % (num, suite.name())
+                else: out += "s = Suite('%s')"% (suite.name()) + "; suites.append(s);"
+                out += self.process(suite)
+                out += ")"
+                num += 1
+            else: out += "#WAR no suite to process"
+
+            if num > 1: 
+                if 0: raise BaseException("no more than one suite at a time")
+                out += "### WARNING: more than one suite defined"
+
+        elif isinstance(node, ec.Suite): 
+            if not STREAM: out += "s.add(\n"
+            add( self.process_attr(node),1 )
+            if STREAM: ind = Indent()
+            for kid in node.nodes: out += self.process(kid)
+            if STREAM: del ind
+
+        elif isinstance(node, ec.Family): 
+            many = ""; one = ""; post = "" # circumvent limitation to 255 items
+            if inc % 200 == 0: 
+                one += "("; post = "),"
+                if inc > 200: many = "),"
+            if STREAM: 
+                add( many + one + "Family('%s').add(" % node.name(), 1)
+                res = self.process_attr(node)
+            else:
+                out += ")\ncur = Family('%s')" % node.name()
+                out += "fam.add(cur); fam = cur; fam.add("
+                res = self.process_attr(node)
+
+            if STREAM: 
+                if res is not None: 
+                        out += Indent.indent(res) # add(res, 1)
+                ind = Indent()
+            num = 0
+            for kid in node.nodes: self.process(kid, num)            ; num += 1
+            if STREAM: 
+                del ind
+                add( Indent.indent(post + "), # endfamily %s" % node.name()), 1 )
+            out += "# %s " % num
+
+        elif isinstance(node, ec.Task): 
+            res = self.process_attr(node)
+            if res is None:  
+                add( "Task('%s')," % node.name(), 1)
+                # print Indent.indent("Task('%s')," % node.name())
+            else: add( "Task('%s').add(\n" % node.name() +
+                       "%s%s)," % (res, Indent.indent()), 1)
+
+        return out
+
+    def main(self):
+        return self.head() + self.process() + self.tail()
+
+    def head(self):
+        return """#!/usr/bin/env python
+# NOTICE: this file was originally created with def2def.py
+import sys
+# sys.path.append('../o/def')
+# sys.path.append('.')
+sys.path.append('/home/ma/emos/def/o/def')
+from ecf import *
+import ecf  as ecf
+# import inc_emos as ie
+"""
+
+    def tail(self):
+        return """
+
+if __name__ == '__main__':
+    defs = Defs()
+    defs.add(suite0); 
+    defs.auto_add_externs(True)
+    if 1: 
+      import cli_proc, ecf
+      cli_proc.process(ie.Seed(defs), compare=False)
+    else:
+       port = 1500 + int(get_uid()) # when started with ecflow_start.sh # ECMWF
+       node = "localhost"
+       path = '/' + suite0.name()
+       if 0: # test job creation
+         job_ctrl = ecflow.JobCreationCtrl()                    
+         defs.check_job_creation(job_ctrl)
+
+       print "replacing %s on %s@%s" % (path, node, port)
+       client = ecf.Client("localhost", port)
+       client.replace(path, defs)
+"""
+
+def usage():
+        print("""def2def.py
+  -f file    [filename]
+  -s string  [description of the suite]
+  -c client  [host@post:/path/to/node]
+  -h help
+
+""")
+
+def test(quiet=1):
+        import os
+        num = 0
+        if quiet: quiet = " > /dev/null "
+        else: quiet = ""
+        for cmd in (
+                        "./def2def.py    || : ", # usage
+                        "./def2def.py -h || : ", # usage
+                        "./def2def.py -s 'suite s; family f; task t'",
+                        "./def2def.py -s 'suite s\n family f\n task t'",
+                        "./def2def.py -p vsms2@32222/o ",
+                        "./def2def.py -f ../o.exp",
+                        "./def2def.py    ../o.exp"):
+                # print "#", cmd
+                # os.system(cmd + " > /dev/null && echo '#' OK%d" % num)
+                os.system(cmd + quiet
+                          + " && echo '#' OK%d " % num + cmd
+                          + " || echo '#' NOK%d " %  num + cmd)
+                num += 1
+
+def process(desc=None, path=None, fname=None):
+        if desc is not None: 
+                import tempfile
+                print("#desc: ", desc) # , "\n"
+                # import unicodedata
+                #unic = unicodedata.normalize('NFKD', desc).encode('ascii', 'ignore')
+                #print "#unic: ", unic # , "\n"
+                USER = os.getenv("USER")
+                try:
+                        with tempfile.NamedTemporaryFile(mode="w+t", dir="/tmp/%s" % USER) as temp:
+                                if type(desc) == list:
+                                        for line in desc:
+                                                temp.write(line)
+                                                temp.write("\n")
+                                elif type(desc) == str:
+                                        temp.write(desc.rstrip())
+                                temp.flush()
+                                # defs = ec.Defs(temp.name)
+                                # if DEBUG: print defs
+                                return process(fname= temp.name)
+                except RuntimeError as e:    
+                        out = "#WAR: failed: " + str(e)
+                        # print "temp, NOK"; sys.exit(1)
+                        print(out)
+                        return out
+                # return "%s" % defs
+        elif path is not None: 
+                import re
+                node, rem = path.split("@")
+                port, suite = rem.split('/')[0:2]
+                print(node, port, suite)
+                client = ec.Client(node, port)
+                client.ch_register(False, [ suite ])
+                client.sync_local()
+                defs = client.get_defs()
+        elif fname is not None: pass
+        elif fname is None and len(sys.argv) > 1:
+                fname = sys.argv[1]
+        else: usage(); sys.exit(2)
+
+        if fname:
+                defs = ec.Defs(fname)
+        defs.auto_add_externs(True)
+        if DEBUG: print(defs)
+        return DefFormat(defs).main()
+
+DEBUG = 0
+if __name__ == '__main__':
+        opts, args = getopt.getopt(sys.argv[1:], "gqhf:s:p:t",
+                                   ["debug", "help", "file", "string", "path", "test"])
+        fname = None
+        desc  = None
+        path  = None
+        QUIET = 0
+        DEBUG = 0
+        for o, a in opts:
+                if o in ("-g", "debug"): DEBUG = 1
+                if o in ("-h", "help"): usage(); sys.exit(2)
+                if o in ("-f", "file"): fname = a
+                if o in ("-s", "string"): desc = a
+                if o in ("-p", "path"): path = a
+                if o in ("-t", "test"): test(QUIET); sys.exit(0)
+                if o in ("-q", "quiet"): QUIET = 1
+
+        print(process(desc, path, fname))
+# ./def2def.py -q -t 
+# ./def2def.py -t 
diff -pruN 5.12.4-1/libs/pyext/samples/ecflow_1638.py 5.13.0-1/libs/pyext/samples/ecflow_1638.py
--- 5.12.4-1/libs/pyext/samples/ecflow_1638.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/ecflow_1638.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,27 @@
+from ecflow import *
+  
+print ("Simulator test ecflow_1638")
+
+# the following test fails in ecflow 5.3.1
+# Simulation start    at:: 1,5,2020 @ 00:00
+# Simulation finished at:: 3,5,2020 @ 00:00
+# ie Friday->Saturday(midnight) 2 days
+# Hence we expect  task t4; cron 23:00             to complete 2
+# Hence we expect  task t5; cron 10:00 20:00 01:00 to complete 22
+
+defs = Defs(
+        Suite("ecflow_1638",
+            Clock(1,5,2020),
+            Task("t2",Date("1.5.2010"),Date("1.5.2011"),Verify(State.complete,0)),
+            Task("t3",Time("23:00"),Verify(State.complete,1)),
+            Task("t4",Cron("23:00"),Verify(State.complete,2)),
+            Task("t5",Cron("10:00 20:00 01:00"),Verify(State.complete,22)),
+            )
+        )
+defs.ecflow_1639.add_end_clock(Clock(3,5,2020))
+print(defs)
+
+theResult = defs.simulate()
+assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
+
+    
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/samples/ecflow_urwid.py 5.13.0-1/libs/pyext/samples/ecflow_urwid.py
--- 5.12.4-1/libs/pyext/samples/ecflow_urwid.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/ecflow_urwid.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,682 @@
+#!/usr/bin/python
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# file deepcode ignore PythonIdenticalBranches: <comment the reason here>
+
+"""Thanks https://github.com/pazz/urwidtrees
+"""
+
+
+
+import os
+import re
+import sys
+import time
+
+import urwid
+import ecflow
+mark = 'dirmark'
+
+UPDATE_INTERVAL = 180
+
+singles = {"queued": "Q",
+           "submitted": "S",
+           "active": "R",
+           "complete": "C",
+           "aborted": "A",
+           "suspended": "P",
+           "unknown": "U",
+           "RUNNING": "R",
+           "HALTED": "H",
+           "SHUTDOWN": "S",
+
+           "dirmark": "-",
+           # "unkown": "U",
+           }
+global STATUS_KIND
+STATUS_KIND = True
+
+
+def is_expanded(item):
+    return get_status(item, True) in (
+        "aborted", "active", "submitted", "RUNNING", "unknown",
+        "A", "R", "S", "U", "abo", "RUN", "unk",
+    )
+
+
+def decorate(node, parent=None, keys=None):
+    if type(node) not in (ecflow.Defs, ecflow.Alias,
+                          ecflow.Suite, ecflow.Family, ecflow.Task):
+        if 1:
+            raise Exception(type(node))
+        return ""
+    status = get_status(node)
+    ext = ' %c [%s]' % (kinds[type(node)], status)
+    num = 0
+
+    if type(node) in (ecflow.Suite, ecflow.Family, ecflow.Task, ):
+        if "%s" % node.get_defstatus() == status:
+            if status != "queued":
+                ext += " (defstatus)"
+
+    if type(node) == ecflow.Defs:
+        return ext
+    exp = node.get_repeat()
+    if exp:
+        ext += "\n%s" % exp
+
+    exp = node.get_trigger()
+    if exp:
+        ext += "\n%s" % exp
+
+    exp = node.get_complete()
+    if exp:
+        ext += "\n%s" % exp
+
+    exp = node.get_late()
+    if exp:
+        ext += "\n%s" % exp
+
+    exp = node.get_autocancel()
+    if exp:
+        ext += "\n%s" % exp
+
+    for item in node.events:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.meters:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.labels:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.limits:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.inlimits:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.times:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.dates:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.todays:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.crons:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.days:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.zombies:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    for item in node.variables:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+        else:
+            ext += " %s" % item
+        num += 1
+
+    gvar = ecflow.VariableList()
+    node.get_generated_variables(gvar)
+    for item in gvar:
+        if keys:
+            parent._children[num] = LeafNode(item)
+            keys.append("%s" % item)
+
+    if keys:
+        return num
+    return ext
+
+
+def get_name(item, full=False, parent=None, keys=None):
+    if type(item) in (ContainerNode, LeafNode):
+        item = item.get_value()
+    if type(item) in (dict, tuple, ):
+        return "#list"
+    if type(item) in (str, ):
+        if 1:
+            raise Exception(item)
+        return item
+    if type(item) in (ecflow.Client, ):
+        return "%s@%s" % (item.get_host(), item.get_port()) + \
+               " - %s " % time.time()
+
+    # ext = ' %c [%s]' % (kinds[type(item)], get_status(item))
+    ext = decorate(item)
+    if type(item) in (ecflow.Defs, ):
+        return "defs" + str(ext) + " - %s " % time.time()
+
+    if type(item) in (ecflow.Client, ):
+        return "%s@%s" % (item.get_host(), item.get_port()) + \
+               " - %s " % time.time()
+    if full:
+        return "%s" % item.name() + str(ext)
+    return item.name()
+
+
+def get_status(item, full=False):
+    if type(item) in (ecflow.Client, ):
+        item = item.get_defs()
+
+    if type(item) in (ecflow.Defs, ):
+        out = "%s" % item.get_server_state()
+    elif type(item) in (dict, tuple):
+        out = "unknown"
+    elif type(item) == str:
+        if item == dir_sep():
+            out = "unknown"
+        else:
+            raise Exception(item, type(item))
+    else:
+        out = "%s" % item.get_state()
+
+    if full:
+        return out
+    if STATUS_KIND == 1:
+        return singles[out]
+    if STATUS_KIND == 3:
+        return out[:3]
+    return out
+
+
+class FlagNodeW(urwid.TreeWidget):
+    unexpanded_icon = urwid.AttrMap(urwid.TreeWidget.unexpanded_icon, mark)
+    expanded_icon = urwid.AttrMap(urwid.TreeWidget.expanded_icon, mark)
+
+    def __init__(self, item):
+        super(FlagNodeW, self).__init__(item)
+        self._w = urwid.AttrWrap(self._w, None)
+        self.flagged = False
+        self.update_w()
+
+    def selectable(self):
+        return True
+
+    def keypress(self, size, key):
+        key = super(FlagNodeW, self).keypress(size, key)
+        if key:
+            key = self.unhandled_key(size, key)
+        return key
+
+    def unhandled_key(self, size, key):
+        if key == " ":
+            self.flagged = not self.flagged
+            self.update_w()
+        else:
+            return key
+
+    def update_w(self):
+        if self.flagged:
+            self._w.attr = 'flagged'
+            self._w.focus_attr = 'focus'
+        else:
+            self._w.attr = 'body'
+            self._w.focus_attr = 'focus'
+        self._w.attr = get_status(self.get_node().get_value(), True)
+
+
+class EmptyW(urwid.TreeWidget):
+
+    def get_display_text(self):
+        return ('flag', "(empty)")
+
+
+class ErrorW(urwid.TreeWidget):
+
+    def get_display_text(self):
+        return ('flag', "(error)")
+
+
+class NodeW(FlagNodeW):
+
+    def __init__(self, item):
+        super(NodeW, self).__init__(item)
+        node = item.get_value()
+        add_widget(node, self)
+
+    def get_display_text(self):
+        node = self.get_node().get_value()
+        return get_name(node, True)
+
+
+class ContainerNodeW(FlagNodeW):
+
+    def __init__(self, item):
+        super(ContainerNodeW, self).__init__(item)
+        node = item.get_value()
+        add_widget(node, self)
+        self.expanded = is_expanded(node)
+        self.update_expanded_icon()
+
+    def get_display_text(self):
+        node = self.get_node().get_value()
+        return get_name(node, True)
+
+
+class EmptyNode(urwid.TreeNode):
+
+    def load_widget(self):
+        return EmptyW(self)
+
+
+class ErrorNode(urwid.TreeNode):
+
+    def load_widget(self):
+        return ErrorW(self)
+
+
+class LeafNode(urwid.TreeNode):
+
+    def __init__(self, item, parent=None):
+        if type(item) == ecflow.Task:
+            path = item.get_abs_node_path()
+            depth = path.count(dir_sep())
+            key = os.path.basename(path)
+        else:
+            path = "%s" % item
+            depth = 0
+            key = "%s" % item
+        urwid.TreeNode.__init__(self, item, key=key,
+                                parent=parent, depth=depth)
+
+    def load_parent(self):
+        node = self.get_value()
+        if type(node) in (ecflow.Client, ecflow.Defs, ):
+            path = dir_sep()
+        else:
+            path = node.get_abs_node_path()
+        parentname, name = os.path.split(path)
+        if 1:
+            raise Exception
+        parent = ContainerNode(self.ci.find_abs_node_path(parentname))
+        parent.set_child_node(self.get_key().get_value(), self)
+        return parent
+
+    def load_widget(self):
+        return NodeW(self)
+
+    # def load_child_keys(self): return [None]
+
+
+class ContainerNode(urwid.ParentNode):
+
+    def __init__(self, item, parent=None):
+        if type(item) in (ecflow.Client, ecflow.Defs, ):
+            path = dir_sep()
+        else:
+            path = item.get_abs_node_path()
+        depth = path.count(dir_sep())
+        if path == dir_sep():
+            depth = 0
+            key = None
+        else:
+            key = os.path.basename(path)
+        urwid.ParentNode.__init__(
+            self, item, key=key, parent=parent, depth=depth)
+
+    def load_parent(self):
+        node = self.get_value()
+        if type(node) in (ecflow.Client, ecflow.Defs, ):
+            path = dir_sep()
+        else:
+            path = node.get_abs_node_path()
+        parentname, name = os.path.split(path)
+        if 1:
+            raise Exception
+        parent = ContainerNode(self.ci.find_abs_node_path(parentname))
+        parent.set_child_node(self.get_key().get_value(), self)
+        return parent
+
+    def load_child_keys(self):
+        keys = []
+        num = 0
+        node = self.get_value()
+        if type(node) in (ecflow.Client, ):
+            node = node.get_defs()
+
+        if type(node) in (ecflow.Defs, ):
+            for item in node.suites:
+                self._children[num] = ContainerNode(item)
+                keys.append(get_name(item))
+                num += 1
+
+        elif type(node) in (ecflow.Suite, ecflow.Family, ):
+            for item in node.nodes:
+                if type(item) in (ecflow.Family, ):
+                    self._children[num] = ContainerNode(item)
+                elif type(item) in (ecflow.Task, ):
+                    self._children[num] = LeafNode(item)
+                else:
+                    self._children[num] = LeafNode(item)
+                keys.append(get_name(item))
+                num += 1
+
+            if 0:
+                num += decorate(node, self, keys)
+
+        elif type(node) in (ecflow.Task, ):
+            pass
+
+        elif 1:
+            raise Exception(type(node))
+        else:
+            self._children[0] = EmptyNode(
+                self, parent=self, key=None, depth=num)
+        self.dir_count = num + 1
+        # print(keys)
+        return keys
+
+    def load_child_node(self, key):
+        # index = self.get_child_index(key)
+        node = self.get_value()
+        num = 0
+        if type(node) in (ecflow.Client, ):
+            node = node.get_defs()
+
+        if type(node) in (ecflow.Task, ):
+            return EmptyNode(None)
+
+        if type(node) in (ecflow.Suite, ecflow.Family):
+            num = 0
+            for item in node.nodes:
+                if num == key:
+                    node = item
+                    break
+                if item.name() == key:
+                    node = item
+                    break
+                num += 1
+
+        if key is None:
+            return EmptyNode(None)
+
+        if type(node) in (ecflow.Defs, ):
+            path = dir_sep()
+            for item in node.suites:
+                if num == key:
+                    node = item
+                    break
+                if get_name(item) == key:
+                    node = item
+                    break
+                num += 1
+            return ContainerNode(node, parent=self)
+
+        # path = os.path.join(get_name(node), key)
+        if type(node) in (ecflow.Suite, ecflow.Family, ):
+            return ContainerNode(node, parent=self)
+
+        return LeafNode(node, parent=self)
+
+    def load_widget(self):
+        return ContainerNodeW(self)
+
+
+class EcflowBrowser(object):
+    palette = [
+        ('body', 'black', 'light gray'),
+        ('flagged', 'black', 'dark green', ('bold', 'underline')),
+        ('focus', 'light gray', 'dark blue', 'standout'),
+        ('flagged focus', 'yellow', 'dark cyan',
+         ('bold', 'standout', 'underline')),
+        ('head', 'yellow', 'black', 'standout'),
+        ('foot', 'light gray', 'black'),
+        ('key', 'light cyan', 'black', 'underline'),
+        ('title', 'white', 'black', 'bold'),
+        ('dirmark', 'black', 'dark cyan', 'bold'),
+        ('flag', 'dark gray', 'light gray'),
+        ('error', 'dark red', 'light gray'),
+
+        ('queued', 'dark gray', 'light blue'),
+        ('submitted', 'dark gray', 'light cyan'),
+        ('active', 'dark gray', 'light green'),
+        ('complete', 'dark gray', 'yellow'),
+        ('aborted', 'dark gray', 'dark red'),
+        ('unknown', 'dark gray', 'light gray'),
+        ('suspended', 'dark gray', 'brown'),
+        ('RUNNING', 'dark gray', 'light green'),
+        ('HALTED', 'dark gray', 'dark cyan'),  # purple
+        ('SHUTDOWN', 'dark gray', 'light red'),  # pink'),
+    ]
+
+    footer_text = [
+        ('title', "Directory Browser"), "    ",
+        ('key', "UP"), ",", ('key', "DOWN"), ",",
+        ('key', "PAGE UP"), ",", ('key', "PAGE DOWN"),
+        "  ",
+        ('key', "SPACE"), "  ",
+        ('key', "+"), ",",
+        ('key', "-"), "  ",
+        ('key', "LEFT"), "  ",
+        ('key', "HOME"), "  ",
+        ('key', "END"), "  ",
+        ('key', "Q"),
+    ]
+
+    def __init__(self, server, suites):
+        host, port = server.split('@')
+        self.ci = ecflow.Client(host, int(port))
+        self.ci.ch_register(False, suites)
+        self.ci.sync_local()
+        # print(self.ci.get_defs())
+        self.start_time = time.time()
+
+        # cwd = os.getcwd()
+        cwd = self.ci.get_defs()
+        store_initial_cwd(dir_sep())
+        self.header = urwid.Text("")
+        self.listbox = urwid.TreeListBox(urwid.TreeWalker(ContainerNode(cwd)))
+        self.listbox.offset_rows = 1
+        self.footer = urwid.AttrWrap(urwid.Text(self.footer_text),
+                                     'foot')
+        self.view = urwid.Frame(
+            urwid.AttrWrap(self.listbox, 'body'),
+            header=urwid.AttrWrap(self.header, 'head'),
+            footer=self.footer)
+
+    def main(self):
+        """Run the program."""
+
+        self.loop = urwid.MainLoop(self.view, self.palette,
+                                   unhandled_input=self.unhandled_input)
+        self.loop.run()
+
+        # on exit, write the flagged filenames to the console
+        names = [escape_filename_sh(x) for x in get_flagged_names()]
+        print(" ".join(names))
+
+    def unhandled_input(self, k):
+        # update display of focus directory
+        if k in ('q', 'Q'):
+            raise urwid.ExitMainLoop()
+
+        if k in ('z', 'Z', ):
+            self.ci.sync_local()
+
+        global STATUS_KIND
+        if k in ('3', "3", 3):
+            STATUS_KIND = 3
+
+        elif k in ('1', "1", 1):
+            STATUS_KIND = 1
+
+        elif k in ('f', "F"):  # full
+            STATUS_KIND = 0
+
+
+def main(server, suites):
+    EcflowBrowser(server, suites).main()
+
+
+_widget_cache = {}
+
+
+def add_widget(path, widget):
+    _widget_cache[path] = widget
+
+
+def get_flagged_names():
+    lst = []
+    for w in list(_widget_cache.values()):
+        if w.flagged:
+            node = w.get_node().get_value()
+            lst.append(get_name(node))
+    return lst
+
+
+_initial_cwd = []
+
+
+def store_initial_cwd(name):
+    global _initial_cwd
+    _initial_cwd = name.split(dir_sep())
+
+
+def escape_filename_sh(name):
+    """Return a hopefully safe shell-escaped version of a filename."""
+
+    # check whether we have unprintable characters
+    for ch in name:
+        if ord(ch) < 32:
+            # found one so use the ansi-c escaping
+            return escape_filename_sh_ansic(name)
+
+    # all printable characters, so return a double-quoted version
+    name.replace('\\', '\\\\')
+    name.replace('"', '\\"')
+    name.replace('`', '\\`')
+    name.replace('$', '\\$')
+    return '"' + name + '"'
+
+
+def escape_filename_sh_ansic(name):
+    """Return an ansi-c shell-escaped version of a filename."""
+
+    out = []
+    # gather the escaped characters into a list
+    for ch in name:
+        if ord(ch) < 32:
+            out.append("\\x%02x" % ord(ch))
+        elif ch == '\\':
+            out.append('\\\\')
+        else:
+            out.append(ch)
+
+    # slap them back together in an ansi-c quote  $'...'
+    return "$'" + "".join(out) + "'"
+
+
+SPLIT_RE = re.compile(r'[a-zA-Z]+|\d+')
+
+
+def alphabetize(s):
+    L = []
+    import itertools
+    for isdigit, group in itertools.groupby(
+            SPLIT_RE.findall(s), key=lambda x: x.isdigit()):
+        if isdigit:
+            for n in group:
+                L.append(('', int(n)))
+        else:
+            L.append((''.join(group).lower(), 0))
+    return L
+
+
+def dir_sep():
+    return getattr(os.path, 'se[', '/')
+
+
+kinds = {ecflow.Defs: "D",
+         ecflow.Client: "C",
+         ecflow.Suite: "S",
+         ecflow.Family: "F",
+         ecflow.Task: "T",
+         ContainerNode: "X",
+         LeafNode: "L",
+         str: "S",
+         }
+
+
+if __name__ == '__main__':
+    if len(sys.argv) == 2:
+        node = sys.argv[1]
+    else:
+        raise Exception("ecflow_urwid.py localhost@2500/test")
+    server, suites = node.split('/')
+    main(server, [suites])
+
+"""
+python ecflow_urwid.py localhost@2500/test
+
+"""
diff -pruN 5.12.4-1/libs/pyext/samples/emos_example.py 5.13.0-1/libs/pyext/samples/emos_example.py
--- 5.12.4-1/libs/pyext/samples/emos_example.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/emos_example.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,483 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Checking Job Creation
+#for the record, Emos alternative syntax is,
+
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+print "suite creation"
+defs = Defs()
+defs.suite("test").add(
+    Variables(ECF_HOME= os.path.join(os.getenv("HOME"), "course")),
+    Task("t1"))
+print defs
+print "Checking job creation: .ecf -> .job0"  
+print defs.check_job_creation()
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# Load the file
+#Using "if __name__ == '__main__':" the script can be used both as a module (providing a function) or as a standalone script:
+
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+
+def generate():
+    # print "Creating suite definition"  
+    return Defs().add(
+        Suite("test").add(
+            Variables(ECF_HOME= os.path.join(os.getenv("HOME"),  "course")),
+            Task("t1")))
+ 
+if __name__ == '__main__':
+    defs = generate()      
+    print defs
+    print "Checking job creation: .ecf -> .job0"  
+    print defs.check_job_creation()
+    print "Saving definition to file 'test.def'"
+    defs.save_as_defs("test.def")
+    try:
+        print "Load the in memory definition(defs) into the server"
+        Client("localhost@%s" % os.getenv("ECF_PORT")).load(defs)
+    except RuntimeError as e: print "Failed:", e
+        
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# families
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+print "Creating suite definition"  
+defs = Defs().add(Suite("test").add(
+    Variable("ECF_HOME", os.path.join(os.getenv("HOME"),  "course")),
+    Family("f1").add(
+      Task("t1"),
+      Task("t2"))))
+print defs
+print "Checking job creation: .ecf -> .job0"  
+print defs.check_job_creation()
+print "Saving definition to file 'test.def'"
+defs.save_as_defs("test.def")
+print "Client -> Server: delete, then load a new definition"  
+try:
+    ci = Client()
+    ci.replace("/test", "test.def") # replace the suite into the server
+    ci.begin_suite("test")    # start the suite
+except RuntimeError as e:
+    print "Failed:",   e
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# ecflow variables
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home = os.path.join(os.getenv("HOME"), "course")
+ 
+def create_family_f1():
+    return Family("f1" ).add(
+        Task("t1").add(Variables(SLEEP= 20)),
+        Task("t2").add(Variables(SLEEP= 20)))
+ 
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    create_family_f1() ))
+ 
+print defs
+defs.save_as_defs("test.def")
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# variable inheritance
+# tab constraint is relaxed with Emos ecf.py
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home = os.path.join(os.getenv("HOME"), "course")
+def create_family_f1():
+    return Family("f1" ).add(
+        Variables(SLEEP= 20),
+        Task("t1"),
+        Task("t2"))
+print "Creating suite definition"
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+             ECF_HOME=    home),
+     create_family_f1() ))
+print defs
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# triggers#!/usr/bin/env python2.7
+import os
+from ecf import *
+home=  os.path.join(os.getenv("HOME"), "course")
+def create_family_f1():
+    return Family("f1" ).add(
+        Variable(SLEEP= 20),
+        Task("t1"),
+        Task("t2").add(Trigger("t1 eq complete")))
+print "Creating suite definition"
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    create_family_f1() ))
+print defs
+defs.save_as_defs("test.def")
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# add an event
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home = os.path.join(os.getenv("HOME"), "course")
+def create_family_f1():
+    return Family("f1").add(
+        Variables(SLEEP= 20),
+        Task("t1"),
+        Task("t2").add(
+            Trigger(["t1"]),
+            Event("a"),
+            Event("b")),
+     
+        Task("t3").add(Trigger("t2:a")),
+        Task("t4").add(Trigger("t2:b")),
+    )
+print "Creating suite definition"
+defs = Defs().add(
+    Suite("test").add(
+        Variables(ECF_INCLUDE= home,
+                  ECF_HOME=    home),
+        create_family_f1() ))
+print defs
+defs.save_as_defs("test.def")
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# add a complete
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home = os.path.join(os.getenv("HOME"),  "course")
+def create_family_f1():
+    return Family("f1").add(
+        Variable(SLEEP= 20),
+        Task("t1"),
+        Task("t2").add(Trigger("t1 eq complete"),
+                       Event("a"),
+                       Event("b")),
+        Task("t3").add(Trigger("t2:a")),
+        Task("t4").add(Trigger("t2 eq complete"), 
+                       Complete("t2:b")  ))
+       
+print "Creating suite definition"  
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    create_family_f1() ))
+print defs
+defs.save_as_defs("test.def")
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# add a meter
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home= os.path.join(os.getenv("HOME"), "course")
+def create_family_f1():
+    return Family("f1").add(
+        Variables(SLEEP= 20),
+        Task("t1").add(Meter("progress", 1, 100, 90)),
+     
+        Task("t2").add(Trigger("t1 eq complete"),
+                       Event("a"),
+                       Event("b")),
+     
+        Task("t3").add(Trigger("t2:a")),
+     
+        Task("t4").add(Trigger("t2 eq complete"),
+                       Complete("t2:b")),
+      
+        Task("t5").add(Trigger("t1:progress ge 30")),
+        Task("t6").add(Trigger("t1:progress ge 60")),
+        Task("t7").add(Trigger("t1:progress ge 90")))
+    
+print "Creating suite definition"  
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    create_family_f1() ))
+print defs
+defs.save_as_defs("test.def")
+
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# Time dependencies
+# #!/usr/bin/env python2.7
+import os
+
+home = os.path.join(os.getenv("HOME"),  "course")
+ 
+def create_family_f2():
+    return Family("f2").add(
+        Variables(SLEEP= 20),
+        Task("t1").add(
+          Time("00:30 23:30 00:30")), # start(hh:mm) end(hh:mm) increment(hh:mm)
+        Task("t2").add(Day( "sunday" )),
+        Task("t3").add(
+            Date("1.*.*"),  # day month year, first of every month or every year
+            Time("12:00")), # hour, minutes at 12 o'clock
+    
+        Task("t4").add(Time("+00:02")), # hour, minutes, relative to suite start
+                                        # 2 minutes after family f2 start
+        Task("t5").add(Time("00:02"))   # hour, minutes suite site
+                                        # 2 minutes past midnight
+)           
+    
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    create_family_f1(),
+    create_family_f2(), ))
+print defs
+defs.save_as_defs("test.def")
+
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# indentation
+# Another approach is to use ecf.py module to benefit from object oriented polymorphism
+#!/usr/bin/env python2.7
+import os
+import sys
+sys.path.append('/home/ma/emos/def/o/def')
+from ecf import *
+print "Creating suite definition" 
+defs = Defs().add(# Stream like definition
+    Suite("test").add(
+        Variables({ # a dictionary to detect duplicated variables
+                "ECF_INCLUDE": os.getenv("HOME") + "/course",
+                "ECF_HOME":    os.getenv("HOME") + "/course",}),
+        Family("f1").add(
+            Variable("SLEEP", "20"),
+            Task("t1").add(Meter("progress", 1, 100, 90)),
+            Task("t2").add(
+                Trigger("t1 eq complete"),
+                Event("a"),
+                Event("b")),
+            Task("t3").add(Trigger("t2:a")),
+            Task("t4").add(Trigger("t2 eq complete"),
+                           Complete("t2:b")),
+            Task("t5").add(Trigger("t1:progress ge 30")),
+            Task("t6").add(Trigger("t1:progress ge 60")),
+            Task("t7").add(Trigger("t1:progress ge 90")),),
+        Family("f2").add(
+            Variable("SLEEP", "20"),
+            Task("t1").add(Time( "00:30 23:30 00:30" )),
+            Task("t2").add(Day( "sunday" )),
+            Task("t3").add(Date("1.*.*"),
+                           Time("12:00")),
+            Task("t4").add(Time("+00:02")),
+            Task("t5").add(Time("00:02")))))
+             
+out = file("test.def", "w")
+print >>out, defs
+
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+# label
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home = os.getenv("HOME") + "/course"
+print "Creating suite definition"  
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    Family("f3").add(
+        Task("t1").add(
+            Label("info","")))))
+print defs
+defs.save_as_defs("test.def")
+
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+# repeat
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home = os.path.join(os.getenv("HOME"),  "course")
+def create_family_f4():
+    return Family("f4").add(
+        Variables(SLEEP= 2),
+        Repeat("NAME", ["a", "b", "c", "d", "e", "f" ], kind="enum"),
+    
+        Family("f5").add(
+            Repeat( "VALUE", 1, 10, kind= "integer"),
+            Task("t1").add(
+                Repeat( "DATE", 20101230, 20110105, kind= "date"),
+                Label("info", ""))))
+     
+print "Creating suite definition"  
+defs = ecflow.Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    create_family_f4(), ))
+print defs
+defs.save_as_defs("test.def")
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# limits
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home= os.path.join(os.getenv("HOME"),  "course")
+def create_family_f5() :
+    return Family("f5").add(
+        Inlimit("l1"),
+        Variables(SLEEP= 20),
+        [ Task( "t" + str(i))     for i in range(1, 10)] # list comprehension
+    )
+     
+print "Creating suite definition"  
+defs = Defs().add(Suite("test").add(
+    Variables(ECF_INCLUDE= home,
+              ECF_HOME=    home),
+    Limit("l1", 2),
+    create_family_f5() ))
+print defs
+defs.save_as_defs("test.def")
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+#  Data acquiation solution
+#!/usr/bin/env python2.7
+import os
+from ecf import * 
+home = os.getenv("HOME") + "/course")  
+defs = Defs().add(Suite("data_aquisition").add(
+    Repeat(kind="day", step=1),
+    Variables(ECF_HOME= home,
+              ECF_INCLUDE= home,
+              ECF_FILES= home + "/data",
+              SLEEP= 2),
+    [ Family(city).add(
+        Task("archive").add(
+            [ Family(obs_type).add(
+                If( city in ("Exeter", "Toulouse", "Offenbach"),
+                    Time("00:00 23:00 01:00")),
+                If( city in ("Washington"),
+                    Time("00:00 23:00 03:00")),
+                If( city in ("Tokyo"),
+                    Time("12:00")),
+                If( city in ("Melbourne"),
+                    Day( "monday" )),
+                If( city in ("Montreal"),
+                    Date("1.*.*")),
+          
+                Task("get"),
+                Task("process").add(Trigger("get eq complete")),
+                Task("store").add(Trigger("get eq complete")))
+              for obs_type in ( "observations", "fields", "images" ) ] ))
+        for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) ]
+    ))
+print defs
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# operational suite solution:
+
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home = os.getenv("HOME") + "/course"
+cycle_triggers = None
+last_step = { "12": 240,
+              "00": 24, }
+def cycle_trigger(cycle):
+    if cycle == "12": return Trigger("./00==complete")
+    return None
+defs = Defs().add(Suite("operation_suite").add(
+     Repeat(kind="day", step=1),
+     Variables(ECF_HOME= home,
+               ECF_INCLUDE= home,
+               ECF_FILES= home + "/oper"),
+    [ Family(str(cycle)).add(
+        Variables(CYCLE=  cycle,
+                  LAST_STEP= last_step[cycle]),
+       
+        cycle_trigger(cycle),
+                  
+        Family("analysis").add(
+            Task("get_observations"),
+            Task("run_analysis").add(Trigger(["get_observations", ])),
+            Task("post_processing").add(Trigger(["run_analysis", ])),
+        ),
+  
+        Family("forecast").add(
+            Trigger("analysis == complete"),
+            Task("get_input_data"),
+            Task("run_forecast").add(
+                Trigger(["get_input_data", ]),
+                Meter("step", 0, last_step[cycle])),
+        ),
+        Family("archive").add(
+            Family("analysis").add(
+                Variables(TYPE= "analysis",
+                          STEP= 0),
+                Trigger(["../analysis/run_analysis", ]),
+                Task("save"),
+                [ Family("step_%02d" % i).add(
+                    Variables(TYPE= "forecast",
+                              STEP= i),
+                    Trigger("../../forecast/run_forecast:step ge %d" % i),
+                    Task("save"))
+                  for i in range(6, last_step+1, 6) ]
+            )
+        )
+    ) for cycle in ( 0 , 12 ) ] ))
+print defs
+
+!!!!!!! 
+Baudouin Raoult
+range(6, last_step, 6) will not return last_step.
+
+>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
+
+# back archiving solution
+#!/usr/bin/env python2.7
+import os
+from ecf import *
+home= os.getenv("HOME") + "/course"
+defs = Defs().add(Suite("back_archiving").add(
+    Repeat( kind= "day", step= 1),
+    Variables(ECF_HOME= home,
+              ECF_INCLUDE= home,
+              ECF_FILES= home + "/back",
+              SLEEP= 2),
+    Limit("access", 2),
+    [ Family(kind).add(
+        Repeat( "DATE", 19900101, 19950712, kind="date"),
+        Variables(KIND= kind),
+        Task("get_old").add(Inlimit("access")),
+        Task("convert").add(Trigger("get_old == complete")),
+        Task("save_new").add(Trigger("convert == complete")))
+      for kind in ( "analysis", "forecast", "climatology", "observations", "images" ) ]
+))
+print defs
diff -pruN 5.12.4-1/libs/pyext/samples/extract_version.py 5.13.0-1/libs/pyext/samples/extract_version.py
--- 5.12.4-1/libs/pyext/samples/extract_version.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/extract_version.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+import sys, os
+
+def get_installed_ecflow_version():
+    "This will extract ecFlow version from /usr/local/apps/ecflow/current."
+    "Will return a list of form `[2,0,24]`"
+    ecflow_dir_ext = os.readlink("/usr/local/apps/ecflow/current")
+    # print(ecflow_dir_ext)
+    version_list = ecflow_dir_ext.split(".")
+    assert len(version_list) == 3 ,"Expected 3 items,release,major,minor but found " + ecflow_dir_ext
+    print("Extracted ecflow version from /usr/local/apps/ecflow/current: " + ecflow_dir_ext)
+    return version_list;
+    
+def get_ecflow_version( work_space ):
+    "This will extract ecFlow version *list* from the source code."
+    "The version is defined in the file CMakeList.txt"
+    "expecting string of form:"
+    "project( ecflow LANGUAGES CXX VERSION 5.10.0 )"
+    file = work_space + "/CMakeLists.txt11"
+    ecflow_version = []
+    if os.path.exists(file):
+        cmake_file = open(file,'r')
+        try :
+            for line in cmake_file :
+                project = line.find('project(')
+                ecflow = line.find('ecflow')
+                cxx = line.find('CXX')
+                version_t = line.find('VERSION')
+                if project != -1 and ecflow != -1 and cxx != -1 and version_t != -1 :
+                    tokens = line.split()
+                    version_index = tokens.index("VERSION")
+                    version = tokens[version_index+1]
+                    if version[-1] == ')':
+                        version = version[:-1]
+                    ecflow_version = version.split(".")
+        finally:
+            cmake_file.close();
+        
+        print("Extracted ecflow version '" + str(ecflow_version) + "' from " + file)
+        return ecflow_version
+    else:
+        return get_installed_ecflow_version()
+    
+    
+print(get_ecflow_version("/Users/avibahra/git/ecflow"))
+    
diff -pruN 5.12.4-1/libs/pyext/samples/mirror.py 5.13.0-1/libs/pyext/samples/mirror.py
--- 5.12.4-1/libs/pyext/samples/mirror.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/mirror.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1034 @@
+#!/usr/bin/env python
+# ////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+# ////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# -m trace --count -C .
+"""an example for a simple python client to help ecFlow scheduling
+ + unit test
+ + task loading in the suite
+
+one script DO-IT-ALL:
+  - play suite + update suite holder aka def-file
+
+  - script as a wrapper for a task
+
+  - download content (passive client)
+
+  - upload statuses (active client)
+
+$manual
+
+  MIRRORING suite from server to server
+
+  test - suspend suite and rerun job if aborted... Thanks
+
+$end
+$comment
+  a comment in a comment
+$end
+
+TODO: check MICRO robust sync
+"""
+import argparse
+import os
+import pwd
+import sys
+import time
+import unittest
+from time import gmtime, strftime
+
+# ECFLOWP = "/usr/local/apps/ecflow/current"
+# ECFLOWC = ECFLOWP + "/bin/ecflow_client "
+# sys.path.append(ECFLOWP + "/lib/python2.7/site-packages/ecflow")
+ECFLOWC = "ecflow_client "
+child = None
+
+
+def getreq():
+    return Family("getreq").add(Task("collectreq"))
+
+
+def ymd():
+    return [Edit("YMD", "29090909"), Label("ymd", "29090909")]
+
+
+def excepthook(exctype, value, traceback):
+    if exctype == KeyboardInterrupt:
+        if child:
+            child.report("abort", "keyb")
+    else:
+        sys.__excepthook__(exctype, value, traceback)
+        if child:
+            child.report("abort", "gen")
+
+
+def fullname(item):
+    return ""
+
+
+sys.excepthook = excepthook
+from ecf import *  # mirror
+import ecf
+import ecflow
+
+
+# class Edit(ecf.Variables):    pass
+
+MICRO = "$$"  # keep ecFlow pleased with micro character balance
+DEBUG = 1
+DEBUG = 0
+USER = "emos"
+# USER = "map"
+
+sms_status = {
+    -1: "unknown",
+    0: "unknown",
+    1: "suspended",
+    2: "complete",
+    3: "queued",
+    4: "submitted",
+    5: "active",
+    6: "aborted",
+    7: "shutdown",
+    8: "halted",
+    9: "unknown",
+}
+sms_type = {
+    13: "definition",
+    12: "suite",
+    11: "family",
+    10: "task",
+    32: "alias",
+}
+
+
+############################
+def usage():
+    print(
+        sys.argv[0],
+        """
+      -h # help
+      -m <server@port> # mirror path fri
+      -t # unit test
+      -r # load the task definition in a suite, associated with -p option
+      -r # with -m, allow suite loading in destination
+      -u usage
+
+can also be used as a module: gen_task, gen_suite
+
+    """,
+    )
+    for num, val in enumerate(sys.argv):
+        print(num, val)
+    child.report("abort")
+    sys.exit(2)
+
+
+############################
+def get_uid():
+    return pwd.getpwnam(get_username()).pw_uid
+
+
+############################
+def gen_task(var=True, load_only=False, kind=None):
+    from ecf import Task, Label, Variables
+
+    pwd = os.getcwd()
+    name = sys.argv[0]
+    if "/" in name:
+        name = name.split("/")[-1]
+    if "." in name:
+        name = name.split(".")[0]
+    rec = "00:30"
+    cmd = "/home/ma/emos/bin/trimurti emos eurus $ECF_JOB$ $ECF_JOBOUT$"
+    cmd = "/usr/local/apps/python/2.7.12-01/bin/python $ECF_JOB$"
+    WDIR = pwd
+    ODIR = pwd
+
+    load = (
+        Label("info", "mirror suites..."),
+        Variables(
+            ECF_MICRO=MICRO[0],
+            ECF_HOME=ODIR,
+            ECF_EXTN=".py",
+            ECF_JOB_CMD=cmd,
+        ),
+    )
+    if load_only:
+        return load
+    return Task(name).add(Cron("04:00 20:00 " + rec), If(var, load))
+
+
+############################
+# def stop(msg, num, child=None):
+#     print(msg);
+#     if child:
+#         child.report(msg)
+#         if num == 0: child.report("complete")
+#     sys.stdout.flush()
+#     sys.stderr.flush()
+#     sys.exit(num)
+def timer(a, b):
+    if child is None:
+        return
+    child.report("timeout")
+    child.report("complete")
+
+
+import signal
+
+signal.signal(signal.SIGALRM, timer)
+signal.alarm(180)
+
+
+############################
+class Child(object):
+    """facilitate job behaviour with ecFlow server:
+    just instanciate and call complete when finished
+
+    obj = Child(); obs.report("complete")
+
+    this does nothing when script is called from command line
+    """
+
+    def __init__(self):
+        import signal
+
+        env = {
+            "ECF_HOST": "$ECF_HOST:$",
+            # check can be on a server, child on another
+            "ECF_PASS": "$ECF_PASS$",
+            "ECF_NAME": "$ECF_NAME$",
+            "ECF_PORT": "$ECF_PORT:0$",
+            "ECF_TRYNO": "$ECF_TRYNO$",
+        }
+        self.client = None
+        if MICRO[0] in env["ECF_PORT"]:
+            print("#MSG: cli mode")
+            return
+        print("#MSG: will communicate with server...")
+        print("#MSG: kill: ssh %s kill -15 %d" % (os.uname()[1], os.getpid()))
+        for sig in (
+            signal.SIGINT,
+            signal.SIGHUP,
+            signal.SIGQUIT,
+            signal.SIGILL,
+            signal.SIGTRAP,
+            signal.SIGIOT,
+            signal.SIGBUS,
+            signal.SIGFPE,
+            signal.SIGUSR1,
+            signal.SIGUSR2,
+            signal.SIGPIPE,
+            signal.SIGTERM,
+            signal.SIGXCPU,
+            signal.SIGPWR,
+        ):
+            signal.signal(sig, self.signal_handler)
+        self.set_client()
+
+    def set_client(self):
+        self.client = ecflow.Client()
+        if len(MICRO) == 2:
+            host = env["ECF_HOST"]
+            print(host)
+            self.client.set_host_port(host, int(env["ECF_PORT"]))
+            self.client.set_child_pid(os.getpid())
+            self.client.set_child_path(env["ECF_NAME"])
+            self.client.set_child_password(env["ECF_PASS"])
+            self.client.set_child_try_no(int(env["ECF_TRYNO"]))
+        else:
+            host = "$ECF_HOST:$"
+            print(host)
+            self.client.set_host_port(host, int("$ECF_PORT:0$"))
+            self.client.set_child_pid(os.getpid())
+            self.client.set_child_path("$ECF_NAME$")
+            self.client.set_child_password("$ECF_PASS$")
+            self.client.set_child_try_no(int("$ECF_TRYNO$"))
+        self.client.child_init()
+
+        self.client.child_label("info", "%s" % strftime("%Y-%m-%d %H:%M:%S", gmtime()))
+        self.client.set_child_timeout(20)
+        print(self.client)
+
+    def signal_handler(self, signum, frame):
+        """ catch signal """
+        print("Aborting: Signal handler called with signal ", signum)
+        self.report("abort", "Signal handler called with signal " + str(signum))
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.report("abort", "__exit__")
+
+    def report(self, msg, meter=None):
+        """ communicate with ecFlow server """
+        if not self.client:
+            print("#MSG: no child")
+            if msg in ("stop", "complete"):
+                sys.stdout.flush()
+                sys.stderr.flush()
+                print("#MSG: no child stop")
+                sys.exit(0)
+            else:
+                print(msg, meter)
+            return
+        elif msg in ("stop", "complete"):
+            self.client.child_complete()
+            self.client = None
+            sys.stdout.flush()
+            sys.stderr.flush()
+            print("#MSG: stop")
+            sys.exit(0)
+        elif msg in ("abort",):
+            self.client.child_abort()
+            self.client = None
+            raise Exception(msg)
+        elif meter:
+            self.client.child_meter(msg, meter)
+        else:
+            self.client.child_label("info", msg)
+
+
+############################
+destinations = {
+    "emos": "${DEST_HOST:=localhost}@${DEST_PORT=5001}",
+    "test": "${DEST_HOST:=localhost}@${DEST_PORT=5001}",
+    "mc": "localhost@5003",
+}
+
+
+def gen_suite(host=None, port=None, path=None):
+    import ecf
+    from ecf import (
+        Task,
+        Label,
+        Variables,
+        Suite,
+        Defs,
+        Family,
+        Trigger,
+        Defstatus,
+        Meter,
+        Event,
+    )
+
+    # destinations = dict()
+    defs = Defs()
+    sname = "mirror"
+    print(list(definitions.keys()), list(destinations.keys()))
+    defs.add_suite(
+        Suite(sname).add(
+            ecf.Defstatus("suspended"),
+            Limit("one", 2),
+            Inlimit("one"),
+            gen_task(load_only=True),
+            Variables(ALL_ECF=" "),
+            [
+                Family(name).add(
+                    Variables(DESTINATIONS=destinations[name]),
+                    Label("info", ""),
+                    gen_task(0, kind=name),
+                )
+                for name in list(definitions.keys())
+                # if name in destinations.keys()
+            ],
+        )
+    )
+    if DEBUG:
+        print(defs)
+    return defs
+
+
+definitions = {  # strings as path for all nodes below sync
+    # or suites, subset of the original, leaves are task...
+    # or else not sync'ed
+    # shall we add list of string/path ???
+    "emos": Suite("emos").add(
+        Defstatus("suspended"), Family("f1").add(Edit(YMD=20320101), Task("t1"))
+    ),
+    "test": Suite("test").add(
+        Defstatus("suspended"), Family("f1").add(Edit(YMD=20320101), Task("t1"))
+    ),
+    "mc": Suite("mc").add(
+        Defstatus("suspended"), Family("main").add(
+            Edit(YMD=20990101), 
+            Family("06bc").add(
+                Task("sweeper"), 
+                Family("fc0006d").add(Task("fc")),
+            ),
+    ), ),
+}
+
+############################
+
+
+class Mirror(object):
+
+    """    """
+
+    def _protect_oper(self, server):
+        if server == "xyz@123":
+            if 1:
+                child.report("abort", "protect")
+            elif (
+                "/o" in self.path
+                or self.path == "all"
+                or "/eda" in self.path
+                or "/mc" in self.path
+            ):
+                raise Exception("# wont do that...")
+
+    def _warmup(self):
+        self._set_register(self.path)
+        if not self.is_sms:
+            self.source.ch_register(False, self.register)
+            self.source.sync_local()
+
+    def _send(self, msg="", client=None, send=False):
+        """self.grouped is None: no buffering, immediate send
+        msg accumulate (send False by default)
+        msg is sent ("", client, send=True)
+        """
+        if self.grouped is None:
+            print("#MSG: send", self.grouped)
+            client.group(msg)
+            time.sleep(self.snap)
+            return
+
+        self.grouped += msg
+        if send and self.grouped != "":
+            print("#MSG: send", self.grouped)
+            client.group(self.grouped)
+            client.sync_local()
+            self.grouped = ""
+            time.sleep(self.snap)
+
+    def __init__(self, server="eurus@1630", path="/e_45r1", replay=False, is_sms=False):
+        self.is_sms = is_sms
+        self.replay = replay  # allow replay from skel definition
+        self.act = 1  # active ie force change allowed
+        self.snap = 1  # sleep interval
+        self.wait = 0  # refresh interval,continue as long as sub/act node exist
+        self.path = path
+        self.grouped = None  # would use atomic alter
+        self.grouped = ""  # command to send to the server ... grouped
+        self._set_register(path)
+
+        if server == "all":
+            self.servers = "$DESTINATIONS$".split(" ")
+        elif " " in server:
+            self.servers = server.split(" ")
+        elif "@" in server:
+            host, port = server.split("@")
+            self.servers = ("%s@%s" % (host, port),)
+        elif ":" in server:
+            host, port = server.split(":")
+            self.servers = ("%s:%s" % (host, port),)
+        if self.servers[-1] == "":
+            del self.servers[-1]
+        host = os.getenv("ECF_HOST", "localhost")
+        # if MICRO[0] in host: host = "localhost"
+        port = os.getenv("ECF_PORT", "3141")
+        if MICRO[0] in port:
+            port = 1500 + int(get_uid())
+        # when started with ecflow_start.sh
+        # aka reference/source  server name
+        self.sname = "%s:%s" % (host, port)
+
+        if "$SOURCE:$" != "" and MICRO[0] not in "$SOURCE:$":
+            self.sname = "$SOURCE:$"
+        if DEBUG:
+            print("#DBG: source is", self.sname)
+        self.set_source()
+
+    def set_source(self):
+        self.source = ecflow.Client(self.sname)
+        self._warmup()
+
+    def __exit__(self):
+        if type(self.source) == ecflow.Client:
+            try:
+                self.source.ch_drop()
+            except:
+                pass
+
+    def _set_register(self, path):
+        if "/" == path[0]:
+            suite = str(path.split("/")[1])
+            self.register = [
+                suite,
+            ]
+
+        elif path == "all":
+            self.register = list(skel.keys())
+
+        else:
+            child.report("abort", "register")
+
+    def _check(self, server, client, stop=0):
+        if client == self.source:
+            stop = 1
+
+        for suite in self.register:
+            top = client.get_defs().find_abs_node("/" + suite)
+
+            if top is None:
+                print(
+                    "#WAR: node not found",
+                    suite,
+                    server,
+                )
+                if stop:
+                    child.report("abort", "check")
+                elif self.act and server != self.sname:
+                    self._protect_oper(server)
+                    if self.replay:
+                        if type(definitions[suite]) == str:
+                            print("#WAR: not yet")
+                            child.report("abort", "str")
+                        print("replaying")
+
+                        defs = ecflow.Defs()
+                        defs.add_suite(definitions[suite])
+                        host = "localhost"
+                        client.load(defs)
+                        client.suspend("/" + suite)
+                        client.begin_suite(suite)
+                        client.sync_local()
+                    else:
+                        print("replay?")
+                else:
+                    pass
+
+            elif server != self.sname and not (
+                top.is_suspended()
+                or "%s" % top.get_state() == "unknown"  # normal backup server
+            ):  # test server
+                print("#ERR: top node shall be suspended - NOGO")
+                print("#ERR:", server, top.name(), top.get_state())
+                if 1:
+                    child.report("abort", "state")
+                print("#MSG: stop")
+                child.report("abort", "state")  # sys.exit(1)
+
+            else:
+                pass
+
+            if suite not in list(definitions.keys()):
+                raise Exception(list(definitions.keys()), suite)
+
+            if type(definitions[suite]) == str:
+                path = definitions[suite]
+
+            elif suite in self.path:
+                path = self.path
+
+            else:
+                return
+
+            node = client.get_defs().find_abs_node(path)
+            if node:
+                return
+            print("#WAR: node not found", path, server)
+            if stop:
+                child.report("abort", "stop")
+
+    def _update_var(self, var, nfrom, ndest, server, client, kind="edit"):
+        name = var.name()
+        vfrom = None
+        vdest = None
+        repeat = nfrom.get_repeat()
+        print("############# %s" % repeat, nfrom.get_abs_node_path())
+        if repeat and repeat.name() == name:
+            vfrom = repeat
+        else:
+            for vfrom in nfrom.variables:
+                if vfrom.name() == name:
+                    break
+
+        for vdest in ndest.variables:
+            if vdest.name() == name:
+                break
+        pnode = ndest.get_abs_node_path()
+        pnode = nfrom.get_abs_node_path()
+
+        if vfrom is None:
+            return
+
+        elif vfrom.name() != name:
+            return
+
+        if vdest is None:
+            return
+
+        vname = vdest.name()
+        vval = vdest.value()
+        if vname != name:
+            return
+
+        if vfrom.name() == vname and str(vfrom.value()) != str(vval) or FORCE:
+            if type(vfrom) == Repeat:
+                self.action(
+                    ndest.get_abs_node_path(),
+                    server,
+                    client,
+                    kind="repeat",
+                    value=str(vfrom.value()),
+                    msg="repeat requeue",
+                )
+            else:
+                self.action(
+                    pnode,
+                    server,
+                    client,
+                    kind=name,
+                    value=str(vfrom.value()),
+                    msg="value update",
+                )
+
+    def process(self, server=None, client=None, item=None, var=False):
+        if server is None:
+            self._check(self.sname, self.source, 1)
+
+            for server in self.servers:
+                server = server.replace("@", ":")
+                if DEBUG:
+                    print("#DBG: target is", server)
+                host, port = server.split(":")
+
+                if int(port) < 65536 and 0 == comm(
+                    ECFLOWC + "--ping --port %s --host %s" % (port, host), False
+                ):
+                    client = ecflow.Client(server)
+                    client.ch_register(False, self.register)
+                    client.sync_local()
+                    self._check(server, client)
+                    for suite in self.register:
+                        node = definitions[suite]
+                        if type(node) == str:
+                            node = self.source.get_defs().find_abs_node(node)
+                        # try: node.add(Label("memo", "This suite was generated by mirror.py"))
+                        # except: pass # used to sync, too late
+                        # update variables
+                        self.process(server, client, node, "repeat")
+                        # self.process(server, client, node) # update statuses
+                        # self.process(server, client, node, "edit") # update
+                        # variables
+                    client.ch_drop()
+
+                else:
+                    # child.report("abort","res")
+                    print("server is not responding")
+
+            if self.wait > 0:
+                print("#MSG: start again... snap ", self.wait)
+                time.sleep(self.wait)
+                self.wait = 0
+                self.source.sync_local()
+                self.process()
+            return
+
+        elif server == self.sname:
+            child.report("abort", "same name " + server + " " + self.sname)  # DONT
+
+        elif client is None:
+            child.report("abort", "no client")  # DONT
+
+        elif type(item) in (ecflow.Suite, ecf.Suite):
+
+            if 0:
+                pass
+            else:
+                # suite =
+                # client.get_defs().find_abs_node(item.get_abs_node_path())
+                suite = client.get_defs().find_abs_node(item.fullname())
+                # print(type(client), item.fullname(), type(suite))
+                if suite:
+                    if not suite.is_suspended():
+                        print("#ERR: top node shall be suspended - stop", suite, server)
+                        return
+                    for node in suite.nodes:
+                        self.process(server, client, node, var)
+            return
+
+        elif type(item) in (ecflow.Family, ecflow.Task):
+            pnode = item.get_abs_node_path()
+            nfrom = self.source.get_defs().find_abs_node(pnode)
+            if 0:
+                pass
+            else:
+                ndest = client.get_defs().find_abs_node(pnode)
+
+            if nfrom is None:
+                if var:
+                    return  # ignore
+                print(
+                    "#ERR: node not found, please update mirror.py skel",
+                    pnode,
+                    self.sname,
+                )
+                child.report("abort", "nfrom")
+
+            elif ndest is None:
+                if var:
+                    return  # ignore
+                print("#ERR: node not found, replay?", pnode, server)
+                return
+
+            else:
+                pass
+            if nfrom is not None:
+                status = "%s" % nfrom.get_state()
+            else:
+                raise Exception(pnode, self.source, "nfrom is not")
+
+            if 0:
+                pass
+            else:
+                dstate = "%s" % ndest.get_state()
+            is_task = type(item) == ecf.Task
+
+            for evs in nfrom.events:
+                for evd in ndest.events:
+                    # if evd.name_or_number() != evs.name_or_number(): continue
+                    if evd.name() == "" and evd.number() != evs.number():
+                        continue
+                    if evd.value() == evs.value():
+                        break
+                    print(
+                        "#event",
+                        evs.name(),
+                        evd.number(),
+                        evs.number(),
+                        evd.value(),
+                        evs.value(),
+                    )
+                    if evs.value():
+                        if evs.name() == "":
+                            self._send(
+                                "alter change event %d set %s;" % (evs.number(), pnode),
+                                client,
+                            )
+                            # client.alter(pnode, "change", "event", "%d" %
+                            # evs.number(), "set")
+                        else:
+                            self._send(
+                                "alter change event %s set %s;" % (evs.name(), pnode),
+                                client,
+                            )
+                        # else: client.alter(pnode, "change", "event",
+                        # evs.name(), "set")
+
+            for evs in nfrom.meters:
+                for evd in ndest.meters:
+                    if evd.name() != evs.name():
+                        continue
+                    if evd.value() == evs.value():
+                        break
+                    print("#meter", evd.value(), evs.value())
+                    try:
+                        value = evs.value()
+                        if value > 100:
+                            value = 100
+                        if value > 0:
+                            self._send(
+                                "alter change meter %s %s %s;"
+                                % (evs.name(), value, pnode),
+                                client,
+                            )
+                        # client.alter(pnode, "change", "meter", evs.name(),
+                        # "%s" % evs.value())
+                    except:
+                        pass
+
+            if status != dstate or FORCE:
+                print(
+                    "#WAR: diff ",
+                    pnode,
+                    status,
+                    dstate,
+                )
+                if status == "complete":
+                    self.action(
+                        pnode, server, client, status, is_task, msg="forced complete"
+                    )
+                    if not is_task:
+                        self._send("", client, send=True)
+                        return
+
+                elif status == "queued":
+                    # self._send("force queued %s;" % (pnode), client)
+                    self.action(
+                        pnode, server, client, status, is_task, msg="forced queued"
+                    )
+                elif status in (
+                    "submitted",
+                    "active",
+                    "unknown",
+                    "aborted",
+                ):
+                    print("#IGN: status is active/submit, ignored")
+                else:
+                    raise Exception(status)
+
+            if type(item) in (ecflow.Suite, ecflow.Family):
+                for node in item.nodes:
+                    self.process(server, client, node, var)
+
+            if var:
+                for edit in item.variables:
+                    self._update_var(edit, nfrom, ndest, server, client, var)
+
+            self._send("", client, send=True)
+        else:
+            raise Exception(type(item), item)
+
+    def action(
+        self, pnode, server, client, kind, is_task=False, value="20010101", msg=""
+    ):
+        if not self.act:
+            return
+
+        self._protect_oper(server)
+
+        print("#MSG:", msg)
+        if kind in (
+            "active",
+            "submitted",
+        ):
+            return
+        elif FORCE:
+            pass  # SMS ONLY
+
+        elif kind == "complete":
+            if is_task:
+                self._send("", client, True)
+                client.force_state(pnode, ecflow.State.complete)
+            else:
+                self._send("", client, True)
+                client.force_state_recursive(pnode, ecflow.State.complete)
+        elif kind == "queued":  # and is_task:
+            self._send("force queued %s;" % pnode, client)
+
+        elif kind == "repeat":
+            raise Exception
+
+        else:  # var
+            if DEBUG:
+                print("#DBG: update var", kind, value)
+            if kind in ("queued",):
+                pass
+            elif kind not in (
+                "YMD",
+                "JUL",
+                "DAY",
+                "SCHOST",
+                "STHOST",
+                "YYYY",
+                "MM",
+                "ECF_FILES",
+                "INIBEGINDATE",
+                "MIXTASK",
+            ):
+                raise Exception(kind)
+            if 0:
+                pass
+            else:
+                client.requeue(pnode)
+                self._send(
+                    "alter change variable %s %s %s;" % (kind, value, pnode),
+                    client,
+                    True,
+                )
+
+
+# ignore Family + queued while is might just be that we dont mirror all
+# fam/tasks and inheritance get it already complete in dest while still
+# queued in source
+
+
+############################
+def replay(path, defs=None):
+    import ecf
+
+    miss = "@undef@"
+    host = os.getenv("ECF_HOST", miss)
+    if host == miss:
+        print("ECF_HOST not defined")
+        exit(1)
+    port = os.getenv("ECF_PORT", 31415)
+    client = ecf.Client(host, port)
+    if defs is None:
+        defs = gen_suite(host, port, path)
+    if DEBUG:
+        print(defs)
+    # print(defs)
+    if (
+        "localhost" in host
+        and port in ("3141", 3141)
+        and ("/test" in path)
+        and "/mirror" not in path
+    ):
+        raise Exception("dont")
+
+    print("#MSG: replacing %s in " % path, host, port, defs)
+    client.replace(path, defs, 1, 1)
+    return client
+
+
+def comm(cmd, rem=True):
+    import subprocess
+
+    if rem and cmd in list(memo.keys()):
+        return memo[cmd]
+    (rc, res) = subprocess.getstatusoutput(cmd)
+    print("#COMM:", rc, res, cmd)
+    if rem:
+        memo[cmd] = rc
+    return rc
+
+
+############################
+class TestMirror(unittest.TestCase):
+    """ a test case """
+
+    def test_1(self, test_ok=1):
+        sname = "mirror"
+        replay("/" + sname, gen_suite())
+
+
+memo = dict()
+############################
+if __name__ == "__main__":
+    import argparse
+
+    parser = argparse.ArgumentParser(add_help=False)
+    parser.add_argument("-?", default=0, help="help")
+    parser.add_argument("-f", "--force", action="store_true", help="force")
+    parser.add_argument("-h", default=0, help="help")
+    parser.add_argument("-m", "--mirror", default="localhost@31415", help="mirror")
+    parser.add_argument("-p", "--path", default="/mirror/test", help="path")
+    parser.add_argument("-r", "--replay", action="store_true", help="replay")
+    parser.add_argument("-t", "--test", action="store_true", help="test")
+    parser.add_argument("-u", "--usage", action="store_true", help="test")
+
+    parsed = parser.parse_args()
+    global FORCE
+    FORCE = parsed.force
+    print(parsed.path, parsed.mirror, parsed.replay, parsed.force, parsed.test)
+    # raise Exception
+    child = Child()
+
+    if parsed.usage:
+        print(
+            """
+
+* mirrors (slow real-time) a source suite, from a source server, to a destination server
+* mirror suite can be hosted on the source, on the destination or another server
+* this script was used in ecflow course to demonstrate
+  * one script that can be used from the command line
+  * defines a suite
+  * play/replace a suite/node
+  * a script can be used as task wrapper/template to generate jobs
+  * an ecflow client (passive) to download status/value from source
+  * an ecflow client (active) to change status/value on destination
+
+* update mirror.py: destination variable with the triplet suite host port
+
+* update mirror.py: definition with the key(suite) and the minimum suite-tree to mirror
+
+* update mirror.py: replay add "if" for "protection" not to overwrite source suite by mistake
+
+* download a copy from the source suite
+  ecflow_client --port 3141 --host localhost --get > tmp.def
+
+* load the mirror suite on the source server
+  SUITE=test ECF_HOST=localhost ECF_PORT=3141 ./mirror.py -p /mirror/test -r # load
+
+* play (suspended) mirrored suite in destination
+  ECF_HOST=ecgate ECF_PORT=31415 ./mirror.py -m ecgate:31415 -p /test
+
+module load python3; module load ecflow/5.7.0
+ecflow_start.sh -p 5001 # source
+ecflow_start.sh -p 5003 # destination
+# ecflow_client --host vecf1 --port 44444 --get mc > mc.dump # an example suite
+ecflow_client --host localhost --port 5001 --replace /mc mc.dump # we take it as a source
+# definitions =  # contains "mc" definition
+# destinations = { # contains one destination for mc at least
+ export  SUITE=mc ECF_HOST=localhost ECF_PORT=5001
+ ./mirror.py -p /mirror/mc -r # load mirror on source server # might be destination or another server yet
+# ImportError: No module named ecf # ecf shall be in the path, at least it can found in ecflow distrib as 
+# ecflow/libs/pyext/samples/api/ecf.py
+# ('#MSG: replacing /mirror/test in ', 'localhost', '5001', #5.7.0 # loading OK
+# begin mirror - 
+# Script OK? mirror.py undef ECF_FILES directory?
+# Edit OK? $ is used as ECF_MICRO
+# cron OK?
+# set DESTINATIONS variable as expected
+
+ECF_HOST=localhost ECF_PORT=5003 python3 ./mirror.py -m localhost:5003 -p /mc # ok
+#COMM: 0 ping server(localhost:5003) succeeded in 00:00:00.001058  ~1 milliseconds ecflow_client --ping --port 5003 --host localhost # OK
+# replay?
+ECF_PORT=5003 python3 ./mirror.py -m localhost:5003 -p /mc -r # ok mc loaded on target
+# begin /mc in 5003 (it looks suspended
+# edit ECF_JOB_CMD "python3 $ECF_JOB$ > $ECF_JOBOUT$ &"
+
+# python3 /home/ma/map/mirror/mc/mirror.job1 # OK after ECF_PASS FREE running as zombie ommand line
+# ImportError: No module named 'ecf' # jobs lost in submit
+
+# mirror jobs submits and complete OKWITH ECF_JOB_CMD updated as 
+module load python3 && module load ecflow/5.7.0 && cd /home/ma/map && python3 $ECF_JOB$ > $ECF_JOBOUT$ 2>&1 &
+"""
+        )
+        sys.exit(2)
+
+    if not MICRO[0] in "$ECF_PORT$":
+        parsed.mirror = "$DESTINATIONS$"
+        parsed.path = "/$FAMILY1$"
+        print("#MSG: ssh %s kill -9 %d" % (os.uname()[1], os.getpid()))
+
+    if parsed.test:
+        sys.argv.pop()
+        unittest.main()
+
+    elif parsed.path and parsed.replay:
+        print("#MSG: path and replay", parsed.path, parsed.replay)
+        port = int(os.getenv("SMS_PROG", 0))
+        s = parsed.path.split("/")[1]
+        defs = None
+        if "mirror" not in parsed.path:
+            defs = Defs()
+            defs.add_suite(definitions[s])
+        replay(parsed.path, defs)
+
+    elif parsed.mirror and parsed.path:
+        print(parsed.mirror, "#", parsed.path, parsed.replay, type(Mirror))
+        mirror = Mirror(parsed.mirror, parsed.path, parsed.replay)
+        print("#MSG: step")
+        mirror.process()
+        print("#MSG: step")
+        child.report("complete")
+        print("#MSG: step")
+
+    else:
+        usage()
+    print("#MSG: step")
+    child.report("complete")
+"""
+  export ECF_HOST=localhost ECF_PORT=5001 SUITE=mc
+  ecflow_client --get /mc > tmp.def
+  ./mirror.py -p /mirror/mc -r # load
+
+  ECF_HOST=localhost ECF_PORT=31415 ./mirror.py -m localhost:31415 -p /mc
+
+/tmp/map/work/git/ecflow/libs/pyext/samples/mirror.py
+"""
diff -pruN 5.12.4-1/libs/pyext/samples/overview.py 5.13.0-1/libs/pyext/samples/overview.py
--- 5.12.4-1/libs/pyext/samples/overview.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/overview.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,458 @@
+#!/usr/bin/env python
+# -*- coding= UTF-8 -*-
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+""" tkinter example with ecflow
+"""
+
+import tkinter as tki
+from tkinter import *
+import queue
+import sys
+import time
+import os
+import pwd
+from threading import Thread
+try: from scrolledlist import ScrolledList
+except: 
+    loc = "http://infohost.nmt.edu/tcc/help/lang/python/examples/scrolledlist"
+    raise Exception("wget %s/scrolledlist.py; # Thanks NMT")
+
+loc = "/usr/local/apps/ecflow/current/lib/python2.7/site-packages/ecflow"
+sys.path.append(loc)
+loc = "/usr/local/lib/python2.7/site-packages/ecflow"
+sys.path.append(loc)
+import ecflow as ec
+
+PROGRAM_NAME = "ecflowview-overview"
+BUTTON_FONT = ('times', 12)
+MONO_FONT = ('lucidatypewriter', 14, 'bold')
+DEBUG = 0
+COLORS = {"aborted": "red",
+          "active":  "green",
+          "submitted": "cyan",
+          "complete": "yellow",
+          "suspended": "orange",
+          "queued": "blue",
+          "unknwon": "grey"}
+running = [True]
+
+ONCE = False
+
+
+def show_check(one):
+    print(one)
+    sep = ','
+    if sep not in one: return
+    exp = one.split(sep)
+    if len(exp) != 4: return
+    host, qid = exp[2], exp[3]
+    check = os.getenv("CHECK_TASK", "check_task.py")
+    global ONCE
+    if check is not None:
+        print(check +  " -n %s -j %s" % (host, qid))
+    elif ONCE:
+        print("#WAR: export CHECK_TASK=$HOME/bin/check_task.py; overview.py $ECF_HOST@$ECF_PORT,")
+        ONCE = True
+
+
+class Label(object):
+    """ a class to encapsulate what was a global variable"""
+    inst = None
+
+    def __init__(self, item): Label.inst = item
+
+    @classmethod
+    def update(cls):
+        if Label.inst is None:
+            return
+        Label.inst.set(time.strftime("%a, %d %b %Y %H:%M:%S"))
+
+
+class MenuBar(tki.Frame):
+    """ guess"""
+
+    def __init__(self, parent):
+        tki.Frame.__init__(self, parent)
+        self.parent = parent
+        self.__helpButton = self.__createHelp()
+        self.__helpButton.grid(row=0, column=3)
+        self.__quitButton = tki.Button(self, text='Quit', font=BUTTON_FONT,
+                                       command=root.destroy)
+        self.__quitButton.grid(row=0, column=1)
+        self.__updateButton = tki.Button(self, text='Update', font=BUTTON_FONT,
+                                         command=parent.update)
+        self.__updateButton.grid(row=0, column=2)
+
+    def quit(self, event=None):
+        self.parent.quit()
+
+    def __createHelp(self):
+        mb = tki.Menubutton(self, font=BUTTON_FONT,
+                            relief=tki.RAISED, text='Help')
+        menu = tki.Menu(mb)
+        mb['menu'] = menu
+        url = "https://confluence.ecmwf.int/display/ECFLOW/Documentation"
+
+        def url1(): self.__url(url=url)
+
+        def url2(): self.__url(url="http://effbot.org/tkinterbook/")
+        menu.add_command(command=url1, label="confluence tutorial?")
+        menu.add_command(command=url2, label="tkinter?")
+        return mb
+
+    def __url(self, url=None):
+        if url is not None:
+            os.system("${BROWSER:=firefox} %s" % url)
+
+
+class TaskList(tki.Frame):
+    """ a class to host all tasks"""
+    # WIDTH = w / 30
+    # LINES = h / 10
+
+    def __init__(self, parent, kind):
+        tki.Frame.__init__(self, parent, 
+                           # side="bottom", 
+                           # fill="both", 
+                           # expand=True,
+                           # sticky="nsew",
+        )
+        self.WIDTH = 80
+        self.LINES = 80
+        self.__kind = kind
+        self.__callback = None
+        #self.__label = tki.Label(
+        #    self, font=BUTTON_FONT, background=COLORS[kind], text=kind)
+        #self.__label.grid(row=0, column=0, sticky=tki.W)
+        select = tki.Button(self, text=kind,
+                                 font=BUTTON_FONT,
+                                 background=COLORS[kind],
+                                 command=self.select)
+        select.grid(row=1, column=0, sticky=tki.W)
+
+        selectall = tki.Button(self, text="select all",
+                                    font=BUTTON_FONT,
+                                    # background=COLORS[kind],
+                                    command=self.select_all)
+        selectall.grid(row=2, column=0, sticky=tki.W)
+
+        self.__scrolledList = ScrolledList(
+            self, 
+            # sticky="nsew",
+            width=self.WIDTH, 
+            height=self.LINES,  # selectmode=tki.EXTENDED,
+            callback=self.__callback)
+        self.__scrolledList.grid(row=3, column=0)
+
+    def select_all(self):
+        res = set()
+        item = self.__scrolledList.listbox.get(0, tki.END)
+        for one in item:
+            print(one)
+
+    def select(self):
+        res = set()
+        selected = self.__scrolledList.listbox.curselection()
+        for i in selected:
+            item = self.__scrolledList.listbox.get(i)
+            res.add(item)
+            for one in res: 
+                show_check(one)
+                
+    def insert(self, path): self.__scrolledList.append(path)
+
+    def clear(self): self.__scrolledList.clear()
+
+
+class PaceKeeper():
+    """ get regular updates"""
+    PACE = 60
+
+    def __init__(self, item, queue):
+        self._item = item
+        Thread(target=self.process, args=(queue, running)).start()
+
+    def process(self, queue, running):
+        while running:
+            queue.put(self._item.update)
+            time.sleep(self.PACE)
+
+    def run(self): self.update()
+
+    def update(self, verbose=False):
+        while True:
+            self._item.update()
+            time.sleep(self.PACE)
+
+
+class Client(object):
+    """ a class to focus on client-ecFlow-server comm"""
+
+    def __init__(self, one="localhost@31415"):
+        # try: nick, hhh = one.split("-")
+        # except: hhh = one; nick = None
+        if "@" in one:
+            host, port = one.split("@")
+        # except: 
+        else: host = "localhost"; port = 31415
+        self.nick = one
+        # if nick is None: self.nick = "%s@%s" % (host, port)
+        print("# client creation", self.nick, host, port)
+        self.client = ec.Client(host, port)
+
+    def process(self, win):
+        # Label.update()
+        self.client.sync_local()
+        defs = self.client.get_defs()
+        if len(defs) == 0:
+            print("# %s-%: empty content" % (self.host, self.port))
+        # Label.update()
+        for suite in defs.suites:
+            self.process_nc(suite, win)
+
+    def process_nc(self, node, win):
+        for item in node.nodes:
+            if isinstance(item, ec.Task):
+                self.process_node(item, win)
+            else:
+                self.process_nc(item, win)
+
+    def process_node(self, item, wins):
+        for kind, win in list(wins.items()):
+            status = "%s" % item.get_state()
+            if status != kind:
+                continue
+            change = item.get_state_change_time()
+            line = "#%s:%s,%s" % (
+                self.nick, item.get_abs_node_path(), change)
+            try:
+                import check_task as ct
+                qid = str(ct.display_var(item, "qid"))
+                host = ct.display_var(item, "ECF_JOB_CMD")
+                line += ",%s,%s" % (host, qid)
+            except: pass
+            win.insert(line)
+
+try:
+    sys.path.append('/usr/local/apps/sms/lib/')
+    import cdp
+    NOCDP = 0
+except:
+    NOCDP = 1
+
+
+class ClientSMS(Client):
+    """ example of class derivation to connect another server-scheduler"""
+    init = 0
+
+    def __init__(self, host="localhost", port=31415, nick=None):
+        if NOCDP:
+            return
+        if not ClientSMS.init:
+            cdp.cdp_init([""], 0)
+            ClientSMS.init = 1
+        else:
+            pass
+        node = cdp.sms_node()
+        tree = cdp.sms_info_pointed(node)
+        cdp.sms_numbers(port, 0)
+        timeout = 60
+        passwd = "1"
+        user = get_username()
+
+        if DEBUG:
+            print("#MSG: login:", nick, host, port, user)
+        handle, rc = cdp.sms_client_login(host, user, passwd,
+                                          timeout, port, tree)
+        self.handle = handle
+        self.host = host
+        self.port = port
+        self.num = -1
+        self.nick = nick
+        if nick is None:
+            self.nick = "%s@%d" % (self.host, self.port)
+
+    def process_node(self, node, wins):
+        if node.type != cdp.NODE_TASK:
+            kid = node.kids
+            while kid:
+                self.process_node(kid, wins)
+                kid = kid.__next__
+        else:
+            for kind, win in list(wins.items()):
+                state = "%s" % ClientSMS.status(node)
+                if state != kind:
+                    continue
+                path = cdp.sms_node_full_name(node)
+                win.insert("%s:%s" % (self.nick, path))
+                if DEBUG:
+                    print(self.host, self.port, path, state)
+
+    def process(self, win):
+        rc = cdp.sms_client_news(self.handle, self.num)
+        if rc or self.num == -1:
+            Label.update()
+            state = cdp.sms_client_status2(self.handle, self.num)
+            cdp.sms_client_status(self.handle, state, self.num)
+
+            item = cdp.sms_status2node(state)
+            if not item:
+                return
+            self.process_node(item, win)
+            Label.update()
+            cdp.sms_node_free(item)
+
+    @classmethod
+    def status(cls, node):
+        s_status = {
+            -1: "unknown",
+            0: "unknown",
+            1: "suspended",
+            2: "complete",
+            3: "queued",
+            4: "submitted",
+            5: "active",
+            6: "aborted",
+            7: "shutdown",
+            8: "halted",
+            9: "unknown", }
+        return s_status[node.status]
+
+    def __exit__(self):
+        cdp.sms_client_logout(self.handle)
+        print("# logout from", self.nick)
+
+    def __delete__(self):
+        cdp.sms_client_logout(self.handle)
+        print("# logout from", self.nick)
+
+
+
+class Application(tki.Frame):
+    """ main """
+
+    def __init__(self, parent=None, client=None, queue=None):
+        if parent is None: parent = tki.Tk()
+        w, h = parent.winfo_screenwidth(), parent.winfo_screenheight()
+        tki.Frame.__init__(self, parent)
+        if client is None:
+            raise Exception("#ERR: please provide a client...\n./overview.py $ECF_HOST@$ECF_PORT")
+        elif type(client) in (set, tuple):
+            self.__clients = client
+        else:
+            self.__clients = [client]
+        self.__queue = queue
+        # width = 640;         height = 780
+        width = w;         height = h
+        self.canvas = tki.Canvas(width=width, height=height, bg='black')
+        self.grid()
+        self.createWidgets()
+        self.canvas.after(50, self.check_queue)
+
+        self.bind_all("<space>", self.update)
+        # self.bind_all("Control_q", self.quit)
+        # self.bind_all("Control_z", self.resize)
+        self.bind_all("<Control-q>", self.quit)
+        self.bind_all("<Control-z>", self.resize)
+
+    def resize(self, event=None): print("New size is: {}x{}".format(event.width, event.height))
+
+    def quit(self, event=None):
+        print("quit...")
+        self.destroy()
+        # global running; running = [ False, ]
+        # sys.exit(0)
+
+    def createWidgets(self):
+        global root
+        root = self
+        rowx = 1
+        var = tki.StringVar(self)
+        glob = Label(root)
+        # glob = Label(var)
+        self.__menuBar = MenuBar(root)
+        self.__menuBar.grid(row=0, column=0, sticky=tki.W)
+        self.label = tki.Label(root, textvariable=var) # Label.inst)
+        self.label.grid(row=0, column=2, sticky=tki.E)
+        self.__wins = dict()
+        rowx += 1
+        colx = 0
+        kinds = ("active", "aborted", "submitted")
+        for kind in kinds:
+            self.__wins[kind] = TaskList(root, kind)
+            self.__wins[kind].grid(row=rowx, column=colx,
+                                   sticky=tki.S + tki.E + tki.W)
+            colx += 1
+        self.update()
+
+    def check_queue(self):
+        try:
+            self.__queue.get(block=False)
+        except queue.Empty:
+            pass
+        else:
+            self.update()
+        self.canvas.after(50, self.check_queue)
+
+    def update(self, event=None):
+        self.label.update()
+        for kind, win in list(self.__wins.items()):
+            win.clear()
+        for client in self.__clients:
+            if type(client) == list:
+                for clt in client:
+                    clt.process(self.__wins)
+            else:
+                client.process(self.__wins)
+
+
+def get_username(): return pwd.getpwuid(os.getuid())[0]
+
+
+def get_uid(): return pwd.getpwnam(get_username()).pw_uid
+
+
+if __name__ == '__main__':
+    try:
+        port = 1500 + int(get_uid())
+    except:
+        port = 31415
+
+    if len(sys.argv) > 1:
+        clients = []
+        for num in range(1, len(sys.argv)):            
+            sep = ','
+            arg = sys.argv[num]
+            if sep in arg:
+                for one in arg.split(sep):
+                    client = Client(one)
+            else:
+                client = Client(arg)
+            clients.append(client)
+    else: 
+        one = "localhost%d" % port
+        print("# using", one)
+        clients = [Client(one), ]
+
+    queue = queue.Queue()
+    app = Application(client=clients, queue=queue)
+    app.master.title(PROGRAM_NAME)
+    app.columnconfigure(0, weight=1)
+    app.rowconfigure(0, weight=1)
+    PaceKeeper(app, queue)
+    app.mainloop()
+
+"""
+python ./overview.py localhost@31415,
+"""
diff -pruN 5.12.4-1/libs/pyext/samples/printdefs.py 5.13.0-1/libs/pyext/samples/printdefs.py
--- 5.12.4-1/libs/pyext/samples/printdefs.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/printdefs.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,180 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+import ecflow
+import argparse # for argument parsing  
+import sys   
+
+class Indentor:
+    """This class manages indentation, 
+    It is used to correctly indent the definition node tree hierarchy
+    """
+    _index = 0
+    def __init__(self):
+        Indentor._index += 1
+    def __del__(self):
+        Indentor._index -= 1
+    @classmethod
+    def indent(cls):
+        for i in range(Indentor._index):
+            print(' ', end=' ')
+     
+class DefsTraverser:
+    """Traverse the ecflow.Defs definition and writes to standard out.
+    
+    Ecflow has the following hierarchy::
+       Task   --> Submittable   -->Node
+       Family --> NodeContainer -->Node
+       Suite  --> NodeContainer -->Node
+    
+    This demonstrates that all nodes in the node tree and all attributes are accessible.
+    Additionally the state data is also accessible. This class will write state data as
+    comments. If the definition was returned from the server, it allows access to latest 
+    snapshot of the state data held in the server. 
+    """
+    def __init__(self,defs):
+        assert (isinstance(defs,ecflow.Defs)),"Expected ecflow.Defs as first argument"
+        self.__defs = defs
+        
+    def do_print(self):
+        for extern in self.__defs.externs:
+            self.__println("extern " + extern)
+        for suite in self.__defs.suites:
+            self.__print("suite ")
+            self.__print_node(suite)
+            clock = suite.get_clock()
+            if clock:
+                indent = Indentor()
+                self.__println(str(clock))
+                del indent
+            self.__print_nc(suite)
+            self.__println("endsuite")  
+ 
+    def __print_nc(self,node_container):
+        indent = Indentor()
+        for node in node_container.nodes:
+            if isinstance(node, ecflow.Task):
+                self.__print("task ")
+                self.__print_node(node)
+                self.__print_alias(node)
+            else: 
+                self.__print("family ")
+                self.__print_node(node)
+                self.__print_nc(node)
+                self.__println("endfamily")
+        del indent
+
+    def __print_alias(self,task):
+       indent = Indentor()
+       for alias in task.nodes:
+           self.__print("alias ")
+           self.__print_node(alias)
+           self.__println("endalias")
+       del indent
+
+    def __print_node(self,node):
+        print(node.name() + " # state:" + str(node.get_state())) 
+        
+        indent = Indentor()
+        defStatus = node.get_defstatus()
+        if defStatus != ecflow.DState.queued: 
+            self.__println("defstatus " + str(defStatus))
+            
+        autocancel = node.get_autocancel()
+        if autocancel: self.__println(str(autocancel))
+        
+        repeat = node.get_repeat()
+        if not repeat.empty(): self.__println(str(repeat)  + " # value: " + str(repeat.value()))
+    
+        late = node.get_late()
+        if late: self.__println(str(late) + " # is_late: " + str(late.is_late()))
+
+        complete_expr = node.get_complete()
+        if complete_expr:
+            for part_expr in complete_expr.parts:
+                trig = "complete "
+                if part_expr.and_expr(): trig = trig + "-a "
+                if part_expr.or_expr():  trig = trig + "-o "
+                self.__print(trig)
+                print(part_expr.get_expression())
+        trigger_expr = node.get_trigger()
+        if trigger_expr:
+            for part_expr in trigger_expr.parts:
+                trig = "trigger "
+                if part_expr.and_expr(): trig = trig + "-a "
+                if part_expr.or_expr():  trig = trig + "-o "
+                self.__print(trig)
+                print(part_expr.get_expression()) 
+                
+        for var in node.variables:    self.__println("edit " + var.name() + " '" + var.value() + "'")
+        for meter in node.meters:     self.__println(str(meter) + " # value: " + str(meter.value()))
+        for event in node.events:     self.__println(str(event) + " # value: " + str(event.value()))
+        for label in node.labels:     self.__println(str(label) + " # value: " + label.new_value())
+        for limit in node.limits:     self.__println(str(limit) + " # value: " + str(limit.value()))
+        for inlimit in node.inlimits: self.__println(str(inlimit))
+        for the_time in node.times:   self.__println(str(the_time))
+        for today in node.todays:     self.__println(str(today))   
+        for date in node.dates:       self.__println(str(date))  
+        for day in node.days:         self.__println(str(day))   
+        for cron in node.crons:       self.__println(str(cron))    
+        for verify in node.verifies:  self.__println(str(verify))
+        for zombie in node.zombies:   self.__println(str(zombie))
+        for queue in node.queues:     self.__println(str(queue))
+        
+        del indent
+
+    def __print(self,the_string):
+        Indentor.indent()
+        print(the_string, end=' ')
+
+    def __println(self,the_string):
+        Indentor.indent()
+        print(the_string)
+ 
+if __name__ == "__main__":
+    
+    DESC = """Will list all the nodes and attributes in the definition
+              Usage:
+                Example1: List all the states
+                   printdefs.py --host cca --port 4141  
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--host', default="localhost",   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default="3141",   
+                        help="The port on the host, defaults to 3141")
+    ARGS = PARSER.parse_args()
+    #print ARGS    
+    
+    # ===========================================================================
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    try:
+        CL.ping() 
+
+        # get the incremental changes, and merge with defs stored on the Client 
+        CL.sync_local()
+        
+        # check to see if definition exists in the server
+        defs = CL.get_defs()
+        if len(defs) == 0 :
+            print("No suites found, exiting...")
+            sys.exit(0) 
+            
+        # print defs;
+        defs_traverser = DefsTraverser(defs)
+        defs_traverser.do_print()
+
+    except RuntimeError as ex:
+        print("Error: " + str(ex))
+        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/libs/pyext/samples/pyflow_example.py 5.13.0-1/libs/pyext/samples/pyflow_example.py
--- 5.12.4-1/libs/pyext/samples/pyflow_example.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/pyflow_example.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+#pyflow Method
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+#pyflow is a pure python module on top of ecflow native API ;
+# it is proposed to facilitate suites definitions. 
+# It is not yet provided in default standard location. 
+# It can be used, adding this one line to the definition script.
+
+import sys; sys.path.append("/home/ma/emos/def/pyflow")
+
+# Enter the following python code into a file i.e. test.py :
+
+#!/usr/bin/env python2.7
+import os
+from pyflow import (Suite, Family, Task, Variable)
+   
+print("Creating suite definition")   
+with Suite("test" ) as suite: 
+ ECF_HOME = os.path.join(os.getenv("HOME"),  "course") # python vriable
+ Variable("ECF_HOME", ECF_HOME)  # suite variable
+ Task("t1")
+print(suite.ecflow_definition()) 
+
+#Then run as a python script:
+
+
+#pyflow
+#Using pyflow, header files are generated and placed in the expected location (ECF_INCLUDE) when the suite is deployed:
+suite.deploy_suite()
diff -pruN 5.12.4-1/libs/pyext/samples/query/query.py 5.13.0-1/libs/pyext/samples/query/query.py
--- 5.12.4-1/libs/pyext/samples/query/query.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/query/query.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,50 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+import ecflow
+import argparse # for argument parsing  
+import sys  
+import os
+    
+if __name__ == "__main__":
+    DESC = """query node state
+              Usage:
+                   query.py --host cca --port 4141 --path /ecflow/regenerate
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--host', default=os.getenv("ECF_HOST","localhost"),   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default=os.getenv("ECF_PORT","3141"),   
+                        help="The port on the host, defaults to 3141")
+    PARSER.add_argument('--path', default="/",   
+                        help="The path to the node. i.e /suite/family/task")
+    ARGS = PARSER.parse_args()
+    
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    try:
+        CL.sync_local()
+        defs = CL.get_defs()        
+        if len(defs) == 0 :
+            print("No suites found, exiting...")
+            sys.exit(0) 
+        if ARGS.path == "/":
+            print(defs.get_state())
+        else:
+            node = defs.find_abs_node(ARGS.path)
+            if node is None:  
+                print("No node found at path " + ARGS.path)
+            else:
+                print(node.get_state())
+    except RuntimeError as ex:
+        print("Error: " + str(ex))
+        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/libs/pyext/samples/resume.py 5.13.0-1/libs/pyext/samples/resume.py
--- 5.12.4-1/libs/pyext/samples/resume.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/resume.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,81 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+import ecflow
+import argparse # for argument parsing     
+import sys
+
+if __name__ == "__main__":
+    
+    DESC = """Will resume any suspended 'node' who name matches input
+              Usage:
+                Example1: resume all suspended node whose name matches 'fred' for suite grib_api
+                   resume.py --host cca --port 4141 --suite grib_api --name fred
+            """    
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--host', default="localhost",   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default="3141",   
+                        help="The port on the host, defaults to 3141")
+    PARSER.add_argument('--suite',   
+                        help="The name of the suite")
+    PARSER.add_argument('--name', default="install",   
+                        help="The name of the node")
+    ARGS = PARSER.parse_args()
+    print(ARGS)    
+     
+    # ===========================================================================
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    try:
+        CL.ping() 
+
+        # get the incremental changes, and merge with defs stored on the Client 
+        CL.sync_local()
+        
+        # check to see if definition exists in the server
+        defs = CL.get_defs()
+        if len(defs) == 0 :
+            print("No suites found, exiting...")
+            sys.exit(0) 
+         
+        paths_list = []
+        node_vec = defs.get_all_nodes()
+        for node in node_vec:
+            if node.name() != ARGS.name: continue
+            if node.get_dstate() != ecflow.DState.suspended: continue
+
+            path = node.get_abs_node_path()
+            paths = path.split('/')
+            if paths[1] == ARGS.suite:
+                paths_list.append(path) 
+                
+        if len(paths_list) > 0:
+            CL.resume(paths_list)
+
+#        # requires ecflow >= 4.0.8
+#         suite = defs.find_suite(ARGS.suite)
+#         if suite is not None:
+#             paths_list = []
+#             node_vec = suite.get_all_nodes()
+#             for node in node_vec:
+#                 if node.name() == ARGS.name and node.get_dstate() == DState.SUSPENDED:
+#                     paths_list.append(node.get_abs_node_path())
+# 
+#             print paths_list
+#             if len(paths_list) > 0:
+#                  CL.resume(paths_list)
+        
+    except RuntimeError as ex:
+        print("Error: " + str(ex))
+        print("Check host and port number are correct.")
diff -pruN 5.12.4-1/libs/pyext/samples/run_batches_with_delay.py 5.13.0-1/libs/pyext/samples/run_batches_with_delay.py
--- 5.12.4-1/libs/pyext/samples/run_batches_with_delay.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/run_batches_with_delay.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,116 @@
+#!/usr/bin/env python3.6
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import ecflow
+import os       # for getenv
+import sys
+import shutil   # used to remove directory tree
+import argparse # for argument parsing     
+
+def sync_local(ci):
+    ci.sync_local()
+    return ci.get_defs() 
+
+def get_tasks_to_run(defs,paths):
+    print("Collating tasks to run in batch")
+    node_path_list = []
+    for path in paths:
+        node = defs.find_abs_node(path)
+        if not node:
+            print("Could not find node",path,"in the definition")
+            continue
+        if isinstance(node,ecflow.Task):
+            node_path_list.append(node.get_abs_node_path())
+        elif isinstance(node,ecflow.NodeContainer):
+            node_vec = node.get_all_nodes()
+            for n in node_vec:
+                if isinstance(n,ecflow.Task):
+                    node_path_list.append(n.get_abs_node_path())
+             
+    uniqueList = []
+    for path in node_path_list:
+        if path not in uniqueList:
+            uniqueList.append(path)
+            print(" found task",path)
+           
+    return uniqueList 
+    
+def chunks(list_to_break, chunk_size):
+    for i in range(0, len(list_to_break), chunk_size):
+        yield list_to_break[i:i + chunk_size]
+        
+def run_chunk(ci,list_of_task_paths):
+    defs = sync_local(ci)
+    CL.suspend(list_of_task_paths);
+
+
+if __name__ == "__main__":
+    
+    DESC = """ 
+            example:
+                python3 libs/pyext/samples/run_batches_with_delay.py -h polonius -p 4141 -b 4 -s 4 -n "/ecflow/cron /limit_basic"
+                The list of paths can be obtained from the GUI, using:
+                sh $WK/libs/pyext/samples/run_batches_with_delay.sh -h %ECF_HOST% -p %ECF_PORT% -b 10 -s 2 -n '<full_name>'
+            """    
+            
+    print("####################################################################")
+    print("Running ecflow version " + ecflow.Client().version()  + " debug build(" + str(ecflow.debug_build()) +")")
+    if 'PYTHONPATH' in os.environ:
+        print("PYTHONPATH: " + str(os.environ['PYTHONPATH'].split(os.pathsep)))
+    print("sys.path:   " + str(sys.path))
+    print("####################################################################")
+ 
+    default_port = "3141"
+    if "ECF_PORT" in os.environ:
+         default_port = os.environ["ECF_PORT"]
+ 
+    default_host = "localhost"
+    if "ECF_HOST" in os.environ:
+        default_host  = os.environ["ECF_HOST"]
+
+    PARSER = argparse.ArgumentParser(description=DESC,  
+                                     formatter_class=argparse.RawDescriptionHelpFormatter)
+    PARSER.add_argument('--host', default=default_host,   
+                        help="The name of the host machine, defaults to 'localhost'")
+    PARSER.add_argument('--port', default=default_port,   
+                        help="The port on the host, defaults to 3141")
+    PARSER.add_argument('--batch_size', default=10, type=int,
+                        help="The number of jobs to submit in batch")
+    PARSER.add_argument('--sleep_between_batch', default=5, type=int,  
+                        help="The number of seconds to sleep between the next batch")
+    PARSER.add_argument('--paths',
+                        help="This list of node path to execute. These could be suites/families.")
+    ARGS = PARSER.parse_args()
+    print(ARGS )  
+    
+    paths = ARGS.paths.split()
+    print(paths)
+    
+    # ===========================================================================
+    CL = ecflow.Client(ARGS.host, ARGS.port)
+    try:
+        print("check server " + ARGS.host + ":" + ARGS.port + " is running")
+        CL.ping() 
+        print("Server is running.")
+         
+        defs = sync_local(CL)
+        node_path_list = get_tasks_to_run(defs,paths)
+        
+        list_of_chunks = (list(chunks(node_path_list,ARGS.batch_size)))
+        for chunk in list_of_chunks:
+            print(chunk)
+            run_chunk(CL,chunk)
+        
+    except RuntimeError as ex:
+        print("Error: " + str(ex))
diff -pruN 5.12.4-1/libs/pyext/samples/run_batches_with_delay.sh 5.13.0-1/libs/pyext/samples/run_batches_with_delay.sh
--- 5.12.4-1/libs/pyext/samples/run_batches_with_delay.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/run_batches_with_delay.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,60 @@
+#!/bin/sh
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# Example of running a shell command from the GUI.
+# Use the following in ecflowUI:
+# sh $WK/libs/pyext/samples/run_batches_with_delay.sh -h %ECF_HOST% -p %ECF_PORT% -b 10 -s 2 -n '<full_name>'
+#    - sh at the front is required
+#    - the tick quotes on <full_name> are required
+#
+
+echo "test.sh $*"
+#exit 0
+
+function usage() {
+   echo "Usage: -h <host> -p <port> -b <batch_size> -s <sleep_between_batch> -n <node paths>"
+   echo "       -h        ECF_HOST"
+   echo "       -p        ECF_PORT"
+   echo "       -b        batch size. the number of job to be submitted in parallel"
+   echo "       -s        number of seconds to sleep between each batch"
+   echo "       -n        list of node paths."
+}
+
+host=
+port=
+batch_size=
+sleep_between_batch=
+
+while getopts ":h:p:b:s:n:" opt
+   do
+     case "${opt}" in
+        h ) host=$OPTARG;;
+        p ) port=$OPTARG;;
+        b ) batch_size=$OPTARG;;
+	    s ) sleep_between_batch=$OPTARG;;
+        n ) node_paths+=("$OPTARG");;
+     esac
+done
+
+echo "host:$host"
+echo "port:$port"
+echo "batch_size=$batch_size"
+echo "sleep_between_batch=$sleep_between_batch"
+echo "paths='${node_paths[@]}'"
+ 
+for path in $node_paths; do
+   echo $path
+done   
+
+python3 /var/tmp/ma0/workspace/ecflow/libs/pyext/samples/run_batches_with_delay.py --host $host --port $port --batch_size $batch_size --sleep_between_batch $sleep_between_batch --paths "$node_paths"
diff -pruN 5.12.4-1/libs/pyext/samples/test.py 5.13.0-1/libs/pyext/samples/test.py
--- 5.12.4-1/libs/pyext/samples/test.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/samples/test.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,46 @@
+#!/usr/bin/env python2.7
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import sys
+sys.path.append("../../../admin/2.0")
+import rest
+import argparse
+
+PARSER = argparse.ArgumentParser(description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter)
+PARSER.add_argument('--file', help="Tar file to upload")
+ARGS = PARSER.parse_args()
+    
+conflunce_base_url = "https://software-test.ecmwf.int/wiki"
+confluence = rest.Confluence(conflunce_base_url,"deploy","deploy2013")
+page_id = confluence.get_page_id("ECFLOW","Releases") 
+if page_id is None:
+    sys.exit(1)
+
+attachment = confluence.get_attachment_id(page_id,ARGS.file)
+if attachment is not None:
+    print("space key:",space_key," allready has an attachment for file ",ARGS.file)
+else:
+    confluence.create_attachment(page_id,"%TARBALL_COMMENT%",ARGS.file)
+    
+#     # ===========================================================================
+#     CL = ecflow.Client("localhost", 4141)
+#     try:
+#         CL.ping() 
+#         print "ping worked";
+#         
+#         alter = 'alter add variable X "X XX" /ecflow/test_local_actions; alter add variable xx "y a" /ecflow/test_local_actions;'
+#         CL.group(alter)
+#  
+#     except RuntimeError, ex:
+#         print "Error: " + str(ex)
diff -pruN 5.12.4-1/libs/pyext/script.py 5.13.0-1/libs/pyext/script.py
--- 5.12.4-1/libs/pyext/script.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/script.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+#
+#
+print 'Hello World !'
+number = 42
diff -pruN 5.12.4-1/libs/pyext/setup.py 5.13.0-1/libs/pyext/setup.py
--- 5.12.4-1/libs/pyext/setup.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/setup.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,108 @@
+#!/usr/bin/env python
+from distutils.core import setup, Extension
+import os
+import sys
+import glob
+
+# ========================================================================
+# Usage:
+#   cd $WK; cd ecbuild/release/; sh -x ../../cmake.sh release; make ; make install
+#   calling 'sh -x ../../cmake.sh release' will generate setup.py from setup.py.in
+# Issues:
+#   Cannot test cmake install, since it will always install to 
+#     /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
+#
+# To test install manually, we can:
+#   python3 setup.py --help-commands # help
+#
+#   cd $WK/libs/pyext
+#   rm -rf build/                     # for a clean build
+#   python setup.py build_ext         # build C/C++ extensions (compile/link to build directory)
+#   python setup.py install --home=~
+#
+# See: http://docs.python.org/2/distutils/apiref.html?highlight=extension#distutils.core.Extension
+#
+# ==========================================================================
+# Permissions: The permission of configured file are wrong: 2 choices
+# o Make sure origin file, has the right permissions
+# o Copy file to different directory, and change the permissions
+#   since file(COPY) does rename files
+#   configure_file(setup.py.in /tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/CMakeFiles/setup.py)
+#       now copy the temporary into the final destination, setting the permissions
+#   file(COPY /tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/CMakeFiles/setup.py
+#     DESTINATION /tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox
+#     FILE_PERMISSIONS OWNER_READ OWNER_WRITE OWNER_EXECUTE GROUP_READ
+#     GROUP_EXECUTE WORLD_READ WORLD_EXECUTE)
+# ============================================================================
+        
+#=============================================================================
+# define the directories to search for include files
+# to get this to work, you will need to include the path
+# to your boost installation and  ecflow includes
+boost_root=os.getenv("BOOST_ROOT") 
+include_dirs = [ "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../3rdparty/cereal/include",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/core/src",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/attribute/src",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/node/parser/src",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/node/src",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/base/src",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/base/src/cts",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/base/src/stc",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/simulator/src",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/../libs/client/src",
+                 "/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/src",
+                 boost_root,
+               ]
+
+# define the library directories to include any extra libraries that may be needed.
+# Give preference to release libs   
+boost_lib_dir = boost_root + "/stage/lib/"
+library_dirs = ['/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/libs/core',
+                '/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/libs/attribute/',
+                '/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/libs/node/',
+                '/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/libs/base/',
+                '/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/libs/simulator/',
+                '/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow-build-sandbox/libs/client/',
+                boost_lib_dir,
+               ]
+
+# define the libraries to link with this includes the boost lib
+libraries = [ 'core' , 'nodeattr', 'node', 'base', 'libsimu', 'libclient',
+              'boost_system',
+              'boost_filesystem',
+              'boost_program_options',
+              'boost_date_time', 
+              'boost_python36' ]
+
+# Using gcc-4.8 with boost 1.53 linux requires these flags
+extra_compile_args = ['-ftemplate-depth-512','-Wno-unused-variable','-Wno-deprecated-declarations','-Wno-unused-local-typedefs','-Wno-maybe-uninitialized' ]
+extra_link_args = []
+
+# create the extension and add it to the python distribution
+# o glob.glob(os.path.join('src', '*.cpp'))
+#   This expand the list of cpp files that need to be compiled
+#
+# The configuation below installs to:
+#   o /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
+#     when, "python setup.py install" is used:
+#   lib/python2.7/site-packages/ecflow/ecflow.so
+#                                     __init__.py               
+setup( name='ecflow', 
+       version='5.13.0', 
+       author      = 'ECMWF',
+       description = """ecflow Python interface""",
+       packages = [ 'ecflow' ],
+       url = 'https://confluence.ecmwf.int/display/ECFLOW/ecflow+home',
+       license = 'Apache',
+       package_dir={'ecflow': '/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/ecflow'},
+       ext_modules=[ Extension( 
+                              'ecflow.ecflow', 
+                              glob.glob(os.path.join('/tmp/ecflow-packaging-stage.EUzwQz10jU/ecflow/libs/pyext/src', '*.cpp')), 
+                              include_dirs=include_dirs, 
+                              library_dirs=library_dirs, 
+                              libraries=libraries,
+                              extra_compile_args=extra_compile_args,
+                              extra_link_args=extra_link_args
+                              )
+                    ],
+   )
diff -pruN 5.12.4-1/libs/pyext/setup.py.in 5.13.0-1/libs/pyext/setup.py.in
--- 5.12.4-1/libs/pyext/setup.py.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/setup.py.in	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,108 @@
+#!/usr/bin/env python
+from distutils.core import setup, Extension
+import os
+import sys
+import glob
+
+# ========================================================================
+# Usage:
+#   cd $WK; cd ecbuild/release/; sh -x ../../cmake.sh release; make ; make install
+#   calling 'sh -x ../../cmake.sh release' will generate setup.py from setup.py.in
+# Issues:
+#   Cannot test cmake install, since it will always install to 
+#     /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
+#
+# To test install manually, we can:
+#   python3 setup.py --help-commands # help
+#
+#   cd $WK/libs/pyext
+#   rm -rf build/                     # for a clean build
+#   python setup.py build_ext         # build C/C++ extensions (compile/link to build directory)
+#   python setup.py install --home=~
+#
+# See: http://docs.python.org/2/distutils/apiref.html?highlight=extension#distutils.core.Extension
+#
+# ==========================================================================
+# Permissions: The permission of configured file are wrong: 2 choices
+# o Make sure origin file, has the right permissions
+# o Copy file to different directory, and change the permissions
+#   since file(COPY) does rename files
+#   configure_file(setup.py.in ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/setup.py)
+#       now copy the temporary into the final destination, setting the permissions
+#   file(COPY ${CMAKE_BINARY_DIR}${CMAKE_FILES_DIRECTORY}/setup.py
+#     DESTINATION ${CMAKE_BINARY_DIR}
+#     FILE_PERMISSIONS OWNER_READ OWNER_WRITE OWNER_EXECUTE GROUP_READ
+#     GROUP_EXECUTE WORLD_READ WORLD_EXECUTE)
+# ============================================================================
+        
+#=============================================================================
+# define the directories to search for include files
+# to get this to work, you will need to include the path
+# to your boost installation and  ecflow includes
+boost_root=os.getenv("BOOST_ROOT") 
+include_dirs = [ "@CMAKE_CURRENT_SOURCE_DIR@/../3rdparty/cereal/include",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/core/src",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/attribute/src",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/node/parser/src",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/node/src",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/base/src",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/base/src/cts",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/base/src/stc",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/simulator/src",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/../libs/client/src",
+                 "@CMAKE_CURRENT_SOURCE_DIR@/src",
+                 boost_root,
+               ]
+
+# define the library directories to include any extra libraries that may be needed.
+# Give preference to release libs   
+boost_lib_dir = boost_root + "/stage/lib/"
+library_dirs = ['@CMAKE_BINARY_DIR@/libs/core',
+                '@CMAKE_BINARY_DIR@/libs/attribute/',
+                '@CMAKE_BINARY_DIR@/libs/node/',
+                '@CMAKE_BINARY_DIR@/libs/base/',
+                '@CMAKE_BINARY_DIR@/libs/simulator/',
+                '@CMAKE_BINARY_DIR@/libs/client/',
+                boost_lib_dir,
+               ]
+
+# define the libraries to link with this includes the boost lib
+libraries = [ 'core' , 'nodeattr', 'node', 'base', 'libsimu', 'libclient',
+              'boost_system',
+              'boost_filesystem',
+              'boost_program_options',
+              'boost_date_time', 
+              'boost_python36' ]
+
+# Using gcc-4.8 with boost 1.53 linux requires these flags
+extra_compile_args = ['-ftemplate-depth-512','-Wno-unused-variable','-Wno-deprecated-declarations','-Wno-unused-local-typedefs','-Wno-maybe-uninitialized' ]
+extra_link_args = []
+
+# create the extension and add it to the python distribution
+# o glob.glob(os.path.join('src', '*.cpp'))
+#   This expand the list of cpp files that need to be compiled
+#
+# The configuation below installs to:
+#   o /usr/local/apps/python/current/lib/python2.7/site-packages/ecflow
+#     when, "python setup.py install" is used:
+#   lib/python2.7/site-packages/ecflow/ecflow.so
+#                                     __init__.py               
+setup( name='ecflow', 
+       version='@ecflow_VERSION@', 
+       author      = 'ECMWF',
+       description = """ecflow Python interface""",
+       packages = [ 'ecflow' ],
+       url = 'https://confluence.ecmwf.int/display/ECFLOW/ecflow+home',
+       license = 'Apache',
+       package_dir={'ecflow': '@CMAKE_CURRENT_SOURCE_DIR@/ecflow'},
+       ext_modules=[ Extension( 
+                              'ecflow.ecflow', 
+                              glob.glob(os.path.join('@CMAKE_CURRENT_SOURCE_DIR@/src', '*.cpp')), 
+                              include_dirs=include_dirs, 
+                              library_dirs=library_dirs, 
+                              libraries=libraries,
+                              extra_compile_args=extra_compile_args,
+                              extra_link_args=extra_link_args
+                              )
+                    ],
+   )
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/BoostPythonUtil.cpp 5.13.0-1/libs/pyext/src/ecflow/python/BoostPythonUtil.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/BoostPythonUtil.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/BoostPythonUtil.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,86 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/BoostPythonUtil.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/core/Converter.hpp"
+
+void BoostPythonUtil::list_to_int_vec(const boost::python::list& list, std::vector<int>& int_vec) {
+    auto the_list_size = len(list);
+    int_vec.reserve(the_list_size);
+    for (ssize_t i = 0; i < the_list_size; ++i) {
+        int_vec.push_back(boost::python::extract<int>(list[i]));
+    }
+}
+
+void BoostPythonUtil::list_to_str_vec(const boost::python::list& list, std::vector<std::string>& vec) {
+    auto the_list_size = len(list);
+    vec.reserve(the_list_size);
+    for (ssize_t i = 0; i < the_list_size; ++i) {
+        vec.push_back(boost::python::extract<std::string>(list[i]));
+    }
+}
+
+void BoostPythonUtil::list_to_str_vec(const boost::python::list& list, std::vector<Variable>& vec) {
+    auto the_list_size = len(list);
+    vec.reserve(the_list_size);
+    for (ssize_t i = 0; i < the_list_size; ++i) {
+        vec.push_back(boost::python::extract<Variable>(list[i]));
+    }
+}
+
+void BoostPythonUtil::dict_to_str_vec(const boost::python::dict& dict,
+                                      std::vector<std::pair<std::string, std::string>>& str_pair_vec) {
+    boost::python::list keys = dict.keys();
+    const auto no_of_keys    = len(keys);
+    str_pair_vec.reserve(no_of_keys);
+
+    for (ssize_t i = 0; i < no_of_keys; ++i) {
+
+        std::string second;
+        std::string first = boost::python::extract<std::string>(keys[i]);
+        if (boost::python::extract<std::string>(dict[keys[i]]).check()) {
+            second = boost::python::extract<std::string>(dict[keys[i]]);
+        }
+        else if (boost::python::extract<int>(dict[keys[i]]).check()) {
+            int the_int = boost::python::extract<int>(dict[keys[i]]);
+            second      = ecf::convert_to<std::string>(the_int);
+        }
+        else
+            throw std::runtime_error("BoostPythonUtil::dict_to_str_vec: type not convertible to string or integer");
+        str_pair_vec.emplace_back(first, second);
+    }
+}
+
+void BoostPythonUtil::dict_to_str_vec(const boost::python::dict& dict, std::vector<Variable>& vec) {
+    boost::python::list keys = dict.keys();
+    const auto no_of_keys    = len(keys);
+    vec.reserve(no_of_keys);
+
+    for (ssize_t i = 0; i < no_of_keys; ++i) {
+
+        std::string second;
+        std::string first = boost::python::extract<std::string>(keys[i]);
+        if (boost::python::extract<std::string>(dict[keys[i]]).check()) {
+            second = boost::python::extract<std::string>(dict[keys[i]]);
+        }
+        else if (boost::python::extract<int>(dict[keys[i]]).check()) {
+            int the_int = boost::python::extract<int>(dict[keys[i]]);
+            second      = ecf::convert_to<std::string>(the_int);
+        }
+        else
+            throw std::runtime_error("BoostPythonUtil::dict_to_str_vec: type not convertible to string or integer");
+
+        vec.emplace_back(first, second);
+    }
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/BoostPythonUtil.hpp 5.13.0-1/libs/pyext/src/ecflow/python/BoostPythonUtil.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/BoostPythonUtil.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/BoostPythonUtil.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_BoostPythonUtil_HPP
+#define ecflow_python_BoostPythonUtil_HPP
+
+#include <vector>
+
+#include <boost/python.hpp> // IWYU pragma: keep
+
+class Variable;
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+
+class BoostPythonUtil {
+public:
+    BoostPythonUtil()                                  = delete;
+    BoostPythonUtil(const BoostPythonUtil&)            = delete;
+    BoostPythonUtil& operator=(const BoostPythonUtil&) = delete;
+
+    /// Convert python list to a vector of integers. raises a type error if integer extraction fails
+    static void list_to_int_vec(const boost::python::list& list, std::vector<int>& int_vec);
+    static void list_to_str_vec(const boost::python::list& list, std::vector<std::string>& int_vec);
+    static void list_to_str_vec(const boost::python::list& list, std::vector<Variable>& vec);
+    static void dict_to_str_vec(const boost::python::dict& dict,
+                                std::vector<std::pair<std::string, std::string>>& str_pair);
+    static void dict_to_str_vec(const boost::python::dict& dict, std::vector<Variable>& vec);
+};
+
+template <typename T>
+const T copyObject(const T& v) {
+    return v;
+}
+
+#endif /* ecflow_python_BoostPythonUtil_HPP */
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ClientDoc.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ClientDoc.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ClientDoc.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ClientDoc.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1586 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/ClientDoc.hpp"
+
+const char* ClientDoc::class_client() {
+    return "Class client provides an interface to communicate with the `ecflow_server`_.:\n\n"
+           ".. code-block:: shell\n\n"
+           "   Client(\n"
+           "      string host, # The server name. Cannot be empty.\n"
+           "      string port  # The port on the server, must be unique to the server\n"
+           "   )\n\n"
+           "   Client(\n"
+           "      string host, # The server name. Cannot be empty.\n"
+           "      int port     # The port on the server, must be unique to the server\n"
+           "   )\n\n"
+           "   Client(\n"
+           "      string host_port, # Expects <host>:<port> || <host>@<port>\n"
+           "   )\n\n"
+           "The client reads in the following environment variables.\n"
+           "For child commands,(i.e these are commands called in the .ecf/jobs files), these variables are used.\n"
+           "For the python interface these environment variable are not really applicable but documented for "
+           "completeness:\n\n"
+           "* ECF_NAME <string> : Full path name to the task\n"
+           "* ECF_PASS <string> : The jobs password, allocated by server, then used by server to authenticate client "
+           "request\n"
+           "* ECF_TRYNO <int>   : The number of times the job has run. Used in file name generation. Set to 1 by "
+           "begin() and re-queue commands.\n"
+           "* ECF_TIMEOUT <int> : Max time in seconds for client to deliver message to main server\n"
+           "* ECF_HOSTFILE <string> : File that lists alternate hosts to try, if connection to main host fails\n"
+           "* ECF_DENIED <any> : Provides a way for child to exit with an error, if server denies connection. Avoids "
+           "24hr wait. Note: when you have hundreds of tasks, using this approach requires a lot of manual "
+           "intervention to determine job status\n"
+           "* NO_ECF <any> : If set exit's immediately with success. Used to test jobs without communicating with "
+           "server\n\n"
+           "The following environment variables are used by the python interface and child commands\n\n"
+           "* ECF_HOST  <string>   : The host name of the main server. defaults to 'localhost'\n"
+           "* ECF_PORT  <int>      : The TCP/IP port to call on the server. Must be unique to a server\n\n"
+           "The ECF_HOST and ECF_PORT can be overridden by using the Constructor or set_host_port() member function.\n"
+           "For optimal usage it is best to reuse the same Client rather than recreating for each client server "
+           "interaction\n"
+           "By default the Client interface will throw exceptions for error's.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client('localhost:3150')   # for errors will throw RuntimeError\n"
+           "       ci.terminate_server()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n\n";
+}
+
+const char* ClientDoc::set_host_port() {
+    return "Explicitly set the host and port to be used by the client, overriding the default host name (localhost) "
+           "and port (3141) and the environment variables: ECF_HOST and ECF_PORT.\n\n"
+           ".. code-block:: shell\n\n"
+           "   set_host_port(\n"
+           "      string host, # The server name. Cannot be empty.\n"
+           "      string port  # The port on the server, must be unique to the server\n"
+           "   )\n\n"
+           "   set_host_port(\n"
+           "      string host, # The server name. Cannot be empty.\n"
+           "      int port     # The port on the server, must be unique to the server\n"
+           "   )\n\n"
+           "   set_host_port(\n"
+           "      string host_port, # Expects <host>:<port> or <host>@<port>\n"
+           "   )\n\n"
+           "Exceptions:\n\n"
+           "- Raise a RuntimeError if the host or port is empty\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()\n"
+           "       ci.set_host_port('localhost','3150')\n"
+           "       ci.set_host_port('avi',3150)\n"
+           "       ci.set_host_port('avi:3150')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n\n";
+}
+
+const char* ClientDoc::set_retry_connection_period() {
+    return "Set the sleep period between connection attempts\n\n"
+           "Whenever there is a connection failure we wait a number of seconds before trying again.\n"
+           "i.e. to get round glitches in the network.\n"
+           "For the ping command this is hard wired as 1 second.\n"
+           "This wait between connection attempts can be configured here.\n"
+           "i.e This could be reduced to increase responsiveness.\n"
+           "Default: In debug this period is 1 second and in release mode 10 seconds.\n\n"
+           ".. code-block:: shell\n\n"
+           "   set_retry_connection_period(\n"
+           "      int period # must be an integer >= 0\n"
+           "   )\n\n"
+           "Exceptions:\n\n"
+           "- None\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   ci = Client()\n"
+           "   ci.set_connection_attempts(3)     # make 3 attempts for server connection\n"
+           "   ci.set_retry_connection_period(1) # wait 1 second between each attempt\n";
+}
+
+const char* ClientDoc::set_connection_attempts() {
+    return "Set the number of times to connect to `ecflow_server`_, in case of connection failures\n\n"
+           "The period between connection attempts is handled by Client.set_retry_connection_period().\n"
+           "If the network is unreliable the connection attempts can be be increased, likewise\n"
+           "when the network is stable this number could be reduced to one.\n"
+           "This can increase responsiveness and reduce latency.\n"
+           "Default value is set as 2.\n"
+           "Setting a value less than one is ignored, will default to 1 in this case::\n\n"
+           "   set_connection_attempts(\n"
+           "      int attempts # must be an integer >= 1\n"
+           "   )\n"
+           "\nExceptions:\n\n"
+           "- None\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   ci = Client()\n"
+           "   ci.set_connection_attempts(3)     # make 3 attempts for server connection\n"
+           "   ci.set_retry_connection_period(1) # wait 1 second between each attempt\n";
+}
+
+const char* ClientDoc::get_defs() {
+    return "Returns the `suite definition`_ stored on the Client.\n\n"
+           "Use :py:class:`ecflow.Client.sync_local()` to retrieve the definition from the server first.\n"
+           "The definition is *retained* in memory until the next call to sync_local().\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()         # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.sync_local()       # get the definition from the server and store on 'ci'\n"
+           "       print(ci.get_defs())  # print out definition stored in the client\n"
+           "       print(ci.get_defs())  # print again, this shows that defs is retained on ci\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::edit_script_edit() {
+    return "get script for Edit\n";
+}
+
+const char* ClientDoc::edit_script_preprocess() {
+    return "get script for Edit Preprocess\n";
+}
+
+const char* ClientDoc::edit_script_submit() {
+    return "submit script from Edit/Preprocess \n"
+           "to run as alias or not:\n\n"
+           ".. code-block:: python\n\n"
+           " ci = Client()\n"
+           " ci.edit_script_submit(path_to_task,\n"
+           "	                   used_variables, # array name=value\n"
+           "	                   file_contents,  # strings array\n"
+           "	                   alias, # bool False,\n"
+           "	                   run  # bool true\n"
+           "                      )\n";
+}
+
+const char* ClientDoc::get_log() {
+    return "Request the `ecflow_server`_ to return the log file contents as a string\n\n"
+           "Use with caution as the returned string could be several megabytes.\n"
+           "Only enabled in the debug build of ECF.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()          # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       print(ci.get_log(100)  # get the 100 last lines from server log file\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::new_log() {
+    return "Request the `ecflow_server`_ to use the path provided, as the new log file\n\n"
+           "The old log file is released.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()               # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.new_log('/path/log.log') # use '/path/log,log' as the new log file\n"
+           "                                   # To keep track of log file Can change ECF_LOG\n"
+           "       ci.alter('\','change','variable','ECF_LOG','/new/path.log')\n"
+           "       ci.new_log()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::clear_log() {
+    return "Request the `ecflow_server`_ to clear log file.\n\n"
+           "Log file will be empty after this call.\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.clear_log()   # log file is now empty\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::flush_log() {
+    return "Request the `ecflow_server`_ to flush and then close log file\n\n"
+           "It is best that the server is `shutdown`_ first, as log file will be reopened\n"
+           "whenever a command wishes to log any changes.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.flush_log()   # Log can now opened by external program\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::log_msg() {
+    return "";
+}
+
+const char* ClientDoc::restart_server() {
+    return "Restart the `ecflow_server`_\n\n"
+           "Start job scheduling, communication with jobs, and respond to all requests.\n"
+           "See `server states`_\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.restart_server()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+const char* ClientDoc::halt_server() {
+    return "Halt the `ecflow_server`_\n\n"
+           "Stop server communication with jobs, and new job scheduling, and stops check pointing.\n"
+           "See `server states`_\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.halt_server()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+const char* ClientDoc::shutdown_server() {
+    return "Shut down the `ecflow_server`_\n\n"
+           "Stop server from scheduling new jobs.\n"
+           "See `server states`_\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.shutdown_server()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::terminate_server() {
+    return "Terminate the `ecflow_server`_\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.terminate_server()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::wait_for_server_reply() {
+    return "Wait for a response from the `ecflow_server`_::\n\n"
+           "   void wait_for_server_reply(\n"
+           "      int time_out     : (default = 60) \n"
+           "   )\n\n"
+           "This is used to check if server has started. Typically for tests.\n"
+           "Returns true if server(ping) replies before time out, otherwise false\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "   if ci.wait_for_server_reply(30):\n"
+           "      print('Server is alive')\n"
+           "   else:\n"
+           "      print('Timed out after 30 second wait for server response.?')\n";
+}
+
+const char* ClientDoc::load_defs() {
+    return "Load a `suite definition`_ or checkpoint file given by the file_path argument into the "
+           "`ecflow_server`_\n::\n\n"
+           "   void load(\n"
+           "      string file_path     : path name to the definition file\n"
+           "      [(bool)force=False]  : If true overwrite suite of same name\n"
+           "      [(bool)print=False]  : print parsed defs to standard out\n"
+           "   )\n\n"
+           "By default throws a RuntimeError exception for errors.\n"
+           "If force is not used and `suite`_ of the same name already exists in the server,\n"
+           "then a error is thrown\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   defs_file = 'Hello.def' \n"
+           "   defs = Defs()\n"
+           "   suite = def.add_suite('s1')\n"
+           "   family = suite.add_family('f1')\n"
+           "   for i in [ '_1', '_2', '_3' ]:\n"
+           "      family.add_task( 't' + i )\n"
+           "   defs.save_as_defs(defs_file)  # write out in memory defs into the file 'Hello.def'\n"
+           "   ...\n"
+           "   try:\n"
+           "       ci = Client()       # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.load(defs_file)  # open and parse defs or checkpoint file, and load into server.\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::load() {
+    return "Load a in memory `suite definition`_ into the `ecflow_server`_\n::\n\n"
+           "   void load(\n"
+           "      Defs defs           : A in memory definition\n"
+           "      [(bool)force=False] : for true overwrite suite of same name\n"
+           "   )\n\n"
+           "If force is not used and `suite`_ already exists in the server, then a error is thrown.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   defs = Defs()\n"
+           "   suite = defs.add_suite('s1')\n"
+           "   family = suite.add_family('f1')\n"
+           "   for i in [ '_1', '_2', '_3' ]: \n"
+           "       family.add_task( Task( 't' + i) )\n"
+           "   ...\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.load(defs)    # Load in memory defs, into the server\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::get_server_defs() {
+    return "Get all suite Node tree's from the `ecflow_server`_.\n\n"
+           "The definition is *retained* in memory until the next call to get_server_defs().\n"
+           "This is important since get_server_defs() could return several megabytes of data.\n"
+           "Hence we only want to call it once, and then access it locally with get_defs().\n"
+           "If you need to access the server definition in a loop use :py:class:`ecflow.Client.sync_local` instead\n"
+           "since this is capable of returning incremental changes, and thus considerably\n"
+           "reducing the network load.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()         # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.get_server_defs()  # get the definition from the server and store on 'ci'\n"
+           "       print(ci.get_defs())  # print out definition stored in the client\n"
+           "       print(ci.get_defs())  # print again, this shows that defs is retained on ci\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::sync() {
+    return "Requests that `ecflow_server`_ returns the full definition or incremental change made and applies them to "
+           "the client Defs\n\n"
+           "When there is a very large definition, calling :py:class:`ecflow.Client.get_server_defs` each time can be "
+           "*very* expensive\n"
+           "both in terms of memory, speed, and network bandwidth. The alternative is to call\n"
+           "this function, which will get the incremental changes, and apply them local client `suite definition`_\n"
+           "effectively synchronising the client and server Defs.\n"
+           "If the period of time between two sync() calls is too long, then the full server definition\n"
+           "is returned and assigned to the client Defs.\n"
+           "We can determine if the changes were applied by calling in_sync() after the call to sync_local()::\n\n"
+           "   void sync_local();                     # The very first call, will get the full Defs.\n"
+           "\n\n"
+           "Exceptions:\n\n"
+           "- raise a RuntimeError if the delta change cannot be applied.\n"
+           "- this could happen if the client Defs bears no resemblance to server Defs\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                       # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.sync_local()                     # Very first call gets the full Defs\n"
+           "       client_defs = ci.get_defs()         # End user access to the returned Defs\n"
+           "       ... after a period of time\n"
+           "       ci.sync_local()                     # Subsequent calls to sync_local() users the local Defs to sync "
+           "incrementally\n"
+           "       if ci.in_sync():                    # returns true server changed and changes applied to client\n"
+           "          print('Client is now in sync with server')\n"
+           "       client_defs = ci.get_defs()         # End user access to the returned Defs\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n"
+           "\n"
+           "Calling sync_local() is considerably faster than calling get_server_defs() for large Definitions";
+}
+
+const char* ClientDoc::in_sync() {
+    return "Returns true if the definition on the client is in sync with the `ecflow_server`_\n\n"
+           ".. Warning:: Calling in_sync() is **only** valid after a call to sync_local().\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "      ci = Client()                       # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "      ci.sync_local()                     # very first call gets the full Defs\n"
+           "      client_defs = ci.get_defs()         # End user access to the returned Defs\n"
+           "      ... after a period of time\n"
+           "      ci.sync_local()                     # Subsequent calls to sync_local() users the local Defs to sync "
+           "incrementally\n"
+           "      if ci.in_sync():                    # returns true  changed and changes applied to client\n"
+           "         print('Client is now in sync with server')\n"
+           "      client_defs = ci.get_defs()         # End user access to the returned Defs\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::news() {
+    return "Query the `ecflow_server`_ to detect any changes.\n\n"
+           "This returns a simple bool, if there has been changes, the user should call "
+           ":py:class:`ecflow.Client.sync_local`.\n"
+           "This will bring the client in sync with changes in the server. If sync_local() is not called\n"
+           "then calling news_local() will always return true.\n"
+           "news_local() uses the definition stored on the client::\n\n"
+           "   bool news_local()\n"
+           "\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                  # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       if ci.news_local():            # has the server changed\n"
+           "          print('Server Changed')     # server changed bring client in sync with server\n"
+           "          ci.sync_local()             # get the full definition from the server if first time\n"
+           "                                      # otherwise apply incremental changes to Client definition,\n"
+           "                                      # bringing it in sync with the server definition\n"
+           "          print(ci.get_defs())        # print the synchronised definition. Should be same as server\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::changed_node_paths() {
+    return "After a call to sync_local() we can access the list of nodes that changed\n\n"
+           "The returned list consists of node paths. *IF* the list is empty assume that\n"
+           "whole definition changed. This should be expected after the first call to sync_local()\n"
+           "since that always retrieves the full definition from the server::\n\n"
+           "   void changed_node_paths()\n"
+           "\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                          # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       if ci.news_local():                    # has the server changed\n"
+           "          print('Server Changed')             # server changed bring client in sync with server\n"
+           "          ci.sync_local()                     # get the full definition from the server if first time\n"
+           "                                              # otherwise apply incremental changes to Client definition,\n"
+           "                                              # bringing it in sync with the server definition\n"
+           "          defs = ci.get_defs()                # get the updated/synchronised definition\n"
+           "          for path in ci.changed_node_paths:\n"
+           "              if path == '/':                 # path '/' represent change to server node/defs\n"
+           "                 print('defs changed')        # defs state change or user variables changed\n"
+           "              else:\n"
+           "                 node = defs.find_abs_node(path)\n"
+           "\n"
+           "         # if changed_node_paths is empty, then assume entire definition changed\n"
+           "         print(defs)                         # print the synchronised definition. Should be same as "
+           "server\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::checkpt() {
+    return "Request the `ecflow_server`_ `check point`_\\ s the definition held in the server immediately\n\n"
+           "This effectively saves the definition held in the server to disk,\n"
+           "in a platform independent manner. This is the default when no arguments are specified.\n"
+           "The saved file will include node state, passwords, etc.\n"
+           "The default file name is <host>.<port>.ecf.check and is saved in ECF_HOME directory.\n"
+           "The `check point`_ file name can be overridden via ECF_CHECK server environment variable.\n"
+           "The back up `check point`_ file name can be overridden via ECF_CHECKOLD server environment variable::\n\n"
+           "   void checkpt(\n"
+           "     [(CheckPt::Mode)mode=CheckPt.UNDEFINED]\n"
+           "                         : Must be one of [ NEVER, ON_TIME, ALWAYS, UNDEFINED ]\n"
+           "                           NEVER  :  Never check point the definition in the server\n"
+           "                           ON_TIME:  Turn on automatic check pointing at interval stored on server\n"
+           "                                     or with interval specified as the second argument\n"
+           "                           ALWAYS:   Check point at any change in node tree, *NOT* recommended for large "
+           "definitions\n"
+           "                           UNDEFINED:The default, which allows for immediate check pointing, or alarm "
+           "setting\n"
+           "     [(int)interval=120] : This specifies the interval in seconds when server should automatically check "
+           "pt.\n"
+           "                           This will only take effect if mode is on_time/CHECK_ON_TIME\n"
+           "                           Should ideally be a value greater than 60 seconds, default is 120 seconds\n"
+           "     [(int)alarm=30]     : Specifies check pt save alarm time. If saving the check pt takes longer than\n"
+           "                           the alarm time, then the late flag is set on the server.\n"
+           "                           This flag will need to be cleared manually.\n"
+           "   )\n\n"
+           ".. Note:: When the time taken to save the check pt is excessive, it can interfere with job scheduling.\n"
+           "          It may be an indication of the following:\n\n"
+           "          * slow disk\n"
+           "          * file system full\n"
+           "          * The definition is very large and needs to split\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                      # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.checkpt()                       # Save the definition held in the server to disk\n"
+           "       ci.checkpt(CheckPt.NEVER)          # Switch off check pointing\n"
+           "       ci.checkpt(CheckPt.ON_TIME)        # Start automatic check pointing at the interval stored in the "
+           "server\n"
+           "       ci.checkpt(CheckPt.ON_TIME,180)    # Start automatic check pointing every 180 seconds\n"
+           "       ci.checkpt(CheckPt.ALWAYS)         # Check point at any state change in node tree. *not* "
+           "recommended for large defs\n"
+           "       ci.checkpt(CheckPt.UNDEFINED,0,35) # Change check point save time alarm to 35 seconds\n"
+           "                                          # With these arguments mode and interval remain unchanged\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::restore_from_checkpt() {
+    return "Request the `ecflow_server`_ loads the `check point`_ file from disk\n\n"
+           "The server will first try to open file at ECF_HOME/ECF_CHECK if that fails it will\n"
+           "then try path ECF_HOME/ECF_CHECKOLD.\n"
+           "An error is returned if the server has not been `halted`_ or contains a `suite definition`_\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()             # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.halt_server()          # server must be halted, otherwise restore_from_checkpt will throw\n"
+           "       ci.restore_from_checkpt() # restore the definition from the check point file\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::reload_wl_file() {
+    return "Request that the `ecflow_server`_ reload the white list file.\n\n"
+           "The white list file if present, can be used to control who has read/write\n"
+           "access to the `ecflow_server`_::\n\n"
+           "   void reload_wl_file()\n\n"
+           "Usage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()            # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.reload_wl_file()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::run() {
+    return "Immediately run the jobs associated with the input `node`_.\n\n"
+           "Ignore `trigger`_\\ s, `limit`_\\ s, `suspended`_, `time`_ or `date`_ dependencies,\n"
+           "just run the `task`_.\n"
+           "When a job completes, it may be automatically re-queued if it has\n"
+           "multiple time `dependencies`_. In the specific case where a `task`_ has a SINGLE\n"
+           "time dependency and we want to avoid re running the `task`_ then\n"
+           "a flag is set so that it is not automatically re-queued when set to `complete`_.\n"
+           "The flag is applied up the `node`_ hierarchy until we reach a node with a `repeat`_\n"
+           "or `cron`_ attribute. This behaviour allow `repeat`_ values to be incremented interactively.\n"
+           "A `repeat`_ attribute is incremented when all the child nodes are `complete`_\n"
+           "in this case the child nodes are automatically re-queued\n::\n\n"
+           "   void run(\n"
+           "      string absolute_node_path : Path name to node. If the path is suite/family will recursively\n"
+           "                                  run all child tasks\n"
+           "      [(bool)force=False]       : If true, run even if there are nodes that are active or submitted.\n"
+           "   )\n"
+           "   void run(\n"
+           "      list  paths               : List of paths. If the path is suite/family will recursively run all "
+           "child tasks\n"
+           "      [(bool)force=False]       : If true, run even if there are nodes that are active or submitted.\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                          # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.run('/s1')                          # run all tasks under suite /s1\n"
+           "\n"
+           "       ci.run(['/s1/f1/t1','/s2/f1/t2'])      # run all tasks specified\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n"
+           "\nEffect:\n\n"
+           "   Lets see the effect of run command on the following defs:\n\n"
+           ".. code-block:: shell\n\n"
+           "   suite s1\n"
+           "      task t1; time 10:00             # will complete straight away\n"
+           "      task t2; time 10:00 13:00 01:00 # will re-queue 3 times and complete on fourth run\n\n"
+           "In the last case (task t2) after each run the next time slot is incremented.\n"
+           "This can be seen by calling the Why command.";
+}
+
+const char* ClientDoc::requeue() {
+
+    return "Re queues the specified `node`_ (s)\n::\n\n"
+           "   void requeue(\n"
+           "      list paths     : A list of paths. Node paths must begin with a leading '/' character\n"
+           "      [(str)option=''] : option = ('' | 'abort' | 'force')\n"
+           "          ''   : empty string, the default, re-queue the node\n"
+           "          abort: means re-queue only aborted tasks below node\n"
+           "          force: means re-queueing even if there are nodes that are active or submitted\n"
+           "   )\n"
+           "   void requeue(\n"
+           "      string absolute_node_path : Path name to node\n"
+           "      [(string)option='']       : option = ('' | 'abort' | 'force')\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.requeue('/s1','abort')       # re-queue aborted tasks below suite /s1\n"
+           "\n"
+           "       path_list = ['/s1/f1/t1','/s2/f1/t2']\n"
+           "       ci.requeue(path_list)\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::free_trigger_dep() {
+    return "Free `trigger`_ `dependencies`_ for a `node`_\n::\n\n"
+           "   void free_trigger_dep(\n"
+           "      string absolute_node_path : Path name to node\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()         # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.free_trigger_dep('/s1/f1/task')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::free_date_dep() {
+    return "Free `date`_ `dependencies`_ for a `node`_\n::\n\n"
+           "   void free_date_dep(\n"
+           "      string absolute_node_path : Path name to node\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.free_date_dep('/s1/task')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::free_time_dep() {
+    return "Free all time `dependencies`_. i.e `time`_, `day`_, `today`_, `cron`_\n::\n\n"
+           "   void free_time_dep(\n"
+           "      string absolute_node_path : Path name to node\n"
+           "   )\n\n"
+           "After freeing the time related dependencies (i.e time,today,cron)\n"
+           "the next time slot will be missed.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.free_time_dep('/s1/task')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::free_all_dep() {
+    return "Free all `trigger`_, `date`_ and all time(`day`_, `today`_, `cron`_,etc) `dependencies`_\n::\n\n"
+           "   void free_all_dep(\n"
+           "      string absolute_node_path : Path name to node\n"
+           "   )\n\n"
+           "After freeing the time related dependencies (i.e time,today,cron)\n"
+           "the next time slot will be missed.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.free_all_dep('/s1/task')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::ping() {
+    return "Checks if the `ecflow_server`_ is running\n::\n\n"
+           "   void ping()\n\n"
+           "The default behaviour is to check on host 'localhost' and port 3141\n"
+           "It should be noted that any Client function will fail if the server is\n"
+           "is not running. Hence ping() is not strictly required. However its main\n"
+           "distinction from other Client function is that it is quite fast.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client('localhost','3150')\n"
+           "       ci.ping()\n"
+           "       print('------- Server already running------')\n"
+           "       do_something_with_server(ci)\n"
+           "   except RuntimeError, e:\n"
+           "       print('------- Server *NOT* running------' + str(e))\n";
+}
+
+const char* ClientDoc::stats() {
+    return "Returns the `ecflow_server`_ statistics as a string\n\n"
+           ".. warning::\n\n"
+           "    When called without arguments, this function will print the statistics to :code:`stdout`,"
+           " before returning the information as a string.\n"
+           "    To avoid printing the output, set the boolean flag :code:`to_stdout` to :code:`False`.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()  # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       stats = ci.stats()      # prints to stdout\n"
+           "       stats = ci.stats(True)  # prints to stdout\n"
+           "       stats = ci.stats(False) # does not print to stdout\n"
+           "       print(stats)\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::stats_reset() {
+    return "Resets the statistical data in the server\n::\n\n"
+           "   void stats_reset()\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()  # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.stats_reset()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::suites() {
+    return "Returns a list strings representing the `suite`_ names\n::\n\n"
+           "   list(string) suites()\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()  # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       suites = ci.suites()\n"
+           "       print(suites)\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::ch_register() {
+    return "Register interest in a set of `suite`_\\ s.\n\n"
+           "If a definition has lots of suites, but the client is only interested in a small subset.\n"
+           "Then using this command can reduce network bandwidth and synchronisation will be quicker.\n"
+           "This command will create a client handle. This handle is held locally on the :py:class:`ecflow.Client`, "
+           "and\n"
+           "can be used implicitly by ch_drop(),ch_add(),ch_remove() and ch_auto_add().\n"
+           "Registering a client handle affects the news() and sync() commands::\n\n"
+           "   void ch_register(\n"
+           "      bool auto_add_new_suites : true means add new suites to my list, when they are created\n"
+           "      list suite_names         : should be a list of suite names, names not in the definition are ignored\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()\n"
+           "       suite_names = [ 's1', 's2', 's3' ]\n"
+           "       ci.ch_register(True,suite_names)    # register interest in suites s1,s2,s3 and any new suites\n"
+           "       ci.ch_register(False,suite_names)   # register interest in suites s1,s2,s3 only\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n\n"
+           "The client 'ci' will hold locally the client handle. Since we have made multiple calls to register\n"
+           "a handle, the variable 'ci' will hold the handle for the last call only.\n"
+           "The handle associated with the suite can be manually retrieved:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()\n"
+           "       ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
+           "       client_handle = ci.ch_handle()        # get the handle associated with last call to ch_register\n"
+           "       ....                                  # after a period of time\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n"
+           "   finally:\n"
+           "       ci.ch_drop( client_handle )           # de-register the handle\n\n"
+           "To automatically drop the handle(preferred) use with:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       with Client() as ci:\n"
+           "          ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
+           "          client_handle = ci.ch_handle()        # get the handle associated with last call to ch_register\n"
+           "       ....                                     # will automatically drop last handle\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::ch_suites() {
+    return "Writes to standard out the list of registered handles and the suites they reference.\n\n"
+           "When dealing with large definitions, where a user is only interested in a small subset\n"
+           "of suites, registering them, improves download performance from the server.\n"
+           "Registered suites have an associated handle.\n";
+}
+
+const char* ClientDoc::ch_drop() {
+    return "Drop/de-register the client handle.\n\n"
+           "When dealing with large definitions, where a user is only interested in a small subset\n"
+           "of suites, registering them, improves download performance from the server.\n"
+           "Registered suites have an associated handle.\n"
+           "Client must ensure un-used handle are dropped otherwise they will stay, in the `ecflow_server`_\n::\n\n"
+           "   void ch_drop(\n"
+           "      int client_handle : The handle must be an integer that is > 0\n"
+           "   )\n"
+           "   void ch_drop()       : Uses the local handle stored on the client, from last call to ch_register()\n\n"
+           "Exception:\n\n"
+           "- RunTimeError thrown if handle has not been previously registered\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "	try:\n"
+           "      ci = Client()                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "      ci.ch_register(False,['s1','s2'])\n"
+           "      while( 1 ):\n"
+           "         # get incremental changes to suites s1 & s2, uses data stored on ci/defs\n"
+           "         ci.sync_local()                # will only retrieve data for suites s1 & s2\n"
+           "         update(ci.get_defs())\n"
+           "	finally:\n"
+           "      ci.ch_drop()\n\n"
+           "To automatically drop the handle(Preferred) use with\n:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       with Client() as ci:\n"
+           "          ci.ch_register(False,['s1','s2'])\n"
+           "          while( 1 ):\n"
+           "              # get incremental changes to suites s1 & s2, uses data stored on ci/defs\n"
+           "              ci.sync_local()                # will only retrieve data for suites s1 & s2\n"
+           "              update(ci.get_defs())\n"
+           "       ....                                  # will automatically drop last handle\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::ch_drop_user() {
+    return "Drop/de-register all handles associated with user.\n\n"
+           "When dealing with large definitions, where a user is only interested in a small subset\n"
+           "of suites, registering them, improves download performance from the server.\n"
+           "Registered suites have an associated handle.\n"
+           "Client must ensure un-used handle are dropped otherwise they will stay, in the `ecflow_server`_\n::\n\n"
+           "   void ch_drop_user(\n"
+           "        string user   # If empty string will drop current user\n"
+           "   )\n\n"
+           "Exception:\n\n"
+           "- RunTimeError thrown if handle has not been previously registered\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  try:\n"
+           "      ci = Client()                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "      ci.ch_register(False,['s1','s2'])\n"
+           "      while( 1 ):\n"
+           "         # get incremental changes to suites s1 & s2, uses data stored on ci/defs\n"
+           "         update(ci.get_defs())\n"
+           "  finally:\n"
+           "      ci.ch_drop_user('') # drop all handles associated with current user\n\n";
+}
+
+const char* ClientDoc::ch_add() {
+    return "Add a set of suites, to an existing registered handle\n\n"
+           "When dealing with large definitions, where a user is only interested in a small subset\n"
+           "of suites, registering them, improves download performance from the server.\n"
+           "Registered suites have an associated handle.\n"
+           "::\n\n"
+           "  integer ch_add(\n"
+           "     integer handle   : the handle obtained after ch_register\n"
+           "     list suite_names : list of strings representing suite names\n"
+           "  )\n"
+           "  integer ch_add(\n"
+           "     list suite_names : list of strings representing suite names\n"
+           "  )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       with Client() as ci:       # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "          ci.ch_register(True,[]) # register interest in any new suites\n"
+           "          ci.ch_add(['s1','s2'])  # add suites s1,s2 to the last added handle\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n\n";
+}
+
+const char* ClientDoc::ch_remove() {
+    return "Remove a set of suites, from an existing handle\n\n"
+           "When dealing with large definitions, where a user is only interested in a small subset\n"
+           "of suites, registering them, improves download performance from the server.\n"
+           "Registered suites have an associated handle.\n"
+           "::\n\n"
+           "  integer ch_remove(\n"
+           "     integer handle   : the handle obtained after ch_register\n"
+           "     list suite_names : list of strings representing suite names\n"
+           "  )\n"
+           "  integer ch_remove(\n"
+           "     list suite_names : list of strings representing suite names\n"
+           "  )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       with Client() as ci:                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "          ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
+           "          ci.ch_remove( ['s1'] )                # remove suites s1 from the last added handle\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n\n";
+}
+
+const char* ClientDoc::ch_auto_add() {
+    return "Change an existing handle so that new suites can be added automatically\n\n"
+           "When dealing with large definitions, where a user is only interested in a small subset\n"
+           "of suites, registering them, improves download performance from the server.\n"
+           "Registered suites have an associated handle.\n"
+           "::\n\n"
+           "   void ch_auto_add(\n"
+           "      integer handle,         : the handle obtained after ch_register\n"
+           "      bool auto_add_new_suite : automatically add new suites, this handle when they are created\n"
+           "   )\n"
+           "   void ch_auto_add(\n"
+           "      bool auto_add_new_suite : automatically add new suites using handle on the client\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       with Client() as ci:                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "          ci.ch_register(True,['s1','s2','s3']) # register interest in suites s1,s2,s3 and any new suites\n"
+           "          ci.ch_auto_add( False )               # disable adding newly created suites to my handle\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n\n";
+}
+
+const char* ClientDoc::get_file() {
+    return "The File command is used to request the various file types associated with a `node`_.\n\n"
+           "By default, the output is composed of the last 10000 lines of the file. The number of lines can be "
+           "customised via the :code:`max_lines` parameter.\n\n"
+           "The content can be retrieved as a sequence of 'bytes'. This allows to download a file that contains "
+           "invalid Unicode sequence, without causing an :code:`UnicodeDecodeError` to be raised.\n"
+           "::\n\n"
+           "   string get_file(\n"
+           "      string absolute_node_path    : Path name to node\n"
+           "      [(string)file_type='script'] : file_type = [ script<default> | job | jobout | manual | kill | stat "
+           "]\n"
+           "      [(string)max_lines='10000'] : The number of lines in the file to return\n"
+           "      [(bool)as_bytes=False] : A flag indicating if the output should be 'bytes'; by default the output is "
+           "of type 'str'\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()        # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       for file in [ 'script', 'job', 'jobout', 'manual', 'kill', 'stat' ]:\n"
+           "           print(ci.get_file('/suite/f1/t1',file))  # print the contents of the file\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::plug() {
+    return "Plug command is used to move `node`_\\ s\n\n"
+           "The destination node can be on another `ecflow_server`_.\n"
+           "In which case the destination path should be of the form '//<host>:<port>/suite/family/task\n::\n\n"
+           "   void plug(\n"
+           "      string source_absolute_node_path       : Path name to source node\n"
+           "      string destination_absolute_node_path  : Path name to destination node. Note if only\n"
+           "                                               '//host:port' is specified the whole suite can be moved\n"
+           "   )\n\n"
+           "By default throws a RuntimeError exception for errors.\n\n"
+           "Exceptions can be raised because:\n\n"
+           "- Source `node`_ is in a `active`_ or `submitted`_ state.\n"
+           "- Another user already has an lock.\n"
+           "- source/destination paths do not exist on the corresponding servers\n"
+           "- If the destination node path is empty, i.e. only host:port is specified,\n"
+           "  then the source `node`_ must correspond to a `suite`_.\n"
+           "- If the source node is added as a child, then its name must be unique\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.plug('/suite','host3:3141')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::query() {
+    return "Query the status of event, meter, state, variable, limit, limit_max or trigger expression without "
+           "blocking\n\n"
+           " - state     return [unknown | complete | queued |             aborted | submitted | active] to standard "
+           "out\n"
+           " - dstate    return [unknown | complete | queued | suspended | aborted | submitted | active] to standard "
+           "out\n"
+           " - event     return 'set' | 'clear' to standard out\n"
+           " - meter     return value of the meter to standard out\n"
+           " - limit     return value of the limit to standard out\n"
+           " - limit_max return max value of the limit to standard out\n"
+           " - variable  return value to standard out\n"
+           " - trigger   returns 'true' if the expression is true, otherwise 'false'\n\n:\n\n"
+           ".. code-block:: shell\n\n"
+           "  string query(\n"
+           "     string query_type        # [ event | meter | variable | trigger | limit | limit_max ]\n"
+           "     string path_to_attribute # path to the attribute\n"
+           "     string attribute         # name of the attribute or trigger expression\n"
+           "  )\n\n"
+           "By default throws a exception for errors.\n\n"
+           "Exceptions can be raised if the path to the attribute does not exist and because:\n\n"
+           "- No event of the given name exists on the specified node\n"
+           "- No meter of the given name exists on the specified node\n"
+           "- No limit of the given name exists on the specified node\n"
+           "- No variable of the given name (repeat or generated variable) exists on the\n"
+           "  specified node or any of its parent\n"
+           "- trigger expression does not parse, or if references to node/attributes are not defined\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       res = ci.query('event','/path/to/node','event_name') # returns 'SET' | 'CLEAR'\n"
+           "       res = ci.query('meter','/path/to/node','meter_name') # returns meter value as a string\n"
+           "       res = ci.query('limit','/path/to/node','limit_name') # returns limit value as a string\n"
+           "       res = ci.query('limit_max','/path/to/node','limit_name') # returns max limit value as a string\n"
+           "       res = ci.query('variable','/path/to/node,'var')      # returns variable value as a string\n"
+           "       res = ci.query('trigger','/path/to/node','/joe90 == complete') # return 'true' | 'false' as a "
+           "string\n"
+           "       res = ci.query('state','/path/to/node') # return node state as a string\n"
+           "       res = ci.query('dstate','/path/to/node') # return node state as a string,can include suspended\n"
+           "   except RuntimeError, e:\n"
+           "       print str(e)\n";
+}
+
+const char* ClientDoc::alter() {
+    return "Alter command is used to change the attributes of a node\n::\n\n"
+           "   void alter(\n"
+           "      (list | string ) paths(s) : A single or list of paths. Path name to the node whose attributes are to "
+           "be changed\n"
+           "      string alter_type         : This must be one of [ 'add' | 'change' | 'delete' | 'set_flag' | "
+           "'clear_flag' ]\n"
+           "      string attr_type          : This varies according to the 'alter_type'. valid strings are:\n"
+           "         add    : [ variable,time,today,date,day,label,zombie,late]\n"
+           "         delete : [ "
+           "variable,time,today,date,day,label,cron,event,meter,trigger,complete,repeat,limit,inlimit,limit_path,"
+           "zombie,late]\n"
+           "         change : [ "
+           "variable,clock-type,clock-gain,event,meter,label,trigger,complete,repeat,limit-max,limit-value,late,time,"
+           "today]\n"
+           "         set_flag and clear_flag:\n"
+           "                  [ force_aborted | user_edit | task_aborted | edit_failed | ecfcmd_failed | "
+           "statuscmd_failed | killcmd_failed |\n"
+           "                    no_script | killed | status | late | message | complete | queue_limit | task_waiting | "
+           "locked | zombie ]\n"
+           "      string name               : used to locate the attribute, when multiple attributes of the same "
+           "type,\n"
+           "                                  optional for some.i.e. when changing, attributes like "
+           "variable,meter,event,label,limits\n"
+           "      string value              : Only used when 'changing' a attribute. provides a new value\n"
+           "   )\n\n"
+           "Exceptions can be raised because:\n\n"
+           "- absolute_node_path does not exist.\n"
+           "- parsing fails\n"
+           "\n"
+           "The following describes the parameters in more detail:\n\n"
+           ".. code-block:: shell\n\n"
+           " add variable variable_name variable_value\n"
+           " add time   format    # when format is +hh:mm | hh:mm | hh:mm(start) hh:mm(finish) hh:mm(increment)\n"
+           " add today  format    # when format is +hh:mm | hh:mm | hh:mm(start) hh:mm(finish) hh:mm(increment)\n"
+           " add date   format    # when format dd.mm.yyyy, can use '*' to indicate any day,month, or year\n"
+           " add day    format    # when format is one of [ sunday,monday,tuesday,wednesday,friday,saturday ]\n"
+           " add zombie format    # when format is one of "
+           "<zombie-type>:<child>:<server-action>|<client-action>:<zombie-lifetime>\n"
+           "                      #  <zombie-type> := [ user | ecf | path ]\n"
+           "                      #  <child> := [ init, event, meter, label, wait, abort, complete ]\n"
+           "                      #  <server-action> := [ adopt | delete ]\n"
+           "                      #  <client-action> := [ fob | fail | block(default) ]\n"
+           "                      #  <zombie-lifetime>:= lifetime of zombie in the server\n"
+           "                      # example\n"
+           "                      # add zombie :label:fob:0   # fob all child label request, & remove zombie as soon "
+           "as possible\n"
+           "\n"
+           " delete variable name # if name is empty will delete -all- variables on the node\n"
+           " delete time name     # To delete a specific time, enter the time in same format as show above,\n"
+           "                      # or as specified in the defs file\n"
+           "                      # an empty name will delete all time attributes on the node\n"
+           " delete today name    # To delete a specific today attribute, enter in same format as show above,\n"
+           "                      # or as specified in the defs file.\n"
+           "                      # an empty name will delete all today attributes on the node\n"
+           " delete date name     # To delete a specific date attribute, enter in same format as show above,\n"
+           "                      # or as specified in the defs file\n"
+           "                      # an empty name will delete all date attributes on the node\n"
+           " delete day name      # To delete a specific day attribute, enter in same format as show above,\n"
+           "                      # or as specified in the defs file\n"
+           "                      # an empty name will delete all day attributes on the node\n"
+           " delete cron name     # To delete a specific cron attribute, enter in same as specified in the defs file\n"
+           "                      # an empty name will delete all cron attributes on the node\n"
+           " delete event name    # To delete a specific event, enter name or number\n"
+           "                      # an empty name will delete all events on the node\n"
+           " delete meter name    # To delete a specific meter , enter the meter name\n"
+           "                      # an empty name will delete all meter on the node \n"
+           " delete label name    # To delete a specific label , enter the label name\n"
+           "                      # an empty name will delete all labels on the node\n"
+           " delete limit name    # To delete a specific limit , enter the limit name\n"
+           "                      # an empty name will delete all limits on the node\n"
+           " delete inlimit name  # To delete a specific inlimit , enter the inlimit name\n"
+           "                      # an empty name will delete all inlimits on the node\n"
+           " delete limit_path limit_name limit_path # To delete a specific limit path\n"
+           " delete trigger       # A node can only have one trigger expression, hence the name is not required\n"
+           " delete complete      # A node can only have one complete expression, hence the name is not required\n"
+           " delete repeat        # A node can only have one repeat, hence the name is not required\n"
+           "\n"
+           " change variable name value    # Find the specified variable, and set the new value.\n"
+           " change clock_type name        # The name must be one of 'hybrid' or 'real'.\n"
+           " change clock_gain name        # The gain must be convertible to an integer.\n"
+           " change clock_sync name        # Sync suite calendar with the computer.\n"
+           " change event name(optional )  # if no name specified the event is set, otherwise name must be 'set' or "
+           "'clear'\n"
+           " change meter name value       # The meter value must be convertible to an integer, and between meter "
+           "min-max range.\n"
+           " change label name value       # sets the label\n"
+           " change trigger name           # The name must be expression. returns an error if the expression does not "
+           "parse\n"
+           " change complete name          # The name must be expression. returns an error if the expression does not "
+           "parse\n"
+           " change limit_max name value   # Sets the max value of the limit. The value must be convertible to an "
+           "integer\n"
+           " change limit_value name value # Sets the consumed tokens to value.The value must be convertible to an "
+           "integer\n"
+           " change repeat value           # If the repeat is a date, then the value must be a valid YMD ( ie. "
+           "yyyymmdd)\n"
+           "                               # and be convertible to an integer, additionally the value must be in "
+           "range\n"
+           "                               # of the repeat start and end dates. Like wise for repeat integer. For "
+           "repeat\n"
+           "                               # string and enum,  the name must either be an integer, that is a valid "
+           "index or\n"
+           "                               # if it is a string, it must correspond to one of enum's or strings list\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  try:\n"
+           "     ci = Client()     # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "     ci.alter('/suite/task','change','trigger','b2 == complete')\n"
+           "  except RuntimeError, e:\n"
+           "     print(str(e))\n";
+}
+
+const char* ClientDoc::force_state() {
+
+    return "Force a node(s) to a given state\n\n"
+           "When a `task`_ is set to `complete`_, it may be automatically re-queued if it has\n"
+           "multiple time `dependencies`_. In the specific case where a task has a single\n"
+           "time dependency and we want to interactively set it to `complete`_\n"
+           "a flag is set so that it is not automatically re-queued when set to complete.\n"
+           "The flag is applied up the node hierarchy until reach a node with a `repeat`_\n"
+           "or `cron`_ attribute. This behaviour allow `repeat`_ values to be incremented interactively.\n"
+           "A `repeat`_ attribute is incremented when all the child nodes are `complete`_\n"
+           "in this case the child nodes are automatically re-queued\n::\n\n"
+           "   void force_state(\n"
+           "      string absolute_node_path: Path name to node. The path must begin with a leading '/'\n"
+           "      State::State state       : [ unknown | complete | queued | submitted | active | aborted ]\n"
+           "   )\n"
+           "   void force_state(\n"
+           "      list paths         : A list of absolute node paths. The paths must begin with a leading '/'\n"
+           "      State::State state : [ unknown | complete | queued | submitted | active | aborted ]\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       # force a single node to complete\n"
+           "       ci.force_state('/s1/f1',State.complete)\n"
+           "\n"
+           "       # force a list of nodes to complete\n"
+           "       paths = [ '/s1/t1', '/s1/t2', '/s1/f1/t1' ]\n"
+           "       ci.force_state(paths,State.complete)\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n"
+           "\nEffect:\n\n"
+           "Lets see the effect of forcing complete on the following defs\n\n"
+           ".. code-block:: shell\n\n"
+           "   suite s1\n"
+           "      task t1; time 10:00             # will complete straight away\n"
+           "      task t2; time 10:00 13:00 01:00 # will re-queue 3 times and complete on fourth \n\n"
+           "In the last case (task t2) after each force complete, the next time slot is incremented.\n"
+           "This can be seen by calling the Why command.";
+}
+
+const char* ClientDoc::force_state_recursive() {
+
+    return "Force node(s) to a given state recursively\n::\n\n"
+           "   void force_state_recursive(\n"
+           "      string absolute_node_path: Path name to node.The paths must begin with a leading '/'\n"
+           "      State::State state       : [ unknown | complete | queued | submitted | active | aborted ]\n"
+           "   )\n"
+           "   void force_state_recursive(\n"
+           "      list  paths         : A list of absolute node paths.The paths must begin with a leading '/'\n"
+           "      State::State state  : [ unknown | complete | queued | submitted | active | aborted ]\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  try:\n"
+           "      ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "      ci.force_state_recursive('/s1/f1',State.complete)\n"
+           "\n"
+           "      # recursively force a list of nodes to complete\n"
+           "      paths = [ '/s1', '/s2', '/s1/f1/t1' ]\n"
+           "      ci.force_state_recursive(paths,State.complete)\n"
+           "  except RuntimeError, e:\n"
+           "      print(str(e))\n";
+}
+
+const char* ClientDoc::force_event() {
+
+    return "Set or clear a `event`_\n::\n\n"
+           "   void force_event(\n"
+           "      string absolute_node_path:event: Path name to node: < event name | number>\n"
+           "                                       The paths must begin with a leading '/'\n"
+           "      string signal                  : [ set | clear ]\n"
+           "   )\n"
+           "   void force_event(\n"
+           "      list paths    : A list of absolute node paths. Each path must include a event name\n"
+           "                      The paths must begin with a leading '/'\n"
+           "      string signal : [ set | clear ]\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.force_event('/s1/f1:event_name','set')\n"
+           "\n"
+           "       # Set or clear a event for a list of events\n"
+           "       paths = [ '/s1/t1:ev1', '/s2/t2:ev2' ]\n"
+           "       ci.force_event(paths,'clear')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::replace() {
+    return "Replaces a `node`_ in a `suite definition`_ with the given path. The definition is in the "
+           "`ecflow_server`_\n::\n\n"
+           "   void replace(\n"
+           "      string absolute_node_path: Path name to node in the client defs.\n"
+           "                                 This is also the node we want to replace in the server.\n"
+           "      string client_defs_file  : File path to defs files, that provides the definition of the new node\n"
+           "      [(bool)parent=False]     : create parent families or suite as needed,\n"
+           "                                 when absolute_node_path does not exist in the server\n"
+           "      [(bool)force=False]      : check for zombies, if force = true, bypass checks\n"
+           "   )\n"
+           "\n"
+           "   void replace(\n"
+           "      string absolute_node_path: Path name to node in the client defs.\n"
+           "                                 This is also the node we want to replace in the server.\n"
+           "      Defs client_defs         : In memory client definition that provides the definition of the new node\n"
+           "      [(bool)parent=False]     : create parent families or suite as needed,\n"
+           "                                 when absolute_node_path does not exist in the server\n"
+           "      [(bool)force=False]      : check for zombies, force = true, bypass checks\n"
+           "   )\n"
+           "\n"
+           "Exceptions can be raised because:\n\n"
+           "- The absolute_node_path does not exist in the provided definition\n"
+           "- The provided client definition must be free of errors\n"
+           "- If the third argument is not provided, then the absolute_node_path must exist in the server defs\n"
+           "- replace will fail, if child task nodes are in `active`_ / `submitted`_ state\n\n"
+           "After replace is done, we check trigger expressions. These are reported to standard output.\n"
+           "It is up to the user to correct invalid trigger expressions, otherwise the tasks will *not* run.\n"
+           "Please note, you can use check() to check trigger expression and limits in the server.\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.replace('/s1/f1','/tmp/defs.def')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n"
+           "\n"
+           "   try:\n"
+           "       ci.replace('/s1',client_defs) # replace suite 's1' in the server, with 's1' in the client_defs\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::kill() {
+    return "Kills the job associated with the `node`_\n::\n\n"
+           "   void kill(\n"
+           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
+           "   )\n"
+           "   void kill(\n"
+           "      string absolute_node_path: Path name to node to kill.\n"
+           "   )\n"
+           "\n"
+           "If a `family`_ or `suite`_ is selected, will kill hierarchically.\n"
+           "Kill uses the ECF_KILL_CMD variable. After `variable substitution`_ it is invoked as a command.\n"
+           "The ECF_KILL_CMD variable should be written in such a way that the output is written to %ECF_JOB%.kill, "
+           "i.e:\n\n"
+           ".. code-block:: shell\n\n"
+           "   kill -15 %ECF_RID% > %ECF_JOB%.kill 2>&1\n"
+           "   /home/ma/emos/bin/ecfkill %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1\n\n"
+           "\n"
+           "Exceptions can be raised because:\n\n"
+           "- The absolute_node_path does not exist in the server\n"
+           "- ECF_KILL_CMD variable is not defined\n"
+           "- `variable substitution`_ fails\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.kill('/s1/f1')\n"
+           "       time.sleep(2)\n"
+           "       print(ci.file('/s1/t1','kill')) # request kill output\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::status() {
+    return "Shows the status of a job associated with a `task`_\n::\n\n"
+           "   void status(\n"
+           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
+           "   )\n"
+           "   void status(\n"
+           "      string absolute_node_path\n"
+           "   )\n\n"
+           "If a `family`_ or `suite`_ is selected, will invoke status command hierarchically.\n"
+           "Status uses the ECF_STATUS_CMD variable. After `variable substitution`_ it is invoked as a command.\n"
+           "The command should be written in such a way that the output is written to %ECF_JOB%.stat, i.e:\n\n"
+           ".. code-block:: shell\n\n"
+           "   /home/ma/emos/bin/ecfstatus  %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.stat 2>&1\n\n"
+           "Exceptions can be raised because:\n\n"
+           "- The absolute_node_path does not exist in the server\n"
+           "- ECF_STATUS_CMD variable is not defined\n"
+           "- `variable substitution`_ fails\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.status('/s1/t1')\n"
+           "       time.sleep(2)\n"
+           "       print(ci.file('/s1/t1','stats')) # request status output\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::order() {
+    return "Re-orders the `node`_\\ s in the `suite definition`_ held by the `ecflow_server`_\n\n"
+           "It should be noted that in the absence of `dependencies`_,\n"
+           "the order in which `task`_\\ s are `submitted`_, depends on the order in the definition.\n"
+           "This changes the order and hence affects the submission order\n::\n\n"
+           "   void order(\n"
+           "      string absolute_node_path: Path name to node.\n"
+           "      string order_type        : Must be one of [ top | bottom | alpha | order | up | down ]\n"
+           "   )\n"
+           "   o top     raises the node within its parent, so that it is first\n"
+           "   o bottom  lowers the node within its parent, so that it is last\n"
+           "   o alpha   Arranges for all the peers of selected note to be sorted alphabetically\n"
+           "   o order   Arranges for all the peers of selected note to be sorted in reverse alphabet\n"
+           "   o up      Moves the selected node up one place amongst its peers\n"
+           "   o down    Moves the selected node down one place amongst its peers\n\n"
+           "Exceptions can be raised because:\n\n"
+           "- The absolute_node_path does not exist in the server\n"
+           "- The order_type is not the right type\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.order('/s1/f1','top')\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::group() {
+    return "Allows a series of commands to be executed in the `ecflow_server`_\n::\n\n"
+           "   void group(\n"
+           "       string cmds : a list of ';' separated commands \n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()               # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.group('get; show')\n"
+           "       ci.group('get; show state') # show node states and trigger abstract syntax trees\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::begin_suite() {
+    return "Begin playing the chosen `suite`_\\ s in the `ecflow_server`_\n\n"
+           ".. Note:: using the force option may cause `zombie`_\\ s if suite has running jobs\n\n"
+           "::\n\n"
+           "   void begin_suite\n"
+           "      string suite_name     : begin playing the given suite\n"
+           "      [(bool)force=False]   : bypass the checks for submitted and active jobs\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                  # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.begin_suite('/suite1')      # begin playing suite '/suite1'\n"
+           "       ci.begin_suite('/suite1',True) # begin playing suite '/suite1' bypass any checks"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::begin_all() {
+    return "Begin playing all the `suite`_\\ s in the `ecflow_server`_\n\n"
+           ".. Note:: using the force option may cause `zombie`_\\ s if suite has running jobs\n\n"
+           "::\n\n"
+           "   void begin_all_suites(\n"
+           "      [(bool)force=False] : bypass the checks for submitted and active jobs\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()             # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.begin_all_suites()     # begin playing all the suites\n"
+           "       ci.begin_all_suites(True) # begin playing all the suites, by passing checks\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::suspend() {
+    return "Suspend `job creation` / generation for the given `node`_\n::\n\n"
+           "   void suspend(\n"
+           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
+           "   )\n"
+           "   void suspend(\n"
+           "      string absolute_node_path: Path name to node to suspend.\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.suspend('/s1/f1/task1')\n"
+           "       paths = ['/s1/f1/t1','/s2/f1/t2']\n"
+           "       ci.suspend(paths)\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::resume() {
+    return "Resume `job creation` / generation for the given `node`_\n::\n\n"
+           "   void resume(\n"
+           "      list paths: List of paths. Paths must begin with a leading '/' character\n"
+           "   )\n"
+           "   void resume(\n"
+           "      string absolute_node_path: Path name to node to resume.\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.resume('/s1/f1/task1')\n"
+           "       paths = ['/s1/f1/t1','/s2/f1/t2']\n"
+           "       ci.resume(paths)\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::job_gen() {
+    return "Job submission for chosen Node *based* on `dependencies`_\n\n"
+           "The `ecflow_server`_ traverses the `node`_ tree every 60 seconds, and if the dependencies are free\n"
+           "does `job creation` and submission. Sometimes the user may free time/date dependencies\n"
+           "to avoid waiting for the server poll, this commands allows early job generation\n::\n\n"
+           "   void job_generation(\n"
+           "      string absolute_node_path: Path name for job generation to start from\n"
+           "   )\n"
+           "   If empty string specified generates for full definition.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.job_generation('/s1')  # generate jobs for suite '/s1 \n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::delete_node() {
+    return "Delete the `node`_ (s) specified.\n\n"
+           "If a node is `submitted`_ or `active`_, then a Exception will be raised.\n"
+           "To force the deletion at the expense of `zombie`_ creation, then set\n"
+           "the force parameter to true\n::\n\n"
+           "   void delete(\n"
+           "      list paths          : List of paths.\n"
+           "      [(bool)force=False] : If true delete even if in 'active' or 'submitted' states\n"
+           "                            Which risks creating zombies.\n"
+           "   )\n"
+           "   void delete(\n"
+           "      string absolute_node_path: Path name of node to delete.\n"
+           "      [(bool)force=False]       : If true delete even if in 'active' or 'submitted' states\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()                     # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.delete('/s1/f1/task1')\n"
+           "\n"
+           "       paths = ['/s1/f1/t1','/s2/f1/t2']\n"
+           "       ci.delete(paths)                  # delete all tasks specified in the paths\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::delete_all() {
+    return "Delete all the `node`_\\ s held in the `ecflow_server`_.\n\n"
+           "The `suite definition`_ in the server will be empty, after this call. **Use with care**\n"
+           "If a node is `submitted`_ or `active`_, then a Exception will be raised.\n"
+           "To force the deletion at the expense of `zombie`_ creation, then set\n"
+           "the force parameter to true\n::\n\n"
+           "   void delete_all(\n"
+           "      [(bool)force=False] : If true delete even if in 'active' or 'submitted' states\n"
+           "                            Which risks creating zombies.\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()    # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.delete_all()\n"
+           "       ci.get_server_defs()\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e));    # expect failure since all nodes deleted";
+}
+
+const char* ClientDoc::check() {
+    return "Check `trigger`_ and `complete expression`_\\ s and `limit`_\\ s\n\n"
+           "The `ecflow_server`_ does not store `extern`_\\ s. Hence all unresolved references\n"
+           "are reported as errors.\n"
+           "Returns a non empty string for any errors or warning\n::\n\n"
+           "   string check(\n"
+           "      list paths # List of paths.\n"
+           "   )\n"
+           "   string check(\n"
+           "      string absolute_node_path\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       print(ci.check('/suite1'))\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* ClientDoc::archive() {
+    return "Archives suite or family nodes. Saves the suite/family nodes to disk, and then removes then from the "
+           "definition\n"
+           "This saves memory in the server, when dealing with huge definitions that are not needed.\n"
+           "If the node is re-queued or begun, it is automatically restored\n"
+           "Use --restore to reload the archived nodes manually\n"
+           "The nodes are saved to ECF_HOME/ECF_NAME.check\n"
+           "Usage::\n\n"
+           "   string archive(\n"
+           "      list paths # List of paths.\n"
+           "   )\n"
+           "   string archive(\n"
+           "      string absolute_node_path\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       print ci.archive('/suite1')\n"
+           "   except RuntimeError, e:\n"
+           "       print str(e)\n";
+}
+const char* ClientDoc::restore() {
+    return "Restore archived nodes.\n"
+           "Usage::\n\n"
+           "   string restore(\n"
+           "      list paths # List of paths.\n"
+           "   )\n"
+           "   string restore(\n"
+           "      string absolute_node_path\n"
+           "   )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()   # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       print ci.restore('/suite1')\n"
+           "   except RuntimeError, e:\n"
+           "       print str(e)\n";
+}
+
+const char* ClientDoc::set_child_path() {
+    return "Set the path to the task, obtained from server using %ECF_NAME%\n\n"
+           "By default the environment variable ECF_NAME is read for the task path\n"
+           "This can be overridden for the python child api";
+}
+const char* ClientDoc::set_child_password() {
+    return "Set the password, needed for authentication, provided by the server using %ECF_PASS%\n\n"
+           "By default the environment variable ECF_PASS is read for the jobs password\n"
+           "This can be overridden for the python child api";
+}
+
+const char* ClientDoc::set_child_pid() {
+    return "Set the process id of this job\n\n"
+           "By default the environment variable ECF_RID is read for the jobs process or remote id\n"
+           "This can be overridden for the python child api";
+}
+
+const char* ClientDoc::set_child_try_no() {
+    return "Set the try no, i.e the number of times this job has run, obtained from the server, using %ECF_TRYNO%\n\n"
+           "By default the environment variable ECF_TRYNO is read to record number of times job has been run\n"
+           "This can be overridden for the python child api";
+}
+
+const char* ClientDoc::set_child_timeout() {
+    return "Set timeout if child cannot connect to server, default is 24 hours. The input is required to be in "
+           "seconds\n\n"
+           "By default the environment variable  ECF_TIMEOUT is read to control how long child command should attempt "
+           "to connect to the server\n"
+           "This can be overridden for the python child api";
+}
+
+const char* ClientDoc::set_child_init_add_vars() {
+    return "Set the list of variables to be added when a task becomes active\n"
+           "Needs a dictionary of name/value pairs, or a list of ecflow Variables";
+}
+
+const char* ClientDoc::set_child_complete_del_vars() {
+    return "Set the list of variables to be deleted when a task becomes complete\n"
+           "Needs a list of strings, representing the variable names.";
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ClientDoc.hpp 5.13.0-1/libs/pyext/src/ecflow/python/ClientDoc.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ClientDoc.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ClientDoc.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,101 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_ClientDoc_HPP
+#define ecflow_python_ClientDoc_HPP
+
+// ===========================================================================
+// IMPORTANT: These appear as python doc strings.
+//            Additionally they are auto documented using sphinx-poco
+//            Hence the doc strings use reStructuredText markup.
+// ===========================================================================
+class ClientDoc {
+public:
+    ClientDoc()                            = delete;
+    ClientDoc(const ClientDoc&)            = delete;
+    ClientDoc& operator=(const ClientDoc&) = delete;
+
+    static const char* class_client();
+    static const char* set_host_port();
+    static const char* set_retry_connection_period();
+    static const char* set_connection_attempts();
+    static const char* get_defs();
+    static const char* edit_script_edit();
+    static const char* edit_script_preprocess();
+    static const char* edit_script_submit();
+    static const char* get_log();
+    static const char* new_log();
+    static const char* clear_log();
+    static const char* flush_log();
+    static const char* log_msg();
+    static const char* restart_server();
+    static const char* halt_server();
+    static const char* shutdown_server();
+    static const char* terminate_server();
+    static const char* wait_for_server_reply();
+    static const char* load_defs();
+    static const char* load();
+    static const char* get_server_defs();
+    static const char* sync();
+    static const char* in_sync();
+    static const char* news();
+    static const char* changed_node_paths();
+    static const char* checkpt();
+    static const char* restore_from_checkpt();
+    static const char* reload_wl_file();
+    static const char* run();
+    static const char* requeue();
+    static const char* free_date_dep();
+    static const char* free_trigger_dep();
+    static const char* free_time_dep();
+    static const char* free_all_dep();
+    static const char* ping();
+    static const char* stats();
+    static const char* stats_reset();
+    static const char* suites();
+    static const char* ch_register();
+    static const char* ch_suites();
+    static const char* ch_drop();
+    static const char* ch_drop_user();
+    static const char* ch_add();
+    static const char* ch_remove();
+    static const char* ch_auto_add();
+    static const char* get_file();
+    static const char* plug();
+    static const char* query();
+    static const char* alter();
+    static const char* force_state();
+    static const char* force_state_recursive();
+    static const char* force_event();
+    static const char* replace();
+    static const char* kill();
+    static const char* check();
+    static const char* status();
+    static const char* order();
+    static const char* group();
+    static const char* begin_suite();
+    static const char* begin_all();
+    static const char* suspend();
+    static const char* resume();
+    static const char* job_gen();
+    static const char* delete_node();
+    static const char* delete_all();
+    static const char* archive();
+    static const char* restore();
+    static const char* set_child_path();
+    static const char* set_child_password();
+    static const char* set_child_pid();
+    static const char* set_child_try_no();
+    static const char* set_child_timeout();
+    static const char* set_child_init_add_vars();
+    static const char* set_child_complete_del_vars();
+};
+
+#endif /* ecflow_python_ClientDoc_HPP */
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/DefsDoc.cpp 5.13.0-1/libs/pyext/src/ecflow/python/DefsDoc.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/DefsDoc.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/DefsDoc.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1030 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/DefsDoc.hpp"
+
+const char* DefsDoc::add() {
+    return "add(..) provides a way to append Nodes and attributes\n\n"
+           "This is best illustrated with an example:\n\n"
+           ".. code-block:: python\n\n"
+           " defs = Defs().add(\n"
+           "     Suite('s1').add(\n"
+           "         Clock(1, 1, 2010, False),\n"
+           "         Autocancel(1, 10, True),\n"
+           "         Task('t1').add(\n"
+           "             Edit({'a':'12', 'b':'bb'}, c='v',d='b'),\n"
+           "             Edit(g='d'),\n"
+           "             Edit(h=1),\n"
+           "             Event(1),\n"
+           "             Event(11,'event'),\n"
+           "             Meter('meter',0,10,10),\n"
+           "             Label('label','c'),\n"
+           "             Trigger('1==1'),\n"
+           "             Complete('1==1'),\n"
+           "             Limit('limit',10),Limit('limit2',10),\n"
+           "             InLimit('limitName','/limit',2),\n"
+           "             Defstatus(DState.complete),\n"
+           "             Today(0,30),Today('00:59'),Today('00:00 11:30 00:01'),\n"
+           "             Time(0,30),Time('00:59'),Time('00:00 11:30 00:01'),\n"
+           "             Day('sunday'),Day(Days.monday),\n"
+           "             Date(1,1,0),Date(28,2,1960),\n"
+           "             Autocancel(3)\n"
+           "             ),\n"
+           "         [ Family('f{}'.format(i)) for i in range(1,6)]))\n\n"
+           "We can also use '+=' with a list here are a few examples:\n\n"
+           ".. code-block:: python\n\n"
+           " defs = Defs();\n"
+           " defs += [ Suite('s2'),Edit({ 'x1':'y', 'aa1':'bb'}, a='v',b='b') ]\n\n"
+           ".. code-block:: python\n\n"
+           " defs += [ Suite('s{}'.format(i)) for i in range(1,6) ]\n\n"
+           ".. code-block:: python\n\n"
+           " defs = Defs()\n"
+           " defs += [ Suite('suite').add(\n"
+           "              Task('x'),\n"
+           "              Family('f').add( [ Task('t{}'.format(i)) for i in range(1,6)] ),\n"
+           "              Task('y'),\n"
+           "              [ Family('f{}'.format(i)) for i in range(1,6) ],\n"
+           "              Edit(a='b'),\n"
+           "              [ Task('t{}'.format(i)) for i in range(1,6) ],\n"
+           "              )]\n\n"
+           "It is also possible to use '+'\n\n"
+           ".. code-block:: python\n\n"
+           " defs = Defs() + Suite('s1')\n"
+           " defs.s1 += Autocancel(1, 10, True)\n"
+           " defs.s1 += Task('t1') + Edit({ 'e':1, 'f':'bb'}) +\\ \n"
+           "            Event(1) + Event(11,'event') + Meter('meter',0,10,10) + Label('label','c') + Trigger('1==1') "
+           "+\\ \n"
+           "            Complete('1==1') + Limit('limit',10) + Limit('limit2',10) + InLimit('limitName','/limit',2) "
+           "+\\ \n"
+           "            Defstatus(DState.complete) + Today(0,30) + Today('00:59') + Today('00:00 11:30 00:01') +\\ \n"
+           "            Time(0,30) + Time('00:59') + Time('00:00 11:30 00:01') + Day('sunday') + Day(Days.monday) +\\ "
+           "\n"
+           "            Date(1,1,0) + Date(28,2,1960) + Autocancel(3)\n\n"
+           ".. warning:: We can only use '+' when the left most object is a node, i.e Task('t1') in this case";
+}
+
+const char* DefsDoc::abs_node_path_doc() {
+    return "returns a string which holds the path to the node\n\n";
+}
+
+const char* DefsDoc::part_expression_doc() {
+    return "PartExpression holds part of a `trigger`_ or `complete expression`_.\n\n"
+           "Expressions can contain references to `event`_\\s, `meter`_\\ s, user variables,\n"
+           "`repeat`_ variables and generated variables. The part expression allows us\n"
+           "to split a large trigger or complete expression into smaller ones\n"
+           "\nConstructor::\n\n"
+           "  PartExpression(exp )\n"
+           "      string   exp: This represents the *first* expression\n\n"
+           "  PartExpression(exp, bool and_expr)\n"
+           "      string   exp: This represents the expression\n"
+           "      bool and_exp: If true the expression is to be anded, with a previously added expression\n"
+           "                    If false the expression is to be 'ored', with a previously added expression\n"
+           "\nUsage:\n"
+           "To add simple expression this class can be by-passed, i.e. can use:\n\n"
+           ".. code-block:: python\n\n"
+           "  task = Task('t1')\n"
+           "  task.add_trigger( 't2 == active' )\n"
+           "  task.add_complete( 't2 == complete' )\n\n"
+           "To add large triggers and complete expression:\n\n"
+           ".. code-block:: python\n\n"
+           "  exp1 = PartExpression('t1 == complete')\n  # a simple expression can be added as a string\n"
+           "  ....\n"
+           "  task2.add_part_trigger( PartExpression('t1 == complete or t4 == complete') ) \n"
+           "  task2.add_part_trigger( PartExpression('t5 == active',True) )    # anded with first expression\n"
+           "  task2.add_part_trigger( PartExpression('t7 == active',False) )   # or'ed with last expression added\n\n"
+           "The trigger for task2 is equivalent to\n"
+           "'t1 == complete or t4 == complete and t5 == active or t7 == active'";
+}
+
+const char* DefsDoc::expression_doc() {
+    return "Expression holds `trigger`_ or `complete expression`_. Also see :py:class:`ecflow.Trigger`\n\n"
+           "Expressions can contain references to events, meters, user variables,repeat variables and generated "
+           "variables.\n"
+           "Expressions hold a list of part expressions. This allows us to split a large trigger or complete\n"
+           "expression into smaller ones.\n"
+           "\nConstructor::\n\n"
+           "   Expression( expression )\n"
+           "      string expression  : This typically represents the complete expression\n"
+           "                           however part expression can still be added\n"
+           "   Expression( part )\n"
+           "      PartExpression part: The first part expression should have no 'and/or' set\n"
+           "\nUsage:\n"
+           "To add simple expression this class can be by passed, i.e. can use:\n\n"
+           ".. code-block:: python\n\n"
+           "  task = Task('t1')\n"
+           "  task.add_trigger( 't2 == active' )\n"
+           "  task.add_complete( 't2 == complete' )\n"
+           "\n"
+           "  task = Task('t2')\n"
+           "  task.add_trigger( 't1 == active' )\n"
+           "  task.add_part_trigger( 't3 == active', True)\n\n"
+           "To store and add large expressions use a Expression with PartExpression:\n\n"
+           ".. code-block:: python\n\n"
+           "  big_expr = Expression( PartExpression('t1 == complete or t4 == complete') )\n"
+           "  big_expr.add( PartExpression('t5 == active',True) )\n"
+           "  big_expr.add( PartExpression('t7 == active',False) )\n"
+           "  task.add_trigger( big_expr)\n\n"
+           "In the example above the trigger for task is equivalent to\n"
+           "'t1 == complete or t4 == complete and t5 == active or t7 == active'\n\n"
+           ".. code-block:: python\n\n"
+           "  big_expr2 = Expression('t0 == complete'))\n"
+           "  big_expr2.add( PartExpression('t1 == complete or t4 == complete',True) )\n"
+           "  big_expr2.add( PartExpression('t5 == active',False) )\n"
+           "  task2.add_trigger( big_expr2)\n\n"
+           "Here the trigger for task2 is equivalent to\n"
+           "'t0 == complete and t1 == complete or t4 == complete or t5 == active'";
+}
+
+const char* DefsDoc::add_trigger_doc() {
+    return "Add a `trigger`_ or `complete expression`_.Also see :py:class:`ecflow.Trigger`\n\n"
+           "This defines a dependency for a `node`_.\n"
+           "There can only be one `trigger`_ or `complete expression`_ dependency per node.\n"
+           "A `node`_ with a trigger can only be activated when the trigger has expired.\n"
+           "A trigger holds a node as long as the expression returns false.\n"
+           "\nException:\n\n"
+           "- Will throw RuntimeError if multiple trigger or complete expression are added\n"
+           "- Will throw RuntimeError if first expression is added as 'AND' or 'OR' expression\n"
+           "  Like wise second and subsequent expression must have 'AND' or 'OR' booleans set\n"
+           "\nUsage:\n\n"
+           "Note we cannot make multiple add_trigger(..) calls on the same `task`_!\n"
+           "to add a simple trigger:\n\n"
+           ".. code-block:: python\n\n"
+           "  task1.add_trigger( 't2 == active' )\n"
+           "  task2.add_trigger( 't1 == complete or t4 == complete' )\n"
+           "  task3.add_trigger( 't5 == active' )\n"
+           "\n"
+           "Long expression can be broken up using add_part_trigger:\n\n"
+           ".. code-block:: python\n\n"
+           "  task2.add_part_trigger( 't1 == complete or t4 == complete')\n"
+           "  task2.add_part_trigger( 't5 == active',True)  # True means  AND\n"
+           "  task2.add_part_trigger( 't7 == active',False) # False means OR\n\n"
+           "The trigger for task2 is equivalent to:\n"
+           "'t1 == complete or t4 == complete and t5 == active or t7 == active'";
+}
+
+const char* DefsDoc::trigger() {
+    return "Add a `trigger`_ or `complete expression`_.\n\n"
+           "This defines a dependency for a `node`_.\n"
+           "There can only be one `trigger`_ or `complete expression`_ dependency per node.\n"
+           "A `node`_ with a trigger can only be activated when the trigger has expired.\n"
+           "Triggers can reference nodes, events, meters, variables, repeats, limits and late flag\n"
+           "A trigger holds a node as long as the expression returns false.\n"
+           "\nException:\n\n"
+           "- Will throw RuntimeError if first expression is added as 'AND' or 'OR' expression\n"
+           "  Like wise second and subsequent expression must have 'AND' or 'OR' booleans set\n"
+           "\nUsage:\n\n"
+           "Multiple trigger will automatically be *anded* together, If *or* is required please\n"
+           "use bool 'False' as the last argument i.e. :\n\n"
+           ".. code-block:: python\n\n"
+           "  task1.add( Trigger('t2 == active' ),\n"
+           "             Trigger('t1 == complete or t4 == complete' ),\n"
+           "             Trigger('t5 == active',False))\n"
+           "\n"
+           "The trigger for task1 is equivalent to :\n\n"
+           ".. code-block:: python\n\n"
+           "  t2 == active and t1 == complete or t4 == complete or t5 == active\n\n"
+           "Since a large number of triggers are of the form `<node> == complete` there are\n"
+           "are short cuts, these involves a use of a list :\n\n"
+           ".. code-block:: python\n\n"
+           "  task1.add( Trigger( ['t2','t3'] )) #  This is same as t2 == complete and t3 == complete\n\n"
+           "You can also use a node :\n\n"
+           ".. code-block:: python\n\n"
+           "  task1.add( Trigger( ['t2',taskx] ))\n\n"
+           "If the node 'taskx' has a parent, we use the full hierarchy, hence we will get a trigger\n"
+           "of the form :\n\n"
+           ".. code-block:: python\n\n"
+           "  t2 ==complete and /suite/family/taskx == complete\n\n"
+           "If however node taskx has not yet been added to its parent, we use a relative name in the trigger :\n\n"
+           ".. code-block:: python\n\n"
+           "  t2 ==complete and taskx == complete\n";
+}
+
+const char* DefsDoc::add_variable_doc() {
+    return "Adds a name value `variable`_. Also see :py:class:`ecflow.Edit`\n\n"
+           "This defines a variable for use in `variable substitution`_ in a `ecf script`_ file.\n"
+           "There can be any number of variables. The variables are names inside a pair of\n"
+           "'%' characters in an `ecf script`_. The name are case sensitive.\n"
+           "Special character in the value, must be placed inside single quotes if misinterpretation\n"
+           "is to be avoided.\n"
+           "The value of the variable replaces the variable name in the `ecf script`_ at `job creation` time.\n"
+           "The variable names for any given node must be unique. If duplicates are added then the\n"
+           "the last value added is kept.\n"
+           "\nException:\n\n"
+           "- Writes warning to standard output, if a duplicate variable name is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  task.add_variable( Variable('ECF_HOME','/tmp/'))\n"
+           "  task.add_variable( 'TMPDIR','/tmp/')\n"
+           "  task.add_variable( 'COUNT',2)\n"
+           "  a_dict = { 'name':'value', 'name2':'value2', 'name3':'value3' }\n"
+           "  task.add_variable(a_dict)\n";
+}
+
+const char* DefsDoc::add_label_doc() {
+    return "Adds a `label`_ to a `node`_. See :py:class:`ecflow.Label`\n\n"
+           "Labels can be updated from the jobs files, via `child command`_\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if a duplicate label name is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  task.add_label( Label('TEA','/me/'))\n"
+           "  task.add_label( 'Joe','/me/')\n\n"
+           "The corresponding child command in the .ecf script file might be:\n\n"
+           ".. code-block:: shell\n\n"
+           "  ecflow_client --label=TEA time\n"
+           "  ecflow_client --label=Joe ninety\n";
+}
+
+const char* DefsDoc::add_aviso_doc() {
+    return "Adds an `aviso`_ to a `node`_. See :py:class:`ecflow.Aviso`\n";
+}
+
+const char* DefsDoc::add_mirror_doc() {
+    return "Adds a `mirror`_ to a `node`_. See :py:class:`ecflow.Mirror`\n";
+}
+
+const char* DefsDoc::add_limit_doc() {
+    return "Adds a `limit`_ to a `node`_ for simple load management. See :py:class:`ecflow.Limit`\n\n"
+           "Multiple limits can be added, however the limit name must be unique.\n"
+           "For a node to be in a limit, a `inlimit`_ must be used.\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if a duplicate limit name is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  family.add_limit( Limit('load',12) )\n"
+           "  family.add_limit( 'load',12 )\n";
+}
+
+const char* DefsDoc::add_inlimit_doc() {
+    return "Adds a `inlimit`_ to a `node`_. See :py:class:`ecflow.InLimit`\n\n"
+           "InLimit reference a `limit`_/:py:class:`ecflow.Limit`. Duplicate InLimits are not allowed\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if a duplicate is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  task2.add_inlimit( InLimit('limitName','/s1/f1',2) )\n"
+           "  task2.add_inlimit( 'limitName','/s1/f1',2 )\n";
+}
+
+const char* DefsDoc::suite_doc() {
+    return "A `suite`_ is a collection of Families,Tasks,Variables, `repeat`_ and `clock`_ definitions\n\n"
+           "Suite is the only node that can be started using the begin API.\n"
+           "There are several ways of adding a suite, see example below and :py:class:`ecflow.Defs.add_suite`\n"
+           "\nConstructor::\n\n"
+           "  Suite(name, Nodes | attributes)\n"
+           "      string name : The Suite name. name must consist of alpha numeric characters or\n"
+           "                    underscore or dot. The first character cannot be a dot, as this\n"
+           "                    will interfere with trigger expressions. Case is significant\n"
+           "      Nodes | Attributes:(optional)\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if the name is not valid\n"
+           "- Throws a RuntimeError if duplicate suite names added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  defs = Defs()                  # create a empty definition. Root of all Suites\n"
+           "  suite = Suite('suite_1')       # create a stand alone suite\n"
+           "  defs.add_suite(suite)          # add suite to definition\n"
+           "  suite2 = defs.add_suite('s2')  # create a suite and add it to the defs\n\n"
+           "  defs = Defs(\n"
+           "           Suite('s1',\n"
+           "              Family('f1',\n"
+           "                 Task('t1'))))   # create in in-place\n";
+}
+
+const char* DefsDoc::family_doc() {
+    return "Create a `family`_ `node`_.A Family node lives inside a `suite`_ or another `family`_\n\n"
+           "A family is used to collect `task`_\\ s together or to group other families.\n"
+           "Typically you place tasks that are related to each other inside the same family\n"
+           "analogous to the way you create directories to contain related files.\n"
+           "There are two ways of adding a family, see example below.\n"
+           "\nConstructor::\n\n"
+           "  Family(name, Nodes | Attributes)\n"
+           "      string name : The Family name. name must consist of alpha numeric characters or\n"
+           "                    underscore or dot. The first character cannot be dot, as this\n"
+           "                    will interfere with trigger expressions. Case is significant\n"
+           "      Nodes | Attributes: (optional)\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if the name is not valid\n"
+           "- Throws a RuntimeError if a duplicate family is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  suite = Suite('suite_1')       # create a suite\n"
+           "  family = Family('family_1')    # create a family\n"
+           "  suite.add_family(family)       # add created family to a suite\n"
+           "  f2 = suite.add_family('f2')    # create a family f2 and add to suite\n\n"
+           "  # create in place\n"
+           "  defs = Defs(\n"
+           "           Suite('s1',\n"
+           "              Family('f1',\n"
+           "                 Task('t1',\n"
+           "                     Edit(SLEEP='10')))))\n";
+}
+
+const char* DefsDoc::task_doc() {
+    return "Creates a `task`_ `node`_. Task is a child of a :py:class:`ecflow.Suite` or :py:class:`ecflow.Family` "
+           "node.\n\n"
+           "Multiple Tasks can be added, however the task names must be unique for a given parent.\n"
+           "Note case is significant. Only Tasks can be submitted. A job inside a Task `ecf script`_ (i.e .ecf file)\n"
+           "should generally be re-entrant since a Task may be automatically submitted more than once if it aborts.\n"
+           "There are several ways of adding a task, see examples below\n"
+           "\nConstructor::\n\n"
+           "  Task(name, Attributes)\n"
+           "     string name : The Task name.Name must consist of alpha numeric characters or\n"
+           "                   underscore or dot. First character cannot be a dot.\n"
+           "                   Case is significant\n"
+           "     attributes: optional, i.e like Meter, Event, Trigger etc\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if the name is not valid\n"
+           "- Throws a RuntimeError if a duplicate Task is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  task = Task('t1')            # create a stand alone task\n"
+           "  family.add_task(task)        # add to the family\n"
+           "  t2 = family.add_task('t2')   # create a task t2 and add to the family\n\n"
+           "  # Create Task in place\n"
+           "  defs = Defs(\n"
+           "           Suite('s1',\n"
+           "              Family('f1',\n"
+           "                 Task('t1',\n"
+           "                    Trigger('1==1'),\n"
+           "                    Edit(SLEEP='10'))))) # add Trigger and Variables in place\n";
+}
+
+const char* DefsDoc::alias_doc() {
+    return "Aliases can be created by the GUI or via edit_script command.\n\n"
+           "Aliases provide a mechanism to edit/test task scripts without effecting the suite.\n"
+           "The Aliases parent is always a Task. Multiple Alias can be added\n";
+}
+
+const char* DefsDoc::add_suite_doc() {
+    return "Add a `suite`_ `node`_. See :py:class:`ecflow.Suite`\n\n"
+           "If a new suite is added which matches the name of an existing suite, then an exception is thrown.\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError is the suite name is not valid\n"
+           "- Throws RuntimeError if duplicate suite is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  defs = Defs()                # create a empty defs\n"
+           "  suite = Suite('suite')       # create a stand alone Suite \n"
+           "  defs.add_suite(suite)        # add suite to defs\n"
+           "  s2 = defs.add_suite('s2')    # create a suite and add to defs\n\n"
+           "  # Alternatively we can create Suite in place\n"
+           "  defs = Defs(\n"
+           "           Suite('s1',\n"
+           "              Family('f1',\n"
+           "                 Task('t1'))),\n"
+           "           Suite('s2',\n"
+           "              Family('f1',\n"
+           "                 Task('t1'))))\n";
+}
+
+const char* DefsDoc::add_extern_doc() {
+    return "`extern`_ refer to nodes that have not yet been defined typically due to cross suite `dependencies`_\n\n"
+           "`trigger`_ and `complete expression`_\\ s may refer to paths, and variables in other suites, that have not "
+           "been\n"
+           "loaded yet. The references to node paths and variable must exist, or exist as externs\n"
+           "Externs can be added manually or automatically.\n\n"
+           "Manual Method:\n\n"
+           ".. code-block:: python\n\n"
+           "  void add_extern(string nodePath )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  defs = Defs('file.def')\n"
+           "  ....\n"
+           "  defs.add_extern('/temp/bill:event_name')\n"
+           "  defs.add_extern('/temp/bill:meter_name')\n"
+           "  defs.add_extern('/temp/bill:repeat_name')\n"
+           "  defs.add_extern('/temp/bill:edit_name')\n"
+           "  defs.add_extern('/temp/bill')\n"
+           "\n"
+           "Automatic Method:\n"
+           "  This will scan all trigger and complete expressions, looking for paths and variables\n"
+           "  that have not been defined. The added benefit of this approach is that duplicates will not\n"
+           "  be added. It is the user's responsibility to check that extern's are eventually defined\n"
+           "  otherwise trigger expression will not evaluate correctly\n\n"
+           ".. code-block:: python\n\n"
+           "  void auto_add_externs(bool remove_existing_externs_first )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  defs = Defs('file.def')\n"
+           "  ...\n"
+           "  defs.auto_add_externs(True)   # remove existing extern first.\n";
+}
+
+const char* DefsDoc::node_doc() {
+    return "A Node class is the abstract base class for Suite, Family and Task\n\n"
+           "Every Node instance has a name, and a path relative to a suite";
+}
+
+const char* DefsDoc::node_container_doc() {
+    return "NodeContainer is the abstract base class for a Suite and Family\n\n"
+           "A NodeContainer can have Families and Tasks as children";
+}
+
+const char* DefsDoc::submittable_doc() {
+    return "Submittable is the abstract base class for a Task and Alias\n\n"
+           "It provides a process id, password and try number";
+}
+
+const char* DefsDoc::add_family_doc() {
+    return "Add a `family`_. See :py:class:`ecflow.Family`.\n\n"
+           "Multiple families can be added. However family names must be unique.\n"
+           "for a given parent. Families can be hierarchical.\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if a duplicate is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  suite = Suite('suite')          # create a suite\n"
+           "  f1 = Family('f1')               # create a family\n"
+           "  suite.add_family(f1)            # add family to suite\n"
+           "  f2 = suite.add_family('f2')     # create a family and add to suite\n";
+}
+
+const char* DefsDoc::add_task_doc() {
+    return "Add a `task`_. See :py:class:`ecflow.Task`\n\n"
+           "Multiple Tasks can be added. However Task names must be unique,\n"
+           "for a given parent. Task can be added to Familiy's or Suites.\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if a duplicate is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  f1 = Family('f1')      # create a family\n"
+           "  t1 = Task('t1')          # create a task\n"
+           "  f1.add_task(t1)          # add task to family\n"
+           "  t2 = f1.add_task('t2') # create task 't2' and add to family";
+}
+
+const char* DefsDoc::add_definition_doc() {
+    return "The Defs class holds the `suite definition`_ structure.\n\n"
+           "It contains all the :py:class:`ecflow.Suite` and hence acts like the root for suite node tree hierarchy.\n"
+           "The definition can be kept as python code, alternatively it can be saved as a flat\n"
+           "ASCII definition file.\n"
+           "If a definition is read in from disk, it will by default, check the `trigger`_ expressions.\n"
+           "If however the definition is created in python, then checking should be done explicitly:\n\n"
+           "   Defs(string)\n"
+           "      string - The Defs class take one argument which represents the file name\n"
+           "   Defs(Suite | Edit )\n"
+           "      :py:class:`ecflow.Suite`- One or more suites\n\n"
+           "      :py:class:`ecflow.Edit` - specifies user defined server variables\n"
+           "\nExample:\n\n"
+           ".. code-block:: python\n\n"
+           " # Build definition using Constructor approach, This allows indentation, to show the structure\n"
+           " # This is a made up example to demonstrate suite construction:\n"
+           " defs = Defs(\n"
+           "     Edit(SLEEP=10,FRED='bill'),  # user defined server variables\n"
+           "     Suite('s1'\n"
+           "         Clock(1, 1, 2010, False),\n"
+           "         Autocancel(1, 10, True),\n"
+           "         Task('t1'\n"
+           "             Edit({'a':'12', 'b':'bb'}, c='v',d='b'),\n"
+           "             Edit(g='d'),\n"
+           "             Edit(h=1),\n"
+           "             Event(1),\n"
+           "             Event(11,'event'),\n"
+           "             Meter('meter',0,10,10),\n"
+           "             Label('label','c'),\n"
+           "             Trigger('1==1'),\n"
+           "             Complete('1==1'),\n"
+           "             Limit('limit',10),Limit('limit2',10),\n"
+           "             InLimit('limitName','/limit',2),\n"
+           "             Defstatus(DState.complete),\n"
+           "             Today(0,30),Today('00:59'),Today('00:00 11:30 00:01'),\n"
+           "             Time(0,30),Time('00:59'),Time('00:00 11:30 00:01'),\n"
+           "             Day('sunday'),Day(Days.monday),\n"
+           "             Date(1,1,0),Date(28,2,1960),\n"
+           "             Autocancel(3)\n"
+           "             ),\n"
+           "         [ Family('f{}'.format(i)) for i in range(1,6)]))\n\n"
+           "  defs.save_as_defs('filename.def')  # save defs into file\n\n"
+           "  defs = Defs()                      # create an empty defs\n"
+           "  suite = defs.add_suite('s1')\n"
+           "  family = suite.add_family('f1')\n"
+           "  for i in [ '_1', '_2', '_3' ]: family.add_task( 't' + i )\n"
+           "  defs.save_as_defs('filename.def')  # save defs into file\n"
+           "\n"
+           "Create a Defs from an existing file on disk:\n\n"
+           ".. code-block:: python\n\n"
+           "  defs = Defs('filename.def')   #  Will open and parse the file and create the Definition\n"
+           "  print(defs)\n";
+}
+
+const char* DefsDoc::add_event_doc() {
+    return "Add a `event`_. See :py:class:`ecflow.Event`\n"
+           "Events can be referenced in `trigger`_ and `complete expression`_\\ s\n\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if a duplicate is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1',\n"
+           "            Event(12),\n"
+           "            Event(11,'eventx'))             # Create events on Task creation\n\n"
+           "  t1.add_event( Event(10) )                 # Create with function on Task\n"
+           "  t1.add_event( Event(11,'Eventname') )\n"
+           "  t1.add_event( 12 )\n"
+           "  t1.add_event( 13, 'name')\n\n"
+           "To reference event 'flag' in a trigger:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1.add_event('flag')\n"
+           "  t2 = Task('t2',\n"
+           "            Trigger('t1:flag == set'))";
+}
+
+const char* DefsDoc::add_meter_doc() {
+    return "Add a `meter`_. See :py:class:`ecflow.Meter`\n"
+           "Meters can be referenced in `trigger`_ and `complete expression`_\\ s\n\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if a duplicate is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1',\n"
+           "            Meter('met',0,50))                   # create Meter on Task creation\n"
+           "  t1.add_meter( Meter('metername',0,100,50) )  # create Meter using function\n"
+           "  t1.add_meter( 'meter',0,200)\n\n"
+           "To reference in a trigger:\n\n"
+           ".. code-block:: python\n\n"
+           "  t2 = Task('t2')\n"
+           "  t2.add_trigger('t1:meter >= 10')\n";
+}
+
+const char* DefsDoc::add_date_doc() {
+    return "Add a `date`_ time dependency. See :py:class:`ecflow.Date`\n\n"
+           "A value of zero for day,month,year means every day, every month, every year\n"
+           "\nException:\n\n"
+           "- Throws RuntimeError if an invalid date is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1',\n"
+           "            Date('1.*.*'),\n"
+           "            Date(1,1,2010)))    # Create Date in place\n\n"
+           "  t1.add_date( Date(1,1,2010) ) # day,month,year\n"
+           "  t1.add_date( 2,1,2010)        # day,month,year\n"
+           "  t1.add_date( 1,0,0)           # day,month,year, the first of each month for every year\n";
+}
+
+const char* DefsDoc::add_day_doc() {
+    return "Add a `day`_ time dependency. See :py:class:`ecflow.Day`\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1',\n"
+           "            Day('sunday'))  # Create Day on Task creation\n\n"
+           "  t1.add_day( Day(Days.sunday) )\n"
+           "  t1.add_day( Days.monday)\n"
+           "  t1.add_day( 'tuesday' )\n";
+}
+
+const char* DefsDoc::add_today_doc() {
+    return "Add a `today`_ time dependency. See :py:class:`ecflow.Today`\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1',\n"
+           "            Today('+00:30 20:00 01:00')) # Create Today in Task constructor\n\n"
+           "  t1.add_today( '00:30' )\n"
+           "  t1.add_today( '+00:30' )\n"
+           "  t1.add_today( '+00:30 20:00 01:00' )\n"
+           "  t1.add_today( Today( 0,10 ))      # hour,min,relative =false\n"
+           "  t1.add_today( Today( 0,12,True )) # hour,min,relative\n"
+           "  t1.add_today( Today(TimeSlot(20,20),False))\n"
+           "  t1.add_today( 0,1 ))              # hour,min,relative=false\n"
+           "  t1.add_today( 0,3,False ))        # hour,min,relative=false\n"
+           "  start = TimeSlot(0,0)\n"
+           "  finish = TimeSlot(23,0)\n"
+           "  incr = TimeSlot(0,30)\n"
+           "  ts = TimeSeries( start, finish, incr, True)\n"
+           "  task2.add_today( Today(ts) )\n";
+}
+
+const char* DefsDoc::add_time_doc() {
+    return "Add a `time`_ dependency. See :py:class:`ecflow.Time`\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1', Time('+00:30 20:00 01:00')) # Create Time in Task constructor\n"
+           "  t1.add_time( '00:30' )\n"
+           "  t1.add_time( '+00:30' )\n"
+           "  t1.add_time( '+00:30 20:00 01:00' )\n"
+           "  t1.add_time( Time( 0,10 ))      # hour,min,relative =false\n"
+           "  t1.add_time( Time( 0,12,True )) # hour,min,relative\n"
+           "  t1.add_time( Time(TimeSlot(20,20),False))\n"
+           "  t1.add_time( 0,1 ))              # hour,min,relative=false\n"
+           "  t1.add_time( 0,3,False ))        # hour,min,relative=false\n"
+           "  start = TimeSlot(0,0)\n"
+           "  finish = TimeSlot(23,0)\n"
+           "  incr = TimeSlot(0,30)\n"
+           "  ts = TimeSeries( start, finish, incr, True)\n"
+           "  task2.add_time( Time(ts) )\n";
+}
+
+const char* DefsDoc::add_cron_doc() {
+    return "Add a `cron`_ time dependency. See :py:class:`ecflow.Cron`\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  start = TimeSlot(0,0)\n"
+           "  finish = TimeSlot(23,0)\n"
+           "  incr = TimeSlot(0,30)\n"
+           "  time_series = TimeSeries( start, finish, incr, True)\n"
+           "  cron = Cron()\n"
+           "  cron.set_week_days( [0,1,2,3,4,5,6] )\n"
+           "  cron.set_days_of_month( [1,2,3,4,5,6] )\n"
+           "  cron.set_months( [1,2,3,4,5,6] )\n"
+           "  cron.set_time_series( time_series )\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_cron( cron )\n\n"
+           "  # we can also create a Cron in the Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            Cron('+00:00 23:00 "
+           "00:30',days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6],months=[1,2,3,4,5,6]))\n";
+}
+
+const char* DefsDoc::add_late_doc() {
+    return "Add a `late`_ attribute. See :py:class:`ecflow.Late`\n\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one late is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  late = Late()\n"
+           "  late.submitted( 20,10 )     # hour,minute\n"
+           "  late.active(    20,10 )     # hour,minute\n"
+           "  late.complete(  20,10,True) # hour,minute,relative\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_late( late )\n\n"
+           "  # we can also create a Late in the Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            Late(submitted='20:10',active='20:10',complete='+20:10'))\n";
+}
+
+const char* DefsDoc::add_autocancel_doc() {
+    return "Add a `autocancel` attribute. See :py:class:`ecflow.Autocancel`\n\n"
+           "This will delete the node on completion. The deletion may be delayed by\n"
+           "an amount of time in hours and minutes or expressed as days\n"
+           "Node deletion is not immediate. The nodes are checked once a minute\n"
+           "and expired auto cancel nodes are deleted\n"
+           "A node may only have one auto cancel attribute\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one auto cancel is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_autocancel( Autocancel(20,10,False) )  # hour,min, relative\n"
+           "  t2 = Task('t2')\n"
+           "  t2.add_autocancel( 3 )                        # 3 days \n"
+           "  t3 = Task('t3')\n"
+           "  t3.add_autocancel( 20,10,True )               # hour,minutes,relative\n"
+           "  t4 = Task('t4')\n"
+           "  t4.add_autocancel( TimeSlot(20,10),True )     # hour,minutes,relative\n\n"
+           "  # we can also create a Autocancel in the Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            Autocancel(20,10,False))\n";
+}
+
+const char* DefsDoc::add_autoarchive_doc() {
+    return "Add a `autoarchive` attribute. See :py:class:`ecflow.Autoarchive`\n\n"
+           "Provides a way to automatically archive a suite/family which has completed.(i.e remove children)\n"
+           "This is required when dealing with super large suite/families, they can be archived off, and then restored "
+           "later.\n"
+           "The node can be recovered using 'autorestore',begin,re-queue and manually via ecflow_client --restore.\n"
+           "The archived node is written to disk, as ECF_HOME/<host>.<port>.ECF_NAME.check,\n"
+           "where '/' is replaced with ':' in ECF_NAME.\n"
+           "The removal may be delayed by an amount of time in hours and minutes or expressed as days\n"
+           "Node removal is not immediate. The nodes are checked once a minute\n"
+           "A Node may only have one autoarchive attribute\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one auto archive is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_autoarchive( Autoarchive(20,10,False) )  # hour,min, relative\n"
+           "  t2 = Task('t2')\n"
+           "  t2.add_autoarchive( 3 )                        # 3 days \n"
+           "  t3 = Task('t3')\n"
+           "  t3.add_autoarchive( 20,10,True )               # hour,minutes,relative\n"
+           "  t4 = Task('t4')\n"
+           "  t4.add_autoarchive( TimeSlot(20,10),True )     # hour,minutes,relative\n\n"
+           "  # we can also create a Autoarchive in the Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            Autoarchive(20,10,False))\n";
+}
+
+const char* DefsDoc::add_autorestore_doc() {
+    return "Add a `autorestore` attribute. See :py:class:`ecflow.Autorestore`\n\n"
+           "Auto-restore is used to automatically restore a previously auto-archived node.\n"
+           "The restore will fail if:\n\n"
+           " - The node has not been archived\n"
+           " - The node has children.\n"
+           " - The file ECF_HOME/<host>.<port>.ECF_NAME.check does not exist\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one autorestore is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_autorestore( ['/s1/f1'] )   \n"
+           "  t2 = Task('t2')\n"
+           "  t2.add_autorestore( Autorestore(['/s2/f1','/s1/f2']) )  \n"
+           "  # we can also create a Autorestore in the Task constructor like any other attribute\n"
+           "  t2 = Task('t2', Autorestore(['/s2/f1','/s1/f2'] ))\n";
+}
+
+const char* DefsDoc::add_verify_doc() {
+    return "Add a Verify attribute.\n\n"
+           "Used in python simulation used to assert that a particular state was reached."
+           "  t2 = Task('t2',\n"
+           "             Verify(State.complete, 6)) # verify task completes 6 times during simulation\n";
+}
+
+const char* DefsDoc::add_repeat_date_doc() {
+    return "Add a RepeatDate attribute. See :py:class:`ecflow.RepeatDate`\n\n"
+           "A node can only have one repeat\n"
+           "Reference to a RepeatDate in a trigger will use date arithmetic in a sub expression. i.e.\n"
+           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer\n\n"
+           "   trigger /suite/family:YMD + 1 > 20190101\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one repeat is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_repeat( RepeatDate('YMD',20100111,20100115) )\n\n"
+           "  # we can also create a repeat in Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            RepeatDate('YMD',20100111,20100115))\n";
+}
+
+const char* DefsDoc::add_repeat_datetime_doc() {
+    return "Add a RepeatDateTime attribute. See :py:class:`ecflow.RepeatDateTime`\n\n"
+           "A node can only have one repeat.\n"
+           "When a RepeatDateTime is used in a trigger expression, the arithmetic value of the Repeat decays to second.\n"
+           "For example, the expression `/suite/family:DATETIME + 1` is evaluated as the number of seconds represented "
+           "by `/suite/family:DT` (since the reference epoch, i.e. 19700101T000000) plus 1."
+           "The result is an integer.\n\n"
+           "   trigger /suite/family:DT + 1 > 123456\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one repeat is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_repeat(RepeatDateTime('DT', '20100111T120000', '20100115T000000', '12:00:00'))\n\n"
+           "  # we can also create a repeat in Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            RepeatDateTime('DT', '20100101T000000', '20100115T000000', '1:00:00'))\n";
+}
+
+const char* DefsDoc::add_repeat_date_list_doc() {
+    return "Add a RepeatDateList attribute. See :py:class:`ecflow.RepeatDateList`\n\n"
+           "A node can only have one repeat\n"
+           "Reference to a RepeatDateList in a trigger will use date arithmetic. i.e.\n"
+           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer:\n\n"
+           ".. code-block:: python\n\n"
+           "  trigger /suite/family:YMD + 1 > 20190101\n\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one repeat is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_repeat( RepeatDateList('YMD',[20100111,20100115]) )\n\n"
+           "  # we can also create a repeat in Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            RepeatDateList('YMD',[20100111,20100115]))\n";
+}
+
+const char* DefsDoc::add_repeat_integer_doc() {
+    return "Add a RepeatInteger attribute. See :py:class:`ecflow.RepeatInteger`\n\n"
+           "A node can only have one `repeat`_\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one repeat is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_repeat( RepeatInteger('testInteger',0,100,2) )\n\n"
+           "  # we can also create a repeat in Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            RepeatInteger('testInteger',0,100,2))\n";
+}
+
+const char* DefsDoc::add_repeat_string_doc() {
+    return "Add a RepeatString attribute. See :py:class:`ecflow.RepeatString`\n\n"
+           "A node can only have one `repeat`_\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one repeat is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_repeat( RepeatString('test_string',['a', 'b', 'c' ] ) )\n\n"
+           "  # we can also create a repeat in Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            RepeatString('test_string',['a', 'b', 'c' ] ) )\n";
+}
+
+const char* DefsDoc::add_repeat_enumerated_doc() {
+    return "Add a RepeatEnumerated attribute. See :py:class:`ecflow.RepeatEnumerated`\n\n"
+           "A node can only have one `repeat`_\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one repeat is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1')\n"
+           "  t1.add_repeat( RepeatEnumerated('test_string', ['red', 'green', 'blue' ] ) )\n\n"
+           "  # we can also create a repeat in Task constructor like any other attribute\n"
+           "  t2 = Task('t2',\n"
+           "            RepeatEnumerated('test_string', ['red', 'green', 'blue' ] ) )\n";
+}
+
+const char* DefsDoc::add_repeat_day_doc() {
+    return "Add a RepeatDay attribute. See :py:class:`ecflow.RepeatDay`\n\n"
+           "A node can only have one `repeat`_\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if more than one repeat is added\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t2 = Task('t2',\n"
+           "            RepeatDay(1))\n";
+}
+
+const char* DefsDoc::add_defstatus_doc() {
+    return "Set the default status( `defstatus`_ ) of node at begin or re queue. See :py:class:`ecflow.Defstatus`\n\n"
+           "A `defstatus`_ is useful in preventing suites from running automatically\n"
+           "once begun, or in setting Task's complete so they can be run selectively\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  t1 = Task('t1') + Defstatus('complete')\n"
+           "  t2 = Task('t2').add_defstatus( DState.suspended )\n\n"
+           "  # we can also create a Defstatus in the Task constructor like any other attribute\n"
+           "  t2 = Task('t3',\n"
+           "            Defstatus('complete'))\n";
+}
+
+const char* DefsDoc::jobgenctrl_doc() {
+    return "The class JobCreationCtrl is used in `job creation` checking\n\n"
+           "Constructor::\n\n"
+           "   JobCreationCtrl()\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   defs = Defs('my.def')                     # specify the definition we want to check, load into memory\n"
+           "   job_ctrl = JobCreationCtrl()\n"
+           "   job_ctrl.set_node_path('/suite/to_check') # will hierarchically check job creation under this node\n"
+           "   defs.check_job_creation(job_ctrl)         # job files generated to ECF_JOB\n"
+           "   print(job_ctrl.get_error_msg())            # report any errors in job generation\n"
+           "\n"
+           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
+           "   job_ctrl.set_dir_for_job_creation(tmp)    # generate jobs file under this directory\n"
+           "   defs.check_job_creation(job_ctrl)\n"
+           "   print(job_ctrl.get_error_msg())\n"
+           "\n"
+           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
+           "   job_ctrl.generate_temp_dir()              # automatically generate directory for job file\n"
+           "   defs.check_job_creation(job_ctrl)\n"
+           "   print(job_ctrl.get_error_msg())\n";
+}
+
+const char* DefsDoc::check_job_creation_doc() {
+    return "Check `job creation` .\n\n"
+           "Will check the following:\n\n"
+           "- `ecf script`_ files and includes files can be located\n"
+           "- recursive includes\n"
+           "- manual and comments `pre-processing`_\n"
+           "- `variable substitution`_\n\n"
+           "Some `task`_\\ s are dummy tasks have no associated `ecf script`_ file.\n"
+           "To disable error message for these tasks please add a variable called ECF_DUMMY_TASK to them.\n"
+           "Checking is done in conjunction with the class :py:class:`ecflow.JobCreationCtrl`.\n"
+           "If no node path is set on class JobCreationCtrl then all tasks are checked.\n"
+           "In the case where we want to check all tasks, use the convenience function that take no arguments.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   defs = Defs('my.def')                     # specify the defs we want to check, load into memory\n"
+           "   ...\n"
+           "   print(defs.check_job_creation())          # Check job generation for all tasks\n"
+           "   ...\n\n"
+           "   # throw on error and Output the tasks as they are being checked\n"
+           "   defs.check_job_creation(throw_on_error=TrueTrue,verbose=True)\n\n"
+           "   job_ctrl = JobCreationCtrl()\n"
+           "   job_ctrl.set_verbose(True)                # Output the tasks as they are being checked\n"
+           "   defs.check_job_creation(job_ctrl)         # Check job generation for all tasks, same as above\n"
+           "   print(job_ctrl.get_error_msg())\n"
+           "   ...\n"
+           "   job_ctrl = JobCreationCtrl()\n"
+           "   job_ctrl.set_node_path('/suite/to_check') # will hierarchically check job creation under this node\n"
+           "   defs.check_job_creation(job_ctrl)         # job files generated to ECF_JOB\n"
+           "   print(job_ctrl.get_error_msg())\n"
+           "   ...\n"
+           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
+           "   job_ctrl.set_dir_for_job_creation(tmp)    # generate jobs file under this directory\n"
+           "   defs.check_job_creation(job_ctrl)\n"
+           "   print(job_ctrl.get_error_msg())\n"
+           "   ...\n"
+           "   job_ctrl = JobCreationCtrl()              # no set_node_path() hence check job creation for all tasks\n"
+           "   job_ctrl.generate_temp_dir()              # automatically generate directory for job file\n"
+           "   defs.check_job_creation(job_ctrl)\n"
+           "   print(job_ctrl.get_error_msg())\n";
+}
+
+const char* DefsDoc::generate_scripts_doc() {
+    return "Automatically generate template `ecf script`_\\ s for this definition\n"
+           "Will automatically add `child command`_\\ s for `event`_\\ s, `meter`_\\ s and `label`_\\ s.\n"
+           "This allows the definition to be refined with out worrying about the scripts.\n"
+           "However it should be noted that, this will create a lot of *duplicated* script contents\n"
+           "i.e in the absence of `event`_\\ s, `meter`_\\ s and `label`_\\ s, most of generated `ecf script`_ files "
+           "will\n"
+           "be the same. Hence should only be used an aid to debugging the definition.\n"
+           "It uses the contents of the definition to parameterise what gets\n"
+           "generated, and the location of the files. Will throw Exceptions for errors.\n"
+           "\nRequires:\n\n"
+           "- ECF_HOME: specified and accessible for all Tasks, otherwise RuntimeError is raised\n"
+           "- ECF_INCLUDE: specifies location for head.h and tail.h includes, will use angle brackets,\n"
+           "               i.e %include <head.h>, if the head.h and tail.h already exist they are used otherwise\n"
+           "               they are generated\n"
+           "\nOptional:\n\n"
+           "- ECF_FILES: If specified, then scripts are generated under this directory otherwise ECF_HOME is used.\n"
+           "             The missing directories are automatically created.\n"
+           "- ECF_CLIENT_EXE_PATH: if specified child command will use this, otherwise will use ecflow_client\n"
+           "                       and assume this accessible on the path.\n"
+           "- ECF_DUMMY_TASK: Will not generated scripts for this task.\n"
+           "- SLEEP: Uses this variable to delay time between calls to child commands, if not specified uses delay of "
+           "one second\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   defs = ecflow.Defs()\n"
+           "   suite = defs.add_suite('s1')\n"
+           "   suite.add_variable('ECF_HOME','/user/var/home')\n"
+           "   suite.add_variable('ECF_INCLUDE','/user/var/home/includes')\n"
+           "   for i in range(1,7) :\n"
+           "      fam = suite.add_family('f' + str(i))\n"
+           "      for t in ( 'a', 'b', 'c', 'd', 'e' ) :\n"
+           "        fam.add_task(t);\n"
+           "   defs.generate_scripts()   # generate '.ecf' and head.h/tail.h if required\n";
+}
+
+const char* DefsDoc::check() {
+    return "Check `trigger`_ and `complete expression`_\\ s and `limit`_\\ s\n\n"
+           "* Client Side: The client side can specify externs. Hence all node path references\n"
+           "  in `trigger`_ expressions, and `inlimit`_ references to `limit`_\\ s, that are\n"
+           "  unresolved and which do *not* appear in `extern`_\\ s are reported as errors\n"
+           "* Server Side: The server does not store externs. Hence all unresolved references\n"
+           "  are reported as errors\n\n"
+           "Returns a non empty string for any errors or warning\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   # Client side\n"
+           "   defs = Defs('my.def')        # Load my.def from disk\n"
+           "   ....\n"
+           "   print(defs.check()) # do the check\n"
+           "\n"
+           "   # Server Side\n"
+           "   try:\n"
+           "       ci = Client()             # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       print(ci.check('/suite'))\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
+
+const char* DefsDoc::simulate() {
+    return "Simulates a suite definition, allowing you predict/verify the behaviour of your suite in few seconds\n\n"
+           "The simulator will analyse the definition, and simulate the ecflow server.\n"
+           "Allowing time dependencies that span several months, to be simulated in a few seconds.\n"
+           "Ecflow allows the use of verify attributes. This example show how we can verify the number of times\n"
+           "a task should run, given a start(optional) and end time(optional):\n\n"
+           ".. code-block:: shell\n\n"
+           "  suite cron3              # use real clock otherwise clock starts when the simulations starts.\n"
+           "     clock real  1.1.2006  # define a start date for deterministic behaviour\n"
+           "     endclock   13.1.2006  # When to finish. end clock is *only* used for the simulator\n"
+           "     family cronFamily\n"
+           "        task t\n"
+           "           cron -d 10,11,12   10:00 11:00 01:00  # run on 10,11,12 of the month at 10am and 11am\n"
+           "           verify complete:6                     # task should complete 6 times between 1.1.2006 -> "
+           "13.1.2006\n"
+           "     endfamily\n"
+           "  endsuite\n\n"
+           "Please note, for deterministic behaviour, the start and end clock should be specified.\n"
+           "However if no 'endclock' is specified the simulation will assume the following defaults.\n\n"
+           "- No time dependencies: 24 hours\n"
+           "- time || today       : 24 hours\n"
+           "- day                 : 1 week\n"
+           "- date                : 1 month\n"
+           "- cron                : 1 year\n"
+           "- repeat              : 1 year\n\n"
+           "If there no time dependencies with an minute resolution, then the simulator will by default\n"
+           "use 1 hour resolution. This needs to be taken into account when specifying the verify attribute\n"
+           "If the simulation does not complete it creates  defs.flat and  defs.depth files.\n"
+           "This provides clues as to the state of the definition at the end of the simulation\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   defs = Defs('my.def')        # specify the defs we want to simulate\n"
+           "   ....\n"
+           "   theResults = defs.simulate()\n"
+           "   print(theResults)\n";
+}
+
+const char* DefsDoc::get_server_state() {
+    return "Returns the `ecflow_server`_ state: See `server states`_\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   try:\n"
+           "       ci = Client()           # use default host(ECF_HOST) & port(ECF_PORT)\n"
+           "       ci.shutdown_server()\n"
+           "       ci.sync_local()\n"
+           "       assert ci.get_defs().get_server_state() == SState.SHUTDOWN, 'Expected server to be shutdown'\n"
+           "   except RuntimeError, e:\n"
+           "       print(str(e))\n";
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/DefsDoc.hpp 5.13.0-1/libs/pyext/src/ecflow/python/DefsDoc.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/DefsDoc.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/DefsDoc.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,79 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_DefsDoc_HPP
+#define ecflow_python_DefsDoc_HPP
+
+#include <boost/core/noncopyable.hpp>
+
+// ===========================================================================
+// IMPORTANT: These appear as python doc strings.
+//            Additionally they are auto documented using sphinx-poco
+//            Hence the doc strings use reStructuredText markup.
+// ===========================================================================
+class DefsDoc {
+public:
+    DefsDoc()                          = delete;
+    DefsDoc(const DefsDoc&)            = delete;
+    DefsDoc& operator=(const DefsDoc&) = delete;
+
+    static const char* add();
+    static const char* abs_node_path_doc();
+    static const char* part_expression_doc();
+    static const char* expression_doc();
+    static const char* add_trigger_doc();
+    static const char* trigger();
+    static const char* add_variable_doc();
+    static const char* add_label_doc();
+    static const char* add_aviso_doc();
+    static const char* add_mirror_doc();
+    static const char* add_limit_doc();
+    static const char* add_inlimit_doc();
+    static const char* node_doc();
+    static const char* node_container_doc();
+    static const char* submittable_doc();
+    static const char* task_doc();
+    static const char* alias_doc();
+    static const char* family_doc();
+    static const char* add_suite_doc();
+    static const char* add_extern_doc();
+    static const char* add_family_doc();
+    static const char* add_task_doc();
+    static const char* suite_doc();
+    static const char* add_definition_doc();
+    static const char* add_event_doc();
+    static const char* add_meter_doc();
+    static const char* add_date_doc();
+    static const char* add_day_doc();
+    static const char* add_today_doc();
+    static const char* add_time_doc();
+    static const char* add_cron_doc();
+    static const char* add_late_doc();
+    static const char* add_autocancel_doc();
+    static const char* add_autoarchive_doc();
+    static const char* add_autorestore_doc();
+    static const char* add_verify_doc();
+    static const char* add_repeat_date_doc();
+    static const char* add_repeat_datetime_doc();
+    static const char* add_repeat_date_list_doc();
+    static const char* add_repeat_integer_doc();
+    static const char* add_repeat_string_doc();
+    static const char* add_repeat_enumerated_doc();
+    static const char* add_repeat_day_doc();
+    static const char* add_defstatus_doc();
+    static const char* jobgenctrl_doc();
+    static const char* check_job_creation_doc();
+    static const char* generate_scripts_doc();
+    static const char* check();
+    static const char* simulate();
+    static const char* get_server_state();
+};
+
+#endif /* ecflow_python_DefsDoc_HPP */
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/EcfExt.cpp 5.13.0-1/libs/pyext/src/ecflow/python/EcfExt.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/EcfExt.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/EcfExt.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/python.hpp>
+#include <boost/python/docstring_options.hpp>
+
+using namespace boost::python;
+
+void export_Core();
+void export_NodeAttr();
+void export_Node();
+void export_Task();
+void export_SuiteAndFamily();
+void export_Defs();
+void export_Client();
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+BOOST_PYTHON_MODULE(ecflow) {
+    boost::python::docstring_options doc_options(
+        true, // show the docstrings from here
+        true, // show Python signatures.
+        false // Don't mention the C++ method signatures in the generated docstrings
+    );
+    scope().attr("__doc__") = "The ecflow module provides the python bindings/api for creating definition structure "
+                              "and communicating with the server.";
+
+    export_Core();
+    export_NodeAttr();
+    export_Node();
+    export_Task();
+    export_SuiteAndFamily();
+    export_Defs();
+    export_Client();
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/Edit.cpp 5.13.0-1/libs/pyext/src/ecflow/python/Edit.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/Edit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/Edit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,44 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/Edit.hpp"
+
+#include <stdexcept>
+
+#include <boost/python.hpp>
+
+#include "ecflow/python/BoostPythonUtil.hpp"
+
+using namespace boost::python;
+using namespace std;
+namespace bp = boost::python;
+
+Edit::Edit(const boost::python::dict& dict) {
+    BoostPythonUtil::dict_to_str_vec(dict, vec_);
+}
+Edit::Edit(const boost::python::dict& dict, const boost::python::dict& dict2) {
+    BoostPythonUtil::dict_to_str_vec(dict, vec_);
+    BoostPythonUtil::dict_to_str_vec(dict2, vec_);
+}
+
+object Edit::init(boost::python::tuple args, dict kw) {
+    // cout << "Edit::init args: " << len(args) << " kwargs " << len(kw) << "\n";
+    //  args[0] is Edit(i.e self)
+    for (int i = 1; i < len(args); ++i) {
+        if (boost::python::extract<dict>(args[i]).check()) {
+            dict d = boost::python::extract<dict>(args[i]);
+            return args[0].attr("__init__")(d, kw); // calls -> .def(init<dict,dict>() -> Edit(dict,dict)
+        }
+        else
+            throw std::runtime_error("Edit::Edit: only accepts dictionary and key word arguments");
+    }
+    bp::tuple rest(args.slice(1, _));
+    return args[0].attr("__init__")(kw); // calls -> .def(init<dict>() -> Edit(const boost::python::dict& dict)
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/Edit.hpp 5.13.0-1/libs/pyext/src/ecflow/python/Edit.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/Edit.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/Edit.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_Edit_HPP
+#define ecflow_python_Edit_HPP
+
+#include <vector>
+
+#include <boost/python.hpp>
+
+#include "ecflow/attribute/Variable.hpp"
+
+class Edit {
+public:
+    explicit Edit(const boost::python::dict& dict);
+    Edit(const boost::python::dict& dict, const boost::python::dict& dict2);
+    const std::vector<Variable>& variables() const { return vec_; }
+    static std::string to_string() { return "edit"; }
+    static boost::python::object init(boost::python::tuple args, boost::python::dict kw);
+
+private:
+    std::vector<Variable> vec_;
+};
+
+#endif /* ecflow_python_Edit_HPP */
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ExportClient.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ExportClient.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ExportClient.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ExportClient.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,769 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <algorithm> // for std::transform
+
+#include <boost/python.hpp>
+
+#include "ecflow/base/WhyCmd.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/client/UrlCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/ClientDoc.hpp"
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/Openssl.hpp"
+#endif
+
+using namespace boost::python;
+using namespace std;
+namespace bp = boost::python;
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+
+void set_host_port(ClientInvoker* self, const std::string& host, int port) {
+    self->set_host_port(host, ecf::convert_to<std::string>(port));
+}
+
+std::string version(ClientInvoker* self) {
+    return ecf::Version::raw();
+}
+std::string server_version(ClientInvoker* self) {
+    self->server_version();
+    return self->get_string();
+}
+
+const std::string& query(ClientInvoker* self,
+                         const std::string& query_type,
+                         const std::string& path_to_attribute,
+                         const std::string& attribute) {
+    self->query(query_type, path_to_attribute, attribute);
+    return self->get_string();
+}
+const std::string& query1(ClientInvoker* self, const std::string& query_type, const std::string& path_to_attribute) {
+    self->query(query_type, path_to_attribute, "");
+    return self->get_string();
+}
+
+// const std::string& get_log(ClientInvoker* self) { self->getLog(); return self->get_string();}
+
+const std::string& get_log(ClientInvoker* self, int lastLines) {
+    self->getLog(lastLines);
+    return self->get_string();
+}
+
+const std::string& edit_script_edit(ClientInvoker* self, const std::string& absNodePath) {
+    self->edit_script_edit(absNodePath);
+    return self->get_string();
+}
+
+const std::string& edit_script_preprocess(ClientInvoker* self, const std::string& absNodePath) {
+    self->edit_script_preprocess(absNodePath);
+    return self->get_string();
+}
+
+int edit_script_submit(ClientInvoker* self,
+                       const std::string& absNodePath,
+                       const bp::list& name_values,
+                       const bp::list& lines,
+                       bool alias = false,
+                       bool run   = true) {
+    std::vector<std::string> file_contents;
+    BoostPythonUtil::list_to_str_vec(lines, file_contents);
+
+    std::vector<std::string> namv;
+    BoostPythonUtil::list_to_str_vec(name_values, namv);
+    NameValueVec used_variables;
+    char sep = '=';
+    for (size_t i = 0; i < namv.size(); ++i) {
+        string::size_type pos = namv[i].find(sep);
+        used_variables.push_back(std::make_pair(namv[i].substr(0, pos - 1), namv[i].substr(pos + 1, namv[i].length())));
+    }
+    return self->edit_script_submit(absNodePath, used_variables, file_contents, alias, run);
+}
+
+namespace /* __ANONYMOUS__ */ {
+
+boost::python::object convert_to_pyobject(const std::string& s, bool as_bytes) {
+    boost::python::object result;
+    if (as_bytes) {
+        result = boost::python::object(boost::python::handle<>(PyBytes_FromObject(
+            PyMemoryView_FromMemory(const_cast<char*>(s.data()), static_cast<ssize_t>(s.size()), PyBUF_READ))));
+    }
+    else {
+        result = boost::python::object(
+            boost::python::handle<>(PyUnicode_FromStringAndSize(s.data(), static_cast<ssize_t>(s.size()))));
+    }
+    return result;
+}
+
+} // namespace
+
+boost::python::object get_file(ClientInvoker* self,
+                               const std::string& absNodePath,
+                               const std::string& file_type = "script",
+                               const std::string& max_lines = "10000",
+                               bool as_bytes                = false) {
+    self->file(absNodePath, file_type, max_lines);
+    const std::string& s = self->get_string();
+
+    return convert_to_pyobject(s, as_bytes);
+}
+
+/// Set the CLI to enable output to standard out
+class CliSetter {
+public:
+    explicit CliSetter(ClientInvoker* self) : _self(self) { self->set_cli(true); }
+    ~CliSetter() { _self->set_cli(false); }
+
+private:
+    ClientInvoker* _self;
+};
+
+const std::string& stats(ClientInvoker* self, bool to_stdout = true) {
+    self->stats();
+    if (to_stdout) {
+        std::cout << self->server_reply().get_string() << std::endl;
+    }
+    return self->server_reply().get_string();
+}
+BOOST_PYTHON_FUNCTION_OVERLOADS(stats_overloads, stats, 1, 2)
+
+void stats_reset(ClientInvoker* self) {
+    self->stats_reset();
+}
+bp::list suites(ClientInvoker* self) {
+    self->suites();
+    const std::vector<std::string>& the_suites = self->server_reply().get_string_vec();
+    bp::list list;
+    size_t the_size = the_suites.size();
+    for (size_t i = 0; i < the_size; i++)
+        list.append(the_suites[i]);
+    return list;
+}
+
+bool news_local(ClientInvoker* self) {
+    self->news_local();
+    return self->get_news();
+}
+
+void free_trigger_dep(ClientInvoker* self, const std::string& path) {
+    self->freeDep(path, true /*trigger*/, false /*all*/, false /*date*/, false /*time*/);
+}
+void free_date_dep(ClientInvoker* self, const std::string& path) {
+    self->freeDep(path, false /*trigger*/, false /*all*/, true /*date*/, false /*time*/);
+}
+void free_time_dep(ClientInvoker* self, const std::string& path) {
+    self->freeDep(path, false /*trigger*/, false /*all*/, false /*date*/, true /*time*/);
+}
+void free_all_dep(ClientInvoker* self, const std::string& path) {
+    self->freeDep(path, false /*trigger*/, true /*all*/, false /*date*/, false /*time*/);
+}
+void free_trigger_dep1(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->freeDep(paths, true /*trigger*/, false /*all*/, false /*date*/, false /*time*/);
+}
+void free_date_dep1(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->freeDep(paths, false /*trigger*/, false /*all*/, true /*date*/, false /*time*/);
+}
+void free_time_dep1(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->freeDep(paths, false /*trigger*/, false /*all*/, false /*date*/, true /*time*/);
+}
+void free_all_dep1(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->freeDep(paths, false /*trigger*/, true /*all*/, false /*date*/, false /*time*/);
+}
+
+void force_state(ClientInvoker* self, const std::string& path, NState::State state) {
+    self->force(path, NState::toString(state), false);
+}
+void force_states(ClientInvoker* self, const bp::list& list, NState::State state) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->force(paths, NState::toString(state), false);
+}
+void force_state_recursive(ClientInvoker* self, const std::string& path, NState::State state) {
+    self->force(path, NState::toString(state), true);
+}
+void force_states_recursive(ClientInvoker* self, const bp::list& list, NState::State state) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->force(paths, NState::toString(state), true);
+}
+void force_event(ClientInvoker* self, const std::string& path, const std::string& set_or_clear) {
+    self->force(path, set_or_clear);
+}
+void force_events(ClientInvoker* self, const bp::list& list, const std::string& set_or_clear) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->force(paths, set_or_clear);
+}
+
+void run(ClientInvoker* self, const std::string& path, bool force) {
+    self->run(path, force);
+}
+void runs(ClientInvoker* self, const bp::list& list, bool force) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->run(paths, force);
+}
+void requeue(ClientInvoker* self, std::string path, const std::string& option) {
+    self->requeue(path, option);
+}
+void requeues(ClientInvoker* self, const bp::list& list, const std::string& option) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->requeue(paths, option);
+}
+void suspend(ClientInvoker* self, const std::string& path) {
+    self->suspend(path);
+}
+void suspends(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->suspend(paths);
+}
+void resume(ClientInvoker* self, const std::string& path) {
+    self->resume(path);
+}
+void resumes(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->resume(paths);
+}
+void archive(ClientInvoker* self, const std::string& path) {
+    self->archive(path);
+}
+void archives(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->archive(paths);
+}
+void restore(ClientInvoker* self, const std::string& path) {
+    self->restore(path);
+}
+void restores(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->restore(paths);
+}
+void the_status(ClientInvoker* self, const std::string& path) {
+    self->status(path);
+}
+void statuss(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->status(paths);
+}
+void do_kill(ClientInvoker* self, const std::string& path) {
+    self->kill(path);
+}
+void do_kills(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->kill(paths);
+}
+const std::string& check(ClientInvoker* self, const std::string& node_path) {
+    self->check(node_path);
+    return self->get_string();
+}
+const std::string& checks(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->check(paths);
+    return self->get_string();
+}
+
+void delete_node(ClientInvoker* self, const bp::list& list, bool force) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->delete_nodes(paths, force);
+}
+
+void ch_suites(ClientInvoker* self) {
+    CliSetter cli(self);
+    self->ch_suites();
+}
+void ch_register(ClientInvoker* self, bool auto_add_new_suites, const bp::list& list) {
+    std::vector<std::string> suites;
+    BoostPythonUtil::list_to_str_vec(list, suites);
+    self->ch_register(auto_add_new_suites, suites);
+}
+
+void ch_add(ClientInvoker* self, int client_handle, const bp::list& list) {
+    std::vector<std::string> suites;
+    BoostPythonUtil::list_to_str_vec(list, suites);
+    self->ch_add(client_handle, suites);
+}
+void ch1_add(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> suites;
+    BoostPythonUtil::list_to_str_vec(list, suites);
+    self->ch1_add(suites);
+}
+
+void ch_remove(ClientInvoker* self, int client_handle, const bp::list& list) {
+    std::vector<std::string> suites;
+    BoostPythonUtil::list_to_str_vec(list, suites);
+    self->ch_remove(client_handle, suites);
+}
+void ch1_remove(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> suites;
+    BoostPythonUtil::list_to_str_vec(list, suites);
+    self->ch1_remove(suites);
+}
+
+/// Need to provide override since the boolean argument is optional.
+/// This saves on client python code, on having to specify the optional arg
+void replace_1(ClientInvoker* self, const std::string& absNodePath, defs_ptr client_defs) {
+    self->replace_1(absNodePath, client_defs);
+}
+void replace_2(ClientInvoker* self, const std::string& absNodePath, const std::string& path_to_client_defs) {
+    self->replace(absNodePath, path_to_client_defs);
+}
+
+void order(ClientInvoker* self, const std::string& absNodePath, const std::string& the_order) {
+    self->order(absNodePath, the_order);
+}
+
+void alters(ClientInvoker* self,
+            const bp::list& list,
+            const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+            const std::string& attrType,
+            const std::string& name  = "",
+            const std::string& value = "") {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->check(paths);
+    self->alter(paths, alterType, attrType, name, value);
+}
+void alter(ClientInvoker* self,
+           const std::string& path,
+           const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
+           const std::string& attrType,
+           const std::string& name  = "",
+           const std::string& value = "") {
+    self->alter(path, alterType, attrType, name, value);
+}
+
+void alter_sorts(ClientInvoker* self, const bp::list& list, const std::string& attribute_name, bool recursive = true) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->check(paths);
+    self->alter_sort(paths, attribute_name, recursive);
+}
+void alter_sort(ClientInvoker* self,
+                const std::string& path,
+                const std::string& attribute_name,
+                bool recursive = true) {
+    self->alter_sort(std::vector<std::string>(1, path), attribute_name, recursive);
+}
+
+void set_child_pid(ClientInvoker* self, int pid) {
+    self->set_child_pid(ecf::convert_to<std::string>(pid));
+}
+
+void set_child_init_add_vars(ClientInvoker* self, const bp::dict& dict) {
+    std::vector<std::pair<std::string, std::string>> vars;
+    BoostPythonUtil::dict_to_str_vec(dict, vars);
+
+    std::vector<Variable> vec;
+    std::transform(vars.begin(),
+                   vars.end(),
+                   std::back_inserter(vec),
+                   [](const std::pair<std::string, std::string>& var) { return Variable(var.first, var.second); });
+
+    self->set_child_init_add_vars(vec);
+}
+
+void set_child_init_add_vars2(ClientInvoker* self, const bp::list& dict) {
+    std::vector<Variable> vec;
+    BoostPythonUtil::list_to_str_vec(dict, vec);
+    self->set_child_init_add_vars(vec);
+}
+
+void set_child_complete_del_vars(ClientInvoker* self, const bp::list& dict) {
+    std::vector<std::string> vars;
+    BoostPythonUtil::list_to_str_vec(dict, vars);
+    self->set_child_complete_del_vars(vars);
+}
+
+// Context mgr. The expression is evaluated and should result in an object called a ``context manager''
+// with expression [as variable]:
+//    with-block
+//
+// . The context manager must have __enter__() and __exit__() methods.
+// . The context manager's __enter__() method is called.
+//   The value returned is assigned to VAR.
+//   If no 'as VAR' clause is present, the value is simply discarded.
+// . The code in BLOCK is executed.
+// . If BLOCK raises an exception, the __exit__(type, value, traceback)
+//   is called with the exception details, the same values returned by sys.exc_info().
+//   The method's return value controls whether the exception is re-raised:
+//    any false value re-raises the exception, and True will result in suppressing it.
+//    You'll only rarely want to suppress the exception, because if you do the author
+//    of the code containing the 'with' statement will never realize anything went wrong.
+// .  If BLOCK didn't raise an exception, the __exit__() method is still called, but type, value, and traceback are all
+// None.
+//
+std::shared_ptr<ClientInvoker> client_enter(std::shared_ptr<ClientInvoker> self) {
+    return self;
+}
+bool client_exit(std::shared_ptr<ClientInvoker> self,
+                 const bp::object& type,
+                 const bp::object& value,
+                 const bp::object& traceback) {
+    self->ch1_drop();
+    return false;
+}
+
+const std::vector<Zombie>& zombieGet(ClientInvoker* self, int pid) {
+    self->zombieGet();
+    return self->server_reply().zombies();
+}
+
+void zombieFobCli(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->zombieFobCliPaths(paths);
+}
+void zombieFailCli(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->zombieFailCliPaths(paths);
+}
+void zombieAdoptCli(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->zombieAdoptCliPaths(paths);
+}
+void zombieBlockCli(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->zombieBlockCliPaths(paths);
+}
+void zombieRemoveCli(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->zombieRemoveCliPaths(paths);
+}
+void zombieKillCli(ClientInvoker* self, const bp::list& list) {
+    std::vector<std::string> paths;
+    BoostPythonUtil::list_to_str_vec(list, paths);
+    self->zombieKillCliPaths(paths);
+}
+
+void export_Client() {
+    // Need std::shared_ptr<ClientInvoker>, to add support for with( __enter__,__exit__)
+    class_<ClientInvoker, std::shared_ptr<ClientInvoker>, boost::noncopyable>("Client", ClientDoc::class_client())
+        .def(init<std::string>() /* host:port      */)
+        .def(init<std::string, std::string>() /* host, port      */)
+        .def(init<std::string, int>() /* host, port(int) */)
+        .def("__enter__", &client_enter) // allow with statement
+        .def("__exit__", &client_exit)   // allow with statement, remove last handle
+        .def("version", &version, "Returns the current client version")
+        .def("set_user_name",
+             &ClientInvoker::set_user_name,
+             "set user name. A password must be provided in the file <host>.<port>.ecf.custom_passwd")
+        .def("server_version",
+             &server_version,
+             "Returns the server version, can throw for old servers, that did not implement this request.")
+        .def("set_host_port", &ClientInvoker::set_host_port, ClientDoc::set_host_port())
+        .def("set_host_port", &ClientInvoker::set_hostport)
+        .def("set_host_port", &set_host_port)
+        .def("get_host",
+             &ClientInvoker::host,
+             return_value_policy<copy_const_reference>(),
+             "Return the host, assume set_host_port() has been set, otherwise return localhost")
+        .def("get_port",
+             &ClientInvoker::port,
+             return_value_policy<copy_const_reference>(),
+             "Return the port, assume set_host_port() has been set. otherwise returns 3141")
+        .def("set_retry_connection_period",
+             &ClientInvoker::set_retry_connection_period,
+             ClientDoc::set_retry_connection_period())
+        .def("set_connection_attempts", &ClientInvoker::set_connection_attempts, ClientDoc::set_connection_attempts())
+        .def("set_auto_sync",
+             &ClientInvoker::set_auto_sync,
+             "If true automatically sync with local definition after each call.")
+        .def("is_auto_sync_enabled", &ClientInvoker::is_auto_sync_enabled, "Returns true if automatic syncing enabled")
+        .def("get_defs", &ClientInvoker::defs, ClientDoc::get_defs())
+        .def("reset", &ClientInvoker::reset, "reset client definition, and handle number")
+        .def("in_sync", &ClientInvoker::in_sync, ClientDoc::in_sync())
+        .def("get_log", &get_log, return_value_policy<copy_const_reference>(), ClientDoc::get_log())
+        .def("edit_script_edit",
+             &edit_script_edit,
+             return_value_policy<copy_const_reference>(),
+             ClientDoc::edit_script_edit())
+        .def("edit_script_preprocess",
+             &edit_script_preprocess,
+             return_value_policy<copy_const_reference>(),
+             ClientDoc::edit_script_preprocess())
+        .def("edit_script_submit", &edit_script_submit, ClientDoc::edit_script_submit())
+        .def("new_log", &ClientInvoker::new_log, (bp::arg("path") = ""), ClientDoc::new_log())
+        .def("clear_log", &ClientInvoker::clearLog, ClientDoc::clear_log())
+        .def("flush_log", &ClientInvoker::flushLog, ClientDoc::flush_log())
+        .def("log_msg", &ClientInvoker::logMsg, ClientDoc::log_msg())
+        .def("restart_server", &ClientInvoker::restartServer, ClientDoc::restart_server())
+        .def("halt_server", &ClientInvoker::haltServer, ClientDoc::halt_server())
+        .def("shutdown_server", &ClientInvoker::shutdownServer, ClientDoc::shutdown_server())
+        .def("terminate_server", &ClientInvoker::terminateServer, ClientDoc::terminate_server())
+        .def("wait_for_server_reply",
+             &ClientInvoker::wait_for_server_reply,
+             (bp::arg("time_out") = 60),
+             ClientDoc::wait_for_server_reply())
+        .def("load",
+             &ClientInvoker::loadDefs,
+             (bp::arg("path_to_defs"),
+              bp::arg("force")      = false,
+              bp::arg("check_only") = false,
+              bp::arg("print")      = false,
+              bp::arg("stats")      = false),
+             ClientDoc::load_defs())
+        .def("load", &ClientInvoker::load, (bp::arg("defs"), bp::arg("force") = false), ClientDoc::load())
+        .def("get_server_defs", &ClientInvoker::getDefs, ClientDoc::get_server_defs())
+        .def("sync_local", &ClientInvoker::sync_local, (bp::arg("sync_suite_clock") = false), ClientDoc::sync())
+        .def("news_local", &news_local, ClientDoc::news())
+        .add_property("changed_node_paths",
+                      bp::range(&ClientInvoker::changed_node_paths_begin, &ClientInvoker::changed_node_paths_end),
+                      ClientDoc::changed_node_paths())
+        .def("suites", &suites, ClientDoc::suites())
+        .def("ch_register", &ch_register, ClientDoc::ch_register())
+        .def("ch_suites", &ch_suites, ClientDoc::ch_suites())
+        .def("ch_handle", &ClientInvoker::client_handle, ClientDoc::ch_register())
+        .def("ch_drop", &ClientInvoker::ch_drop, ClientDoc::ch_drop())
+        .def("ch_drop", &ClientInvoker::ch1_drop)
+        .def("ch_drop_user", &ClientInvoker::ch_drop_user, ClientDoc::ch_drop_user())
+        .def("ch_add", &ch_add, ClientDoc::ch_add())
+        .def("ch_add", &ch1_add)
+        .def("ch_remove", &ch_remove, ClientDoc::ch_remove())
+        .def("ch_remove", &ch1_remove)
+        .def("ch_auto_add", &ClientInvoker::ch_auto_add, ClientDoc::ch_auto_add())
+        .def("ch_auto_add", &ClientInvoker::ch1_auto_add)
+        .def("checkpt",
+             &ClientInvoker::checkPtDefs,
+             (bp::arg("mode")                     = ecf::CheckPt::UNDEFINED,
+              bp::arg("check_pt_interval")        = 0,
+              bp::arg("check_pt_save_alarm_time") = 0),
+             ClientDoc::checkpt())
+        .def("restore_from_checkpt", &ClientInvoker::restoreDefsFromCheckPt, ClientDoc::restore_from_checkpt())
+        .def("reload_wl_file", &ClientInvoker::reloadwsfile, ClientDoc::reload_wl_file())
+        .def("reload_passwd_file", &ClientInvoker::reloadpasswdfile, "reload the passwd file. <host>.<port>.ecf.passwd")
+        .def("reload_custom_passwd_file",
+             &ClientInvoker::reloadcustompasswdfile,
+             "reload the custom passwd file. <host>.<port>.ecf.custom_passwd. For users using ECF_USER or --user or "
+             "set_user_name()")
+        .def("requeue", &requeue, (bp::arg("abs_node_path"), bp::arg("option") = ""), ClientDoc::requeue())
+        .def("requeue", &requeues, (bp::arg("paths"), bp::arg("option") = ""))
+        .def("free_trigger_dep", &free_trigger_dep, ClientDoc::free_trigger_dep())
+        .def("free_trigger_dep", &free_trigger_dep1)
+        .def("free_date_dep", &free_date_dep, ClientDoc::free_date_dep())
+        .def("free_date_dep", &free_date_dep1)
+        .def("free_time_dep", &free_time_dep, ClientDoc::free_time_dep())
+        .def("free_time_dep", &free_time_dep1)
+        .def("free_all_dep", &free_all_dep, ClientDoc::free_all_dep())
+        .def("free_all_dep", &free_all_dep1)
+        .def("ping", &ClientInvoker::pingServer, ClientDoc::ping())
+        .def("stats", &stats, stats_overloads(args("to_stdout"), ClientDoc::stats())[return_value_policy<copy_const_reference>()])
+        .def("stats_reset", &stats_reset, ClientDoc::stats_reset())
+        .def("get_file",
+             &get_file,
+             (bp::arg("task"), bp::arg("type") = "script", bp::arg("max_lines") = "10000", bp::arg("as_bytes") = false),
+             ClientDoc::get_file())
+        .def("plug", &ClientInvoker::plug, ClientDoc::plug())
+        .def("query", &query, return_value_policy<copy_const_reference>(), ClientDoc::query())
+        .def("query", &query1, return_value_policy<copy_const_reference>(), ClientDoc::query())
+        .def("alter",
+             &alters,
+             (bp::arg("paths"),
+              bp::arg("alter_type"),
+              bp::arg("attribute_type"),
+              bp::arg("name")  = "",
+              bp::arg("value") = ""),
+             ClientDoc::alter())
+        .def("alter",
+             &alter,
+             (bp::arg("abs_node_path"),
+              bp::arg("alter_type"),
+              bp::arg("attribute_type"),
+              bp::arg("name")  = "",
+              bp::arg("value") = ""))
+        .def("sort_attributes",
+             &alter_sort,
+             (bp::arg("abs_node_path"), bp::arg("attribute_name"), bp::arg("recursive") = true))
+        .def(
+            "sort_attributes", &alter_sorts, (bp::arg("paths"), bp::arg("attribute_name"), bp::arg("recursive") = true))
+        .def("force_event", &force_event, ClientDoc::force_event())
+        .def("force_event", &force_events)
+        .def("force_state", &force_state, ClientDoc::force_state())
+        .def("force_state", &force_states)
+        .def("force_state_recursive", &force_state_recursive, ClientDoc::force_state_recursive())
+        .def("force_state_recursive", &force_states_recursive)
+        .def("replace", &ClientInvoker::replace, ClientDoc::replace())
+        .def("replace", &ClientInvoker::replace_1)
+        .def("replace", &replace_1)
+        .def("replace", &replace_2)
+        .def("order", &order, ClientDoc::order())
+        .def("group", &ClientInvoker::group, ClientDoc::group())
+        .def("begin_suite",
+             &ClientInvoker::begin,
+             (bp::arg("suite_name"), bp::arg("force") = false),
+             ClientDoc::begin_suite())
+        .def("begin_all_suites", &ClientInvoker::begin_all_suites, (bp::arg("force") = false), ClientDoc::begin_all())
+        .def("job_generation", &ClientInvoker::job_gen, ClientDoc::job_gen())
+        .def("run", &run, ClientDoc::run())
+        .def("run", &runs)
+        .def("check", &check, return_value_policy<copy_const_reference>(), ClientDoc::check())
+        .def("check", &checks, return_value_policy<copy_const_reference>())
+        .def("kill", &do_kill, ClientDoc::kill())
+        .def("kill", &do_kills)
+        .def("status", &the_status, ClientDoc::status())
+        .def("status", &statuss)
+        .def("suspend", &suspend, ClientDoc::suspend())
+        .def("suspend", &suspends)
+        .def("resume", &resume, ClientDoc::resume())
+        .def("resume", &resumes)
+        .def("archive", &archive, ClientDoc::archive())
+        .def("archive", &archives)
+        .def("restore", &restore, ClientDoc::restore())
+        .def("restore", &restores)
+        .def("delete",
+             &ClientInvoker::delete_node,
+             (bp::arg("abs_node_path"), bp::arg("force") = false),
+             ClientDoc::delete_node())
+        .def("delete", &delete_node, (bp::arg("paths"), bp::arg("force") = false))
+        .def("delete_all", &ClientInvoker::delete_all, (bp::arg("force") = false), ClientDoc::delete_all())
+        .def("debug_server_on",
+             &ClientInvoker::debug_server_on,
+             "Enable server debug, Will dump to standard out on server host.")
+        .def("debug_server_off", &ClientInvoker::debug_server_off, "Disable server debug")
+
+        .def("debug", &ClientInvoker::debug, "enable/disable client api debug")
+
+#ifdef ECF_OPENSSL
+        .def("enable_ssl", &ClientInvoker::enable_ssl, ecf::Openssl::ssl_info())
+        .def("disable_ssl", &ClientInvoker::disable_ssl, ecf::Openssl::ssl_info())
+#endif
+        .def("zombie_get", &zombieGet, return_value_policy<copy_const_reference>())
+        .def("zombie_fob", &ClientInvoker::zombieFobCli)
+        .def("zombie_fail", &ClientInvoker::zombieFailCli)
+        .def("zombie_adopt", &ClientInvoker::zombieAdoptCli)
+        .def("zombie_block", &ClientInvoker::zombieBlockCli)
+        .def("zombie_remove", &ClientInvoker::zombieRemoveCli)
+        .def("zombie_kill", &ClientInvoker::zombieKillCli)
+        .def("zombie_fob", &zombieFobCli)
+        .def("zombie_fail", &zombieFailCli)
+        .def("zombie_adopt", &zombieAdoptCli)
+        .def("zombie_block", &zombieBlockCli)
+        .def("zombie_remove", &zombieRemoveCli)
+        .def("zombie_kill", &zombieKillCli)
+
+        .def("set_child_path", &ClientInvoker::set_child_path, ClientDoc::set_child_path())
+        .def("set_child_password", &ClientInvoker::set_child_password, ClientDoc::set_child_password())
+        .def("set_child_pid", &ClientInvoker::set_child_pid, ClientDoc::set_child_pid())
+        .def("set_child_pid", &set_child_pid, ClientDoc::set_child_pid())
+        .def("set_child_try_no", &ClientInvoker::set_child_try_no, ClientDoc::set_child_try_no())
+        .def("set_child_timeout", &ClientInvoker::set_child_timeout, ClientDoc::set_child_timeout())
+        .def("set_child_init_add_vars", &set_child_init_add_vars, ClientDoc::set_child_init_add_vars())
+        .def("set_child_init_add_vars", &set_child_init_add_vars2, ClientDoc::set_child_init_add_vars())
+        .def("set_child_complete_del_vars", &set_child_complete_del_vars, ClientDoc::set_child_complete_del_vars())
+
+        .def("set_zombie_child_timeout",
+             &ClientInvoker::set_zombie_child_timeout,
+             "Set timeout for zombie child commands,that cannot connect to server, default is 24 hours. The input is "
+             "required to be in seconds")
+        .def("child_init", &ClientInvoker::child_init, "Child command,notify server job has started")
+        .def("child_abort",
+             &ClientInvoker::child_abort,
+             (bp::arg("reason") = ""),
+             "Child command,notify server job has aborted, can provide an optional reason")
+        .def("child_event",
+             &ClientInvoker::child_event,
+             (bp::arg("event_name"), bp::arg("value") = true),
+             "Child command,notify server event occurred, requires the event name")
+        .def("child_meter",
+             &ClientInvoker::child_meter,
+             "Child command,notify server meter changed, requires meter name and value")
+        .def("child_label",
+             &ClientInvoker::child_label,
+             "Child command,notify server label changed, requires label name, and new value")
+        .def("child_wait", &ClientInvoker::child_wait, "Child command,wait for expression to come true")
+        .def("child_queue",
+             &ClientInvoker::child_queue,
+             (bp::arg("queue_name"), bp::arg("action"), bp::arg("step") = "", bp::arg("path_to_node_with_queue") = ""),
+             "Child command,active:return current step as string, then increment index, requires queue name, and "
+             "optionally path to node with the queue")
+        .def("child_complete", &ClientInvoker::child_complete, "Child command,notify server job has complete");
+
+    class_<WhyCmd, boost::noncopyable>("WhyCmd",
+                                       "The why command reports, the reason why a node is not running.\n\n"
+                                       "It needs the  definition structure and the path to node\n"
+                                       "\nConstructor::\n\n"
+                                       "   WhyCmd(defs, node_path)\n"
+                                       "      defs_ptr  defs   : pointer to a definition structure\n"
+                                       "      string node_path : The node path\n\n"
+                                       "\nExceptions:\n\n"
+                                       "- raises RuntimeError if the definition is empty\n"
+                                       "- raises RuntimeError if the node path is empty\n"
+                                       "- raises RuntimeError if the node path cannot be found in the definition\n"
+                                       "\nUsage::\n\n"
+                                       "   try:\n"
+                                       "      ci = Client()\n"
+                                       "      ci.sync_local()\n"
+                                       "      ask = WhyCmd(ci.get_defs(),'/suite/family')\n"
+                                       "      print(ask.why())\n"
+                                       "   except RuntimeError, e:\n"
+                                       "       print(str(e))\n\n",
+                                       init<defs_ptr, std::string>())
+        .def("why", &WhyCmd::why, "returns a '/n' separated string, with reasons why node is not running");
+
+    class_<UrlCmd, boost::noncopyable>(
+        "UrlCmd",
+        "Executes a command ECF_URL_CMD to display a url.\n\n"
+        "It needs the definition structure and the path to node.\n"
+        "\nConstructor::\n\n"
+        "   UrlCmd(defs, node_path)\n"
+        "      defs_ptr  defs   : pointer to a definition structure\n"
+        "      string node_path : The node path.\n\n"
+        "\nExceptions\n\n"
+        "- raises RuntimeError if the definition is empty\n"
+        "- raises RuntimeError if the node path is empty\n"
+        "- raises RuntimeError if the node path cannot be found in the definition\n"
+        "- raises RuntimeError if ECF_URL_CMD not defined or if variable substitution fails\n"
+        "\nUsage:\n"
+        "Lets assume that the server has the following definition::\n\n"
+        "   suite s\n"
+        "      edit ECF_URL_CMD  \"${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%\"\n"
+        "      edit ECF_URL_BASE \"http://www.ecmwf.int\"\n"
+        "      family f\n"
+        "         task t1\n"
+        "            edit ECF_URL \"publications/manuals/ecflow\"\n"
+        "         task t2\n"
+        "            edit ECF_URL index.html\n\n"
+        "::\n\n"
+        "   try:\n"
+        "      ci = Client()\n"
+        "      ci.sync_local()\n"
+        "      url = UrlCmd(ci.get_defs(),'/suite/family/task')\n"
+        "      print(url.execute())\n"
+        "   except RuntimeError, e:\n"
+        "       print(str(e))\n\n",
+        init<defs_ptr, std::string>())
+        .def("execute", &UrlCmd::execute, "Displays url in the chosen browser");
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ExportCore.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ExportCore.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ExportCore.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ExportCore.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,282 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/python.hpp>
+#include <boost/python/raw_function.hpp>
+
+#include "ecflow/core/CheckPt.hpp"
+#include "ecflow/core/DState.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/SState.hpp"
+#include "ecflow/core/TimeSeries.hpp"
+#include "ecflow/core/TimeSlot.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/Edit.hpp"
+#include "ecflow/python/NodeAttrDoc.hpp"
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+template <class K, class T>
+struct pair_to_tuple
+{
+    typedef pair_to_tuple<K, T> converter;
+    typedef std::pair<K, T> ctype;
+
+    static PyObject* convert(ctype const& v) {
+        using namespace boost::python;
+        return incref(make_tuple(v.first, v.second).ptr());
+    }
+    static void register_to_python() { boost::python::to_python_converter<ctype, converter>(); }
+};
+
+using namespace boost::python;
+using namespace std;
+using namespace ecf;
+
+bool debug_build() {
+#ifdef NDEBUG
+    return false;
+#else
+    return true;
+#endif
+}
+
+void export_Core() {
+    // For use in test only
+    def("debug_build", debug_build);
+
+    // see: https://github.com/boostorg/python/blob/master/test/raw_ctor.cpp
+    // Uses a raw constructor approach to support pass arbitrary number arguments on the python side.
+    // using no_init postpones defining __init__ function until after raw_function for proper overload resolution order,
+    // since later defs get higher priority.
+    class_<Edit>("Edit", NodeAttrDoc::variable_doc(), no_init)
+        .def("__init__", raw_function(&Edit::init, 0)) // raw_constructor -> will call -> def(init<dict>() )
+        .def(init<dict>())                             //
+        .def(init<dict, dict>())                       //
+        .def("__str__", &Edit::to_string)              // __str__
+        ;
+
+    class_<File, boost::noncopyable>("File", "Utility class, Used in test only.", no_init)
+        .def("find_server", &File::find_ecf_server_path, "Provides pathname to the server")
+        .staticmethod("find_server")
+        .def("find_client", &File::find_ecf_client_path, "Provides pathname to the client")
+        .staticmethod("find_client")
+        .def("source_dir", &File::root_source_dir, "Path name to ecflow source directory")
+        .staticmethod("source_dir")
+        .def("build_dir", &File::root_build_dir, "Path name to ecflow build directory")
+        .staticmethod("build_dir");
+
+    enum_<PrintStyle::Type_t>(
+        "Style",
+        "Style is used to control printing output for the definition\n\n"
+        "- DEFS:  This style outputs the definition file in a format that is parse-able.\n"
+        "         and can be re-loaded back into the server.\n"
+        "         Externs are automatically added.\n"
+        "         This excludes the edit history.\n"
+        "- STATE: The output includes additional state information for debug\n"
+        "         This excludes the edit history\n"
+        "- MIGRATE: Output includes structure and state, allow migration to future ecflow versions\n"
+        "         This includes edit history. If file is reloaded no checking is done\n\n"
+        "The following shows a summary of the features associated with each choice\n"
+        "\n"
+        "   ===================== ==== ===== =======\n"
+        "   Functionality         DEFS STATE MIGRATE\n"
+        "   ===================== ==== ===== =======\n"
+        "   Auto generate externs  Yes  Yes   No\n"
+        "   Checking on reload     Yes  Yes   No\n"
+        "   Edit History           No   No    Yes\n"
+        "   Show trigger AST       No   Yes   No\n"
+        "   ===================== ==== ===== =======\n")
+        .value("NOTHING", PrintStyle::NOTHING)
+        .value("DEFS", PrintStyle::DEFS)
+        .value("STATE", PrintStyle::STATE)
+        .value("MIGRATE", PrintStyle::MIGRATE);
+
+    class_<PrintStyle, boost::noncopyable>("PrintStyle",
+                                           "Singleton used to control the print Style. See :py:class:`ecflow.Style`\n\n"
+                                           "\nUsage::\n\n"
+                                           "   old_style = PrintStyle.get_style()\n"
+                                           "   PrintStyle.set_style(PrintStyle.STATE)\n"
+                                           "   ...\n"
+                                           "   print(defs)                     # show the node state\n"
+                                           "   PrintStyle.set_style(old_style) # reset previous style\n",
+                                           no_init)
+        .def("get_style", &PrintStyle::getStyle, "Returns the style, static method")
+        .staticmethod("get_style")
+        .def("set_style", &PrintStyle::setStyle, "Set the style, static method")
+        .staticmethod("set_style");
+
+    enum_<CheckPt::Mode>(
+        "CheckPt",
+        "CheckPt is enum that is used to control check pointing in the `ecflow_server`_\n\n"
+        "- NEVER  : Switches of check pointing\n"
+        "- ON_TIME: `check point`_ file is saved periodically, specified by checkPtInterval. This is the default.\n"
+        "- ALWAYS : `check point`_ file is saved after any state change, *not* recommended for large definitions\n"
+        "- UNDEFINED : None of the the above, used to provide default argument\n")
+        .value("NEVER", CheckPt::NEVER)
+        .value("ON_TIME", CheckPt::ON_TIME)
+        .value("ALWAYS", CheckPt::ALWAYS)
+        .value("UNDEFINED", CheckPt::UNDEFINED);
+
+    class_<Ecf, boost::noncopyable>("Ecf", "Singleton used to control ecf debugging\n\n", no_init)
+        .def("debug_equality", &Ecf::debug_equality, "Returns true if debugging of equality is enabled")
+        .staticmethod("debug_equality")
+        .def("set_debug_equality", &Ecf::set_debug_equality, "Set debugging for equality")
+        .staticmethod("set_debug_equality")
+        .def("debug_level",
+             &Ecf::debug_level,
+             "Returns integer showing debug level. debug_level > 0 will disable some warning messages")
+        .staticmethod("debug_level")
+        .def("set_debug_level",
+             &Ecf::set_debug_level,
+             "Set debug level. debug_level > 0 will disable some warning messages")
+        .staticmethod("set_debug_level");
+
+    enum_<NState::State>(
+        "State",
+        "Each `node`_ can have a status, which reflects the life cycle of a node.\n\n"
+        "It varies as follows:\n\n"
+        "- When the definition file is loaded into the `ecflow_server`_ the `task`_ status is `unknown`_\n"
+        "- After begin command the `task`_ s are either `queued`_, `complete`_, `aborted`_ or `suspended`_ ,\n"
+        "  a suspended task means that the task is really `queued`_ but it must be resumed by\n"
+        "  the user first before it can be `submitted`_. See :py:class:`ecflow.DState`\n"
+        "- Once the `dependencies`_ are resolved a task is submitted and placed into the `submitted`_ state,\n"
+        "  however if the submission fails, the task is placed in a `aborted`_ state.\n"
+        "- On a successful submission the task is placed into the `active`_ state\n"
+        "- Before a job ends, it may send other message to the server such as:\n"
+        "  Set an `event`_, Change a `meter`_, Change a `label`_, send a message to log file\n\n"
+        "Jobs end by becoming either `complete`_ or `aborted`_")
+        .value("unknown", NState::UNKNOWN)
+        .value("complete", NState::COMPLETE)
+        .value("queued", NState::QUEUED)
+        .value("aborted", NState::ABORTED)
+        .value("submitted", NState::SUBMITTED)
+        .value("active", NState::ACTIVE);
+
+    enum_<DState::State>("DState",
+                         "A DState is like a ecflow.State, except for the addition of SUSPENDED\n\n"
+                         "Suspended stops job generation, and hence is an attribute of a Node.\n"
+                         "DState can be used for setting the default state of node when it is\n"
+                         "begun or re queued. DState is used for defining `defstatus`_.\n"
+                         "See :py:class:`ecflow.Node.add_defstatus` and :py:class:`ecflow.Defstatus`\n"
+                         "The default state of a `node`_ is `queued`_.\n"
+                         "\nUsage::\n\n"
+                         "   task = ecflow.Task('t1')\n"
+                         "   task.add_defstatus(ecflow.DState.complete)"
+                         "   task = ecflow.Task('t2')\n"
+                         "   task += Defstatus('complete')\n"
+                         "   task = Task('t3',\n"
+                         "               Defstatus('complete')) # create in place\n")
+        .value("unknown", DState::UNKNOWN)
+        .value("complete", DState::COMPLETE)
+        .value("queued", DState::QUEUED)
+        .value("aborted", DState::ABORTED)
+        .value("submitted", DState::SUBMITTED)
+        .value("suspended", DState::SUSPENDED)
+        .value("active", DState::ACTIVE);
+
+    class_<Defstatus>("Defstatus",
+                      "A `node`_ can be set with a default status other the `queued`_\n\n"
+                      "The default state of a `node`_ is `queued`_.\n"
+                      "This defines the state to take at 'begin' or 're-queue' time\n"
+                      "See :py:class:`ecflow.Node.add_defstatus` and :py:class:`ecflow.DState`\n",
+                      init<DState::State>())
+        .def(init<std::string>()) // constructor
+        .def("state", &Defstatus::state)
+        .def("__str__", &Defstatus::to_string) // __str__
+        ;
+
+    enum_<SState::State>("SState",
+                         "A SState holds the `ecflow_server`_ state\n\n"
+                         "See `server states`_")
+        .value("HALTED", SState::HALTED)
+        .value("SHUTDOWN", SState::SHUTDOWN)
+        .value("RUNNING", SState::RUNNING);
+
+    class_<TimeSlot>("TimeSlot",
+                     "Represents a time slot.\n\n"
+                     "It is typically used as an argument to a :py:class:`TimeSeries` or\n"
+                     "other time dependent attributes of a node.\n"
+                     "\n"
+                     "\nConstructor::\n\n"
+                     "   TimeSlot(hour,min)\n"
+                     "      int hour:   represent an hour:\n"
+                     "      int minute: represents a minute:\n"
+                     "\nUsage::\n\n"
+                     "   ts = TimeSlot(10,11)\n",
+                     init<int, int>())
+        .def("__str__", &TimeSlot::toString)   // __str__
+        .def("__copy__", copyObject<TimeSlot>) // __copy__ uses copy constructor
+        .def(self == self)                     // __eq__
+        .def("hour", &TimeSlot::hour)          // return int
+        .def("minute", &TimeSlot::minute)      // return int
+        .def("empty", &TimeSlot::isNULL)       // return bool
+        ;
+
+    // single slot, | start, finish, incr,  bool relative to suite start
+    class_<TimeSeries>(
+        "TimeSeries",
+        "A TimeSeries can hold a single time slot or a series.\n\n"
+        "Time series can be created relative to the `suite`_ start or start of a repeating node.\n"
+        "A Time series can be used as argument to the :py:class:`ecflow.Time`, :py:class:`ecflow.Today` and "
+        ":py:class:`ecflow.Cron` attributes of a node.\n"
+        "If a time the job takes to complete is longer than the interval, a 'slot' is missed\n"
+        "e.g time 10:00 20:00 01:00, if the 10.00 run takes more than an hour the 11.00 is missed\n\n"
+        "\nConstructor::\n\n"
+        "   TimeSeries(single,relative_to_suite_start)\n"
+        "      TimeSlot single :  A single point in a 24 clock \n"
+        "      optional bool relative_to_suite_start : depend on suite begin time or\n"
+        "                                              start of repeating node. Default is false\n"
+        "\n"
+        "   TimeSeries(hour,minute,relative_to_suite_start)\n"
+        "      int hour   :  hour in 24 clock \n"
+        "      int minute :  minute < 59 \n"
+        "      bool relative_to_suite_start<optional> : depend on suite begin time or\n"
+        "                                              start of repeating node. Default is false\n"
+        "\n"
+        "   TimeSeries(start,finish,increment,relative_to_suite_start)\n"
+        "      start TimeSlot :     The start time  \n"
+        "      finish TimeSlot :    The finish time, when used in a series. This must greater than the start.\n"
+        "      increment TimeSlot : The increment. This must be less that difference between start and finish\n"
+        "      bool relative_to_suite_start<optional> : The time is relative suite start, or start of repeating node.\n"
+        "                                               The default is false\n"
+        "\nExceptions:\n\n"
+        "- Raises IndexError when an invalid time series is specified\n"
+        "\nUsage::\n\n"
+        "   time_series = TimeSeries(TimeSlot(10,11),False)\n",
+        init<TimeSlot, boost::python::optional<bool>>())
+        .def(init<int, int, boost::python::optional<bool>>())
+        .def(init<TimeSlot, TimeSlot, TimeSlot, boost::python::optional<bool>>())
+        .def(self == self)                       // __eq__
+        .def("__str__", &TimeSeries::toString)   // __str__
+        .def("__copy__", copyObject<TimeSeries>) // __copy__ uses copy constructor
+        .def("has_increment",
+             &TimeSeries::hasIncrement,
+             "distinguish between a single time slot and a series. returns true for a series") // false if single time
+                                                                                               // slot
+        .def("start",
+             &TimeSeries::start,
+             return_value_policy<copy_const_reference>(),
+             "returns the start time") // returns a time slot
+        .def("finish",
+             &TimeSeries::finish,
+             return_value_policy<copy_const_reference>(),
+             "returns the finish time if time series specified, else returns a NULL time slot") // returns a time slot
+        .def("incr",
+             &TimeSeries::incr,
+             return_value_policy<copy_const_reference>(),
+             " returns the increment time if time series specified, else returns a NULL time slot") // returns a time
+                                                                                                    // slot
+        .def("relative", &TimeSeries::relative, "returns a boolean where true means that the time series is relative");
+
+    using namespace boost::python;
+    pair_to_tuple<std::string, std::string>::register_to_python();
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ExportDefs.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ExportDefs.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ExportDefs.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ExportDefs.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,369 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include <boost/python.hpp>
+#include <boost/python/raw_function.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/JobCreationCtrl.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/DefsDoc.hpp"
+#include "ecflow/python/Edit.hpp"
+#include "ecflow/python/GlossaryDoc.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace ecf;
+using namespace boost::python;
+using namespace std;
+namespace bp = boost::python;
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+
+void save_as_defs(const Defs& theDefs, const std::string& filename, PrintStyle::Type_t the_style_enum) {
+    PrintStyle style(the_style_enum);
+    std::stringstream ss;
+    ss << theDefs;
+
+    std::string file_creation_error_msg;
+    if (!File::create(filename, ss.str(), file_creation_error_msg)) {
+        std::string error = "save_as_defs failed: ";
+        error += file_creation_error_msg;
+        throw std::runtime_error(error);
+    }
+}
+
+void save_as_defs_1(const Defs& theDefs, const std::string& filename) {
+    save_as_defs(theDefs, filename, PrintStyle::DEFS);
+}
+
+static defs_ptr create_defs(const std::string& file_name) {
+    defs_ptr defs = Defs::create();
+
+    std::string errorMsg, warningMsg;
+    if (!defs->restore(file_name, errorMsg, warningMsg)) {
+        throw std::runtime_error(errorMsg);
+    }
+    if (!warningMsg.empty())
+        std::cerr << warningMsg;
+    return defs;
+}
+
+std::string check_defs(defs_ptr defs) {
+    std::string error_msg;
+    std::string warning_msg;
+    if (defs.get() && !defs->check(error_msg, warning_msg)) {
+        error_msg += "\n";
+        error_msg += warning_msg;
+        return error_msg;
+    }
+    return warning_msg;
+}
+
+void restore_from_checkpt(defs_ptr defs, const std::string& file_name) {
+    defs->restore(file_name);
+}
+
+std::string simulate(defs_ptr defs) {
+    if (defs.get()) {
+        // name output file after name of the first suite
+        std::string defs_filename = "pyext.def";
+        if (!defs->suiteVec().empty()) {
+            defs_filename = (*defs->suiteVec().begin())->name() + ".def";
+        }
+
+        Simulator simulator;
+        std::string errorMsg;
+        if (!simulator.run(*defs, defs_filename, errorMsg)) {
+            return errorMsg;
+        }
+    }
+    return string();
+}
+
+SState::State get_server_state(defs_ptr self) {
+    return self->server().get_state();
+}
+
+/// Since we don't pass in a child pos, the nodes are added to the end
+suite_ptr add_suite(defs_ptr self, suite_ptr s) {
+    self->addSuite(s);
+    return s;
+}
+
+std::vector<task_ptr> get_all_tasks(defs_ptr self) {
+    std::vector<task_ptr> tasks;
+    self->get_all_tasks(tasks);
+    return tasks;
+}
+std::vector<node_ptr> get_all_nodes(defs_ptr self) {
+    std::vector<node_ptr> nodes;
+    self->get_all_nodes(nodes);
+    return nodes;
+}
+
+// Context management, Only used to provide indentation
+defs_ptr defs_enter(defs_ptr self) {
+    return self;
+}
+bool defs_exit(defs_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
+    return false;
+}
+
+std::string check_job_creation(defs_ptr defs, bool throw_on_error, bool verbose) {
+    job_creation_ctrl_ptr jobCtrl = std::make_shared<JobCreationCtrl>();
+    if (verbose)
+        jobCtrl->set_verbose(verbose);
+    defs->check_job_creation(jobCtrl);
+    if (!jobCtrl->get_error_msg().empty() && throw_on_error) {
+        throw std::runtime_error(jobCtrl->get_error_msg());
+    }
+    return jobCtrl->get_error_msg();
+}
+
+// Add  server user variables
+defs_ptr add_variable(defs_ptr self, const std::string& name, const std::string& value) {
+    self->set_server().add_or_update_user_variables(name, value);
+    return self;
+}
+defs_ptr add_variable_int(defs_ptr self, const std::string& name, int value) {
+    self->set_server().add_or_update_user_variables(name, ecf::convert_to<std::string>(value));
+    return self;
+}
+defs_ptr add_variable_var(defs_ptr self, const Variable& var) {
+    self->set_server().add_or_update_user_variables(var.name(), var.theValue());
+    return self;
+}
+defs_ptr add_variable_dict(defs_ptr self, const bp::dict& dict) {
+    std::vector<std::pair<std::string, std::string>> vec;
+    BoostPythonUtil::dict_to_str_vec(dict, vec);
+    std::vector<std::pair<std::string, std::string>>::iterator i;
+    auto vec_end = vec.end();
+    for (i = vec.begin(); i != vec_end; ++i) {
+        self->set_server().add_or_update_user_variables((*i).first, (*i).second);
+    }
+    return self;
+}
+void delete_variable(defs_ptr self, const std::string& name) {
+    self->set_server().delete_user_variable(name);
+}
+
+void sort_attributes(defs_ptr self, ecf::Attr::Type attr) {
+    self->sort_attributes(attr);
+}
+void sort_attributes1(defs_ptr self, ecf::Attr::Type attr, bool recurse) {
+    self->sort_attributes(attr, recurse);
+}
+void sort_attributes2(defs_ptr self, ecf::Attr::Type attr, bool recurse, const bp::list& list) {
+    std::vector<std::string> no_sort;
+    BoostPythonUtil::list_to_str_vec(list, no_sort);
+    self->sort_attributes(attr, recurse, no_sort);
+}
+
+void sort_attributes3(defs_ptr self, const std::string& attribute_name, bool recursive, const bp::list& list) {
+    std::string attribute = attribute_name;
+    boost::algorithm::to_lower(attribute);
+    ecf::Attr::Type attr = Attr::to_attr(attribute_name);
+    if (attr == ecf::Attr::UNKNOWN) {
+        std::stringstream ss;
+        ss << "sort_attributes: the attribute " << attribute_name << " is not valid";
+        throw std::runtime_error(ss.str());
+    }
+    std::vector<std::string> no_sort;
+    BoostPythonUtil::list_to_str_vec(list, no_sort);
+    self->sort_attributes(attr, recursive, no_sort);
+}
+
+// Support sized and Container protocol
+size_t defs_len(defs_ptr self) {
+    return self->suiteVec().size();
+}
+bool defs_container(defs_ptr self, const std::string& name) {
+    return (self->findSuite(name)) ? true : false;
+}
+
+static object do_add(defs_ptr self, const bp::object& arg) {
+    // std::cout << "defs::do_add \n";
+    if (arg.ptr() == object().ptr())
+        return object(self); // *IGNORE* None
+    else if (extract<suite_ptr>(arg).check())
+        self->addSuite(extract<suite_ptr>(arg));
+    else if (extract<dict>(arg).check())
+        add_variable_dict(self, extract<dict>(arg));
+    else if (extract<Edit>(arg).check()) {
+        Edit edit                        = extract<Edit>(arg);
+        const std::vector<Variable>& vec = edit.variables();
+        for (const auto& i : vec)
+            self->set_server().add_or_update_user_variables(i.name(), i.theValue());
+    }
+    else if (extract<bp::list>(arg).check()) {
+        bp::list the_list = extract<bp::list>(arg);
+        int the_list_size = len(the_list);
+        for (int i = 0; i < the_list_size; ++i)
+            (void)do_add(self, the_list[i]); // recursive
+    }
+    else if (extract<Variable>(arg).check()) {
+        Variable var = extract<Variable>(arg);
+        self->set_server().add_or_update_user_variables(var.name(), var.theValue());
+    }
+    else
+        throw std::runtime_error("ExportDefs::add : Unknown type");
+    return object(self);
+}
+
+static object add(bp::tuple args, dict kwargs) {
+    int the_list_size = len(args);
+    defs_ptr self     = extract<defs_ptr>(args[0]); // self
+    if (!self)
+        throw std::runtime_error("ExportDefs::add() : first argument is not a Defs");
+
+    for (int i = 1; i < the_list_size; ++i)
+        (void)do_add(self, args[i]);
+    (void)add_variable_dict(self, kwargs);
+
+    return object(self); // return defs as python object, relies class_<Defs>... for type registration
+}
+
+static object defs_iadd(defs_ptr self, const bp::list& list) {
+    // std::cout << "defs_iadd  list " << self->name() << "\n";
+    int the_list_size = len(list);
+    for (int i = 0; i < the_list_size; ++i)
+        (void)do_add(self, list[i]);
+    return object(self); // return node_ptr as python object, relies class_<Node>... for type registration
+}
+
+static object defs_getattr(defs_ptr self, const std::string& attr) {
+    // cout << "  defs_getattr  self.name() : " << self->name() << "  attr " << attr << "\n";
+    suite_ptr child = self->findSuite(attr);
+    if (child)
+        return object(child);
+
+    Variable var = self->server().findVariable(attr);
+    if (!var.empty())
+        return object(var);
+
+    std::stringstream ss;
+    ss << "ExportDefs::defs_getattr : function of name '" << attr << "' does not exist *OR* suite or defs variable";
+    throw std::runtime_error(ss.str());
+    return object();
+}
+
+object defs_raw_constructor(bp::tuple args, dict kw) {
+    // cout << "defs_raw_constructor  len(args):" << len(args) << endl;
+    // args[0] is Defs(i.e self)
+    bp::list the_list;
+    std::string name;
+    for (int i = 1; i < len(args); ++i) {
+        if (extract<string>(args[i]).check())
+            name = extract<string>(args[i]);
+        else
+            the_list.append(args[i]);
+    }
+    if (!name.empty() && len(the_list) > 0)
+        throw std::runtime_error("defs_raw_constructor: Can't mix string with other arguments. String argument "
+                                 "specifies a path(loads a definition from disk)");
+    return args[0].attr("__init__")(the_list, kw); // calls -> init(list attr, dict kw)
+}
+
+defs_ptr defs_init(bp::list the_list, bp::dict kw) {
+    // cout << " defs_init: the_list: " << len(the_list) << " dict: " << len(kw) << endl;
+    defs_ptr defs = Defs::create();
+    (void)add_variable_dict(defs, kw);
+    (void)defs_iadd(defs, the_list);
+    return defs;
+}
+
+void export_Defs() {
+    class_<Defs, defs_ptr>("Defs", DefsDoc::add_definition_doc(), init<>("Create a empty Defs"))
+        .def("__init__", raw_function(&defs_raw_constructor, 0)) // will call -> task_init
+        .def("__init__", make_constructor(&defs_init))
+        .def("__init__", make_constructor(&create_defs), DefsDoc::add_definition_doc())
+        .def(self == self)                    // __eq__
+        .def("__copy__", copyObject<Defs>)    // __copy__ uses copy constructor
+        .def("__str__", &Defs::toString)      // __str__
+        .def("__enter__", &defs_enter)        // allow with statement, hence indentation support
+        .def("__exit__", &defs_exit)          // allow with statement, hence indentation support
+        .def("__len__", &defs_len)            // Sized protocol
+        .def("__contains__", &defs_container) // Container protocol
+        .def("__iter__", bp::range(&Defs::suite_begin, &Defs::suite_end)) // iterable protocol
+        .def("__getattr__", &defs_getattr) /* Any attempt to resolve a property, method, or field name that doesn't
+                                              actually exist on the object itself will be passed to __getattr__*/
+        .def("__iadd__", &defs_iadd) // defs += [ Suite('s1'), Edit(var='value'), Variable('a','b') [ Suite('t2') ] ]
+        .def("__iadd__", &do_add)    // defs += Suite("s1")
+        .def("__add__", &do_add)
+        .def("add", raw_function(add, 1), DefsDoc::add())
+        .def("add_suite", &add_suite, DefsDoc::add_suite_doc())
+        .def("add_suite", &Defs::add_suite, GlossaryDoc::list())
+        .def("add_extern", &Defs::add_extern, DefsDoc::add_extern_doc())
+        .def("auto_add_externs", &Defs::auto_add_externs, DefsDoc::add_extern_doc())
+        .def("add_variable", &add_variable, DefsDoc::add_variable_doc())
+        .def("add_variable", &add_variable_int)
+        .def("add_variable", &add_variable_var)
+        .def("add_variable", &add_variable_dict)
+        .def("sort_attributes", &sort_attributes)
+        .def("sort_attributes", &sort_attributes1)
+        .def("sort_attributes", &sort_attributes2)
+        .def("sort_attributes",
+             &sort_attributes3,
+             (bp::arg("attribute_type"), bp::arg("recursive") = true, bp::arg("no_sort") = bp::list()))
+        .def("sort_attributes", &Defs::sort_attributes, (bp::arg("attribute_type"), bp::arg("recursive") = true))
+        .def("delete_variable", &delete_variable, "An empty string will delete all user variables")
+        .def("find_suite", &Defs::findSuite, "Given a name, find the corresponding `suite`_")
+        .def("find_abs_node", &Defs::findAbsNode, "Given a path, find the the `node`_")
+        .def("find_node_path",
+             &Defs::find_node_path,
+             "Given a type(suite,family,task) and a name, return path of the first match, otherwise return an empty "
+             "string")
+        .def("find_node", &Defs::find_node, "Given a type(suite,family,task) and a path to a node, return the node.")
+        .def("get_all_nodes", &get_all_nodes, "Returns all the `node`_\\ s in the definition")
+        .def("get_all_tasks", &get_all_tasks, "Returns all the `task`_ nodes")
+        .def("has_time_dependencies",
+             &Defs::hasTimeDependencies,
+             "returns True if the `suite definition`_ has any time `dependencies`_")
+        .def("save_as_checkpt",
+             &Defs::save_as_checkpt,
+             "Save the in memory `suite definition`_ as a `check point`_ file. This includes all node state.")
+        .def("restore_from_checkpt",
+             &restore_from_checkpt,
+             "Restore the `suite definition`_ from a `check point`_ file stored on disk")
+        .def("save_as_defs",
+             &save_as_defs,
+             "Save the in memory `suite definition`_ into a file. The file name must be passed as an argument\n\n")
+        .def("save_as_defs",
+             &save_as_defs_1,
+             "Save the in memory `suite definition`_ into a file. The file name must be passed as an argument\n\n")
+        .def("check", &check_defs, DefsDoc::check())
+        .def("simulate", &simulate, DefsDoc::simulate())
+        .def("check_job_creation",
+             &check_job_creation,
+             (bp::arg("throw_on_error") = false, bp::arg("verbose") = false),
+             DefsDoc::check_job_creation_doc())
+        .def("check_job_creation", &Defs::check_job_creation)
+        .def("generate_scripts", &Defs::generate_scripts, DefsDoc::generate_scripts_doc())
+        .def("get_state", &Defs::state)
+        .def("get_server_state", &get_server_state, DefsDoc::get_server_state())
+        .add_property("suites", bp::range(&Defs::suite_begin, &Defs::suite_end), "Returns a list of `suite`_\\ s")
+        .add_property("externs", bp::range(&Defs::extern_begin, &Defs::extern_end), "Returns a list of `extern`_\\ s")
+        .add_property("user_variables",
+                      bp::range(&Defs::user_variables_begin, &Defs::user_variables_end),
+                      "Returns a list of user defined `variable`_\\ s")
+        .add_property("server_variables",
+                      bp::range(&Defs::server_variables_begin, &Defs::server_variables_end),
+                      "Returns a list of server `variable`_\\ s");
+
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<defs_ptr>(); // needed for mac and boost 1.6
+#endif
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ExportNode.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ExportNode.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ExportNode.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ExportNode.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,782 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include <boost/python.hpp>
+#include <boost/python/raw_function.hpp>
+#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/MiscAttrs.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/node/NodeContainer.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/DefsDoc.hpp"
+#include "ecflow/python/NodeAttrDoc.hpp"
+#include "ecflow/python/NodeUtil.hpp"
+
+using namespace ecf;
+using namespace boost::python;
+using namespace std;
+namespace bp = boost::python;
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+
+Defs* get_defs(node_ptr self) {
+    return self->defs();
+}
+
+node_ptr add_variable(node_ptr self, const std::string& name, const std::string& value) {
+    self->add_variable(name, value);
+    return self;
+}
+node_ptr add_variable_int(node_ptr self, const std::string& name, int value) {
+    self->add_variable_int(name, value);
+    return self;
+}
+node_ptr add_variable_var(node_ptr self, const Variable& var) {
+    self->addVariable(var);
+    return self;
+}
+
+node_ptr add_event(node_ptr self, const Event& e) {
+    self->addEvent(e);
+    return self;
+}
+node_ptr add_event_1(node_ptr self, int number) {
+    self->addEvent(Event(number));
+    return self;
+}
+node_ptr add_event_2(node_ptr self, int number, const std::string& name) {
+    self->addEvent(Event(number, name));
+    return self;
+}
+node_ptr add_event_3(node_ptr self, const std::string& name) {
+    self->addEvent(Event(name));
+    return self;
+}
+
+node_ptr add_meter(node_ptr self, const Meter& m) {
+    self->addMeter(m);
+    return self;
+}
+node_ptr add_meter_1(node_ptr self, const std::string& meter_name, int min, int max, int color_change) {
+    self->addMeter(Meter(meter_name, min, max, color_change));
+    return self;
+}
+node_ptr add_meter_2(node_ptr self, const std::string& meter_name, int min, int max) {
+    self->addMeter(Meter(meter_name, min, max));
+    return self;
+}
+
+node_ptr add_queue(node_ptr self, const QueueAttr& m) {
+    self->add_queue(m);
+    return self;
+}
+node_ptr add_queue1(node_ptr self, const std::string& name, const bp::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    QueueAttr queue_attr(name, vec);
+    self->add_queue(queue_attr);
+    return self;
+}
+
+node_ptr add_generic(node_ptr self, const GenericAttr& m) {
+    self->add_generic(m);
+    return self;
+}
+node_ptr add_generic1(node_ptr self, const std::string& name, const bp::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    GenericAttr attr(name, vec);
+    self->add_generic(attr);
+    return self;
+}
+
+node_ptr add_label(node_ptr self, const std::string& name, const std::string& value) {
+    self->addLabel(Label(name, value));
+    return self;
+}
+node_ptr add_label_1(node_ptr self, const Label& label) {
+    self->addLabel(label);
+    return self;
+}
+
+node_ptr add_aviso(node_ptr self, const ecf::AvisoAttr& attr) {
+    self->addAviso(attr);
+    return self;
+}
+
+node_ptr add_mirror(node_ptr self, const ecf::MirrorAttr& attr) {
+    self->addMirror(attr);
+    return self;
+}
+
+node_ptr add_limit(node_ptr self, const std::string& name, int limit) {
+    self->addLimit(Limit(name, limit));
+    return self;
+}
+node_ptr add_limit_1(node_ptr self, const Limit& limit) {
+    self->addLimit(limit);
+    return self;
+}
+node_ptr add_in_limit(node_ptr self,
+                      const std::string& name,
+                      const std::string& pathToNode,
+                      int tokens,
+                      bool limit_this_node_only) {
+    self->addInLimit(InLimit(name, pathToNode, tokens, limit_this_node_only));
+    return self;
+}
+node_ptr add_in_limit_1(node_ptr self, const InLimit& inlimit) {
+    self->addInLimit(inlimit);
+    return self;
+}
+node_ptr add_time(node_ptr self, int hour, int minute) {
+    self->addTime(ecf::TimeAttr(hour, minute));
+    return self;
+}
+node_ptr add_time_1(node_ptr self, int hour, int minute, bool relative) {
+    self->addTime(ecf::TimeAttr(hour, minute, relative));
+    return self;
+}
+node_ptr add_time_2(node_ptr self, const std::string& ts) {
+    self->addTime(ecf::TimeAttr(TimeSeries::create(ts)));
+    return self;
+}
+node_ptr add_time_3(node_ptr self, const ecf::TimeAttr& ts) {
+    self->addTime(ts);
+    return self;
+}
+node_ptr add_today(node_ptr self, int hour, int minute) {
+    self->addToday(ecf::TodayAttr(hour, minute));
+    return self;
+}
+node_ptr add_today_1(node_ptr self, int hour, int minute, bool relative) {
+    self->addToday(ecf::TodayAttr(hour, minute, relative));
+    return self;
+}
+node_ptr add_today_2(node_ptr self, const std::string& ts) {
+    self->addToday(ecf::TodayAttr(TimeSeries::create(ts)));
+    return self;
+}
+node_ptr add_today_3(node_ptr self, const ecf::TodayAttr& ts) {
+    self->addToday(ts);
+    return self;
+}
+node_ptr add_date(node_ptr self, int day, int month, int year) {
+    self->addDate(DateAttr(day, month, year));
+    return self;
+}
+node_ptr add_date_1(node_ptr self, const DateAttr& d) {
+    self->addDate(d);
+    return self;
+}
+node_ptr add_day(node_ptr self, DayAttr::Day_t day) {
+    self->addDay(DayAttr(day));
+    return self;
+}
+node_ptr add_day_1(node_ptr self, const std::string& day) {
+    self->addDay(DayAttr(DayAttr::getDay(day)));
+    return self;
+}
+node_ptr add_day_2(node_ptr self, const DayAttr& day) {
+    self->addDay(day);
+    return self;
+}
+
+node_ptr add_autocancel(node_ptr self, int days) {
+    self->addAutoCancel(ecf::AutoCancelAttr(days));
+    return self;
+}
+node_ptr add_autocancel_1(node_ptr self, int hour, int min, bool relative) {
+    self->addAutoCancel(ecf::AutoCancelAttr(hour, min, relative));
+    return self;
+}
+node_ptr add_autocancel_2(node_ptr self, const TimeSlot& ts, bool relative) {
+    self->addAutoCancel(ecf::AutoCancelAttr(ts, relative));
+    return self;
+}
+node_ptr add_autocancel_3(node_ptr self, const ecf::AutoCancelAttr& attr) {
+    self->addAutoCancel(attr);
+    return self;
+}
+node_ptr add_autoarchive(node_ptr self, int days, bool idle) {
+    self->add_autoarchive(ecf::AutoArchiveAttr(days, idle));
+    return self;
+}
+node_ptr add_autoarchive_1(node_ptr self, int hour, int min, bool relative, bool idle) {
+    self->add_autoarchive(ecf::AutoArchiveAttr(hour, min, relative, idle));
+    return self;
+}
+node_ptr add_autoarchive_2(node_ptr self, const TimeSlot& ts, bool relative, bool idle) {
+    self->add_autoarchive(ecf::AutoArchiveAttr(ts, relative, idle));
+    return self;
+}
+node_ptr add_autoarchive_3(node_ptr self, const ecf::AutoArchiveAttr& attr) {
+    self->add_autoarchive(attr);
+    return self;
+}
+
+node_ptr add_zombie(node_ptr self, const ZombieAttr& attr) {
+    self->addZombie(attr);
+    return self;
+}
+
+node_ptr add_autorestore(node_ptr self, const ecf::AutoRestoreAttr& attr) {
+    self->add_autorestore(attr);
+    return self;
+}
+node_ptr add_autorestore1(node_ptr self, const bp::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    self->add_autorestore(ecf::AutoRestoreAttr(vec));
+    return self;
+}
+
+node_ptr add_cron(node_ptr self, const ecf::CronAttr& attr) {
+    self->addCron(attr);
+    return self;
+}
+node_ptr add_late(node_ptr self, const ecf::LateAttr& attr) {
+    self->addLate(attr);
+    return self;
+}
+std::string get_state_change_time(node_ptr self, const std::string& format) {
+    if (format == "iso_extended")
+        return to_iso_extended_string(self->state_change_time());
+    else if (format == "iso")
+        return to_iso_string(self->state_change_time());
+    return to_simple_string(self->state_change_time());
+}
+
+node_ptr add_repeat_date(node_ptr self, const RepeatDate& d) {
+    self->addRepeat(d);
+    return self;
+}
+node_ptr add_repeat_datetime(node_ptr self, const RepeatDateTime& d) {
+    self->addRepeat(d);
+    return self;
+}
+node_ptr add_repeat_date_list(node_ptr self, const RepeatDateList& d) {
+    self->addRepeat(d);
+    return self;
+}
+node_ptr add_repeat_integer(node_ptr self, const RepeatInteger& d) {
+    self->addRepeat(d);
+    return self;
+}
+node_ptr add_repeat_string(node_ptr self, const RepeatString& d) {
+    self->addRepeat(d);
+    return self;
+}
+node_ptr add_repeat_enum(node_ptr self, const RepeatEnumerated& d) {
+    self->addRepeat(d);
+    return self;
+}
+node_ptr add_repeat_day(node_ptr self, const RepeatDay& d) {
+    self->addRepeat(d);
+    return self;
+}
+
+void sort_attributes(node_ptr self, ecf::Attr::Type attr) {
+    self->sort_attributes(attr);
+}
+void sort_attributes1(node_ptr self, ecf::Attr::Type attr, bool recursive) {
+    self->sort_attributes(attr, recursive);
+}
+void sort_attributes2(node_ptr self, ecf::Attr::Type attr, bool recursive, const bp::list& list) {
+    std::vector<std::string> no_sort;
+    BoostPythonUtil::list_to_str_vec(list, no_sort);
+    self->sort_attributes(attr, recursive, no_sort);
+}
+
+void sort_attributes3(node_ptr self, const std::string& attribute_name, bool recursive, const bp::list& list) {
+    std::string attribute = attribute_name;
+    boost::algorithm::to_lower(attribute);
+    ecf::Attr::Type attr = Attr::to_attr(attribute_name);
+    if (attr == ecf::Attr::UNKNOWN) {
+        std::stringstream ss;
+        ss << "sort_attributes: the attribute " << attribute_name << " is not valid";
+        throw std::runtime_error(ss.str());
+    }
+    std::vector<std::string> no_sort;
+    BoostPythonUtil::list_to_str_vec(list, no_sort);
+    self->sort_attributes(attr, recursive, no_sort);
+}
+
+std::vector<node_ptr> get_all_nodes(node_ptr self) {
+    std::vector<node_ptr> nodes;
+    self->get_all_nodes(nodes);
+    return nodes;
+}
+
+node_ptr add_trigger(node_ptr self, const std::string& expr) {
+    self->add_trigger(expr);
+    return self;
+}
+node_ptr add_trigger_expr(node_ptr self, const Expression& expr) {
+    self->add_trigger_expr(expr);
+    return self;
+}
+node_ptr add_complete(node_ptr self, const std::string& expr) {
+    self->add_complete(expr);
+    return self;
+}
+node_ptr add_complete_expr(node_ptr self, const Expression& expr) {
+    self->add_complete_expr(expr);
+    return self;
+}
+node_ptr add_part_trigger(node_ptr self, const PartExpression& expr) {
+    self->add_part_trigger(PartExpression(expr));
+    return self;
+}
+node_ptr add_part_trigger_1(node_ptr self, const std::string& expression) {
+    self->add_part_trigger(PartExpression(expression));
+    return self;
+}
+node_ptr add_part_trigger_2(node_ptr self, const std::string& expression, bool and_expr) {
+    self->add_part_trigger(PartExpression(expression, and_expr));
+    return self;
+}
+node_ptr add_part_complete(node_ptr self, const PartExpression& expr) {
+    self->add_part_complete(PartExpression(expr));
+    return self;
+}
+node_ptr add_part_complete_1(node_ptr self, const std::string& expression) {
+    self->add_part_complete(PartExpression(expression));
+    return self;
+}
+node_ptr add_part_complete_2(node_ptr self, const std::string& expression, bool and_expr) {
+    self->add_part_complete(PartExpression(expression, and_expr));
+    return self;
+}
+bool evaluate_trigger(node_ptr self) {
+    Ast* t = self->triggerAst();
+    if (t)
+        return t->evaluate();
+    return false;
+}
+bool evaluate_complete(node_ptr self) {
+    Ast* t = self->completeAst();
+    if (t)
+        return t->evaluate();
+    return false;
+}
+
+node_ptr add_defstatus(node_ptr self, DState::State s) {
+    self->addDefStatus(s);
+    return self;
+}
+node_ptr add_defstatus1(node_ptr self, const Defstatus& ds) {
+    self->addDefStatus(ds.state());
+    return self;
+}
+
+/////////////////////////////////////////////////////////////////////////////////////////
+
+static object do_rshift(node_ptr self, const bp::object& arg) {
+    // std::cout << "do_rshift\n";
+    (void)NodeUtil::do_add(self, arg);
+
+    if (extract<node_ptr>(arg).check()) {
+        NodeContainer* nc = self->isNodeContainer();
+        if (!nc)
+            throw std::runtime_error("ExportNode::do_rshift() : Can only add a child to Suite or Family");
+        node_ptr child = extract<node_ptr>(arg);
+
+        std::vector<node_ptr> children;
+        nc->immediateChildren(children);
+        node_ptr previous_child;
+        for (auto& i : children) {
+            if (previous_child && i == child) {
+                // if existing trigger, add new trigger as AND
+                if (child->get_trigger())
+                    child->add_part_trigger(
+                        PartExpression(previous_child->name() + " == complete", PartExpression::AND));
+                else
+                    child->add_trigger_expr(Expression(previous_child->name() + " == complete"));
+            }
+            if (i->defStatus() != DState::COMPLETE)
+                previous_child = i;
+        }
+    }
+    return object(self);
+}
+static object do_lshift(node_ptr self, const bp::object& arg) {
+    // std::cout << "do_lshift : " << self->name() << "\n"; cout << flush;
+    (void)NodeUtil::do_add(self, arg);
+
+    if (extract<node_ptr>(arg).check()) {
+
+        NodeContainer* nc = self->isNodeContainer();
+        if (!nc)
+            throw std::runtime_error("ExportNode::do_lshift() : Can only add a child to Suite or Family");
+        node_ptr child = extract<node_ptr>(arg);
+
+        std::vector<node_ptr> children;
+        nc->immediateChildren(children);
+        node_ptr previous_child;
+        for (size_t i = 0; i < children.size(); i++) {
+            if (i == 0)
+                continue;
+            if (children[i - 1]->defStatus() != DState::COMPLETE)
+                previous_child = children[i - 1];
+
+            if (previous_child && previous_child != child && children[i] == child) {
+                // if existing trigger, add new trigger as AND
+                if (previous_child->get_trigger())
+                    previous_child->add_part_trigger(
+                        PartExpression(child->name() + " == complete", PartExpression::AND));
+                else
+                    previous_child->add_trigger_expr(Expression(child->name() + " == complete"));
+            }
+        }
+    }
+    return object(self);
+}
+
+static object add(bp::tuple args, bp::dict kwargs) {
+    int the_list_size = len(args);
+    node_ptr self     = extract<node_ptr>(args[0]); // self
+    if (!self)
+        throw std::runtime_error("ExportNode::add() : first argument is not a node");
+
+    for (int i = 1; i < the_list_size; ++i)
+        (void)NodeUtil::do_add(self, args[i]);
+
+    // key word arguments are use for adding variable only
+    (void)NodeUtil::add_variable_dict(self, kwargs);
+
+    return object(self); // return node_ptr as python object, relies class_<Node>... for type registration
+}
+
+static object node_getattr(node_ptr self, const std::string& attr) {
+    // cout << " node_getattr  self.name() : " << self->name() << "  attr " << attr << "\n";
+    size_t pos     = 0;
+    node_ptr child = self->findImmediateChild(attr, pos);
+    if (child) {
+        return object(child);
+    }
+
+    const Variable& var = self->findVariable(attr);
+    if (!var.empty())
+        return object(var);
+
+    const Variable& gvar = self->findGenVariable(attr);
+    if (!gvar.empty())
+        return object(gvar);
+
+    const Event& event = self->findEventByNameOrNumber(attr);
+    if (!event.empty())
+        return object(event);
+
+    const Meter& meter = self->findMeter(attr);
+    if (!meter.empty())
+        return object(meter);
+
+    limit_ptr limit = self->find_limit(attr);
+    if (limit.get())
+        return object(limit);
+
+    std::stringstream ss;
+    ss << "ExportNode::node_getattr: function of name '" << attr
+       << "' does not exist *OR* child node,variable,meter,event or limit on node " << self->absNodePath();
+    throw std::runtime_error(ss.str());
+    return object();
+}
+
+//////////////////////////////////////////////////////////////////////////////////////////////////////////////
+struct null_deleter
+{
+    void operator()(void const*) const {}
+};
+void do_replace_on_server(node_ptr self, ClientInvoker& theClient, bool suspend_node_first, bool force_replace) {
+    // cout << "ExportNode: do_replace_on_server " << self->absNodePath() << "\n";
+    // cout << " suspend_node_first " << suspend_node_first << "\n";
+    // cout << " force_replace  " << force_replace  << "\n";
+
+    // Need to make a defs_ptr from a Defs*  to avoid double delete use null_deletor
+    defs_ptr defs                   = defs_ptr(self->defs(), null_deleter());
+    bool create_parents_as_required = true;
+    if (suspend_node_first)
+        theClient.suspend(self->absNodePath());
+    theClient.replace_1(self->absNodePath(), defs, create_parents_as_required, force_replace); // this can throw
+}
+void replace_on_server(node_ptr self, bool suspend_node_first, bool force_replace) {
+    ClientInvoker theClient; // assume HOST and PORT found from environment
+    do_replace_on_server(self, theClient, suspend_node_first, force_replace);
+}
+void replace_on_server1(node_ptr self,
+                        const std::string& host,
+                        const std::string& port,
+                        bool suspend_node_first,
+                        bool force_replace) {
+    ClientInvoker theClient(host, port);
+    do_replace_on_server(self, theClient, suspend_node_first, force_replace);
+}
+void replace_on_server2(node_ptr self, const std::string& host_port, bool suspend_node_first, bool force_replace) {
+    ClientInvoker theClient(host_port);
+    do_replace_on_server(self, theClient, suspend_node_first, force_replace);
+}
+//////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+void export_Node() {
+    // Turn off proxies by passing true as the NoProxy template parameter.
+    // shared_ptrs don't need proxies because calls on one a copy of the
+    // shared_ptr will affect all of them (duh!).
+    class_<std::vector<node_ptr>>("NodeVec", "Hold a list of Nodes (i.e `suite`_, `family`_ or `task`_\\ s)")
+        .def(vector_indexing_suite<std::vector<node_ptr>, true>());
+
+    class_<Node, boost::noncopyable, node_ptr>("Node", DefsDoc::node_doc(), no_init)
+        .def("name", &Node::name, return_value_policy<copy_const_reference>())
+        .def("add", raw_function(add, 1), DefsDoc::add())  // a.add(b) & a.add([b])
+        .def(self < self)                                  // __lt__
+        .def("__add__", &NodeUtil::do_add, DefsDoc::add()) // a + b
+        .def("__rshift__",
+             &do_rshift) // nc >> a >> b >> c     a + (b.add(Trigger('a==complete')) + (c.add(Trigger('b==complete')))
+        .def("__lshift__",
+             &do_lshift) // nc << a << b << c     (a.add(Trigger('b==complete')) + (b.add(Trigger('c==complete'))) + c
+        .def("__iadd__", &NodeUtil::do_add)    // a += b
+        .def("__iadd__", &NodeUtil::node_iadd) // a += [ b ]
+        .def("__getattr__", &node_getattr)     /* Any attempt to resolve a property, method, or field name that doesn't
+                                                  actually exist on the object itself will be passed to __getattr__*/
+        .def("remove", &Node::remove, "Remove the node from its parent. and returns it")
+        .def("add_trigger", &add_trigger, DefsDoc::add_trigger_doc())
+        .def("add_trigger", &add_trigger_expr)
+        .def("add_complete", &add_complete, DefsDoc::add_trigger_doc())
+        .def("add_complete", &add_complete_expr)
+        .def("add_part_trigger", &add_part_trigger, DefsDoc::add_trigger_doc())
+        .def("add_part_trigger", &add_part_trigger_1)
+        .def("add_part_trigger", &add_part_trigger_2)
+        .def("add_part_complete", &add_part_complete, DefsDoc::add_trigger_doc())
+        .def("add_part_complete", &add_part_complete_1)
+        .def("add_part_complete", &add_part_complete_2)
+        .def("evaluate_trigger", &evaluate_trigger, "evaluate trigger expression")
+        .def("evaluate_complete", &evaluate_complete, "evaluate complete expression")
+        .def("add_variable", &add_variable, DefsDoc::add_variable_doc())
+        .def("add_variable", &add_variable_int)
+        .def("add_variable", &add_variable_var)
+        .def("add_variable", &NodeUtil::add_variable_dict)
+        .def("add_label", &add_label, DefsDoc::add_label_doc())
+        .def("add_label", &add_label_1)
+        .def("add_aviso", &add_aviso, DefsDoc::add_aviso_doc())
+        .def("add_mirror", &add_mirror, DefsDoc::add_mirror_doc())
+        .def("add_limit", &add_limit, DefsDoc::add_limit_doc())
+        .def("add_limit", &add_limit_1)
+        .def("add_inlimit",
+             &add_in_limit,
+             (bp::arg("limit_name"),
+              bp::arg("path_to_node_containing_limit") = "",
+              bp::arg("tokens")                        = 1,
+              bp::arg("limit_this_node_only")          = false),
+             DefsDoc::add_inlimit_doc())
+        .def("add_inlimit", &add_in_limit_1)
+        .def("add_event", &add_event, DefsDoc::add_event_doc())
+        .def("add_event", &add_event_1)
+        .def("add_event", &add_event_2)
+        .def("add_event", &add_event_3)
+        .def("add_meter", &add_meter, DefsDoc::add_meter_doc())
+        .def("add_meter", &add_meter_1)
+        .def("add_meter", &add_meter_2)
+        .def("add_queue", &add_queue)
+        .def("add_queue", &add_queue1)
+        .def("add_generic", &add_generic)
+        .def("add_generic", &add_generic1)
+        .def("add_date", &add_date, DefsDoc::add_date_doc())
+        .def("add_date", &add_date_1)
+        .def("add_day", &add_day, DefsDoc::add_day_doc())
+        .def("add_day", &add_day_1)
+        .def("add_day", &add_day_2)
+        .def("add_today", &add_today, DefsDoc::add_today_doc())
+        .def("add_today", &add_today_1)
+        .def("add_today", &add_today_2)
+        .def("add_today", &add_today_3)
+        .def("add_time", &add_time, DefsDoc::add_time_doc())
+        .def("add_time", &add_time_1)
+        .def("add_time", &add_time_2)
+        .def("add_time", &add_time_3)
+        .def("add_cron", &add_cron, DefsDoc::add_cron_doc())
+        .def("add_late", &add_late, DefsDoc::add_late_doc())
+        .def("add_autocancel", &add_autocancel, DefsDoc::add_autocancel_doc())
+        .def("add_autocancel", &add_autocancel_1)
+        .def("add_autocancel", &add_autocancel_2)
+        .def("add_autocancel", &add_autocancel_3)
+        .def("add_autoarchive",
+             &add_autoarchive,
+             (bp::arg("days"), bp::arg("idle") = false),
+             DefsDoc::add_autoarchive_doc())
+        .def("add_autoarchive",
+             &add_autoarchive_1,
+             (bp::arg("hour"), bp::arg("min"), bp::arg("relative"), bp::arg("idle") = false))
+        .def("add_autoarchive", &add_autoarchive_2, (bp::arg("TimeSlot"), bp::arg("relative"), bp::arg("idle") = false))
+        .def("add_autoarchive", &add_autoarchive_3)
+        .def("add_autorestore", &add_autorestore, DefsDoc::add_autorestore_doc())
+        .def("add_autorestore", &add_autorestore1)
+        .def("add_verify", &Node::addVerify, DefsDoc::add_verify_doc())
+        .def("add_repeat", &add_repeat_date, DefsDoc::add_repeat_date_doc())
+        .def("add_repeat", &add_repeat_datetime, DefsDoc::add_repeat_datetime_doc())
+        .def("add_repeat", &add_repeat_date_list, DefsDoc::add_repeat_date_list_doc())
+        .def("add_repeat", &add_repeat_integer, DefsDoc::add_repeat_integer_doc())
+        .def("add_repeat", &add_repeat_string, DefsDoc::add_repeat_string_doc())
+        .def("add_repeat", &add_repeat_enum, DefsDoc::add_repeat_enumerated_doc())
+        .def("add_repeat", &add_repeat_day, DefsDoc::add_repeat_day_doc())
+        .def("add_defstatus", &add_defstatus, DefsDoc::add_defstatus_doc())
+        .def("add_defstatus", &add_defstatus1, DefsDoc::add_defstatus_doc())
+        .def("add_zombie", &add_zombie, NodeAttrDoc::zombie_doc())
+        .def("delete_variable", &Node::deleteVariable)
+        .def("delete_event", &Node::deleteEvent)
+        .def("delete_meter", &Node::deleteMeter)
+        .def("delete_label", &Node::deleteLabel)
+        .def("delete_queue", &Node::delete_queue)
+        .def("delete_generic", &Node::delete_generic)
+        .def("delete_trigger", &Node::deleteTrigger)
+        .def("delete_complete", &Node::deleteComplete)
+        .def("delete_repeat", &Node::deleteRepeat)
+        .def("delete_limit", &Node::deleteLimit)
+        .def("delete_inlimit", &Node::deleteInlimit)
+        .def("delete_time", &Node::deleteTime)
+        .def("delete_time", &Node::delete_time)
+        .def("delete_today", &Node::deleteToday)
+        .def("delete_today", &Node::delete_today)
+        .def("delete_date", &Node::deleteDate)
+        .def("delete_date", &Node::delete_date)
+        .def("delete_day", &Node::deleteDay)
+        .def("delete_day", &Node::delete_day)
+        .def("delete_cron", &Node::deleteCron)
+        .def("delete_cron", &Node::delete_cron)
+        .def("delete_zombie", &Node::deleteZombie)
+        .def("delete_zombie", &Node::delete_zombie)
+        .def("change_trigger", &Node::changeTrigger)
+        .def("change_complete", &Node::changeComplete)
+        .def("sort_attributes", &sort_attributes)
+        .def("sort_attributes", &sort_attributes1)
+        .def("sort_attributes", &sort_attributes2)
+        .def("sort_attributes",
+             &sort_attributes3,
+             (bp::arg("attribute_type"), bp::arg("recursive") = true, bp::arg("no_sort") = bp::list()))
+        .def("sort_attributes", &Node::sort_attributes, (bp::arg("attribute_type"), bp::arg("recursive") = true))
+        .def("get_abs_node_path", &Node::absNodePath, DefsDoc::abs_node_path_doc())
+        .def("has_time_dependencies", &Node::hasTimeDependencies)
+        .def("update_generated_variables", &Node::update_generated_variables)
+        .def("get_generated_variables",
+             &Node::gen_variables,
+             "returns a list of generated variables. Use ecflow.VariableList as return argument")
+        .def("is_suspended", &Node::isSuspended, "Returns true if the `node`_ is in a `suspended`_ state")
+        .def("find_variable",
+             &Node::findVariable,
+             return_value_policy<copy_const_reference>(),
+             "Find user variable on the node only.  Returns a object")
+        .def("find_gen_variable",
+             &Node::findGenVariable,
+             return_value_policy<copy_const_reference>(),
+             "Find generated variable on the node only.  Returns a object")
+        .def("find_parent_variable",
+             &Node::find_parent_variable,
+             return_value_policy<copy_const_reference>(),
+             "Find user variable variable up the parent hierarchy.  Returns a object")
+        .def("find_parent_variable_sub_value",
+             &Node::find_parent_variable_sub_value,
+             "Find user variable *up* node tree, then variable substitute the value, otherwise return empty string")
+        .def("find_meter",
+             &Node::findMeter,
+             return_value_policy<copy_const_reference>(),
+             "Find the `meter`_ on the node only. Returns a object")
+        .def("find_event",
+             &Node::findEventByNameOrNumber,
+             return_value_policy<copy_const_reference>(),
+             "Find the `event`_ on the node only. Returns a object")
+        .def("find_label",
+             &Node::find_label,
+             return_value_policy<copy_const_reference>(),
+             "Find the `label`_ on the node only. Returns a object")
+        .def("find_queue",
+             &Node::find_queue,
+             return_value_policy<copy_const_reference>(),
+             "Find the queue on the node only. Returns a queue object")
+        .def("find_generic",
+             &Node::find_generic,
+             return_value_policy<copy_const_reference>(),
+             "Find the `generic`_ on the node only. Returns a Generic object")
+        .def("find_limit", &Node::find_limit, "Find the `limit`_ on the node only. returns a limit ptr")
+        .def("find_node_up_the_tree", &Node::find_node_up_the_tree, "Search immediate node, then up the node hierarchy")
+        .def("get_state", &Node::state, "Returns the state of the node. This excludes the suspended state")
+        .def("get_state_change_time",
+             &get_state_change_time,
+             (bp::arg("format") = "iso_extended"),
+             "Returns the time of the last state change as a string. Default format is iso_extended, (iso_extended, "
+             "iso, simple)")
+        .def("get_dstate", &Node::dstate, "Returns the state of node. This will include suspended state")
+        .def("get_defstatus", &Node::defStatus)
+        .def("get_repeat", &Node::repeat, return_value_policy<copy_const_reference>())
+        .def("get_late", &Node::get_late, return_internal_reference<>())
+        .def("get_autocancel", &Node::get_autocancel, return_internal_reference<>())
+        .def("get_autoarchive", &Node::get_autoarchive, return_internal_reference<>())
+        .def("get_autorestore", &Node::get_autorestore, return_internal_reference<>())
+        .def("get_trigger", &Node::get_trigger, return_internal_reference<>())
+        .def("get_complete", &Node::get_complete, return_internal_reference<>())
+        .def("get_defs", get_defs, return_internal_reference<>())
+        .def("get_parent", &Node::parent, return_internal_reference<>())
+        .def("get_all_nodes", &get_all_nodes, "Returns all the child nodes")
+        .def("get_flag",
+             &Node::get_flag,
+             return_value_policy<copy_const_reference>(),
+             "Return additional state associated with a node.")
+        .def("replace_on_server",
+             &replace_on_server,
+             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
+             "replace node on the server.")
+        .def("replace_on_server",
+             &replace_on_server1,
+             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
+             "replace node on the server.")
+        .def("replace_on_server",
+             &replace_on_server2,
+             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
+             "replace node on the server.")
+        .def("replace_on_server",
+             &do_replace_on_server,
+             (bp::arg("suspend_node_first") = true, bp::arg("force") = true),
+             "replace node on the server.")
+        .add_property("meters", bp::range(&Node::meter_begin, &Node::meter_end), "Returns a list of `meter`_\\ s")
+        .add_property("events", bp::range(&Node::event_begin, &Node::event_end), "Returns a list of `event`_\\ s")
+        .add_property("variables",
+                      bp::range(&Node::variable_begin, &Node::variable_end),
+                      "Returns a list of user defined `variable`_\\ s")
+        .add_property("labels", bp::range(&Node::label_begin, &Node::label_end), "Returns a list of `label`_\\ s")
+        .add_property("avisos", bp::range(&Node::aviso_begin, &Node::aviso_end), "Returns a list of `aviso`_\\ s")
+        .add_property("mirrors", bp::range(&Node::mirror_begin, &Node::mirror_end), "Returns a list of `mirror`_\\ s")
+        .add_property("limits", bp::range(&Node::limit_begin, &Node::limit_end), "Returns a list of `limit`_\\ s")
+        .add_property(
+            "inlimits", bp::range(&Node::inlimit_begin, &Node::inlimit_end), "Returns a list of `inlimit`_\\ s")
+        .add_property("verifies", bp::range(&Node::verify_begin, &Node::verify_end), "Returns a list of Verify's")
+        .add_property("times", bp::range(&Node::time_begin, &Node::time_end), "Returns a list of `time`_\\ s")
+        .add_property("todays", bp::range(&Node::today_begin, &Node::today_end), "Returns a list of `today`_\\ s")
+        .add_property("dates", bp::range(&Node::date_begin, &Node::date_end), "Returns a list of `date`_\\ s")
+        .add_property("days", bp::range(&Node::day_begin, &Node::day_end), "Returns a list of `day`_\\ s")
+        .add_property("crons", bp::range(&Node::cron_begin, &Node::cron_end), "Returns a list of `cron`_\\ s")
+        .add_property("zombies", bp::range(&Node::zombie_begin, &Node::zombie_end), "Returns a list of `zombie`_\\ s")
+        .add_property("queues", bp::range(&Node::queue_begin, &Node::queue_end), "Returns a list of `queue`_\\ s")
+        .add_property(
+            "generics", bp::range(&Node::generic_begin, &Node::generic_end), "Returns a list of `generic`_\\ s");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<node_ptr>(); // needed for mac and boost 1.6
+#endif
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ExportNodeAttr.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ExportNodeAttr.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ExportNodeAttr.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ExportNodeAttr.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1073 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <stdexcept>
+
+#include <boost/python.hpp>
+#include <boost/python/raw_function.hpp>
+#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/ClockAttr.hpp"
+#include "ecflow/attribute/CronAttr.hpp"
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/attribute/RepeatAttr.hpp"
+#include "ecflow/attribute/TimeAttr.hpp"
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/attribute/Zombie.hpp"
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/node/Attr.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/InLimit.hpp"
+#include "ecflow/node/JobCreationCtrl.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/DefsDoc.hpp"
+#include "ecflow/python/NodeAttrDoc.hpp"
+#include "ecflow/python/Trigger.hpp"
+
+using namespace ecf;
+using namespace boost::python;
+using namespace std;
+namespace bp = boost::python;
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+///////////////////////////////////////////////////////////////////////////////////////////////////
+object late_raw_constructor(bp::tuple args, bp::dict kw) {
+    // cout << "late_raw_constructor len(args):" << len(args) << endl;
+    //  args[0] is Late(i.e self)
+    if (len(args) > 1)
+        throw std::runtime_error("late_raw_constructor: Late only expects keyword arguments, ie. "
+                                 "Late(submitted='00:20',active='15:00',complete='+30:00')");
+    return args[0].attr("__init__")(kw); // calls -> late_init(dict kw)
+}
+
+static void extract_late_keyword_arguments(std::shared_ptr<LateAttr> late, bp::dict& dict) {
+    boost::python::list keys = dict.keys();
+    const int no_of_keys     = len(keys);
+    for (int i = 0; i < no_of_keys; ++i) {
+        if (extract<string>(keys[i]).check()) {
+            std::string first = extract<std::string>(keys[i]);
+            if (extract<string>(dict[keys[i]]).check()) {
+                std::string second = extract<string>(dict[keys[i]]);
+                int hour           = 0;
+                int min            = 0;
+                bool relative      = TimeSeries::getTime(second, hour, min);
+                if (first == "submitted")
+                    late->add_submitted(hour, min);
+                else if (first == "active")
+                    late->add_active(hour, min);
+                else if (first == "complete")
+                    late->add_complete(hour, min, relative);
+                else
+                    throw std::runtime_error(
+                        "extract_late_keyword_arguments: keyword arguments, expected [submitted | active | complete]");
+            }
+            else
+                throw std::runtime_error("extract_late_keyword_arguments: expected keyword arguments to be a string, "
+                                         "ie Late(submitted='00:20',active='15:00',complete='+30:00')");
+        }
+    }
+}
+
+static std::shared_ptr<LateAttr> late_init(bp::dict& dict) {
+    std::shared_ptr<LateAttr> late = std::make_shared<LateAttr>();
+    extract_late_keyword_arguments(late, dict);
+    return late;
+}
+
+static std::shared_ptr<LateAttr> late_create() {
+    return std::make_shared<LateAttr>();
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////////////
+object cron_raw_constructor(bp::tuple args, bp::dict kw) {
+    // cout << "cron_raw_constructor len(args):" << len(args) << endl;
+    //  args[0] is Cron(i.e self) args[1] is string name
+    for (int i = 1; i < len(args); ++i) {
+        if (extract<string>(args[i]).check()) {
+            std::string time_series = extract<string>(args[i]);
+            if (time_series.empty())
+                throw std::runtime_error("cron_raw_constructor: Empty string, please pass a valid time, i.e '12:30'");
+            return args[0].attr("__init__")(time_series, kw); // calls -> init(const std::string& ts, dict kw)
+        }
+        if (extract<TimeSeries>(args[i]).check()) {
+            TimeSeries time_series = extract<TimeSeries>(args[i]);
+            return args[0].attr("__init__")(time_series, kw); // calls -> init(const TimeSeries& ts, dict kw)
+        }
+        else
+            throw std::runtime_error("cron_raw_constructor: expects string | TimeSeries and keyword arguments");
+    }
+    throw std::runtime_error("cron_raw_constructor: expects string | TimeSeries and keyword arguments !!");
+    return object();
+}
+
+static void extract_cron_keyword_arguments(std::shared_ptr<CronAttr> cron, bp::dict& dict) {
+    boost::python::list keys = dict.keys();
+    const int no_of_keys     = len(keys);
+    for (int i = 0; i < no_of_keys; ++i) {
+
+        if (extract<string>(keys[i]).check()) {
+            std::string first = extract<std::string>(keys[i]);
+            if (extract<bp::list>(dict[keys[i]]).check()) {
+
+                bp::list second = extract<bp::list>(dict[keys[i]]);
+                std::vector<int> int_vec;
+                BoostPythonUtil::list_to_int_vec(second, int_vec);
+
+                //  expected keywords are: days_of_week,last_week_days_ofThe_month, days_of_month, months
+                if (first == "days_of_week")
+                    cron->addWeekDays(int_vec);
+                else if (first == "days_of_month")
+                    cron->addDaysOfMonth(int_vec);
+                else if (first == "months")
+                    cron->addMonths(int_vec);
+                else if (first == "last_week_days_of_the_month")
+                    cron->add_last_week_days_of_month(int_vec);
+                else
+                    throw std::runtime_error(
+                        "extract_cron_keyword_arguments: keyword arguments, expected [days_of_week | "
+                        "last_week_days_of_the_month | days_of_month | months | last_day_of_the_month");
+            }
+            else if (extract<bool>(dict[keys[i]]).check()) {
+                if (first == "last_day_of_the_month")
+                    cron->add_last_day_of_month();
+                else
+                    throw std::runtime_error(
+                        "extract_cron_keyword_arguments: keyword arguments, expected [days_of_week | "
+                        "last_week_days_of_the_month | days_of_month | months | last_day_of_the_month]");
+            }
+            else
+                throw std::runtime_error("extract_cron_keyword_arguments: keyword arguments to be a list");
+        }
+    }
+}
+
+static std::shared_ptr<CronAttr> cron_init(const std::string& ts, bp::dict& dict) {
+    std::shared_ptr<CronAttr> cron = std::make_shared<CronAttr>(ts);
+    extract_cron_keyword_arguments(cron, dict);
+    return cron;
+}
+
+static std::shared_ptr<CronAttr> cron_init1(const TimeSeries& ts, bp::dict& dict) {
+    std::shared_ptr<CronAttr> cron = std::make_shared<CronAttr>(ts);
+    extract_cron_keyword_arguments(cron, dict);
+    return cron;
+}
+
+static std::shared_ptr<CronAttr> cron_create() {
+    return std::make_shared<CronAttr>();
+}
+static std::shared_ptr<CronAttr> cron_create2(const TimeSeries& ts) {
+    return std::make_shared<CronAttr>(ts);
+}
+///////////////////////////////////////////////////////////////////////////////////////////////////
+
+void add_time_series_3(CronAttr* self, const std::string& ts) {
+    self->addTimeSeries(TimeSeries::create(ts));
+}
+
+void set_week_days(CronAttr* cron, const bp::list& list) {
+    std::vector<int> int_vec;
+    BoostPythonUtil::list_to_int_vec(list, int_vec);
+    cron->addWeekDays(int_vec);
+}
+void set_last_week_days_of_month(CronAttr* cron, const bp::list& list) {
+    std::vector<int> int_vec;
+    BoostPythonUtil::list_to_int_vec(list, int_vec);
+    cron->add_last_week_days_of_month(int_vec);
+}
+
+void set_days_of_month(CronAttr* cron, const bp::list& list) {
+    std::vector<int> int_vec;
+    BoostPythonUtil::list_to_int_vec(list, int_vec);
+    cron->addDaysOfMonth(int_vec);
+}
+void set_last_day_of_the_month(CronAttr* cron) {
+    cron->add_last_day_of_month();
+}
+
+void set_months(CronAttr* cron, const bp::list& list) {
+    std::vector<int> int_vec;
+    BoostPythonUtil::list_to_int_vec(list, int_vec);
+    cron->addMonths(int_vec);
+}
+
+// Create as shared because: we want to pass a Python list as part of the constructor,
+// *AND* the only way make_constructor works is with a pointer.
+// The Node::add function seem to cope with this, some boost python magic,must do a conversion
+// from shared_ptr to pass by reference
+static std::shared_ptr<RepeatEnumerated> create_RepeatEnumerated(const std::string& name, const bp::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    return std::make_shared<RepeatEnumerated>(name, vec);
+}
+static std::shared_ptr<RepeatDateList> create_RepeatDateList(const std::string& name, const bp::list& list) {
+    std::vector<int> vec;
+    BoostPythonUtil::list_to_int_vec(list, vec);
+    return std::make_shared<RepeatDateList>(name, vec);
+}
+static std::shared_ptr<RepeatString> create_RepeatString(const std::string& name, const bp::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    return std::make_shared<RepeatString>(name, vec);
+}
+static std::shared_ptr<AutoRestoreAttr> create_AutoRestoreAttr(const boost::python::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    return std::make_shared<AutoRestoreAttr>(vec);
+}
+
+static std::shared_ptr<QueueAttr> create_queue(const std::string& name, const boost::python::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    return std::make_shared<QueueAttr>(name, vec);
+}
+
+static std::shared_ptr<GenericAttr> create_generic(const std::string& name, const boost::python::list& list) {
+    std::vector<std::string> vec;
+    BoostPythonUtil::list_to_str_vec(list, vec);
+    return std::make_shared<GenericAttr>(name, vec);
+}
+
+static std::shared_ptr<ZombieAttr>
+create_ZombieAttr(Child::ZombieType zt, const bp::list& list, User::Action uc, int life_time_in_server) {
+    std::vector<Child::CmdType> vec;
+    int the_list_size = len(list);
+    vec.reserve(the_list_size);
+    for (int i = 0; i < the_list_size; ++i) {
+        vec.push_back(extract<Child::CmdType>(list[i]));
+    }
+    return std::make_shared<ZombieAttr>(zt, vec, uc, life_time_in_server);
+}
+
+static std::shared_ptr<ZombieAttr> create_ZombieAttr1(Child::ZombieType zt, const bp::list& list, User::Action uc) {
+    std::vector<Child::CmdType> vec;
+    int the_list_size = len(list);
+    vec.reserve(the_list_size);
+    for (int i = 0; i < the_list_size; ++i) {
+        vec.push_back(extract<Child::CmdType>(list[i]));
+    }
+    return std::make_shared<ZombieAttr>(zt, vec, uc);
+}
+
+static bp::list wrap_set_of_strings(Limit* limit) {
+    bp::list list;
+    const std::set<std::string>& paths = limit->paths();
+    for (std::string path : paths) {
+        list.append(path);
+    }
+    return list;
+}
+
+static job_creation_ctrl_ptr makeJobCreationCtrl() {
+    return std::make_shared<JobCreationCtrl>();
+}
+
+static std::shared_ptr<AvisoAttr> aviso_init(const std::string& name,
+                                             const std::string& listener,
+                                             const std::string& url,
+                                             const std::string& schema,
+                                             const std::string& polling,
+                                             const std::string& auth) {
+    auto attr = std::make_shared<AvisoAttr>(nullptr, name, listener, url, schema, polling, 0, auth, "");
+    return attr;
+}
+
+static std::shared_ptr<MirrorAttr> mirror_init(const std::string& name,
+                                               const std::string& path,
+                                               const std::string& host,
+                                               const std::string& port,
+                                               const std::string& polling,
+                                               bool ssl,
+                                               const std::string& auth) {
+    auto attr = std::make_shared<MirrorAttr>(nullptr, name, path, host, port, polling, ssl, auth, "");
+    return attr;
+}
+
+void export_NodeAttr() {
+    // Trigger & Complete thin wrapper over Expression, allows us to call: Task("a").add(Trigger("a=1"),Complete("b=1"))
+    class_<Trigger, std::shared_ptr<Trigger>>("Trigger", DefsDoc::trigger(), init<std::string>())
+        .def(init<PartExpression>())
+        .def(init<bp::list>())
+        .def(init<std::string, bool>())
+        .def(self == self)                    // __eq__
+        .def("__str__", &Trigger::expression) // __str__
+        .def("get_expression", &Trigger::expression, "returns the trigger expression as a string");
+
+    class_<Complete, std::shared_ptr<Complete>>("Complete", DefsDoc::trigger(), init<std::string>())
+        .def(init<PartExpression>())
+        .def(init<bp::list>())
+        .def(init<std::string, bool>())
+        .def(self == self)                     // __eq__
+        .def("__str__", &Complete::expression) // __str__
+        .def("get_expression", &Complete::expression, "returns the complete expression as a string");
+
+    // mimic PartExpression(const std::string& expression  )
+    // mimic PartExpression(const std::string& expression, bool andExpr /* true means AND , false means OR */ )
+    // Use to adding large trigger and complete expressions
+    class_<PartExpression>("PartExpression", DefsDoc::part_expression_doc(), init<std::string>())
+        .def(init<std::string, bool>())
+        .def(self == self) // __eq__
+        .def("get_expression",
+             &PartExpression::expression,
+             return_value_policy<copy_const_reference>(),
+             "returns the part expression as a string")
+        .def("and_expr", &PartExpression::andExpr)
+        .def("or_expr", &PartExpression::orExpr);
+
+    class_<Expression, std::shared_ptr<Expression>>("Expression", DefsDoc::expression_doc(), init<std::string>())
+        .def(init<PartExpression>())
+        .def(self == self)                       // __eq__
+        .def("__str__", &Expression::expression) // __str__
+        .def("get_expression", &Expression::expression, "returns the complete expression as a string")
+        .def("add",
+             &Expression::add,
+             "Add a part expression, the second and subsequent part expressions must have 'and/or' set")
+        .add_property(
+            "parts", bp::range(&Expression::part_begin, &Expression::part_end), "Returns a list of PartExpression's");
+
+    enum_<Flag::Type>("FlagType",
+                      "Flags store state associated with a node\n\n"
+                      "- FORCE_ABORT   - Node* do not run when try_no > ECF_TRIES, and task aborted by user\n"
+                      "- USER_EDIT     - task\n"
+                      "- TASK_ABORTED  - task*\n"
+                      "- EDIT_FAILED   - task*\n"
+                      "- JOBCMD_FAILED - task*\n"
+                      "- KILLCMD_FAILED   - task*\n"
+                      "- STATUSCMD_FAILED - task*\n"
+                      "- NO_SCRIPT     - task*\n"
+                      "- KILLED        - task* do not run when try_no > ECF_TRIES, and task killed by user\n"
+                      "- STATUS        - task* indicates that the status command has been run\n"
+                      "- LATE          - Node attribute, Task is late, or Defs checkpt takes to long\n"
+                      "- MESSAGE       - Node\n"
+                      "- BYRULE        - Node*, set if node is set to complete by complete trigger expression\n"
+                      "- QUEUELIMIT    - Node\n"
+                      "- WAIT          - task* \n"
+                      "- LOCKED        - Server\n"
+                      "- ZOMBIE        - task*\n"
+                      "- NO_REQUE      - task\n"
+                      "- ARCHIVED      - Suite/Family\n"
+                      "- RESTORED      - Family/Family\n"
+                      "- THRESHOLD     - task\n"
+                      "- SIGTERM       - Defs, records that server received a SIGTERM signal\n"
+                      "- LOG_ERROR     - Error in opening or writing to log file\n"
+                      "- CHECKPT_ERROR - Error in opening or writing to checkpt file \n"
+                      "- NOT_SET\n")
+        .value("force_abort", Flag::FORCE_ABORT)
+        .value("user_edit", Flag::USER_EDIT)
+        .value("task_aborted", Flag::TASK_ABORTED)
+        .value("edit_failed", Flag::EDIT_FAILED)
+        .value("jobcmd_failed", Flag::JOBCMD_FAILED)
+        .value("killcmd_failed", Flag::KILLCMD_FAILED)
+        .value("statuscmd_failed", Flag::STATUSCMD_FAILED)
+        .value("no_script", Flag::NO_SCRIPT)
+        .value("killed", Flag::KILLED)
+        .value("status", Flag::STATUS)
+        .value("late", Flag::LATE)
+        .value("message", Flag::MESSAGE)
+        .value("byrule", Flag::BYRULE)
+        .value("queuelimit", Flag::QUEUELIMIT)
+        .value("wait", Flag::WAIT)
+        .value("locked", Flag::LOCKED)
+        .value("zombie", Flag::ZOMBIE)
+        .value("no_reque", Flag::NO_REQUE_IF_SINGLE_TIME_DEP)
+        .value("archived", Flag::ARCHIVED)
+        .value("restored", Flag::RESTORED)
+        .value("threshold", Flag::THRESHOLD)
+        .value("sigterm", Flag::ECF_SIGTERM)
+        .value("not_set", Flag::NOT_SET)
+        .value("log_error", Flag::LOG_ERROR)
+        .value("checkpt_error", Flag::CHECKPT_ERROR)
+        .value("remote_error", Flag::REMOTE_ERROR);
+
+    class_<Flag>("Flag", "Represents additional state associated with a Node.\n\n", init<>())
+        .def("__str__", &Flag::to_string) // __str__
+        .def(self == self)                // __eq__
+        .def("is_set", &Flag::is_set, "Queries if a given flag is set")
+        .def("set", &Flag::set, "Sets the given flag. Used in test only")
+        .def("clear", &Flag::clear, "Clear the given flag. Used in test only")
+        .def("reset", &Flag::reset, "Clears all flags. Used in test only")
+        .def("list", &Flag::list, "Returns the list of all flag types. returns FlagTypeVec. Used in test only")
+        .staticmethod("list")
+        .def("type_to_string", &Flag::enum_to_string, "Convert type to a string. Used in test only")
+        .staticmethod("type_to_string");
+
+    class_<std::vector<Flag::Type>>("FlagTypeVec", "Hold a list of flag types")
+        .def(vector_indexing_suite<std::vector<Flag::Type>, true>());
+
+    class_<JobCreationCtrl, boost::noncopyable, job_creation_ctrl_ptr>("JobCreationCtrl", DefsDoc::jobgenctrl_doc())
+        .def("__init__", make_constructor(makeJobCreationCtrl), DefsDoc::jobgenctrl_doc())
+        .def("set_node_path",
+             &JobCreationCtrl::set_node_path,
+             "The node we want to check job creation for. If no node specified check all tasks")
+        .def("set_dir_for_job_creation",
+             &JobCreationCtrl::set_dir_for_job_creation,
+             "Specify directory, for job creation")
+        .def("set_verbose", &JobCreationCtrl::set_verbose, "Output each task as its being checked.")
+        .def("get_dir_for_job_creation",
+             &JobCreationCtrl::dir_for_job_creation,
+             return_value_policy<copy_const_reference>(),
+             "Returns the directory set for job creation")
+        .def(
+            "generate_temp_dir",
+            &JobCreationCtrl::generate_temp_dir,
+            "Automatically generated temporary directory for job creation. Directory written to stdout for information")
+        .def("get_error_msg",
+             &JobCreationCtrl::get_error_msg,
+             return_value_policy<copy_const_reference>(),
+             "Returns an error message generated during checking of job creation");
+
+    enum_<Child::ZombieType>("ZombieType", NodeAttrDoc::zombie_type_doc())
+        .value("ecf", Child::ECF)
+        .value("ecf_pid", Child::ECF_PID)
+        .value("ecf_pid_passwd", Child::ECF_PID_PASSWD)
+        .value("ecf_passwd", Child::ECF_PASSWD)
+        .value("user", Child::USER)
+        .value("path", Child::PATH);
+
+    enum_<User::Action>("ZombieUserActionType", NodeAttrDoc::zombie_user_action_type_doc())
+        .value("fob", User::FOB)
+        .value("fail", User::FAIL)
+        .value("remove", User::REMOVE)
+        .value("adopt", User::ADOPT)
+        .value("block", User::BLOCK)
+        .value("kill", User::KILL);
+
+    enum_<Child::CmdType>("ChildCmdType", NodeAttrDoc::child_cmd_type_doc())
+        .value("init", Child::INIT)
+        .value("event", Child::EVENT)
+        .value("meter", Child::METER)
+        .value("label", Child::LABEL)
+        .value("wait", Child::WAIT)
+        .value("queue", Child::QUEUE)
+        .value("abort", Child::ABORT)
+        .value("complete", Child::COMPLETE);
+
+    enum_<Attr::Type>("AttrType",
+                      "Sortable attribute type, currently [event | meter | label | limit | variable | all ]")
+        .value("event", Attr::EVENT)
+        .value("meter", Attr::METER)
+        .value("label", Attr::LABEL)
+        .value("limit", Attr::LIMIT)
+        .value("variable", Attr::VARIABLE)
+        .value("all", Attr::ALL);
+
+    // 	ZombieAttr(ecf::Child::ZombieType t, const std::vector<ecf::Child::CmdType>& c, ecf::User::Action a, int
+    // zombie_lifetime);
+    class_<ZombieAttr>("ZombieAttr", NodeAttrDoc::zombie_doc())
+        .def("__init__", make_constructor(&create_ZombieAttr))
+        .def("__init__", make_constructor(&create_ZombieAttr1))
+        .def("__str__", &ZombieAttr::toString)   // __str__
+        .def("__copy__", copyObject<ZombieAttr>) // __copy__ uses copy constructor
+        .def(self == self)                       // __eq__
+        .def("empty", &ZombieAttr::empty, "Return true if the attribute is empty")
+        .def("zombie_type", &ZombieAttr::zombie_type, "Returns the `zombie type`_")
+        .def("user_action", &ZombieAttr::action, "The automated action to invoke, when zombies arise")
+        .def("zombie_lifetime",
+             &ZombieAttr::zombie_lifetime,
+             "Returns the lifetime in seconds of `zombie`_ in the server")
+        .add_property("child_cmds",
+                      bp::range(&ZombieAttr::child_begin, &ZombieAttr::child_end),
+                      "The list of child commands. If empty action applies to all child cmds");
+
+    class_<std::vector<Zombie>>("ZombieVec", "Hold a list of zombies")
+        .def(vector_indexing_suite<std::vector<Zombie>, true>());
+
+    class_<Zombie>("Zombie", "Represent a zombie process stored by the server")
+        .def("__str__", &Zombie::to_string)  // __str__
+        .def("__copy__", copyObject<Zombie>) // __copy__ uses copy constructor
+        .def(self == self)                   // __eq__
+        .def("empty", &Zombie::empty)
+        .def("manual_user_action", &Zombie::manual_user_action)
+        .def("fob", &Zombie::fob)
+        .def("fail", &Zombie::fail)
+        .def("adopt", &Zombie::adopt)
+        .def("block", &Zombie::block)
+        .def("remove", &Zombie::remove)
+        .def("kill", &Zombie::kill)
+        .def("type", &Zombie::type)
+        .def("type_str", &Zombie::type_str)
+        .def("last_child_cmd", &Zombie::last_child_cmd)
+        .def("attr", &Zombie::attr, return_value_policy<copy_const_reference>())
+        .def("calls", &Zombie::calls)
+        .def("jobs_password", &Zombie::jobs_password, return_value_policy<copy_const_reference>())
+        .def("path_to_task", &Zombie::path_to_task, return_value_policy<copy_const_reference>())
+        .def("process_or_remote_id", &Zombie::process_or_remote_id, return_value_policy<copy_const_reference>())
+        .def("user_cmd", &Zombie::user_cmd, return_value_policy<copy_const_reference>())
+        .def("try_no", &Zombie::try_no)
+        .def("duration", &Zombie::duration)
+        .def("user_action", &Zombie::user_action)
+        .def("user_action_str", &Zombie::user_action_str)
+        .def("host", &Zombie::host, return_value_policy<copy_const_reference>())
+        .def("allowed_age", &Zombie::allowed_age);
+
+    class_<Variable>("Variable", NodeAttrDoc::variable_doc(), init<std::string, std::string>())
+        .def("__str__", &Variable::toString)   // __str__
+        .def("__copy__", copyObject<Variable>) // __copy__ uses copy constructor
+        .def(self < self)                      // __lt__
+        .def(self == self)                     // __eq__
+        .def("name", &Variable::name, return_value_policy<copy_const_reference>(), "Return the variable name as string")
+        .def("value",
+             &Variable::theValue,
+             return_value_policy<copy_const_reference>(),
+             "Return the variable value as a string")
+        .def("empty",
+             &Variable::empty,
+             "Return true if the variable is empty. Used when returning a Null variable, from a find");
+    // .add_property("value", make_function(&Variable::theValue ,return_value_policy<copy_const_reference>()),
+    //                       &Variable::set_value,  "get/set the value as a property")
+    // The following works v = Variable('name','fred')
+    //   print v.value
+    // But it will then break v.value()
+
+    // We need to return pass a list of Variable as arguments, to retrieve the generated variables
+    class_<std::vector<Variable>>("VariableList", "Hold a list of Variables")
+        .def(vector_indexing_suite<std::vector<Variable>>());
+
+    class_<Label>("Label", NodeAttrDoc::label_doc(), init<std::string, std::string>())
+        .def(self == self)                  // __eq__
+        .def("__str__", &Label::toString)   // __str__
+        .def("__copy__", copyObject<Label>) // __copy__ uses copy constructor
+        .def(self < self)                   // __lt__
+        .def("name", &Label::name, return_value_policy<copy_const_reference>(), "Return the `label`_ name as string")
+        .def("value",
+             &Label::value,
+             return_value_policy<copy_const_reference>(),
+             "Return the original `label`_ value as string")
+        .def("new_value",
+             &Label::new_value,
+             return_value_policy<copy_const_reference>(),
+             "Return the new label value as string")
+        .def(
+            "empty", &Label::empty, "Return true if the Label is empty. Used when returning a NULL Label, from a find");
+
+    // This will not work, because paths_begin
+    //.add_property("node_paths", bp::range(&Limit::paths_begin,&Limit::paths_begin),"List of nodes(paths) that have
+    // consumed a limit")
+
+    class_<Limit, std::shared_ptr<Limit>>("Limit", NodeAttrDoc::limit_doc(), init<std::string, int>())
+        .def(self == self)                  // __eq__
+        .def("__str__", &Limit::toString)   // __str__
+        .def("__copy__", copyObject<Limit>) // __copy__ uses copy constructor
+        .def(self < self)                   // __lt__
+        .def("name", &Limit::name, return_value_policy<copy_const_reference>(), "Return the `limit`_ name as string")
+        .def("value", &Limit::value, "The `limit`_ token value as an integer")
+        .def("limit", &Limit::theLimit, "The max value of the `limit`_ as an integer")
+        .def("increment", &Limit::increment, "used for test only")
+        .def("decrement", &Limit::decrement, "used for test only")
+        .def("node_paths", &wrap_set_of_strings, "List of nodes(paths) that have consumed a limit");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<std::shared_ptr<Limit>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<InLimit>("InLimit", NodeAttrDoc::inlimit_doc())
+        .def(init<std::string>())
+        .def(init<std::string, std::string>())
+        .def(init<std::string, std::string, int>())
+        .def(init<std::string, std::string, int, bool>())
+        .def(init<std::string, std::string, int, bool, bool>())
+        .def(self == self)                    // __eq__
+        .def("__str__", &InLimit::toString)   // __str__
+        .def("__copy__", copyObject<InLimit>) // __copy__ uses copy constructor
+        .def(self < self)                     // __lt__
+        .def(
+            "name", &InLimit::name, return_value_policy<copy_const_reference>(), "Return the `inlimit`_ name as string")
+        .def("path_to_node",
+             &InLimit::pathToNode,
+             return_value_policy<copy_const_reference>(),
+             "Path to the node that holds the limit, can be empty")
+        .def("limit_this_node_only",
+             &InLimit::limit_this_node_only,
+             "Only this node is limited. i.e. typically Family or Suite")
+        .def("limit_submission", &InLimit::limit_submission, "Limit submission only")
+        .def("tokens", &InLimit::tokens, "The number of token to consume from the Limit");
+
+    class_<Event>("Event", NodeAttrDoc::event_doc(), init<int, bp::optional<std::string>>())
+        .def(init<int, std::string, bool>()) // here bool is the initial value, by default is false/clear. The value
+                                             // taken by begin/re-queue
+        .def(init<std::string, bool>()) // here bool is the initial value, by default is false/clear. The value taken by
+                                        // begin/re-queue
+        .def(init<std::string>())
+        .def(self == self)                  // __eq__
+        .def("__str__", &Event::toString)   // __str__
+        .def("__copy__", copyObject<Event>) // __copy__ uses copy constructor
+        .def(self < self)                   // __lt__
+        .def("name",
+             &Event::name,
+             return_value_policy<copy_const_reference>(),
+             "Return the Events name as string. If number supplied name may be empty.")
+        .def("number", &Event::number, "Return events number as a integer. If not specified return max integer value")
+        .def("name_or_number", &Event::name_or_number, "Returns name or number as string")
+        .def("value", &Event::value, "Return events current value")
+        .def("initial_value",
+             &Event::initial_value,
+             "Return events initial value, This is value taken for begin/re-queue")
+        .def(
+            "empty", &Event::empty, "Return true if the Event is empty. Used when returning a NULL Event, from a find");
+
+    class_<Meter>("Meter", NodeAttrDoc::meter_doc(), init<std::string, int, int, bp::optional<int>>())
+        .def(self == self)                  // __eq__
+        .def("__str__", &Meter::toString)   // __str__
+        .def("__copy__", copyObject<Meter>) // __copy__ uses copy constructor
+        .def(self < self)                   // __lt__
+        .def("name", &Meter::name, return_value_policy<copy_const_reference>(), "Return the Meters name as string")
+        .def("min", &Meter::min, "Return the Meters minimum value")
+        .def("max", &Meter::max, "Return the Meters maximum value")
+        .def("value", &Meter::value, "Return meters current value")
+        .def("color_change", &Meter::colorChange, "returns the color change")
+        .def(
+            "empty", &Meter::empty, "Return true if the Meter is empty. Used when returning a NULL Meter, from a find");
+
+    class_<QueueAttr>("Queue", NodeAttrDoc::queue_doc())
+        .def("__init__", make_constructor(&create_queue))
+        .def(self == self)                      // __eq__
+        .def("__str__", &QueueAttr::toString)   // __str__
+        .def("__copy__", copyObject<QueueAttr>) // __copy__ uses copy constructor
+        .def(self < self)                       // __lt__
+        .def("name", &QueueAttr::name, return_value_policy<copy_const_reference>(), "Return the queue name as string")
+        .def("value", &QueueAttr::value, "Return the queue current value as string")
+        .def("index", &QueueAttr::index, "Return the queue current index as a integer")
+        .def("empty",
+             &QueueAttr::empty,
+             "Return true if the Queue is empty. Used when returning a NULL Queue, from a find");
+
+    class_<GenericAttr>(
+        "Generic", "A generic attribute, used to add new attributes for the future, without requiring a API change")
+        .def("__init__", make_constructor(&create_generic))
+        .def(self == self)                        // __eq__
+        .def("__str__", &GenericAttr::to_string)  // __str__
+        .def("__copy__", copyObject<GenericAttr>) // __copy__ uses copy constructor
+        .def(self < self)                         // __lt__
+        .def("name",
+             &GenericAttr::name,
+             return_value_policy<copy_const_reference>(),
+             "Return the generic name as string")
+        .def("empty",
+             &GenericAttr::empty,
+             "Return true if the Generic is empty. Used when returning a NULL Generic, from a find")
+        .add_property("values",
+                      boost::python::range(&GenericAttr::values_begin, &GenericAttr::values_end),
+                      "The list of values for the generic");
+
+    class_<DateAttr>("Date", NodeAttrDoc::date_doc(), init<int, int, int>()) // day,month,year
+        .def(init<std::string>())
+        .def(self == self)                     // __eq__
+        .def("__str__", &DateAttr::toString)   // __str__
+        .def("__copy__", copyObject<DateAttr>) // __copy__ uses copy constructor
+        .def(self < self)                      // __lt__
+        .def("day", &DateAttr::day, "Return the day. The range is 0-31, 0 means its wild-carded")
+        .def("month", &DateAttr::month, "Return the month. The range is 0-12, 0 means its wild-carded")
+        .def("year", &DateAttr::year, "Return the year, 0 means its wild-carded");
+
+    enum_<DayAttr::Day_t>("Days", NodeAttrDoc::days_enum_doc())
+        .value("sunday", DayAttr::SUNDAY)
+        .value("monday", DayAttr::MONDAY)
+        .value("tuesday", DayAttr::TUESDAY)
+        .value("wednesday", DayAttr::WEDNESDAY)
+        .value("thursday", DayAttr::THURSDAY)
+        .value("friday", DayAttr::FRIDAY)
+        .value("saturday", DayAttr::SATURDAY);
+
+    class_<DayAttr>("Day", NodeAttrDoc::day_doc(), init<DayAttr::Day_t>())
+        .def(init<std::string>())             // constructor
+        .def(self == self)                    // __eq__
+        .def("__str__", &DayAttr::toString)   // __str__
+        .def("__copy__", copyObject<DayAttr>) // __copy__ uses copy constructor
+        .def(self < self)                     // __lt__
+        .def("day", &DayAttr::day, "Return the day as enumerator");
+
+    class_<TimeAttr>("Time", NodeAttrDoc::time_doc(), init<TimeSlot, bp::optional<bool>>())
+        .def(init<int, int, bp::optional<bool>>()) // hour, minute, relative
+        .def(init<TimeSeries>())
+        .def(init<TimeSlot, TimeSlot, TimeSlot, bool>())
+        .def(init<std::string>())
+        .def(self == self)                     // __eq__
+        .def("__str__", &TimeAttr::toString)   // __str__
+        .def("__copy__", copyObject<TimeAttr>) // __copy__ uses copy constructor
+        .def("time_series",
+             &TimeAttr::time_series,
+             return_value_policy<copy_const_reference>(),
+             "Return the Time attributes time series");
+
+    class_<TodayAttr>("Today", NodeAttrDoc::today_doc(), init<TimeSlot, bp::optional<bool>>())
+        .def(init<int, int, bp::optional<bool>>()) // hour, minute, relative
+        .def(init<TimeSeries>())
+        .def(init<TimeSlot, TimeSlot, TimeSlot, bool>())
+        .def(init<std::string>())
+        .def(self == self)                      // __eq__
+        .def("__str__", &TodayAttr::toString)   // __str__
+        .def("__copy__", copyObject<TodayAttr>) // __copy__ uses copy constructor
+        .def("time_series",
+             &TodayAttr::time_series,
+             return_value_policy<copy_const_reference>(),
+             "Return the Todays time series");
+
+    class_<LateAttr, std::shared_ptr<LateAttr>>("Late", NodeAttrDoc::late_doc())
+        .def("__init__", raw_function(&late_raw_constructor, 1)) // will call -> late_init
+        .def("__init__", make_constructor(&late_init))
+        .def("__init__", make_constructor(&late_create))
+        .def(
+            "submitted",
+            &LateAttr::addSubmitted,
+            "submitted(TimeSlot):The time node can stay `submitted`_. Submitted is always relative. If the node stays\n"
+            "submitted longer than the time specified, the `late`_ flag is set\n")
+        .def(
+            "submitted",
+            &LateAttr::add_submitted,
+            "submitted(hour,minute) The time node can stay submitted. Submitted is always relative. If the node stays\n"
+            "submitted longer than the time specified, the late flag is set\n")
+        .def("active",
+             &LateAttr::add_active,
+             "active(hour,minute): The time the node must become `active`_. If the node is still `queued`_ or "
+             "`submitted`_\n"
+             "by the time specified, the late flag is set")
+        .def(
+            "active",
+            &LateAttr::addActive,
+            "active(TimeSlot):The time the node must become `active`_. If the node is still `queued`_ or `submitted`_\n"
+            "by the time specified, the late flag is set")
+        .def("complete",
+             &LateAttr::add_complete,
+             "complete(hour,minute):The time the node must become `complete`_. If relative, time is taken from the "
+             "time\n"
+             "the node became `active`_, otherwise node must be `complete`_ by the time given")
+        .def("complete",
+             &LateAttr::addComplete,
+             "complete(TimeSlot): The time the node must become `complete`_. If relative, time is taken from the time\n"
+             "the node became `active`_, otherwise node must be `complete`_ by the time given")
+        .def(self == self)                     // __eq__
+        .def("__str__", &LateAttr::toString)   // __str__
+        .def("__copy__", copyObject<LateAttr>) // __copy__ uses copy constructor
+        .def("submitted",
+             &LateAttr::submitted,
+             return_value_policy<copy_const_reference>(),
+             "Return the submitted time as a TimeSlot")
+        .def("active",
+             &LateAttr::active,
+             return_value_policy<copy_const_reference>(),
+             "Return the active time as a TimeSlot")
+        .def("complete",
+             &LateAttr::complete,
+             return_value_policy<copy_const_reference>(),
+             "Return the complete time as a TimeSlot")
+        .def("complete_is_relative",
+             &LateAttr::complete_is_relative,
+             "Returns a boolean where true means that complete is relative")
+        .def("is_late", &LateAttr::isLate, "Return True if late");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<std::shared_ptr<LateAttr>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<AutoCancelAttr, std::shared_ptr<AutoCancelAttr>>(
+        "Autocancel", NodeAttrDoc::autocancel_doc(), init<int, int, bool>() // hour, minute, relative
+        )
+        .def(init<int>()) // days
+        .def(init<TimeSlot, bool>())
+        .def(self == self)                           // __eq__
+        .def("__str__", &AutoCancelAttr::toString)   // __str__
+        .def("__copy__", copyObject<AutoCancelAttr>) // __copy__ uses copy constructor
+        .def(self < self)                            // __lt__
+        .def("time",
+             &AutoCancelAttr::time,
+             return_value_policy<copy_const_reference>(),
+             "returns cancel time as a TimeSlot")
+        .def("relative", &AutoCancelAttr::relative, "Returns a boolean where true means the time is relative")
+        .def("days", &AutoCancelAttr::days, "Returns a boolean true if time was specified in days");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<std::shared_ptr<AutoCancelAttr>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<AutoArchiveAttr, std::shared_ptr<AutoArchiveAttr>>(
+        "Autoarchive",
+        NodeAttrDoc::autoarchive_doc(),
+        init<int, int, bool, bool>() // hour, minute,relative,idle(true means queued,aborted,complete, false means
+                                     // completed only)
+        )
+        .def(init<int, bool>())                       // days, idle
+        .def(init<TimeSlot, bool, bool>())            // TimeSlot,relative,idle
+        .def(self == self)                            // __eq__
+        .def("__str__", &AutoArchiveAttr::toString)   // __str__
+        .def("__copy__", copyObject<AutoArchiveAttr>) // __copy__ uses copy constructor
+        .def(self < self)                             // __lt__
+        .def("time",
+             &AutoArchiveAttr::time,
+             return_value_policy<copy_const_reference>(),
+             "returns archive time as a TimeSlot")
+        .def("relative", &AutoArchiveAttr::relative, "Returns a boolean where true means the time is relative")
+        .def("days", &AutoArchiveAttr::days, "Returns a boolean true if time was specified in days")
+        .def("idle",
+             &AutoArchiveAttr::idle,
+             "Returns a boolean true if archiving when idle, i.e queued,aborted,complete and time elapsed");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    boost::python::register_ptr_to_python<std::shared_ptr<AutoArchiveAttr>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<AutoRestoreAttr, std::shared_ptr<AutoRestoreAttr>>("Autorestore", NodeAttrDoc::autorestore_doc())
+        .def("__init__", make_constructor(&create_AutoRestoreAttr))
+        .def(self == self)                            // __eq__
+        .def("__str__", &AutoRestoreAttr::toString)   // __str__
+        .def("__copy__", copyObject<AutoRestoreAttr>) // __copy__ uses copy constructor
+        .def("nodes_to_restore",
+             &AutoRestoreAttr::nodes_to_restore,
+             return_value_policy<copy_const_reference>(),
+             "returns a list of nodes to be restored");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    boost::python::register_ptr_to_python<std::shared_ptr<AutoRestoreAttr>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<RepeatDate>("RepeatDate",
+                       NodeAttrDoc::repeat_date_doc(),
+                       init<std::string, int, int, bp::optional<int>>()) // name, start, end , delta
+        .def(self == self)                                               // __eq__
+        .def("__str__", &RepeatDate::toString)                           // __str__
+        .def("__copy__", copyObject<RepeatDate>)                         // __copy__ uses copy constructor
+        .def("name", &RepeatDate::name, return_value_policy<copy_const_reference>(), "Return the name of the repeat.")
+        .def("start", &RepeatDate::start, "Return the start date as an integer in yyyymmdd format")
+        .def("end", &RepeatDate::end, "Return the end date as an integer in yyyymmdd format")
+        .def("step",
+             &RepeatDate::step,
+             "Return the step increment. This is used to update the repeat, until end date is reached");
+
+    class_<RepeatDateTime>(
+        "RepeatDateTime",
+        NodeAttrDoc::repeat_datetime_doc(),
+        init<std::string, std::string, std::string, bp::optional<std::string>>()) // name, start, end , delta
+        .def(self == self)                                                        // __eq__
+        .def("__str__", &RepeatDateTime::toString)                                // __str__
+        .def("__copy__", copyObject<RepeatDateTime>)                              // __copy__ uses copy constructor
+        .def("name",
+             &RepeatDateTime::name,
+             return_value_policy<copy_const_reference>(),
+             "Return the name of the repeat.")
+        .def(
+            "start", &RepeatDateTime::start, "Return the start date as an integer (i.e. seconds since 19700101T000000)")
+        .def("end", &RepeatDateTime::end, "Return the end date as an integer (i.e. seconds since 19700101T000000)")
+        .def("step",
+             &RepeatDateTime::step,
+             "Return the step increment (in seconds). This is used to update the repeat, until end instant is reached");
+
+    class_<RepeatDateList>("RepeatDateList", NodeAttrDoc::repeat_date_list_doc())
+        .def("__init__", make_constructor(&create_RepeatDateList))
+        .def(self == self)                           // __eq__
+        .def("__str__", &RepeatDateList::toString)   // __str__
+        .def("__copy__", copyObject<RepeatDateList>) // __copy__ uses copy constructor
+        .def("name",
+             &RepeatDateList::name,
+             return_value_policy<copy_const_reference>(),
+             "Return the name of the repeat.")
+        .def("start", &RepeatDateList::start, "Return the start date as an integer in yyyymmdd format")
+        .def("end", &RepeatDateList::end, "Return the end date as an integer in yyyymmdd format");
+
+    class_<RepeatInteger>("RepeatInteger",
+                          NodeAttrDoc::repeat_integer_doc(),
+                          init<std::string, int, int, bp::optional<int>>()) // name, start, end , delta = 1
+        .def(self == self)                                                  // __eq__
+        .def("__str__", &RepeatInteger::toString)                           // __str__
+        .def("__copy__", copyObject<RepeatInteger>)                         // __copy__ uses copy constructor
+        .def(
+            "name", &RepeatInteger::name, return_value_policy<copy_const_reference>(), "Return the name of the repeat.")
+        .def("start", &RepeatInteger::start)
+        .def("end", &RepeatInteger::end)
+        .def("step", &RepeatInteger::step);
+
+    // Create as shared because: we want to pass a Python list as part of the constructor,
+    // and the only way make_constructor works is with a pointer.
+    class_<RepeatEnumerated, std::shared_ptr<RepeatEnumerated>>("RepeatEnumerated",
+                                                                NodeAttrDoc::repeat_enumerated_doc())
+        .def("__init__", make_constructor(&create_RepeatEnumerated))
+        .def(self == self)                             // __eq__
+        .def("__str__", &RepeatEnumerated::toString)   // __str__
+        .def("__copy__", copyObject<RepeatEnumerated>) // __copy__ uses copy constructor
+        .def("name",
+             &RepeatEnumerated::name,
+             return_value_policy<copy_const_reference>(),
+             "Return the name of the `repeat`_.")
+        .def("start", &RepeatEnumerated::start)
+        .def("end", &RepeatEnumerated::end)
+        .def("step", &RepeatEnumerated::step);
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<std::shared_ptr<RepeatEnumerated>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<RepeatString, std::shared_ptr<RepeatString>>("RepeatString", NodeAttrDoc::repeat_string_doc())
+        .def("__init__", make_constructor(&create_RepeatString))
+        .def(self == self)                         // __eq__
+        .def("__str__", &RepeatString::toString)   // __str__
+        .def("__copy__", copyObject<RepeatString>) // __copy__ uses copy constructor
+        .def("name",
+             &RepeatString::name,
+             return_value_policy<copy_const_reference>(),
+             "Return the name of the `repeat`_.")
+        .def("start", &RepeatString::start)
+        .def("end", &RepeatString::end)
+        .def("step", &RepeatString::step);
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<std::shared_ptr<RepeatString>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<RepeatDay>("RepeatDay", NodeAttrDoc::repeat_day_doc(), init<bp::optional<int>>())
+        .def(self == self)                      // __eq__
+        .def("__str__", &RepeatDay::toString)   // __str__
+        .def("__copy__", copyObject<RepeatDay>) // __copy__ uses copy constructor
+        ;
+
+    class_<Repeat>("Repeat", NodeAttrDoc::repeat_doc(), init<int>())
+        .def(self == self)                   // __eq__
+        .def("__str__", &Repeat::toString)   // __str__
+        .def("__copy__", copyObject<Repeat>) // __copy__ uses copy constructor
+        .def("empty", &Repeat::empty, "Return true if the repeat is empty.")
+        .def("name",
+             &Repeat::name,
+             return_value_policy<copy_const_reference>(),
+             "The `repeat`_ name, can be referenced in `trigger`_ expressions")
+        .def("start", &Repeat::start, "The start value of the repeat, as an integer")
+        .def("end", &Repeat::end, "The last value of the repeat, as an integer")
+        .def("step", &Repeat::step, "The increment for the repeat, as an integer")
+        .def("value", &Repeat::last_valid_value, "The current value of the repeat as an integer");
+
+    void (CronAttr::*add_time_series)(const TimeSeries&) = &CronAttr::addTimeSeries;
+    void (CronAttr::*add_time_series_2)(const TimeSlot& s, const TimeSlot& f, const TimeSlot& i) =
+        &CronAttr::addTimeSeries;
+    class_<CronAttr, std::shared_ptr<CronAttr>>("Cron", NodeAttrDoc::cron_doc())
+        .def("__init__", raw_function(&cron_raw_constructor, 1)) // will call -> cron_init or cron_init1
+        .def("__init__", make_constructor(&cron_init))
+        .def("__init__", make_constructor(&cron_init1))
+        .def("__init__", make_constructor(&cron_create2))
+        .def("__init__", make_constructor(&cron_create))
+        .def(self == self)                     // __eq__
+        .def("__str__", &CronAttr::toString)   // __str__
+        .def("__copy__", copyObject<CronAttr>) // __copy__ uses copy constructor
+        .def("set_week_days",
+             &set_week_days,
+             "Specifies days of week. Expects a list of integers, with integer range 0==Sun to 6==Sat")
+        .def("set_last_week_days_of_the_month",
+             &set_last_week_days_of_month,
+             "Specifies last week days of the month. Expects a list of integers, with integer range 0==Sun to 6==Sat")
+        .def("set_days_of_month",
+             &set_days_of_month,
+             "Specifies days of the month. Expects a list of integers with integer range 1-31")
+        .def("set_last_day_of_the_month", &set_last_day_of_the_month, "Set cron for the last day of the month")
+        .def("set_months", &set_months, "Specifies months. Expects a list of integers, with integer range 1-12")
+        .def("set_time_series",
+             &CronAttr::add_time_series,
+             (bp::arg("hour"), bp::arg("minute"), bp::arg("relative") = false),
+             "time_series(hour(int),minute(int),relative to suite start(bool=false)), Add a time slot")
+        .def("set_time_series", add_time_series, "Add a time series. This will never complete")
+        .def("set_time_series", add_time_series_2, "Add a time series. This will never complete")
+        .def("set_time_series", &add_time_series_3, "Add a time series. This will never complete")
+        .def("time", &CronAttr::time, return_value_policy<copy_const_reference>(), "return cron time as a TimeSeries")
+        .def("last_day_of_the_month", &CronAttr::last_day_of_the_month, "Return true if last day of month is enabled")
+        .add_property("week_days",
+                      bp::range(&CronAttr::week_days_begin, &CronAttr::week_days_end),
+                      "returns a integer list of week days")
+        .add_property("last_week_days_of_the_month",
+                      bp::range(&CronAttr::last_week_days_of_month_begin, &CronAttr::last_week_days_end_of_month_end),
+                      "returns a integer list of last week days of the month")
+        .add_property("days_of_month",
+                      bp::range(&CronAttr::days_of_month_begin, &CronAttr::days_of_month_end),
+                      "returns a integer list of days of the month")
+        .add_property("months",
+                      bp::range(&CronAttr::months_begin, &CronAttr::months_end),
+                      "returns a integer list of months of the year");
+
+    class_<VerifyAttr>("Verify", init<NState::State, int>()) // state, expected
+        .def(self == self)                                   // __eq__
+        .def("__str__", &VerifyAttr::toString)               // __str__
+        .def("__copy__", copyObject<VerifyAttr>)             // __copy__ uses copy constructor
+        ;
+
+    class_<ClockAttr, std::shared_ptr<ClockAttr>>(
+        "Clock", NodeAttrDoc::clock_doc(), init<int, int, int, bp::optional<bool>>()) // day, month, year, hybrid
+        .def(init<int, int, int, bool>())
+        .def(init<bool>())
+        .def(self == self)                      // __eq__
+        .def("__str__", &ClockAttr::toString)   // __str__
+        .def("__copy__", copyObject<ClockAttr>) // __copy__ uses copy constructor
+        .def("set_gain_in_seconds", &ClockAttr::set_gain_in_seconds, "Set the gain in seconds")
+        .def("set_gain", &ClockAttr::set_gain, "Set the gain in hours and minutes")
+        .def("day", &ClockAttr::day, "Returns the day as an integer, range 1-31")
+        .def("month", &ClockAttr::month, "Returns the month as an integer, range 1-12")
+        .def("year", &ClockAttr::year, "Returns the year as an integer, > 1400")
+        .def("gain", &ClockAttr::gain, "Returns the gain as an long. This represents seconds")
+        .def("positive_gain",
+             &ClockAttr::positive_gain,
+             "Returns a boolean, where true means that the gain is positive");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<std::shared_ptr<ClockAttr>>(); // needed for mac and boost 1.6
+#endif
+
+    class_<ecf::AvisoAttr>("AvisoAttr", NodeAttrDoc::aviso_doc())
+        .def("__init__", make_constructor(&aviso_init))
+        .def(self == self)                      // __eq__
+        .def("__str__", &ecf::to_python_string) // __str__
+        .def("__copy__", copyObject<AvisoAttr>) // __copy__ uses copy constructor
+        .def("name",
+             &AvisoAttr::name,
+             return_value_policy<copy_const_reference>(),
+             "Returns the name of the Aviso attribute")
+        .def("listener",
+             &AvisoAttr::listener,
+             return_value_policy<copy_const_reference>(),
+             "Returns the Aviso listener configuration")
+        .def("url",
+             &AvisoAttr::url,
+             return_value_policy<copy_const_reference>(),
+             "Returns the URL used to contact the Aviso server")
+        .def("schema",
+             &AvisoAttr::schema,
+             return_value_policy<copy_const_reference>(),
+             "Returns the path to the schema used to contact the Aviso server")
+        .def("polling", &AvisoAttr::polling, "Returns polling interval used to contact the Aviso server")
+        .def("auth",
+             &AvisoAttr::auth,
+             return_value_policy<copy_const_reference>(),
+             "Returns the path to Authentication credentials used to contact the Aviso server");
+
+    class_<MirrorAttr>("MirrorAttr", NodeAttrDoc::mirror_doc())
+        .def("__init__", make_constructor(&mirror_init))
+        .def(self == self)                       // __eq__
+        .def("__str__", &ecf::to_python_string)  // __str__
+        .def("__copy__", copyObject<MirrorAttr>) // __copy__ uses copy constructor
+        .def("name",
+             &MirrorAttr::name,
+             return_value_policy<copy_const_reference>(),
+             "Returns the name of the Mirror attribute")
+        .def("remote_path",
+             &MirrorAttr::remote_path,
+             return_value_policy<copy_const_reference>(),
+             "Returns the path on the remote ecFlow server")
+        .def("remote_host",
+             &MirrorAttr::remote_host,
+             return_value_policy<copy_const_reference>(),
+             "Returns the host of the remote ecFlow server")
+        .def("remote_port",
+             &MirrorAttr::remote_port,
+             return_value_policy<copy_const_reference>(),
+             "Returns the port of the remote ecFlow server")
+        .def("ssl", &MirrorAttr::ssl, "Returns a boolean, where true means that SSL is enabled")
+        .def("polling", &MirrorAttr::polling, "Returns the polling interval used to contact the remove ecFlow server")
+        .def("auth",
+             &MirrorAttr::auth,
+             return_value_policy<copy_const_reference>(),
+             "Returns the path to Authentication credentials used to contact the remote ecFlow server");
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ExportSuiteAndFamily.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ExportSuiteAndFamily.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ExportSuiteAndFamily.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ExportSuiteAndFamily.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,153 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/python.hpp>
+#include <boost/python/raw_function.hpp>
+#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/DefsDoc.hpp"
+#include "ecflow/python/NodeUtil.hpp"
+
+using namespace ecf;
+using namespace boost::python;
+using namespace std;
+namespace bp = boost::python;
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+
+/// Since we don't pass in a child pos, the nodes are added to the end
+family_ptr add_family(NodeContainer* self, family_ptr f) {
+    self->addFamily(f);
+    return f;
+}
+task_ptr add_task(NodeContainer* self, task_ptr t) {
+    self->addTask(t);
+    return t;
+}
+
+suite_ptr add_clock(suite_ptr self, const ClockAttr& clk) {
+    self->addClock(clk);
+    return self;
+}
+suite_ptr add_end_clock(suite_ptr self, const ClockAttr& clk) {
+    self->add_end_clock(clk);
+    return self;
+}
+
+// Sized and Container protocol
+size_t family_len(family_ptr self) {
+    return self->nodeVec().size();
+}
+size_t suite_len(suite_ptr self) {
+    return self->nodeVec().size();
+}
+bool family_container(family_ptr self, const std::string& name) {
+    size_t pos;
+    return (self->findImmediateChild(name, pos)) ? true : false;
+}
+bool suite_container(suite_ptr self, const std::string& name) {
+    size_t pos;
+    return (self->findImmediateChild(name, pos)) ? true : false;
+}
+
+// Context management, Only used to provide indentation
+suite_ptr suite_enter(suite_ptr self) {
+    return self;
+}
+bool suite_exit(suite_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
+    return false;
+}
+family_ptr family_enter(family_ptr self) {
+    return self;
+}
+bool family_exit(family_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
+    return false;
+}
+
+family_ptr family_init(const std::string& name, bp::list the_list, bp::dict kw) {
+    // cout << "family_init : " << name << " the_list: " << len(the_list) << " dict: " << len(kw) << endl;
+    family_ptr node = Family::create(name);
+    (void)NodeUtil::add_variable_dict(node, kw);
+    (void)NodeUtil::node_iadd(node, the_list);
+    return node;
+}
+
+suite_ptr suite_init(const std::string& name, bp::list the_list, bp::dict kw) {
+    // cout << "suite_init : " << name << " the_list: " << len(the_list) << " dict: " << len(kw) << endl;
+    suite_ptr node = Suite::create(name);
+    (void)NodeUtil::add_variable_dict(node, kw);
+    (void)NodeUtil::node_iadd(node, the_list);
+    return node;
+}
+
+void export_SuiteAndFamily() {
+    // Turn off proxies by passing true as the NoProxy template parameter.
+    // shared_ptrs don't need proxies because calls on one a copy of the
+    // shared_ptr will affect all of them (duh!).
+    class_<std::vector<family_ptr>>("FamilyVec", "Hold a list of `family`_ nodes")
+        .def(vector_indexing_suite<std::vector<family_ptr>, true>());
+
+    class_<std::vector<suite_ptr>>("SuiteVec", "Hold a list of `suite`_ nodes's")
+        .def(vector_indexing_suite<std::vector<suite_ptr>, true>());
+
+    // choose the correct overload
+    class_<NodeContainer, bases<Node>, boost::noncopyable>("NodeContainer", DefsDoc::node_container_doc(), no_init)
+        .def("__iter__", bp::range(&NodeContainer::node_begin, &NodeContainer::node_end))
+        .def("add_family", &NodeContainer::add_family, DefsDoc::add_family_doc())
+        .def("add_family", add_family)
+        .def("add_task", &NodeContainer::add_task, DefsDoc::add_task_doc())
+        .def("add_task", add_task)
+        .def("find_node", &NodeContainer::find_by_name, "Find immediate child node given a name")
+        .def("find_task", &NodeContainer::findTask, "Find a task given a name")
+        .def("find_family", &NodeContainer::findFamily, "Find a family given a name")
+        .add_property(
+            "nodes", bp::range(&NodeContainer::node_begin, &NodeContainer::node_end), "Returns a list of Node's");
+
+    class_<Family, bases<NodeContainer>, family_ptr>("Family", DefsDoc::family_doc())
+        .def("__init__", raw_function(&NodeUtil::node_raw_constructor, 1)) // will call -> family_init
+        .def("__init__", make_constructor(&family_init), DefsDoc::family_doc())
+        .def("__init__", make_constructor(&Family::create_me), DefsDoc::family_doc())
+        .def(self == self)                      // __eq__
+        .def("__str__", &Family::to_string)     // __str__
+        .def("__copy__", copyObject<Family>)    // __copy__ uses copy constructor
+        .def("__enter__", &family_enter)        // allow with statement, hence indentation support
+        .def("__exit__", &family_exit)          // allow with statement, hence indentation support
+        .def("__len__", &family_len)            // Implement sized protocol for immediate children
+        .def("__contains__", &family_container) // Implement container protocol for immediate children
+        ;
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<family_ptr>(); // needed for mac and boost 1.6
+#endif
+
+    class_<Suite, bases<NodeContainer>, suite_ptr>("Suite", DefsDoc::suite_doc())
+        .def("__init__", raw_function(&NodeUtil::node_raw_constructor, 1)) // will call -> suite_init
+        .def("__init__", make_constructor(&suite_init), DefsDoc::suite_doc())
+        .def("__init__", make_constructor(&Suite::create_me), DefsDoc::suite_doc())
+        .def(self == self)                     // __eq__
+        .def("__str__", &Suite::to_string)     // __str__
+        .def("__copy__", copyObject<Suite>)    // __copy__ uses copy constructor
+        .def("__enter__", &suite_enter)        // allow with statement, hence indentation support
+        .def("__exit__", &suite_exit)          // allow with statement, hence indentation support
+        .def("__len__", &suite_len)            // Implement sized protocol for immediate children
+        .def("__contains__", &suite_container) // Implement container protocol for immediate children
+        .def("add_clock", &add_clock)
+        .def("get_clock", &Suite::clockAttr, "Returns the `suite`_ `clock`_")
+        .def("add_end_clock", &add_end_clock, "End clock, used to mark end of simulation")
+        .def("get_end_clock", &Suite::clock_end_attr, "Return the suite's end clock. Can be NULL")
+        .def("begun", &Suite::begun, "Returns true if the `suite`_ has begun, false otherwise");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<suite_ptr>(); // needed for mac and boost 1.6
+#endif
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/ExportTask.cpp 5.13.0-1/libs/pyext/src/ecflow/python/ExportTask.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/ExportTask.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/ExportTask.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,98 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/python.hpp>
+#include <boost/python/raw_function.hpp>
+#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
+
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/DefsDoc.hpp"
+#include "ecflow/python/NodeUtil.hpp"
+
+using namespace ecf;
+using namespace boost::python;
+using namespace std;
+namespace bp = boost::python;
+
+// Sized protocol
+bool task_len(task_ptr self) {
+    return self->aliases().size();
+}
+
+task_ptr task_enter(task_ptr self) {
+    return self;
+}
+bool task_exit(task_ptr self, const bp::object& type, const bp::object& value, const bp::object& traceback) {
+    return false;
+}
+
+task_ptr task_init(const std::string& name, bp::list the_list, bp::dict kw) {
+    // cout << "task_init: " << name << " the_list: " << len(the_list) << " dict: " << len(kw) << endl;
+    task_ptr node = Task::create(name);
+    (void)NodeUtil::add_variable_dict(node, kw);
+    (void)NodeUtil::node_iadd(node, the_list);
+    return node;
+}
+
+// See: http://wiki.python.org/moin/boost.python/HowTo#boost.function_objects
+
+void export_Task() {
+    // Turn off proxies by passing true as the NoProxy template parameter.
+    // shared_ptrs don't need proxies because calls on one a copy of the
+    // shared_ptr will affect all of them (duh!).
+    class_<std::vector<task_ptr>>("TaskVec", "Hold a list of `task`_ nodes")
+        .def(vector_indexing_suite<std::vector<task_ptr>, true>());
+
+    class_<Submittable, bases<Node>, boost::noncopyable>("Submittable", DefsDoc::submittable_doc(), no_init)
+        .def("get_jobs_password",
+             &Submittable::jobsPassword,
+             return_value_policy<copy_const_reference>(),
+             "The password. This generated by server")
+        .def("get_process_or_remote_id",
+             &Submittable::process_or_remote_id,
+             return_value_policy<copy_const_reference>(),
+             "The process or remote id of the running job")
+        .def("get_try_no", &Submittable::tryNo, "The current try number as a string.")
+        .def("get_int_try_no", &Submittable::try_no, "The current try number as integer.")
+        .def("get_aborted_reason",
+             &Submittable::abortedReason,
+             return_value_policy<copy_const_reference>(),
+             "If node was aborted and a reason was provided, return the string");
+
+    class_<Task, bases<Submittable>, task_ptr>("Task", DefsDoc::task_doc())
+        .def("__init__", raw_function(&NodeUtil::node_raw_constructor, 1)) // will call -> task_init
+        .def("__init__", make_constructor(&task_init), DefsDoc::task_doc())
+        .def("__init__",
+             make_constructor(&Task::create_me),
+             DefsDoc::task_doc())          // create_me take a single string argument
+        .def(self == self)                 // __eq__
+        .def("__enter__", &task_enter)     // allow with statement, hence indentation support
+        .def("__exit__", &task_exit)       // allow with statement, hence indentation support
+        .def("__str__", &Task::to_string)  // __str__
+        .def("__copy__", copyObject<Task>) // __copy__ uses copy constructor
+        .def("__len__", &task_len)         // Implement sized protocol for immediate children
+        .def("__iter__", bp::range(&Task::alias_begin, &Task::alias_end)) // implement iter protocol
+        .add_property("aliases", bp::range(&Task::alias_begin, &Task::alias_end), "Returns a list of aliases")
+        .add_property("nodes", bp::range(&Task::alias_begin, &Task::alias_end), "Returns a list of aliases");
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<task_ptr>(); // needed for mac and boost 1.6
+#endif
+
+    class_<Alias, bases<Submittable>, alias_ptr>("Alias", DefsDoc::alias_doc(), no_init)
+        .def(self == self)                  // __eq__
+        .def("__str__", &Alias::to_string)  // __str__
+        .def("__copy__", copyObject<Alias>) // __copy__ uses copy constructor
+        ;
+#if ECF_ENABLE_PYTHON_PTR_REGISTER
+    bp::register_ptr_to_python<alias_ptr>(); // needed for mac and boost 1.6
+#endif
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/GlossaryDoc.cpp 5.13.0-1/libs/pyext/src/ecflow/python/GlossaryDoc.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/GlossaryDoc.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/GlossaryDoc.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/GlossaryDoc.hpp"
+
+const char* GlossaryDoc::list() {
+    return "Create a empty Defs\n\n"
+        // ".. _active: glossary_\n"
+        // ".. _aborted: glossary_\n"
+        // ".. _autocancel: glossary_\n"
+        // ".. _complete expression: glossary_\n"
+        // ".. _check point: glossary_\n"
+        // ".. _child command: glossary_\n"
+        // ".. _clock: glossary_\n"
+        // ".. _complete: glossary_\n"
+        // ".. _cron: glossary_\n"
+        // ".. _date: glossary_\n"
+        // ".. _day: glossary_\n"
+        // ".. _defstatus: glossary_\n"
+        // ".. _dependencies: glossary_\n"
+        // ".. _ecflow_server: glossary_\n"
+        // ".. _ecf script: glossary_\n"
+        // ".. _event: glossary_\n"
+        // ".. _extern: glossary_\n"
+        // ".. _family: glossary_\n"
+        // ".. _halted: glossary_\n"
+        // ".. _inlimit: glossary_\n"
+        // ".. _job creation: glossary_\n"
+        // ".. _job file: glossary_\n"
+        // ".. _label: glossary_\n"
+        // ".. _late: glossary_\n"
+        // ".. _limit: glossary_\n"
+        // ".. _meter: glossary_\n"
+        // ".. _node: glossary_\n"
+        // ".. _pre-processing: glossary_\n"
+        // ".. _repeat: glossary_\n"
+        // ".. _server states: glossary_\n"
+        // ".. _suite definition: glossary_\n"
+        // ".. _submitted: glossary_\n"
+        // ".. _suite: glossary_\n"
+        // ".. _shutdown: glossary_\n"
+        // ".. _suspended: glossary_\n"
+        // ".. _task: glossary_\n"
+        // ".. _time: glossary_\n"
+        // ".. _today: glossary_\n"
+        // ".. _trigger: glossary_\n"
+        // ".. _queued: glossary_\n"
+        // ".. _unknown: glossary_\n"
+        // ".. _variable inheritance: glossary_\n"
+        // ".. _variable substitution: glossary_\n"
+        // ".. _variable: glossary_\n"
+        // ".. _zombie: glossary_\n"
+        // ".. _zombie type: glossary_\n"
+        // ".. _glossary: https://confluence.ecmwf.int/display/ECFLOW/Glossary\n"
+        ;
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/GlossaryDoc.hpp 5.13.0-1/libs/pyext/src/ecflow/python/GlossaryDoc.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/GlossaryDoc.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/GlossaryDoc.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_GlossaryDoc_HPP
+#define ecflow_python_GlossaryDoc_HPP
+
+#include <boost/core/noncopyable.hpp>
+
+// ===========================================================================
+// IMPORTANT: These appear as python doc strings.
+//            Additionally they are auto documented using sphinx-poco
+//            Hence the doc strings use reStructuredText markup.
+// ===========================================================================
+class GlossaryDoc {
+public:
+    GlossaryDoc()                              = delete;
+    GlossaryDoc(const GlossaryDoc&)            = delete;
+    GlossaryDoc& operator=(const GlossaryDoc&) = delete;
+
+    static const char* list();
+};
+
+#endif /* ecflow_python_GlossaryDoc_HPP */
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/NodeAttrDoc.cpp 5.13.0-1/libs/pyext/src/ecflow/python/NodeAttrDoc.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/NodeAttrDoc.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/NodeAttrDoc.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,758 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/NodeAttrDoc.hpp"
+
+const char* NodeAttrDoc::variable_doc() {
+    return "Defines a `variable`_ on a `node`_ for use in `ecf script`_.\n\n"
+           "A Node can have a number of variables.\n"
+           "These variables can be added at any node level: Defs, `suite`_, `family`_ or `task`_.\n"
+           "The variables are names inside a pair of '%' characters in an `ecf script`_.\n"
+           "The content of a variable replaces the variable name in the `ecf script`_ at\n"
+           "job submission time. When a variable is needed at submission time, it is first\n"
+           "sought in the task itself. If it is not found, it is sought from the tasks parent\n"
+           "and so on, up through the node levels until found. See `variable inheritance`_\n"
+           "A undefined variable in a `ecf script`_, causes the `task`_ to be `aborted`_,\n"
+           "without the job being submitted.\n"
+           "\nConstructor::\n\n"
+           "   Variable(name,value)\n"
+           "      string name: the name of the variable\n"
+           "      string value: The value of the variable\n\n"
+           "   Edit(dict,kwarg) # alternative that allows multiple variables\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   ...\n"
+           "   var = Variable('ECF_JOB_CMD','/bin/sh %ECF_JOB% &')\n"
+           "   task.add_variable(var)\n"
+           "   task.add_variable('JOE','90')\n\n"
+           "The following use example of using Edit, which allow multiple variables to added at the same time :\n\n"
+           ".. code-block:: python\n\n"
+           "   t = Task('t1',\n"
+           "             Edit({ 'a':'y', 'b':'bb'}, c='v',d='b'),\n"
+           "             Edit({ 'e':1100, 'f':'bb'}),\n"
+           "             Edit(g='d'),\n"
+           "             Edit(h='1'))\n\n"
+           ".. code-block:: python\n\n"
+           "  defs = Defs(\n"
+           "            Suite('s1'),\n"
+           "            Edit(SLEEP='1')) # Add user variable to definition\n"
+           "  defs.s1 += [ Task('a') ]\n"
+           "  defs.s1.a += [ Edit({ 'x1':'y', 'aa1':'bb'}, a='v',b='b'),\n"
+           "                 Edit({ 'var':10, 'aa':'bb'}),\n"
+           "                 Edit(d='d') ]\n";
+}
+
+const char* NodeAttrDoc::zombie_doc() {
+    return "The `zombie`_ attribute defines how a `zombie`_ should be handled in an automated fashion\n\n"
+           "Very careful consideration should be taken before this attribute is added\n"
+           "as it may hide a genuine problem.\n"
+           "It can be added to any `node`_. But is best defined at the `suite`_ or `family`_ level.\n"
+           "If there is no zombie attribute the default behaviour is to block the init,complete,abort `child "
+           "command`_.\n"
+           "and *fob* the event,label,and meter `child command`_\n"
+           "This attribute allows the server to make a automated response.\n"
+           "Please see: :py:class:`ecflow.ZombieType`, :py:class:`ecflow.ChildCmdType`, "
+           ":py:class:`ecflow.ZombieUserActionType`\n"
+           "\nConstructor::\n\n"
+           "   ZombieAttr(ZombieType,ChildCmdTypes, ZombieUserActionType, lifetime)\n"
+           "      ZombieType            : Must be one of ZombieType.ecf, ZombieType.path, ZombieType.user\n"
+           "      ChildCmdType          : A list(ChildCmdType) of Child commands. Can be left empty in\n"
+           "                              which case the action affect all child commands\n"
+           "      ZombieUserActionType  : One of [ fob, fail, block, remove, adopt ]\n"
+           "      int lifetime<optional>: Defines the life time in seconds of the zombie in the server.\n"
+           "                              On expiration, zombie is removed automatically\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   # Add a zombie attribute so that child commands(i.e ecflow_client --init)\n"
+           "   # will fail the job if it is a zombie process.\n"
+           "   s1 = Suite('s1')\n"
+           "   child_list = [ ChildCmdType.init, ChildCmdType.complete, ChildCmdType.abort ]\n"
+           "   s1.add_zombie( ZombieAttr(ZombieType.ecf, child_list, ZombieUserActionType.fob))\n\n"
+           "   # create the zombie as part of the node constructor\n"
+           "   s1 = Suite('s1',\n"
+           "              ZombieAttr(ZombieType.ecf, child_list, ZombieUserActionType.fail))\n";
+}
+
+const char* NodeAttrDoc::zombie_type_doc() {
+    return "`zombie`_\\ s are running jobs that fail authentication when communicating with the `ecflow_server`_.\n\n"
+           "See class `zombie type`_ and :py:class:`ecflow.ZombieAttr` for further information.\n";
+}
+
+const char* NodeAttrDoc::zombie_user_action_type_doc() {
+    return "ZombieUserActionType is used define an automated response. See class :py:class:`ZombieAttr`\n\n"
+           "This can be either on the client side or on the server side\n"
+           "\nclient side:\n\n"
+           "- fob:    The `child command`_ always succeeds, i.e allows job to complete without blocking\n"
+           "- fail:   The `child command`_ is asked to fail.\n"
+           "- block:  The `child command`_ is asked to block.\n"
+           "  This is the default action for init,complete and abort child commands\n"
+           "\nserver side:\n\n"
+           "- adopt:  Allows the password supplied with the `child command`_\\ s, to be adopted by the server\n"
+           "- kill:   Kills the zombie process associated with the `child command`_ using ECF_KILL_CMD.\n"
+           "  path zombies will need to be killed manually. If kill is specified for path zombies\n"
+           "  they will be fobed, i.e allowed to complete without blocking the job.\n"
+           "- remove: `ecflow_server`_ removes the `zombie`_ from the zombie list.\n"
+           "  The child continues blocking. If the process is still running, the\n"
+           "  `zombie`_ may well re-appear\n\n"
+           "Note: Only adopt will allow the `child command`_ to continue and change the `node`_ tree\n";
+}
+
+const char* NodeAttrDoc::child_cmd_type_doc() {
+    return "ChildCmdType represents the different `child command`_\\ s.\n"
+           "This type is used as a parameter to the class :py:class:`ecflow.ZombieAttr`\n\n"
+           "Child commands are called within a `job file`_::\n\n"
+           "  ChildCmdType::init     corresponds to : ecflow_client --init=<process_id>\n"
+           "  ChildCmdType::event    corresponds to : ecflow_client --event=<event_name | number>\n"
+           "  ChildCmdType::meter    corresponds to : ecflow_client --meter=<meter_name>, <meter_value>\n"
+           "  ChildCmdType::label    corresponds to : ecflow_client --label=<label_name>. <label_value>\n"
+           "  ChildCmdType::wait     corresponds to : ecflow_client --wait=<expression>\n"
+           "  ChildCmdType::abort    corresponds to : ecflow_client --abort=<reason>\n"
+           "  ChildCmdType::complete corresponds to : ecflow_client --complete\n";
+}
+
+const char* NodeAttrDoc::label_doc() {
+    return "A `label`_ has a name and value and provides a way of displaying information in a GUI.\n\n"
+           "The value can be anything(ASCII) as it cannot be used in triggers.\n"
+           "The value of the label is set to be the default value given in the definition\n"
+           "when the `suite`_ is begun. This is useful in repeated suites: A task sets the label\n"
+           "to be something.\n\n"
+           "Labels can be set at any level: Suite,Family,Task.\n"
+           "There are two ways of updating the label\n\n"
+           "- A `child command`_ can be used to automatically update the label on a `task`_\n"
+           "- Using the alter command, the labels on `suite`_ `family`_ and `task`_ can be changed manually\n"
+           "\nConstructor::\n\n"
+           "   Label(name,value)\n"
+           "      string name:  The name of the label\n"
+           "      string value: The value of the label\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   t1 = Task('t1',\n"
+           "             Label('name','value'),  # create Labels in-place\n"
+           "             Label('a','b'))\n"
+           "   t1.add_label('l1','value')\n"
+           "   t1.add_label(Label('l2','value2'))\n"
+           "   for label in t1.labels:\n"
+           "      print(label)\n";
+}
+
+const char* NodeAttrDoc::limit_doc() {
+    return "`limit`_ provides a simple load management\n\n"
+           "i.e. by limiting the number of `task`_\\ s submitted by a server.\n"
+           "Limits are typically defined at the `suite`_ level, or defined in a\n"
+           "separate suite, so that they can be used by multiple suites.\n"
+           "Once a limit is defined in a `suite definition`_, you must also assign families/tasks to use\n"
+           "this limit. See  `inlimit`_ and :py:class:`ecflow.InLimit`\n"
+           "\nConstructor::\n\n"
+           "   Limit(name,value)\n"
+           "      string name: the name of the limit\n"
+           "      int   value: The value of the limit\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   limit = Limit('fast', 10)\n"
+           "    ...\n"
+           "   suite = Suite('s1',\n"
+           "                 Limit('slow',10))  # create Limit in Node constructor\n"
+           "   suite.add_limit(limit)           # add existing limit using function\n";
+}
+
+const char* NodeAttrDoc::inlimit_doc() {
+    return "`inlimit`_ is used in conjunction with `limit`_ to provide simple load management:\n\n"
+           ".. code-block:: shell\n\n"
+           "   suite x\n"
+           "      limit fast 1\n"
+           "      family f\n"
+           "         inlimit /x:fast\n"
+           "         task t1\n"
+           "         task t2\n\n"
+           "Here 'fast' is the name of :py:class:`ecflow.Limit` and the number defines the maximum number of tasks\n"
+           "that can run simultaneously using this limit. That is why you do not need a `trigger`_\n"
+           "between tasks 't1' and 't2'. There is no need to change the tasks. The jobs are\n"
+           "created in the order they are defined\n"
+           "\nConstructor::\n\n"
+           "   InLimit(name, optional<path = ''>, optional<token = 1>, optional<limit_this_node_only = false>)\n"
+           "      string name           : The name of the referenced Limit\n"
+           "      string path<optional> : The path to the Limit, if this is left out, then Limit of 'name' must be "
+           "specified\n"
+           "                              some where up the parent hierarchy\n"
+           "      int value<optional>   : The usage of the Limit. Each job submission will consume 'value' tokens\n"
+           "                              from the Limit. defaults to 1 if no value specified.\n"
+           "      bool limit_this_node_only<optional> : Only limits this node and *NOT* its children\n"
+           "                                            Can be used load balance families\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   inlimit = InLimit('fast','/x/f', 2)\n"
+           "    ...\n"
+           "   family = Family('f1',\n"
+           "                   InLimit('mars','/x/f', 2)) # create InLimit in Node constructor\n"
+           "   family.add_inlimit(inlimit)                # add existing inlimit using function\n";
+}
+
+const char* NodeAttrDoc::event_doc() {
+    return "`event`_\\ s are used as signal mechanism.\n\n"
+           "Typically they would be used to signal partial completion of a `task`_\n"
+           "and to be able to `trigger`_ another job, which is waiting for this partial completion.\n"
+           "Only tasks can have events that are automatically set via a `child command`_\\ s, see below.\n"
+           "Events are cleared automatically when a `node`_ is re-queued or begun.\n"
+           "Suites and Families can have events, but these events must be set via the Alter command\n"
+           "Multiple events can be added to a task.\n"
+           "An Event has a number and a optional name. Events are typically used\n"
+           "in `trigger`_ and `complete expression`_ , to control job creation.\n"
+           "Event are fired within a script/`job file`_, i.e.:\n\n"
+           ".. code-block:: shell\n\n"
+           "   ecflow_client --init=$$\n"
+           "   ecflow_client --event=foo\n"
+           "   ecflow_client --complete\n\n"
+           "Hence the defining of an event for a `task`_, should be followed with the addition of ecflow_client "
+           "--event\n"
+           "`child command`_ in the corresponding `ecf script`_ file.\n"
+           "\nConstructor::\n\n"
+           "   Event(number, optional<name = ''>)\n"
+           "      int number            : The number must be >= 0\n"
+           "      string name<optional> : If name is given, can only refer to Event by its name\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   event = Event(2,'event_name')\n"
+           "   task.add_event(event)\n"
+           "   task1.add_event('2')          # create an event '2' and add to the task\n"
+           "   task2.add_event('name')       # create an event 'name' and add to task\n\n"
+           "   # Events can be created in the Task constructor, like any other attribute\n"
+           "   t = Task('t3',\n"
+           "            Event(2,'event_name'))\n";
+}
+
+const char* NodeAttrDoc::meter_doc() {
+    return "`meter`_\\ s can be used to indicate proportional completion of `task`_\n\n"
+           "They are able to `trigger`_ another job, which is waiting on this proportion.\n"
+           "Can also be used to indicate progress of a job. Meters can be used in\n"
+           "`trigger`_ and `complete expression`_.\n"
+           "\nConstructor::\n\n"
+           "   Meter(name,min,max,<optional>color_change)\n"
+           "      string name                : The meter name\n"
+           "      int min                    : The minimum and initial meter value\n"
+           "      int max                    : The maximum meter value. Must be greater than min value.\n"
+           "      int color_change<optional> : default = max, Must be between min-max, used in the GUI\n"
+           "\nExceptions:\n\n"
+           "- raises IndexError when an invalid Meter is specified\n"
+           "\nUsage:\n\n"
+           "Using a meter requires:\n\n"
+           "- Defining a meter on a `task`_:\n\n"
+           ".. code-block:: python\n\n"
+           "     meter = Meter('progress',0,100,100)\n"
+           "     task.add_meter(meter)\n\n"
+           "- Updating the corresponding `ecf script`_ file with the meter `child command`_:\n\n"
+           ".. code-block:: shell\n\n"
+           "     ecflow_client --init=$$\n"
+           "     for i in 10 20 30 40 50 60 80 100; do\n"
+           "         ecflow_client --meter=progress $i\n"
+           "         sleep 2 # or do some work\n"
+           "     done\n"
+           "     ecflow_client --complete\n\n"
+           "- Optionally addition in a `trigger`_ or `complete expression`_ for job control:\n\n"
+           "  .. code-block:: shell\n\n"
+           "     trigger task:progress ge 60\n\n"
+           "  trigger and complete expression should *avoid* using equality i.e.:\n\n"
+           "  .. code-block:: shell\n\n"
+           "     trigger task:progress == 60\n\n"
+           "  Due to network issues the meter event's may **not** arrive in sequential order\n"
+           "  hence the `ecflow_server`_ will ignore meter value's, which are less than the current value\n"
+           "  as a result triggers's which use meter equality may never evaluate\n";
+}
+
+const char* NodeAttrDoc::queue_doc() {
+    return "Queue allows specification of queue on Task, Family and Suite nodes\n\n";
+}
+
+const char* NodeAttrDoc::date_doc() {
+    return "Used to define a `date`_ dependency.\n\n"
+           "There can be multiple Date dependencies for a `node`_.\n"
+           "Any of the 3 attributes, i.e. day, month, year can be wild carded using a zero\n"
+           "If a hybrid `clock`_ is defined on a suite, any node held by a date dependency\n"
+           "will be set to `complete`_ at the beginning of the `suite`_, without the\n"
+           "task ever being dispatched otherwise, the suite would never complete.\n"
+           "\nConstructor::\n\n"
+           "  Date(string)\n"
+           "     string : * means wild card\n"
+           "  Date(day,month,year)\n"
+           "     int day   : represents the day, zero means wild card. day >= 0 & day < 31\n"
+           "     int month : represents the month, zero means wild card. month >= 0 & month < 12\n"
+           "     int year  : represents the year, zero means wild card. year >= 0\n"
+           "\nExceptions:\n\n"
+           "- raises IndexError when an invalid date is specified\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "  date = Date(11,12,2010)  # represent 11th of December 2010\n"
+           "  date = Date(1,0,0);      # means the first day of every month of every year\n"
+           "  t = Task('t1',\n"
+           "            Date('1.*.*'));  # Create Date in place.\n";
+}
+
+const char* NodeAttrDoc::day_doc() {
+    return "Defines a `day`_ dependency.\n\n"
+           "There can be multiple day dependencies. If a hybrid `clock`_ is defined\n"
+           "on a suite, any node held by a day dependency will be set to `complete`_ at the\n"
+           "beginning of the `suite`_, without the task ever being dispatched otherwise\n"
+           "the suite would never complete.\n"
+           "\nConstructor::\n\n"
+           "   Day(string)\n"
+           "      string: 'sunday','monday',etc\n"
+           "   Day(Days)\n"
+           "      Days day: Is an enumerator with represent the days of the week\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   day1 = Day(Days.sunday)\n"
+           "   t = Task('t1',\n"
+           "           Day('tuesday'))\n";
+}
+
+const char* NodeAttrDoc::days_enum_doc() {
+    return "This enum is used as argument to a :py:class:`ecflow.Day` class.\n\n"
+           "It represents the days of the week\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   day1 = Day(Days.sunday)\n"
+           "   day2 = Day(Days.monday)\n"
+           "   t = Task('t1',\n"
+           "           day1,\n"
+           "           day2,\n"
+           "           Day(Days.tuesday))\n";
+}
+
+const char* NodeAttrDoc::time_doc() {
+    return "Is used to define a `time`_ dependency\n\n"
+           "This can then control job submission.\n"
+           "There can be multiple time dependencies for a node, however overlapping times may\n"
+           "cause unexpected results. The time dependency can be made relative to the beginning\n"
+           "of the suite or in repeated families relative to the beginning of the repeated family.\n"
+           "\nConstructor::\n\n"
+           "   Time(string)\n"
+           "     string: i.e '00:30' || '00:30 20:00 00:30'"
+           "   Time(hour,minute,relative<optional> = false)\n"
+           "      int hour:               hour in 24 clock\n"
+           "      int minute:             minute <= 59\n"
+           "      bool relative<optional>: default = False, Relative to suite start or repeated node.\n\n"
+           "   Time(single,relative<optional> = false)\n"
+           "      TimeSlot single:         A single time\n"
+           "      bool relative:           Relative to suite start or repeated node. Default is false\n\n"
+           "   Time(start,finish,increment,relative<optional> = false)\n"
+           "      TimeSlot start:          The start time\n"
+           "      TimeSlot finish:         The finish/end time\n"
+           "      TimeSlot increment:      The increment\n"
+           "      bool relative<optional>: default = False, relative to suite start or repeated node\n\n"
+           "   Time(time_series)\n"
+           "      TimeSeries time_series:Similar to constructor above\n"
+           "\nExceptions:\n\n"
+           "- raises IndexError when an invalid Time is specified\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   time1 = Time( 10,10 )                                                   #  time 10:10 \n"
+           "   time2 = Time( TimeSlot(10,10), true)                                    #  time +10:10 \n"
+           "   time2 = Time( TimeSlot(10,10), TimeSlot(20,10),TimeSlot(0,10), false )  #  time 10:10 20:10 00:10 \n\n"
+           "   t = Task('t1',\n"
+           "            time1,time2,time3,\n"
+           "            Time('10:30 20:10 00:10')) # Create time in place\n";
+}
+
+const char* NodeAttrDoc::today_doc() {
+    return "`today`_ is a time dependency that does not wrap to tomorrow.\n\n"
+           "If the `suite`_\\ s begin time is past the time given for the Today,\n"
+           "then the node is free to run.\n"
+           "\nConstructor::\n\n"
+           "   Today(hour,minute,relative<optional> = false)\n"
+           "      int hour               : hour in 24 clock\n"
+           "      int minute             : minute <= 59\n"
+           "      bool relative<optional>: Default = false,Relative to suite start or repeated node.\n\n"
+           "   Today(single,relative<optional> = false)\n"
+           "      TimeSlot single        : A single time\n"
+           "      bool relative          : Relative to suite start or repeated node. Default is false\n\n"
+           "   Today(start,finish,increment,relative<optional> = false)\n"
+           "      TimeSlot start         : The start time\n"
+           "      TimeSlot finish        : The finish/end time. This must be greater than the start time.\n"
+           "      TimeSlot increment     : The increment\n"
+           "      bool relative<optional>: Default = false, Relative to suite start or repeated node.\n\n"
+           "   Today(time_series)\n"
+           "      TimeSeries time_series: Similar to constructor above\n"
+           "\nExceptions:\n\n"
+           "- raises IndexError when an invalid Today is specified\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   today1 = Today( 10,10 )                                                   #  today 10:10 \n"
+           "   today2 = Today( TimeSlot(10,10) )                                         #  today 10:10 \n"
+           "   today3 = Today( TimeSlot(10,10), true)                                    #  today +10:10 \n"
+           "   today4 = Today( TimeSlot(10,10), TimeSlot(20,10),TimeSlot(0,10), false )  #  time 10:10 20:10 00:10 \n"
+           "   t = Task('t1',\n"
+           "            today1,today2,today3,today4,\n"
+           "            Today('10:30 20:10 00:10')) # Create today in place\n";
+}
+
+const char* NodeAttrDoc::late_doc() {
+    return "Sets the `late`_ flag.\n\n"
+           "When a Node is classified as being late, the only action `ecflow_server`_ can take\n"
+           "is to set a flag. The GUI will display this alongside the `node`_ name as a icon.\n"
+           "Only one Late attribute can be specified on a Node.\n"
+           "\nConstructor::\n\n"
+           "   Late()\n"
+           "   Late(kwargs)\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   # This is interpreted as: The node can stay `submitted`_ for a maximum of 15 minutes\n"
+           "   # and it must become `active`_ by 20:00 and the run time must not exceed 2 hours\n"
+           "   late = Late()\n"
+           "   late.submitted( 0,15 )\n"
+           "   late.active(   20,0 )\n"
+           "   late.complete(  2,0, true )\n\n"
+           "   late = Late(submitted='00:15',active='20:00',complete='+02:00')\n"
+           "   t = Task('t1',\n"
+           "            Late(submitted='00:15',active='20:00'))\n";
+}
+
+const char* NodeAttrDoc::autocancel_doc() {
+    return "Provides a way to automatically delete/remove a node which has completed\n\n"
+           "See `autocancel`_\n"
+           "\nConstructor::\n\n"
+           "   Autocancel(TimeSlot,relative)\n"
+           "      TimeSlot single: A time\n"
+           "      bool relative:   Relative to completion. False means delete the node at the real time specified.\n\n"
+           "   Autocancel(hour,minute,relative)\n"
+           "      int hour:        hour in 24 hrs\n"
+           "      int minute:      minute <= 59\n"
+           "      bool relative:   Relative to completion. False means delete the node at the real time specified.\n\n"
+           "   Autocancel(days)\n"
+           "      int days:        Delete the node 'days' after completion\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   attr = Autocancel( 1,30, true )              # delete node 1 hour and 30 minutes after completion\n"
+           "   attr = Autocancel( TimeSlot(0,10), true )    # delete node 10 minutes after completion\n"
+           "   attr = Autocancel( TimeSlot(10,10), false )  # delete node at 10:10 after completion\n"
+           "   attr = Autocancel( 3  )                      # delete node 3 days after completion\n\n"
+           "   t1 = Task('t1',\n"
+           "              Autocancel(2,0,true))             # delete task 2 hours after completion\n";
+}
+
+const char* NodeAttrDoc::autoarchive_doc() {
+    return "Provides a way to automatically archive a suite/family which has completed or is *idle*\n\n"
+           "This is required when dealing with super large suite/families, they can be archived off, and then restored "
+           "later.\n"
+           "This reduces the time to checkpoint and network band width.\n"
+           "The archived node is written to disk, as ECF_HOME/<host>.<port>.ECF_NAME.check,\n"
+           "where '/' is replaced with ':' in ECF_NAME.\n"
+           "The node can be recovered using 'autorestore', begin,re-queue and manually via ecflow_client --restore.\n"
+           "The archiving is never immediate. The nodes are checked one a minute, and expired autoarchive nodes are "
+           "archived.\n"
+           "If the node is suspended or any of its parent are suspended,or previously restored then archive does not "
+           "happen.\n"
+           "\nConstructor::\n\n"
+           "   Autoarchive(TimeSlot,relative,idle)\n"
+           "      TimeSlot     : A time\n"
+           "      bool relative: Relative to node state, False means archive the node at the real time specified.\n\n"
+           "      bool idle:     True includes queued,aborted and complete, False means archive after completion "
+           "only\n\n"
+           "   Autoarchive(hour,minute,relative)\n"
+           "      int hour:      hour in 24 hrs\n"
+           "      int minute:    minute <= 59\n"
+           "      bool relative: Relative to node state. False means archive the node at the real time specified.\n\n"
+           "      bool idle:     True includes queued,aborted and complete, False means archive after completion "
+           "only\n\n"
+           "   AutoArchive(days,idle)\n"
+           "      int days:      archive the node after 'days' elapsed \n"
+           "      bool idle:     True archive if node queued,aborted and complete, False means archive after "
+           "completion only\n\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   attr = Autoarchive( 1,30, true )              # archive node 1 hour and 30 minutes after completion\n"
+           "   attr = Autoarchive( TimeSlot(0,10), true )    # archive node 10 minutes after completion\n"
+           "   attr = Autoarchive( TimeSlot(10,10), false )  # archive node at 10:10 after completion\n"
+           "   attr = Autoarchive( 3  )                      # archive node 3 days after completion\n"
+           "   attr = Autoarchive( 3,true  )                 # archive node 3 days after complete,queued or aborted, "
+           "i.e node is idle\n";
+}
+
+const char* NodeAttrDoc::autorestore_doc() {
+    return "Provides a way to automatically restore a previously archived node\n\n"
+           "This is required when dealing with super large suite/families, they can be archived off, and then restored "
+           "later.\n"
+           "This reduces the time to checkpoint the definition and network band width.\n"
+           "The archived node is written to disk, as ECF_HOME/<host>.<port>.ECF_NAME.check,\n"
+           "where '/' is replaced with ':' in ECF_NAME.\n"
+           "The node can be recovered using 'autorestore', begin,re-queue and manually via ecflow_client --restore.\n"
+           "The archiving is never immediate. The nodes are checked one a minute, and expired autoarchive nodes are "
+           "archived.\n"
+           "If the node is suspended or any of its parent are suspended then then the archive does not happen.\n"
+           "\nConstructor::\n\n"
+           "   Autorestore( list of paths )\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   attr = Autorestore( ['/s1/f1'] )           # restore archived node at /s1/f1\n"
+           "   attr = Autorestore( ['/s1/f1','/s1/f2'] )  # restore archived node at /s1/f1 and /s1/f2\n";
+}
+
+const char* NodeAttrDoc::repeat_doc() {
+    return "Represents one of RepeatString,RepeatEnumerated,RepeatInteger,RepeatDate,RepeatDay\n\n";
+}
+
+const char* NodeAttrDoc::repeat_date_doc() {
+    return "Allows a `node`_ to be repeated using a yyyymmdd format\n\n"
+           "A node can only have one `repeat`_.\n"
+           "The repeat name can be referenced in `trigger`_ expressions.\n"
+           "The trigger expression referencing a RepeatDate will use date arithmetic\n"
+           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer\n\n"
+           "   trigger /suite/family:YMD + 1 > 20190101\n"
+           "\nConstructor::\n\n"
+           "   RepeatDate(variable,start,end,delta)\n"
+           "      string variable:     The name of the repeat. The current date can referenced in\n"
+           "                           in trigger expressions using the variable name\n"
+           "      int start:           Start date, must have format: yyyymmdd\n"
+           "      int end:             End date, must have format: yyyymmdd\n"
+           "      int delta<optional>: default = 1, Always in days. The increment used to update the date\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if start/end are not valid dates\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   rep = RepeatDate('YMD', 20050130, 20050203 )\n"
+           "   rep = RepeatDate('YMD', 20050130, 20050203, 2)\n"
+           "   t = Task('t1',\n"
+           "            RepeatDate('YMD', 20050130, 20050203 ))\n";
+}
+
+const char* NodeAttrDoc::repeat_datetime_doc() {
+    return "Allows a `node`_ to be repeated based on date+time instants (using yyyymmddTHHMMSS format).\n\n"
+           "A node can only have one `repeat`_.\n"
+           "The repeat name can be referenced in `trigger`_ expressions.\n"
+           "The trigger expression referencing a RepeatDate will use date arithmetic\n"
+           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer\n\n"
+           "   trigger /suite/family:YMD + 1 > 20190101\n"
+           "\nConstructor::\n\n"
+           "   RepeatDateTime(variable, start, end[, step])\n"
+           "      string variable:     The name of the repeat. The Repeat can referenced in\n"
+           "                           in trigger expressions using the variable name\n"
+           "      int start:           Start date+time instant, formatted as yyyymmddTHHMMSS\n"
+           "      int end:             End date+time instant, formatted as yyyymmddTHHMMSS\n"
+           "      int step:            The increment duration used to update the instant when iterating\n"
+           "                           Formatted as HH:MM.SS, if not provided default delta is '24:00:00'.\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if start/end are not valid date+time instants\n"
+           "- Throws a RuntimeError if delta is not a valid duration\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   rep = RepeatDateTime('DATETIME', '20050130T000000', '20050203T000000')\n"
+           "   rep = RepeatDateTime('DATETIME', '20050130T000000', '20050203T000000', '48:00:00')\n"
+           "   t = Task('t1',\n"
+           "            RepeatDateTime('DATETIME', '20050130T000000', '20050203T120000', '1:00:00'))\n";
+}
+
+const char* NodeAttrDoc::repeat_date_list_doc() {
+    return "Allows a `node`_ to be repeated using arbitrary list of yyyymmdd integers\n\n"
+           "A node can only have one `repeat`_.\n"
+           "The repeat name can be referenced in `trigger`_ expressions.\n"
+           "The trigger expression referencing a RepeatDateList will use date arithmetic\n"
+           "Here (/suite/family:YMD + 1) uses date arithmetic only, the result is still an integer:\n\n"
+           ".. code-block:: shell\n\n"
+           "   trigger /suite/family:YMD + 1 > 20190101\n"
+           "\nConstructor::\n\n"
+           "   RepeatDateList(variable,list)\n"
+           "      string variable:     The name of the repeat. The current date can referenced in\n"
+           "                           in trigger expressions using the variable name\n"
+           "      list list_of_int:    Arbitrary list of integers following a yyyymmdd format\n"
+           "\nException:\n\n"
+           "- Throws a RuntimeError if list of integers are not valid dates\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   rep = RepeatDateList('YMD', [20050130, 20050203] )\n"
+           "   t = Task('t1',\n"
+           "            RepeatDateList('YMD',[20050130, 20050203] ))\n";
+}
+
+const char* NodeAttrDoc::repeat_integer_doc() {
+    return "Allows a `node`_ to be repeated using a integer range.\n\n"
+           "A node can only have one `repeat`_.\n"
+           "The repeat can be referenced in `trigger`_ expressions.\n"
+           "\nConstructor::\n\n"
+           "   RepeatInteger(variable,start,end,step)\n"
+           "      string variable:     The name of the repeat. The current integer value can be\n"
+           "                           referenced in trigger expressions using the variable name\n"
+           "      int start:           Start integer value\n"
+           "      int end:             End end integer value\n"
+           "      int step<optional>:  Default = 1, The step amount\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   t = Task('t1',\n"
+           "            RepeatInteger('HOUR', 6, 24, 6 ))\n";
+}
+
+const char* NodeAttrDoc::repeat_enumerated_doc() {
+    return "Allows a node to be repeated using a enumerated list.\n\n"
+           "A `node`_ can only have one `repeat`_.\n"
+           "The repeat can be referenced in `trigger`_ expressions.\n"
+           "\nConstructor::\n\n"
+           "   RepeatEnumerated(variable,list)\n"
+           "      string variable:     The name of the repeat. The current enumeration index can be\n"
+           "                           referenced in trigger expressions using the variable name\n"
+           "      vector list:         The list of enumerations\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   t = Task('t1',\n"
+           "            RepeatEnumerated('COLOR', [ 'red', 'green', 'blue' ] ))\n";
+}
+
+const char* NodeAttrDoc::repeat_string_doc() {
+    return "Allows a `node`_ to be repeated using a string list.\n\n"
+           "A `node`_ can only have one `repeat`_.\n"
+           "The repeat can be referenced in `trigger`_ expressions.\n"
+           "\nConstructor::\n\n"
+           "   RepeatString(variable,list)\n"
+           "      string variable:     The name of the repeat. The current index of the string list can be\n"
+           "                           referenced in trigger expressions using the variable name\n"
+           "      vector list:         The list of enumerations\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   t = Task('t1',\n"
+           "            RepeatString('COLOR', [ 'red', 'green', 'blue' ] ))\n";
+}
+
+const char* NodeAttrDoc::repeat_day_doc() {
+    return "A repeat that is infinite.\n\n"
+           "A node can only have one `repeat`_.\n"
+           "\nConstructor::\n\n"
+           "   RepeatDay(step)\n"
+           "      int step:     The step.\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   t = Task('t1',\n"
+           "             RepeatDay( 1 ))\n";
+}
+
+const char* NodeAttrDoc::cron_doc() {
+    return "A `cron`_ defines a repeating time dependency for a node.\n\n"
+           "\nConstructor::\n\n"
+           "   Cron()\n"
+           "   Cron(string time_series,\n"
+           "        days_of_week=list of ints,   # 0-6, Sunday-Saturday\n"
+           "        days_of_month=list of ints,  # 1-31\n"
+           "        months=list of ints)         # 1-12\n"
+           "   Cron(TimeSeries time_series,\n"
+           "        days_of_week=list of ints,\n"
+           "        days_of_month=list of ints,\n"
+           "        months=list of ints)\n"
+           "\nExceptions:\n\n"
+           "- raises IndexError || RuntimeError when an invalid cron is specified\n"
+           "\nUsage (see the `cron definition<text_based_def_cron>`_ for more examples):\n\n"
+           ".. code-block:: python\n\n"
+           "    # Run every day at 2pm\n"
+           "    cron = Cron('14:00')\n\n"
+           "    # Run every 30 minutes between 0:00 and 20:00, the first 6 days of the month from January until July\n"
+           "    cron = Cron('+00:00 20:00 00:30', days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6])\n\n"
+           "    # Run relative to suite start time or task requeue time\n"
+           "    cron = Cron('+01:30',days_of_week=[0,1,2,3,4,5,6])\n\n"
+
+           "    # Run relative to suite start time or task requeue time\n"
+           "    cron = Cron('+00:15 23:00 00:30', days_of_week=[0,1,2],days_of_month=[4,5,6], months=[1,2,3])\n\n"
+
+           "    # Define Cron based on start/end/increment\n"
+           "    start = TimeSlot(0 , 0)\n"
+           "    finish = TimeSlot(23, 0)\n"
+           "    incr = TimeSlot(0, 30)\n"
+           "    ts = TimeSeries(start, finish, incr, True)  # True means relative to suite start\n"
+           "    cron = Cron(ts, days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2])\n\n"
+           "    # Use Cron methods to set weekdays, days of month and month parameters\n"
+           "    cron = Cron()\n"
+           "    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])\n"
+           "    cron.set_days_of_month([1, 2, 3, 4, 5, 6 ])\n"
+           "    cron.set_months([1, 2, 3, 4, 5, 6])\n"
+           "    cron.set_time_series(ts)\n\n"
+           "    # Use Cron methods to set time series\n"
+           "    cron = Cron()\n"
+           "    cron.set_time_series(1, 30, True)  # same as cron +01:30\n\n"
+           "    # Use Cron methods to set time series over all days of the week\n"
+           "    cron = Cron()\n"
+           "    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])\n"
+           "    cron.set_time_series('00:30 01:30 00:01')\n\n"
+           "    # Use Cron methods to set relative time series over all days of the week\n"
+           "    cron = Cron()\n"
+           "    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])\n"
+           "    cron.set_time_series('+00:30')\n";
+}
+
+const char* NodeAttrDoc::clock_doc() {
+    return "Specifies the `clock`_ type used by the `suite`_.\n\n"
+           "Only suites can have a `clock`_.\n"
+           "A gain can be specified to offset from the given date.\n"
+           "\nConstructor::\n\n"
+           "   Clock(day,month,year,hybrid)\n"
+           "      int day              : Specifies the day of the month  1-31\n"
+           "      int month            : Specifies the month 1-12\n"
+           "      int year             : Specifies the year > 1400\n"
+           "      bool hybrid<optional>: Default = False, true means hybrid, false means real\n"
+           "                             by default the clock is not real\n\n"
+           "      Time will be set to midnight, use set_gain() to alter\n"
+           "\n"
+           "   Clock(hybrid)\n"
+           "      bool hybrid: true means hybrid, false means real\n"
+           "                   by default the clock is real\n"
+           "      Time will be set real time of the computer\n"
+           "\n"
+           "\nExceptions:\n\n"
+           "- raises IndexError when an invalid Clock is specified\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   suite = Suite('s1')\n"
+           "   clock = Clock(1,1,2012,False)\n"
+           "   clock.set_gain(1,10,True)\n"
+           "   suite.add_clock(clock)\n";
+}
+
+const char* NodeAttrDoc::aviso_doc() {
+    return "An `aviso`_ attribute, assigned to a `node`_, represents an external trigger holding the node queued until"
+           "an Aviso notification matching the attribute configuration is detected.\n"
+           "\n"
+           "Although `aviso`_ attributes can be set at any level (Suite, Family, Task), it only makes sense to assign "
+           "aviso attributes to tasks, and only one aviso attribute per node is allowed.\n"
+           "\n"
+           "\nConstructor::\n\n"
+           "   AvisoAttr(name, listener, ...)\n"
+           "      string name: The Aviso attribute name\n"
+           "      string listener: The Aviso listener configuration (in JSON format)\n"
+           "      string url: The URL used to contact the Aviso server\n"
+           "      string schema: The path to the Aviso schema\n"
+           "      string polling: The polling interval used to contact the Aviso server\n"
+           "      string auth: The path to the Aviso Authentication credentials\n"
+           "\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   t1 = Task('t1',\n"
+           "             AvisoAttr('name', '{...}', 'http://aviso.com', '60', '/path/to/auth'))\n"
+           "\n"
+           "   t2 = Task('t2')\n"
+           "   t2.add_aviso('name', '{...}', 'http://aviso.com', '60', '/path/to/auth')\n";
+}
+
+const char* NodeAttrDoc::mirror_doc() {
+    return "A `mirror`_ attribute, assigned to a `node`_, enables establishing an external link and "
+           "locally replicate the state of a node executing on a remote ecFlow server.\n"
+           "\n"
+           "Although `mirror`_ attributes can be set at any level (Suite, Family, Task), it only makes sense to assign "
+           "mirror attributes to Tasks, and only one mirror attribute per node is allowed.\n"
+           "\n"
+           "\nConstructor::\n\n"
+           "   MirrorAttr(name, remote_path, ...)\n"
+           "      string name: The Mirror attribute name\n"
+           "      string remote_path: The path on the remote ecFlow server to the node being replicated\n"
+           "      string remote_host: The host of the remote ecFlow server\n"
+           "      string remote_port: The port of the remote ecFlow server\n"
+           "      string polling: The polling interval used to contact the remote ecFlow server\n"
+           "      Bool ssl: `true`, when using SSL to contact the remote ecFlow server; `false`, otherwise\n"
+           "      string auth: The path to the Mirror Authentication credentials\n"
+           "\n"
+           "\nUsage:\n\n"
+           ".. code-block:: python\n\n"
+           "   t1 = Task('t1',\n"
+           "             MirrorAttr('name', '/remote/task', 'remote-ecflow', '3141', '60', True, '/path/to/auth'))\n"
+           "\n"
+           "   t2 = Task('t2')\n"
+           "   t2.add_aviso('name', '/remote/task', 'remote-ecflow', '3141', '60', True, '/path/to/auth')\n";
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/NodeAttrDoc.hpp 5.13.0-1/libs/pyext/src/ecflow/python/NodeAttrDoc.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/NodeAttrDoc.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/NodeAttrDoc.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,61 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_NodeAttrDoc_HPP
+#define ecflow_python_NodeAttrDoc_HPP
+
+#include <boost/core/noncopyable.hpp>
+
+// ===========================================================================
+// IMPORTANT: These appear as python doc strings.
+//            Additionally they are auto documented using sphinx-poco
+//            Hence the doc strings use reStructuredText markup
+// ===========================================================================
+class NodeAttrDoc {
+public:
+    NodeAttrDoc()                              = delete;
+    NodeAttrDoc(const NodeAttrDoc&)            = delete;
+    NodeAttrDoc& operator=(const NodeAttrDoc&) = delete;
+
+    static const char* variable_doc();
+    static const char* zombie_doc();
+    static const char* zombie_type_doc();
+    static const char* zombie_user_action_type_doc();
+    static const char* child_cmd_type_doc();
+    static const char* label_doc();
+    static const char* limit_doc();
+    static const char* inlimit_doc();
+    static const char* event_doc();
+    static const char* meter_doc();
+    static const char* queue_doc();
+    static const char* date_doc();
+    static const char* day_doc();
+    static const char* days_enum_doc();
+    static const char* time_doc();
+    static const char* today_doc();
+    static const char* late_doc();
+    static const char* autocancel_doc();
+    static const char* autoarchive_doc();
+    static const char* autorestore_doc();
+    static const char* repeat_doc();
+    static const char* repeat_date_doc();
+    static const char* repeat_datetime_doc();
+    static const char* repeat_date_list_doc();
+    static const char* repeat_integer_doc();
+    static const char* repeat_enumerated_doc();
+    static const char* repeat_string_doc();
+    static const char* repeat_day_doc();
+    static const char* cron_doc();
+    static const char* clock_doc();
+    static const char* aviso_doc();
+    static const char* mirror_doc();
+};
+
+#endif /* ecflow_python_NodeAttrDoc_HPP */
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/NodeUtil.cpp 5.13.0-1/libs/pyext/src/ecflow/python/NodeUtil.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/NodeUtil.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/NodeUtil.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,184 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/NodeUtil.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/ClockAttr.hpp"
+#include "ecflow/attribute/CronAttr.hpp"
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/attribute/RepeatAttr.hpp"
+#include "ecflow/attribute/TimeAttr.hpp"
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/node/Attr.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/InLimit.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/python/BoostPythonUtil.hpp"
+#include "ecflow/python/Edit.hpp"
+#include "ecflow/python/Trigger.hpp"
+
+using namespace boost::python;
+using namespace std;
+using namespace ecf;
+namespace bp = boost::python;
+
+object NodeUtil::node_raw_constructor(bp::tuple args, bp::dict kw) {
+    // cout << "node_raw_constructor len(args):" << len(args) << endl;
+    // args[0] is Task(i.e self) args[1] is string name
+    bp::list the_list;
+    std::string name;
+    for (int i = 1; i < len(args); ++i) {
+        if (extract<string>(args[i]).check())
+            name = extract<string>(args[i]);
+        else
+            the_list.append(args[i]);
+    }
+    if (name.empty())
+        throw std::runtime_error("node_raw_constructor: first argument must be a string");
+    return args[0].attr("__init__")(name, the_list, kw); // calls -> init(const std::string& name, list attr, dict kw)
+}
+
+node_ptr NodeUtil::add_variable_dict(node_ptr self, const bp::dict& dict) {
+    std::vector<Variable> vec;
+    BoostPythonUtil::dict_to_str_vec(dict, vec);
+    for (const auto& i : vec)
+        self->addVariable(i);
+    return self;
+}
+
+object NodeUtil::node_iadd(node_ptr self, const bp::list& list) {
+    // std::cout << "node_iadd list " << self->name() << "\n";
+    int the_list_size = len(list);
+    for (int i = 0; i < the_list_size; ++i)
+        (void)do_add(self, list[i]);
+    return object(self); // return node_ptr as python object, relies class_<Node>... for type registration
+}
+
+object NodeUtil::do_add(node_ptr self, const bp::object& arg) {
+    // std::cout << "do_add " << self->name() << "\n";
+    if (arg.ptr() == object().ptr())
+        return object(self); // *IGNORE* None
+    if (extract<Edit>(arg).check()) {
+        Edit edit                        = extract<Edit>(arg);
+        const std::vector<Variable>& vec = edit.variables();
+        for (const auto& i : vec)
+            self->addVariable(i);
+    }
+    else if (extract<node_ptr>(arg).check()) {
+        // std::cout << "  do_add node_ptr\n";
+        NodeContainer* nc = self->isNodeContainer();
+        if (!nc)
+            throw std::runtime_error("ExportNode::add() : Can only add a child to Suite or Family");
+        node_ptr child = extract<node_ptr>(arg);
+        nc->addChild(child);
+    }
+    else if (extract<Event>(arg).check())
+        self->addEvent(extract<Event>(arg));
+    else if (extract<Meter>(arg).check())
+        self->addMeter(extract<Meter>(arg));
+    else if (extract<Label>(arg).check())
+        self->addLabel(extract<Label>(arg));
+    else if (extract<Trigger>(arg).check()) {
+        Trigger t = extract<Trigger>(arg);
+        self->py_add_trigger_expr(t.expr());
+    }
+    else if (extract<Complete>(arg).check()) {
+        Complete t = extract<Complete>(arg);
+        self->py_add_complete_expr(t.expr());
+    }
+    else if (extract<Limit>(arg).check())
+        self->addLimit(extract<Limit>(arg));
+    else if (extract<InLimit>(arg).check())
+        self->addInLimit(extract<InLimit>(arg));
+    else if (extract<DayAttr>(arg).check())
+        self->addDay(extract<DayAttr>(arg));
+    else if (extract<DateAttr>(arg).check())
+        self->addDate(extract<DateAttr>(arg));
+    else if (extract<TodayAttr>(arg).check())
+        self->addToday(extract<TodayAttr>(arg));
+    else if (extract<TimeAttr>(arg).check())
+        self->addTime(extract<TimeAttr>(arg));
+    else if (extract<CronAttr>(arg).check())
+        self->addCron(extract<CronAttr>(arg));
+    else if (extract<LateAttr>(arg).check())
+        self->addLate(extract<LateAttr>(arg));
+    else if (extract<ZombieAttr>(arg).check())
+        self->addZombie(extract<ZombieAttr>(arg));
+    else if (extract<RepeatDate>(arg).check())
+        self->addRepeat(Repeat(extract<RepeatDate>(arg)));
+    else if (extract<RepeatDateTime>(arg).check())
+        self->addRepeat(Repeat(extract<RepeatDateTime>(arg)));
+    else if (extract<RepeatDateList>(arg).check())
+        self->addRepeat(Repeat(extract<RepeatDateList>(arg)));
+    else if (extract<RepeatInteger>(arg).check())
+        self->addRepeat(Repeat(extract<RepeatInteger>(arg)));
+    else if (extract<RepeatEnumerated>(arg).check())
+        self->addRepeat(Repeat(extract<RepeatEnumerated>(arg)));
+    else if (extract<RepeatString>(arg).check())
+        self->addRepeat(Repeat(extract<RepeatString>(arg)));
+    else if (extract<RepeatDay>(arg).check())
+        self->addRepeat(Repeat(extract<RepeatDay>(arg)));
+    else if (extract<AutoCancelAttr>(arg).check())
+        self->addAutoCancel(extract<AutoCancelAttr>(arg));
+    else if (extract<Defstatus>(arg).check()) {
+        Defstatus t = extract<Defstatus>(arg);
+        self->addDefStatus(t.state());
+    }
+    else if (extract<AutoArchiveAttr>(arg).check())
+        self->add_autoarchive(extract<AutoArchiveAttr>(arg));
+    else if (extract<AutoRestoreAttr>(arg).check())
+        self->add_autorestore(extract<AutoRestoreAttr>(arg));
+    else if (extract<VerifyAttr>(arg).check())
+        self->addVerify(extract<VerifyAttr>(arg));
+    else if (extract<bp::list>(arg).check()) {
+        // std::cout << "  do_add list\n";
+        bp::list the_list = extract<bp::list>(arg);
+        int the_list_size = len(the_list);
+        for (int i = 0; i < the_list_size; ++i)
+            (void)do_add(self, the_list[i]); // recursive
+    }
+    else if (extract<ClockAttr>(arg).check()) {
+        if (!self->isSuite())
+            throw std::runtime_error("ExportNode::add() : Can only add a clock to a suite");
+        self->isSuite()->addClock(extract<ClockAttr>(arg));
+    }
+    else if (extract<Variable>(arg).check()) {
+        self->addVariable(extract<Variable>(arg));
+    }
+    else if (auto attr = extract<ecf::AvisoAttr>(arg); attr.check()) {
+        self->addAviso(attr);
+    }
+    else if (auto attr = extract<ecf::MirrorAttr>(arg); attr.check()) {
+        self->addMirror(attr);
+    }
+    else if (extract<dict>(arg).check()) {
+        dict d = extract<dict>(arg);
+        add_variable_dict(self, d);
+    }
+    else
+        throw std::runtime_error("ExportNode::add : Unknown type ");
+    return object(self);
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/NodeUtil.hpp 5.13.0-1/libs/pyext/src/ecflow/python/NodeUtil.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/NodeUtil.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/NodeUtil.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_NodeUtil_HPP
+#define ecflow_python_NodeUtil_HPP
+
+#include <boost/python.hpp>
+
+#include "ecflow/node/NodeFwd.hpp"
+
+class NodeUtil {
+public:
+    NodeUtil()                           = delete;
+    NodeUtil(const NodeUtil&)            = delete;
+    NodeUtil& operator=(const NodeUtil&) = delete;
+
+    /// any nodes and attributes to be added
+    static boost::python::object do_add(node_ptr self, const boost::python::object& arg);
+
+    /// add ecflow variables from a python dictionary of strings
+    static node_ptr add_variable_dict(node_ptr self, const boost::python::dict& dict);
+
+    /// Add all the object in python list, to the node
+    static boost::python::object node_iadd(node_ptr self, const boost::python::list& list);
+
+    /// raw constructor,assumes first argument is a string.
+    /// Assumes Task,Family,Suite has defined a constructor  init(const std::string& name, list attrs, dict kw)
+    static boost::python::object node_raw_constructor(boost::python::tuple args, boost::python::dict kw);
+};
+
+#endif /* ecflow_python_NodeUtil_HPP */
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/Trigger.cpp 5.13.0-1/libs/pyext/src/ecflow/python/Trigger.cpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/Trigger.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/Trigger.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/python/Trigger.hpp"
+
+#include <stdexcept>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Node.hpp"
+
+using namespace boost::python;
+using namespace std;
+using namespace ecf;
+namespace bp = boost::python;
+
+static void construct_expr(std::vector<PartExpression>& vec, const bp::list& list) {
+    int the_list_size = len(list);
+    for (int i = 0; i < the_list_size; ++i) {
+        std::string part_expr;
+        if (extract<std::string>(list[i]).check()) {
+            part_expr = extract<std::string>(list[i]);
+            if (Str::valid_name(part_expr)) {
+                part_expr += " == complete";
+            }
+        }
+        else if (extract<node_ptr>(list[i]).check()) {
+            node_ptr node = extract<node_ptr>(list[i]);
+            if (node->parent())
+                part_expr = node->absNodePath();
+            else
+                part_expr = node->name();
+            part_expr += " == complete";
+        }
+        else
+            throw std::runtime_error("Trigger: Expects string, or list(strings or nodes)");
+
+        if (vec.empty())
+            vec.emplace_back(part_expr);
+        else
+            vec.emplace_back(part_expr, true /*AND*/);
+    }
+}
+
+Trigger::Trigger(const bp::list& list) {
+    construct_expr(vec_, list);
+}
+Complete::Complete(const bp::list& list) {
+    construct_expr(vec_, list);
+}
diff -pruN 5.12.4-1/libs/pyext/src/ecflow/python/Trigger.hpp 5.13.0-1/libs/pyext/src/ecflow/python/Trigger.hpp
--- 5.12.4-1/libs/pyext/src/ecflow/python/Trigger.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/src/ecflow/python/Trigger.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,63 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_python_Trigger_HPP
+#define ecflow_python_Trigger_HPP
+
+#include <boost/python.hpp>
+
+#include "ecflow/node/Expression.hpp"
+
+////////////////////////////////////////////////////////////////////////////////////////
+// Trigger & Complete thin wrapper over Expression, allows us to call:
+//  Task("a").add(Trigger("a == 1"),Complete("b == 1"))
+///////////////////////////////////////////////////////////////////////////////////
+
+class Trigger {
+public:
+    explicit Trigger(const std::string& expression) { add(PartExpression(expression)); }
+    Trigger(const std::string& expression, bool and_type) { add(PartExpression(expression, and_type)); }
+    explicit Trigger(const PartExpression& pe) { add(pe); }
+    Trigger(const Trigger& rhs) = default;
+    explicit Trigger(const boost::python::list& list);
+
+    bool operator==(const Trigger& rhs) const { return vec_ == rhs.vec_; }
+    bool operator!=(const Trigger& rhs) const { return !operator==(rhs); }
+    std::string expression() const { return Expression::compose_expression(vec_); }
+
+    const std::vector<PartExpression>& expr() const { return vec_; }
+
+private:
+    void add(const PartExpression& t) { vec_.push_back(t); }
+    std::vector<PartExpression> vec_;
+    Trigger& operator=(Trigger const& f) = delete; // prevent assignment
+};
+
+class Complete {
+public:
+    explicit Complete(const std::string& expression) { add(PartExpression(expression)); }
+    Complete(const std::string& expression, bool and_type) { add(PartExpression(expression, and_type)); }
+    explicit Complete(const PartExpression& pe) { add(pe); }
+    Complete(const Complete& rhs) = default;
+    explicit Complete(const boost::python::list& list);
+
+    bool operator==(const Complete& rhs) const { return vec_ == rhs.vec_; }
+    bool operator!=(const Complete& rhs) const { return !operator==(rhs); }
+    std::string expression() const { return Expression::compose_expression(vec_); }
+
+    const std::vector<PartExpression>& expr() const { return vec_; }
+
+private:
+    void add(const PartExpression& t) { vec_.push_back(t); }
+    std::vector<PartExpression> vec_;
+    Complete& operator=(Complete const& f) = delete; // prevent assignment
+};
+
+#endif /* ecflow_python_Trigger_HPP */
diff -pruN 5.12.4-1/libs/pyext/test/CleanupOnlineTutorial.py 5.13.0-1/libs/pyext/test/CleanupOnlineTutorial.py
--- 5.12.4-1/libs/pyext/test/CleanupOnlineTutorial.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/CleanupOnlineTutorial.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import os
+
+# clean up any file after running the online tutorial examples
+# Place in separate exception, otherwise not all files will be removed
+try: os.remove("test.def")
+except: pass
+
+try: os.remove("TestSuite.def")
+except: pass
+
+try: os.remove("SuiteBuilder.def")
+except: pass
+
+try: os.remove("server.defs")   
+except: pass
diff -pruN 5.12.4-1/libs/pyext/test/data/.gitignore 5.13.0-1/libs/pyext/test/data/.gitignore
--- 5.12.4-1/libs/pyext/test/data/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/data/.gitignore	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1 @@
+/CUSTOMER
diff -pruN 5.12.4-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf 5.13.0-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf
--- 5.12.4-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t1.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,72 @@
+%manual
+	OPERATORS: This is an example of using a manual
+	
+	This is used to also test variable subsitution of 
+	generated variables
+	SUITE     = %SUITE%
+	DATE      = %DATE%
+	DAY       = %DAY%
+	DD        = %DD%
+	DOW       = %DOW%
+	DOY       = %DOY%
+	MM        = %MM%
+	MONTH     = %MONTH%
+	YYYY      = %YYYY%
+	ECF_DATE   = %ECF_DATE%
+	ECF_TIME   = %ECF_TIME%
+	ECF_CLOCK  = %ECF_CLOCK%
+
+	FAMILY    = %FAMILY%
+	FAMILY1   = %FAMILY1%
+
+	TASK      = %TASK%
+	ECF_RID    = %ECF_RID:<not defined yet, since empty string in task>%
+	ECF_TRYNO  = %ECF_TRYNO%
+	ECF_NAME   = %ECF_NAME%
+	ECF_PASS   = %ECF_PASS%
+	ECF_SCRIPT = %ECF_SCRIPT%
+	ECF_JOB    = %ECF_JOB%
+	ECF_JOBOUT = %ECF_JOBOUT%
+    
+    Other ECF_ variables
+	ECF_KILL_CMD  = %ECF_KILL_CMD:<not defined yet>%
+	ECF_JOB_CMD   = %ECF_JOB_CMD%
+	ECF_HOME      = %ECF_HOME%
+	ECF_TRIES     = %ECF_TRIES:<Error>%
+	SMFILES      = %SMFILES:<not defined yet>%
+	ECF_INCLUDE   = %ECF_INCLUDE:<not defined yet>%
+	ECF_FETCH     = %ECF_FETCH:<not defined yet>%
+	ECF_OUT       = %ECF_OUT:<not defined yet>%
+	ECF_MICRO     = %ECF_MICRO%
+%end
+
+#============================================================
+# Using angle brackets should use ECF_INCLUDE
+#=========================================================
+%include <head.h>
+
+
+echo do some work
+# SLEEPTIME is defined thedefs.def file. Test variable substituition
+sleep %SLEEPTIME%
+echo end of job
+
+# test smsevent. smsmeter replaced with path to client exe
+smsevent  eventname
+smsmeter  metername 10
+
+%include <tail.h>
+
+
+%manual
+	Rest of the manual page is placed here, closer to the code
+%end
+%comment
+  Comment start
+%end
+%comment
+  Comment end
+%end
+%nopp
+  ignore everything in here
+%end
diff -pruN 5.12.4-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf 5.13.0-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf
--- 5.12.4-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+ 
+%include <head.h>
+
+echo do some work
+# SLEEPTIME is defined thedefs.def file. Test variable substituition
+sleep 10
+echo end of job
+
+%include <tail.h>
diff -pruN 5.12.4-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf 5.13.0-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf
--- 5.12.4-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/data/ECF_HOME/suite_job_gen/family/t3.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,34 @@
+ 
+%include <head.h>
+
+
+echo do some work
+sleep 10
+echo end of job
+
+#=====================================================
+# change the ecfmicro character
+%ecfmicro &
+
+&manual
+	START Rest of the manual page is placed here, closer to the code
+&end
+&comment
+  Comment start
+  &SUITE&
+&end
+&comment
+  Comment end
+&end
+&nopp
+  ignore everything in here
+&end
+&manual
+	END of the manual
+&end
+#=====================================================
+# change the ecfmicro character back
+&ecfmicro %
+
+
+%include <tail.h>
diff -pruN 5.12.4-1/libs/pyext/test/data/includes/head.h 5.13.0-1/libs/pyext/test/data/includes/head.h
--- 5.12.4-1/libs/pyext/test/data/includes/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/data/includes/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+#!/bin/ksh
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+set -o pipefail # fail if last(rightmost) command exits with a non-zero status
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+## In applying this licence, ECMWF does not waive the privileges and immunities
+## granted to it by virtue of its status as an intergovernmental organisation
+## nor does it submit to any jurisdiction.
+
+# Defines the variables that are needed for any communication with ecflow server
+
+export ECF_PORT=%ECF_PORT%    # ECF port number on the server
+export ECF_HOST=%ECF_HOST%    # The hostname where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+export ECF_RID=$$             # Let All child commands pass process id to server
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%   # if server is SSL make sure client is
+fi
+
+# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
+os_name=$(uname -s)
+if [[ $os_name = Linux ]] ; then
+   host %ECF_HOST%
+fi
+
+echo "About to run ecflow_client --version"
+%ECF_CLIENT_EXE_PATH:ecflow_client% --version
+
+echo "About to run ecflow_client --init"
+%ECF_CLIENT_EXE_PATH:ecflow_client% --init=$$
+
+# Define a error hanlder
+
+ERROR() {
+   echo "ERROR() called"
+	set +e                                       # Clear -e flag, so we don't fail
+	wait                                         # wait for background process to stop
+	%ECF_CLIENT_EXE_PATH:ecflow_client% --abort  # Notify ECF_ that something went wrong
+	trap 0                                       # Remove the trap
+	exit 0                                       # End the script
+}
+
+# Trap any calls to exit and errors caught by the -e flag
+
+trap ERROR 0
+
+# Trap any signal that may cause the script to fail
+
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
diff -pruN 5.12.4-1/libs/pyext/test/data/includes/tail.h 5.13.0-1/libs/pyext/test/data/includes/tail.h
--- 5.12.4-1/libs/pyext/test/data/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/data/includes/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,4 @@
+wait                                            # wait for background process to stop
+%ECF_CLIENT_EXE_PATH:ecflow_client% --complete  # Notify ECF of a normal end
+trap 0                                          # Remove all traps
+exit 0                                          # End the shell
diff -pruN 5.12.4-1/libs/pyext/test/data/python_includes/head.py 5.13.0-1/libs/pyext/test/data/python_includes/head.py
--- 5.12.4-1/libs/pyext/test/data/python_includes/head.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/data/python_includes/head.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,94 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import datetime,time
+import os, signal, platform
+import ecflow
+
+print("cwd: " + os.getcwd())
+print("PYTHONPATH=====================================================")
+try:
+    print(os.environ['PYTHONPATH'].split(os.pathsep))
+except KeyError:
+    print("Could not get PYTHONPATH")
+
+print("LD_LIBRARY_PATH=====================================================")
+try:
+    print(os.environ['LD_LIBRARY_PATH'].split(os.pathsep))
+except KeyError:
+    print("Could not get LD_LIBRARY_PATH")
+    
+    
+class Client(object):
+    """Encapsulate communication with the ecflow server. This will automatically call
+       the child command init()/complete(), for job start/finish. It will also
+       handle exceptions and signals, by calling the abort child command.
+       *ONLY* one instance of this class, should be used. Otherwise zombies will be created.
+    """
+    def __init__(self,init_add_vars = False):
+        print ("Creating Client")
+        self.ci = ecflow.Client()
+        self.ci.set_host_port("%ECF_HOST%","%ECF_PORT%")
+        self.ci.set_child_pid(os.getpid())
+        self.ci.set_child_path("%ECF_NAME%")
+        self.ci.set_child_password("%ECF_PASS%")
+        self.ci.set_child_try_no(%ECF_TRYNO%)
+        if init_add_vars:
+            self.ci.set_child_init_add_vars({"name1":"1", "name2":"2"})
+            self.ci.set_child_init_add_vars([ecflow.Variable("name3","3"), ecflow.Variable("name4","4")])
+            self.ci.set_child_complete_del_vars(["name","name1","name2","name3","name4"])
+    
+        print("   Only wait 20 seconds, if the server cannot be contacted (note default is 24 hours) before failing")
+        self.ci.set_child_timeout(20)
+        self.ci.set_zombie_child_timeout(10)
+     
+        # Abort the task for the following signals
+        signal.signal(signal.SIGINT,  self.signal_handler)
+        signal.signal(signal.SIGHUP,  self.signal_handler)
+        signal.signal(signal.SIGQUIT, self.signal_handler)
+        signal.signal(signal.SIGILL,  self.signal_handler)
+        signal.signal(signal.SIGTRAP, self.signal_handler)
+        signal.signal(signal.SIGIOT,  self.signal_handler)
+        signal.signal(signal.SIGBUS,  self.signal_handler)
+        signal.signal(signal.SIGFPE,  self.signal_handler)
+        signal.signal(signal.SIGUSR1, self.signal_handler)
+        signal.signal(signal.SIGUSR2, self.signal_handler)
+        signal.signal(signal.SIGPIPE, self.signal_handler)
+        signal.signal(signal.SIGTERM, self.signal_handler)
+        signal.signal(signal.SIGXCPU, self.signal_handler) 
+        if platform.system() != "Darwin":
+            signal.signal(signal.SIGPWR,  self.signal_handler)
+     
+    def at_time(self):
+%ecfmicro #
+        return datetime.datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')
+#ecfmicro %
+
+    def signal_handler(self,signum, frame):
+        print('   Aborting: Signal handler called with signal ', signum)
+        self.ci.child_abort("Signal handler called with signal " + str(signum));
+     
+    def __enter__(self):
+        print('Calling init at: ' + self.at_time())
+        self.ci.child_init()
+        return self.ci
+     
+    def __exit__(self,ex_type,value,tb):
+        print ("   Client:__exit__: ex_type:" + str(ex_type) + " value:" + str(value) + "\n   traceback:" + str(tb))
+        if ex_type is not None:
+            print('Calling abort ' + self.at_time())
+            self.ci.child_abort("Aborted with exception type " + str(ex_type) + ":" + str(value))
+            return False
+        print('Calling complete at: ' + self.at_time())
+        self.ci.child_complete()
+        return False 
diff -pruN 5.12.4-1/libs/pyext/test/ecflow_test_util.py 5.13.0-1/libs/pyext/test/ecflow_test_util.py
--- 5.12.4-1/libs/pyext/test/ecflow_test_util.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/ecflow_test_util.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,255 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+# Utility code used in the tests.
+#
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+from socket import gethostname 
+import os,sys,fnmatch
+import time
+import fcntl
+import datetime,time
+import shutil   # used to remove directory tree
+import platform # for python version info
+
+from ecflow import Client, debug_build, File
+
+def all_files(root, patterns='*', single_level=False, yield_folders=False):
+    """Expand patterns from semi-colon separated string to list"""
+    patterns = patterns.split(';')
+    for path, subdirs, files in os.walk(root):
+        if yield_folders:
+            files.extend(subdirs)
+        files.sort()
+        for name in files:
+            for pattern in patterns:
+                if fnmatch.fnmatch(name,pattern):
+                    yield os.path.join(path, name)
+                    break
+        if single_level:
+            break    
+        
+# Enable to stop data being deleted, and stop server from being terminated
+def debugging() : return False
+
+def ecf_home(port): 
+    # debug_build() is defined for ecflow. Used in test to distinguish debug/release ecflow
+    # Vary ECF_HOME based on debug/release/port/python version, allowing multiple invocations of these tests
+    ecf_home_base = "/test/data/ecf_home_py" + str(sys.version_info[0])
+    if debug_build():
+        return os.getcwd() + ecf_home_base + "_debug_" + str(port)
+    return os.getcwd() + ecf_home_base + "_release_" + str(port)
+
+def get_parent_dir(file_path):
+    return os.path.dirname(file_path)
+
+def log_file_path(port): return "./" + gethostname() + "." + port + ".ecf.log"
+def checkpt_file_path(port): return "./" + gethostname() + "." + port + ".ecf.check"
+def backup_checkpt_file_path(port): return "./" + gethostname() + "." + port + ".ecf.check.b"
+def white_list_file_path(port): return "./" + gethostname() + "." + port + ".ecf.lists"
+
+def print_test_start(test_name):
+    print("#######################################################################################")
+    print(test_name)  
+    print("ecflow version(" + Client().version() + ") debug build(" + str(debug_build()) +")  python(" + platform.python_version() + ")")
+    print("PYTHONPATH                : " + str(os.environ['PYTHONPATH'].split(os.pathsep)))
+    #print("sys.path                  : " + str(sys.path))
+    print("Current working directory : " + str(os.getcwd()))
+    print("Python version            : " + str(sys.version_info[0]) + "." + str(sys.version_info[1]))
+    print("#######################################################################################")
+    
+def clean_up_server(port):
+    print("   clean_up " + port)
+    try: os.remove(log_file_path(port))
+    except: pass
+    try: os.remove(checkpt_file_path(port))
+    except: pass
+    try: os.remove(backup_checkpt_file_path(port))
+    except: pass
+    try: os.remove(white_list_file_path(port))  
+    except: pass
+    
+def clean_up_data(port):
+    print("   Attempting to Removing ECF_HOME " + ecf_home(port))
+    try: 
+        shutil.rmtree(ecf_home(port),True)   # True means ignore errors 
+        print("   Remove OK") 
+    except: 
+        print("   Remove Failed") 
+        pass
+        
+# =======================================================================================
+class EcfPortLock(object):
+    """allow debug and release version of python tests to run at the same
+    time, buy generating a unique port each time"""
+    def __init__(self):
+        print("   EcfPortLock:__init__")
+        pass
+    
+    def at_time(self):
+        return datetime.datetime.fromtimestamp(time.time()).strftime('%H:%M:%S')
+    
+    def find_free_port(self,seed_port):
+        print("   EcfPortLock:find_free_port starting with " + str(seed_port) + " at time " + self.at_time())
+        port = seed_port
+        while 1:
+            # port must be free for at least 15 seconds
+            if self._timed_free_port(port,15) == True:
+                print("   *FOUND* free server port " + str(port) + " : " + self.at_time())
+                if self.do_lock(port):
+                    break
+            else:
+                print("   *Server* port " + str(port) + " busy( by  ping), trying next port " + self.at_time())
+            port = port + 1
+            
+        return str(port)  
+    
+    def _timed_free_port(self,port,wait_time = 10):
+        count = 0
+        while count < wait_time:
+            if self._free_port(port) == True:
+                count = count + 1
+                time.sleep(1)
+            else:
+                return False
+        return self._free_port(port)
+            
+    def _free_port(self,port):
+        try:
+            ci = Client()
+            ci.set_host_port("localhost",str(port))
+            ci.ping() 
+            return False
+        except RuntimeError as e:
+            return True
+            
+    def do_lock(self,port):
+        file = self._lock_file(port)
+        if os.path.exists(file):
+            print("   *LOCKED* lock file exists " + file + " trying next port : " + self.at_time() )
+            return False
+        try:
+            fp = open(file, 'w') 
+            try:
+                self.lock_time = self.at_time()
+                fcntl.lockf(fp, fcntl.LOCK_EX | fcntl.LOCK_NB)
+                self.lock_file_fp = fp
+                print("   *LOCKED* file " + file + " : " + self.lock_time )
+                return True;
+            except IOError:
+                print("   Could *NOT* lock file " + file + " trying next port : " + self.at_time())
+                return False
+        except IOError as e:
+            print("   Could not open file " + file + " for write trying next port : " + self.at_time())
+            return False
+        
+    def remove(self,port):
+        file = self._lock_file(port)
+        print("   Remove lock file : " + file + " : lock_time: " + self.lock_time + " release_time: " + self.at_time() )
+        self.lock_file_fp.close()
+        os.remove(file)
+    
+    def _lock_file(self,port):
+        if "ECF_PORT_LOCK_DIR" in os.environ:
+            lock_file = os.environ["ECF_PORT_LOCK_DIR"] + "/" + str(port) + ".lock"
+            #print("     EcfPortLock::_lock_file ECF_PORT_LOCK_DIR: " + lock_file)
+            return lock_file
+        if os.path.exists(File.source_dir()):
+            lock_file = File.source_dir() + "/" + str(port) + ".lock"
+            #print("     EcfPortLock::_lock_file File::source_dir(): " + lock_file)
+            return lock_file
+        lock_file = os.getcwd() + "/" + str(port) + ".lock"
+        #print("     EcfPortLock::_lock_file os.getcwd(): " + lock_file)
+        return lock_file
+        
+# ===============================================================================
+
+class Server(object):
+    """TestServer: allow debug and release version of python tests to run at the same
+    time, by generating a unique port each time"""
+    def __init__(self):
+        print("Server:__init__: Starting server")    
+        if not debugging():
+            seed_port = int(os.getenv('ECF_FREE_PORT', '3153'))
+            if sys.version_info[0] == 3: # python3 can run at same time
+                seed_port = int(os.getenv('ECF_FREE_PORT', '3154'))  
+            if debug_build(): seed_port = seed_port + 1 
+            self.lock_file = EcfPortLock()
+            self.the_port = self.lock_file.find_free_port(seed_port)   
+        else:
+            self.the_port = "3152"
+            
+        # Only worth doing this test, if the server is running
+        # ON HPUX, having only one connection attempt, sometimes fails
+        #ci.set_connection_attempts(1)     # improve responsiveness only make 1 attempt to connect to server
+        #ci.set_retry_connection_period(0) # Only applicable when make more than one attempt. Added to check api.
+        self.ci = Client("localhost", self.the_port)
+
+    def at_time(self):
+        return datetime.datetime.fromtimestamp(time.time()).strftime('%Y-%m-%d %H:%M:%S')
+
+    def __enter__(self):
+        try:
+            print("Server:__enter__: About to ping localhost: " + self.the_port +  " : " + self.at_time())       
+            self.ci.ping() 
+            print("   ------- Server all ready running on port " + self.the_port + " *UNEXPECTED* -- : " + self.at_time() )
+            sys.exit(1)
+        except RuntimeError as e:
+            while 1:
+                # Only worth doing this test, if the server is running
+                # ON HPUX, having only one connection attempt, sometimes fails
+                #ci.set_connection_attempts(1)     # improve responsiveness only make 1 attempt to connect to server
+                #ci.set_retry_connection_period(0) # Only applicable when make more than one attempt. Added to check api.
+                self.ci = Client("localhost", self.the_port)
+
+                print("   ------- Server *NOT* running on port " + self.the_port + " as *EXPECTED* ------ ") 
+                print("   ------- Start the server on port " + self.the_port + " ---------")  
+                if not debugging():
+                    clean_up_server(str(self.the_port))   
+                    clean_up_data(str(self.the_port))    
+        
+                server_exe = File.find_server();
+                assert len(server_exe) != 0, "Could not locate the server executable"
+            
+                server_exe += " --port=" + self.the_port + " --ecfinterval=4 &"
+                print("   TestClient.py: Starting server " + server_exe)
+                os.system(server_exe) 
+            
+                print("   Allow time for server to start " + self.at_time())
+                if self.ci.wait_for_server_reply() :
+                    print("   Server has started " +  self.at_time())
+                    break
+                else:
+                    print("   Server failed to start after 60 second, trying next port !!!!!! " + self.at_time())
+                    self.the_port = self.lock_file.find_free_port( int(self.the_port) + 1 )   
+             
+        print("   Run the tests, leaving Server:__enter__:") 
+
+        # return the Client, that can call to the server
+        return self.ci
+    
+    def __exit__(self,exctype,value,tb):
+        print("Server:__exit__: Kill the server, clean up log file, check pt files and lock files, ECF_HOME " + self.at_time())
+        print("   exctype:",exctype)
+        print("   value:",value)
+        print("   tb:",tb)
+        print("   Terminate server "+ self.at_time() )
+        self.ci.terminate_server()  
+        print("   Terminate server OK " + self.at_time() )
+        self.lock_file.remove(self.the_port)
+        
+        # Do not clean up data, if an assert was raised. This allow debug
+        if exctype is None:
+            if not debugging():
+                clean_up_server(str(self.the_port))
+                clean_up_data(str(self.the_port))
+        return False
diff -pruN 5.12.4-1/libs/pyext/test/py_s_TestClientApi.py 5.13.0-1/libs/pyext/test/py_s_TestClientApi.py
--- 5.12.4-1/libs/pyext/test/py_s_TestClientApi.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_s_TestClientApi.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2143 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+#  code for testing client code in python
+import time
+import os
+import pwd
+import select
+from datetime import datetime
+import shutil   # used to remove directory tree
+
+# ecflow_test_util, see File ecflow_test_util.py
+import ecflow_test_util as Test
+from ecflow import Defs, Suite, Family, Task, Edit, Meter, Clock, DState,  Style, State, RepeatDate, RepeatDateTime, \
+                   PrintStyle, File, Client, SState, CheckPt, Cron, Late, debug_build, Flag, FlagType
+
+def ecf_includes() :  return os.getcwd() + "/test/data/includes"
+
+def debugging() : return False  # Use to enable auto flush and disable log file tests
+
+def create_defs(name=""):
+    defs = Defs()
+    suite_name = name
+    if len(suite_name) == 0: suite_name = "s1"
+    suite = defs.add_suite(suite_name);
+    
+    ecfhome = Test.ecf_home(the_port);
+    suite.add_variable("ECF_HOME", ecfhome);
+    suite.add_variable("ECF_CLIENT_EXE_PATH", File.find_client());
+    suite.add_variable("SLEEP", "1");  # not strictly required since default is 1 second
+    suite.add_variable("ECF_INCLUDE", ecf_includes());
+
+    family = suite.add_family("f1")
+    family.add_task("t1")
+    family.add_task("t2")
+    return defs;
+    
+def test_host_port(ci,host,port):
+    try :
+        ci.set_host_port(host,port)
+        return True
+    except RuntimeError:
+        return False 
+
+def test_host_port_(ci,host_port):
+    try :
+        ci.set_host_port(host_port)
+        return True
+    except RuntimeError:
+        return False 
+    
+def test_client_host_port(host,port):
+    try :
+        Client(host,port)
+        return True
+    except RuntimeError:
+        return False 
+
+def test_client_host_port_(host_port):
+    try :
+        Client(host_port)
+        return True
+    except RuntimeError:
+        return False 
+    
+def sync_local(ci):
+    if ci.is_auto_sync_enabled():
+        return
+    ci.sync_local()
+        
+def test_set_host_port():
+    print("test_set_host_port")
+    ci = Client();
+    print(" Client.get_host() = " + ci.get_host())
+    print(" Client.get_port() = " + ci.get_port())
+    assert test_host_port(ci,"host","3141") ,  "Expected no errors"
+    assert test_host_port(ci,"host",4444) ,    "Expected no errors"
+    assert test_host_port_(ci,"host:4444") ,    "Expected no errors"
+    assert test_host_port_(ci,"host@4444") ,    "Expected no errors"
+    assert test_host_port(ci,"","") == False , "Expected errors"
+    assert test_host_port(ci,"host","") == False , "Expected errors"
+    assert test_host_port(ci,"host","host") == False , "Expected errors"
+    assert test_host_port_(ci,"host:host") == False , "Expected errors"
+    assert test_host_port_(ci,"3141:host") == False , "Expected errors"
+    assert test_host_port_(ci,"3141@host") == False , "Expected errors"
+    assert test_host_port_(ci,"3141@") == False , "Expected errors"
+    
+    assert test_client_host_port("host","3141") ,  "Expected no errors"
+    assert test_client_host_port("host",4444) ,    "Expected no errors"
+    assert test_client_host_port_("host:4444") ,    "Expected no errors"
+    assert test_client_host_port("","") == False , "Expected errors"
+    assert test_client_host_port("host","") == False , "Expected errors"
+    assert test_client_host_port("host","host") == False , "Expected errors"
+    assert test_client_host_port_("host:host") == False , "Expected errors"
+    assert test_client_host_port_("3141:host") == False , "Expected errors"
+
+def print_test(ci,test_name):
+    print(test_name)
+    if ci.is_auto_sync_enabled():
+        ci.log_msg(test_name + " ============= AUTO SYNC ENABLED ================================ ")
+    else:
+        ci.log_msg(test_name + " ================================================================ ")
+
+def test_version(ci):
+    print_test(ci,"test_version")
+    client_version = ci.version();
+    server_version = ci.server_version();
+    print("  client_version: ",client_version)
+    print("  server_version: ",server_version)
+    assert client_version == server_version, "Expected client version(" + client_version +") and server version(" +  server_version + ") to match\n";
+    
+def test_client_get_server_defs(ci):
+    print_test(ci,"test_client_get_server_defs")
+    ci.delete_all() # start fresh
+    ci.load(create_defs())  
+    ci.get_server_defs() 
+    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())
+
+    ci.delete_all() # start fresh
+    ci.load(create_defs()) 
+    sync_local(ci) 
+    
+    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())
+
+
+def test_client_new_log(ci, port):
+    print_test(ci,"test_client_new_log")
+    log_path = Test.log_file_path(port)
+    if not os.path.exists(log_path):
+        print(log_path  + " : log does not exist ?")    
+    
+    new_log_file_name = "./test_client_new_log_" + str(os.getpid()) + ".log"
+    try : os.remove(new_log_file_name) # delete file if it exists
+    except: pass
+    
+    ci.new_log(new_log_file_name) 
+    ci.flush_log() # close log file and force write to disk
+    assert os.path.exists(new_log_file_name),new_log_file_name + " : New log does not exist"
+    try: os.remove(new_log_file_name)
+    except: pass
+    
+    # reset new log to original
+    ci.new_log(log_path) 
+    ci.ping()
+    ci.flush_log() # close log file and force write to disk    
+    log_file = open(log_path)
+    try:     log_text = log_file.read();     # assume log file not to big
+    finally: log_file.close();
+    assert log_text.find("--ping") != -1, "Expected to find --ping in log file"
+ 
+    if not os.path.exists(log_path):
+        print(log_path  + " : log does not exist ?")
+
+def test_client_clear_log(ci, port):
+    if debugging() : return   #  dont run this test when debugging as log file is lost
+    print_test(ci,"test_client_clear_log")
+    log_path = Test.log_file_path(port)
+    # populate log
+    ci.ping();
+    ci.ping();
+    ci.flush_log() # close log file and force write to disk    
+    log_file = open(log_path)
+    try:     log_text = log_file.read();     # assume log file not to big
+    finally: log_file.close();
+    assert log_text.find("--ping") != -1, "Expected to find --ping in log file"
+    
+    ci.clear_log()    
+    if not os.path.exists(log_path):
+        print(log_path  + " : log does not exist ?")
+
+    log_file = open(log_path)
+    try:     log_text = log_file.read();     # assume log file not to big
+    finally: log_file.close();
+    assert len(log_text) == 0, "Expected log file to be empty but found " + log_text
+
+    if not os.path.exists(log_path):
+        print(log_path  + " : log does not exist ?")
+
+
+def test_client_log_msg(ci, port):
+    if debugging() : return   #  dont run this test when debugging  
+
+    print_test(ci,"test_client_log_msg")
+    log_path = Test.log_file_path(port)
+    if not os.path.exists(log_path):
+        print(log_path  + " : log does not exist ?")
+
+    # Send a message to the log file, then make sure it was written
+    ci.log_msg("Humpty dumpty sat on a wall!")
+    ci.flush_log(); # flush and close log file, so we can open it
+    log_file = open(log_path)
+    try:     log_text = log_file.read();     # assume log file not to big
+    finally: log_file.close();
+    assert log_text.find("Humpty dumpty sat on a wall!") != -1, "Expected to find Humpty dumpty in the log file"                
+
+    if not os.path.exists(log_path):
+        print(log_path  + " : log does not exist ?")
+
+def test_client_restart_server(ci):
+    print_test(ci,"test_client_restart_server")
+    ci.restart_server()
+    sync_local(ci)
+    assert ci.get_defs().get_server_state() == SState.RUNNING, "Expected server to be running"
+    
+    paths = list(ci.changed_node_paths)
+    assert len(paths) == 1, "expected changed node to be the root node: " + paths
+    assert paths[0] == "/", "Expected root path but found " + str(paths[0])
+
+
+def test_client_halt_server(ci):
+    print_test(ci,"test_client_halt_server")
+    ci.halt_server()
+    sync_local(ci)
+    assert ci.get_defs().get_server_state() == SState.HALTED, "Expected server to be halted"
+    
+    paths = list(ci.changed_node_paths)
+    assert len(paths) == 1, "expected changed node to be the root node"
+    assert paths[0] == "/", "Expected root path but found " + str(paths[0])
+    ci.restart_server()   
+
+def test_client_shutdown_server(ci):
+    print_test(ci,"test_client_shutdown_server")
+    ci.shutdown_server()
+    sync_local(ci)
+    assert ci.get_defs().get_server_state() == SState.SHUTDOWN, "Expected server to be shutdown"
+    
+    paths = list(ci.changed_node_paths)
+    assert len(paths) == 1, "expected changed node to be the root node"
+    assert paths[0] == "/", "Expected root path but found " + str(paths[0])
+
+
+def test_client_load_in_memory_defs(ci):
+    print_test(ci,"test_client_load_in_memory_defs")
+    ci.delete_all() # start fresh
+    ci.load(create_defs())  
+    sync_local(ci) 
+    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())              
+
+
+def test_client_load_from_disk(ci):            
+    print_test(ci,"test_client_load_from_disk")
+    ci.delete_all() # start fresh
+    defs = create_defs();
+    defs_file = "test_client_load_from_disk_" + str(os.getpid()) + ".def"
+    defs.save_as_defs(defs_file)     
+    assert os.path.exists(defs_file), "Expected file " + defs_file + " to exist after defs.save_as_defs()"
+    ci.load(defs_file) # open and parse defs file, and load into server.\n"
+        
+    sync_local(ci) 
+    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite of name s1:\n" + str(ci.get_defs())
+    os.remove(defs_file)
+
+
+def test_client_checkpt(ci, port):
+    print_test(ci,"test_client_checkpt")
+    # start fresh
+    ci.delete_all() 
+    try:    
+        os.remove(Test.checkpt_file_path(port))
+        os.remove(Test.backup_checkpt_file_path(port))
+    except: pass
+    
+    ci.load(create_defs())  
+    ci.checkpt()
+    assert os.path.exists(Test.checkpt_file_path(port)), "Expected check pt file to exist after ci.checkpt()"
+    assert os.path.exists(Test.backup_checkpt_file_path(port)) == False, "Expected back up check pt file to *NOT* exist"
+    
+    ci.checkpt()   # second check pt should cause backup check pt to be written
+    assert os.path.exists(Test.backup_checkpt_file_path(port)), "Expected back up check pt file to exist after second ci.checkpt()"
+
+    ci.checkpt(CheckPt.NEVER)         # switch of check pointing
+    ci.checkpt(CheckPt.ALWAYS)        # always check point, at any state change
+    ci.checkpt(CheckPt.ON_TIME)       # Check point periodically, by interval set in server
+    ci.checkpt(CheckPt.ON_TIME, 200)  # Check point periodically, by interval set in server
+    ci.checkpt(CheckPt.UNDEFINED, 0, 35)  # Change check point save time alarm
+
+    os.remove(Test.checkpt_file_path(port))
+    os.remove(Test.backup_checkpt_file_path(port))
+
+
+def test_client_restore_from_checkpt(ci, port):          
+    print_test(ci,"test_client_restore_from_checkpt")
+    # start fresh
+    ci.delete_all() 
+    try:    
+        os.remove(Test.checkpt_file_path(port))
+        os.remove(Test.backup_checkpt_file_path(port))
+    except: pass
+    
+    ci.load(create_defs())  
+    ci.checkpt()
+    ci.delete_all() 
+    
+    sync_local(ci) 
+    assert ci.get_defs().find_suite("s1") is None, "Expected all suites to be delete:\n"
+    
+    ci.halt_server()  # server must be halted, otherwise restore_from_checkpt will throw
+    ci.restore_from_checkpt()
+    
+    sync_local(ci) 
+    assert ci.get_defs().find_suite("s1") is not None, "Expected to find suite s1 after restore from checkpt:\n" + str(ci.get_defs())
+
+    os.remove(Test.checkpt_file_path(port))
+    ci.restart_server()   
+
+
+def get_username(): return pwd.getpwuid(os.getuid())[ 0 ]
+
+def test_client_reload_wl_file(ci, port):
+    print_test(ci,"test_client_reload_wl_file")
+    
+    expected = False
+    try:    ci.reload_wl_file();            
+    except: expected = True
+    assert expected, "Expected reload to fail when no white list specified"
+    
+    # create a white list file
+    wl_file = open(Test.white_list_file_path(port), 'w')
+    wl_file.write("#\n")
+    wl_file.write("4.4.14   #   comment\n\n")
+    wl_file.write("# These user have read and write access to the server\n")
+    wl_file.write(get_username() + "\n")  # add current user otherwise remaining test's, wont have access from server anymore
+    wl_file.write("axel  # admin\n")
+    wl_file.write("john  # admin\n\n")
+    wl_file.write("# Read only users\n")
+    wl_file.write("-fred   # needs read access only\n")
+    wl_file.write("-joe90  # needs read access only\n")
+    wl_file.close();
+    
+    ci.reload_wl_file();  
+    os.remove(Test.white_list_file_path(port))          
+
+
+def test_client_run(ci):            
+    print_test(ci,"test_client_run")
+    ci.delete_all()     
+    defs = create_defs("test_client_run")  
+    suite = defs.find_suite("test_client_run")
+    suite.add_defstatus(DState.suspended)
+
+    defs.generate_scripts();
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+    
+    ci.restart_server()
+    ci.load(defs)           
+    ci.begin_all_suites()
+    ci.run("/test_client_run", False)
+    
+    count = 0
+    while 1:
+        count += 1
+        ci.sync_local() # get the changes, synced with local defs
+        suite = ci.get_defs().find_suite("test_client_run")
+        assert suite is not None, "Expected to find suite test_client_run:\n" + str(ci.get_defs())
+        print(f"Suite state: {suite.get_state()}, {count}, at {datetime.now()}")
+        if suite.get_state() == State.complete:
+            break;
+        assert suite.get_state() != State.aborted, "Expected suite to complete, but found it was aborted"
+        time.sleep(3)
+        if count > 20:
+            assert False, "test_client_run aborted after " + str(count) + " loops:\n" + str(ci.get_defs())
+        
+    ci.log_msg("Looped " + str(count) + " times")
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_run"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)  
+
+
+def test_client_run_with_multiple_paths(ci):            
+    print_test(ci,"test_client_run_with_multiple_paths")
+    ci.delete_all()     
+    defs = create_defs("test_client_run_with_multiple_paths")  
+    suite = defs.find_suite("test_client_run_with_multiple_paths")
+    suite.add_defstatus(DState.suspended)
+
+    defs.generate_scripts();
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+    
+    ci.restart_server()
+    ci.load(defs)           
+    ci.begin_all_suites()
+    path_list = [ "/test_client_run_with_multiple_paths/f1/t1", "/test_client_run_with_multiple_paths/f1/t2"]
+    ci.run( path_list, False)
+
+    count = 0
+    while 1:
+        count += 1
+        ci.sync_local() # get the changes, synced with local defs
+        suite = ci.get_defs().find_suite("test_client_run_with_multiple_paths")
+        assert suite is not None, "Expected to find suite test_client_run_with_multiple_paths:\n" + str(ci.get_defs())
+        if suite.get_state() == State.complete:
+            break;
+        time.sleep(3)
+        if count > 20:
+            assert False, "test_client_run_with_multiple_paths aborted after " + str(count) + " loops:\n" + str(ci.get_defs())
+        
+    ci.log_msg("Looped " + str(count) + " times")
+    
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_run_with_multiple_paths"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)     
+
+    
+def test_client_requeue(ci):
+    print_test(ci,"test_client_requeue")
+    ci.delete_all()     
+    defs = create_defs("test_client_requeue")  
+    suite = defs.find_suite("test_client_requeue")
+    suite.add_defstatus(DState.suspended)
+     
+    defs.generate_scripts()
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+ 
+    ci.restart_server()
+    ci.load(defs)           
+    ci.begin_all_suites()
+    
+    ci.force_state_recursive("/test_client_requeue",State.unknown)
+    sync_local(ci)
+    suite = ci.get_defs().find_suite("test_client_requeue")
+    assert suite.get_state() == State.unknown, "Expected to find suite with state unknown"
+
+    ci.requeue("/test_client_requeue")
+    sync_local(ci);
+    suite = ci.get_defs().find_suite("test_client_requeue")
+    assert suite.get_state() == State.queued, "Expected to find suite with state queued"
+
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_requeue"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)     
+
+def test_client_requeue_with_multiple_paths(ci):
+    print_test(ci,"test_client_requeue_with_multiple_paths")
+    ci.delete_all()     
+    defs = create_defs("test_client_requeue_with_multiple_paths")  
+    suite = defs.find_suite("test_client_requeue_with_multiple_paths")
+    suite.add_defstatus(DState.suspended)
+     
+    defs.generate_scripts()
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+ 
+    ci.restart_server()
+    ci.load(defs)           
+    ci.begin_all_suites()
+    
+    ci.force_state_recursive("/test_client_requeue_with_multiple_paths",State.unknown)
+    sync_local(ci);
+    task1 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t1")
+    task2 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t2")
+    assert task1.get_state() == State.unknown, "Expected to find t1 with state unknown"
+    assert task2.get_state() == State.unknown, "Expected to find t2 with state unknown"
+
+    path_list = [ "/test_client_requeue_with_multiple_paths/f1/t1", "/test_client_requeue_with_multiple_paths/f1/t2" ]
+    ci.requeue( path_list)
+    sync_local(ci);
+    task1 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t1")
+    task2 = ci.get_defs().find_abs_node("/test_client_requeue_with_multiple_paths/f1/t2")
+    assert task1.get_state() == State.queued, "Expected to find task t1 with state queued"
+    assert task2.get_state() == State.queued, "Expected to find task t2 with state queued"
+
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_requeue_with_multiple_paths"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)     
+
+
+def test_client_free_dep(ci):
+    print_test(ci,"test_client_free_dep")
+    ci.delete_all()  
+       
+    # add a real clock, since we are adding date dependencies
+    # Note: adding a future time dependency on a task, will cause it to requeue, when complete
+    # Hence even when we free these dependency they get requeued.
+    # So we use todays date.
+    ltime = time.localtime();
+    day = ltime.tm_mday
+    month = ltime.tm_mon
+    year = ltime.tm_year
+    
+    defs = Defs()
+    suite = defs.add_suite("test_client_free_dep");
+    suite.add_clock(Clock(False)) # true means hybrid, False means real
+    ecfhome = Test.ecf_home(the_port);
+    suite.add_variable("ECF_HOME", ecfhome);
+    suite.add_variable("ECF_CLIENT_EXE_PATH", File.find_client());
+    suite.add_variable("SLEEPTIME", "1");
+    suite.add_variable("ECF_INCLUDE", ecf_includes());
+    family = suite.add_family("f1")
+    family.add_task("t1").add_time("00:01")
+    family.add_task("t2").add_date(day,month,year)
+    family.add_task("t3").add_trigger("1 == 0")
+    t4 = family.add_task("t4")
+    t4.add_time("00:01")
+    t4.add_date(day,month,year)
+    t4.add_trigger("1 == 0")
+
+    defs.generate_scripts();
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+ 
+    ci.restart_server()
+    ci.load(defs)           
+    ci.begin_all_suites()
+    
+    t1_path = "/test_client_free_dep/f1/t1"
+    t2_path = "/test_client_free_dep/f1/t2"
+    t3_path = "/test_client_free_dep/f1/t3"
+    t4_path = "/test_client_free_dep/f1/t4"
+    while 1:
+        ci.sync_local()
+        t1 = ci.get_defs().find_abs_node(t1_path)
+        t2 = ci.get_defs().find_abs_node(t2_path)
+        t3 = ci.get_defs().find_abs_node(t3_path)
+        t4 = ci.get_defs().find_abs_node(t4_path)
+ 
+        if t1.get_state() == State.queued: ci.free_time_dep(t1_path)
+        if t2.get_state() == State.queued: ci.free_date_dep(t2_path)
+        if t3.get_state() == State.queued: ci.free_trigger_dep(t3_path)
+        if t4.get_state() == State.queued: ci.free_all_dep(t4_path)
+
+        suite = ci.get_defs().find_suite("test_client_free_dep")
+        if suite.get_state() == State.complete:
+            break;
+        time.sleep(3)       
+            
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_free_dep"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)
+
+
+class CustomStdOut:
+    def __enter__(self):
+        # create a pipe to store some content temporarily
+        self.read_pipe, self.write_pipe = os.pipe()
+        # save the original ouput fd
+        self.stdout = os.dup(1)
+        # redirect stdout into the write pipe
+        fd = os.dup2(self.write_pipe, 1)
+        return self
+
+    def __exit__(self, exc_type, exc_value, exc_traceback):
+        # restore the original output fd
+        os.dup2(self.stdout, 1)
+
+    def _more_data(self):
+        # check if there is more data in the read pipe
+        r, _, _ = select.select([self.read_pipe], [], [], 0)
+        return bool(r)
+
+    def value(self):
+        out = ''
+        while self._more_data():
+            out += os.read(self.read_pipe, 1024).decode('utf-8')
+        return out
+
+
+def test_client_stats(ci):
+    print_test(ci,"test_client_stats")
+    with CustomStdOut() as out:
+        stats = ci.stats()
+        assert "statistics" in stats, "Expected 'statistics' in the response"
+        assert "statistics" in out.value(), "Expected 'statistics' in the captured output"
+
+
+def test_client_stats_with_stdout(ci):
+    print_test(ci,"test_client_stats_with_stdout")
+    with CustomStdOut() as out:
+        stats = ci.stats(True)
+        assert "statistics" in stats, "Expected 'statistics' in the response"
+        assert "statistics" in out.value(), "Expected 'statistics' in the captured output"
+
+
+def test_client_stats_without_stdout(ci):
+    print_test(ci,"test_client_stats_without_stdout")
+    with CustomStdOut() as out:
+        stats = ci.stats(False)
+        assert "statistics" in stats, "Expected 'statistics' in the response"
+        assert not out.value() , "No captured output expected"
+
+
+def test_client_stats_reset(ci):
+    print_test(ci,"test_client_stats_reset")
+    ci.stats_reset()   
+    stats = ci.stats()
+    assert "statistics" in stats, "Expected 'statistics' in the response"
+
+
+def test_client_debug_server_on_off(ci):
+    print_test(ci,"test_client_debug_server_on_off")
+    ci.debug_server_on()  # writes to standard out
+    ci.debug_server_off()  
+
+
+def test_client_check(ci):
+    print_test(ci,"test_client_check")
+    ci.delete_all()     
+    
+    defs = Defs()
+    defs.add_extern("/a/b/c/d")
+    defs.add_extern("/a/b/c/d/e:event")
+    defs.add_extern("/a/b/c/d/e:meter")
+    defs.add_extern("/made/up/redundant/extren")
+    defs.add_extern("/made/up/redundant/extren")
+    defs.add_extern("/limits:c1a")
+    defs.add_extern("/limits:c1a")
+    defs.add_extern("fred")
+    defs.add_extern("limits:hpcd")
+    defs.add_extern("/suiteName:sg1")
+    defs.add_extern("/obs/limits:hpcd")
+    suite = defs.add_suite("extern")
+    family_f1 = suite.add_family("f1")
+    family_f1.add_task("p").add_trigger("/a/b/c/d == complete")      # extern path
+    family_f1.add_task("q").add_trigger("/a/b/c/d/e:event == set")   # extern event path
+    family_f1.add_task("r").add_trigger("/a/b/c/d/e:meter le 30")    # extern meter path
+
+    suite.add_inlimit("c1a","/limits")
+    suite.add_inlimit("fred")
+    
+    family_anon = suite.add_family("anon")
+    family_anon.add_inlimit("hpcd","limits")
+    family_anon.add_task("t1").add_inlimit("sg1","/suiteName")
+    family_anon.add_task("t2").add_inlimit("hpcd","/obs/limits")
+    family_anon.add_task("t3").add_inlimit("c1a","/limits")
+ 
+    # CLIENT side check
+    client_check = defs.check()
+    assert len(client_check) == 0, "Expected clean defs check due to externs but found:\n" + client_check + "\n" + str(defs)
+
+    # SERVER side check
+    ci.load(defs)
+    server_check = ci.check("") # empty string means check the whole defs, otherwise a node path can be specified.
+    # print(server_check)
+    assert len(server_check) > 0, "Expected defs to fail, since no externs in server "
+    
+def test_client_suites(ci):
+    print_test(ci,"test_client_suites")
+    ci.delete_all() 
+    assert len(ci.suites()) == 0 ,"expected 0 suite "
+
+    defs = create_defs("test_client_suites")
+    ci.load(defs)  
+    assert len(ci.suites()) == 1 ,"expected 1 suite "
+    
+    ci.delete_all() 
+    defs.add_suite("s2")
+    ci.load(defs)  
+    assert len(ci.suites()) == 2 ,"expected 2 suite "
+    
+def test_client_ch_suites(ci):
+    print_test(ci,"test_client_ch_suites")
+    try: ci.ch_drop_user("")  # drop all handle associated with current user
+    except: pass              # Drop throws if no handle registered
+    ci.delete_all()     
+    
+    defs = Defs()
+    for i in range(1,7): defs.add_suite("s" + str(i))
+    ci.load(defs)
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 after load, but found " + str(len(list((ci.get_defs().suites))))
+
+    suite_names = [ 's1', 's2', 's3' ]
+    ci.ch_register(True,suite_names)    # register interest in suites s1,s2,s3 and any new suites
+    print("ch_handle after register : " , ci.ch_handle())
+    ci.ch_suites()  # writes to standard out, list of suites and handles
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 3,"Expected 3 registered suites but found " + str(len(list((ci.get_defs().suites))))
+
+    ci.ch_register(False,[ "s1"])       # register interest in suites s1. ci remembers the last client handle
+    ci.ch_suites()  # writes to standard out, list of suites and handles
+    sync_local(ci)
+    ci.ch_suites()  # writes to standard out, list of suites and handles
+    assert len(list(ci.get_defs().suites)) == 1,"Expected 1 registered suites but found " + str(len(list((ci.get_defs().suites))))
+    
+
+def test_client_ch_register(ci):
+    print_test(ci,"test_client_ch_register")
+    try: ci.ch_drop_user("")  # drop all handle associated with current user
+    except: pass              # Drop throws if no handle registered
+    ci.delete_all()  
+    
+    defs = Defs()
+    for i in range(1,7): defs.add_suite("s" + str(i))
+    ci.load(defs)
+    
+    suite_names = [ 's1', 's2', 's3' ]
+    ci.ch_register(True, suite_names)    # register interest in suites s1,s2,s3 and any new suites
+    ci.ch_register(False,suite_names)    # register interest in suites s1,s2,s3 only
+
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 3,"Expected 3 registered suites but found " + str(len(list((ci.get_defs().suites))))
+  
+            
+def test_client_ch_drop(ci):
+    print_test(ci,"test_client_ch_drop")
+    try: ci.ch_drop_user("")  # drop all handle associated with current user
+    except: pass              # Drop throws if no handle registered
+    ci.delete_all()   
+    
+    defs = Defs()
+    for i in range(1,7): defs.add_suite("s" + str(i))
+    ci.load(defs)
+    
+    try:
+        # register interest in suites s1,s2,s3 and any new suites
+        suite_names = [ 's1', 's2', 's3' ]
+        ci.ch_register(True, suite_names)    
+    finally:  
+        ci.ch_drop()  # drop using handle stored in ci., from last register
+
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
+         
+          
+def test_client_ch_drop_user(ci):
+    print_test(ci,"test_client_ch_drop_user")
+    ci.delete_all()   
+    try: ci.ch_drop_user("")  # drop all handle associated with current user
+    except: pass              # Drop throws if no handle registered
+    
+    defs = Defs()
+    for i in range(1,7): defs.add_suite("s" + str(i))
+    ci.load(defs)
+    
+    try:
+        # register interest in suites s1,s2,s3 and any new suites
+        suite_names = [ 's1', 's2', 's3' ]
+        ci.ch_register(True, suite_names)
+        sync_local(ci)
+        assert len(list(ci.get_defs().suites)) == 3,"Expected 3 suites but found " + str(len(list((ci.get_defs().suites))))
+    except RuntimeError as e:
+        print(str(e))
+    
+    ci.ch_drop_user("")  # drop all handle associated with current user
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
+            
+            
+def test_client_ch_add(ci):
+    print_test(ci,"test_client_ch_add")
+    ci.delete_all()  
+    try: ci.ch_drop_user("")  # drop all handle associated with current user
+    except: pass              # Drop throws if no handle registered
+    
+    defs = Defs()
+    for i in range(1,7): defs.add_suite("s" + str(i))
+    ci.load(defs)
+    
+    try:
+        suite_names = []
+        ci.ch_register(True,suite_names)        # register interest in any new suites
+        suite_names = [ 's1', 's2' ]
+        ci.ch_add(suite_names)                  # add suites s1,s2 to the last added handle
+        sync_local(ci)
+        assert len(list(ci.get_defs().suites)) == 2,"Expected 2 suites but found " + str(len(list((ci.get_defs().suites))))
+
+        suite_names = [ 's3', 's4' ]
+        ci.ch_add( ci.ch_handle(),suite_names)  # add suites s3,s4 using last handle
+        sync_local(ci)
+        assert len(list(ci.get_defs().suites)) == 4,"Expected 4 suites but found " + str(len(list((ci.get_defs().suites))))
+        
+    except RuntimeError as e:
+        print(str(e))
+        
+    ci.ch_drop_user("")  # drop all handle associated with current user
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
+
+            
+def test_client_ch_auto_add(ci):
+    print_test(ci,"test_client_ch_auto_add")
+    ci.delete_all()  
+    try: ci.ch_drop_user("")  # drop all handle associated with current user
+    except: pass              # Drop throws if no handle registered
+    
+    defs = Defs()
+    for i in range(1,7): defs.add_suite("s" + str(i))
+    ci.load(defs)
+    
+    try:
+        suite_names = [ 's1', 's2' , 's3']
+        ci.ch_register(True,suite_names)        # register interest in suites s1,s2,s3 and any new suites
+        ci.ch_auto_add( False )                 # disable adding newly created suites to last registered handle\n"
+        ci.ch_auto_add( True )                  # enable adding newly created suites to last registered handle\n"
+        ci.ch_auto_add( ci.ch_handle(), False ) # disable adding newly created suites to handle\n"
+        sync_local(ci)
+        assert len(list(ci.get_defs().suites)) == 3,"Expected 3 suites but found " + str(len(list((ci.get_defs().suites))))
+    except RuntimeError as e:
+        print(str(e))
+        
+    ci.ch_drop_user("")  # drop all handle associated with current user
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
+        
+           
+def test_client_ch_remove(ci):
+    print_test(ci,"test_client_ch_remove")
+    ci.delete_all()  
+    try: ci.ch_drop_user("")  # drop all handle associated with current user
+    except: pass              # Drop throws if no handle registered
+    
+    defs = Defs()
+    for i in range(1,7): defs.add_suite("s" + str(i))
+    ci.load(defs)
+    
+    try:
+        suite_names = [ 's1', 's2' , 's3']
+        ci.ch_register(True,suite_names)     # register interest in suites s1,s2,s3 and any new suites
+        sync_local(ci)
+        assert len(list(ci.get_defs().suites)) == 3,"Expected 3 suites but found " + str(len(list((ci.get_defs().suites))))
+
+        suite_names = [ 's1' ]
+        ci.ch_remove( suite_names )          # remove suites s1 from the last added handle\n"
+        sync_local(ci)
+        assert len(list(ci.get_defs().suites)) == 2,"Expected 2 suites but found " + str(len(list((ci.get_defs().suites))))
+        
+        suite_names = [ 's2' ]
+        ci.ch_remove( ci.ch_handle(), suite_names )  # remove suites s2 from the last added handle\n"
+        sync_local(ci)
+        assert len(list(ci.get_defs().suites)) == 1,"Expected 1 suites but found " + str(len(list((ci.get_defs().suites))))
+
+    except RuntimeError as e:
+        print(str(e))
+        
+    ci.ch_drop_user("")  # drop all handle associated with current user
+    sync_local(ci)
+    assert len(list(ci.get_defs().suites)) == 6,"Expected 6 suites but found " + str(len(list((ci.get_defs().suites))))
+           
+           
+def test_client_get_file(ci):
+    print_test(ci, "test_client_get_file")
+    ci.delete_all()     
+    defs = create_defs("test_client_get_file")  
+    
+    # Also test where user has specified his OWN ECF_JOBOUT (rare)
+    t2 = defs.find_abs_node("/test_client_get_file/f1/t2")
+    t2_jobout = Test.ecf_home(the_port) + "/test_client_get_file/t2.xx"
+    t2.add_variable("ECF_JOBOUT", t2_jobout)
+    
+    defs.generate_scripts()
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+ 
+    ci.restart_server()
+    ci.load(defs)           
+    ci.begin_all_suites()
+    
+    while 1:
+        if ci.news_local():
+            ci.sync_local()  # get the changes, synced with local defs
+            suite = ci.get_defs().find_suite("test_client_get_file")
+            assert suite is not None, "Expected to find suite"
+            if suite.get_state() == State.complete:
+                break
+        time.sleep(1)
+
+    try:
+        for task in ['/test_client_get_file/f1/t1', '/test_client_get_file/f1/t2']:
+
+            result_string = ci.get_file(task)
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}) to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}) to return something"
+
+            result_string = ci.get_file(task, as_bytes=False)
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}, as_bytes=False) to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}, as_bytes=False) to return something"
+
+            result_bytes = ci.get_file(task, as_bytes=True)
+            assert isinstance(result_bytes, bytes), \
+                f"Expected ci.get_file({task}, as_bytes=True) to return 'bytes'"
+            assert len(result_bytes) > 0, \
+                f"Expected ci.get_file({task}, as_bytes=True) to return something"
+
+            assert len(result_string) == len(result_bytes), \
+                f"Expected 'str' result and 'bytes' result to have the same length"
+
+            result_string = ci.get_file(task, max_lines='10')
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}, max_lines='10') to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}, max_lines='10') to return something"
+
+            result_string = ci.get_file(task, max_lines='10', as_bytes=False)
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=False) to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=False) to return something"
+
+            result_bytes = ci.get_file(task, max_lines='10', as_bytes=True)
+            assert isinstance(result_bytes, bytes), \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=True) to return 'bytes'"
+            assert len(result_bytes) > 0, \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=True) to return something"
+
+            assert len(result_string) == len(result_bytes), \
+                f"Expected 'str' result and 'bytes' result to have the same length"
+
+            for file_type in ['script', 'job', 'jobout', 'manual']:
+
+                result_string = ci.get_file(task, file_type)
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}) to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}) to return something"
+
+                result_string = ci.get_file(task, file_type, as_bytes=False)
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=False) to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=False) to return something"
+
+                result_bytes = ci.get_file(task, file_type, as_bytes=True)
+                assert isinstance(result_bytes, bytes), \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=True) to return 'bytes'"
+                assert len(result_bytes) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=True) to return something"
+
+                assert len(result_string) == len(result_bytes), \
+                    f"Expected 'str' result and 'bytes' result to have the same length"
+
+                result_string = ci.get_file(task, file_type, '10')
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}, '10') to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, '10') to return something"
+
+                result_string = ci.get_file(task, file_type, '10', as_bytes=False)
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=False) to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=False) to return something"
+
+                result_bytes = ci.get_file(task, file_type, '10', as_bytes=True)
+                assert isinstance(result_bytes, bytes), \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=True) to return 'bytes'"
+                assert len(result_bytes) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=True) to return something"
+
+                assert len(result_string) == len(result_bytes), \
+                    f"Expected 'str' result and 'bytes' result to have the same length"
+
+        assert os.path.exists(t2_jobout), f"User specified ECF_JOBOUT file not created {t2_jobout}"
+ 
+    except RuntimeError as e:
+        print(str(e))
+
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_get_file"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)  
+
+    
+def test_client_plug(ci):
+    pass
+           
+def test_client_alter_sort(ci):
+    print_test(ci,"test_client_alter_sort")
+    ci.delete_all()   
+    
+    defs = create_defs("test_client_alter_sort")
+    t1 = "/test_client_alter_sort/f1/t1"
+    task_t1 = defs.find_abs_node(t1)
+    task_t1.add_variable("z","value").add_variable("y","value").add_variable("x","value")
+    task_t1.add_event("z").add_event("y").add_event("x")
+    task_t1.add_meter("z",0,100,100).add_meter("y",0,100,100).add_meter("x",0,100,100)
+    task_t1.add_label("z","name").add_label("y","name").add_label("x","name")
+    task_t1.add_limit("z",10).add_limit("y",10).add_limit("x",10)
+    
+    ci.load(defs)   
+    
+    ci.sort_attributes(t1,"variable")
+    ci.sort_attributes(t1,"event")
+    ci.sort_attributes(t1,"meter")
+    ci.sort_attributes(t1,"label")
+    ci.sort_attributes(t1,"limit")
+
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.variables)) == 3 ,"Expected 3 variable :\n" + str(ci.get_defs())
+    assert len(list(task_t1.events)) == 3 ,"Expected 3 events :\n" + str(ci.get_defs())
+    assert len(list(task_t1.meters)) == 3 ,"Expected 3 meters :\n" + str(ci.get_defs())
+    assert len(list(task_t1.labels)) == 3 ,"Expected 3 labels :\n" + str(ci.get_defs())
+    assert len(list(task_t1.limits)) == 3 ,"Expected 3 limits :\n" + str(ci.get_defs())
+    expected = ['x','y','z']; vactual = []; eactual = []; mactual = []; lactual = []; liactual = [];
+    for v in task_t1.variables: vactual.append(v.name())
+    for v in task_t1.events: eactual.append(v.name())
+    for v in task_t1.meters: mactual.append(v.name())
+    for v in task_t1.labels: lactual.append(v.name())
+    for v in task_t1.limits: liactual.append(v.name())
+    assert expected == vactual, "variable Attributes not sorted, expected:" + str(expected) + " but found:" + str(vactual)
+    assert expected == eactual, "event Attributes not sorted, expected:" + str(expected) + " but found:" + str(eactual)
+    assert expected == mactual, "meter Attributes not sorted, expected:" + str(expected) + " but found:" + str(mactual)
+    assert expected == lactual, "label Attributes not sorted, expected:" + str(expected) + " but found:" + str(lactual)
+    assert expected == liactual,"limit Attributes not sorted, expected:" + str(expected) + " but found:" + str(liactual)
+
+def test_client_alter_sort_defs(ci):
+    print_test(ci,"test_client_alter_sort_defs")
+    ci.delete_all()   
+    
+    defs = create_defs("test_client_alter_sort_defs")
+    t1 = "/test_client_alter_sort_defs/f1/t1"
+    task_t1 = defs.find_abs_node(t1)
+    task_t1.add_variable("z","value").add_variable("y","value").add_variable("x","value")
+    task_t1.add_event("z").add_event("y").add_event("x")
+    task_t1.add_meter("z",0,100,100).add_meter("y",0,100,100).add_meter("x",0,100,100)
+    task_t1.add_label("z","name").add_label("y","name").add_label("x","name")
+    task_t1.add_limit("z",10).add_limit("y",10).add_limit("x",10)
+    
+    ci.load(defs)   
+    
+    ci.sort_attributes("/","variable",True)
+    ci.sort_attributes("/","event",True)
+    ci.sort_attributes("/","meter",True)
+    ci.sort_attributes("/","label",True)
+    ci.sort_attributes("/","limit",True)
+
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.variables)) == 3 ,"Expected 3 variable :\n" + str(ci.get_defs())
+    assert len(list(task_t1.events)) == 3 ,"Expected 3 events :\n" + str(ci.get_defs())
+    assert len(list(task_t1.meters)) == 3 ,"Expected 3 meters :\n" + str(ci.get_defs())
+    assert len(list(task_t1.labels)) == 3 ,"Expected 3 labels :\n" + str(ci.get_defs())
+    assert len(list(task_t1.limits)) == 3 ,"Expected 3 limits :\n" + str(ci.get_defs())
+    expected = ['x','y','z']; vactual = []; eactual = []; mactual = []; lactual = []; liactual = [];
+    for v in task_t1.variables: vactual.append(v.name())
+    for v in task_t1.events: eactual.append(v.name())
+    for v in task_t1.meters: mactual.append(v.name())
+    for v in task_t1.labels: lactual.append(v.name())
+    for v in task_t1.limits: liactual.append(v.name())
+    assert expected == vactual, "variable Attributes not sorted, expected:" + str(expected) + " but found:" + str(vactual)
+    assert expected == eactual, "event Attributes not sorted, expected:" + str(expected) + " but found:" + str(eactual)
+    assert expected == mactual, "meter Attributes not sorted, expected:" + str(expected) + " but found:" + str(mactual)
+    assert expected == lactual, "label Attributes not sorted, expected:" + str(expected) + " but found:" + str(lactual)
+    assert expected == liactual,"limit Attributes not sorted, expected:" + str(expected) + " but found:" + str(liactual)
+ 
+           
+def test_client_alter_add(ci):
+    print_test(ci,"test_client_alter_add")
+    ci.delete_all()     
+    ci.load(create_defs("test_client_alter_add"))   
+
+    t1 = "/test_client_alter_add/f1/t1"
+    ci.alter(t1,"add","variable","var","var_name")
+    ci.alter(t1,"add","variable","var2","--")
+    ci.alter(t1,"add","variable","var3","--fred")
+    ci.alter(t1,"add","variable","var4"," --fred ")
+    ci.alter(t1,"add","variable","var5","--fred --jake")
+    ci.alter(t1,"add","variable","var6"," --fred --jake ")
+    ci.alter(t1,"add","variable","var7","")
+    ci.alter(t1,"add","time","+00:30")
+    ci.alter(t1,"add","time","01:30")
+    ci.alter(t1,"add","time","01:30 20:00 00:30")
+    ci.alter(t1,"add","today","+00:30")
+    ci.alter(t1,"add","today","01:30")
+    ci.alter(t1,"add","today","01:30 20:00 00:30")
+    ci.alter(t1,"add","date","01.01.2001")
+    ci.alter(t1,"add","date","*.01.2001")
+    ci.alter(t1,"add","date","*.*.2001")
+    ci.alter(t1,"add","date","*.*.*")
+    ci.alter(t1,"add","day","sunday")
+    ci.alter(t1,"add","day","monday")
+    ci.alter(t1,"add","day","tuesday")
+    ci.alter(t1,"add","day","wednesday")
+    ci.alter(t1,"add","day","thursday")
+    ci.alter(t1,"add","day","friday")
+    ci.alter(t1,"add","day","saturday")
+    ci.alter(t1,"add","late","late -s +00:15 -a 20:00 -c +02:00")
+    ci.alter(t1,"add","label","label_name","label_value")
+    ci.alter(t1,"add","label","label_name2","/a/label/with/path/values")
+
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.variables)) == 7 ,"Expected 7 variable :\n" + str(ci.get_defs())
+    assert len(list(task_t1.times)) == 3 ,"Expected 3 time :\n" + str(ci.get_defs())
+    assert len(list(task_t1.todays)) == 3 ,"Expected 3 today's :\n" + str(ci.get_defs())
+    assert len(list(task_t1.dates)) == 4 ,"Expected 4 dates :\n" + str(ci.get_defs())
+    assert len(list(task_t1.days)) == 7 ,"Expected 7 days :\n" + str(ci.get_defs())
+    assert len(list(task_t1.labels)) == 2 ,"Expected 2 labels :\n" + str(ci.get_defs())
+    assert str(task_t1.get_late()) == "late -s +00:15 -a 20:00 -c +02:00", "Expected late 'late -s +00:15 -a 20:00 -c +02:00'" + str(ci.get_defs())
+           
+
+def test_client_alter_delete(ci):
+    print_test(ci,"test_client_alter_delete")
+    ci.delete_all() 
+    defs = create_defs("test_client_alter_delete")  
+    suite_with_limits = defs.add_suite("suite_with_limits")
+    suite_with_limits.add_limit("limitX",10)
+    suite_with_limits_X = defs.add_suite("suite_with_limits_X")
+    suite_with_limits_X.add_limit("limitX",10)
+ 
+    t1 = "/test_client_alter_delete/f1/t1"
+    task_t1 = defs.find_abs_node(t1)
+    task_t1.add_variable("var","value")
+    task_t1.add_variable("var1","value")
+    task_t1.add_time("00:30")
+    task_t1.add_time("00:31")
+    task_t1.add_today("00:30")
+    task_t1.add_today("00:31")
+    task_t1.add_date(1,1,2001)
+    task_t1.add_date(1,1,2002)
+    task_t1.add_day("sunday")
+    task_t1.add_day("monday")
+    cron = Cron()
+    cron.set_week_days( [0,1,2,3,4,5,6] )
+    cron.set_time_series( "+00:30" )
+    task_t1.add_cron(cron)
+    task_t1.add_cron(cron)
+    task_t1.add_event("event")
+    task_t1.add_event("event1")
+    task_t1.add_meter("meter",0,100,100)
+    task_t1.add_meter("meter1",0,100,100)
+    task_t1.add_label("label","name")
+    task_t1.add_label("label1","name")
+    task_t1.add_limit("limit",10)
+    task_t1.add_limit("limit1",10)
+    task_t1.add_inlimit( "limit",t1,2)
+    task_t1.add_inlimit( "limit1",t1,2)
+    task_t1.add_inlimit( "limitX","/suite_with_limits",2)
+    task_t1.add_inlimit( "limitX","/suite_with_limits_X",2)
+    task_t1.add_trigger( "t2 == active" )
+    task_t1.add_complete( "t2 == complete" )
+    
+    assert task_t1.get_late() is None, "expected no late" 
+    late = Late()
+    late.submitted(20, 10)
+    late.active(20, 10)
+    late.complete(20, 10, True)
+    task_t1.add_late(late)
+    assert task_t1.get_late() is not None, "expected late" 
+    
+            
+    t2 = "/test_client_alter_delete/f1/t2"
+    task_t2 = defs.find_abs_node(t2)
+    task_t2.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
+    
+    #print(defs)
+    ci.load(defs)   
+
+    ci.alter(t1,"delete","variable","var")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.variables)) == 1 ,"Expected 1 variable :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","variable")  # delete all veriables
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.variables)) == 0 ,"Expected 0 variable :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","time","00:30")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.times)) == 1 ,"Expected 1 time :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","time")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.times)) == 0 ,"Expected 0 time :\n" + str(ci.get_defs())
+    
+    ci.alter(t1,"delete","today","00:30")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.todays)) == 1 ,"Expected 1 today :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","today")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.todays)) == 0 ,"Expected 0 today :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","date","01.01.2001")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.dates)) == 1 ,"Expected 1 date :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","date")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.dates)) == 0 ,"Expected 0 date :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","day","sunday")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.days)) == 1 ,"Expected 1 day :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","day")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.days)) == 0 ,"Expected 0 day :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","event","event")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.events)) == 1 ,"Expected 1 event :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","event")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.events)) == 0 ,"Expected 0 event :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","meter","meter")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.meters)) == 1 ,"Expected 1 meter :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","meter")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.meters)) == 0 ,"Expected 0 meter :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","label","label")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.labels)) == 1 ,"Expected 1 label :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","label")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.labels)) == 0 ,"Expected 0 label :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","inlimit","limit")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.inlimits)) == 3 ,"Expected 3 inlimit :\n" + str(ci.get_defs())
+    
+    ci.alter(t1,"delete","inlimit","/suite_with_limits:limitX")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.inlimits)) == 2 ,"Expected 2 inlimit :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","inlimit","/suite_with_limits_X:limitX")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.inlimits)) == 1 ,"Expected 1 inlimit :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","inlimit")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.inlimits)) == 0 ,"Expected 0 inlimit :\n" + str(ci.get_defs())
+
+
+    ci.alter(t1,"delete","limit","limit")
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.limits)) == 1 ,"Expected 1 limit :\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","limit")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.limits)) == 0 ,"Expected 0 limit :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","cron")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.crons)) == 0 ,"Expected 0 crons :\n" + str(ci.get_defs())
+
+    ci.alter(t1,"delete","late")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert task_t1.get_late() is None, "expected no late after delete" 
+
+
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert task_t1.get_trigger() is not None, "Expected trigger:\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","trigger")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert task_t1.get_trigger() is None, "Expected trigger to be deleted:\n" + str(ci.get_defs())
+
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert task_t1.get_complete() is not None, "Expected complete:\n" + str(ci.get_defs())
+    ci.alter(t1,"delete","complete")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert task_t1.get_complete() is None, "Expected complete to be deleted:\n" + str(ci.get_defs())
+
+    ci.alter(t2,"delete","repeat")   
+    sync_local(ci)
+    task_t2 = ci.get_defs().find_abs_node(t2)
+    repeat = task_t2.get_repeat()
+    assert repeat.empty(), "Expected repeat to be deleted:\n" + str(ci.get_defs())
+
+
+def test_client_alter_change(ci):
+    print_test(ci,"test_client_alter_change")
+    ci.delete_all() 
+    defs =create_defs("test_client_alter_change")   
+    t1 = "/test_client_alter_change/f1/t1"
+    repeat_date_path = "/test_client_alter_change/f1/repeat_date"
+    repeat_datetime_path = "/test_client_alter_change/f1/repeat_datetime"
+    
+    task_t1 = defs.find_abs_node(t1)
+    task_t1.add_variable("var","value")
+    task_t1.add_variable("var1","value")
+    task_t1.add_event("event")
+    task_t1.add_event("event1")
+    task_t1.add_meter("meter",0,100,100)
+    task_t1.add_meter("meter1",0,100,100)
+    task_t1.add_label("label","name")
+    task_t1.add_label("label1","name1")
+    task_t1.add_limit("limit",10)
+    task_t1.add_limit("limit1",10)
+    task_t1.add_inlimit( "limit",t1,2)
+    task_t1.add_inlimit( "limit1",t1,2)
+    task_t1.add_trigger( "t2 == active" )
+    task_t1.add_complete( "t2 == complete" )
+    task_t1.add_time("00:31")
+    task_t1.add_today("00:30")
+
+    late = Late()
+    late.submitted(20, 10)
+    late.active(20, 10)
+    late.complete(20, 10, True)
+    task_t1.add_late(late)
+
+            
+    f1 = defs.find_abs_node("/test_client_alter_change/f1")
+    # Add a new Repeat (based on date)
+    repeat_date = f1.add_task("repeat_date")
+    repeat_date.add_repeat( RepeatDate("date",20100111,20100115,2) )  # can't add cron and repeat at the same level
+    # Add a new Repeat (based on date+time)
+    repeat_datetime = f1.add_task("repeat_datetime")
+    repeat_datetime.add_repeat(RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00"))
+           
+    ci.load(defs)   
+
+    ci.alter(t1,"change","time","00:31","10:10")   
+    ci.alter(t1,"change","today","00:30","10:10")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    assert len(list(task_t1.times)) == 1 ,"Expected 1 time :\n" + str(ci.get_defs())
+    assert len(list(task_t1.todays)) == 1 ,"Expected 1 time :\n" + str(ci.get_defs())
+    for t in task_t1.times:
+        assert str(t) == "time 10:10"," expected 'time 10:10' but found:\n" + str(t)
+    for t in task_t1.todays:
+        assert str(t) == "today 10:10"," expected 'today 10:10' but found:\n" + str(t)
+
+
+    ci.alter(t1,"change","late","-s +10:00")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    variable = task_t1.get_late()
+    assert str(task_t1.get_late()) == "late -s +10:00", "Expected alter of late to be 'late -s +10:00' but found " + str(task_t1.get_late())
+
+
+    ci.alter(t1,"change","variable","var","changed_var")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    variable = task_t1.find_variable("var")
+    assert variable.value() == "changed_var", "Expected alter of variable to be 'change_var' but found " + variable.value()
+    res = ci.query('variable',task_t1.get_abs_node_path(),"var")
+    assert res == 'changed_var',"Expected alter of variable to be 'change_var' but found " + res
+
+
+    ci.alter(t1,"change","variable","var","--")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    variable = task_t1.find_variable("var")
+    assert variable.value() == "--", "Expected alter of variable to be '--' but found " + variable.value()
+    res = ci.query('variable',task_t1.get_abs_node_path(),"var")
+    assert res == '--',"Expected alter of variable to be '--' but found " + res
+    
+    ci.alter(t1,"change","variable","var","--fred")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    variable = task_t1.find_variable("var")
+    assert variable.value() == "--fred", "Expected alter of variable to be '--fred' but found " + variable.value()
+    
+    ci.alter(t1,"change","variable","var","--fred --bill")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    variable = task_t1.find_variable("var")
+    assert variable.value() == "--fred --bill", "Expected alter of variable to be '--fred --bill' but found " + variable.value()
+
+    ci.alter(t1,"change","meter","meter","10")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    meter = task_t1.find_meter("meter")
+    assert meter.value() == 10, "Expected alter of meter to be 10 but found " + str(meter.value())
+    res = ci.query('meter',task_t1.get_abs_node_path(),"meter")
+    assert res == '10',"Expected alter of meter to be 10 but found " + res
+
+    ci.alter(t1,"change","event","event","set")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    event = task_t1.find_event("event")
+    assert event.value() == True, "Expected alter of event to be set but found " + str(event.value())
+    res = ci.query('event',task_t1.get_abs_node_path(),"event")
+    assert res == 'set',"Expected alter of event to be 'set' but found " + res
+
+    ci.alter(t1,"change","trigger","t2 == aborted")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    trigger = task_t1.get_trigger()
+    assert trigger.get_expression() == "t2 == aborted", "Expected alter of trigger to be 't2 == aborted' but found " + trigger.get_expression()
+    res = ci.query('trigger',task_t1.get_abs_node_path(),"t2 == aborted")
+    assert res == 'false',"Expected evaluation of trigger to fail, but found: " + res
+
+    ci.alter(t1,"change","trigger","/test_client_alter_change/f1/t2 == complete")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    trigger = task_t1.get_trigger()
+    assert trigger.get_expression() == "/test_client_alter_change/f1/t2 == complete", "Expected alter of trigger to be '/test_client_alter_change/f1/t2 == complete' but found " + trigger.get_expression()
+
+    ci.alter(t1,"change","complete","t2 == aborted")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    complete = task_t1.get_complete()
+    assert complete.get_expression() == "t2 == aborted", "Expected alter of complete to be 't2 == aborted' but found " + complete.get_expression()
+
+    ci.alter(t1,"change","complete","/test_client_alter_change/f1/t2 == active")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    complete = task_t1.get_complete()
+    assert complete.get_expression() == "/test_client_alter_change/f1/t2 == active", "Expected alter of complete to be '/test_client_alter_change/f1/t2 == active' but found " + complete.get_expression()
+
+    ci.alter(t1,"change","limit_max","limit", "2")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    limit = task_t1.find_limit("limit")
+    assert limit is not None, "Expected to find limit"
+    assert limit.limit() == 2, "Expected alter of limit_max to be 2 but found " + str(limit.limit())
+
+    ci.alter(t1,"change","limit_value","limit", "2")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    limit = task_t1.find_limit("limit")
+    assert limit is not None, "Expected to find limit"
+    assert limit.value() == 2, "Expected alter of limit_value to be 2 but found " + str(limit.value())
+
+    
+    ci.alter(t1,"change","label","label","new-value")   
+    sync_local(ci)
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    label = task_t1.find_label("label")
+    assert label.new_value() == "new-value", "Expected alter of label to be 'new-value' but found " + label.new_value()
+
+    ci.alter(repeat_date_path,"change","repeat","20100113")
+    sync_local(ci)
+    task = ci.get_defs().find_abs_node(repeat_date_path)
+    repeat = task.get_repeat()
+    assert repeat.value() == 20100113, "Expected alter of repeat to be 20100113 but found " + str(repeat.value())
+    res = ci.query('variable',task.get_abs_node_path(),repeat.name())
+    assert res == "20100113", "Expected alter of repeat to be 20100113 but found " + res
+
+    ci.alter(repeat_datetime_path, "change", "repeat", "20100113T000000")
+    sync_local(ci)
+    task = ci.get_defs().find_abs_node(repeat_datetime_path)
+    repeat = task.get_repeat()
+    assert repeat.value() == 1263340800, "Expected alter of repeat to be 1263340800 (i.e. seconds between 19700101T000000 and 20100113T000000) but found " + str(repeat.value())
+    res = ci.query('variable', task.get_abs_node_path(), repeat.name())
+    assert res == "20100113T000000", "Expected alter of repeat to be 20100113T000000 but found " + res
+
+def test_client_alter_flag(ci):
+    print_test(ci,"test_client_alter_flag")
+    ci.delete_all() 
+    defs =create_defs("test_client_alter_flag")   
+    t1 = "/test_client_alter_flag/f1/t1"
+     
+    task_t1 = defs.find_abs_node(t1)
+           
+    ci.load(defs)   
+
+    flag = Flag()
+    flag_list = flag.list() # flag_list is of type FlagTypeVec
+    for flg in flag_list: 
+        ci.alter(t1,"set_flag",flag.type_to_string(flg) )   
+        sync_local(ci)
+        task_t1 = ci.get_defs().find_abs_node(t1)
+        task_flag = task_t1.get_flag()
+        assert task_flag.is_set( flg ),"expected flag %r to be set" % task_flag.type_to_string(flg)
+
+        # alter itself causes the flag message to be set, and preserved
+        if flg == FlagType.message: continue 
+        
+        ci.alter(t1,"clear_flag",flag.type_to_string(flg) )   
+        sync_local(ci)
+        task_t1 = ci.get_defs().find_abs_node(t1)
+        task_flag = task_t1.get_flag()
+        assert not task_flag.is_set( flg ),"expected flag %r NOT to be set" % task_flag.type_to_string(flg)
+
+
+    # ISSUES:
+    # o Currently we can only change clock attr if we have one.
+    # o Even when we have a clock attr, it only makes sense to apply clock attr changes
+    #   before begin(), i.e how do we apply change in gain after begin ??
+    
+    #" change clock-type name        # The name must be one of 'hybrid' or 'real'.\n"
+    #       " change clock-gain name        # The gain must be convertible to an integer.\n"
+    #        " change label name value       # sets the label\n"
+    #        " change repeat value           # If the repeat is a date, then the value must be a valid YMD ( ie. yyyymmdd)\n"
+    #        "                               # and be convertible to an integer, additionally the value must be in range\n"
+    #        "                               # of the repeat start and end dates. Like wise for repeat integer. For repeat\n"
+    #         "                               # string and enum,  the name must either be an integer, that is a valid index or\n"
+    #         "                               # if it is a string, it must correspond to one of enum's or strings list\n"
+
+
+def test_client_force(ci):
+    print_test(ci,"test_client_force")
+    ci.delete_all()     
+    defs = create_defs("test_client_force") 
+     
+    path_list = [ "/test_client_force/f1/t1", "/test_client_force/f1/t2" ]       
+    t1 = path_list[0]      
+    for path in path_list:
+        task = defs.find_abs_node(path)
+        assert task is not None, "Expected to find task at path " + path
+        task.add_event("event")
+
+    ci.load(defs)   
+    
+    state_list = [ State.unknown, State.active, State.complete, State.queued, State.submitted, State.aborted ]
+    for state in state_list:
+        ci.force_state(t1,state) 
+        sync_local(ci)
+        task = ci.get_defs().find_abs_node(t1)
+        assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())      
+    for state in state_list:
+        ci.force_state( path_list,state) 
+        sync_local(ci)
+        for path in path_list:
+            task = ci.get_defs().find_abs_node(path)
+            assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())     
+ 
+    for state in state_list:
+        ci.force_state_recursive("/test_client_force",state) 
+        sync_local(ci)
+        task = ci.get_defs().find_abs_node(t1)
+        assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())
+    suite_paths = [ "/test_client_force"]
+    for state in state_list:
+        ci.force_state_recursive( suite_paths,state) 
+        sync_local(ci)
+        task = ci.get_defs().find_abs_node(t1)
+        assert task.get_state() == state, "Expected state " + state + " but found " + str(task.get_state())           
+    
+    event_states = [ "set", "clear" ]
+    for ev_state in event_states:
+        for path in path_list:
+            ci.force_event(path + ":event" , ev_state)
+            sync_local(ci)
+            task = ci.get_defs().find_abs_node(path)
+            event_fnd = False
+            for event in task.events:
+                event_fnd = True
+                if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
+                else:                   assert event.value() == False ," Expected event value to be clear"
+            assert event_fnd == True," Expected event to be found"
+
+    event_path_list = [ "/test_client_force/f1/t1:event", "/test_client_force/f1/t2:event" ]       
+    event_states = [ "set", "clear" ]
+    for ev_state in event_states:
+        ci.force_event( event_path_list , ev_state)
+        sync_local(ci)
+        for path in path_list:
+            task = ci.get_defs().find_abs_node(path)
+            event_fnd = False
+            for event in task.events:
+                event_fnd = True
+                if ev_state == "set" :  assert event.value() == True  ," Expected event value to be set"
+                else:                   assert event.value() == False ," Expected event value to be clear"
+            assert event_fnd == True," Expected event to be found"
+
+      
+
+def test_client_replace(ci,on_disk):
+    print_test(ci,"test_client_replace client_defs on disk = " + str(on_disk))
+    # Create and load the following defs
+    # s1
+    #   f1
+    #     t1
+    #     t2
+    ci.delete_all()     
+    ci.load(create_defs("s1"))  
+    
+    #===============================================================================
+    # Example of using replace to ADD a *NEW* node hierarchy to an existing suite
+    # we should end up with:
+    # s1
+    #   f1
+    #     t1
+    #     t2
+    #   f2
+    #     t1
+    #     t2
+    test_client_replace_def_file = "test_client_replace_" + str(os.getpid()) + ".def"
+    client_def = create_defs("s1")
+    client_def.find_suite("s1").add_family("f2").add_task("t1")
+    if on_disk:
+        client_def.save_as_defs(test_client_replace_def_file)
+        client_def = test_client_replace_def_file
+    
+    ci.replace("/s1/f2",client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
+    ci.get_server_defs()
+    assert len(list(ci.get_defs().suites)) == 1 ,"Expected 1 suites:\n" + str(ci.get_defs())
+    assert ci.get_defs().find_abs_node("/s1/f2/t1") is not None, "Expected to find task /s1/f2/t1\n" + str(ci.get_defs())
+
+
+    # Example of using replace to *REMOVE* node hierarchy to an existing suite, could have used delete
+    assert ci.get_defs().find_abs_node("/s1/f1/t1") is not None, "Expected to find task /s1/f1/t1\n" + str(ci.get_defs())
+    assert ci.get_defs().find_abs_node("/s1/f2/t1") is not None, "Expected to find task /s1/f2/t1\n" + str(ci.get_defs())
+    client_def = Defs()
+    client_def.add_suite("s1")    # should only have the suite
+    if on_disk:
+        client_def.save_as_defs(test_client_replace_def_file)
+        client_def = test_client_replace_def_file
+
+    ci.replace("/s1",client_def)   
+    ci.get_server_defs()
+    assert len(list(ci.get_defs().suites)) == 1 ,"Expected 1 suites:\n" + str(ci.get_defs())
+    assert ci.get_defs().find_abs_node("/s1/f1/t1") is None, "Expected NOT to find task /s1/f1/t1\n" + str(ci.get_defs())
+    assert ci.get_defs().find_abs_node("/s1/f2/t1") is None, "Expected NOT to find task /s1/f2/t1\n" + str(ci.get_defs())
+
+
+    #===============================================================================
+    # Example of using replace to add a *NEW* suite
+    client_def = Defs();
+    client_def.add_suite("s2")
+    if on_disk:
+        client_def.save_as_defs(test_client_replace_def_file)
+        client_def = test_client_replace_def_file
+
+    ci.replace("/s2",client_def,True,False)  # True means create parents as needed, False means don't bypass checks/zombies
+    ci.get_server_defs()
+    assert len(list(ci.get_defs().suites)) == 2 ," Expected two suites:\n" + str(ci.get_defs())
+           
+    # replace added suite s2 with a new s2 which has a task, 
+    # s2 must exist on the client defs
+    client_def = Defs();
+    client_def.add_suite("s2").add_task("t1")
+    if on_disk:
+        client_def.save_as_defs(test_client_replace_def_file)
+        client_def = test_client_replace_def_file
+
+    ci.replace("/s2",client_def) 
+        
+    ci.get_server_defs()
+    assert len(list(ci.get_defs().suites)) == 2 ," Expected two suites:\n" + str(ci.get_defs())
+    assert ci.get_defs().find_abs_node("/s2/t1") is not None, "Expected to find task /s2/t1\n" + str(ci.get_defs())
+    if on_disk:
+        os.remove(test_client_replace_def_file)
+
+
+def test_node_replace(ci):
+    print_test(ci,"test_node_replace")
+    PrintStyle.set_style( Style.MIGRATE ) # show node state 
+    ci.delete_all()     
+    defs = Defs() + (Suite("s1") + Family('f1').add(Task('t1'),Task('t2')))
+    ci.load(defs)  
+ 
+    # We should have 4 nodes
+    sync_local(ci)
+    ci_defs = ci.get_defs()
+    node_vec = ci_defs.get_all_nodes()
+    assert len(list(node_vec)) == 4,"Expected two 4 nodes: \n" + str(ci.get_defs())
+             
+    # replace each node, add variable first, then check, it was added
+    for node in node_vec:
+        node += Edit(var="XX", var2="xx")
+        node.replace_on_server(ci) # default is to suspend server node first, so replaced node is also suspended
+                
+        sync_local(ci)
+        replace_node = ci.get_defs().find_abs_node(node.get_abs_node_path())
+        assert len(list(replace_node.variables)) == 2,"Expected two 2 variable: \n" + str(replace_node)+ "\n" + str(ci.get_defs())
+        assert replace_node.get_dstate() == DState.suspended,"Expected node to be suspended:\n" + str(replace_node) + "\n" + str(ci.get_defs())
+
+    # resume nodes, test that when False passed in we do not suspend the replaced node
+    for node in node_vec:
+        ci.resume(node.get_abs_node_path())
+        sync_local(ci)
+        replace_node = ci.get_defs().find_abs_node(node.get_abs_node_path())
+        assert replace_node.get_dstate() != DState.suspended,"Expected node not to suspended:\n" +  str(replace_node)
+        
+        replace_node += Meter("meter",0,100)
+        
+        # cant use node i.e this is only client side, and is still suspended
+        # When we replace is server the client defs is sent to server. hence node would be suspended
+        replace_node.replace_on_server(ci,suspend_node_first=False)
+        sync_local(ci)
+
+        replace_node = ci.get_defs().find_abs_node(node.get_abs_node_path())
+        assert len(list(replace_node.meters)) == 1,"Expected 1 meter: \n" + str(replace_node)
+        assert len(list(replace_node.variables)) == 2,"Expected two 2 variable: \n" + str(replace_node)
+        assert replace_node.get_dstate() != DState.suspended,"Expected node not to suspended:\n" +  str(replace_node)
+
+    # replace the suite
+    defs = Defs() + Suite("s1")
+    host_port = ci.get_host() + ':' + ci.get_port()
+    defs.s1.replace_on_server(host_port)
+  
+    ci.get_server_defs()
+    assert len(list(ci.get_defs().s1)) == 0,"Expected 0 family: \n" + str(ci.get_defs())
+    assert ci.get_defs().s1.get_dstate() == DState.suspended,"Expected node to be suspended:\n" +  str(ci.get_defs())
+
+
+def test_client_kill(ci):
+    pass
+        
+def test_client_status(ci):
+    pass
+           
+def test_client_order(ci):
+    pass
+           
+def test_client_group(ci):
+    pass
+           
+def test_client_suspend(ci):
+    print_test(ci,"test_client_suspend")
+    ci.delete_all()     
+    defs = create_defs("test_client_suspend")  
+    suite = defs.find_suite("test_client_suspend")
+    suite.add_variable("ECF_DUMMY_TASK","")
+        
+    ci.load(defs)  
+    ci.begin_all_suites()  
+    
+    ci.suspend("/test_client_suspend")  
+           
+    sync_local(ci);
+    suite = ci.get_defs().find_suite("test_client_suspend")
+    assert suite.is_suspended(), "Expected to find suite suspended"
+    
+    assert ci.query('dstate',suite.get_abs_node_path()) == "suspended", "Expected to find suite dstate suspended but found: " + res
+    assert ci.query('state',suite.get_abs_node_path()) == "queued", "Expected to find suite state queued but found: " + res
+
+
+def test_client_suspend_multiple_paths(ci):
+    print_test(ci,"test_client_suspend_multiple_paths")
+    ci.delete_all()     
+    defs = create_defs("test_client_suspend_multiple_paths")  
+    suite = defs.find_suite("test_client_suspend_multiple_paths")
+    suite.add_variable("ECF_DUMMY_TASK","")
+    
+    ci.load(defs)  
+    ci.begin_all_suites()  
+    
+    path_list = [ "/test_client_suspend_multiple_paths/f1/t1", "/test_client_suspend_multiple_paths/f1/t2" ]
+    ci.suspend( path_list )  
+           
+    sync_local(ci);
+    task_t1 = ci.get_defs().find_abs_node("/test_client_suspend_multiple_paths/f1/t1")
+    task_t2 = ci.get_defs().find_abs_node("/test_client_suspend_multiple_paths/f1/t2")
+    assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
+    assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
+            
+def test_client_resume(ci):
+    print_test(ci,"test_client_resume")
+    ci.delete_all()     
+    defs = create_defs("test_client_resume")  
+    suite = defs.find_suite("test_client_resume")
+    suite.add_variable("ECF_DUMMY_TASK","")
+        
+    ci.load(defs)  
+    ci.begin_all_suites()  
+    
+    ci.suspend("/test_client_resume")  
+    sync_local(ci);
+    suite = ci.get_defs().find_suite("test_client_resume")
+    assert suite.is_suspended(), "Expected to find suite suspended"
+    
+    ci.resume("/test_client_resume")  
+    sync_local(ci);
+    suite = ci.get_defs().find_suite("test_client_resume")
+    assert suite.is_suspended() == False, "Expected to find suite resumed"
+
+def test_client_resume_multiple_paths(ci):
+    print_test(ci,"test_client_resume_multiple_paths")
+    ci.delete_all()     
+    defs = create_defs("test_client_resume_multiple_paths")  
+    suite = defs.find_suite("test_client_resume_multiple_paths")
+    suite.add_variable("ECF_DUMMY_TASK","")
+        
+    ci.load(defs)  
+    ci.begin_all_suites()  
+    
+    path_list = [ "/test_client_resume_multiple_paths/f1/t1", "/test_client_resume_multiple_paths/f1/t2" ]
+    ci.suspend( path_list )  
+  
+    sync_local(ci);
+    task_t1 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t1")
+    task_t2 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t2")
+    assert task_t1.is_suspended(), "Expected to find task t1 to be suspended"
+    assert task_t2.is_suspended(), "Expected to find task t2 to be suspended"
+
+    ci.resume( path_list )  
+    sync_local(ci);
+    task_t1 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t1")
+    task_t2 = ci.get_defs().find_abs_node("/test_client_resume_multiple_paths/f1/t2")
+    assert task_t1.is_suspended() == False, "Expected to find task t1 to be resumed"
+    assert task_t2.is_suspended() == False, "Expected to find task t2 to be resumed"
+ 
+          
+def test_client_delete_node(ci): 
+    print_test(ci,"test_client_delete_node")
+    ci.delete_all() 
+    defs = create_defs("test_client_delete_node")
+    
+    task_vec = defs.get_all_tasks();
+    assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
+
+    ci.load(defs)  
+    sync_local(ci);
+    for task in task_vec:
+        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
+        assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(ci.get_defs()) 
+
+    for task in task_vec:
+        ci.delete(task.get_abs_node_path())
+
+    sync_local(ci);
+    for task in task_vec:
+        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
+        assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(ci.get_defs())   
+    
+def test_client_delete_node_multiple_paths(ci): 
+    print_test(ci,"test_client_delete_node_multiple_paths")
+    ci.delete_all() 
+    defs = create_defs("test_client_delete_node_multiple_paths")
+    
+    task_vec = defs.get_all_tasks();
+    assert len(task_vec) > 0, "Expected some tasks but found none:\n" + str(defs)
+
+    paths = []
+    for task in task_vec:
+        paths.append(task.get_abs_node_path()) 
+ 
+    ci.load(defs)  
+    
+    sync_local(ci);
+    for task in task_vec:
+        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
+        assert node is not None , "Expected to find task " + task.get_abs_node_path()  + ":\n"  + str(ci.get_defs()) 
+
+    ci.delete(paths)
+
+    sync_local(ci);
+    for task in task_vec:
+        node = ci.get_defs().find_abs_node(task.get_abs_node_path()) 
+        assert node is None , "Expected not to find task " + task.get_abs_node_path()  + " as it should have been deleted:\n" + str(ci.get_defs())   
+    
+def test_client_archive_and_restore(ci):
+    suite_name = "test_client_archive_and_restore"
+    print_test(ci,suite_name)
+    ci.delete_all()     
+    defs = create_defs(suite_name)  
+    suite = defs.find_suite(suite_name)
+    suite_path = suite.get_abs_node_path();
+     
+    ci.restart_server()
+    ci.load(defs)  
+     
+    sync_local(ci) # get the changes, synced with local defs
+    node_vec = ci.get_defs().get_all_nodes()
+    assert len(node_vec) == 4, "Expected 4 nodes, but found " + str(len(node_vec))
+ 
+    ci.archive(suite_path)
+    sync_local(ci) # get the changes, synced with local defs
+    node_vec = ci.get_defs().get_all_nodes()
+    assert len(node_vec) == 1, "Expected 1 nodes, but found " + str(len(node_vec))
+    the_suite = ci.get_defs().find_suite(suite_name)
+    assert the_suite is not None, "Expected to find suite"
+    assert the_suite.get_flag().is_set(FlagType.archived), " expected archive flag to be set"
+ 
+    ci.restore(suite_path)
+    sync_local(ci) # get the changes, synced with local defs
+    node_vec = ci.get_defs().get_all_nodes()
+    assert len(node_vec) == 4, "Expected 4 nodes, but found " + str(len(node_vec))
+    the_restored_suite = ci.get_defs().find_suite(suite_name)
+    assert the_restored_suite is not None, "Expected to find suite"
+    assert the_restored_suite.get_flag().is_set(FlagType.restored), " expected restored flag to be set"
+    assert not the_restored_suite.get_flag().is_set(FlagType.archived), "expected archive flag to be cleared"
+    
+
+def test_client_check_defstatus(ci):            
+    print_test(ci,"test_client_check_defstatus")
+    ci.delete_all()     
+    defs = create_defs("test_client_check_defstatus")  
+    
+    # stop defs form running when begin is called.
+    suite = defs.find_suite("test_client_check_defstatus")
+    suite.add_defstatus(DState.suspended)
+
+    t1 = "/test_client_check_defstatus/f1/t1"
+    t2 = "/test_client_check_defstatus/f1/t2"
+    task_t1 = defs.find_abs_node(t1)
+    task_t1.add_defstatus(DState.suspended)
+    
+    defs.generate_scripts();
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+    
+    ci.restart_server()
+    ci.load(defs)           
+    ci.begin_all_suites()
+     
+    sync_local(ci) # get the changes, synced with local defs
+    #print(ci.get_defs())
+    task_t1 = ci.get_defs().find_abs_node(t1)
+    task_t2 = ci.get_defs().find_abs_node(t2)
+    assert task_t1 is not None,"Could not find t1"
+    assert task_t2 is not None,"Could not find t2"
+  
+    assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
+    assert task_t2.get_state() == State.queued, "Expected state queued " + str(task_t2.get_state())
+
+    assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_state())
+    assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_state())
+   
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_client_check_defstatus"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)     
+    
+def test_ECFLOW_189(ci):
+    # Bug, when a node is resumed it ignored holding dependencies higher up the tree.
+    # i.e Previously when we resumed a node, it ignored trigger/time/node state, dependencies higher up the tree
+    print_test(ci,"test_ECFLOW_189")
+    ci.delete_all()     
+    defs = create_defs("test_ECFLOW_189")  
+    defs.generate_scripts();
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+    
+    ci.restart_server()
+    ci.load(defs)   
+    
+    ci.suspend("/test_ECFLOW_189")
+    ci.suspend("/test_ECFLOW_189/f1/t1")
+    ci.suspend("/test_ECFLOW_189/f1/t2")
+        
+    ci.begin_all_suites()
+    
+    sync_local(ci) # get the changes, synced with local defs
+    #print(ci.get_defs())
+    task_t1 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t1")
+    task_t2 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t2")
+    assert task_t1 is not None,"Could not find /test_ECFLOW_189/f1/t1"
+    assert task_t2 is not None,"Could not find /test_ECFLOW_189/f1/t2"
+  
+    assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
+    assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
+    assert task_t1.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t1.get_dstate())
+    assert task_t2.get_dstate() == DState.suspended, "Expected state suspended but found " + str(task_t2.get_dstate())
+
+    # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
+    ci.resume("/test_ECFLOW_189/f1/t1")
+    ci.resume("/test_ECFLOW_189/f1/t2")
+     
+    time.sleep(3)
+    sync_local(ci) # get the changes, synced with local defs
+    #print(ci.get_defs())
+    task_t1 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t1")
+    task_t2 = ci.get_defs().find_abs_node("/test_ECFLOW_189/f1/t2")
+    assert task_t1.get_state() == State.queued, "Expected state queued but found " + str(task_t1.get_state())
+    assert task_t2.get_state() == State.queued, "Expected state queued but found " + str(task_t2.get_state())
+    assert task_t1.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t1.get_dstate())
+    assert task_t2.get_dstate() == DState.queued, "Expected state queued but found " + str(task_t2.get_dstate())
+
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_ECFLOW_189"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)    
+
+
+def test_ECFLOW_1761(ci):
+    print_test(ci,"test_ECFLOW_1761")
+    print("# get log: last 10 lines")
+    ci.get_log(10)
+    
+    ci_defs = ci.get_defs()
+    task = ci_defs.get_all_nodes()[0]  # take first task
+    
+    #print(ci.edit_script_edit(task.get_abs_node_path())
+
+    #print(ci.edit_script_preprocess(task.get_abs_node_path()))
+
+    #ci.edit_script_submit(
+    #    task.get_abs_node_path(),
+    #        [],  # name-value variables list
+    #        [],  # lines (script)
+    #        False, # True,  $ alias
+    #        False)  # run
+
+
+def test_ECFLOW_199(ci):
+    # Test ClientInvoker::changed_node_paths
+    print_test(ci,"test_ECFLOW_199")
+    ci.delete_all()     
+    defs = create_defs("test_ECFLOW_199")  
+    defs.generate_scripts();
+    msg = defs.check_job_creation(verbose=True)
+    assert len(msg) == 0, msg
+    
+    ci.restart_server()
+    ci.load(defs)   
+    
+    ci.suspend("/test_ECFLOW_199")
+    ci.suspend("/test_ECFLOW_199/f1/t1")
+    ci.suspend("/test_ECFLOW_199/f1/t2")
+        
+    ci.begin_all_suites()
+    
+    sync_local(ci) # get the changes, synced with local defs
+    #print(ci.get_defs())
+    assert len(list(ci.changed_node_paths)) == 0, "Expected first call to sync_local, to have no changed paths but found " + str(len(list(ci.changed_node_paths)))
+    
+    # ok now resume t1/t2, they should remain queued, since the Suite is still suspended
+    # Note: ECFLOW-1512, we may get additional paths.( i.e. suite path) due to changes in suite calendar
+    ci.resume("/test_ECFLOW_199/f1/t1")
+    sync_local(ci)
+    found_path = False
+    for path in ci.changed_node_paths:
+        print("   changed node path " + path);
+        if path == "/test_ECFLOW_199/f1/t1":
+            found_path = True
+    assert found_path, "Expected '/test_ECFLOW_199/f1/t1' in list of changed paths"
+
+    ci.resume("/test_ECFLOW_199/f1/t2")
+    sync_local(ci)
+    found_path = False
+    for path in ci.changed_node_paths:
+        print("   changed node path " + path);
+        if path == "/test_ECFLOW_199/f1/t2":
+            found_path = True
+    assert found_path, "Expected '/test_ECFLOW_199/f1/t2' in list of changed paths"
+
+
+    dir_to_remove = Test.ecf_home(the_port) + "/" + "test_ECFLOW_199"
+    shutil.rmtree(dir_to_remove, ignore_errors=True)  
+
+def test_client_ch_with_drops_handles(the_port,top_ci):
+    print_test(ci,"test_client_ch_with_drops_handles")
+    try:
+        print("  test using with but without register, handle should be zero, ie do nothing")
+        with Client("localhost",the_port) as local_ci:
+            #print("Handle:",local_ci.ch_handle())
+            assert local_ci.ch_handle() == 0,"Expected handle to be zero"
+            local_ci.ch_suites()
+        print("  Test Client with register, should drop handle ")
+        with Client("localhost",the_port) as local_ci:
+            local_ci.ch_register(True, [ 's1','s2'])
+            #print("Handle:",local_ci .ch_handle())
+            local_ci.ch_suites()
+            #raise RuntimeError("xxx") # check exeption is still caught
+    except RuntimeError as e:
+        print("Exception",e)
+    print("after with:")
+    # really need a way to get hold of the suites, via python api.
+    top_ci.ch_suites() # should be empty
+ 
+def do_tests(ci,the_port):
+    test_version(ci)
+    PrintStyle.set_style( Style.STATE ) # show node state 
+            
+    test_client_get_server_defs(ci)             
+    test_client_new_log(ci, the_port)             
+    test_client_clear_log(ci, the_port)             
+    test_client_log_msg(ci, the_port)             
+           
+    test_client_restart_server(ci)             
+    test_client_halt_server(ci)             
+    test_client_shutdown_server(ci)   
+       
+    test_client_load_in_memory_defs(ci)             
+    test_client_load_from_disk(ci)             
+    test_client_checkpt(ci, the_port)             
+    test_client_restore_from_checkpt(ci, the_port)             
+            
+    test_client_reload_wl_file(ci, the_port)             
+    
+    test_client_run(ci)  
+    test_client_run_with_multiple_paths(ci)     
+    test_client_requeue(ci)             
+    test_client_requeue_with_multiple_paths(ci)             
+    test_client_free_dep(ci)              
+   
+    test_client_suites(ci)
+    test_client_ch_with_drops_handles(the_port,ci)
+    test_client_ch_suites(ci)  
+    test_client_ch_register(ci)             
+    test_client_ch_drop(ci)             
+    test_client_ch_drop_user(ci)             
+    test_client_ch_add(ci)             
+    test_client_ch_auto_add(ci)             
+    test_client_ch_remove(ci)             
+              
+    test_client_get_file(ci)             
+    #test_client_plug(ci)             
+    test_client_alter_sort(ci) 
+    test_client_alter_sort_defs(ci) 
+    test_client_alter_add(ci) 
+    test_client_alter_delete(ci) 
+    test_client_alter_change(ci) 
+    test_client_alter_flag(ci) 
+
+    test_client_force(ci)             
+    test_client_replace(ci,False)             
+    test_client_replace(ci,True)             
+    test_node_replace(ci)             
+   
+    #test_client_kill(ci)             
+    #test_client_status(ci)             
+    #test_client_order(ci)             
+    #test_client_group(ci)             
+    test_client_suspend(ci)             
+    test_client_suspend_multiple_paths(ci)             
+    test_client_resume(ci)             
+    test_client_resume_multiple_paths(ci)             
+    test_client_delete_node(ci)             
+    test_client_delete_node_multiple_paths(ci)             
+    test_client_archive_and_restore(ci)             
+ 
+    test_client_check(ci)  
+    test_client_check_defstatus(ci)  
+    
+    test_client_stats(ci)
+    test_client_stats_with_stdout(ci)
+    test_client_stats_without_stdout(ci)
+    test_client_stats_reset(ci)             
+    test_client_debug_server_on_off(ci)    
+          
+    test_ECFLOW_189(ci)         
+    test_ECFLOW_199(ci)         
+    test_ECFLOW_1761(ci)
+
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))   
+
+    # server independent tests
+    test_set_host_port();
+    
+    with Test.Server() as ci:
+        server_version = ci.server_version();
+        print("Running ecflow server version " + server_version)
+        print("Running ecflow client version " + ci.version())
+        assert ci.version() == server_version, " Client version not same as server version"
+        
+        global the_port
+        the_port = ci.get_port()
+        
+        # test with sync_local
+        do_tests(ci,the_port)  
+        
+        # test with auto sync
+        ci.set_auto_sync(True)
+        do_tests(ci,the_port)  
+
+        print("All Tests pass ======================================================================")    
diff -pruN 5.12.4-1/libs/pyext/test/py_s_TestPythonChildApi.py 5.13.0-1/libs/pyext/test/py_s_TestPythonChildApi.py
--- 5.12.4-1/libs/pyext/test/py_s_TestPythonChildApi.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_s_TestPythonChildApi.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,196 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+#  code for testing client code in python
+import time
+import os
+import pwd
+import sys  # determine python version
+from datetime import datetime
+import shutil   # used to remove directory tree
+
+from ecflow import Defs, Clock, DState, Event, Style, State, PrintStyle, File, Client, SState, File, debug_build
+import ecflow_test_util as Test
+
+
+def ecf_includes(): return File.source_dir() + "/libs/pyext/test/data/python_includes"
+
+def create_defs(name,the_port):
+    defs = Defs()
+    suite_name = name
+    if len(suite_name) == 0: suite_name = "s1"
+    suite = defs.add_suite(suite_name);
+    
+    ecfhome = Test.ecf_home(the_port);
+    suite.add_variable("ECF_HOME", ecfhome);
+    suite.add_variable("ECF_INCLUDE", ecf_includes());
+    
+    prefix_job_cmd = ""
+    if 'PYTHONPATH' in os.environ:
+        prefix_job_cmd = "export PYTHONPATH=" + os.environ['PYTHONPATH'] +";" 
+    if 'LD_LIBRARY_PATH' in os.environ:
+        prefix_job_cmd += "export LD_LIBRARY_PATH=" + os.environ['LD_LIBRARY_PATH'] +";"
+   
+    # sys.version_info is a tuple containing (major,minor,micro,releaselevel,serial)
+    # releaselevel = alpha beta candidate final
+    if (sys.version_info > (3, 0)):
+        suite.add_variable("ECF_JOB_CMD",prefix_job_cmd + "python3 %ECF_JOB% 1> %ECF_JOBOUT% 2>&1")
+    else:
+        suite.add_variable("ECF_JOB_CMD",prefix_job_cmd + "python %ECF_JOB% 1> %ECF_JOBOUT% 2>&1")
+
+    family = suite.add_family("f1")
+    t1 = family.add_task("t1")
+    t1.add_event("event_fred")
+    t1.add(Event("event_set",True)) # ECFLOW-1526
+    t1.add_meter("meter", 0, 100)
+    t1.add_label("label_name", "value")
+    t1.add_queue("q1",["1","2","3"])
+
+    family.add_task("t2")  # test wait
+    family.add_task("t3").add_trigger("t1:q1 >= 3 and t1:event_fred and t1:event_set == clear") # wait on queue q1 and events
+    family.add_task("t4").add_trigger("t1:name1 == 1 and t1:name2 == 2 and t1:name3 == 3 and t1:name4 == 4") # test ECFLOW-1573
+ 
+    defs.auto_add_externs(True) # because variable name1,name2,name3,name4  are not added until t1 is active.(i.e. runtime)
+    return defs;
+    
+def wait_for_suite_to_complete(ci,suite_name):
+    count = 0
+    while 1:
+        count += 1
+        ci.sync_local() # get the changes, synced with local defs
+        suite = ci.get_defs().find_suite(suite_name)
+        assert suite is not None, " Expected to find suite " + suite_name + ":\n" + str(ci.get_defs())
+        if suite.get_state() == State.complete:
+            break;
+        if suite.get_state() == State.aborted:
+            print(ci.get_defs());
+            assert False," Suite aborted \n"  
+        time.sleep(2)
+        if count > 20:
+            assert False, suite_name + " aborted after " + str(count) + " loops, printing defs:\n" + str(ci.get_defs())
+        
+    ci.log_msg("Looped " + str(count) + " times")
+    
+def test_python_child_api(ci):   
+    suite_name = "test_python_child_api"         
+    print("\n" + suite_name + " " + ci.get_host() + ":" + str(ci.get_port()))
+    print(" ECF_HOME(" + Test.ecf_home(ci.get_port()) + ")")
+    print(" ECF_INCLUDES(" + ecf_includes() + ")")
+    ci.delete_all(True)     
+    defs = create_defs(suite_name,ci.get_port())  
+    suite = defs.find_suite(suite_name)
+    suite.add_defstatus(DState.suspended)
+
+    # create the ecf file /test_python_child_api/f1/t1
+    ecf_home = Test.ecf_home(ci.get_port())
+    test_home = ecf_home + "/" + suite_name
+    dir = test_home + "/f1"
+    
+    # on cray creating recursive directories can fail, try again. yuk
+    try:
+        if not os.path.exists(dir): os.makedirs(dir)
+    except:
+        try:
+            if not os.path.exists(dir): os.makedirs(dir)
+        except:
+            # try breaking down
+            if not os.path.exists(ecf_home): os.makedirs(ecf_home)
+            new_dir = ecf_home + "/test_python_child_api"
+            if not os.path.exists(new_dir): os.makedirs(new_dir)
+            new_dir = ecf_home + "/test_python_child_api/f1"
+            if not os.path.exists(new_dir): os.makedirs(new_dir)
+    if not os.path.exists(dir): os.makedirs(dir)
+
+    # record the log file with the test
+    ci.new_log(test_home + "/" + suite_name + ".log")
+
+    server_version = ci.server_version()
+    file = dir + "/t1.ecf"
+    contents = "%include <head.py>\n\n"
+    contents += "with Client(True) as ci:\n" # Here True means add variables durint init and remove them on complete ECFLOW-1573
+    contents += "    print('   doing some work: t1.ecf')\n"
+    contents += "    if ci.version() != '" + server_version + "':\n"
+    contents += "        assert False, 'Client and server versions different'\n"
+    contents += "    ci.child_event('event_fred')      # set the event\n"
+    contents += "    ci.child_event('event_set',False) # clear the event ECFLOW-1526\n"
+    contents += "    ci.child_meter('meter',100)\n"
+    contents += "    ci.child_label('label_name','100')\n"
+    contents += "    step = ci.child_queue('q1','active')\n"
+    contents += "    assert step == '1','expected first step to be 1'\n"
+    contents += "    step = ci.child_queue('q1','complete',step)\n"
+    contents += "    step = ci.child_queue('q1','active')\n"
+    contents += "    assert step == '2','expected second step to be 2'\n"
+    contents += "    step = ci.child_queue('q1','complete',step)\n"
+    contents += "    step = ci.child_queue('q1','active')\n"
+    contents += "    assert step == '3','expected third step to be 3'\n"
+    contents += "    step = ci.child_queue('q1','complete',step)\n"
+    contents += "    step = ci.child_queue('q1','active')\n"
+    contents += "    assert step == '<NULL>','expected <NULL? for end of queue'\n"
+    contents += "    print('   Finished event,meter,label and queue child commands')\n"
+    open(file,'w').write(contents)
+    print(" Created file " + file)
+      
+    # create the ecf file /test_python_child_api/f1/t2
+    file = dir + "/t2.ecf"
+    contents = "%include <head.py>\n\n"
+    contents += "with Client() as ci:\n"
+    contents += "    print('   Waiting for /test_python_child_api/f1/t1 == complete')\n"
+    contents += "    ci.child_wait('/test_python_child_api/f1/t1 == complete')\n"
+    contents += "    print('   Finished waiting')\n"
+    open(file,'w').write(contents)
+    print(" Created file " + file)
+    
+    # create the ecf file /test_python_child_api/f1/t3
+    file = dir + "/t3.ecf"
+    contents = "%include <head.py>\n\n"
+    contents += "with Client() as ci:\n"
+    contents += "    print('   Running t3.ecf')\n"
+    open(file,'w').write(contents)
+    print(" Created file " + file)
+    
+    # create the ecf file /test_python_child_api/f1/t4
+    file = dir + "/t4.ecf"
+    contents = "%include <head.py>\n\n"
+    contents += "with Client() as ci:\n"
+    contents += "    print('   Running t4.ecf')\n"
+    open(file,'w').write(contents)
+    print(" Created file " + file)
+            
+    ci.restart_server()
+    ci.load(defs)          
+    ci.begin_all_suites()
+    print(" Running the test, wait for suite to complete ...")  
+    ci.run("/test_python_child_api", False)
+
+    wait_for_suite_to_complete(ci,suite_name);
+    
+    defs.save_as_defs(os.path.join(ecf_home,suite_name, suite_name + ".def"))
+
+    if not Test.debugging():
+        print(" Test OK: removing directory ",test_home)
+        shutil.rmtree(test_home,ignore_errors=True)      
+
+#///////////////////////////////////////////////////////////////////////////////////////        
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+
+    with Test.Server() as ci:
+    
+        server_version = ci.server_version();
+        print("Running ecflow server version " + server_version)
+        print("Running ecflow client version " + ci.version() )
+        assert ci.version() == server_version, "Client version not same as server version"
+
+        PrintStyle.set_style( Style.STATE ) # show node state 
+        test_python_child_api(ci)  
+        print("\nAll Tests pass ======================================================================")    
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestAddDelete.py 5.13.0-1/libs/pyext/test/py_u_TestAddDelete.py
--- 5.12.4-1/libs/pyext/test/py_u_TestAddDelete.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestAddDelete.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,764 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# code for testing addition and deletion 
+#
+import sys
+import os
+import copy
+import unittest # for assertItemsEqual
+import ecflow
+import ecflow_test_util as Test
+
+if __name__ == "__main__":
+    
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    #===========================================================================
+    # Defs: add, delete and sort *USER* variables, use set(a).intersection(b) to compare lists
+    #===========================================================================
+    defs = ecflow.Defs()
+    defs.add_variable("ZFRED", "/tmp/")
+    defs.add_variable("YECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
+    defs.add_variable("XECF_URL_BASE", "http://www.ecmwf.int")
+    defs.add_variable("AECF_URL", "publications/manuals/sms")
+    assert len(list(defs.user_variables)) == 4, "Expected *user* 4 variable"    
+    
+    # sort
+    expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED']
+    actual = []
+    defs.sort_attributes("variable");
+    for v in defs.user_variables: actual.append(v.name())
+    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+
+    expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
+    actual = []
+    defs.add_variable("ZZ", "x")
+    defs.sort_attributes(ecflow.AttrType.variable);
+    for v in defs.user_variables: actual.append(v.name())
+    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+
+    expected = ['AA', 'AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
+    actual = []
+    defs.add_variable("AA", "x")
+    defs.sort_attributes("all");
+    for v in defs.user_variables: actual.append(v.name())
+    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+
+    expected = ['AA', 'AECF_URL', 'BB','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
+    actual = []
+    defs.add_variable("BB", "x")
+    defs.sort_attributes(ecflow.AttrType.all );
+    for v in defs.user_variables: actual.append(v.name())
+    assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+
+    
+    
+    defs.delete_variable("ZFRED");assert len(list(defs.user_variables)) == 6, "Expected 6 variables since we just delete ZFRED"
+    defs.delete_variable("");     assert len(list(defs.user_variables)) == 0, "Expected 0 variables since we should have deleted all"
+    
+    a_dict = { "name":"value", "name2":"value2", "name3":"value3", "name4":"value4" }
+    defs.add_variable(a_dict)
+    assert len(list(defs.user_variables)) == 4, "Expected 4 variable"    
+    defs.delete_variable("");         assert len(list(defs.user_variables)) == 0, "Expected 0 variable since we should have deleted all"
+
+    # add a empty dictionary
+    a_dict = {}
+    defs.add_variable(a_dict)
+    assert len(list(defs.user_variables)) == 0, "Expected zero variables"    
+    
+    a_dict = { "name":0, "name2":1, "name3":2, "name4":3 }
+    defs.add_variable(a_dict)
+    assert len(list(defs.user_variables)) == 4, "Expected 4 variable"    
+    defs.delete_variable("");         assert len(list(defs.user_variables)) == 0, "Expected 0 variable since we should have deleted all"
+
+    #===========================================================================
+    # Suite: add,delete and sort variables
+    #===========================================================================
+    suite = ecflow.Suite("s1")
+    suite.add_variable(ecflow.Variable("ECF_HOME", "/tmp/"))
+    suite.add_variable("ZZZZZZ", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
+    suite.add_variable("YYYYY", "http://www.ecmwf.int")
+    suite.add_variable("aaaa", "publications/manuals/sms")
+    assert len(list(suite.variables)) == 4, "Expected 4 variable"    
+    
+    # sort
+    expected = ['aaaa','ECF_HOME','YYYYY','ZZZZZZ']
+    actual = []
+    suite.sort_attributes("variable");
+    suite.sort_attributes(ecflow.AttrType.variable);
+    for v in suite.variables: actual.append(v.name())
+    assert set(expected).intersection(actual), "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+
+    suite.delete_variable("ECF_HOME"); assert len(list(suite.variables)) == 3, "Expected 3 variable since we just delete ECF_HOME"
+    suite.delete_variable("");         assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
+    
+    a_dict = { "name":"value", "name2":"value2", "name3":"value3", "name4":"value4" }
+    suite.add_variable(a_dict)
+    assert len(list(suite.variables)) == 4, "Expected 4 variable"    
+    suite.delete_variable("");         assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
+
+    a_dict = { "name":1, "name2":2, "name3":3, "name4":4 }
+    suite.add_variable(a_dict)
+    assert len(list(suite.variables)) == 4, "Expected 4 variable"    
+    suite.delete_variable("");         assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
+
+    # add a empty dictionary
+    a_dict = { }
+    suite.add_variable(a_dict)
+    assert len(list(suite.variables)) == 0, "Expected zero variables"    
+
+    # adding dictionary items that are not strings,or ints in value ,should result in a type error
+    expected_type_error = False
+    try:
+        a_bad_dict = { "name":"fred", "name2":14, "name3": list( 1,2,3), "name4":12 }
+        suite.add_variable(a_bad_dict)
+    except TypeError:
+        expected_type_error = True
+        
+    assert expected_type_error, "Expected Type error"
+    assert len(list(suite.variables)) == 0, "Expected 0 variable since we should have deleted all"
+    
+    suite.add_variable("ECF_URL_CMD", "test duplicates") 
+    suite.add_variable("ECF_URL_CMD", "Expected warning")  # expect a warning message to standard out
+
+
+    #===========================================================================
+    # add,delete and sort limits
+    #===========================================================================
+    suite.add_limit(ecflow.Limit("zlimitName1", 10))
+    suite.add_limit(ecflow.Limit("ylimitName2", 10))
+    suite.add_limit("xlimitName3", 10)
+    suite.add_limit("alimitName4", 10)
+    assert len(list(suite.limits)) == 4, "Expected 4 Limits"
+    
+    # sort
+    expected = ['alimitName4','xlimitName3','ylimitName2','zlimitName1']
+    actual = []
+    suite.sort_attributes(ecflow.AttrType.limit);
+    suite.sort_attributes("limit");
+    for v in suite.limits: actual.append(v.name())
+    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+
+    suite.delete_limit("zlimitName1"); assert len(list(suite.limits)) == 3, "Expected 3 limits since we just deleted one limitName1" 
+    suite.delete_limit("");            assert len(list(suite.limits)) == 0, "Expected 0 limits since we just deleted all of them"
+
+    # The following will fail, since the iterators are essentially read only, 
+    # This is because we are using C++ vector iterators, hence we can't delete the vectors items, whilst traversing 
+    #    for limit in suite.limits: suite.delete_limit(limit.name())
+    # We can get round this by copy the limits first
+    suite.add_limit(ecflow.Limit("limitName1", 10))
+    suite.add_limit(ecflow.Limit("limitName2", 10))
+    suite.add_limit("limitName3", 10)
+    suite.add_limit("limitName4", 10)
+    limit_names = []
+    for limit in suite.limits:
+        limit_names.append(limit.name())
+    for limit in limit_names:
+        suite.delete_limit(limit)
+    assert len(list(suite.limits)) == 0, "Expected 0 Limits,since we just deleted all of them, via iteration"
+
+    #===========================================================================
+    # Test Limit and node paths, ECFLOW-518
+    #===========================================================================
+    the_limit = ecflow.Limit("limitName1", 10)
+    assert the_limit.name() == "limitName1", "name not as expected"
+    assert the_limit.value() == 0 ,"Expected limit value of 0"
+    assert the_limit.limit() == 10 ,"Expected limit of 10"
+    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
+    
+    the_limit.increment(1,"/path1") ;  assert the_limit.value() == 1 ,"Expected limit value of 1"
+    the_limit.increment(1,"/path2") ;  assert the_limit.value() == 2 ,"Expected limit value of 2"
+    the_limit.increment(1,"/path3") ;  assert the_limit.value() == 3 ,"Expected limit value of 3"
+    the_limit.increment(1,"/path4") ;  assert the_limit.value() == 4 ,"Expected limit value of 4"
+    for path in the_limit.node_paths(): print(path)
+    assert len(list(the_limit.node_paths())) == 4 ,"expected 4 path"
+    the_limit.decrement(1,"/path1") ; assert the_limit.value() == 3 ,"Expected limit value of 3"
+    the_limit.decrement(1,"/path2") ; assert the_limit.value() == 2 ,"Expected limit value of 2"
+    the_limit.decrement(1,"/path3") ; assert the_limit.value() == 1 ,"Expected limit value of 1"
+    the_limit.decrement(1,"/path4") ; assert the_limit.value() == 0 ,"Expected limit value of 0"
+    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
+
+    the_limit.increment(1,"/path1") # add same path, should only consume one token
+    the_limit.increment(1,"/path1")
+    the_limit.increment(1,"/path1")
+    the_limit.increment(1,"/path1")
+    assert len(list(the_limit.node_paths())) == 1 ,"expected 1 path"
+    assert the_limit.value() == 1 ,"Expected limit value of 1"
+
+    #===========================================================================
+    # add and delete inlimits
+    #===========================================================================
+    suite.add_inlimit(ecflow.InLimit("limitName1", "/s1/f1", 2))
+    suite.add_inlimit(ecflow.InLimit("limitName2", "/s1/f1", 2, True))
+    suite.add_inlimit("limitName3", "/s1/f1", 2)
+    suite.add_inlimit("limitName4", "/s1/f1", 2)
+    suite.add_inlimit("limitNameA", "/s1/f1", 2)
+    suite.add_inlimit("limitNameA", "/s1/f1/a", 2)
+    suite.add_inlimit("limitNameA", "/s1/f1/b", 2)
+    assert len(list(suite.inlimits)) == 7, "Expected 7 inLimits"
+    suite.delete_inlimit("limitName1"); assert len(list(suite.inlimits)) == 6, "Expected 6 inlimits since we just deleted one limitName1" 
+    suite.delete_inlimit("/s1/f1:limitNameA"); assert len(list(suite.inlimits)) == 5, "Expected 5 inlimits since we just deleted one limitName1" 
+    suite.delete_inlimit("/s1/f1/a:limitNameA"); assert len(list(suite.inlimits)) == 4, "Expected 4 inlimits since we just deleted one limitName1" 
+    suite.delete_inlimit("/s1/f1/b:limitNameA"); assert len(list(suite.inlimits)) == 3, "Expected 3 inlimits since we just deleted one limitName1" 
+    suite.delete_inlimit("");           assert len(list(suite.inlimits)) == 0, "Expected 0 inlimits since we just deleted all of them"
+
+    #===============================================================================
+    # add and delete triggers and complete
+    #===============================================================================
+    task = ecflow.Task("task")
+    task.add_trigger("t2 == active")
+    task.add_complete("t2 == complete")
+    assert task.get_complete(), "Expected complete"
+    assert task.get_trigger(), "Expected trigger"
+    assert task.get_trigger().get_expression() == "t2 == active","add trigger failed"
+    assert task.get_complete().get_expression() == "t2 == complete","add complete failed"
+    task.delete_trigger();  assert not task.get_trigger(), "Expected no trigger"
+    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
+    
+    task.add_part_trigger(ecflow.PartExpression("t1 == complete"))
+    task.add_part_trigger(ecflow.PartExpression("t2 == active", True))  #  for long and/or expressions, subsequent expr must be and/or
+    task.add_part_complete(ecflow.PartExpression("t3 == complete"))
+    task.add_part_complete(ecflow.PartExpression("t4 == active", False))  #  for long and/or expressions, subsequent expr must be and/or
+    task.delete_trigger();  assert not task.get_trigger(), "Expected no trigger"
+    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
+
+    task.add_part_trigger("t1 == complete")
+    task.add_part_trigger("t2 == active", True)  #  for long and/or expressions, subsequent expr must be and/or
+    task.add_part_complete("t3 == complete")
+    task.add_part_complete("t4 == active", False)  #  for long and/or expressions, subsequent expr must be and/or
+    task.delete_trigger();  assert not task.get_trigger(), "Expected no trigger"
+    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
+    
+    #===========================================================================
+    # Add triggers using expressions
+    #===========================================================================
+    expr = ecflow.Expression("t1 == complete")
+    task = ecflow.Task("task")
+    task.add_trigger(expr)
+    assert task.get_trigger().get_expression() == "t1 == complete","add trigger failed : " + task.get_trigger().get_expression()
+
+    expr = ecflow.Expression("t1 == complete")
+    expr.add(ecflow.PartExpression("t2 == complete", True))
+    expr.add(ecflow.PartExpression("t3 == complete", True))
+    task = ecflow.Task("task")
+    task.add_trigger(expr)
+    assert task.get_trigger().get_expression() == "t1 == complete AND t2 == complete AND t3 == complete","add trigger failed : " + task.get_trigger().get_expression()
+
+    #===========================================================================
+    # add,delete,find events
+    #===========================================================================
+    task.add_event(ecflow.Event(1)); 
+    task.add_event(2)                              
+    task.add_event(ecflow.Event(10, "Eventname"))  
+    task.add_event(10, "Eventname2")               
+    task.add_event("fred")                         
+    
+    # sort
+    expected = ['1','2','Eventname','Eventname2','fred']
+    actual = []
+    task.sort_attributes("event");
+    task.sort_attributes(ecflow.AttrType.event);
+    for v in task.events: actual.append(v.name_or_number())
+    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+     
+    # test find
+    event = task.find_event("EVENT")
+    assert(event.empty()),"Expected to not to find event"
+    assert(event.name() == ""),"Expected to not to find event, number is maximum int"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task.find_event("1"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.number() == 1), "Expected to find event 1"
+    assert(event.name() == ""), "Expected name to be empty"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task.find_event("2"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.number() == 2), "Expected to find event 1"
+    assert(event.name() == ""), "Expected name to be empty"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task.find_event("10"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.number() == 10), "Expected to find event 10"
+    assert(event.name() == "Eventname"), "Expected name to be empty"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task.find_event("fred"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.name() == "fred"), "Expected name to be empty, when name defind an not number, number is max_int"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    for e in task.events:     print(str(e)," # value: ",str(e.value()))
+    a_dict = {}
+    for e in task.events:
+        if e.name() != "": a_dict[e.name()] = e.value()
+        else:              a_dict[e.number()] = e.value()
+    print(a_dict)
+
+    assert len(list(task.events)) == 5, "Expected 5 Events"
+    task.delete_event("1");         assert len(list(task.events)) == 4, "Expected 4 Events"
+    task.delete_event("Eventname"); assert len(list(task.events)) == 3, "Expected 3 Events"
+    task.delete_event("");          assert len(list(task.events)) == 0, "Expected 0 Events"
+
+
+    #===========================================================================
+    # add and delete meter
+    #===========================================================================
+    task.add_meter(ecflow.Meter("zzzz", 0, 100, 50))
+    task.add_meter(ecflow.Meter("yyyy", 0, 100))
+    task.add_meter("bbbb", 0, 100, 50)
+    task.add_meter("aaaa", 0, 100)
+    assert len(list(task.meters)) == 4, "Expected 4 Meters"
+    
+    # sort
+    expected = ['aaaa','bbbb','yyyy','zzzz']
+    actual = []
+    task.sort_attributes(ecflow.AttrType.meter);
+    task.sort_attributes("meter");
+    for v in task.meters: actual.append(v.name())
+    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+ 
+    task.delete_meter("zzzz"); assert len(list(task.meters)) == 3, "Expected 3 Meters"
+    task.delete_meter("yyyy"); assert len(list(task.meters)) == 2, "Expected 2 Meters"
+    task.delete_meter("");     assert len(list(task.meters)) == 0, "Expected 0 Meters"
+
+    #===========================================================================
+    # add and delete queue
+    #===========================================================================
+    queue_items = [ "001", "002"]
+    task.add_queue(ecflow.Queue("queue",queue_items))
+    task.add_queue("queue1",queue_items)
+    task.add_queue("queue2",queue_items)
+    task.add_queue("queue3",queue_items)
+    assert len(list(task.queues)) == 4, "Expected 4 Queues"
+    task.delete_queue("queue3"); assert len(list(task.queues)) == 3, "Expected 3 Queues"
+    task.delete_queue("queue2"); assert len(list(task.queues)) == 2, "Expected 2 Queues"
+    task.delete_queue("");       assert len(list(task.queues)) == 0, "Expected 0 Queues"
+
+    #===========================================================================
+    # add and delete, find generic. These are arbitary attributes for future func.
+    #===========================================================================
+    generic_items = [ "001", "002"]
+    task.add_generic(ecflow.Generic("gen",generic_items ))
+    task.add_generic("gen1",generic_items )
+    task.add_generic("gen2",generic_items )
+    task.add_generic("gen3",generic_items )
+    assert len(list(task.generics)) == 4, "Expected 4 Generics"
+    gen = task.find_generic("gen3")
+    assert not gen.empty()," find failed"
+    assert gen.name() == "gen3", "expected for find gen3"
+    
+    task.delete_generic("gen1"); assert len(list(task.generics)) == 3, "Expected 3 Generics"
+    task.delete_generic("gen2"); assert len(list(task.generics)) == 2, "Expected 2 Generics"
+    task.delete_generic("");     assert len(list(task.generics)) == 0, "Expected 0 Generics"
+
+    #===========================================================================
+    # add and delete label
+    #===========================================================================
+    task.add_label(ecflow.Label("labela", "value"))
+    task.add_label(ecflow.Label("labelb", "value"))
+    task.add_label("labelc", "value")
+    task.add_label("labeld", "value")
+    assert len(list(task.labels)) == 4, "Expected 4 labels"
+    
+    # sort
+    expected = ['labela','labelb','labelc','labeld']
+    actual = []
+    task.sort_attributes("label");
+    task.sort_attributes(ecflow.AttrType.label);
+    for v in task.labels: actual.append(v.name())
+    assert expected == actual, "Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+    
+    task.delete_label("labela"); assert len(list(task.labels)) == 3, "Expected 3 Labels"
+    task.delete_label("labelb"); assert len(list(task.labels)) == 2, "Expected 2 Labels"
+    task.delete_label("");       assert len(list(task.labels)) == 0, "Expected 0 Labels"
+
+    #===========================================================================
+    # add delete Repeat
+    #===========================================================================
+    task.add_repeat(ecflow.RepeatInteger("integer", 0, 100, 2))
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    task.add_repeat(ecflow.RepeatEnumerated("enum", ["red", "green", "blue" ]))
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task.add_repeat(ecflow.RepeatDate("date", 20100111, 20100115, 2))
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task.add_repeat(ecflow.RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00"))
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task.add_repeat(ecflow.RepeatDateList("date",[20100111, 20100115]))
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+     
+    task.add_repeat(ecflow.RepeatString("string", ["a", "b", "c" ]))
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task.add_repeat(ecflow.RepeatDay(1))
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    
+    #===========================================================================
+    # create a time series, used for adding time and today
+    #===========================================================================
+    start = ecflow.TimeSlot(0, 0)
+    finish = ecflow.TimeSlot(23, 0)
+    incr = ecflow.TimeSlot(0, 30)
+    time_series = ecflow.TimeSeries(start, finish, incr, True)
+
+    # Add and delete today
+    # NOTE: **********************************************************************
+    # Do *NOT* delete attributes using iterator traversal
+    # The iterators *are* bound to the c++ iterators hence if we delete
+    # over the traversal, we can corrupt the vector, leading to undefined behavour.  
+    # Hence we **cannot** delete more than once over a traversal
+    # Soln 1: take a copy
+    # *****************************************************************************
+    # task.add_today( Today( 0,10 ))
+    # task.add_today( Today( 0,59, True ))
+    # task.add_today( Today(TimeSlot(20,10)) )
+    # task.add_today( Today(TimeSlot(20,20),False)) 
+    # for today in task.todays: 
+    #    task.delete_today(today) # will corrupt C++ vector
+  
+    task.add_today("00:30")
+    task.add_today("+00:30")
+    task.add_today("+00:30 20:00 01:00")
+    task.add_today(ecflow.Today(time_series))
+    task.add_today(ecflow.Today("+00:30"))
+    task.add_today(ecflow.Today("+00:30 20:00 01:00"))
+    task.add_today(ecflow.Today(0, 10))
+    task.add_today(0, 59, True)
+    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 10)))
+    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 20), False)) 
+    assert len(list(task.todays)) == 10, "Expected 8 todays"
+    vec_copy = []
+    for today in task.todays: vec_copy.append(today)
+    for today in vec_copy: task.delete_today(today)
+    assert len(list(task.todays)) == 0, "Expected 0 todays"
+        
+    #===========================================================================
+    # add and delete time
+    #===========================================================================
+    task.add_time("00:30")
+    task.add_time("+00:30")
+    task.add_time("+00:30 20:00 01:00")
+    task.add_time(ecflow.Time(time_series))
+    task.add_time(ecflow.Time(0, 10))
+    task.add_time(ecflow.Time("+00:30"))
+    task.add_time(ecflow.Time("+00:30 20:00 01:00"))
+    task.add_time(0, 59, True)
+    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 10)))
+    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 20), False)) 
+    assert len(list(task.times)) == 10, "Expected 8 times"
+    vec_copy = []
+    for time in task.times: vec_copy.append(time)
+    for time in vec_copy: task.delete_time(time)
+    assert len(list(task.todays)) == 0, "Expected 0 todays"
+
+    #===========================================================================
+    # add and delete date
+    #===========================================================================
+    for i in [ 1, 2, 4, 8, 16 ] :
+        task.add_date(i, 0, 0)
+    task.add_date(ecflow.Date(1, 1, 2010))
+    task.add_date(1, 1, 2010)       # duplicate
+    task.add_date(ecflow.Date(2, 1, 2010))
+    task.add_date(ecflow.Date(3, 1, 2010))
+    task.add_date(ecflow.Date(4, 1, 2010)) 
+    assert len(list(task.dates)) == 10, "Expected 10 dates but found " + str(len(list(task.dates)))
+    vec_copy = []
+    for attr in task.dates: vec_copy.append(attr)
+    for attr in vec_copy: task.delete_date(attr)
+    assert len(list(task.dates)) == 0, "Expected 0 dates"
+
+    #===========================================================================
+    # add and delete day
+    #===========================================================================
+    task.add_day(ecflow.Day(ecflow.Days.sunday))
+    task.add_day(ecflow.Days.monday)
+    task.add_day(ecflow.Days.tuesday)  # duplicate ?
+    task.add_day(ecflow.Day("tuesday"))   
+    task.add_day("sunday")     
+    assert len(list(task.days)) == 5, "Expected 5 days"
+    vec_copy = []
+    for attr in task.days: vec_copy.append(attr)
+    for attr in vec_copy: task.delete_day(attr)
+    assert len(list(task.days)) == 0, "Expected 0 days"
+    
+    #===========================================================================
+    # add and delete crons
+    #===========================================================================
+    cron = ecflow.Cron()
+    start = ecflow.TimeSlot(23 , 0)
+    ts = ecflow.TimeSeries(start,True)  # True means relative to suite start
+    cron.set_time_series(ts)
+    
+    cron = ecflow.Cron()
+    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])
+    cron.set_days_of_month([1, 2, 3, 4, 5, 6 ])
+    cron.set_months([1, 2, 3, 4, 5, 6])
+    start = ecflow.TimeSlot(0 , 0)
+    finish = ecflow.TimeSlot(23, 0)
+    incr = ecflow.TimeSlot(0, 30)
+    ts = ecflow.TimeSeries(start, finish, incr, True)  # True means relative to suite start
+    cron.set_time_series(ts)
+
+    cron0 = ecflow.Cron()
+    cron0.set_week_days([0, 1, 2, 3, 4, 5 ])
+    cron0.set_time_series(1, 30) # default relative = false, added in release 4.0.7
+
+    cron1 = ecflow.Cron()
+    cron1.set_week_days([0, 1, 2, 3, 4, 5, 6 ])
+    cron1.set_time_series(1, 30, True)
+    
+    cron2 = ecflow.Cron()
+    cron2.set_week_days([0, 1, 2, 3, 4, 5, 6])
+    cron2.set_time_series("00:30 01:30 00:01")
+    
+    cron3 = ecflow.Cron()
+    cron3.set_week_days([0, 1, 2, 3, 4, 5, 6])
+    cron3.set_time_series("+00:30")
+
+    task.add_cron(cron)
+    task.add_cron(cron1)
+    task.add_cron(cron2)
+    task.add_cron(cron3)
+    assert len(list(task.crons)) == 4, "Expected 4 crons"
+    vec_copy = []
+    for attr in task.crons: vec_copy.append(attr)
+    for attr in vec_copy: task.delete_cron(attr)
+    assert len(list(task.crons)) == 0, "Expected 0 crons"  
+    
+    #===========================================================================
+    # add autocancel
+    #===========================================================================
+    print("test add autoCancel")
+    t1 = ecflow.Task("t1")
+    assert t1.get_autocancel() is None, " Expected no autocancel"
+    t1.add_autocancel(3)                       # 3 days
+    assert t1.get_autocancel() is not None, " Expected autocancel"
+    print(str(t1.get_autocancel()))
+
+    t3 = ecflow.Task("t3")
+    t3.add_autocancel(20, 10, True)              # hour,minutes,relative
+    print(str(t3.get_autocancel()))
+    
+    t4 = ecflow.Task("t4")
+    t4.add_autocancel(ecflow.TimeSlot(10, 10), True)    # hour,minutes,relative
+    print(str(t4.get_autocancel()))
+
+    t5 = ecflow.Task("t5")
+    t5.add_autocancel(ecflow.Autocancel(1, 10, True))   # hour,minutes,relative
+    print(str(t5.get_autocancel()))
+    
+    #===========================================================================
+    # add autoarchive
+    #===========================================================================
+    print("test add autoarchive")
+    f1 = ecflow.Family("f1")
+    assert f1.get_autoarchive() is None, " Expected no autoarchive"
+    f1.add_autoarchive(3)                       # 3 days
+    assert f1.get_autoarchive() is not None, " Expected autoarchive"
+    print(str(f1.get_autoarchive()))
+ 
+    f2 = ecflow.Family("f2")
+    assert f2.get_autoarchive() is None, " Expected no autoarchive"
+    f2.add_autoarchive(3,True)                       # 3 days
+    assert f2.get_autoarchive() is not None, " Expected autoarchive"
+    print(str(f2.get_autoarchive()))
+
+    f3 = ecflow.Family("f3")
+    f3.add_autoarchive(20, 10, True)              # hour,minutes,relative
+    print(str(f3.get_autoarchive()))
+    
+    f3_1 = ecflow.Family("f3_1")
+    f3_1.add_autoarchive(20, 10, True,True)          # hour,minutes,relative,idle
+    print(str(f3_1.get_autoarchive()))
+
+    f4 = ecflow.Family("f4")
+    f4.add_autoarchive(ecflow.TimeSlot(10, 10), True)    # hour,minutes,relative
+    print(str(f4.get_autoarchive()))
+
+    f4_1 = ecflow.Family("f4_1")
+    f4_1.add_autoarchive(ecflow.TimeSlot(10, 10), True,True)    # hour,minutes,relative,idle
+    print(str(f4_1.get_autoarchive()))
+
+    f4_2 = ecflow.Family("f4_2")
+    assert f4_2.get_autoarchive() is None, " Expected no autoarchive"
+    f4_2.add_autoarchive(ecflow.Autoarchive(10,True))    # Days,idle
+    assert f4_2.get_autoarchive() is not None, " Expected autoarchive"
+    print(str(f4_2.get_autoarchive()))
+
+    #===========================================================================
+    # autocancel
+    #===========================================================================
+    f5 = ecflow.Family("f5")
+    f5.add_autocancel(ecflow.Autocancel(1, 10, True))   # hour,minutes,relative
+    print(str(f5.get_autocancel()))
+    
+    #===========================================================================
+    # add autorestore
+    #===========================================================================
+    print("test add autorestore")
+    t1 = ecflow.Task("f1")
+    assert t1.get_autorestore() is None, " Expected no autorestore"
+    t1.add_autorestore(["/s1/f2"])                       
+    assert t1.get_autorestore() is not None, " Expected autorestore"
+    print(str(t1.get_autorestore()))
+
+    f5 = ecflow.Family("f5")
+    assert f5.get_autorestore() is None, " Expected no autorestore"
+    f5.add_autorestore(["/s1/f2","/s2","/s3"])                       
+    assert f5.get_autorestore() is not None, " Expected autorestore"
+    print(str(f5.get_autoarchive()))
+    
+    f6 = ecflow.Family("f6")
+    assert f6.get_autorestore() is None, " Expected no autorestore"
+    f6.add_autorestore(ecflow.Autorestore(["/s1/f2","/s2","/s3"]))                       
+    assert f6.get_autorestore() is not None, " Expected autorestore"
+    print(str(f6.get_autoarchive()))
+    
+    #===========================================================================
+    # add late
+    #===========================================================================
+    late = ecflow.Late()
+    late.submitted(ecflow.TimeSlot(20, 10))
+    late.active(ecflow.TimeSlot(20, 10))
+    late.complete(ecflow.TimeSlot(20, 10), True)
+    task.add_late(late)
+    
+    late = ecflow.Late()
+    late.submitted(20, 10)
+    late.active(20, 10)
+    late.complete(20, 10, True)
+    t1.add_late(late)
+    
+    
+    #===========================================================================
+    # add defstatus, last one set takes effect
+    #===========================================================================
+    task.add_defstatus(ecflow.DState.complete)
+    assert task.get_defstatus() == ecflow.DState.complete
+    task.add_defstatus(ecflow.DState.queued)
+    assert task.get_defstatus() == ecflow.DState.queued
+    task.add_defstatus(ecflow.DState.aborted)
+    assert task.get_defstatus() == ecflow.DState.aborted
+    task.add_defstatus(ecflow.DState.submitted)
+    assert task.get_defstatus() == ecflow.DState.submitted
+    task.add_defstatus(ecflow.Defstatus(ecflow.DState.suspended ));
+    assert task.get_defstatus() == ecflow.DState.suspended
+    task.add_defstatus(ecflow.Defstatus("active"))  
+    assert task.get_defstatus() == ecflow.DState.active
+
+    # the state should be unknown until the suite is begun
+    assert task.get_state() == ecflow.State.unknown
+    assert task.get_dstate() == ecflow.DState.unknown
+ 
+    #===========================================================================
+    # add clock
+    #===========================================================================
+    clock = ecflow.Clock(1, 1, 2010, False)     # day,month, year, hybrid
+    clock.set_gain(1, 10, True)                 # True means positive gain
+    suite = ecflow.Suite("suite")
+    suite.add_clock(clock)
+    
+    clock = ecflow.Clock(1, 1, 2011, True)       # day,month, year, hybrid
+    clock.set_gain_in_seconds(12, True)
+    s1 = ecflow.Suite("s1")
+    s1.add_clock(clock)
+    
+    print("#===========================================================================")
+    print("# get clock")
+    print("#===========================================================================")
+    s0 = ecflow.Suite("s0")
+    assert s0.get_clock() is None, "Expected no clock"
+    
+    s0.add_clock(ecflow.Clock(1, 1, 2010, False))
+    assert s0.get_clock() is not None, "Expected clock"
+
+    #===========================================================================
+    # end clock, used in simulator only, not persisted
+    #===========================================================================
+    clock = ecflow.Clock(1, 1, 2010, False)     # day,month, year, hybrid
+    clock.set_gain(1, 10, True)                 # True means positive gain
+    suite = ecflow.Suite("suite")
+    suite.add_end_clock(clock)
+    
+    clock = ecflow.Clock(1, 1, 2011, True)       # day,month, year, hybrid
+    clock.set_gain_in_seconds(12, True)
+    s1 = ecflow.Suite("s1")
+    s1.add_end_clock(clock)
+    
+    print("#===========================================================================")
+    print("# get end clock")
+    print("#===========================================================================")
+    s0 = ecflow.Suite("s0")
+    assert s0.get_end_clock() is None, "Expected no end clock"
+    
+    s0.add_end_clock(ecflow.Clock(1, 1, 2010, False))
+    assert s0.get_end_clock() is not None, "Expected end clock"
+    #===========================================================================
+    # Add zombie. Note we can *NOT* add two zombie attributes of the same ZombieType
+    #===========================================================================
+    zombie_life_time_in_server = 800
+    child_list = [ ecflow.ChildCmdType.init, ecflow.ChildCmdType.event, ecflow.ChildCmdType.meter, ecflow.ChildCmdType.label, ecflow.ChildCmdType.wait, ecflow.ChildCmdType.abort, ecflow.ChildCmdType.complete ]
+    zombie_type_list = [ ecflow.ZombieType.ecf, ecflow.ZombieType.ecf_pid, ecflow.ZombieType.ecf_pid_passwd, ecflow.ZombieType.ecf_passwd, ecflow.ZombieType.user, ecflow.ZombieType.path ]
+    for zombie_type in zombie_type_list:
+        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block, zombie_life_time_in_server)
+        s1.add_zombie(zombie_attr)
+    assert len(list(s1.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(s1.zombies)))
+    
+    # delete all the zombies
+    s1.delete_zombie("")
+    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
+    
+    # add with zombie_life_time_in_server not set, this is optional
+    for zombie_type in zombie_type_list:
+        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block)
+        s1.add_zombie(zombie_attr)
+    assert len(list(s1.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(s1.zombies)))
+
+    s1.delete_zombie("")
+    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
+
+    # repeat the the test with empty child list. Empty child list means apply to all child commands
+    child_list = []
+    for zombie_type in zombie_type_list:
+        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block, zombie_life_time_in_server)
+        s1.add_zombie(zombie_attr)
+        
+        # test delete of specific zombie attribute
+        assert len(list(s1.zombies)) == 1, "Expected 1 zombie attributes but found " + str(len(list(s1.zombies)))
+        s1.delete_zombie(zombie_type)
+        assert len(list(s1.zombies)) == 0, "Expected 0 zombie attributes but found " + str(len(list(s1.zombies)))
+
+
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestAddDeleteError.py 5.13.0-1/libs/pyext/test/py_u_TestAddDeleteError.py
--- 5.12.4-1/libs/pyext/test/py_u_TestAddDeleteError.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestAddDeleteError.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,93 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import os
+from ecflow import Defs, Suite, Variable, Limit, InLimit, Task, PartExpression, \
+                   Event, Meter, Label, RepeatInteger, RepeatEnumerated, RepeatDate,RepeatDateList,RepeatString, \
+                   TimeSlot, TimeSeries, Today, Time, Date, Day, Days, Cron, Autocancel, Late, \
+                   DState, Clock, ChildCmdType, ZombieType, ZombieAttr, ZombieUserActionType, Client, debug_build
+import ecflow_test_util as Test
+    
+if __name__ == "__main__":
+    
+    Test.print_test_start(os.path.basename(__file__))
+    
+    #
+    # Test for: See  ECFLOW-106 Times/Dates attributes attached to suite node
+    #
+    defs = Defs()
+    suite = defs.add_suite("s1") 
+    
+    #
+    # Suite should not be allowed time based dependencies
+    # Check Today
+    expected_error = False
+    try:
+        suite.add_today("00:30")
+    except RuntimeError: 
+        expected_error = True
+    assert expected_error, "Suite should not allow any time based dependencies"
+
+    expected_error = False
+    try:
+        suite.add_today(0,30)
+    except RuntimeError: 
+        expected_error = True
+    assert expected_error, "Suite should not allow any time based dependencies"
+    
+    #
+    # Check Time
+    expected_error = False
+    try:
+        suite.add_time("+00:30")
+    except RuntimeError: 
+        expected_error = True
+    assert expected_error, "Suite should not allow any time based dependencies"
+
+    expected_error = False
+    try:
+        suite.add_time(0,30)
+    except RuntimeError: 
+        expected_error = True
+    assert expected_error, "Suite should not allow any time based dependencies"
+
+    # 
+    # Check Date::See  ECFLOW-106 Times/Dates attributes attached to suite node
+    expected_error = False
+    try:
+        suite.add_date( 1,1,2010)
+    except RuntimeError: 
+        expected_error = True
+    assert expected_error, "Suite should not allow any time based dependencies"
+ 
+    # 
+    # Check Day:: See  ECFLOW-106 Times/Dates attributes attached to suite node
+    expected_error = False
+    try:
+        suite.add_day("sunday")
+    except RuntimeError: 
+        expected_error = True
+    assert expected_error, "Suite should not allow any time based dependencies"
+
+    # 
+    #Adding a RepeatDateList with a empty list should be an error
+    expected_error = False
+    task = Task("t")
+    try:
+        task.add_repeat(RepeatDateList("date",[]))
+    except RuntimeError: 
+        expected_error = True
+    assert expected_error, "RepeatDateList adding an empty date list should be an error"
+
+    print("All Tests pass")
+    
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestAddDeleteFunc.py 5.13.0-1/libs/pyext/test/py_u_TestAddDeleteFunc.py
--- 5.12.4-1/libs/pyext/test/py_u_TestAddDeleteFunc.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestAddDeleteFunc.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,331 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import os
+from ecflow import Defs, Suite, Variable, Limit, InLimit, Task, PartExpression, \
+                   Event, Meter, Label, Queue, RepeatInteger, RepeatEnumerated, RepeatDate, RepeatDateTime, \
+                   RepeatDateList, RepeatString, TimeSlot, TimeSeries, Today, Time, Date, Day, Days, Cron, Autocancel, \
+                   Late, DState, Clock, ChildCmdType, ZombieType, ZombieAttr, ZombieUserActionType, Client, debug_build
+import ecflow_test_util as Test
+
+if __name__ == "__main__":
+
+    Test.print_test_start(os.path.basename(__file__))
+    
+    #
+    # Add Nodes functional way
+    #
+    defs = Defs()
+    defs.add_suite("s1").add_task("t1").add_variable("var","v")
+    defs.add_suite("s2").add_family("f1").add_task("t1").add_variable("var","v")
+    defs.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
+    assert len(defs) == 3,"Expected 3 suites"    
+
+
+    # add and delete variables
+    a_dict = { "name":"value", "name2":"value2", "name3":"value3", "name4":"value4" }
+    suite = Suite("s1")
+    suite.add_variable(Variable("ECF_HOME","'/tmp/'")) \
+         .add_variable("Fred", 1)\
+         .add_variable("ECF_URL_BASE",'http://www.ecmwf.int')\
+         .add_variable("ECF_URL",'"publications/manuals/sms"')\
+         .add_variable(a_dict)
+    print(suite)
+    assert len(list(suite.variables)) == 8,"Expected 8 variable"    
+    suite.delete_variable("");         assert len(list(suite.variables)) == 0,"Expected 0 variable since we should have deleted all"
+    
+    
+    # add and delete limits
+    the_limit = Limit("limitName1", 10)
+    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
+    suite.add_limit(  Limit("limitName1", 10) )\
+        .add_limit(  Limit("limitName2", 10) )\
+        .add_limit(  "limitName3", 10 )\
+        .add_limit(  "limitName4", 10 )
+    assert len(list(suite.limits)) == 4,"Expected 4 Limits"
+    suite.delete_limit("");           assert len(list(suite.limits)) == 0,"Expected 0 limits since we just deleted all of them"
+
+
+    # add and delete in-limits
+    suite.add_inlimit( InLimit("limitName1","/s1/f1",2,True) )\
+        .add_inlimit( InLimit("limitName2","/s1/f1",2))\
+        .add_inlimit( "limitName3","/s1/f1",2,True)\
+        .add_inlimit( "limitName4","/s1/f1",2)
+    assert len(list(suite.inlimits)) == 4,"Expected 4 inLimits"
+    suite.delete_inlimit("limitName1"); assert len(list(suite.inlimits)) == 3,"Expected 3 inlimits since we just deleted one limitName1" 
+    suite.delete_inlimit("");           assert len(list(suite.inlimits)) == 0,"Expected 0 inlimits since we just deleted all of them"
+
+
+    # add and delete triggers and complete
+    task = Task("task")
+    task.add_trigger( "t2 == active" ).add_complete( "t2 == complete" )
+    assert task.get_complete(), "Expected complete"
+    assert task.get_trigger(),  "Expected trigger"
+    task.delete_trigger();  assert not task.get_trigger(),  "Expected no trigger"
+    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
+    
+    task.add_part_trigger(  PartExpression("t1 == complete") )\
+        .add_part_complete( PartExpression("t3 == complete") ) \
+        .add_part_complete( PartExpression("t4 == active",False) )   
+    task.delete_trigger();  assert not task.get_trigger(),  "Expected no trigger"
+    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
+
+    task.add_part_trigger(  "t1 == complete" ) \
+        .add_part_complete( "t3 == complete" ) \
+        .add_part_complete( "t4 == active",False)  #  for long and/or expressions, subsequent expr must be and/or
+    task.delete_trigger();  assert not task.get_trigger(),  "Expected no trigger"
+    task.delete_complete(); assert not task.get_complete(), "Expected no complete"
+    
+    
+    # add and delete events
+    task.add_event( Event(1) ).add_event( 2 ).add_event( Event(10, "Eventname") ).add_event( 10, "Eventname2" ).add_event( "fred" )
+    assert len(list(task.events)) == 5,"Expected 5 Events"
+    task.delete_event("");          assert len(list(task.events)) == 0,"Expected 0 Events"
+
+
+    # add and delete meter
+    task.add_meter( Meter("metername1", 0, 100, 50) )\
+        .add_meter( Meter("metername2", 0, 100) )\
+        .add_meter( "metername3", 0, 100, 50 )\
+        .add_meter( "metername4", 0, 100 )
+    assert len(list(task.meters)) == 4,"Expected 4 Meters"
+    task.delete_meter("");           assert len(list(task.meters)) == 0,"Expected 0 Meters"
+
+    # add and delete queue
+    queue_items = [ "001", "002"]
+    task.add_queue( Queue("q1", queue_items) )\
+        .add_queue( Queue("q2", queue_items) )\
+        .add_queue( "q3", queue_items )\
+        .add_queue( "q4", queue_items)
+    assert len(list(task.queues)) == 4,"Expected 4 Queues"
+    task.delete_queue("");           assert len(list(task.queues)) == 0,"Expected 0 Queues"
+
+    # add and delete label
+    task.add_label( Label("label_name1", "value") )\
+        .add_label( Label("label_name2", "value") )\
+        .add_label( "label_name3", "value" )\
+        .add_label( "label_name4", "value" )
+    assert len(list(task.labels)) == 4,"Expected 4 labels"
+    task.delete_label("");            assert len(list(task.labels)) == 0,"Expected 0 Labels"
+
+    # add delete Repeat
+    task.add_repeat( RepeatInteger("integer", 0, 100, 2) ).add_variable("fred","j")
+    repeat = task.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    task.add_repeat( RepeatEnumerated("enum", ["red", "green", "blue" ]) ).add_variable("Q","j")
+    print(task)
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task.add_repeat( RepeatDate("date", 20100111, 20100115,2) ).add_variable("W","j")
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task.add_repeat(RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00")).add_variable("W", "j")
+    task.delete_repeat()
+    repeat = task.get_repeat();
+    assert repeat.empty(), "Expected no repeat"
+
+    task.add_repeat( RepeatDateList("date",[20100111, 20100115]) ).add_variable("W","j")
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    task.add_repeat( RepeatString("string", ["a", "b", "c" ] ) ).add_variable("E","j")
+    task.delete_repeat()      
+    repeat = task.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    
+    # create a time series, used for adding time and today
+    start = TimeSlot(0, 0)
+    finish = TimeSlot(23, 0)
+    incr = TimeSlot(0, 30)
+    time_series = TimeSeries( start, finish, incr, True)
+
+    # Add and delete today
+    # NOTE: **********************************************************************
+    # Do *NOT* delete attributes using iterator traversal
+    # The iterators *are* bound to the c++ iterators hence if we delete
+    # over the traversal, we can corrupt the vector, leading to undefined behaviour.  
+    # Hence we **cannot** delete more than once over a traversal
+    # Soln 1: take a copy
+    # *****************************************************************************
+    # task.add_today( Today( 0,10 ))
+    # task.add_today( Today( 0,59, True ))
+    # task.add_today( Today(TimeSlot(20,10)) )
+    # task.add_today( Today(TimeSlot(20,20),False)) 
+    # for today in task.todays: 
+    #    task.delete_today(today) # will corrupt C++ vector
+  
+    task.add_today( "00:30" ).add_today( "+00:30" ).add_today( "+00:30 20:00 01:00" )\
+        .add_today( Today( time_series) )\
+        .add_today( Today( 0,10 )).add_today( 0, 59, True )\
+        .add_today( Today(TimeSlot(20,10)) )\
+        .add_today( Today(TimeSlot(20,20),False)) 
+    assert len(list(task.todays)) == 8,"Expected 8 todays"
+    vec_copy = []
+    for today in task.todays: vec_copy.append(today)
+    for today in vec_copy: task.delete_today(today)
+    assert len(list(task.todays)) == 0,"Expected 0 todays"
+        
+             
+    # add and delete time
+    task.add_time( "00:30" ).add_time( "+00:30" ).add_time( "+00:30 20:00 01:00" )\
+        .add_time( Time(time_series ))\
+        .add_time( Time( 0,10 ))\
+        .add_time( 0, 59, True)\
+        .add_time( Time(TimeSlot(20,10)) )\
+        .add_time( Time(TimeSlot(20,20),False)) 
+    assert len(list(task.times)) == 8,"Expected 8 times"
+    vec_copy = []
+    for time in task.times: vec_copy.append(time)
+    for time in vec_copy: task.delete_time(time)
+    assert len(list(task.todays)) == 0,"Expected 0 todays"
+
+
+    # add and delete date
+    for i in [ 1, 2, 4, 8, 16 ] :
+        task.add_date( i, 0, 0)
+    task.add_date( Date(1, 1, 2010))\
+        .add_date( Date(2, 1, 2010))\
+        .add_date( Date(3, 1, 2010))\
+        .add_date( Date(4, 1, 2010))\
+        .add_date( 1, 1, 2010)
+    assert len(list(task.dates)) == 10,"Expected 10 dates but found " + str(len(list(task.dates)))
+    vec_copy = []
+    for attr in task.dates: vec_copy.append(attr)
+    for attr in vec_copy: task.delete_date(attr)
+    assert len(list(task.dates)) == 0,"Expected 0 dates"
+
+    # add and delete day
+    task.add_day( Day(Days.sunday))\
+        .add_day( Days.monday)\
+        .add_day( Days.tuesday)\
+        .add_day( "sunday")     
+    assert len(list(task.days)) == 4,"Expected 4 days"
+    vec_copy = []
+    for attr in task.days: vec_copy.append(attr)
+    for attr in vec_copy: task.delete_day(attr)
+    assert len(list(task.days)) == 0,"Expected 0 days"
+    
+    # add and delete crons
+    cron = Cron()
+    cron.set_week_days( [0, 1, 2, 3, 4, 5, 6]  )
+    cron.set_days_of_month( [1, 2, 3, 4, 5, 6 ] )
+    cron.set_months(  [1, 2, 3, 4, 5, 6]  )
+    start = TimeSlot(0 ,0)
+    finish = TimeSlot(23, 0)
+    incr = TimeSlot(0, 30)
+    ts = TimeSeries( start, finish, incr, True)  # True means relative to suite start
+    cron.set_time_series( ts )
+
+    cron1 = Cron()
+    cron1.set_week_days( [0, 1, 2, 3, 4, 5, 6 ] )
+    cron1.set_time_series( 1, 30,  True )
+    
+    cron2 = Cron()
+    cron2.set_week_days( [0, 1, 2, 3, 4, 5, 6] )
+    cron2.set_time_series( "00:30 01:30 00:01" )
+    
+    cron3 = Cron()
+    cron3.set_week_days( [0, 1, 2, 3, 4, 5, 6] )
+    cron3.set_time_series( "+00:30" )
+
+    task.add_cron( cron ) \
+        .add_cron( cron1 ) \
+        .add_cron( cron2 ) \
+        .add_cron( cron3 )
+    assert len(list(task.crons)) == 4,"Expected 4 crons"
+    vec_copy = []
+    for attr in task.crons: vec_copy.append(attr)
+    for attr in vec_copy: task.delete_cron(attr)
+    assert len(list(task.crons)) == 0,"Expected 0 crons"  
+    
+    
+    # add autocancel
+    t1 = Task("t1")
+    t1.add_autocancel( 3 ).add_variable("A","j")                       
+    t3 = Task("t3")
+    t3.add_autocancel( 20, 10, True ).add_variable("B","j") 
+    t4 = Task("t4")
+    t4.add_autocancel( TimeSlot(10, 10), True ).add_variable("C","j") 
+    t5 = Task("t5")
+    t5.add_autocancel( Autocancel(1, 10, True) ).add_variable("D","j") 
+    
+    
+    # add late
+    late = Late()
+    late.submitted( TimeSlot(20, 10) )
+    late.active(    TimeSlot(20, 10))
+    late.complete(  TimeSlot(20, 10), True)
+    task.add_late(late ).add_variable("FRED33","j") 
+        
+    
+    # add defstatus, last one set takes effect
+    task.add_defstatus( DState.complete )\
+        .add_defstatus( DState.queued )\
+        .add_defstatus( DState.aborted )\
+        .add_defstatus( DState.submitted )\
+        .add_defstatus( DState.suspended )\
+        .add_defstatus( DState.active )
+    
+    #
+    # add clock
+    #
+    clock = Clock(1, 1, 2010, False)     # day,month, year, hybrid
+    clock.set_gain(1, 10, True)         # True means positive gain
+    suite =  Suite("suite")
+    suite.add_clock(clock).add_variable("fred1","j") 
+    
+    end_clock = Clock(1, 1, 2017, False)     # day,month, year, hybrid
+    suite.add_end_clock(end_clock).add_variable("fred2","j") 
+    
+    clock = Clock(1, 1, 2011, True)       # day,month, year, hybrid
+    clock.set_gain_in_seconds(12, True)
+    s1 =  Suite("s1")
+    s1.add_clock(clock).add_variable("fred3","j") 
+    s1.add_end_clock(end_clock).add_variable("fred4","j") 
+    
+    #
+    # Add zombie. Note we can *NOT* add two zombie attributes of the same ZombieType
+    #
+    zombie_life_time_in_server = 800
+    child_list = [ ChildCmdType.init, ChildCmdType.event, ChildCmdType.meter, ChildCmdType.label, ChildCmdType.wait, ChildCmdType.abort, ChildCmdType.complete ]
+    zombie_type_list = [ ZombieType.ecf, ZombieType.user, ZombieType.path ]
+    count = 1;
+    for zombie_type in zombie_type_list:
+        zombie_attr = ZombieAttr(zombie_type, child_list, ZombieUserActionType.block, zombie_life_time_in_server)
+        s1.add_zombie(zombie_attr).add_variable("afred" + str(count),"j") 
+        count += 1
+    assert len(list(s1.zombies)) == 3,"Expected 3 zombie attributes but found " + str(len(list(s1.zombies)))
+    
+    # delete all the zombies
+    s1.delete_zombie("")
+    assert len(list(s1.zombies)) == 0,"Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
+
+    # repeat the the test with empty child list. Empty child list means apply to all child commands
+    # + don't specify zombie_life_time_in_server as this is optional
+    child_list = [ ]
+    zombie_type_list = [ ZombieType.ecf, ZombieType.user, ZombieType.path ]
+    for zombie_type in zombie_type_list:
+        zombie_attr = ZombieAttr(zombie_type, child_list, ZombieUserActionType.block)
+        s1.add_zombie(zombie_attr).add_variable("bfred" + str(count),"j") 
+        
+        # test delete of specific zombie attribute
+        assert len(list(s1.zombies)) == 1,"Expected 1 zombie attributes but found " + str(len(list(s1.zombies)))
+        s1.delete_zombie(zombie_type)
+        assert len(list(s1.zombies)) == 0,"Expected 0 zombie attributes but found " + str(len(list(s1.zombies)))
+        count += 1;
+
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestAddNodeFunc.py 5.13.0-1/libs/pyext/test/py_u_TestAddNodeFunc.py
--- 5.12.4-1/libs/pyext/test/py_u_TestAddNodeFunc.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestAddNodeFunc.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,69 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+from ecflow import Defs, Client, debug_build
+import ecflow_test_util as Test
+import os
+
+def create_defs_sequentially():
+    local_defs = Defs()
+    suite = local_defs.add_suite("s1")
+    suite.add_variable("Var","value")
+    suite.add_meter( "metername3", 0, 100, 50 )
+    suite.add_event( 2 )
+    suite.add_event( 3 )
+    f1 = suite.add_family("f1")
+    f1 = f1.add_family("f1")
+    t1 = f1.add_task("t1")
+    t1.add_variable("fred","jones")
+    
+    f2 = suite.add_family("f2")
+    f1 = f2.add_family("f1")
+    t1 = f1.add_task("t1")
+    t1.add_variable("fred","jones")
+
+    f3 = suite.add_family("f3")
+    t1 = f3.add_task("t1")
+    t1.add_variable("fred",    "jones")
+    
+    suite.add_task("t1").add_variable("fred","jones")
+    return local_defs
+
+def create_defs_functionally():
+    f_defs = Defs()
+    suite = f_defs.add_suite("s1")
+    suite.add_variable("Var","value").add_family("f1").add_family("f1").add_task("t1").add_variable("fred","jones")
+    suite.add_family("f2").add_family("f1").add_task("t1").add_variable("fred","jones")
+    suite.add_meter( "metername3", 0, 100, 50 ).add_family("f3").add_task("t1").add_variable("fred","jones")
+    suite.add_event( 2 ).add_event( 3 ).add_task("t1").add_variable("fred","jones")
+    return f_defs
+    
+    
+if __name__ == "__main__":
+        
+    Test.print_test_start(os.path.basename(__file__))
+
+    #
+    # Add Nodes functional way
+    #
+    defs = Defs()
+    defs.add_suite("s1").add_task("t1").add_variable("var","v")
+    defs.add_suite("s2").add_family("f1").add_task("t1").add_variable("var","v")
+    defs.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
+    assert len(defs) == 3,"Expected 3 suites"    
+  
+    # These test show that although add_variable() returns a node_ptr, its really a suite
+    # hence calling add_family/add_task still works.
+    assert create_defs_sequentially() == create_defs_functionally(),"Functional suite not as expected "
+  
+    print("All Tests pass")
+    
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestAutoAddExtern.py 5.13.0-1/libs/pyext/test/py_u_TestAutoAddExtern.py
--- 5.12.4-1/libs/pyext/test/py_u_TestAutoAddExtern.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestAutoAddExtern.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+#  code for testing pointers and hierarchy in python
+
+import os
+from ecflow import Suite, Family, Task, Defs, Client, debug_build
+import ecflow_test_util as Test
+
+def check_then_auto_add_extern(defs):
+    error_msg = defs.check() 
+    print(error_msg)
+    assert len(error_msg) !=0,"Expect error in checks\n" + str(defs)
+    
+    defs.auto_add_externs(True)
+    error_msg = defs.check()
+    assert len(error_msg) == 0,"Expect check to pass after auto add extern\n" + error_msg + "\n" + str(defs)
+    
+if __name__ == "__main__":   
+    Test.print_test_start(os.path.basename(__file__))
+
+    defs = Defs()
+    error_msg = defs.check();  assert len(error_msg) == 0,"Expect empty defs to pass check"
+    suite = defs.add_suite("ext");
+
+    f1 = suite.add_family("f1")
+    f1.add_task("t").add_trigger("/a/b/c/d == complete");     check_then_auto_add_extern(defs)
+    f1.add_task("t1").add_trigger("/a/b/c/d/e:event == set"); check_then_auto_add_extern(defs)
+    f1.add_task("t2").add_trigger("/a/b/c/d/x:event");        check_then_auto_add_extern(defs)     
+    f1.add_task("t3").add_trigger("/a/b/c/d/y:meter le 30");  check_then_auto_add_extern(defs)  
+    f1.add_task("t4").add_trigger("/a/b/c/d/z<flag>late");    check_then_auto_add_extern(defs)   
+    
+    f2 = suite.add_family("f2")
+    f2.add_inlimit("hpcd","limits");                           check_then_auto_add_extern(defs)
+    f2.add_task("t").add_inlimit("sg1","/suiteName");          check_then_auto_add_extern(defs)
+    f2.add_task("t1").add_inlimit("hpcd","/obs/limits");       check_then_auto_add_extern(defs) 
+    f2.add_task("t2").add_inlimit("c1a","/limits");            check_then_auto_add_extern(defs)     
+    print (defs)
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestAviso.py 5.13.0-1/libs/pyext/test/py_u_TestAviso.py
--- 5.12.4-1/libs/pyext/test/py_u_TestAviso.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestAviso.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,90 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+import os
+import ecflow as ecf
+import itertools as it
+
+import ecflow_test_util as Test
+
+
+def can_create_aviso_from_parameters():
+    aviso = ecf.AvisoAttr("name", "listener", "url", "schema", "polling", "auth")
+    assert aviso.name() == "name"
+    assert aviso.listener() == "listener"
+    assert aviso.url() == "url"
+    assert aviso.schema() == "schema"
+    assert aviso.polling() == "polling"
+    assert aviso.auth() == "auth"
+
+
+def can_add_aviso_to_task():
+    suite = ecf.Suite("s1")
+
+    family = ecf.Family("f1")
+    suite.add_family(family)
+
+    task = ecf.Task("f1")
+    family.add_task(task)
+
+    aviso = ecf.AvisoAttr("name", "listener", "url", "schema", "polling", "auth")
+    task.add_aviso(aviso)
+    assert len(list(task.avisos)) == 1
+
+    actual = list(task.avisos)[0]
+    assert actual.name() == "name"
+    assert actual.listener() == "listener"
+    assert actual.url() == "url"
+    assert actual.schema() == "schema"
+    assert actual.polling() == "polling"
+    assert actual.auth() == "auth"
+
+
+def can_embed_aviso_into_task():
+    suite = ecf.Suite("s1")
+
+    family = ecf.Family("f1")
+    suite.add_family(family)
+
+    task = ecf.Task("f1", ecf.AvisoAttr("name", "listener", "url", "schema", "polling", "auth"))
+    assert len(list(task.avisos)) == 1
+
+    actual = list(task.avisos)[0]
+    assert actual.name() == "name"
+    assert actual.listener() == "listener"
+    assert actual.url() == "url"
+    assert actual.schema() == "schema"
+    assert actual.polling() == "polling"
+    assert actual.auth() == "auth"
+
+
+def cannot_have_multiple_avisos_in_single_task():
+    suite = ecf.Suite("s1")
+
+    family = ecf.Family("f1")
+    suite.add_family(family)
+
+    try:
+        task = ecf.Task("f1", ecf.AvisoAttr("name", "listener", "url", "schema", "polling", "auth"),
+                        ecf.AvisoAttr("another", "listener", "url", "schema", "polling", "auth"))
+        assert False, "Expected exception indicating multiple avisos are not allowed in a task"
+    except RuntimeError as e:
+        assert True
+
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+
+    can_create_aviso_from_parameters()
+    can_add_aviso_to_task()
+    can_embed_aviso_into_task()
+    cannot_have_multiple_avisos_in_single_task()
+
+    print("All tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestCopy.py 5.13.0-1/libs/pyext/test/py_u_TestCopy.py
--- 5.12.4-1/libs/pyext/test/py_u_TestCopy.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestCopy.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,515 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# code for testing copy
+#
+import ecflow
+import sys
+import os
+import copy
+import ecflow_test_util as Test
+
+if __name__ == "__main__":
+    
+    Test.print_test_start(os.path.basename(__file__))
+
+    defs = ecflow.Defs()
+    defs.add_suite("a").add_family("f1").add_task("t1").add_variable("a","b").add_event(1).add_meter("meter", 0, 100).add_label("label", "v").add_time("+00:30 20:00 01:00")
+    print(defs)
+    
+    defs_copy = copy.copy(defs)
+    print(defs_copy)
+    assert defs_copy == defs,"defs should be equal after copy"
+    
+ 
+    #===========================================================================
+    # Defs: add and delete *USER* variables
+    #===========================================================================
+    defs = ecflow.Defs()
+    defs.add_variable("FRED", "/tmp/")
+    defs.add_variable("ECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
+    defs.add_variable("ECF_URL_BASE", "http://www.ecmwf.int")
+    defs.add_variable("ECF_URL", "publications/manuals/sms")
+    assert len(list(defs.user_variables)) == 4, "Expected *user* 4 variable"    
+    defs_copy = copy.copy(defs)
+    assert len(list(defs_copy.user_variables)) == 4, "Expected *user* 4 variable"    
+
+    defs.delete_variable("FRED");     assert len(list(defs.user_variables)) == 3, "Expected 3 variables since we just delete FRED"
+    defs.delete_variable("");         assert len(list(defs.user_variables)) == 0, "Expected 0 variables since we should have deleted all"
+    assert len(list(defs_copy.user_variables)) == 4, "Expected *user* 4 variable"    
+
+    #===========================================================================
+    # Suite: add and delete variables
+    #===========================================================================
+    suite = ecflow.Suite("s1")
+    suite.add_variable(ecflow.Variable("ECF_HOME", "/tmp/"))
+    suite.add_variable("ECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
+    suite.add_variable("ECF_URL_BASE", "http://www.ecmwf.int")
+    suite.add_variable("ECF_URL", "publications/manuals/sms")
+    assert len(list(suite.variables)) == 4, "Expected 4 variable"   
+    suite_copy = copy.copy(suite)
+    assert len(list(suite_copy.variables)) == 4, "Expected 4 variables in copy"   
+
+    #===========================================================================
+    # add and delete limits
+    #===========================================================================
+    suite.add_limit(ecflow.Limit("limitName1", 10))
+    suite.add_limit(ecflow.Limit("limitName2", 10))
+    suite.add_limit("limitName3", 10)
+    suite.add_limit("limitName4", 10)
+    assert len(list(suite.limits)) == 4, "Expected 4 Limits"
+    
+    suite_copy = copy.copy(suite)
+    assert len(list(suite_copy.limits)) == 4, "Expected 4 Limits in copy"
+    suite_copy.delete_limit("limitName1"); assert len(list(suite_copy.limits)) == 3, "Expected 3 limits since we just deleted one limitName1" 
+    suite_copy.delete_limit("");           assert len(list(suite_copy.limits)) == 0, "Expected 0 limits since we just deleted all of them"
+
+    #===========================================================================
+    # Test Limit and node paths 
+    #===========================================================================
+    the_limit = ecflow.Limit("limitName1", 10)
+    assert the_limit.name() == "limitName1", "name not as expected"
+    assert the_limit.value() == 0 ,"Expected limit value of 0"
+    assert the_limit.limit() == 10 ,"Expected limit of 10"
+    assert len(list(the_limit.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
+    
+    the_limit.increment(1,"/path1") ;  assert the_limit.value() == 1 ,"Expected limit value of 1"
+    the_limit.increment(1,"/path2") ;  assert the_limit.value() == 2 ,"Expected limit value of 2"
+    the_limit.increment(1,"/path3") ;  assert the_limit.value() == 3 ,"Expected limit value of 3"
+    the_limit.increment(1,"/path4") ;  assert the_limit.value() == 4 ,"Expected limit value of 4"
+    for path in the_limit.node_paths(): print(path)
+    assert len(list(the_limit.node_paths())) == 4 ,"expected 4 path"
+    
+    limit_copy = copy.copy(the_limit)
+    assert len(list(limit_copy.node_paths())) == 4 ,"expected 4 path in copy"
+
+    limit_copy.decrement(1,"/path1") ; assert limit_copy.value() == 3 ,"Expected limit value of 3"
+    limit_copy.decrement(1,"/path2") ; assert limit_copy.value() == 2 ,"Expected limit value of 2"
+    limit_copy.decrement(1,"/path3") ; assert limit_copy.value() == 1 ,"Expected limit value of 1"
+    limit_copy.decrement(1,"/path4") ; assert limit_copy.value() == 0 ,"Expected limit value of 0"
+    assert len(list(limit_copy.node_paths())) == 0 ,"Expected nodes which have consumed a limit to be empty"
+
+    limit_copy.increment(1,"/path1") # add same path, should only consume one token
+    limit_copy.increment(1,"/path1")
+    limit_copy.increment(1,"/path1")
+    limit_copy.increment(1,"/path1")
+    assert len(list(limit_copy.node_paths())) == 1 ,"expected 1 path"
+    assert limit_copy.value() == 1 ,"Expected limit value of 1"
+
+    #===========================================================================
+    # add and delete inlimits
+    #===========================================================================
+    suite.add_inlimit(ecflow.InLimit("limitName1", "/s1/f1", 2))
+    suite.add_inlimit(ecflow.InLimit("limitName2", "/s1/f1", 2, True))
+    suite.add_inlimit("limitName3", "/s1/f1", 2)
+    suite.add_inlimit("limitName4", "/s1/f1", 2, True)
+    assert len(list(suite.inlimits)) == 4, "Expected 4 inLimits"
+    
+    suite_copy = copy.copy(suite)
+    assert len(list(suite_copy.inlimits)) == 4, "Expected 4 inLimits"
+    suite_copy.delete_inlimit("limitName1"); assert len(list(suite_copy.inlimits)) == 3, "Expected 3 inlimits since we just deleted one limitName1" 
+    suite_copy.delete_inlimit("");           assert len(list(suite_copy.inlimits)) == 0, "Expected 0 inlimits since we just deleted all of them"
+
+    #===============================================================================
+    # add and delete triggers and complete
+    #===============================================================================
+    task = ecflow.Task("task")
+    task.add_trigger("t2 == active")
+    task.add_complete("t2 == complete")
+    
+    task_copy = copy.copy(task)
+    assert task_copy.get_complete(), "Expected complete"
+    assert task_copy.get_trigger(), "Expected trigger"
+    task_copy.delete_trigger();  assert not task_copy.get_trigger(), "Expected no trigger"
+    task_copy.delete_complete(); assert not task_copy.get_complete(), "Expected no complete"
+    
+    #===========================================================================
+    # Add triggers using expressions
+    #===========================================================================
+    expr = ecflow.Expression("t1 == complete")
+    task = ecflow.Task("task")
+    task.add_trigger(expr)
+    
+    task_copy = copy.copy(task)
+    assert task_copy.get_trigger(), "Expected trigger"
+
+    expr = ecflow.Expression("t1 == complete")
+    expr.add(ecflow.PartExpression("t1 == complete", True))
+    expr.add(ecflow.PartExpression("t2 == complete", True))
+    task = ecflow.Task("task")
+    task.add_trigger(expr)
+
+    task_copy = copy.copy(task)
+    assert task_copy.get_trigger(), "Expected trigger"
+
+     
+    #===========================================================================
+    # add,delete,find events
+    #===========================================================================
+    task.add_event(ecflow.Event(1)); 
+    task.add_event(2)                              
+    task.add_event(ecflow.Event(10, "Eventname"))  
+    task.add_event(10, "Eventname2")               
+    task.add_event("fred")                         
+    
+    # test find
+    task_copy = copy.copy(task)
+    event = task_copy.find_event("EVENT")
+    assert(event.empty()),"Expected to not find event"
+    assert(event.name() == ""),"Expected to not to find event, number is maximum int"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task_copy.find_event("1"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.number() == 1), "Expected to find event 1"
+    assert(event.name() == ""), "Expected name to be empty"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task_copy.find_event("2"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.number() == 2), "Expected to find event 1"
+    assert(event.name() == ""), "Expected name to be empty"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task_copy.find_event("10"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.number() == 10), "Expected to find event 10"
+    assert(event.name() == "Eventname"), "Expected name to be empty"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    event = task_copy.find_event("fred"); 
+    assert(not event.empty()),"Expected to find event"
+    assert(event.name() == "fred"), "Expected name to be empty, when name defind an not number, number is max_int"
+    assert(event.value() == 0),"Expected to not to find event"
+
+    for e in task_copy.events:     print(str(e)," # value: ",str(e.value()))
+    a_dict = {}
+    for e in task_copy.events:
+        if e.name() != "": a_dict[e.name()] = e.value()
+        else:              a_dict[e.number()] = e.value()
+    print(a_dict)
+
+    assert len(list(task_copy.events)) == 5, "Expected 5 Events"
+    task_copy.delete_event("1");         assert len(list(task_copy.events)) == 4, "Expected 4 Events"
+    task_copy.delete_event("Eventname"); assert len(list(task_copy.events)) == 3, "Expected 3 Events"
+    task_copy.delete_event("");          assert len(list(task_copy.events)) == 0, "Expected 0 Events"
+
+
+    #===========================================================================
+    # add and delete meter
+    #===========================================================================
+    task.add_meter(ecflow.Meter("metername1", 0, 100, 50))
+    task.add_meter(ecflow.Meter("metername2", 0, 100))
+    task.add_meter("metername3", 0, 100, 50)
+    task.add_meter("metername4", 0, 100)
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.meters)) == 4, "Expected 4 Meters"
+    task_copy.delete_meter("metername1"); assert len(list(task_copy.meters)) == 3, "Expected 3 Meters"
+    task_copy.delete_meter("metername4"); assert len(list(task_copy.meters)) == 2, "Expected 2 Meters"
+    task_copy.delete_meter("");           assert len(list(task_copy.meters)) == 0, "Expected 0 Meters"
+
+    #===========================================================================
+    # add and delete queue
+    #===========================================================================
+    queue_items = [ "a", "b"]
+    task.add_queue(ecflow.Queue("q1", queue_items ))
+    task.add_queue(ecflow.Queue("q2", queue_items))
+    task.add_queue("q3", [ "a", "b"])
+    task.add_queue("q4",  [ "a", "b"])
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.queues)) == 4, "Expected 4 queues"
+    task_copy.delete_queue("q1"); assert len(list(task_copy.queues)) == 3, "Expected 3 queues"
+    task_copy.delete_queue("q2"); assert len(list(task_copy.queues)) == 2, "Expected 2 queues"
+    task_copy.delete_queue("");   assert len(list(task_copy.queues)) == 0, "Expected 0 queues"
+
+    #===========================================================================
+    # copy generic
+    #===========================================================================
+    generic_items = [ "a", "b"]
+    task.add_generic(ecflow.Generic("q1",generic_items ))
+    task.add_generic(ecflow.Generic("q2",generic_items))
+    task.add_generic("q3", [ "a", "b"])
+    task.add_generic("q4",  [ "a", "b"])
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.generics)) == 4, "Expected 4  Generics after copy"
+    task_copy.delete_generic("q1"); assert len(list(task_copy.generics)) == 3, "Expected 3 Generics"
+    task_copy.delete_generic("q2"); assert len(list(task_copy.generics)) == 2, "Expected 2 Generics"
+    task_copy.delete_generic("");   assert len(list(task_copy.generics)) == 0, "Expected 0 Generics"
+
+    #===========================================================================
+    # add and delete label
+    #===========================================================================
+    task.add_label(ecflow.Label("label_name1", "value"))
+    task.add_label(ecflow.Label("label_name2", "value"))
+    task.add_label("label_name3", "value")
+    task.add_label("label_name4", "value")
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.labels)) == 4, "Expected 4 labels"
+    task_copy.delete_label("label_name1"); assert len(list(task_copy.labels)) == 3, "Expected 3 Labels"
+    task_copy.delete_label("label_name4"); assert len(list(task_copy.labels)) == 2, "Expected 2 Labels"
+    task_copy.delete_label("");            assert len(list(task_copy.labels)) == 0, "Expected 0 Labels"
+
+
+    #===========================================================================
+    # add delete Repeat
+    #===========================================================================
+    task = ecflow.Task("task")
+    task.add_repeat(ecflow.RepeatInteger("integer", 0, 100, 2))
+    task_copy = copy.copy(task)
+    repeat = task_copy.get_repeat(); assert not repeat.empty(), "Expected repeat"
+    task_copy.delete_repeat()      
+    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    task = ecflow.Task("task")
+    task.add_repeat(ecflow.RepeatEnumerated("enum", ["red", "green", "blue" ]))
+    task_copy = copy.copy(task)
+    task_copy.delete_repeat()      
+    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task = ecflow.Task("task")
+    task.add_repeat(ecflow.RepeatDate("date", 20100111, 20100115, 2))
+    task_copy = copy.copy(task)
+    task_copy.delete_repeat()      
+    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task = ecflow.Task("task")
+    task.add_repeat(ecflow.RepeatDateTime("datetime", "20100111T000000", "20100115T000000", "48:00:00"))
+    task_copy = copy.copy(task)
+    task_copy.delete_repeat()
+    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
+
+    task = ecflow.Task("task")
+    task.add_repeat(ecflow.RepeatDateList("date", [20100111, 20100115]))
+    task_copy = copy.copy(task)
+    task_copy.delete_repeat()      
+    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    task = ecflow.Task("task")
+    task.add_repeat(ecflow.RepeatString("string", ["a", "b", "c" ]))
+    task_copy = copy.copy(task)
+    task_copy.delete_repeat()      
+    repeat = task_copy.get_repeat(); assert repeat.empty(), "Expected no repeat"
+    
+    
+    #===========================================================================
+    # create a time series, used for adding time and today
+    #===========================================================================
+    start = ecflow.TimeSlot(0, 0)
+    finish = ecflow.TimeSlot(23, 0)
+    incr = ecflow.TimeSlot(0, 30)
+    time_series = ecflow.TimeSeries(start, finish, incr, True)
+
+    # Add and delete today
+    # NOTE: **********************************************************************
+    # Do *NOT* delete attributes using iterator traversal
+    # The iterators *are* bound to the c++ iterators hence if we delete
+    # over the traversal, we can corrupt the vector, leading to undefined behavour.  
+    # Hence we **cannot** delete more than once over a traversal
+    # Soln 1: take a copy
+    # *****************************************************************************
+    # task.add_today( Today( 0,10 ))
+    # task.add_today( Today( 0,59, True ))
+    # task.add_today( Today(TimeSlot(20,10)) )
+    # task.add_today( Today(TimeSlot(20,20),False)) 
+    # for today in task.todays: 
+    #    task.delete_today(today) # will corrupt C++ vector
+  
+    task.add_today("00:30")
+    task.add_today("+00:30")
+    task.add_today("+00:30 20:00 01:00")
+    task.add_today(ecflow.Today(time_series))
+    task.add_today(ecflow.Today(0, 10))
+    task.add_today(0, 59, True)
+    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 10)))
+    task.add_today(ecflow.Today(ecflow.TimeSlot(20, 20), False)) 
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.todays)) == 8, "Expected 8 todays"
+    vec_copy = []
+    for today in task_copy.todays: vec_copy.append(today)
+    for today in vec_copy: task_copy.delete_today(today)
+    assert len(list(task_copy.todays)) == 0, "Expected 0 todays"
+        
+    #===========================================================================
+    # add and delete time
+    #===========================================================================
+    task.add_time("00:30")
+    task.add_time("+00:30")
+    task.add_time("+00:30 20:00 01:00")
+    task.add_time(ecflow.Time(time_series))
+    task.add_time(ecflow.Time(0, 10))
+    task.add_time(0, 59, True)
+    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 10)))
+    task.add_time(ecflow.Time(ecflow.TimeSlot(20, 20), False)) 
+
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.times)) == 8, "Expected 8 times"
+    vec_copy = []
+    for time in task_copy.times: vec_copy.append(time)
+    for time in vec_copy: task_copy.delete_time(time)
+    assert len(list(task_copy.times)) == 0, "Expected 0 todays"
+
+    #===========================================================================
+    # add and delete date
+    #===========================================================================
+    for i in [ 1, 2, 4, 8, 16 ] :
+        task.add_date(i, 0, 0)
+    task.add_date(ecflow.Date(1, 1, 2010))
+    task.add_date(1, 1, 2010)       # duplicate
+    task.add_date(ecflow.Date(2, 1, 2010))
+    task.add_date(ecflow.Date(3, 1, 2010))
+    task.add_date(ecflow.Date(4, 1, 2010)) 
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.dates)) == 10, "Expected 10 dates but found " + str(len(list(task_copy.dates)))
+    vec_copy = []
+    for attr in task_copy.dates: vec_copy.append(attr)
+    for attr in vec_copy: task_copy.delete_date(attr)
+    assert len(list(task_copy.dates)) == 0, "Expected 0 dates"
+
+    #===========================================================================
+    # add and delete day
+    #===========================================================================
+    task.add_day(ecflow.Day(ecflow.Days.sunday))
+    task.add_day(ecflow.Days.monday)
+    task.add_day(ecflow.Days.tuesday)  # duplicate ?
+    task.add_day("sunday")     
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.days)) == 4, "Expected 4 days"
+    vec_copy = []
+    for attr in task_copy.days: vec_copy.append(attr)
+    for attr in vec_copy: task_copy.delete_day(attr)
+    assert len(list(task_copy.days)) == 0, "Expected 0 days"
+    
+    #===========================================================================
+    # add and delete crons
+    #===========================================================================
+    cron = ecflow.Cron()
+    start = ecflow.TimeSlot(23 , 0)
+    ts = ecflow.TimeSeries(start,True)  # True means relative to suite start
+    cron.set_time_series(ts)
+    
+    cron = ecflow.Cron()
+    cron.set_week_days([0, 1, 2, 3, 4, 5, 6])
+    cron.set_days_of_month([1, 2, 3, 4, 5, 6 ])
+    cron.set_months([1, 2, 3, 4, 5, 6])
+    start = ecflow.TimeSlot(0 , 0)
+    finish = ecflow.TimeSlot(23, 0)
+    incr = ecflow.TimeSlot(0, 30)
+    ts = ecflow.TimeSeries(start, finish, incr, True)  # True means relative to suite start
+    cron.set_time_series(ts)
+
+    cron0 = ecflow.Cron()
+    cron0.set_week_days([0, 1, 2, 3, 4, 5 ])
+    cron0.set_time_series(1, 30) # default relative = false, added in release 4.0.7
+
+    cron1 = ecflow.Cron()
+    cron1.set_week_days([0, 1, 2, 3, 4, 5, 6 ])
+    cron1.set_time_series(1, 30, True)
+    
+    cron2 = ecflow.Cron()
+    cron2.set_week_days([0, 1, 2, 3, 4, 5, 6])
+    cron2.set_time_series("00:30 01:30 00:01")
+    
+    cron3 = ecflow.Cron()
+    cron3.set_week_days([0, 1, 2, 3, 4, 5, 6])
+    cron3.set_time_series("+00:30")
+
+    task = ecflow.Task("task")
+    task.add_cron(cron)
+    task.add_cron(cron1)
+    task.add_cron(cron2)
+    task.add_cron(cron3)
+    
+    task_copy = copy.copy(task)
+    assert len(list(task_copy.crons)) == 4, "Expected 4 crons"
+    vec_copy = []
+    for attr in task_copy.crons: vec_copy.append(attr)
+    for attr in vec_copy: task_copy.delete_cron(attr)
+    assert len(list(task_copy.crons)) == 0, "Expected 0 crons"  
+    
+    #===========================================================================
+    # add autocancel
+    #===========================================================================
+    print("test add autoCancel")
+    t1 = ecflow.Task("t1")
+    assert t1.get_autocancel() is None, " Expected no autocancel"
+    t1.add_autocancel(3)  # 3 days
+    
+    task_copy = copy.copy(t1)
+    assert task_copy.get_autocancel() is not None, " Expected autocancel"
+    print(str(task_copy.get_autocancel()))
+
+    #===========================================================================
+    # add late  
+    #===========================================================================
+    late = ecflow.Late()
+    late.submitted(ecflow.TimeSlot(20, 10))
+    late.active(ecflow.TimeSlot(20, 10))
+    late.complete(ecflow.TimeSlot(20, 10), True)
+    task.add_late(late)
+    task_copy = copy.copy(task)
+    assert task_copy.get_late() is not None, " Expected late"
+    
+    #===========================================================================
+    # add defstatus, last one set takes effect
+    #===========================================================================
+    task.add_defstatus(ecflow.DState.complete)
+    task_copy = copy.copy(task)
+    assert task_copy.get_defstatus() == ecflow.DState.complete
+
+    #===========================================================================
+    # add clock
+    #===========================================================================
+    clock = ecflow.Clock(1, 1, 2010, False)     # day,month, year, hybrid
+    clock.set_gain(1, 10, True)                 # True means positive gain
+    suite = ecflow.Suite("suite")
+    assert suite.get_clock() is None, "Expected no clock"
+    suite.add_clock(clock)
+    
+    suite_copy = copy.copy(suite)
+    assert suite_copy.get_clock() is not None, "expected clock"
+    
+    #===========================================================================
+    # Add zombie. Note we can *NOT* add two zombie attributes of the same ZombieType
+    #===========================================================================
+    s1 = ecflow.Task("s1")
+    zombie_life_time_in_server = 800
+    child_list = [ ecflow.ChildCmdType.init, ecflow.ChildCmdType.event, ecflow.ChildCmdType.meter, ecflow.ChildCmdType.label, ecflow.ChildCmdType.wait, ecflow.ChildCmdType.abort, ecflow.ChildCmdType.complete ]
+    zombie_type_list = [ ecflow.ZombieType.ecf, ecflow.ZombieType.ecf_pid, ecflow.ZombieType.ecf_pid_passwd, ecflow.ZombieType.ecf_passwd, ecflow.ZombieType.user, ecflow.ZombieType.path ]
+    for zombie_type in zombie_type_list:
+        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block, zombie_life_time_in_server)
+        s1.add_zombie(zombie_attr)
+    task_copy = copy.copy(s1)
+    assert len(list(task_copy.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(task_copy.zombies)))
+    
+    # delete all the zombies
+    s1.delete_zombie("")
+    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
+    
+    # add with zombie_life_time_in_server not set, this is optional
+    for zombie_type in zombie_type_list:
+        zombie_attr = ecflow.ZombieAttr(zombie_type, child_list, ecflow.ZombieUserActionType.block)
+        s1.add_zombie(zombie_attr)
+    task_copy = copy.copy(s1)
+    assert len(list(task_copy.zombies)) == 6, "Expected 6 zombie attributes but found " + str(len(list(task_copy.zombies)))
+
+    s1.delete_zombie("")
+    assert len(list(s1.zombies)) == 0, "Expected zero zombie attributes but found " + str(len(list(s1.zombies)))
+
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestDefs.py 5.13.0-1/libs/pyext/test/py_u_TestDefs.py
--- 5.12.4-1/libs/pyext/test/py_u_TestDefs.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestDefs.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,241 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+#  code for testing creation of defs file in python
+import os
+import ecflow
+
+print(ecflow.__doc__)
+print(ecflow.Defs.__doc__)
+    
+from ecflow import Suite, Family, Task, Defs, Clock, DState, PartExpression, Variable, Limit, InLimit, \
+                   Date, Day, Event, Meter, Label, Autocancel, Days, TimeSlot, TimeSeries, Style, State, \
+                   RepeatString, RepeatDate, RepeatDateTime, RepeatInteger, RepeatDay, RepeatEnumerated, \
+                   Verify, PrintStyle, Time, Today, Late, Cron, Client, debug_build,Ecf
+import ecflow_test_util as Test
+
+if __name__ == "__main__":
+    
+    Test.print_test_start(os.path.basename(__file__))
+
+    suite = Suite("s1")
+    assert (isinstance(suite, ecflow.Suite)), "Expected suite"
+    assert (not isinstance(suite, ecflow.Family)), "Expected suite"
+    assert (not isinstance(suite, ecflow.Task)), "Expected suite"
+ 
+    family = Family("f1")
+    assert (isinstance(family, ecflow.Family)), "Expected Family"
+    assert (not isinstance(family, ecflow.Suite)), "Expected Family"
+    assert (not isinstance(family, ecflow.Task)), "Expected Family"
+    suite.add_family(family)
+
+    task = Task("f1")
+    assert (isinstance(task, ecflow.Task)), "Expected Task"
+    assert (not isinstance(task, ecflow.Suite)), "Expected Task"
+    assert (not isinstance(task, ecflow.Family)), "Expected Task"
+    family.add_task(task)
+
+    
+    defs = Defs()
+    defs2 = Defs()
+    assert defs == defs2, "Empty defs should be equal"
+ 
+    assert defs.get_state() == ecflow.State.unknown, "Expected default state to be unknown"
+    defs.add_suite(suite);  # add existing suite to defs
+ 
+    suite = defs.add_suite("s2");
+    suite.add_variable(Variable("ECF_HOME","/tmp/"))
+    suite.add_variable("ECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
+    suite.add_variable("ECF_URL_BASE","http://www.ecmwf.int")
+    suite.add_variable("ECF_URL","publications/manuals/sms")
+    suite.add_limit( Limit("limitName", 10) )
+    suite.add_limit( "limitName_2", 10 )
+    assert suite.begun() == False, "Suite should not have begun"
+
+    clock = Clock(1,1,2010,False);
+    clock.set_gain(1,10,True);
+    suite.add_clock(clock);
+
+    assert defs != defs2, "Defs should no longer compare as they are different"
+    
+    defs.add_extern("/path/to/task");
+    defs.add_extern("/fred/bill:event_name");
+    
+    family = suite.add_family("f1")
+    family.add_defstatus( DState.active );
+
+    task = family.add_task("t1")
+    task.add_trigger( "t2 == active" )
+    task.add_complete( "t2 == complete" )
+    task.add_autocancel( Autocancel(3) );
+
+    task2 = family.add_task("t2")
+    task2.add_defstatus(  DState.complete );
+    task2.add_part_trigger(  PartExpression("t1 == complete") )
+    task2.add_part_trigger(  PartExpression("t1 == active",True) )  #  for long and/or expressions, subsequent expr must be and/or
+    task2.add_part_complete( PartExpression("t1 == complete") )
+    task2.add_part_complete( PartExpression("t1 == active",False) )  #  for long and/or expressions, subsequent expr must be and/or
+    task2.add_label(      Label("labelname", "label1") )
+    task2.add_label(      "labelname2", "label1")
+    task2.add_inlimit(    InLimit("limitName","/s1/f1",2) )
+    task2.add_inlimit(    InLimit("limitName1","/s1/f1",2,True) )
+    task2.add_inlimit(    "limitName2" )
+    task2.add_inlimit(    "limitName3","path" )
+    task2.add_inlimit(    "limitName4","path",1 )
+    task2.add_inlimit(    "limitName5","path",1,True )
+    task2.add_event(      10 )
+    task2.add_event(      Event(10,"Eventname") )
+    task2.add_meter(      Meter("metername",0,100,50) )
+    task2.add_meter(      "metername2",0,100,50 )
+    task2.add_date(       Date(1,1,2010) )
+    task2.add_date(       1,2,2010 )
+    task2.add_day(        Day(Days.sunday) )
+    task2.add_day(        Days.monday )
+    task2.add_autocancel( Autocancel(TimeSlot(20,10),True) )
+
+    task2.add_today(      0,10 )
+    task2.add_today(      Today( 0,59, True ))
+    task2.add_today(      Today(TimeSlot(20,10)) )
+    task2.add_today(      Today(TimeSlot(20,20),False)) 
+    start = TimeSlot(0,0)
+    finish = TimeSlot(23,0)
+    incr = TimeSlot(0,30)
+    ts = TimeSeries( start, finish, incr, True);
+    task2.add_today(      Today(ts) )
+
+    task2.add_time(       20,10 )
+    task2.add_time(       Time(20,12,True) )
+    task2.add_time(       Time(TimeSlot(20,12))) 
+    task2.add_time(       Time(TimeSlot(20,20),True)) 
+    task2.add_time(       Time(ts) )
+    
+    late = Late()
+    late.submitted( 20,10 )
+    late.active(TimeSlot(20,10))
+    late.complete(TimeSlot(20,10),True)
+    task2.add_late(  late )
+        
+    cron = Cron()
+    cron.set_week_days( [0,1,2,3,4,5,6] )
+    cron.set_days_of_month(  [1,2,3,4,5,6] )
+    cron.set_months( [1,2,3,4,5,6] )
+    cron.set_time_series( ts )
+    task2.add_cron( cron );
+    
+    task3 = family.add_task("t3")
+    task3.add_repeat( RepeatDate("testDate",20100111,20100115,2) )
+    task3.add_defstatus( DState.queued );
+    task3.add_verify( Verify(State.complete, 1) )
+    task3.add_autocancel( Autocancel(20,10,False) )
+    task3.add_label( Label("label_name","label_value") )
+
+    task3_1 = family.add_task("t3_1")
+    task3_1.add_repeat( RepeatDate("testDate",20100111,20100115) )
+
+    task3_2 = family.add_task("t3_2")
+    task3_2.add_repeat(RepeatDateTime("testDateTime", "20100111T000000", "20100115T000000"))
+
+
+    task4 = family.add_task("t4")
+    task4.add_repeat( RepeatInteger("testInteger",0,100,2) )
+    task4.add_defstatus( DState.aborted );
+    
+    task4_1 = family.add_task("t4_1")
+    task4_1.add_repeat( RepeatInteger("testInteger",0,100) )
+ 
+    
+    task5 = family.add_task("t5")
+    task5.add_repeat( RepeatEnumerated("testInteger", ["red", "green", "blue" ] ) )
+    task5.add_defstatus( DState.submitted );
+        
+    task6 = family.add_task("t6")
+    task6.add_repeat( RepeatString("test_string",  ["a", "b", "c" ] ) )
+    task6.add_defstatus( DState.suspended );
+    
+    task7 = family.add_task("t7")
+    task7.add_repeat( RepeatDay(2) )
+    task7.add_defstatus( DState.active );
+    
+    task8 = family.add_task("t8")
+    task8.add_repeat( RepeatDay() )
+    print("task8.get_try_no()    :string:",task8.get_try_no())
+    print("task8.get_int_try_no():int   :",task8.get_int_try_no())
+    
+    the_defs = task8.get_defs()
+ 
+          
+    # Test find      
+    assert defs.find_suite("s1") is not None, "Expected to find suite of name s1"
+    assert defs.find_suite("sffff1") is None, "Should not be able to find suite of name sfffff1"
+        
+    # save the defs file as a check point file and restore it again
+    checkpt_file = "py_u_TestDefs.check"
+    defs_file = "py_u_TestDefs.def"
+    if debug_build() :
+        checkpt_file = "py_u_TestDefs_debug.check"
+        defs_file = "py_u_TestDefs_debug.def"
+    defs.save_as_checkpt(checkpt_file);
+    
+    restored_checkpt_defs = Defs()
+    restored_checkpt_defs.restore_from_checkpt(checkpt_file)
+    
+    print("Save and restore as Defs ******************************************************")
+    defs.save_as_defs(defs_file)           # default is to save as DEFS
+    restored_from_defs = Defs( defs_file ) # restore the defs
+
+    defs.save_as_defs(defs_file,Style.DEFS)
+    restored_from_defs = Defs( defs_file ) # restore the defs
+            
+    print("Save and restore using STATE ******************************************************")
+    defs.save_as_defs(defs_file,Style.STATE)
+    restored_from_defs = Defs( defs_file ) # restore the defs
+
+    print("Save and restore using MIGRATE ******************************************************")
+    defs.save_as_defs(defs_file,Style.MIGRATE)
+    restored_from_defs = Defs( defs_file ) # restore the defs
+    assert restored_checkpt_defs == restored_from_defs ,"File should be the same"
+
+        
+    print("Print in DEFS style ******************************************************")
+    PrintStyle.set_style(Style.DEFS)
+    the_string = str(restored_from_defs)
+    assert the_string.find("defs_state") == -1, "Print in DEFS style failed"
+    print(the_string)
+    
+    print("Print in STATE style *****************************************************")
+    PrintStyle.set_style(Style.STATE)
+    the_string = str(restored_from_defs)
+    assert the_string.find("defs_state STATE") != -1, "Print in STATE style failed"
+    print(the_string)
+    
+    print("Print in MIGRATE style *****************************************************")
+    PrintStyle.set_style(Style.MIGRATE)
+    the_string = str(restored_from_defs)
+    assert the_string.find("defs_state MIGRATE") != -1, "Print in MIGRATE style failed"
+    print(the_string)
+     
+    # Comment this out if you want to see what the file looked like
+    os.remove(checkpt_file)
+    os.remove(defs_file)
+    
+    # Test job creation failure
+    msg = defs.check_job_creation()
+    assert len(msg) != 0 ,"Expected job creation to fail"
+    
+    expected_exeption = False;
+    try:
+        defs.check_job_creation(throw_on_error=True) 
+    except RuntimeError as e:
+        expected_exeption = True
+    assert expected_exeption,"expected exception"  
+ 
+    print("All tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestDefsCheck.py 5.13.0-1/libs/pyext/test/py_u_TestDefsCheck.py
--- 5.12.4-1/libs/pyext/test/py_u_TestDefsCheck.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestDefsCheck.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,71 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+#  Test the error and waning checks defined in the defs work
+import os
+from ecflow import  Defs, Limit, InLimit, Client, debug_build
+import ecflow_test_util as Test
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+     
+    defs = Defs()
+    suite = defs.add_suite("s1");
+    suite.add_task("t1").add_trigger("t2 == active)")   
+    theCheckValue = defs.check();
+    print("Message: '" + theCheckValue + "'")
+    assert len(theCheckValue) != 0,  "Expected Error: triggers fail parse, miss-matched brackets in expression."
+ 
+    # The number of tokens specified on the in-limit must be less than or equal to those specified on the LIMIT
+    defs = Defs()
+    suite = defs.add_suite("s1");
+    suite.add_limit( Limit("disk", 50) );
+    family = suite.add_family("anon");
+    family.add_inlimit( InLimit("disk","/s1",100) )
+    family.add_task( "t1" );
+    theCheckValue = defs.check();
+    print("Message: '" + theCheckValue + "'")
+    assert len(theCheckValue) != 0,  "Expected Error: since inlimit value('100') is greater than the LIMIT value('50')"  
+
+
+    # When a path is specified on the in-limit we search for the limit on that path, otherwise the extern's
+    defs = Defs()
+    suite = defs.add_suite("s1");
+    family = suite.add_family("anon");
+    family.add_inlimit( InLimit("disk","/s1",100) )
+    family.add_task( "t1" );
+    theCheckValue = defs.check();
+    print("Message: '" + theCheckValue + "'")
+    assert len(theCheckValue) != 0,  "Expected warning: since inlimit PATH(/s1:disk) reference a limit('disk') that does not exist"  
+    
+    # Add as extern and repeat the check
+    defs.add_extern("/s1:disk")
+    assert len(defs.check()) == 0,  "Expected no warnings, since extern specified: "  + defs.check()
+
+
+    # When no path is specified on the in-limit, we search for the limit up the node tree, otherwise the extern's
+    defs = Defs()
+    suite = defs.add_suite("s1");
+    family = suite.add_family("anon");
+    family.add_inlimit( InLimit("disk","",100) )
+    family.add_task( "t1" );
+    theCheckValue = defs.check();
+    print("Message: '" + theCheckValue + "'")
+    assert len(theCheckValue) != 0,  "Expected warning: since inlimit SHOULD reference a limit('disk') somewhere UP parent hierarchy"  
+    
+    # Add as extern and repeat the check
+    defs.add_extern("disk")
+    assert len(defs.check()) == 0,  "Expected no warnings, since extern specified"  
+    
+    print("All Tests pass")
+    
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestDerivable.py 5.13.0-1/libs/pyext/test/py_u_TestDerivable.py
--- 5.12.4-1/libs/pyext/test/py_u_TestDerivable.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestDerivable.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+#  code for testing derivation works
+import os
+import sys
+import ecflow
+import ecflow_test_util as Test
+
+class MyDefs(ecflow.Defs): pass
+class MySuite(ecflow.Suite): pass
+class MyFamily(ecflow.Family): pass
+class MyTask(ecflow.Task): pass
+class MyClient(ecflow.Client): pass
+
+if sys.version_info[0] > 2:
+    class MySuite2(ecflow.Suite):
+        def __init__(self, name):
+            super().__init__(name)
+    
+    class MyFamily2(ecflow.Family):
+        def __init__(self, name):
+            super().__init__(name)
+    
+    class MyTask2(ecflow.Task):
+        def __init__(self, name):
+            super().__init__(name)
+
+    n = MySuite2('s')
+    print(n)
+
+    n = MyFamily2('f')
+    print(n)
+
+    n = MyTask2('t')
+    print(n)
+
+else:
+    print("Python2 ignoring derivation test")
+
+
+if __name__ == "__main__":
+    
+    Test.print_test_start(os.path.basename(__file__))
+    print("All tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestEcf.py 5.13.0-1/libs/pyext/test/py_u_TestEcf.py
--- 5.12.4-1/libs/pyext/test/py_u_TestEcf.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestEcf.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+#  code for testing creation of defs file in python
+import os
+import ecflow
+      
+from ecflow import Ecf, Client, debug_build
+
+if __name__ == "__main__":
+    print("####################################################################")
+    print("Running TestEcf, ecflow version " + Client().version() + " debug build(" + str(debug_build()) +")")
+    print("####################################################################")
+    
+    default_debug_level = Ecf.debug_level()
+    assert default_debug_level == 0, "Expected default debug level to be 0"
+    Ecf.set_debug_level(10)
+    assert  Ecf.debug_level() == 10, "Expected debug level to be 10"
+    Ecf.set_debug_level(0)
+    assert  Ecf.debug_level() == 0, "Expected debug level to be 0"
+
+
+    assert  Ecf.debug_equality() == False, "Expected  default for Ecf.debug_equality() == False "
+    Ecf.set_debug_equality(True)
+    assert  Ecf.debug_equality() == True, "Expected  debug_equality() == True "
+    Ecf.set_debug_equality(False)
+    assert  Ecf.debug_equality() == False, "Expected  Ecf.debug_equality() == False "
+
+    print("All tests pass")
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestError.py 5.13.0-1/libs/pyext/test/py_u_TestError.py
--- 5.12.4-1/libs/pyext/test/py_u_TestError.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestError.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,608 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+#  code for testing errors in creation of defs file in python
+
+import os
+from ecflow import Day, Date, Meter, Event, Queue, Clock, Variable, Label, Limit, InLimit, \
+                   RepeatDate, RepeatDateTime, RepeatEnumerated, RepeatInteger, RepeatString, \
+                   Task, Family, Suite, Defs, Client, debug_build, Trigger
+import ecflow_test_util as Test
+
+def check_day(day):
+    try:    
+        Day(day)
+        return True
+    except RuntimeError: 
+        return False
+
+def check_date(day,month,year):
+    try:    
+        Date(day,month,year)
+        return True
+    except IndexError: 
+        return False
+    
+def check_date_str(str_date):
+    try:    
+        Date( str_date)
+        return True
+    except IndexError: 
+        return False
+    except  RuntimeError: 
+        return False
+
+def check_meter(name,min_meter_value,max_meter_value,color_change):
+    try:    
+        Meter(name,min_meter_value,max_meter_value,color_change)
+        return True
+    except IndexError: 
+        return False
+    except RuntimeError: 
+        return False
+
+def check_queue(name,queue_items):
+    try:    
+        Queue(name, queue_items)
+        return True
+    except IndexError: 
+        return False
+    except RuntimeError: 
+        return False
+    
+def check_event_number_and_name(number,name):
+    try:    
+        Event(number,name)
+        return True
+    except: 
+        return False
+    
+def check_event(number):
+    try:    
+        Event(number)
+        return True
+    except RuntimeError: 
+        return False
+        
+def check_clock(day_of_month,month,year):
+    try:    
+        Clock(day_of_month,month,year)
+        return True
+    except IndexError: 
+        return False
+
+def check_variable(name,value):
+    try:    
+        Variable(name,value)
+        return True
+    except RuntimeError: 
+        return False
+    
+def check_label(name,value):
+    try:    
+        Label(name,value)
+        return True
+    except RuntimeError: 
+        return False
+    
+def check_limit(name,int_token):
+    try:    
+        Limit(name,int_token)
+        return True
+    except RuntimeError: 
+        return False
+    except TypeError: 
+        return False
+    
+def check_inlimit(name,path_to_node,int_token):
+    try:    
+        InLimit(name,path_to_node,int_token)
+        return True
+    except RuntimeError: 
+        return False
+    except TypeError: 
+        return False
+        
+def check_repeat_date(name, start, end, step):
+    try:    
+        RepeatDate(name,start,end,step)
+        return True
+    except RuntimeError: 
+        return False
+
+def check_repeat_datetime(name, start, end, step):
+    try:
+        RepeatDateTime(name,start,end,step)
+        return True
+    except RuntimeError:
+        return False
+
+def check_repeat_integer(name, start, end, step):
+    try:    
+        RepeatInteger(name,start,end,step)
+        return True
+    except RuntimeError: 
+        return False
+    except TypeError: 
+        return False
+
+def check_repeat_enumerated(name, list_of_strings):
+    try:    
+        RepeatEnumerated(name,list_of_strings)
+        return True
+    except RuntimeError: 
+        return False
+    except TypeError: 
+        return False
+ 
+def check_repeat_string(name, list_of_strings):
+    try:    
+        RepeatString(name,list_of_strings)
+        return True
+    except RuntimeError: 
+        return False
+    except TypeError: 
+        return False
+        
+def check_node_name(name):
+    try:
+        Task(name)
+        Family(name)
+        Suite(name)
+        return True;
+    except RuntimeError: 
+        return False
+  
+def check_defs(path_to_defs):
+    try:    
+        Defs(path_to_defs)
+        return True
+    except RuntimeError: 
+        return False
+          
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    # Names with leading '.' should not be allowed. Will interfere with triggers
+    # Empty names not allowed
+    # Spaces not allowed
+    invalid_names = [ ".", "", " ","   ",  "fred doc", "1 "]
+    
+    # Allow names with leading underscore
+    valid_names = [ "_", "__", "_._", "1.2", "fred.doc", "_.1"]
+    
+    assert check_day("monday"),            "Expected valid day"
+    assert check_day("tuesday"),           "Expected valid day"
+    assert check_day("wednesday"),         "Expected valid day"
+    assert check_day("thursday"),          "Expected valid day"
+    assert check_day("friday"),            "Expected valid day"
+    assert check_day("saturday"),          "Expected valid day"
+    assert check_day("sunday"),            "Expected valid day"
+    assert check_day("")        == False,  "Expected exeception"
+    assert check_day("sunday1") == False,  "Expected exeception"
+    assert check_day("2")       == False,  "Expected exeception"
+
+    assert check_date(0,1,2010),            "Expected valid date"
+    assert check_date(10,0,2010),           "Expected valid date"
+    assert check_date(10,1,0),              "Expected valid date"
+    assert check_date(0,0,0),               "Expected valid date"
+    assert check_date(40,1,2010) == False,  "Expected exception since day > 31"
+    assert check_date(-10,1,2010) == False, "Expected exception since day >= 0"
+    assert check_date(1,14,2010) == False,  "Expected exception since month > 12"
+    assert check_date(1,-1,2010) == False,  "Expected exception since month >= 0"
+    assert check_date(1,1,-2) == False,     "Expected exception since year >= 0"
+
+    assert check_date_str("*.1.2010"),            "Expected valid date"
+    assert check_date_str("10.*.2010"),           "Expected valid date"
+    assert check_date_str("10.1.*"),              "Expected valid date"
+    assert check_date_str("*.*.*"),               "Expected valid date"
+    assert check_date_str("40.1.2010") == False,  "Expected exception since day > 31"
+    assert check_date_str("-10.1.2010") == False, "Expected exception since day >= 0"
+    assert check_date_str("1.14.2010") == False,  "Expected exception since month > 12"
+    assert check_date_str("1.-1.2010") == False,  "Expected exception since month >= 0"
+    assert check_date_str("1.1.-2") == False,     "Expected exception since year >= 0"
+
+    # clock do not support wild carding hence we cant use 0 like in Date
+    assert check_clock(12,1,2010),           "Expected valid date"
+    assert check_clock(10,1,2010),           "Expected valid date"
+    assert check_clock(10,1,1400),           "Expected valid date"
+    assert check_clock(31,12,2010),          "Expected valid date"
+    assert check_clock(40,1,2010) == False,  "Expected exception since day > 31"
+    assert check_clock(-10,1,2010) == False, "Expected exception since day >= 0"
+    assert check_clock(1,14,2010) == False,  "Expected exception since month > 12"
+    assert check_clock(1,-1,2010) == False,  "Expected exception since month >= 0"
+    assert check_clock(1,1,-2) == False,     "Expected exception since year >= 0"
+
+    assert check_meter("m",0,100,100),             "Expected valid Meter"
+    assert check_meter("m",0,100,0),               "Expected valid Meter"
+    assert check_meter("m",200,100,100) == False,  "Expected exception since min > max"
+    assert check_meter("m",0,100,-20) == False,    "Expected exception since color_change should between min-max"
+    assert check_meter("m",0,100,200) == False,    "Expected exception since color_change should between min-max"
+    assert check_meter("",0,100,100) == False,     "Expected exception since no name specified"
+    assert check_meter(" ",0,100,100) == False,    "Expected Exception cannot have spaces for a name"
+
+    assert check_queue("m",["a"]),                 "Expected valid Queue"
+    assert check_queue("m",["a","b"]),             "Expected valid Queue"
+    assert check_queue("",["a","b"]) == False,     "Expected exception queue name is empty"
+    assert check_queue(" ",["a","b"]) == False,    "Expected Exception cannot have spaces for a name"
+    assert check_queue(".",["a","b"]) == False,    "Expected Exception cannot start name with a ."
+    assert check_queue("m",[]) == False,           "Expected Exception queue items list is empty"
+ 
+    assert check_event(1),                            "Expected valid Event"
+    assert check_event(2),                            "Expected valid Event"
+    assert check_event_number_and_name(2,"fred"),     "Expected valid Event"
+    assert check_event_number_and_name(2,2) == False, "Expected failure since the name is not a string"
+
+    assert check_repeat_date("m",20000101,20001201,200),          "Expected valid repeat"
+    assert check_repeat_date("m",20001201,20000101,200) == False, "Expected exception since end YMD > start YMD"
+    assert check_repeat_date("m",200001011,20001201,200)== False, "Expected Exception since start is invalid."
+    assert check_repeat_date("m",20000101,200012013,200)== False, "Expected Exception since send is invalid."
+    assert check_repeat_date("m",00000000,00000000,200)== False,  "Expected Exception since start/end are not valid dates is invalid."
+    assert check_repeat_date("",20000101,20001201,200)==False,    "Expected Exception since no name specified"
+    assert check_repeat_date(" ",20000101,20001201,200)==False,   "Expected Exception cannot have spaces for a name"
+    assert check_repeat_datetime("m", "20000101T000000", "20001201T000000", "4800:00:00"), "Expected valid repeat"
+    assert check_repeat_datetime("m", "20001201T000000", "20000101T000000", "4800:00:00") == False, "Expected exception since end YMD > start YMD"
+    assert check_repeat_datetime("m", "200001011T000000", "20001201T000000", "4800:00:00") == False, "Expected Exception since start is invalid."
+    assert check_repeat_datetime("m", "20000101T000000", "200012013T000000", "4800:00:00") == False, "Expected Exception since send is invalid."
+    assert check_repeat_datetime("m", "00000000T000000", "00000000T000000", "4800:00:00") == False, "Expected Exception since start/end are not valid dates is invalid."
+    assert check_repeat_datetime("", "20000101T000000", "20001201T000000", "4800:00:00") == False, "Expected Exception since no name specified"
+    assert check_repeat_datetime(" ", "20000101T000000", "20001201T000000", "4800:00:00") == False, "Expected Exception cannot have spaces for a name"
+    assert check_repeat_integer("name",0, 10, 2 ),                "Expected valid repeat"
+    assert check_repeat_integer("",0, 10, 2 )==False,             "Expected Exception since no name specified"
+    assert check_repeat_integer(" ",0, 10, 2 )==False,            "Expected Exception cannot have spaces for a name"
+    assert check_repeat_string("name",[ "a" ]),                   "Expected valid repeat"
+    assert check_repeat_string("",["a"] )==False,                 "Expected Exception since no name specified"
+    assert check_repeat_string(" ",["a"] )==False,                "Expected Exception cannot have spaces for a name"
+    assert check_repeat_string("name",[ 1,2 ])==False,            "Expected Exception since a list of strings was expected"
+    assert check_repeat_string("name",[])==False,                 "Expected Exception since list of strings is empty"
+    assert check_repeat_enumerated("name",[ "a" ]),               "Expected valid repeat"
+    assert check_repeat_enumerated("",["a"] )==False,             "Expected Exception since no name specified"
+    assert check_repeat_enumerated(" ",["a"] )==False,            "Expected Exception since no name specified"
+    assert check_repeat_enumerated("name",[ 1,2 ])==False,        "Expected Exception since a list of strings was expected"
+    assert check_repeat_enumerated("name",[])==False,             "Expected Exception since list is empty"
+
+
+    assert check_variable("name","value"),        "Expected valid Variable"
+    assert check_variable("name",""),             "Expected valid Variable"
+    assert check_variable("name"," "),            "Expected valid Variable"
+    assert check_variable("name","12"),           "Expected valid Variable"
+    assert check_variable("","12")==False,        "Expected Exception name must be specified"
+    assert check_variable(" ","12")==False,       "Expected Exception cannot have spaces for a name"
+
+    assert check_label("name","value"),        "Expected valid label"
+    assert check_label("name",""),             "Expected valid label"
+    assert check_label("name"," "),            "Expected valid label"
+    assert check_label("name","12"),           "Expected valid label"
+    assert check_label("","12")==False,        "Expected exception name must be specified"
+    assert check_label(" ","12")==False,       "Expected Exception cannot have spaces for a name"
+
+    assert check_limit("name",1),              "Expected valid limit"
+    assert check_limit("name",20000),          "Expected valid limit"
+    assert check_limit("name","ten")==False,   "Expected exception, token must be a integer"
+    assert check_limit("name","2")==False,     "Expected exception, token must be a integer"
+    assert check_limit("","2")==False,         "Expected exception, no name specified"
+    assert check_limit(" ","2")==False,        "Expected exception, cannot have spaces for a name"
+
+    assert check_inlimit("limit_name","/path/to/limit",1),      "Expected valid in limit"
+    assert check_inlimit("limit_name","/path/to/limit",999999), "Expected valid in limit"
+    assert check_inlimit("limit_name","",1),                    "Expected valid in limit"
+    assert check_inlimit("","",1)==False,                       "Expected exception, no limit name specified"
+    assert check_inlimit(" ","",1)==False,                      "Expected exception, cannot have spaces for a name"
+ 
+
+    # ========================================================================
+    print("Check node names")
+    for i in range(25):
+        assert check_node_name(str(i)),             "Integer names should be allowed"
+     
+    for name in valid_names:
+        assert check_node_name(name),  "Expected valid name " + name
+    
+    for name in invalid_names:
+        assert check_node_name(name)==False,  "Expected exception for invalid name " + name
+
+   
+    assert check_defs("a_made_up_path_that_doesnt_not_exit.def") == False, "Expected exception, Defs file does not exist"
+
+    # =================================================================================
+    print("test save_as_defs")
+    defs = Defs()                      # create a empty definition
+    s1 = defs.add_suite("s1")          # create a suite "s1" and add to defs
+    defs.save_as_defs("testerror.def") # create a defs on disk
+    assert check_defs("testerror.def"), "Expected defs file to exist"
+    os.remove("testerror.def")
+
+    # =================================================================================
+    print("Check duplicate suites not allowed")
+    test_passed = False
+    try :
+        defs = Defs()               # create a empty definition
+        s1 = defs.add_suite("s1")   # create a suite "s1" and add to defs
+        s2 = defs.add_suite("s1")   # Exception thrown trying to add suite name "s1" again
+    except RuntimeError as e : 
+        test_passed = True
+        pass 
+    assert test_passed,"duplicate suite test failed"   
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_today("00:30")
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding today at the suite level should fail"   
+    print("check adding today at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_time("00:30")
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding time at the suite level should fail"    
+    print("check adding time at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_date(1,1,2016)
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding date at the suite level should fail"    
+    print("check adding date at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_day("monday")
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding day at the suite level should fail"    
+    print("check adding day at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_trigger("1 == 0")
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding a trigger at suite level should fail"    
+    print("check adding trigger at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_part_trigger("1 == 0")
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding a part trigger at suite level should fail"    
+    print("check adding part trigger at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_complete("1 == 0")
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding a complete trigger at suite level should fail"    
+    print("check adding complete trigger at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    test_passed = False
+    try:
+        defs = Defs()
+        defs.add_suite("1").add_part_complete("1 == 0")
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Adding a part complete trigger at suite level should fail"    
+    print("check adding part complete trigger at the suite level: RuntimeError: ")
+
+    # =================================================================================
+    print("check adding trigger referencing parent should fail ECFLOW-1436")
+    defs = Defs()
+    defs += Suite("obs") + Family("anon", Task("t1", Trigger("anon == complete")))
+    assert len(defs.check()) > 0,"Adding a trigger referencing a parent without .. should fail"    
+
+
+    # =================================================================================
+    print("check duplicate family not allowed")
+    test_passed = False
+    try:
+        suite = Suite("1")
+        fam1 = Family("1")
+        fam2 = Family("1")
+        suite.add_family(fam1)
+        suite.add_family(fam2)
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"duplicate Family test failed"   
+  
+    # =================================================================================
+    print("duplicate task not allowed")
+    test_passed = False
+    try:
+        suite = Suite("1")
+        ta = Task("a")
+        tb = Task("a")
+        suite.add_task(ta)
+        suite.add_task(tb)
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"duplicate Task test failed"   
+
+    # =================================================================================
+    print("Task and family of same name should not be allowed")
+    test_passed = False
+    try:
+        suite = Suite("1")
+        ta = Task("a")
+        tb = Family("a")
+        suite.add_task(ta)
+        suite.add_family(tb)
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"Task and family of same name should not be allowed"   
+
+    # =================================================================================
+    print("check duplicate meter not allowed")
+    test_passed = False
+    try:
+        defs = Defs()
+        suite = defs.add_suite("1")
+        ta = suite.add_task("a")
+        ta.add_meter("meter",0,100);
+        ta.add_meter("meter",0,100);
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"duplicate meter test failed"   
+
+    # =================================================================================
+    print("check duplicate queue not allowed")
+    test_passed = False
+    try:
+        defs = Defs()
+        suite = defs.add_suite("1")
+        suite.add_queue("q",["a"]);
+        suite.add_queue("q",["a","b"]);
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"duplicate queue test failed"   
+
+    # =================================================================================
+    print("check duplicate event not allowed")
+    test_passed = False
+    try:
+        defs = Defs()
+        suite = defs.add_suite("1")
+        ta = suite.add_task("a")
+        ta.add_event(1);
+        ta.add_event("1");
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"duplicate event test failed"   
+    
+    test_passed = False
+    try:
+        defs = Defs()
+        suite = defs.add_suite("1")
+        ta = suite.add_task("a")
+        ta.add_event("name");
+        ta.add_event("name");
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"duplicate event test failed"   
+    
+    test_passed = False
+    try:
+        defs = Defs()
+        suite = defs.add_suite("1")
+        ta = suite.add_task("a")
+        ta.add_event(1,"name");
+        ta.add_event(1,"name");
+    except RuntimeError as e : 
+        test_passed = True
+        pass
+    assert test_passed,"duplicate event test failed"   
+    
+    
+    # =================================================================================
+    print("check cannot add same node to different containers")
+    defs1 = Defs();
+    suite = defs1.add_suite("s1")
+    family =  suite.add_family("f1")
+    task  = family.add_task("t1")
+    
+    test_passed = False
+    try :
+        defs2 = Defs();
+        defs2.add_suite(suite)
+    except RuntimeError as e : 
+        test_passed = True
+        pass    
+    assert test_passed,"Can't add same suite to two different defs"   
+
+    test_passed = False
+    try :
+        defs3 = Defs();
+        suite = defs3.add_suite(suite)
+        suite.add_family(family)
+    except RuntimeError as e : 
+        test_passed = True
+        pass    
+    assert test_passed,"Can't add same family to two different suites"   
+
+    test_passed = False
+    try :
+        defs4 = Defs();
+        suite = defs4.add_suite("s1")
+        suite.add_task(task)
+    except RuntimeError as e : 
+        test_passed = True
+        pass    
+    assert test_passed,"Can't add same task to two different containers"   
+
+    test_passed = False
+    try :
+        defs4 = Defs();
+        suite = defs4.add_suite("s1")
+        suite.add_autocancel(3)
+        suite.add_autocancel(4)
+    except RuntimeError as e : 
+        test_passed = True
+        pass    
+    assert test_passed,"Can't add two autocancel on same node" 
+    
+    test_passed = False
+    try :
+        defs4 = Defs();
+        suite = defs4.add_suite("s1")
+        suite.add_autoarchive(3)
+        suite.add_autocancel(4)
+    except RuntimeError as e : 
+        test_passed = True
+        pass    
+    assert test_passed,"Can't add autocancel and autoarchive on same node"  
+    
+    test_passed = False
+    try :
+        defs4 = Defs();
+        suite = defs4.add_suite("s1")
+        suite.add_autorestore(["/s1"])
+        suite.add_autorestore(["/s1"])
+    except RuntimeError as e : 
+        test_passed = True
+        pass    
+    assert test_passed,"Can't add two autorestore on same node"  
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestFind.py 5.13.0-1/libs/pyext/test/py_u_TestFind.py
--- 5.12.4-1/libs/pyext/test/py_u_TestFind.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestFind.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,162 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+#  code for testing pointers and hierarchy in python
+
+from ecflow import Suite, Family, Task, Defs, Client, debug_build, Edit
+import ecflow_test_util as Test
+import os
+
+def create_defs(name=""):
+    suite_name = name
+    if len(suite_name) == 0: suite_name = "s1"
+    defs =  Defs(Edit(FRED_2="XX",DEFS_VAR="0"),
+                Suite(suite_name, Edit(SUITE_VAR="1",FRED_1="%FRED_2%"),
+                    Family("f1",Edit(FRED_0="%FRED_1%"),
+                          Task("f1_t1", Edit(TASK_VAR="3",FRED="%FRED_0%")),
+                          Task("f1_t2", Edit(TASK_VAR="3",FRED="%FRED_0%"))
+                    ),
+                    Family("f2",Edit(FRED_0="%FRED_1%"),
+                          Task("f2_t1", Edit(TASK_VAR="3",FRED="%FRED_0%")),
+                          Task("f2_t2", Edit(TASK_VAR="3",FRED="%FRED_0%"))
+                    )
+                )
+            )
+    return defs;
+
+def test_ecflow_1213(defs):
+    s1 = defs.find_node_path("suite","s1")
+    assert s1 == "/s1"," expected to find suite s1"
+
+    f1 = defs.find_node_path("family","f1")
+    assert f1 == "/s1/f1"," expected to find family f1"
+  
+    f2 = defs.find_node_path("family","f2")
+    assert f2 == "/s1/f2"," expected to find family f2"
+
+    f1_t1 = defs.find_node_path("task","f1_t1")
+    f1_t2 = defs.find_node_path("task","f1_t2")
+    assert f1_t1 == "/s1/f1/f1_t1"," expected to find task f1_t1"
+    assert f1_t2 == "/s1/f1/f1_t2"," expected to find task f1_t2"
+    
+    f2_t1 = defs.find_node_path("task","f2_t1") 
+    f2_t2 = defs.find_node_path("task","f2_t2")
+    assert f2_t1 == "/s1/f2/f2_t1"," expected to find task f2_t1"
+    assert f2_t2 == "/s1/f2/f2_t2"," expected to find task f2_t2"
+    
+    # find_node
+    s1 = defs.find_node("suite","/s1")
+    assert s1 is not None and isinstance(s1, Suite), "expected find find suite s1"
+    
+    f1 = defs.find_node("family","/s1/f1")
+    assert f1 is not None and isinstance(f1, Family)," expected to find family f1"
+  
+    f2 = defs.find_node("family","/s1/f2")
+    assert f2 is not None and isinstance(f2, Family)," expected to find family f2"
+
+    f1_t1 = defs.find_node("task","/s1/f1/f1_t1")
+    f1_t2 = defs.find_node("task","/s1/f1/f1_t2")
+    assert f1_t1 is not None and isinstance(f1_t1, Task)," expected to find task f1_t1"
+    assert f1_t2 is not None and isinstance(f1_t2, Task)," expected to find task f1_t2"
+    
+    f2_t1 = defs.find_node("task","/s1/f2/f2_t1")
+    f2_t2 = defs.find_node("task","/s1/f2/f2_t2")
+    assert f2_t1 is not None and isinstance(f2_t1, Task)," expected to find task f2_t1"
+    assert f2_t2 is not None and isinstance(f2_t1, Task)," expected to find task f2_t2"
+
+
+if __name__ == "__main__":   
+    
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    defs = create_defs()
+    
+    test_ecflow_1213(defs)
+    
+    s1 = defs.find_suite("s1")
+    assert s1 is not None, "expected find find suite s1"
+    assert "s1" in defs, "expected find find suite s1"
+
+    sx = defs.find_suite("sx")
+    assert sx is None, "expected not to find suite sx"
+    
+    f1 = s1.find_family("f1")
+    assert f1 is not None, "expected find find family f1"
+    f1 = s1.find_node("f1")
+    assert f1 is not None, "expected find find family f1"
+
+    fx = s1.find_family("fx")
+    assert fx is None, "expected not to find family fx"
+    fx = s1.find_node("fx")
+    assert fx is None, "expected not to find family fx"
+
+    f2 = s1.find_family("f2")
+    assert f2 is not None, "expected find find family f2"
+    f2 = s1.find_node("f2")
+    assert f2 is not None, "expected find find family f2"
+    
+    f2_t1 = f2.find_task("f2_t1")
+    assert f2_t1 is not None, "Expected to find task"
+
+    f2_t2 = f2.find_task("f2_t2")
+    assert f2_t2 is not None, "Expected to find task"
+    f2_t2 = f2.find_node("f2_t2")
+    assert f2_t2 is not None, "Expected to find task"
+
+    f2_tx = f2.find_task("f2_tx")
+    assert f2_tx is None, "Expected not to find task"
+    f2_tx = f2.find_node("f2_tx")
+    assert f2_tx is None, "Expected not to find task"
+
+    tasks = defs.get_all_tasks()
+    assert len(tasks) == 4, "Expected four tasks, but found " + str(len(tasks))
+    for task in tasks:
+        # test find variable
+        var = task.find_parent_variable("TASK_VAR")
+        assert not var.empty()
+        assert var.value() == "3"
+        
+        var = task.find_parent_variable_sub_value("FRED")
+        assert var == "XX"
+
+        var = task.find_parent_variable_sub_value("ZZZZ")
+        assert var == ""
+
+        var = task.find_variable("TASK_VAR")
+        assert not var.empty()
+        assert var.value() == "3"
+        
+        var = task.find_parent_variable("SUITE_VAR");
+        assert not var.empty()
+        assert var.value() == "1"
+         
+        var = task.find_parent_variable("DEFS_VAR")
+        assert not var.empty()
+        assert var.value() == "0"
+
+        var = task.find_parent_variable("MADE_UP_VAR")
+        assert var.empty()
+
+        if task.name() == "f1_t1":
+            node = task.find_node_up_the_tree("f1")
+            assert node is not None
+            assert node.get_abs_node_path() == "/s1/f1"
+            
+            node = task.find_node_up_the_tree("s1")
+            assert node is not None
+            assert node.get_abs_node_path() == "/s1"
+
+            node = task.find_node_up_the_tree("freddd")
+            assert node is None
+            
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestFlag.py 5.13.0-1/libs/pyext/test/py_u_TestFlag.py
--- 5.12.4-1/libs/pyext/test/py_u_TestFlag.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestFlag.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import ecflow
+import sys
+import os
+import ecflow_test_util as Test
+
+if __name__ == "__main__":
+
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    flag = ecflow.Flag()
+    assert str(flag) == "", "expected empty string, for an empty flag"
+         
+    flag_list =  flag.list() # flag_list is of type FlagTypeVec
+    my_flag_list = [ ecflow.FlagType.force_abort,
+                     ecflow.FlagType.user_edit,
+                     ecflow.FlagType.task_aborted,
+                     ecflow.FlagType.edit_failed,
+                     ecflow.FlagType.jobcmd_failed,
+                     ecflow.FlagType.killcmd_failed,
+                     ecflow.FlagType.statuscmd_failed,
+                     ecflow.FlagType.no_script,
+                     ecflow.FlagType.killed,
+                     ecflow.FlagType.status,
+                     ecflow.FlagType.late,
+                     ecflow.FlagType.message,
+                     ecflow.FlagType.byrule,
+                     ecflow.FlagType.queuelimit,
+                     ecflow.FlagType.wait,
+                     ecflow.FlagType.locked,
+                     ecflow.FlagType.zombie,
+                     ecflow.FlagType.no_reque,
+                     ecflow.FlagType.archived,
+                     ecflow.FlagType.restored,
+                     ecflow.FlagType.threshold,
+                     ecflow.FlagType.sigterm,
+                     ecflow.FlagType.log_error,
+                     ecflow.FlagType.checkpt_error,
+                     ecflow.FlagType.remote_error
+                    ]
+    print("Flag list:")
+    for flg in flag_list: print("flag ",flag.type_to_string(flg))
+    print("My   list:")
+    for flg in my_flag_list: print("flag ",flag.type_to_string(flg))
+
+    assert len(flag_list) == len(my_flag_list), "expected flag list have changed"
+    expected_flags = "force_aborted,user_edit,task_aborted,edit_failed,ecfcmd_failed,killcmd_failed,statuscmd_failed" \
+                     ",no_script,killed,status,late,message,by_rule,queue_limit,task_waiting,locked,zombie,no_reque" \
+                     ",archived,restored,threshold,sigterm,log_error,checkpt_error,remote_error";
+
+    #Set *ALL* the flags
+    for flg in flag_list:
+       flag.set( flg )
+       assert flag.is_set( flg ),"expected flag %r to be set" % flag.type_to_string(flg)
+    
+    # clear *ALL* the flags
+    assert str(flag) == expected_flags, "Expected flags \n{0}\nbut found \n{1}".format(str(flag),expected_flags)
+    for flg in flag_list:
+        flag.clear(flg)
+        assert not flag.is_set( flg ),"expected flag {0} not to be set".format(flag.type_to_string(flg))
+
+    # test reset
+    for flg in flag_list:
+       flag.set( flg )
+    flag.reset()
+    for flg in flag_list:
+        assert not flag.is_set( flg ),"expected flag %r not to be set" % flag.type_to_string(flg)
+        
+    #===========================================================================
+    # Setting flag type
+    #===========================================================================
+    for flg in my_flag_list:
+        flag.set( flg )
+        print("current flag:",flag)
+        assert flag.is_set( flg ),"expected flag %r to be set" % flag.type_to_string(flg)
+
+    #===========================================================================
+    # Node:  get the flag, should be empty for a newly created node.
+    #===========================================================================
+    suite = ecflow.Suite("s1")
+    flag = suite.get_flag()
+    for flg in flag_list:
+        assert not flag.is_set( flg ),"expected flag %r not to be set" % flag.type_to_string(flg)
+    assert str(flag) == "", "expected empty string, for an empty flag"
+    
+    #assert False
+    print("All tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestGeneratedVariable.py 5.13.0-1/libs/pyext/test/py_u_TestGeneratedVariable.py
--- 5.12.4-1/libs/pyext/test/py_u_TestGeneratedVariable.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestGeneratedVariable.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# code for testing  generated variables
+
+import os
+import ecflow
+import ecflow_test_util as Test
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+     
+    #===========================================================================
+    print("Defs: test generated variables")
+    #===========================================================================
+    defs = ecflow.Defs()
+    suite = defs.add_suite("s1")
+    family = suite.add_family("f1")
+    task = family.add_task("t1")
+
+    print("\nsuite generated variables, Most of date related suite generated variables will only have values after the suite has begun")
+    variable_list = ecflow.VariableList()
+    suite.get_generated_variables(variable_list)
+    for gen_var in variable_list:
+        print(gen_var)
+        gen_var = suite.find_gen_variable(gen_var.name())
+        assert not gen_var.empty(), "Could not find suite generated variable " + gen_var
+    assert len(list(variable_list)) == 14,"Expected 14 generated variables for suites"    
+    assert variable_list[0].name() == "SUITE", "expected generated variable of name SUITE but found " + variable_list[0].name()
+    assert variable_list[0].value() == "s1", "expected generated variable of value 's1' but found " + variable_list[0].value()
+
+
+    print("\nfamily generated variables")
+    variable_list = ecflow.VariableList()
+    family.get_generated_variables(variable_list)
+    for gen_var in variable_list:
+        print(gen_var)
+        gen_var = family.find_gen_variable(gen_var.name())
+        assert not gen_var.empty(), "Could not find family generated variable " + gen_var
+
+    assert len(list(variable_list)) == 2,"Expected 2 generated variables for families"    
+    assert variable_list[0].name() == "FAMILY", "expected generated variable of name FAMILY but found " + variable_list[0].name()
+    assert variable_list[0].value() == "f1", "expected generated variable of value 'f1' but found " + variable_list[0].value()
+    assert variable_list[1].name() == "FAMILY1", "expected generated variable of name FAMILY1 but found " + variable_list[1].name()
+    assert variable_list[1].value() == "f1", "expected generated variable of value 'f1' but found " + variable_list[1].value()
+
+    print("\ntask generated variables")
+    variable_list = ecflow.VariableList()
+    task.get_generated_variables(variable_list)
+    for gen_var in variable_list:
+        print(gen_var)
+        gen_var = task.find_gen_variable(gen_var.name())
+        assert not gen_var.empty(), "Could not find task generated variable " + gen_var
+
+    assert len(list(variable_list)) == 8,"Expected 8 generated variables for tasks"    
+    assert variable_list[0].name() == "TASK", "expected generated variable of name TASK but found " + variable_list[0].name()
+    assert variable_list[0].value() == "t1", "expected generated variable of value 't1' but found " + variable_list[0].value()
+    assert variable_list[1].name() == "ECF_JOB", "expected generated variable of name ECF_JOB but found " + variable_list[1].name()
+    assert variable_list[1].value() == "./s1/f1/t1.job0", "expected generated variable of value './s1/f1/t1.job0' but found " + variable_list[1].value()
+    assert variable_list[2].name() == "ECF_SCRIPT", "expected generated variable of name ECF_SCRIPT but found " + variable_list[2].name()
+    assert variable_list[2].value() == "./s1/f1/t1.ecf", "expected generated variable of value './s1/f1/t1.ecf' but found " + variable_list[2].value()
+    assert variable_list[3].name() == "ECF_JOBOUT", "expected generated variable of name ECF_JOBOUT but found " + variable_list[3].name()
+    assert variable_list[3].value() == "./s1/f1/t1.0", "expected generated variable of value './s1/f1/t1.0' but found " + variable_list[3].value()
+    assert variable_list[4].name() == "ECF_TRYNO", "expected generated variable of name ECF_TRYNO but found " + variable_list[4].name()
+    assert variable_list[4].value() == "0", "expected generated variable of value '0' but found " + variable_list[4].value()
+    assert variable_list[5].name() == "ECF_RID", "expected generated variable of name ECF_RID but found " + variable_list[5].name()
+    assert variable_list[5].value() == "", "expected generated variable of value '' but found " + variable_list[5].value()
+    assert variable_list[6].name() == "ECF_NAME", "expected generated variable of name ECF_NAME but found " + variable_list[6].name()
+    assert variable_list[6].value() == "/s1/f1/t1", "expected generated variable of value '/s1/f1/t1' but found " + variable_list[6].value()
+    assert variable_list[7].name() == "ECF_PASS", "expected generated variable of name ECF_NAME but found " + variable_list[7].name()
+    assert variable_list[7].value() == "", "expected generated variable of value '' but found " + variable_list[7].value()
+
+    print("\nAll Tests pass")
+    
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestGetAllTasks.py 5.13.0-1/libs/pyext/test/py_u_TestGetAllTasks.py
--- 5.12.4-1/libs/pyext/test/py_u_TestGetAllTasks.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestGetAllTasks.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,103 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# Simple check for get all tasks
+from ecflow import Defs, Client, debug_build
+import ecflow_test_util as Test
+import os
+
+def create_defs():
+    defs = Defs()
+    suite = defs.add_suite("test_get_all")
+    suite.add_task("t0")
+    fam = suite.add_family("f1")
+    fam.add_task("t1") 
+    fam.add_task("t2") 
+    fam2 = fam.add_family("f2")
+    fam2.add_task("t3") 
+    return defs
+   
+def test_get_all_tasks(defs):
+  
+    task_vec2 = defs.get_all_tasks()
+    assert len(task_vec2) == 4, "Expected four tasks, but found " + str(len(task_vec2))
+   
+    assert task_vec2[0].name() == "t0", "Expected task of name t0 but found " + task_vec2[0].name()
+    assert task_vec2[1].name() == "t1", "Expected task of name t1 but found " + task_vec2[1].name()
+    assert task_vec2[2].name() == "t2", "Expected task of name t2 but found " + task_vec2[2].name()
+    assert task_vec2[3].name() == "t3", "Expected task of name t3 but found " + task_vec2[3].name()
+   
+    print("test_get_all_tasks PASSED")
+   
+def test_get_all_nodes(defs):
+    
+    # Get all the nodes make sure they are in order
+    node_vec = defs.get_all_nodes()
+    assert len(node_vec) == 7, "Expected seven nodes, but found " + str(len(node_vec))
+    assert node_vec[0].name() == "test_get_all", "Nodes should be returned in order, expected test_get_all but found" + node_vec[0].name()
+    assert node_vec[1].name() == "t0", "Nodes should be returned in order, expected 't0' but found" + node_vec[1].name()
+    assert node_vec[2].name() == "f1", "Nodes should be returned in order, expected 'f1' but found" + node_vec[2].name()
+    assert node_vec[3].name() == "t1", "Nodes should be returned in order, expected 't1' but found" + node_vec[3].name()
+    assert node_vec[4].name() == "t2", "Nodes should be returned in order, expected 't2' but found" + node_vec[4].name()
+    assert node_vec[5].name() == "f2", "Nodes should be returned in order, expected 'f2' but found" + node_vec[5].name()
+    assert node_vec[6].name() == "t3", "Nodes should be returned in order, expected 't3' but found" + node_vec[6].name()
+
+    # test empty defs
+    empty_defs = Defs()
+    node_vec = empty_defs.get_all_nodes()
+    assert len(node_vec) == 0, "Expected zero nodes, for an empty defs but found " + str(len(node_vec))
+
+    # test one suite defs
+    one_suite_defs = Defs()
+    one_suite_defs.add_suite("s1")
+    node_vec = one_suite_defs.get_all_nodes()
+    assert len(node_vec) == 1, "Expected one node, but found " + str(len(node_vec))
+
+    print("test_get_all_nodes PASSED")
+    
+def test_get_all_nodes_from_nodes():
+    defs = Defs()
+    suite = defs.add_suite("test_get_all")
+    node_vec = suite.get_all_nodes()
+    assert len(node_vec) == 1, "Expected one nodes but found " + str(len(node_vec))
+
+    fam1 = suite.add_family("f1")
+    fam2 = suite.add_family("f2")
+    fam3 = suite.add_family("f3")
+    node_vec = suite.get_all_nodes()
+    assert len(node_vec) == 4, "Expected 4 nodes but found " + str(len(node_vec))
+
+    node_vec = fam1.get_all_nodes()
+    assert len(node_vec) == 1, "Expected 1 nodes but found " + str(len(node_vec))
+
+    f1_t1 = fam1.add_task("t1") 
+    f1_t2 = fam1.add_task("t2") 
+    node_vec = fam1.get_all_nodes()
+    assert len(node_vec) == 3, "Expected 3 nodes but found " + str(len(node_vec))
+
+    node_vec = f1_t1.get_all_nodes()
+    assert len(node_vec) == 1, "Expected 1 nodes but found " + str(len(node_vec))
+
+    node_vec = suite.get_all_nodes()
+    assert len(node_vec) == 6, "Expected 6 nodes but found " + str(len(node_vec))
+
+    print("test_get_all_nodes_from_nodes PASSED")
+   
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    test_get_all_tasks(create_defs())
+    test_get_all_nodes(create_defs())
+    test_get_all_nodes_from_nodes()
+    print("All Tests pass")    
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestJobGeneration.py 5.13.0-1/libs/pyext/test/py_u_TestJobGeneration.py
--- 5.12.4-1/libs/pyext/test/py_u_TestJobGeneration.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestJobGeneration.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,156 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# This code is used check job generation
+#
+import os
+import shutil   # used to remove directory tree
+
+import ecflow_test_util as Test
+from ecflow import Defs, JobCreationCtrl, TaskVec, File, Client, debug_build
+
+def ecf_includes() : return File.source_dir() + "/libs/pyext/test/data/includes"
+
+def suite_name(): return "suite_job_gen_" + str(os.getpid())  # allow python2 and python3 to run in parallel
+
+def create_defs(ecf_home,task_vec):
+    defs = Defs();
+    suite = defs.add_suite( suite_name() );
+    suite.add_variable("ECF_HOME",ecf_home);
+    suite.add_variable("ECF_CLIENT_EXE_PATH",File.find_client());
+    suite.add_variable("SLEEPTIME","1");
+    suite.add_variable("ECF_INCLUDE",ecf_includes());
+    
+    fam =  suite.add_family("family")
+    t1 = fam.add_task("t1")
+    t1.add_event("eventname");
+    t1.add_meter("meter",0,100,100)
+    
+    t2 = fam.add_task("t2")
+    t3 = fam.add_task("t3")
+    t4 = fam.add_task("dummy_task")
+    t4.add_variable("ECF_DUMMY_TASK","any"); # stop job generation errors for tasks without an .ecf
+    task_vec.append(t1);
+    task_vec.append(t2);
+    task_vec.append(t3);
+    task_vec.append(t4);
+    
+    # Create dir. **NOTE**, if the second component of os.path.joind(..) is absolute, 
+    # the first path is ignored, hence remove first char
+    dir_to_create = os.path.join(str(ecf_home),fam.get_abs_node_path()[1:])
+    print("Creating dir ",dir_to_create)
+    os.makedirs( dir_to_create  )
+     
+    # copy ecf files from ecflow source, to create unique file per process
+    src_t1  = os.path.join(ecf_home, "suite_job_gen" , "family" , "t1.ecf")
+    dest_t1 = os.path.join(ecf_home,  t1.get_abs_node_path()[1:] + ".ecf" )
+    src_t2  = os.path.join(ecf_home, "suite_job_gen" , "family" , "t2.ecf")
+    dest_t2 = os.path.join(ecf_home,  t2.get_abs_node_path()[1:] + ".ecf" )
+    src_t3  = os.path.join(ecf_home, "suite_job_gen" , "family" , "t3.ecf")
+    dest_t3 = os.path.join(ecf_home,  t3.get_abs_node_path()[1:] + ".ecf" )
+ 
+    shutil.copy(src_t1, dest_t1)
+    shutil.copy(src_t2, dest_t2)
+    shutil.copy(src_t3, dest_t3)
+    
+    return defs
+
+
+def delete_jobs(task_vec, ecf_home):
+    print("delete jobs")
+    for task in task_vec:
+        the_job_file = ecf_home + task.get_abs_node_path() + ".job" + task.get_try_no()
+        if os.path.exists(the_job_file) :
+            print("removing file " + the_job_file)
+            try: os.remove(the_job_file)
+            except: pass
+        man_file = ecf_home + task.get_abs_node_path() + ".man"  
+        if os.path.exists(man_file) :
+            print("removing man_file " + man_file)
+            try: os.remove(man_file)
+            except: pass
+   
+def check_jobs(task_vec, ecf_home):
+    print("Check job file exists")
+    for task in task_vec:
+        variable = task.find_variable("ECF_DUMMY_TASK")
+        if not variable.empty(): continue;
+        the_job_file = ecf_home + task.get_abs_node_path() + ".job" + task.get_try_no()
+      
+        if os.path.exists(the_job_file) :
+            print("Found job file " + the_job_file)
+        else:
+            assert False, "Could not find job file " + the_job_file
+
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+    
+    workspace = File.source_dir();
+    print(workspace)
+
+    ecf_home = workspace + "/libs/pyext/test/data/ECF_HOME"
+    task_vec = TaskVec()
+    defs = create_defs(ecf_home,task_vec)
+    print(str(defs))
+
+    print("Generate jobs for *ALL* tasks, to default locations ECF_HOME/ECF_NAME.job0") 
+    print(defs.check_job_creation())   
+    check_jobs(task_vec,ecf_home)
+    delete_jobs(task_vec,ecf_home)
+       
+    print("\nGenerate jobs for *ALL* tasks, to default locations ECF_HOME/ECF_NAME.job0")
+    job_ctrl = JobCreationCtrl()
+    defs.check_job_creation( job_ctrl )       
+    print(job_ctrl.get_error_msg())
+    check_jobs(task_vec,ecf_home)
+    delete_jobs(task_vec,ecf_home)
+    
+    print("\nGenerate jobs for all nodes, under path, to default locations ECF_HOME/ECF_NAME.job0")    
+    job_ctrl = JobCreationCtrl()
+    job_ctrl.set_node_path( task_vec[0].get_abs_node_path() )    
+    defs.check_job_creation(job_ctrl)       
+    print(job_ctrl.get_error_msg());
+    delete_jobs(task_vec,ecf_home)
+   
+    print("\nGenerate jobs for all tasks, to the specified directory")
+    # Directory will automatically created under the provided directory
+    job_ctrl = JobCreationCtrl()
+    job_ctrl.set_dir_for_job_creation(workspace + "/libs/pyext/test/data")  # generate jobs file under this directory
+    defs.check_job_creation(job_ctrl)
+    print(job_ctrl.get_error_msg())
+    
+    generated_dir = job_ctrl.get_dir_for_job_creation() + "/" + suite_name()
+    print("removing directory tree " + generated_dir)
+    shutil.rmtree(generated_dir)      
+ 
+    # Create jobs for all task, to a TMP directory ($TMPDIR/ecf_check_job_creation/ECF_NAME.job0
+    # When run via rsh then TMPDIR may not be defined, hence expect exception to be thrown
+    try:
+        job_ctrl = JobCreationCtrl()                    
+        job_ctrl.generate_temp_dir()       
+        defs.check_job_creation(job_ctrl)
+        print(job_ctrl.get_error_msg())
+        print("removing directory tree " + job_ctrl.get_dir_for_job_creation())
+        shutil.rmtree(job_ctrl.get_dir_for_job_creation(),ignore_errors=True)     
+        delete_jobs(task_vec,ecf_home)
+    except RuntimeError as e:
+        print("failed: " + str(e))  
+        
+    try:
+        dir_to_del = os.path.join(ecf_home,suite_name())
+        print("removing directory tree " + dir_to_del )
+        shutil.rmtree(dir_to_del)     
+        print("All test pass")
+    except RuntimeError as e:
+        print("failed: " + str(e))    
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestMirror.py 5.13.0-1/libs/pyext/test/py_u_TestMirror.py
--- 5.12.4-1/libs/pyext/test/py_u_TestMirror.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestMirror.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,91 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+import os
+import ecflow as ecf
+import itertools as it
+
+import ecflow_test_util as Test
+
+
+def can_create_mirror_from_parameters():
+    mirror = ecf.MirrorAttr("name", "r_path", "r_host", "r_port", "polling", True, "auth")
+    assert mirror.name() == "name"
+    assert mirror.remote_path() == "r_path"
+    assert mirror.remote_host() == "r_host"
+    assert mirror.remote_port() == "r_port"
+    assert mirror.polling() == "polling"
+    assert mirror.ssl() == True
+    assert mirror.auth() == "auth"
+
+
+def can_add_mirror_to_task():
+    suite = ecf.Suite("s1")
+
+    family = ecf.Family("f1")
+    suite.add_family(family)
+
+    task = ecf.Task("f1")
+    family.add_task(task)
+
+    mirror = ecf.MirrorAttr("name", "r_path", "r_host", "r_port", "polling", True, "auth")
+    task.add_mirror(mirror)
+    assert len(list(task.mirrors)) == 1
+
+    actual = list(task.mirrors)[0]
+    assert actual.name() == "name"
+    assert actual.remote_path() == "r_path"
+    assert actual.remote_host() == "r_host"
+    assert actual.remote_port() == "r_port"
+    assert actual.ssl() == True
+    assert actual.auth() == "auth"
+
+
+def can_embed_mirror_into_task():
+    suite = ecf.Suite("s1")
+
+    family = ecf.Family("f1")
+    suite.add_family(family)
+
+    task = ecf.Task("f1", ecf.MirrorAttr("name", "r_path", "r_host", "r_port", "polling", True, "auth"))
+    assert len(list(task.mirrors)) == 1
+
+    actual = list(task.mirrors)[0]
+    assert actual.name() == "name"
+    assert actual.remote_path() == "r_path"
+    assert actual.remote_host() == "r_host"
+    assert actual.remote_port() == "r_port"
+    assert actual.ssl() == True
+    assert actual.auth() == "auth"
+
+
+def cannot_have_multiple_mirrors_in_single_task():
+    suite = ecf.Suite("s1")
+
+    family = ecf.Family("f1")
+    suite.add_family(family)
+
+    try:
+        task = ecf.Task("f1", ecf.MirrorAttr("name", "r_path", "r_host", "r_port", "polling", True, "auth"),
+                        ecf.MirrorAttr("another", "r_path", "r_host", "r_port", "polling", True, "auth"))
+        assert False, "Expected exception indicating multiple mirrors are not allowed in a task"
+    except RuntimeError as e:
+        assert True
+
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+
+    can_create_mirror_from_parameters()
+    can_add_mirror_to_task()
+    can_embed_mirror_into_task()
+    cannot_have_multiple_mirrors_in_single_task()
+
+    print("All tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestParent.py 5.13.0-1/libs/pyext/test/py_u_TestParent.py
--- 5.12.4-1/libs/pyext/test/py_u_TestParent.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestParent.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,77 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+#  code for testing pointers and hierarchy in python
+
+from ecflow import Suite, Family, Task, Defs, Client, debug_build
+import ecflow_test_util as Test
+import os
+
+def absNodePath(node):
+    """ Given a node return its absolute node path. """
+    """ Example of using get_parent()               """
+    name_list = []
+    name_list.append(node.name())
+    parent = node.get_parent();
+    while parent:
+        name_list.append(parent.name())
+        parent = parent.get_parent()
+        
+    name_list.reverse()
+    ret = ""
+    for name in name_list:
+        ret = ret +  "/"
+        ret = ret + name
+    return ret
+    
+
+if __name__ == "__main__":  
+    Test.print_test_start(os.path.basename(__file__))
+   
+    suite = Suite("s1");
+    family = Family("f1")
+    task = Task("t1")
+
+    assert not suite.get_parent(), "Suite parent is always NULL"
+    assert not family.get_parent(), "Expect no parent"
+    assert not task.get_parent(), "Expect no parent"
+    
+    print("suite.get_defs() = " + str(suite.get_defs()))
+    print("family.get_defs() = " + str(family.get_defs()))
+    print("task.get_defs() = " + str(task.get_defs()))
+    assert not suite.get_defs(),   "Expected no defs, since suite not added to defs yet"
+    assert not family.get_defs(),  "Expected no defs"
+    assert not task.get_defs(),    "Expected no defs"
+    
+    suite.add_family(family)
+    family.add_task(task)
+    
+    family2 = Family("f2")
+    family.add_family(family2)
+
+    t1 = Task("t1")
+    family2.add_task(t1)
+       
+    defs = Defs()
+    defs.add_suite(suite);
+    
+    print(absNodePath(t1))
+    print(absNodePath(family2))
+    print(absNodePath(family))
+    print(absNodePath(suite))
+    
+    assert t1.get_abs_node_path() == absNodePath(t1),          "Expected " + t1.get_abs_node_path()      + " but got " + absNodePath(t1)
+    assert family2.get_abs_node_path() == absNodePath(family2),"Expected " + family2.get_abs_node_path() + " but got " + absNodePath(family2)
+    assert family.get_abs_node_path() == absNodePath(family),  "Expected " + family.get_abs_node_path()  + " but got " + absNodePath(family)
+    assert suite.get_abs_node_path() == absNodePath(suite),    "Expected " + family.get_abs_node_path()  + " but got " + absNodePath(suite)
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestRemove.py 5.13.0-1/libs/pyext/test/py_u_TestRemove.py
--- 5.12.4-1/libs/pyext/test/py_u_TestRemove.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestRemove.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+#  code for testing creation of defs file in python
+import os
+import ecflow
+import copy
+from ecflow import Suite, Family, Task, Defs, Clock, DState, PartExpression, Variable, Limit, InLimit, \
+                   Date, Day, Event, Meter, Label, Autocancel, Days, TimeSlot, TimeSeries, Style, State, \
+                   RepeatString, RepeatDate, RepeatInteger, RepeatDay, RepeatEnumerated, \
+                   Verify, PrintStyle, Time, Today, Late, Cron, Client, debug_build
+import ecflow_test_util as Test
+
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+    
+    defs = Defs()
+    s0 = defs.add_suite("s0")
+    s1 = defs.add_suite("s1")
+    f1 =  s1.add_family("f1")
+    t1 = f1.add_task("t1")
+    t2 = f1.add_task("t2")
+    assert len(list(f1.nodes)) == 2 ,"Expected family to have 2 nodes"
+    defs_copy = copy.copy(defs)
+     
+    
+    t2_remove = t2.remove()
+    assert len(f1) == 1 ,"Expected family to have 1 nodes"
+
+    t1_remove = t1.remove()
+    assert len(f1) == 0 ,"Expected family to have 0 nodes"
+
+    f1_remove = f1.remove()
+    assert len(s1) == 0 ,"Expected suite to have no nodes"
+
+    node_vec = defs.get_all_nodes()
+    assert len(node_vec) == 2, "Expected 2 suites only, but found " + str(len(node_vec))
+
+    s1_remove = s1.remove()
+    node_vec = defs.get_all_nodes()
+    assert len(node_vec) == 1, "Expected 1 suites only, but found " + str(len(node_vec))
+
+    s0_remove = s0.remove()
+    node_vec = defs.get_all_nodes()
+    assert len(node_vec) == 0, "Expected 0 suites only, but found " + str(len(node_vec))
+
+    # =========================================================
+    defs2 = Defs();
+    defs2.add_suite(s0_remove)
+    s = defs2.add_suite(s1_remove) # s1_remove is returned as s
+    f =  s.add_family(f1_remove)   # f1_remove is returned as f
+    f.add_task(t1_remove)
+    f.add_task(t2_remove)
+    assert defs2 == defs_copy ,"expected defs to be the same"
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestRepeatArithmetic.py 5.13.0-1/libs/pyext/test/py_u_TestRepeatArithmetic.py
--- 5.12.4-1/libs/pyext/test/py_u_TestRepeatArithmetic.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestRepeatArithmetic.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,91 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# This test checks trigger evaluation uses date arithmetic when
+# the expression reference a repeat DATE variable.
+# Addition and subtraction for repeat date, should follow data arithmetic
+# The repeat variable in the expression must be on the LHS(left hand side)
+# of the expression, otherwise integer arithmetic is used
+import os
+import ecflow
+import ecflow_test_util as Test
+
+
+def test_repeat_arithmetic(repeat_to_add,repeat_to_add2):
+    defs = ecflow.Defs()
+    s1 = defs.add_suite("s1");
+    t1 = s1.add_task("t1").add_repeat( repeat_to_add );
+    t2 = s1.add_task("t2").add_trigger("t1:YMD ge 20100601");
+ 
+    # Check trigger expressions
+    assert len(defs.check()) == 0,  "Expected no errors in parsing expressions."
+ 
+    # Initial value of repeat is 20090101 hence trigger should fail to evaluate
+    assert t2.evaluate_trigger() == False, "Expected trigger to evaluate. 20090101 >= 20100601"
+   
+    # Check end of month - 1
+    t2.change_trigger("t1:YMD - 1 eq 20081231")
+    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101 - 1  == 20081231"
+
+    # check addition
+    t2.change_trigger("t1:YMD + 1 eq 20090102");    
+    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101 + 1  == 20090102"
+
+    # Check the end of each month + 1
+    t1.delete_repeat();
+    t1.add_repeat( repeat_to_add2 ) 
+    t2.change_trigger("t1:YMD + 1 eq 20090201");   
+    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090131 + 1  == 20090201"
+
+
+def test_repeat_datetime_arithmetic(repeat_to_add,repeat_to_add2):
+
+    defs = ecflow.Defs()
+    s1 = defs.add_suite("s1")
+    t1 = s1.add_task("t1").add_repeat( repeat_to_add )
+    t2 = s1.add_task("t2").add_trigger("t1:DT ge 20100601T000000")
+
+    # Check trigger expressions
+    print(f"## defs: {defs}")
+    assert len(defs.check()) == 0,  "Expected no errors in parsing expressions."
+
+    # Initial value of repeat is 20090101 hence trigger should fail to evaluate
+    assert t2.evaluate_trigger() == False, "Expected trigger to evaluate. 20090101T000000 >= 20100601T000000"
+
+    # Check end of month - 1 day
+    t2.change_trigger("t1:DT - 86400 eq 20081231T000000")
+    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101T000000 - 86400  == 20081231T000000"
+
+    # check addition
+    t2.change_trigger("t1:DT + 86400 eq 20090102T000000");
+    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090101T000000 + 86400  == 20090102T000000"
+
+    # Check the end of each month + 1 day
+    t1.delete_repeat();
+    t1.add_repeat( repeat_to_add2 )
+    t2.change_trigger("t1:DT + 86400 eq 20090201T000000");
+    assert t2.evaluate_trigger(), "Expected trigger to evaluate. 20090131 + 86400  == 20090201T000000"
+
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+
+    test_repeat_arithmetic(ecflow.RepeatDate("YMD", 20090101, 20091231, 1),
+                           ecflow.RepeatDate("YMD", 20090131, 20101231, 1))
+    test_repeat_arithmetic(ecflow.RepeatDateList("YMD", [20090101, 20091231]),
+                           ecflow.RepeatDateList("YMD", [20090131, 20101231]))
+
+    test_repeat_datetime_arithmetic(ecflow.RepeatDateTime("DT", "20090101T000000", "20091231T000000", "24:00:00"),
+                                    ecflow.RepeatDateTime("DT", "20090131T000000", "20101231T000000", "24:00:00"))
+
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestSimulator.py 5.13.0-1/libs/pyext/test/py_u_TestSimulator.py
--- 5.12.4-1/libs/pyext/test/py_u_TestSimulator.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestSimulator.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,129 @@
+#####1####/2####/3####/4####/5####/6####/7####/8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http:#www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#####1####/2####/3####/4####/5####/6####/7####/8
+
+#  Test that simulation works
+
+import os,fnmatch
+import ecflow
+import ecflow_test_util as Test
+
+def simulate_defs_with_time():
+    #suite test_time_series
+    #  family family
+    #      task t1
+    #         time 00:00 23:00 04:00  # should run 6 times 00:00 04:00 08:00 12:00 16:00 20:00
+    #  endfamily
+    #endsuite
+    print("simulate_defs_with_time()")
+    defs = ecflow.Defs()
+    suite = defs.add_suite("test_time_series")
+    clock = ecflow.Clock(1, 1, 2011, False)       # day,month, year, hybrid make test start at midnight, otherwise current time used
+    suite.add_clock(clock)
+    family = suite.add_family("family")
+    task = family.add_task("t1")
+    ts = ecflow.TimeSeries(ecflow.TimeSlot(0,0), ecflow.TimeSlot(23,0), ecflow.TimeSlot(4,0), True)
+    task.add_time( ecflow.Time(ts) )
+    task.add_verify( ecflow.Verify(ecflow.State.complete, 6) ) # expect task to complete 6 times
+         
+    theResult = defs.simulate()
+    assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
+    
+    print("  simple check for state change time")
+    print("   iso_extended:",task.get_state_change_time())
+    print("   iso_extended:",task.get_state_change_time("is0_extended"))
+    print("   iso         :",task.get_state_change_time("iso"))
+    print("   simple      :",task.get_state_change_time("simple"))
+    print("   rubbish     :",task.get_state_change_time("rubbish"))
+ 
+    os.remove("test_time_series.def.log")
+    
+def simulate_deadlock():
+    # This simulation is expected to fail, since we have a deadlock/ race condition
+    
+    print ("simulate_deadlock")
+    # suite dead_lock
+    #  family family
+    #    task t1
+    #          trigger t2 == complete
+    #    task t2
+    #          trigger t1 == complete
+    #   endfamily
+    # endsuite
+    
+    defs = ecflow.Defs()
+    suite = defs.add_suite("dead_lock")
+    fam = suite.add_family("family")
+    fam.add_task("t1").add_trigger("t2 == complete")
+    fam.add_task("t2").add_trigger("t1 == complete")
+    
+    theResult = defs.simulate()
+    assert len(theResult) != 0, "Expected simulation to return errors, but found none" 
+    print(theResult)
+           
+    os.remove("dead_lock.def.log")
+    os.remove("defs.depth")
+    os.remove("defs.flat")
+
+def test_time_series():
+    print ("Simulator:: ...test_time_series")
+
+    # suite suite
+    #  clock real <sunday>
+    #    family family
+    #       task t1
+    #       time 00:30 23:59 04:00  # should run 6 times 00:30 4:30 8:30 12:30 16:30 20:30
+    #      endfamily
+    #endsuite
+
+    # Initialise real clock on a Monday, such that task should _only_ run
+    # on Monday since we are using a hybrid clock
+    clock = ecflow.Clock(12, 10, 2009, False)     # day,month, year, hybrid 12 October 2009 was a Monday
+
+    theDefs = ecflow.Defs()
+    suite = theDefs.add_suite("test_time_series")
+    suite.add_clock( clock )
+
+    fam = suite.add_family( "family" )
+    task = fam.add_task("t")
+    
+    task.add_time("00:30 23:59 04:00");
+    task.add_verify( ecflow.Verify(ecflow.State.complete, 6) ) # expect task to complete 6 times
+
+    theResult = theDefs.simulate()
+    assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
+
+    os.remove("test_time_series.def.log")
+    
+
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    simulate_defs_with_time()
+    simulate_deadlock()
+    test_time_series()
+    
+    # traverse the CSim test data, make sure python simulation matches c++
+    workspace_dir = ecflow.File.source_dir()
+    csim_test_data = workspace_dir + "/CSim/test/data/good_defs"
+    print (csim_test_data)
+    for path in Test.all_files(csim_test_data,'*.def'):
+        print (path)
+        theDefs = ecflow.Defs(path)
+        theResult = theDefs.simulate()
+        assert len(theResult) == 0,  "Expected simulation to return without any errors, but found:\n" + theResult
+
+    # remove generated .log files
+    for path in Test.all_files(".",'*.log'):
+        os.remove(path)
+        
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestTraversal.py 5.13.0-1/libs/pyext/test/py_u_TestTraversal.py
--- 5.12.4-1/libs/pyext/test/py_u_TestTraversal.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestTraversal.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,228 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# This file is used to test the python traversal routines
+# This is done by loading from disk a defs file.
+# traversing this defs file, and creating another defs file
+# then comparing the two. If traversal was correct. the file should be the same
+
+import ecflow
+import ecflow_test_util as Test
+import os,fnmatch,sys
+            
+class Indentor:
+    """This class manages indentation, for use with context manager
+    It is used to correctly indent the definition node tree hierarchy
+    """
+    _index = 0
+    def __init__(self):
+        Indentor._index += 1
+    def __del__(self):
+        Indentor._index -= 1
+    @classmethod
+    def indent(cls,the_file):
+        for i in range(Indentor._index):
+            the_file.write(' ')
+            
+class DefsTraverser:
+    """Traverse the ecflow.Defs definition and write to file.
+    
+    This demonstrates that all nodes in the node tree and all attributes are accessible.
+    Additionally the state data is also accessible. This class will write state data as
+    comments. If the definition was returned from the server, it allows access to latest 
+    snapshot of the state data held in the server. 
+    """
+    def __init__(self,defs,file_name):
+        assert (isinstance(defs,ecflow.Defs)),"Expected ecflow.Defs as first argument"
+        assert (isinstance(file_name,str)),"Expected a string argument. Representing a file name"
+        self.__defs = defs
+        self.__file = open(file_name, 'w')
+        
+    def write_to_file(self):
+        for extern in self.__defs.externs:
+            self.__writeln("extern " + extern)
+        for suite in self.__defs:
+            self.__write("suite ")
+            self.__print_node(suite)
+            clock = suite.get_clock()
+            if clock:
+                indent = Indentor()
+                self.__writeln(str(clock))
+                del indent
+            self.__print_nc(suite)
+            self.__writeln("endsuite")  
+        self.__file.close()
+
+    def __print_nc(self,node_container):
+        indent = Indentor()
+        for node in node_container:
+            if isinstance(node, ecflow.Task):
+                self.__write("task ")
+                self.__print_node(node)
+                self.__print_alias(node)
+            else: 
+                self.__write("family ")
+                self.__print_node(node)
+                self.__print_nc(node)
+                self.__writeln("endfamily")
+        del indent
+
+    def __print_alias(self,task):
+       indent = Indentor()
+       for alias in task:
+           self.__write("alias ")
+           self.__print_node(alias)
+           self.__writeln("endalias")
+       del indent
+
+    def __print_node(self,node):
+        self.__file.write(node.name() + " # state:" + str(node.get_state()) + "\n")
+        
+        indent = Indentor()
+        defStatus = node.get_defstatus()
+        if defStatus != ecflow.DState.queued: 
+            self.__writeln("defstatus " + str(defStatus))
+            
+        autocancel = node.get_autocancel()
+        if autocancel: self.__writeln(str(autocancel))
+
+        autoarchive = node.get_autoarchive()
+        if autoarchive: self.__writeln(str(autoarchive))
+
+        autorestore = node.get_autorestore()
+        if autorestore: self.__writeln(str(autorestore))
+        
+        repeat = node.get_repeat()
+        if not repeat.empty(): self.__writeln(str(repeat)  + " # value: " + str(repeat.value()))
+    
+        late = node.get_late()
+        if late: self.__writeln(str(late) + " # is_late: " + str(late.is_late()))
+
+        complete_expr = node.get_complete()
+        if complete_expr:
+            for part_expr in complete_expr.parts:
+                trig = "complete "
+                if part_expr.and_expr(): trig = trig + "-a "
+                if part_expr.or_expr():  trig = trig + "-o "
+                self.__write(trig)
+                self.__file.write( part_expr.get_expression() + "\n")
+        trigger_expr = node.get_trigger()
+        if trigger_expr:
+            for part_expr in trigger_expr.parts:
+                trig = "trigger "
+                if part_expr.and_expr(): trig = trig + "-a "
+                if part_expr.or_expr():  trig = trig + "-o "
+                self.__write(trig)
+                self.__file.write( part_expr.get_expression() + "\n")
+                
+        for var in node.variables:    self.__writeln("edit " + var.name() + " '" + var.value() + "'")
+        for meter in node.meters:     self.__writeln(str(meter) + " # value: " + str(meter.value()))
+        for event in node.events:     self.__writeln(str(event) + " # value: " + str(event.value()))
+        for label in node.labels:     self.__writeln(str(label) + " # value: " + label.new_value())
+        for limit in node.limits:     self.__writeln(str(limit) + " # value: " + str(limit.value()))
+        for inlimit in node.inlimits: self.__writeln(str(inlimit))
+        for the_time in node.times:   self.__writeln(str(the_time))
+        for today in node.todays:     self.__writeln(str(today))   
+        for date in node.dates:       self.__writeln(str(date))  
+        for day in node.days:         self.__writeln(str(day))   
+        for cron in node.crons:       self.__writeln(str(cron))    
+        for verify in node.verifies:  self.__writeln(str(verify))
+        for zombie in node.zombies:   self.__writeln(str(zombie))
+        for queue in node.queues:     self.__writeln(str(queue))
+        for generic in node.generics: self.__writeln(str(generic))
+        
+        del indent
+
+    def __write(self,the_string):
+        Indentor.indent(self.__file)
+        self.__file.write(the_string)
+
+    def __writeln(self,the_string):
+        Indentor.indent(self.__file)
+        self.__file.write(the_string + "\n")
+                                   
+def check_traversal(path_to_def):
+    # Open a def on disk *and* load into memory
+    reference_def = ecflow.Defs( path_to_def )
+         
+    # traverse the opened def and write it out again
+    file_name = "copy.def"
+    traverser = DefsTraverser(reference_def,file_name)
+    traverser.write_to_file()
+         
+    # restore the defs we create via traversal. If traversal was good it should
+    # be the same as def on disk.
+    try:
+        traversed_def = ecflow.Defs( file_name )
+    except RuntimeError as e: 
+        print("Could not parse file " + file_name + "\n" + str(e))
+        sys.exit(1)
+         
+    # compare the two defs
+    ecflow.Ecf.set_debug_equality(True)
+    defs_equal = (traversed_def == reference_def)
+    if not defs_equal:
+        print(str(path_to_def) + " FAILED ")
+        print("The traversed defs=========\n" + str(traversed_def) + "\nnot the same as reference def============\n" + str(reference_def))
+        print("===================== " + file_name + " ====================================")
+        the_traversed_def_on_disk = open(file_name)
+        for line in the_traversed_def_on_disk:
+            print(line)
+            
+        assert defs_equal, "Failed: ---"
+      
+        # Notice: this path does not delete file_name, left for analysis of failure
+    else:
+        print(str(path_to_def) + " PASSED ")
+        os.remove(file_name)        
+        
+
+def all_files(root, patterns='*', single_level=False, yield_folders=False):
+    """Expand patterns from semi-colon separated string to list"""
+    patterns = patterns.split(';')
+    for path, subdirs, files in os.walk(root):
+        if yield_folders:
+            files.extend(subdirs)
+        files.sort()
+        for name in files:
+            for pattern in patterns:
+                if fnmatch.fnmatch(name,pattern):
+                    yield os.path.join(path, name)
+                    break
+        if single_level:
+            break    
+        
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    cwd = os.getcwd()
+    #print cwd
+    #print "split = " + str(os.path.split(cwd))
+    #print "basename = " + os.path.basename(cwd)
+    #print "dirname = " + os.path.dirname(cwd)
+    #print "splitext = " + str( os.path.splitext(cwd) )
+    #print "isdir = " + str(os.path.isdir(cwd))
+    
+    # Traverse all the good defs in the Parser directory
+    newpath = ""
+    if os.path.basename(cwd) == "libs/pyext":
+        newpath = os.path.join( os.path.dirname(cwd),"libs/node/parser/test/data/good_defs" )
+    
+    #print newpath
+    for path_to_defs_file in all_files(newpath, '*.def;*.txt'):
+        check_traversal(path_to_defs_file)
+        
+    # try the mega_def. Commented out since it takes to long
+    #mega_def = os.path.join( os.path.dirname(cwd), "libs/node/parser/test/data/single_defs/mega.def")
+    #check_traversal(mega_def)
+    print("All Tests pass")    
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestUserManual.py 5.13.0-1/libs/pyext/test/py_u_TestUserManual.py
--- 5.12.4-1/libs/pyext/test/py_u_TestUserManual.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestUserManual.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,135 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# This code is used in the user manual 
+#
+
+from ecflow import Suite, Task, RepeatDate
+      
+if __name__ == "__main__":
+ 
+    class ExperimentalSuite(object):
+        def __init__(self, start, end) :
+            self.start_ = start
+            self.end_ = end
+            self.start_cycle_ = 12
+            self.end_cycle_ = 12
+            
+        def generate(self) :
+            x_suite = Suite("x")
+            make_fam = x_suite.add_family("make")
+            make_fam.add_task("build")
+            make_fam.add_task("more_work")
+            
+            main_fam = x_suite.add_family("main")
+            main_fam.add_repeat( RepeatDate("YMD",self.start_,self.end_) )
+            main_fam.add_trigger( "make == complete" )
+           
+            previous = 0
+            for FAM in ( 0, 6, 12, 18 ) :
+                fam_fam = x_suite.add_family(str(FAM))
+                if FAM > 0 :
+                    fam_fam.add_trigger( "./" + str(previous) + " == complete " )
+                   
+                self.add_complete(fam_fam,FAM)
+                
+                fam_fam.add_task("run")
+                fam_fam.add_task("run_more").add_trigger( "run == complete")
+                previous = FAM
+            return x_suite
+           
+        def add_complete(self, family, fam):
+            if fam < self.start_cycle_ and fam > self.end_cycle_ :
+                family.add_complete("../main:YMD eq " + str(self.start_) + " or ../main:YMD ge " + str(self.end_))  
+            elif fam < self.start_cycle_  :
+                family.add_complete("../main:YMD eq " + str(self.start_))            
+            elif fam > self.end_cycle_    :
+                family.add_complete("../main:YMD ge " + str(self.end_))
+            return
+ 
+    print(str( ExperimentalSuite(20050601,20050605).generate() ))
+   
+# ==========================================================================
+ 
+# Control structure and looping
+    var = "aa"
+    if var in ( "a", "aa", "aaa" ) :     print("it is a kind of a ")
+    elif var in ( "b", "bb", "bb" ) :    print("it is a kind of b ")
+    else :                               print("it is something else ")
+   
+              
+# ====================================================================================
+
+    # Reuseable class for adding synoptic times
+    class VarAdder(object):
+        def __init__(self, node):
+            self.node = node
+          
+        def add(self, time):
+            {
+               6:  lambda  self : self.add6(time),
+               12: lambda  self : self.add12(time),
+               18: lambda  self : self.add18(time),
+               24: lambda  self : self.add24(time) 
+             }.get(time, self.errorHandler)(self)
+      
+        def add6(self, time):  
+            print("add6 " + str(time))
+            self.node.add_today(17, 30)
+            self.node.add_variable("ANTIME", str(time))
+
+        def add12(self, time):  
+            print("add12 " + str(time))
+            self.node.add_today(19, 15)
+            self.node.add_variable("ANTIME", str(time))
+
+        def add18(self, time):  
+            print("add18 " + str(time))
+            self.node.add_time(1, 30)
+            self.node.add_variable("ANTIME", str(time))
+
+        def add24(self, time):  
+            print("add24 " + str(time))
+            self.node.add_time(3, 0)
+            self.node.add_variable("ANTIME", "0")
+            self.node.add_variable("DELTA_DAY", "1")
+            self.node.add_variable("EXPVER", "0002")
+         
+        def errorHandler(self, ignore): print("invalid time " + str(ignore))
+
+#for i in (0, 6 ,12, 18, 24):
+for i in (0, 6):
+    task = Task("t" + str(i))
+    print(task.name())
+    varAdder = VarAdder(task)
+    varAdder.add(114)
+    for var in task.variables: 
+        print(str(var) + "\n")
+    for the_time in task.times : 
+        print(str(the_time) + "\n")
+    for today in task.todays : 
+        print(str(today) + "\n")
+         
+# ==========================================================================
+
+suite = Suite("x")
+previous_time = 0
+for i in (0,6,12,18,24) :
+    the_fam = suite.add_family(str(i))
+    if i != 0:
+        the_fam.add_trigger("./" + previous_time + " == complete ")
+    the_fam.add_task("t1")
+    the_fam.add_task("t2").add_trigger("t1 == complete")
+    previous_time = str(i)
+
+# print str(suite)
diff -pruN 5.12.4-1/libs/pyext/test/py_u_TestWith.py 5.13.0-1/libs/pyext/test/py_u_TestWith.py
--- 5.12.4-1/libs/pyext/test/py_u_TestWith.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_TestWith.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,94 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# code for testing with statement
+# In our case it provides the ability to indent
+
+from ecflow import Defs, Suite, Task, Family, Client, Variable, Edit, debug_build
+import ecflow_test_util as Test
+import sys,os
+    
+if __name__ == "__main__":
+    Test.print_test_start(os.path.basename(__file__))
+ 
+    # sys.version_info is a tuple containing (major,minor,micro,releaselevel,serial)
+    version = sys.version_info;
+    if (sys.version_info < (2, 7)):
+        print("This test only run with python version 2.7 or greater, but found : " + str(version))
+        sys.exit(0)
+    
+    # Add with context manager, in our case this only provides ability to indent
+    with Defs() as defs:
+        with defs.add_suite("s2") as s2:
+            with s2.add_family("f1") as f1:
+                with f1.add_task("t1") as t1:
+                    assert len(f1) == 1,"Expected 1 task"
+            s2.add_family("f2")
+            s2.add_task("t1")
+        assert len(s2) == 3,"Expected 2 families and one task suite"
+    assert len(defs) == 1,"Expected 1 suite"
+#    print defs
+ 
+    with Suite("s2") as s2:
+        s2.add_family("f1")
+        s2.add_task("t1")
+        assert len(s2) == 2,"Expected 2 nodes family and task"
+        
+    with Family("f1") as f1:
+        f1.add_family("f2")
+        f1.add_task("t1")
+        assert len(s2) == 2,"Expected 2 nodes family and task"
+        
+        
+    #
+    # Add Nodes functional way
+    #
+    defs1 = Defs()
+    defs1.add_suite("s1").add_task("t1").add_variable("var","v")
+    defs1.add_suite("s2").add_family("f1").add_task("t1").add_variable("var","v")
+    defs1.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
+    
+    # add node using with, they should compare
+    with Defs() as defs2:
+        with defs2.add_suite("s1") as s1:
+            t1 = s1.add_task("t1")
+            t1.add_variable("var","v")
+        with defs2.add_suite("s2") as s2:
+            with s2.add_family("f1") as f1:
+                with f1.add_task("t1") as t1:
+                    t1.add_variable("var","v")
+        with defs2.add_suite("s3") as s3:
+            with s3.add_family("f1") as f1:
+                with f1.add_family("f2") as f2: 
+                    with f2.add_task("t1") as t1: 
+                        t1.add_variable("var","v")
+    
+    assert defs1 == defs2,"expected defs to be the same"     
+    
+    # add node using with, they should compare
+    with Defs() as defs3:
+        with defs3.add_suite("s1") as s1:
+            s1 + Task('t1',var='v')
+        with defs3.add_suite("s2") as s2:
+            with s2.add_family("f1") as f1:
+                with f1.add_task("t1") as t1:
+                    t1 += Edit(var='v')
+        with defs3.add_suite("s3") as s3:
+            with s3.add_family("f1") as f1:
+                with f1.add_family("f2") as f2: 
+                    with f2.add_task("t1") as t1: 
+                        t1 += Edit(var='v')
+    
+    assert defs1 == defs3,"expected defs to be the same"           
+        
+    print("All tests pass")
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/test/py_u_sort.py 5.13.0-1/libs/pyext/test/py_u_sort.py
--- 5.12.4-1/libs/pyext/test/py_u_sort.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_sort.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,137 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+import unittest 
+from ecflow import *
+
+class Test_sort(unittest.TestCase):
+
+    def get_object_list(self,obj,name_list):
+        if obj == 'Meter': 
+            return [ Meter(name,0,100) for name in name_list ]
+        elif obj == 'Label':
+            return [ Label(name,'value') for name in name_list ]
+        elif obj == 'Variable':
+            return [ Variable(name,'value') for name in name_list ]
+        elif obj == 'Limit':
+            return [ Limit(name,10) for name in name_list ]
+        else:
+            return [ eval(obj)(name) for name in name_list ]
+
+    def test_sort_objects(self):
+        names = [ 'zz',  'ww', 'aa']
+        object_list = [ 'Task','Family','Suite','Event','Meter','Label','Variable','Limit']
+        for obj in object_list:
+            self.assertEqual(sorted(self.get_object_list(obj,names)), self.get_object_list(obj,sorted(names)), " sort of " + obj + " failed")
+#             print(obj,'-----------------')
+#             for item in sorted(self.get_object_list(obj,names)):
+#                 print(item)
+                
+                
+class Test_sort_api(unittest.TestCase):
+    def test_sort_attributes_api(self):
+        nodes = [ Defs(), Suite('s'), Family('f'), Task('t')]
+        sort_attr = ['event','meter','label','variable','all']
+        for attr in sort_attr:
+            for node in nodes:
+                node.sort_attributes(attr)
+                node.sort_attributes(attr,True)
+                node.sort_attributes(attr,True,['/path','/path2'])
+
+        sort_attr = [AttrType.event, AttrType.meter, AttrType.label,AttrType.variable, AttrType.all  ]
+        for attr in sort_attr:
+            for node in nodes:
+                node.sort_attributes(attr)
+                node.sort_attributes(attr,True)
+                node.sort_attributes(attr,True,['/path','/path2'])
+
+# see ECFLOW-1642
+class Test_ECFLOW_1642(unittest.TestCase):
+    def get_events(self):
+        return [Event(name) for name in
+            "foo buzz bar google zulu mason".split()]
+
+    def sorted_events(self):
+        return [Event(name) for name in
+            "bar buzz foo google mason zulu".split()]
+
+    def expected_def(self):
+        defs = Defs(Suite("mysuite",
+                Family("fam1",self.get_events()),
+                Family("fam2",self.sorted_events(),
+                   Task("task1",self.sorted_events()),
+                ),
+                Task("task2",self.sorted_events()),
+                self.sorted_events()))
+        return defs
+
+    def defs_to_sort(self):
+        defs = Defs(Suite("mysuite",
+                Family("fam1",self.get_events()),
+                Family("fam2",self.get_events(),
+                   Task("task1",self.get_events()),
+                ),
+                Task("task2",self.get_events()),
+                self.get_events()))
+        return defs
+    
+    def test_no_sort(self):
+        defs = self.defs_to_sort()
+        defs.sort_attributes('event',True,['/mysuite/fam1'])
+        self.assertEqual(defs,self.expected_def(),"Expected\n" + str(self.expected_def()) + "but found\n" + str(defs))
+
+    def test_no_sort2(self):
+        defs = self.defs_to_sort()
+        defs.sort_attributes(AttrType.event,True,['/mysuite/fam1'])
+        self.assertEqual(defs,self.expected_def(),"Expected\n" + str(self.expected_def()) + "but found\n" + str(defs))
+    
+class Test_defs_sort(unittest.TestCase):
+    def test_defs_sort_attributes(self):
+        defs = Defs()
+        defs.add_variable("ZFRED", "/tmp/")
+        defs.add_variable("YECF_URL_CMD", "${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%")
+        defs.add_variable("XECF_URL_BASE", "http://www.ecmwf.int")
+        defs.add_variable("AECF_URL", "publications/manuals/sms")
+        assert len(list(defs.user_variables)) == 4, "Expected *user* 4 variable"    
+     
+        # sort
+        expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED']
+        actual = []
+        defs.sort_attributes("variable");
+        for v in defs.user_variables: actual.append(v.name())
+        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+ 
+        expected = ['AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
+        actual = []
+        defs.add_variable("ZZ", "x")
+        defs.sort_attributes(AttrType.variable);
+        for v in defs.user_variables: actual.append(v.name())
+        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+     
+        expected = ['AA', 'AECF_URL','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
+        actual = []
+        defs.add_variable("AA", "x")
+        defs.sort_attributes("all");
+        for v in defs.user_variables: actual.append(v.name())
+        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+     
+        expected = ['AA', 'AECF_URL', 'BB','XECF_URL_BASE','YECF_URL_CMD','ZFRED','ZZ']
+        actual = []
+        defs.add_variable("BB", "x")
+        defs.sort_attributes(AttrType.all );
+        for v in defs.user_variables: actual.append(v.name())
+        assert actual == expected,"Attributes not sorted, expected:" + str(expected) + " but found:" + str(actual)
+ 
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
\ No newline at end of file
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test.py 5.13.0-1/libs/pyext/test/py_u_test.py
--- 5.12.4-1/libs/pyext/test/py_u_test.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# SCRATCH test for ecflow python api
+
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import unittest 
+import sys
+import os
+
+def test_compile(text):
+    test_file = "py_u_test_tutorial.def"
+    file = open(test_file ,'w')
+    file.write(text)
+    file.close()
+    execfile(test_file)
+    os.remove(test_file)  
+
+class TestCron(unittest.TestCase):
+    def setUp(self):
+        pass
+    
+    def test_pass(self):
+        pass
+
+    def test_fail(self):
+        pass
+        
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_add.py 5.13.0-1/libs/pyext/test/py_u_test_add.py
--- 5.12.4-1/libs/pyext/test/py_u_test_add.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_add.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,714 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDateTime, RepeatDateList, RepeatDay, RepeatEnumerated, RepeatInteger, \
+                  RepeatString, SState, State, Style, Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, \
+                  TimeSlot, Today, UrlCmd, Variable, VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, \
+                  ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import unittest 
+import sys
+
+class Test_dunder_rshift(unittest.TestCase):
+    def test_node_dunder_rshift(self):
+        # will ONLY work if we have starting NodeContainer
+        suite = Suite('s') >> Task('t1') >> Task('t2') >> Task('t3') >> Task('t4')
+        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
+        
+        self.assertEqual(str(suite.t2.get_trigger()),"t1 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
+        self.assertEqual(str(suite.t3.get_trigger()),"t2 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
+        self.assertEqual(str(suite.t4.get_trigger()),"t3 == complete","Trigger not as expected: " + str( suite.t4.get_trigger())) 
+
+        fam = Family("f1") >> Task('t1') >> Task('t2') >> Task('t3') >> Task('t4')
+        self.assertEqual(len(list(fam)),4,"expected 4 children but found " + str(len(list(fam))) )
+
+        self.assertEqual(str(fam.t2.get_trigger()),"t1 == complete","Trigger not as expected: " + str( fam.t2.get_trigger())) 
+        self.assertEqual(str(fam.t3.get_trigger()),"t2 == complete","Trigger not as expected: " + str( fam.t3.get_trigger())) 
+        self.assertEqual(str(fam.t4.get_trigger()),"t3 == complete","Trigger not as expected: " + str( fam.t4.get_trigger())) 
+
+    def test_node_dunder_rshift_trigger_cat(self):
+        suite = Suite('s')
+        # will ONLY work if we have starting NodeContainer
+        suite >> Task('t1') >> (Task('t2') + Trigger("x == 1")) >> (Task('t3') + Trigger("y==1")) >> Task('t4')
+        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
+        
+        self.assertEqual(str(suite.t2.get_trigger()),"x == 1 AND t1 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
+        self.assertEqual(str(suite.t3.get_trigger()),"y==1 AND t2 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
+        self.assertEqual(str(suite.t4.get_trigger()),"t3 == complete","Trigger not as expected: " + str( suite.t4.get_trigger())) 
+
+class Test_dunder_lshift(unittest.TestCase):
+    def test_node_dunder_lshift(self):
+        # will ONLY work if we have starting NodeContainer
+        suite = Suite('s') << Task('t1') << Task('t2') << Task('t3') << Task('t4')
+        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
+        
+        self.assertEqual(suite.t4.get_trigger(),None,"Trigger not as expected: " + str( suite.t4.get_trigger())) 
+        self.assertEqual(str(suite.t3.get_trigger()),"t4 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
+        self.assertEqual(str(suite.t2.get_trigger()),"t3 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
+        self.assertEqual(str(suite.t1.get_trigger()),"t2 == complete","Trigger not as expected: " + str( suite.t1.get_trigger())) 
+ 
+        fam = Family("f1") << Task('t1') << Task('t2') << Task('t3') << Task('t4')
+        self.assertEqual(len(list(fam)),4,"expected 4 children but found " + str(len(list(fam))) )
+ 
+        self.assertEqual(fam.t4.get_trigger(),None,"Trigger not as expected: " + str( fam.t4.get_trigger())) 
+        self.assertEqual(str(fam.t3.get_trigger()),"t4 == complete","Trigger not as expected: " + str( fam.t3.get_trigger())) 
+        self.assertEqual(str(fam.t2.get_trigger()),"t3 == complete","Trigger not as expected: " + str( fam.t2.get_trigger())) 
+        self.assertEqual(str(fam.t1.get_trigger()),"t2 == complete","Trigger not as expected: " + str( fam.t1.get_trigger())) 
+
+    def test_node_dunder_lshift_trigger_cat(self):
+        suite = Suite('s')
+        # will ONLY work if we have starting NodeContainer
+        suite >> Task('t1') << (Task('t2') + Trigger("x == 1")) << (Task('t3') + Trigger("y==1")) << Task('t4')
+        self.assertEqual(len(list(suite)),4,"expected 4 children but found " + str(len(list(suite))) )
+         
+        self.assertEqual(suite.t4.get_trigger(),None,"Trigger not as expected: " + str( suite.t4.get_trigger())) 
+        self.assertEqual(str(suite.t3.get_trigger()),"y==1 AND t4 == complete","Trigger not as expected: " + str( suite.t3.get_trigger())) 
+        self.assertEqual(str(suite.t2.get_trigger()),"x == 1 AND t3 == complete","Trigger not as expected: " + str( suite.t2.get_trigger())) 
+        self.assertEqual(str(suite.t1.get_trigger()),"t2 == complete","Trigger not as expected: " + str( suite.t1.get_trigger())) 
+
+class Test_dunder_add(unittest.TestCase):
+    
+    def test_node_dunder_add_variable(self):
+        # will ONLY work if we have starting NodeContainer
+        suite = Suite("s") + Family("f") + Family("f2") + Task("t3") + Edit(name="value")
+        self.assertEqual(len(list(suite.variables)),1 ,"expected suite to have 1 variable " + str(len(list(suite.variables))) )
+
+        suite = Suite("s") + Family("f") + Family("f2") + (Task("t3") + Edit(name="value"))
+        self.assertEqual(len(list(suite.t3.variables)),1 ,"expected task t3 to have 1 variable " + str(len(list(suite.t3.variables))) )
+                
+    def test_defs_dunder_add(self):
+        # will ONLY work if we have starting defs
+        defs = Defs() + Suite("s") + Suite("s1")
+        self.assertEqual(len(defs),2 ,"expected 2 suites but found " + str(len(defs)) )
+        
+        defs += Suite("sx")  #   + Suite('x')  wont work,   Suite('sx').__add__(Suite('x') not defined
+        self.assertEqual(len(defs),3 ,"expected 3 suites but found " + str(len(defs)) )
+        
+        defs + Suite("a") + Suite("b")
+        self.assertEqual(len(defs),5 ,"expected 5 suites but found " + str(len(defs)) )
+
+    def test_node_dunder_add_meter(self):
+        # will ONLY work if we have starting NodeContainer
+        suite = Suite("s") + Family("f") + Family("f2") + Task("t3") + Edit(name="value")
+        suite.t3 + Event(11,"event") + Meter("meter",0,10,10) + Label("label","c") + Trigger("1==1") 
+        self.assertEqual(len(suite),3 ,"expected 3 children but found " + str(len(suite)) )
+        self.assertEqual(len(list(suite.t3.events)),1 ,"expected 1 event found " + str(len(list(suite.t3.events))) )
+        self.assertEqual(len(list(suite.t3.meters)),1 ,"expected 1 event found " + str(len(list(suite.t3.meters))) )
+        self.assertEqual(len(list(suite.t3.labels)),1 ,"expected 1 event found " + str(len(list(suite.t3.labels))) )
+
+    def test_node_dunder_add(self):
+        suite = Suite("s")  
+        suite += Task("t3")  # + Task("t2") not allowed as Task("t1").__add__("t2") not defined
+        suite.t3 += Event(11,"event")  # + Task("t2") not allowed as Task("t1").__add__("t2") not defined
+        self.assertEqual(len(suite),1 ,"expected 1 children but found " + str(len(suite)) )
+        self.assertEqual(len(list(suite.t3.events)),1 ,"expected 1 event found " + str(len(list(suite.t3.events))) )
+
+        suite = Suite('s') + [ Task("t{0}".format(i)) for i in range(1,5)]
+        self.assertEqual(len(suite),4 ,"expected 4 children but found " + str(len(suite)) )
+
+    def test_dunder_add_all(self):
+        defs = Defs() + Suite("s1")
+        defs.s1 += Clock(1, 1, 2010, False)
+        defs.s1 += Autocancel(1, 10, True)
+        defs.s1 += Task('t1') + Edit({ "a":"y", "b":"bb"}, c="v",d="b") + Edit({ "e":1, "f":"bb"}) +  Edit(g="d") + Edit(h=1) +\
+                    Event(1) + Event(11,"event") + Meter("meter",0,10,10) + Label("label","c") + Trigger("1==1") + \
+                    Complete("1==1") + Limit("limit",10) + Limit("limit2",10) + InLimit("limitName","/limit",2) + \
+                    Defstatus(DState.complete) + Today(0,30) + Today("00:59") + Today("00:00 11:30 00:01") + \
+                    Time(0,30) + Time("00:59") + Time("00:00 11:30 00:01") + Day("sunday") + Day(Days.monday) + \
+                    Date(1,1,0) + Date(28,2,1960) + Autocancel(3) 
+                    
+        t1 = defs.find_abs_node("/s1/t1")
+        self.assertTrue(t1 is not None, "Can't find t1")
+        self.assertEqual(len(defs.s1),1, "Expected 1 nodes but found " + str(len(defs.s1)))
+        self.assertEqual(len(list(t1.variables)), 8, "expected 8 variables but found " + str(len(list(t1.variables))))
+        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
+        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
+        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
+        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
+        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
+        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
+        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
+        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
+        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
+        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
+        #print(defs)
+
+
+class Test_crash(unittest.TestCase):
+    def test_trigger_node_list(self):
+        suite = Suite("s")
+        fam = suite.add_family("f")
+        task = fam.add_task("t")
+        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
+ 
+        suite = Suite("s")
+        fam = Family("f")
+        task = Task("t")
+        suite.add_family(fam)
+        task = fam.add_task(task)
+        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
+
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
+
+        # The following will crash or cause memory error. Since the Defs() is transitory/temp()
+        # Unlike the previous example where we keep the defs in a variable.
+        #task = Defs().add_suite("s").add_family("f").add_task("t")
+        #self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
+         
+        # Like wise this will crash since the Suite() is transitory reference counted, and goes out of scope.
+#         task = Suite("s").add_family("f").add_task("t")
+#         self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
+
+class TestListComprehension(unittest.TestCase):
+    def test_suite_list(self):
+        defs = Defs()
+        defs += [ Suite("s{0}".format(i)) for i in range(1,6) ]
+        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
+
+        defs.add( [ Suite("s{0}".format(i)) for i in range(6,11) ] )
+        self.assertEqual(len(defs), 10, " expected 10 suites but found " + str(len(defs)))
+
+        defs = Defs( [ Suite("s{0}".format(i)) for i in range(1,6) ] )
+        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
+
+    def test_family_list(self):
+        defs = Defs()
+        defs += [ Suite("suite").add( [ Family("f{0}".format(i)) for i in range(1,6)]  ) ]
+        self.assertEqual(len(defs.suite), 5, " expected 5 familes but found " + str(len(defs.suite)))
+
+        defs = Defs( [ Suite("xx", [ Family("f{0}".format(i)) for i in range(1,6)]  ) ] )
+        self.assertEqual(len(defs.xx), 5, " expected 5 familes but found " + str(len(defs.xx)))
+
+    def test_task_list(self):
+        defs = Defs()
+        defs += [ Suite("suite").add( Family("f").add( [ Task("t{0}".format(i)) for i in range(1,6)]  )) ]
+        self.assertEqual(len(defs.suite.f), 5, " expected 5 task but found " + str(len(defs.suite.f)))
+
+        defs = Defs( [ Suite("suite", Family("f",[ Task("t{0}".format(i)) for i in range(1,6)]  )) ] )
+        self.assertEqual(len(defs.suite.f), 5, " expected 5 task but found " + str(len(defs.suite.f)))
+
+    def test_task_list2(self):
+        defs = Defs()
+        defs += [ Suite("suite").add( Task("x"), 
+                                      Family("f").add( [ Task("t{0}".format(i)) for i in range(1,6)]  ),
+                                      Task("y"),
+                                      [ Family("f{0}".format(i)) for i in range(1,6) ],
+                                      Edit(a="b"),
+                                      [ Task("t{0}".format(i)) for i in range(1,6) ],
+                                    )
+                ]
+        self.assertEqual(len(defs.suite), 13, " expected 13 nodes but found " + str(len(defs.suite)))
+        self.assertEqual(len(defs.suite.f), 5, " expected 5 nodes but found " + str(len(defs.suite.f)))
+        self.assertEqual(len(list(defs.suite.variables)), 1, " expected 1 variable " + str(len(list(defs.suite.variables))))
+
+    def test_5Suite_with_5families_with_5tasks(self):
+        defs = Defs().add(   
+                [ Suite("s{0}".format(i)).add( 
+                    [ Family("f{0}".format(i)).add( 
+                        [ Task("t{0}".format(i)) 
+                              for i in range(1,6)] ) 
+                        for i in range(1,6)]  ) 
+                    for i in range(1,6) ] )
+        #print defs
+        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
+        for suite in defs:
+            self.assertEqual(len(suite), 5, " expected 5 familes but found " + str(len(suite)))
+            for fam in suite:
+                self.assertEqual(len(fam), 5, " expected 5 tasks but found " + str(len(fam)))
+                
+    def test__5Suite_with_5families_with_5tasks(self):
+        defs = Defs()
+        defs += [ Suite("s{0}".format(i)).add( 
+                        [ Family("f{0}".format(i)).add( 
+                            [ Task("t{0}".format(i)) for i in range(1,6)] ) 
+                        for i in range(1,6)] ) 
+                    for i in range(1,6) 
+                ]
+        #print defs
+        self.assertEqual(len(defs), 5, " expected 5 suites but found " + str(len(defs)))
+        for suite in defs:
+            self.assertEqual(len(suite), 5, " expected 5 familes but found " + str(len(suite)))
+            for fam in suite:
+                self.assertEqual(len(fam), 5, " expected 5 tasks but found " + str(len(fam)))
+        
+
+class TestTrigger(unittest.TestCase):
+    def test_trigger(self):
+        t = Trigger("a == complete")
+        self.assertEqual(str(t),"a == complete","Trigger not as expected:"+ str(t))
+
+    def test_trigger_string_list(self):
+        t = Trigger(["a"])
+        self.assertEqual(str(t),"a == complete","Trigger not as expected: "+ str(t))
+
+        t = Trigger(["a == 1"])
+        self.assertEqual(str(t),"a == 1","Trigger not as expected: "+ str(t))
+        
+        t = Trigger(["a","b","c"])
+        self.assertEqual(str(t),"a == complete AND b == complete AND c == complete","Trigger not as expected: " + str(t))
+
+    def test_trigger_node_list(self):
+        t = Trigger([Task("a")])
+        self.assertEqual(str(t),"a == complete","Trigger not as expected: "+ str(t))
+
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
+        t = Trigger([task])
+        self.assertEqual(str(t),"/s/f/t == complete","Trigger not as expected: "+ str(t))
+
+    def test_trigger_string_and_node_list(self):
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        t = Trigger(["a","b",task])
+        self.assertEqual(str(t),"a == complete AND b == complete AND /s/f/t == complete","Trigger not as expected: " + str(t))
+        task += t
+        self.assertEqual(str(task.get_trigger() ),"a == complete AND b == complete AND /s/f/t == complete","Trigger not as expected: " + str(task.get_trigger())) 
+
+    def test_add(self):
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        task.add(Trigger("1==1"))
+        expr = task.get_trigger()
+        self.assertEqual(str(expr),"1==1","Trigger not as expected: " +  expr.get_expression())
+        
+        task.add(Trigger("2==1"))
+        self.assertEqual(str(expr),"1==1 AND 2==1","Trigger not as expected: " +  str(expr))
+        
+    def test_add_composition(self):
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        task.add(Trigger("1==1"))
+        task.add(Trigger("1==2",False))
+        task.add(Trigger("x==2"))
+        expr = task.get_trigger()
+        self.assertEqual(str(expr),"1==1 OR 1==2 AND x==2","Trigger not as expected: " +  expr.get_expression())
+
+
+class TestComplete(unittest.TestCase):
+    def test_trigger(self):
+        t = Complete("a == complete")
+        self.assertEqual(str(t),"a == complete","Complete not as expected:"+ str(t))
+
+    def test_Complete_string_list(self):
+        t = Complete(["a"])
+        self.assertEqual(str(t),"a == complete","Complete not as expected: "+ str(t))
+        
+        t = Complete(["a","b","c"])
+        self.assertEqual(str(t),"a == complete AND b == complete AND c == complete","Complete not as expected: " + str(t))
+
+    def test_Complete_node_list(self):
+        t = Complete([Task("a")])
+        self.assertEqual(str(t),"a == complete","Complete not as expected: "+ str(t))
+
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        self.assertEqual(task.get_abs_node_path(),"/s/f/t","Path not as expected " + task.get_abs_node_path() )
+        t = Complete([task])
+        self.assertEqual(str(t),"/s/f/t == complete","Complete not as expected: "+ str(t))
+
+    def test_Complete_string_and_node_list(self):
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        t = Complete(["a","b",task])
+        self.assertEqual(str(t),"a == complete AND b == complete AND /s/f/t == complete","Complete not as expected: " + str(t))
+
+    def test_add(self):
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        task.add(Complete("1==1"))
+        expr = task.get_complete()
+        self.assertEqual(str(expr),"1==1","Complete not as expected: " +  expr.get_expression())
+        
+        task.add(Complete("2==1"))
+        self.assertEqual(str(expr),"1==1 AND 2==1","Complete not as expected: " +  str(expr))
+        
+    def test_add_composition(self):
+        defs = Defs()
+        task = defs.add_suite("s").add_family("f").add_task("t")
+        task.add( Complete("1==1"))
+        task.add( Complete("1==2",False))
+        task.add( Complete("x==2"))
+        expr = task.get_complete()
+        self.assertEqual(str(expr),"1==1 OR 1==2 AND x==2","Trigger not as expected: " +  expr.get_expression())
+
+
+class TestDefsAdd(unittest.TestCase):
+    def test_add_suite1(self):
+        defs = Defs().add(Suite("a"))
+        self.assertEqual(len(defs),1,"Expected 1 suite to be added")
+
+    def test_add_suite3(self):
+        defs = Defs().add(Suite("a"),Suite("b"),Suite("c").add(Edit(a="b")))
+        self.assertEqual(len(defs),3,"Expected 3 suite to be added")
+
+    def test_add_variables(self):
+        defs = Defs().add(Edit(a="b",b='c',d='e'))
+        self.assertEqual(len(list(defs.user_variables)),3,"Expected 3 variables to be added")
+
+    def test_add_variables2(self):
+        defs = Defs(Edit(a="b",b='c',d='e'))
+        self.assertEqual(len(list(defs.user_variables)),3,"Expected 3 variables to be added")
+        
+class TestSuiteAdd(unittest.TestCase):
+    def test_add_suite1(self):
+        s = Suite("a").add(Family("a").add(Edit(a="b")))
+        self.assertEqual(len(s),1,"Expected 1 child to be added")
+
+class TestFamilyAdd(unittest.TestCase):
+    def test_add_task(self):
+        s = Family("a").add(Task("a").add(Edit(a="b")))
+        self.assertEqual(len(s),1,"Expected 1 child to be added")
+
+class TestDefstatus(unittest.TestCase):
+    def test_illegal_defstatus(self):
+        if sys.version_info[0] == 2 and sys.version_info[1] >= 7:
+            with self.assertRaises(RuntimeError):
+                Defstatus("fred")
+            
+class TestEdit(unittest.TestCase):
+    def test_add_variable(self):
+        defs = Defs().add(Suite("s").add(Edit(a=1,b=1),Edit(c="c")))
+        self.assertEqual(len(list(defs.s.variables)), 3, "expected 3 variables")
+    
+    def test_edit(self):
+        t = Task("t1").add(
+                    Edit({ "a":"y", "b":"bb"}, c="v",d="b"),
+                    Edit({ "e":"1", "f":"bb"}),
+                    Edit(g="d"),
+                    Edit(h="1"))
+        self.assertEqual(len(list(t.variables)), 8, "expected 8 variables but found " + str(len(list(t.variables))))
+        
+class TestAddAll(unittest.TestCase):
+    def test_add(self):
+        defs = Defs().add(
+            Suite("s1").add(
+                Clock(1, 1, 2010, False),
+                Autocancel(1, 10, True),
+                Task("t1").add(
+                    Edit({ "a":"y", "b":"bb"}, c="v",d="b"),
+                    Edit({ "e":1, "f":"bb"}),
+                    Edit(g="d"),
+                    Edit(h=1),
+                    Event(1),
+                    Event(11,"event"),
+                    Meter("meter",0,10,10),
+                    Label("label","c"),
+                    Trigger("1==1"),
+                    Complete("1==1"),
+                    Limit("limit",10),Limit("limit2",10),
+                    InLimit("limitName","/limit",2),
+                    Defstatus(DState.complete),
+                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01"),
+                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01"),
+                    Day("sunday"),Day(Days.monday),
+                    Date(1,1,0),Date(28,2,1960),
+                    Autocancel(3)
+                    ),
+                [ Family("f{0}".format(i)) for i in range(1,6)]
+            )
+        )
+        t1 = defs.find_abs_node("/s1/t1")
+        self.assertTrue(t1 is not None, "Can't find t1")
+        self.assertEqual(len(defs.s1),6, "Expected 6 nodes but found " + str(len(defs.s1)))
+        self.assertEqual(len(list(t1.variables)), 8, "expected 8 variables")
+        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
+        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
+        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
+        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
+        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
+        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
+        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
+        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
+        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
+        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
+        #print(defs)
+
+    def test_raw_constructor(self):
+        defs = Defs().add(
+            Suite("s1", 
+                Clock(1, 1, 2010, False), 
+                Autocancel(1, 10, True),
+                Task("t1",
+                    Edit({ "a":"y", "b":"bb"}, c="v",d="b"),
+                    Edit({ "e":1, "f":"bb"}),
+                    Edit(g="d"),
+                    Edit(h=1),
+                    Event(1),
+                    Event(11,"event"),
+                    Meter("meter",0,10,10),
+                    Label("label","c"),
+                    Trigger("1==1"),
+                    Complete("1==1"),
+                    Limit("limit",10),Limit("limit2",10),
+                    InLimit("limitName","/limit",2),
+                    Defstatus(DState.complete),
+                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01"),
+                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01"),
+                    Day("sunday"),Day(Days.monday),
+                    Date(1,1,0),Date(28,2,1960),
+                    Autocancel(3)
+                    ),
+                [ Family("f{0}".format(i)) for i in range(1,6)]
+            )
+        )
+        print(defs)
+        t1 = defs.find_abs_node("/s1/t1")
+        self.assertTrue(t1 is not None, "Can't find t1")
+        self.assertEqual(len(defs.s1),6, "Expected 6 nodes but found " + str(len(defs.s1)))
+        self.assertEqual(len(list(t1.variables)), 8, "expected 8 variables")
+        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
+        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
+        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
+        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
+        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
+        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
+        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
+        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
+        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
+        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
+     
+     
+class TestIAdd(unittest.TestCase):
+    def test_iadd_with_getattr(self):
+        defs = Defs();
+        s1 = defs.add_suite("s1")
+        s1 += [ Task("a"),Task("b")]
+        defs.s1.a += [ Edit({ "x1":"y", "aa1":"bb"}, a="v",b="b",),
+                    Edit({ "x":"y", "aa":"bb"}),
+                    Edit(d="d")
+                ]
+        defs.s1.b += [ Event(1),
+                    Event(11,"event"),
+                    Meter("meter",0,10,10),
+                    Label("label","c"),
+                ]
+        self.assertEqual(len(list(defs.s1.a.variables)), 7, "expected 7 variables")
+        self.assertEqual(len(list(defs.s1.b.events)), 2, "expected 2 events")
+        self.assertEqual(len(list(defs.s1.b.meters)), 1, "expected 1 meter")
+        self.assertEqual(len(list(defs.s1.b.labels)), 1, "expected 1 label")
+
+    def test_iadd(self):
+        defs = Defs();
+        defs += [ Suite("s2"),Edit({ "x1":"y", "aa1":"bb"}, a="v",b="b",) ]
+        s1 = defs.add_suite("s1")
+        s1 += [ Clock(1, 1, 2010, False), Autocancel(1, 10, True) ] #+ returns the same node back
+        t1 = s1.add_task("t1")
+        t1 +=   [   Edit({ "x1":"y", "aa1":"bb"}, a="v",b="b",),
+                    Edit({ "x":"y", "aa":"bb"}),
+                    Edit(d="d"),
+                    Event(1),
+                    Event(11,"event"),
+                    Meter("meter",0,10,10),
+                    Label("label","c"),
+                    Trigger("1==1"),
+                    Complete("1==1"),
+                    Limit("limit",10),Limit("limit2",10),
+                    InLimit("limitName","/limit",2),
+                    Defstatus(DState.complete),
+                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01"),
+                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01"),
+                    Day("sunday"),Day(Days.monday),
+                    Date(1,1,0),Date(28,2,1960),
+                    Autocancel(3)
+                ]
+        self.assertTrue(t1 is not None, "Can't find t1")
+        self.assertEqual(len(list(defs.suites)), 2, "expected 7 suites")
+        self.assertEqual(len(list(t1.variables)), 7, "expected 7 variables")
+        self.assertEqual(len(list(t1.limits)), 2, "expected 2 limits")
+        self.assertEqual(len(list(t1.inlimits)), 1, "expected 1 inlimits")
+        self.assertEqual(len(list(t1.events)), 2, "expected 2 events")
+        self.assertEqual(len(list(t1.meters)), 1, "expected 1 meter")
+        self.assertEqual(len(list(t1.labels)), 1, "expected 1 label")
+        self.assertEqual(len(list(t1.times)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.todays)), 3, "expected 3 times")
+        self.assertEqual(len(list(t1.days)), 2, "expected 2 days")
+        self.assertEqual(len(list(t1.dates)), 2, "expected 2 dates")
+        self.assertTrue(t1.get_trigger(), "Can't find t1 trigger")
+        self.assertTrue(t1.get_complete(), "Can't find t1 complete")
+        self.assertTrue(t1.get_autocancel(), "Can't find t1 autocancel")
+        #print(defs)
+        
+class TestComparison(unittest.TestCase):
+    def setUp(self):
+        self.cron = Cron()
+        self.cron.set_time_series(TimeSeries(TimeSlot(23 , 0) ,True)) # True means relative to suite start
+        self.late = Late()
+        self.late.submitted(TimeSlot(20, 10))
+        self.late.active(TimeSlot(20, 10))
+        self.late.complete(TimeSlot(20, 10), True)
+        self.late2 = Late()
+        self.late2.submitted(20, 10)
+        self.late2.active(20, 10)
+        self.late2.complete(20, 10, True)
+    
+        self.defs1 = Defs()
+        self.defs1.add_suite("s1").add_task("t1").add_variable("a","v").add_event(1).add_event(11,"event").add_meter("meter",0,10,10).add_label("label","c")
+        self.defs1.add_suite("s2").add_family("f1").add_task("t1").add_trigger("1==1").add_complete("1==1")
+        self.defs1.add_suite("s3").add_family("f1").add_family("f2").add_task("t1").add_variable("var","v")
+        self.defs1.add_suite("edit").add_variable("a","a").add_variable("b","b") 
+        self.defs1.add_suite("limit").add_limit("limit",10).add_limit("limit2",10) 
+        self.defs1.add_suite("inlimit").add_inlimit("limitName", "/limit", 2)  
+        self.defs1.add_suite("RepeatInteger").add_repeat(RepeatInteger("integer", 0, 100, 2)) 
+        self.defs1.add_suite("RepeatEnumerated").add_repeat(RepeatEnumerated("enum", ["red", "green", "blue" ])) 
+        self.defs1.add_suite("RepeatDate").add_repeat(RepeatDate("ymd", 20100111, 20100115, 2))
+        self.defs1.add_suite("RepeatDateTime").add_repeat(RepeatDateTime("ymd", "20100111T000000", "20100115T000000", "48:00:00"))
+        self.defs1.add_suite("RepeatDateList").add_repeat(RepeatDateList("ymd",[20100111, 20100115]))
+        self.defs1.add_suite("RepeatString").add_repeat(RepeatString("string", ["a", "b", "c" ]))
+        self.defs1.add_suite("RepeatDay").add_repeat(RepeatDay(1))
+        self.defs1.add_suite("defstatus").add_defstatus(DState.active) 
+        self.defs1.add_suite("today").add_task("today").add_today("00:30").add_today(0,59).add_today("00:00 11:30 00:01")
+        self.defs1.add_suite("time").add_task("time").add_time("00:30").add_time(0,59).add_time("00:00 11:30 00:01")
+        self.defs1.add_suite("day").add_task("day").add_day("sunday").add_day(Days.monday)
+        self.defs1.add_suite("date").add_task("date").add_date(1,1,0).add_date(28,2,1960)
+        self.defs1.add_suite("cron").add_task("cron").add_cron(self.cron)
+        self.defs1.add_suite("late").add_family("late").add_late(self.late).add_task("late").add_late(self.late2)
+        self.defs1.add_suite("clock").add_clock(Clock(1, 1, 2010, False))
+        self.defs1.add_suite("autocancel").add_autocancel(3)
+        
+        zombie_suite = self.defs1.add_suite("zombie") 
+        self.zombie_life_time_in_server = 800
+        self.child_list = [ ChildCmdType.init, ChildCmdType.event, ChildCmdType.meter, ChildCmdType.label, ChildCmdType.wait, ChildCmdType.abort,ChildCmdType.complete ]
+        zombie_type_list = [ ZombieType.ecf, ZombieType.user,ZombieType.path ]
+        for zombie_type in zombie_type_list:
+            zombie_attr = ZombieAttr(zombie_type, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server)
+            zombie_suite.add_zombie(zombie_attr)
+   
+ 
+    def test_compare_with_add(self):
+        defs = Defs().add(
+            Suite("s1").add(
+                Task("t1").add(
+                    Edit(a="v"),
+                    Event(1),
+                    Event(11,"event"),
+                    Meter("meter",0,10,10),
+                    Label("label","c")
+                )
+            ),
+            Suite("s2").add(
+                Family("f1").add(
+                    Task("t1").add(
+                        Trigger("1==1"),
+                        Complete("1==1")
+                    )
+                )
+            ),
+            Suite("s3").add(
+                Family("f1").add(
+                    Family("f2").add(
+                        Task("t1").add(
+                            Edit(var = "v")
+                        )
+                    )
+                )
+            ),
+            Suite("edit").add( Edit({"a": "a"}), Edit({ "b" : "b"}) ), # add separate, otherwise with dict order is undefined
+            Suite("limit").add( Limit("limit",10),Limit("limit2",10)),
+            Suite("inlimit").add( InLimit("limitName","/limit",2)),
+            Suite("RepeatInteger").add( RepeatInteger("integer", 0, 100, 2)),
+            Suite("RepeatEnumerated").add( RepeatEnumerated("enum", ["red", "green", "blue" ])),
+            Suite("RepeatDate").add( RepeatDate("ymd", 20100111, 20100115, 2)),
+            Suite("RepeatDateTime").add( RepeatDateTime("ymd", "20100111T000000", "20100115T000000", "48:00:00")),
+            Suite("RepeatDateList").add( RepeatDateList("ymd", [20100111, 20100115])),
+            Suite("RepeatString").add( RepeatString("string", ["a", "b", "c" ])),
+            Suite("RepeatDay").add( RepeatDay(1)),
+            Suite("defstatus").add( Defstatus(DState.active)),
+            Suite("today").add(
+                Task("today").add(
+                    Today(0,30),Today("00:59"),Today("00:00 11:30 00:01")
+                )
+            ),
+            Suite("time").add(
+                Task("time").add(
+                    Time(0,30),Time("00:59"),Time("00:00 11:30 00:01")
+                )
+            ),
+            Suite("day").add(
+                Task("day").add(
+                    Day("sunday"),Day(Days.monday)
+                )
+            ),
+            Suite("date").add(
+                Task("date").add(
+                    Date(1,1,0),Date(28,2,1960)
+                )
+            ),
+            Suite("cron").add(
+                Task("cron").add(
+                    self.cron
+                )
+            ),
+            Suite("late").add(
+                Family("late").add(
+                    self.late,
+                    Task("late").add(
+                        self.late2
+                    )
+                )
+            ),
+            Suite("clock").add( Clock(1, 1, 2010, False)),
+            Suite("autocancel").add( Autocancel(3)),
+            Suite("zombie").add( 
+                ZombieAttr( ZombieType.ecf, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
+                ZombieAttr( ZombieType.user, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
+                ZombieAttr( ZombieType.path, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server)
+            )
+        )      
+
+        self.assertEqual(self.defs1,defs,"defs not equal\n" + str(self.defs1) + "\n\n" + str(defs))    
+
+    def test_compare_with_raw_constructor(self):
+        defs = Defs()
+        defs += Suite('s1',Task('t1',Event(1),Event(11,'event'),Meter("meter",0,10,10),Label("label","c"),a='v'))
+        defs += Suite('s2',Family('f1',Task('t1',Trigger("1==1"),Complete("1==1"))))
+        defs += Suite('s3',Family('f1',Family('f2',Task('t1',var='v'))))
+        defs += Suite('edit',Edit(a='a'),Edit(b='b'))
+        defs += Suite('limit',Limit("limit",10),Limit("limit2",10))
+        defs += Suite('inlimit',InLimit("limitName", "/limit", 2 ))
+        defs += Suite('RepeatInteger',RepeatInteger("integer", 0, 100, 2) )
+        defs += Suite('RepeatEnumerated', RepeatEnumerated("enum", ["red", "green", "blue" ]))
+        defs += Suite('RepeatDate', RepeatDate("ymd", 20100111, 20100115, 2))
+        defs += Suite('RepeatDateTime', RepeatDateTime("ymd", "20100111T000000", "20100115T000000", "48:00:00"))
+        defs += Suite('RepeatDateList', RepeatDateList("ymd", [20100111, 20100115]))
+        defs += Suite('RepeatString',RepeatString("string", ["a", "b", "c" ]))
+        defs += Suite('RepeatDay', RepeatDay(1))
+        defs += Suite('defstatus', Defstatus('active'))
+        defs += Suite('today',Task('today',Today("00:30"),Today(0,59),Today("00:00 11:30 00:01")))
+        defs += Suite('time',Task('time',Time("00:30"),Time(0,59),Time("00:00 11:30 00:01")))
+        defs += Suite('day',Task('day',Day("sunday"),Day(Days.monday)))
+        defs += Suite('date',Task('date',Date(1,1,0),Date(28,2,1960)))
+        defs += Suite('cron',Task('cron',self.cron))
+        defs += Suite('late',Family('late',self.late,Task('late',self.late2)))
+        defs += Suite('clock',Clock(1, 1, 2010, False) )
+        defs += Suite('autocancel',Autocancel(3) )
+        
+        defs += Suite("zombie",ZombieAttr( ZombieType.ecf, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
+                               ZombieAttr( ZombieType.user, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server),
+                               ZombieAttr( ZombieType.path, self.child_list, ZombieUserActionType.block, self.zombie_life_time_in_server))
+                               
+        self.assertEqual(self.defs1,defs,"defs not equal\n" + str(self.defs1) + "\n\n" + str(defs))    
+
+        
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_collection.py 5.13.0-1/libs/pyext/test/py_u_test_collection.py
--- 5.12.4-1/libs/pyext/test/py_u_test_collection.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_collection.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,101 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+import ecflow
+import unittest 
+
+def setup_test(self):
+    self.defs0 = ecflow.Defs()
+    self.suite0 = ecflow.Suite("s")
+    self.family0 = ecflow.Family("s")
+    self.task0 = ecflow.Task("s")
+
+    self.defs1 = ecflow.Defs();        self.defs1.add_suite("s1")
+    self.suite1 = ecflow.Suite("s");   self.suite1.add_task("t")
+    self.family1 = ecflow.Family("s"); self.family1.add_task("t")
+
+    self.defs3 = ecflow.Defs()
+    self.suite3 = ecflow.Suite("s") 
+    self.family3 = ecflow.Family("s") 
+    [ self.defs3.add_suite("s" + str(i))   for i in [ 1, 2, 3 ] ]
+    [ self.suite3.add_family("f" + str(i)) for i in [ 1, 2, 3 ] ]
+    [ self.family3.add_task("t" + str(i))  for i in [ 1, 2, 3 ] ]
+
+class TestSizedProtocol(unittest.TestCase):
+    def setUp(self):
+        setup_test(self)
+        
+    def test_empty(self):
+        self.assertEqual(len(self.defs0), 0, "Expected empty defs to be of size zero")
+        self.assertEqual(len(self.suite0), 0, "Expected empty suite to be of size zero")
+        self.assertEqual(len(self.family0), 0, "Expected empty family to be of size zero")
+        self.assertEqual(len(self.task0), 0, "Expected empty task to be of size zero")
+
+    def test_size1(self):
+        self.assertEqual(len(self.defs1), 1, "Expected defs with one suite")
+        self.assertEqual(len(self.suite1), 1, "Expected suite with one child")
+        self.assertEqual(len(self.family1), 1, "Expected family with one child")
+
+    def test_size3(self):
+        self.assertEqual(len(self.defs3), 3, "Expected defs with 3 suite but found " + str(len(self.defs3)))
+        self.assertEqual(len(self.suite3), 3, "Expected suite with 3 child but found " + str(len(self.suite3)))
+        self.assertEqual(len(self.family3), 3, "Expected family with 3 child but found " + str(len(self.family3)))
+
+class TestContainerProtocol(unittest.TestCase):
+    def setUp(self):
+        setup_test(self)
+
+    def test_contains(self):
+        self.assertEqual(("s" not in self.defs0), True, "Err in defs container")
+        self.assertEqual(("z" not in self.defs3), True, "Err in defs container")
+        self.assertEqual(("s1" in self.defs3), True, "Err in defs container")
+        self.assertEqual(("s2" in self.defs3), True, "Err in defs container")
+        self.assertEqual(("s3" in self.defs3), True, "Err in defs container")
+
+        self.assertEqual(("f" not in self.suite0), True, "Err in suites container")
+        self.assertEqual(("z" not in self.suite3), True, "Err in suites container")
+        self.assertEqual(("f1" in self.suite3), True, "Err in suites container")
+        self.assertEqual(("f2" in self.suite3), True, "Err in suites container")
+        self.assertEqual(("f3" in self.suite3), True, "Err in suites container")
+
+        self.assertEqual(("z" not in self.family0), True, "Err in family container")
+        self.assertEqual(("t" not in self.family0), True, "Err in family container")
+        self.assertEqual(("t1" in self.family3), True, "Err in family container")
+        self.assertEqual(("t2" in self.family3), True, "Err in family container")
+        self.assertEqual(("t3" in self.family3), True, "Err in family container")
+    
+class TestIterableProtocol(unittest.TestCase):
+    def setUp(self):
+        setup_test(self)
+
+    def test_iterator(self):
+        self.assertTrue(hasattr(self.defs3,'__iter__') , "defs has no __iter__")
+        self.assertTrue(hasattr(self.suite3,'__iter__') , "suite has no __iter__")
+        self.assertTrue(hasattr(self.family3,'__iter__') , "family has no __iter__")
+        self.assertTrue(hasattr(self.task0,'__iter__') , "task has no __iter__ for aliases")
+        self.assertEqual([suite.name() for suite in self.defs3 ] , ["s1","s2","s3"],"Defs iterator protocol not working")
+        self.assertEqual([child.name() for child in self.suite3] , ["f1","f2","f3"],"Suites iterator protocol not working")
+        self.assertEqual([child.name() for child in self.family3], ["t1","t2","t3"],"Family iterator protocol not working")
+        
+class TestNodesIteration(unittest.TestCase):
+    def setUp(self):
+        setup_test(self)
+
+    def test_node_iterator(self):
+        self.assertEqual([suite.name() for suite in self.defs3.suites] , ["s1","s2","s3"],"Defs.suites not working")
+        self.assertEqual([child.name() for child in self.suite3.nodes] , ["f1","f2","f3"],"Suite.nodes working")
+        self.assertEqual([child.name() for child in self.family3.nodes], ["t1","t2","t3"],"Family.nodes not working")
+        self.assertEqual([alias.name() for child in self.task0.nodes]   , []              ,"Task.nodes not working")
+
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_cron.py 5.13.0-1/libs/pyext/test/py_u_test_cron.py
--- 5.12.4-1/libs/pyext/test/py_u_test_cron.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_cron.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,114 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# SCRATCH test for ecflow python api
+
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import unittest 
+import sys
+import os
+
+class TestCron(unittest.TestCase):
+    def setUp(self):
+        cron = Cron()
+        cron.set_week_days( [0,1,2,3,4,5,6] )
+        cron.set_days_of_month( [1,2,3,4,5,6] )
+        cron.set_months( [1,2,3,4,5,6] )
+        cron.set_time_series( "+00:00 23:00 00:30" )
+        self.cron1 =  cron
+        
+        cron2 = Cron()
+        cron2.set_time_series(1, 30) # default relative = false, added in release 4.0.7
+        self.cron2 = cron2
+
+        cron3 = Cron()
+        cron3.set_week_days([0, 1, 2, 3, 4, 5, 6 ])
+        cron3.set_time_series(1, 30, True)
+        self.cron3 = cron3
+    
+        cron4 = Cron()
+        cron4.set_week_days([0, 1, 2, 3, 4, 5, 6])
+        cron4.set_time_series("00:30 01:30 00:01")
+        self.cron4 = cron4
+
+        cron5 = Cron()
+        cron5.set_week_days([0, 1, 2, 3, 4, 5, 6])
+        cron5.set_time_series("+00:30")
+        self.cron5 = cron5
+        
+        start = TimeSlot(0, 0)
+        finish = TimeSlot(23, 0)
+        incr = TimeSlot(0, 30)
+        time_series = TimeSeries(start, finish, incr, True)
+        cron6 = Cron( time_series )
+        cron6.set_week_days([0, 1, 2, 3])
+        self.cron6 = cron6
+        
+        cron7 = Cron()
+        cron7.set_week_days( [0,1,2] )                       # This cant overlap with last_week_days_of_the_month
+        cron7.set_last_week_days_of_the_month( [3,4,5,6] )   # This cant overlap with days_of_week
+        cron7.set_days_of_month( [1,2,3,4,5,6] )
+        cron7.set_months( [1,2,3,4,5,6] )
+        cron7.set_time_series( "+00:00 23:00 00:30" )
+        cron7.set_last_day_of_the_month()
+        self.cron7 = cron7
+
+    def test_me0(self):
+        cron = Cron("+00:00 23:00 00:30", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6])
+        self.assertEqual(self.cron1, cron, "cron not equal\n" + str(self.cron1) + "\n" + str(cron))
+                
+        cron = Cron("01:30")
+        self.assertEqual(self.cron2, cron, "cron not equal\n" + str(self.cron2) + "\n" + str(cron))
+
+        cron = Cron("+01:30",days_of_week=[0,1,2,3,4,5,6])
+        self.assertEqual(self.cron3, cron, "cron not equal\n" + str(self.cron3) + "\n" + str(cron))
+
+        cron = Cron("00:30 01:30 00:01",days_of_week=[0,1,2,3,4,5,6])
+        self.assertEqual(self.cron4, cron, "cron not equal\n" + str(self.cron4) + "\n" + str(cron))
+
+        cron = Cron("+00:30",days_of_week=[0,1,2,3,4,5,6])
+        self.assertEqual(self.cron5, cron, "cron not equal\n" + str(self.cron5) + "\n" + str(cron))
+
+        cron = Cron("+00:00 23:00 00:30",days_of_week=[0,1,2,3])
+        self.assertEqual(self.cron6, cron, "cron not equal\n" + str(self.cron6) + "\n" + str(cron))
+
+        cron = Cron("+00:00 23:00 00:30",days_of_week=[0,1,2],                   # This cant overlap with last_week_days_of_the_month
+                                         last_week_days_of_the_month=[3,4,5,6],  # This cant overlap with days_of_week
+                                         days_of_month=[1,2,3,4,5,6],
+                                         months=[1,2,3,4,5,6],
+                                         last_day_of_the_month=True)
+        self.assertEqual(self.cron7, cron, "cron not equal\n" + str(self.cron7) + "\n" + str(cron))
+ 
+    def test_fail(self):
+        with self.assertRaises(RuntimeError):
+            cron = Cron("");  # empty
+        with self.assertRaises(RuntimeError):
+            cron = Cron("", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6]); # empty
+        with self.assertRaises(RuntimeError):
+            cron = Cron("0023", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6]) # bad time
+        with self.assertRaises(RuntimeError):
+            cron = Cron("00:10", days_of_weekss=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], months=[1,2,3,4,5,6]) # bad kw,days_of_weekss
+        with self.assertRaises(RuntimeError):
+            cron = Cron("00:10", days_of_week=[0,1,2,3,4,5,6],days_of_months=[1,2,3,4,5,6], months=[1,2,3,4,5,6]) # bad kw, days_of_months
+        with self.assertRaises(RuntimeError):
+            cron = Cron("00:10", days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6], monthss=[1,2,3,4,5,6]) # bad kw, monthss
+        with self.assertRaises(RuntimeError):
+            cron = Cron("00:10", days_of_week="0,1,2,3,4,5,6",days_of_month=[1,2,3,4,5,6], month=[1,2,3,4,5,6])  # bad kw, expect vector of string
+        
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_defs_constructor.py 5.13.0-1/libs/pyext/test/py_u_test_defs_constructor.py
--- 5.12.4-1/libs/pyext/test/py_u_test_defs_constructor.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_defs_constructor.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,148 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# SCRATCH test for ecflow python api
+
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import unittest 
+import sys
+import os
+
+class Test_default_defs(unittest.TestCase):
+     
+    def setUp(self):
+        self.file_name = 'Test_default_defs.defs'
+        defs = Defs() + Suite('s1')
+        defs.save_as_defs( self.file_name)
+ 
+    def test_defs_default_constructor(self):
+        defs = Defs()                 
+        #PrintStyle.set_style( Style.MIGRATE )  
+        #print defs
+        self.assertEqual(defs.get_state(), State.unknown, "expected unknow state but found " + str(defs.get_state()))
+        self.assertEqual(defs.get_server_state(), SState.RUNNING, "expected default server state tobe running state but found " + str(defs.get_server_state()))
+        self.assertEqual(len(list(defs.suites)), 0, "expected no suites but found " + str(len(list(defs.suites))))
+ 
+        defs = Defs(self.file_name)  
+        self.assertEqual(defs.get_state(), State.unknown, "expected unknow state but found " + str(defs.get_state()))
+        self.assertEqual(defs.get_server_state(), SState.RUNNING, "expected default server state tobe running state but found " + str(defs.get_server_state()))
+        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
+         
+    def tearDown(self):
+        try:  os.remove(self.file_name)
+        except: pass
+     
+class Test_defs_raw_constructor(unittest.TestCase):
+     
+    def test_defs_raw_constructor_errors(self):
+        with self.assertRaises(RuntimeError):
+            defs = Defs("file_name.def",Suite('s1'))                
+        with self.assertRaises(RuntimeError):
+            defs = Defs("file_name.def",Edit(a='b'))                
+        with self.assertRaises(RuntimeError):
+            defs = Defs("file_name.def",{'a':'b'})                
+        with self.assertRaises(RuntimeError):
+            defs = Defs("file_name.def",Variable('a','b'))                
+        with self.assertRaises(RuntimeError):
+            defs = Defs("file_name.def",[Variable('a','b')])                
+       
+    def test_defs_raw_constructor_suite_creation(self):
+        defs = Defs(Suite('s1'))                
+        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
+
+        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'))                
+        self.assertEqual(len(list(defs.suites)), 3, "expected 3 suites but found " + str(len(list(defs.suites))))
+
+        defs = Defs([ Suite('s{0}'.format(i)) for i in range(1,5) ])                
+        self.assertEqual(len(list(defs.suites)), 4, "expected 4 suites but found " + str(len(list(defs.suites))))
+
+    def test_defs_raw_constructor_variables(self):
+        defs = Defs(Edit(a='b'))                
+        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
+
+        defs = Defs(Variable('a','b'))                
+        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
+
+        defs = Defs({'a':'a','b':'b'})                
+        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
+
+        defs = Defs(a='a',b='b')  # uses kwy word arguments          
+        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
+ 
+        defs = Defs(Edit(a='b'),Variable('b','b'),{'c':'a','d':'b'}, e='a',f='b')       
+        self.assertEqual(len(list(defs.user_variables)), 6, "expected 6 user variable but found " + str(len(list(defs.user_variables))))
+
+    def test_defs_raw_constructor(self):
+        defs = Defs(Suite('s1'),Edit(a='b'))                
+        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
+        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
+
+        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'),Variable('a','b'))                
+        self.assertEqual(len(list(defs.user_variables)), 1, "expected 1 user variable but found " + str(len(list(defs.user_variables))))
+        self.assertEqual(len(list(defs.suites)), 3, "expected 3 suites but found " + str(len(list(defs.suites))))
+
+        defs = Defs([ Suite('s{0}'.format(i)) for i in range(1,5) ],{'a':'a','b':'b'})                
+        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
+        self.assertEqual(len(list(defs.suites)), 4, "expected 4 suites but found " + str(len(list(defs.suites))))
+
+        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'),a='a',b='b')  # uses kwy word arguments          
+        self.assertEqual(len(list(defs.user_variables)), 2, "expected 2 user variable but found " + str(len(list(defs.user_variables))))
+        self.assertEqual(len(list(defs.suites)), 3, "expected 3 suites but found " + str(len(list(defs.suites))))
+
+        defs = Defs(Suite('s1'),Edit(a='b'),Variable('b','b'),{'c':'a','d':'b'}, e='a',f='b')       
+        self.assertEqual(len(list(defs.user_variables)), 6, "expected 6 user variable but found " + str(len(list(defs.user_variables))))
+        self.assertEqual(len(list(defs.suites)), 1, "expected 1 suites but found " + str(len(list(defs.suites))))
+
+    def test_defs_constructor(self):
+        defs = Defs(Suite('s1'),Edit(a='b'))  
+        defs2 = Defs() + Suite('s1') + Edit(a='b')  
+        defs3 = Defs()
+        defs3 += Suite('s1')
+        defs3 += Edit(a='b')
+        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
+        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
+             
+        defs = Defs(Suite('s1'),Suite('s2'),Suite('s3'),Variable('a','b'))  
+        defs2 = Defs() + Suite('s1') + Suite('s2') + Suite('s3') + Variable('a','b')   
+        defs3 = Defs().add(Suite('s1'),Suite('s2'),Suite('s3'),Variable('a','b') )           
+        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
+        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
+ 
+        defs = Defs([ Suite('s{0}'.format(i)) for i in range(1,5) ],{'a':'a'})                
+        defs2 = Defs() + [ Suite('s{0}'.format(i)) for i in range(1,5) ] +  {'a':'a'}
+        defs3 = Defs()
+        for i in range(1,5):
+            defs3.add_suite('s{0}'.format(i))   
+        defs3.add_variable('a','a')        
+        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
+        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
+ 
+        defs = Defs(Suite('s1'),Edit(a='a'),Variable('b','b'),{'c':'c'},{'d':'d'} )       
+        defs2 = Defs().add(Suite('s1'),Edit(a='a'),Variable('b','b'),{'c':'c'},{'d':'d'})
+        defs3 = Defs()
+        defs3.add_suite('s1')   
+        defs3.add_variable('a','a')        
+        defs3.add_variable('b','b')        
+        defs3.add_variable('c','c')        
+        defs3.add_variable('d','d')        
+        self.assertEqual(defs,defs2,"defs not equal\n" + str(defs) + "\n\n" + str(defs2))    
+        self.assertEqual(defs,defs3,"defs not equal\n" + str(defs) + "\n\n" + str(defs3))    
+
+
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_get_attr.py 5.13.0-1/libs/pyext/test/py_u_test_get_attr.py
--- 5.12.4-1/libs/pyext/test/py_u_test_get_attr.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_get_attr.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,114 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# SCRATCH test for ecflow python api
+
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate,RepeatDateList, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import unittest 
+import sys
+import os
+
+class Test_get_attr(unittest.TestCase):
+    def test_get_attr(self):
+        defs = Defs() + (Suite('s') + Family('f').add(Task('t') + Edit(var="1")))
+        defs += Edit(var="1")
+        
+        self.assertIsInstance(defs.s, Suite, "Expected suite")
+        self.assertIsInstance(defs.s.f, Family, "Expected family")
+        self.assertIsInstance(defs.s.f.t, Task, "Expected Task but found " + str(type(defs.s.f.t)))
+        
+        self.assertIsInstance(defs.var, Variable, "Expected Variable but found " + str(type(defs.var)))
+        self.assertIsInstance(defs.s.f.t.var, Variable, "Expected Variable but found " + str(type(defs.s.f.t.var)))
+        
+    def test_get_attr_generated_variables(self):
+        defs = Defs() + (Suite('s') + Family('f').add((Task('t')  + Edit(var="1") + RepeatDate("YMD", 20100111, 20100115, 2)),
+                                                      (Task('t2') + Edit(var="1") + RepeatDateList("YMD",[20100111, 20100115 ]))))
+        defs.s.f.t += Meter("meter",0,100)
+        defs.s.f.t += Event("event")
+        defs.s.f.t += Limit("limitx",10)
+        #PrintStyle.set_style(Style.STATE)
+        #print(defs)
+        
+        self.assertTrue(defs.ECF_MICRO, "expected generated variable")
+        self.assertTrue(defs.ECF_HOME, "expected generated variable")
+        self.assertTrue(defs.ECF_JOB_CMD , "expected generated variable")
+        self.assertTrue(defs.ECF_KILL_CMD , "expected generated variable")
+        self.assertTrue(defs.ECF_STATUS_CMD , "expected generated variable")
+        self.assertTrue(defs.ECF_URL_CMD , "expected generated variable")
+        self.assertTrue(defs.ECF_LOG  , "expected generated variable")
+        self.assertTrue(defs.ECF_INTERVAL   , "expected generated variable")
+        self.assertTrue(defs.ECF_LISTS   , "expected generated variable")
+        self.assertTrue(defs.ECF_CHECK   , "expected generated variable")
+        self.assertTrue(defs.ECF_CHECKOLD   , "expected generated variable")
+        self.assertTrue(defs.ECF_CHECKINTERVAL   , "expected generated variable")
+        self.assertTrue(defs.ECF_CHECKMODE   , "expected generated variable")
+        self.assertTrue(defs.ECF_TRIES   , "expected generated variable")
+        self.assertTrue(defs.ECF_VERSION   , "expected generated variable")
+        self.assertTrue(defs.ECF_PORT   , "expected generated variable")
+        self.assertTrue(defs.ECF_HOST    , "expected generated variable")
+
+        self.assertTrue(defs.s.SUITE, "expected generated variable")
+        self.assertEqual(defs.s.SUITE.value() , 's', "expected suite name of 's' but found")
+        self.assertTrue(defs.s.ECF_DATE , "expected generated variable")
+        self.assertTrue(defs.s.YYYY , "expected generated variable")
+        self.assertTrue(defs.s.DOW , "expected generated variable")
+        self.assertTrue(defs.s.DOY , "expected generated variable")
+        self.assertTrue(defs.s.DATE , "expected generated variable")
+        self.assertTrue(defs.s.DAY , "expected generated variable")
+        self.assertTrue(defs.s.DD , "expected generated variable")
+        self.assertTrue(defs.s.MM , "expected generated variable")
+        self.assertTrue(defs.s.MONTH , "expected generated variable")
+        self.assertTrue(defs.s.ECF_CLOCK , "expected generated variable")
+        self.assertTrue(defs.s.ECF_TIME , "expected generated variable")
+        self.assertTrue(defs.s.TIME  , "expected generated variable")
+    
+        self.assertTrue(defs.s.f.FAMILY   , "expected generated variable")
+        self.assertTrue(defs.s.f.FAMILY1   , "expected generated variable")
+
+        self.assertTrue(defs.s.f.t.TASK    , "expected generated variable")
+        self.assertEqual(defs.s.f.t.TASK.value() , 't', "expected task name of 's'")
+        self.assertTrue(defs.s.f.t.ECF_JOB     , "expected generated variable")
+        self.assertTrue(defs.s.f.t.ECF_SCRIPT      , "expected generated variable")
+        self.assertTrue(defs.s.f.t.ECF_JOBOUT      , "expected generated variable")
+        self.assertTrue(defs.s.f.t.ECF_TRYNO      , "expected generated variable")
+        self.assertEqual(defs.s.f.t.ECF_TRYNO.value() , '0', "expected task try no of '0'")
+        self.assertTrue(defs.s.f.t.ECF_RID      , "expected generated variable")
+        self.assertTrue(defs.s.f.t.ECF_NAME      , "expected generated variable")
+        self.assertEqual(defs.s.f.t.ECF_NAME.value()  , '/s/f/t', "expected task ECF_NAME of '/s/f/t'")
+        self.assertTrue(defs.s.f.t.ECF_PASS       , "expected generated variable")
+
+        self.assertEqual(defs.s.f.t.YMD.value() , '20100111', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t.YMD_YYYY.value() , '2010', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t.YMD_MM.value() , '1', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t.YMD_DD.value() , '11', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t.YMD_DOW.value() , '1', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t.YMD_JULIAN.value() , '2455208', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t.event.value() , 0, "expected generated event of value 0 but found " + str(defs.s.f.t.event.value()))
+        self.assertEqual(defs.s.f.t.meter.value() , 0, "expected generated meter of value 0 but found " + str(defs.s.f.t.meter.value()))
+        self.assertEqual(defs.s.f.t.limitx.value() , 0, "expected generated limit of value 0 but found " + str(defs.s.f.t.limitx.value()))#
+        
+        self.assertEqual(defs.s.f.t2.YMD.value() , '20100111', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t2.YMD_YYYY.value() , '2010', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t2.YMD_MM.value() , '1', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t2.YMD_DD.value() , '11', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t2.YMD_DOW.value() , '1', "expected generated YMD of value")
+        self.assertEqual(defs.s.f.t2.YMD_JULIAN.value() , '2455208', "expected generated YMD of value")
+
+
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_late.py 5.13.0-1/libs/pyext/test/py_u_test_late.py
--- 5.12.4-1/libs/pyext/test/py_u_test_late.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_late.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,86 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# SCRATCH test for ecflow python api
+
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import unittest 
+import sys
+import os
+
+class TestLate(unittest.TestCase):
+    def setUp(self):
+        late = Late()
+        late.submitted(TimeSlot(20, 10))
+        late.active(TimeSlot(20, 10))
+        late.complete(TimeSlot(20, 10), True)
+        self.late = late
+        #print("setUp ",str(self.late))
+         
+        late = Late()
+        late.submitted(10, 10)
+        late.active(10, 10)
+        late.complete(10, 10, False)
+        self.late1 = late
+          
+        late = Late()
+        late.submitted(10, 10)
+        self.late2 = late
+  
+        late = Late()
+        late.active(10, 10)
+        self.late3 = late
+  
+        late = Late()
+        late.complete(10, 12, False)
+        self.late4 = late
+     
+    def test_pass(self):
+        late = Late(submitted='20:10',active='20:10',complete='+20:10')
+        #print("test_pass",str(late))
+        self.assertEqual(self.late, late, "late shoud be the same:\n" + str(self.late) + "\n" + str(late))
+        
+        late = Late(submitted='10:10',active='10:10',complete='10:10')
+        self.assertEqual(self.late1, late, "late shoud be the same:\n" + str(self.late1) + "\n" + str(late))
+  
+        late = Late(submitted='10:10')
+        self.assertEqual(self.late2, late, "late shoud be the same:\n" + str(self.late2) + "\n" + str(late))
+  
+        late = Late(active='10:10')
+        self.assertEqual(self.late3, late, "late shoud be the same:\n" + str(self.late3) + "\n" + str(late))
+  
+        late = Late(complete='10:12')
+        self.assertEqual(self.late4, late, "late shoud be the same:\n" + str(self.late4) + "\n" + str(late))
+
+    def test_fail(self):
+        self.assertNotEqual(self.late ,  self.late1, "Late should not be equal")
+         
+        with self.assertRaises(RuntimeError):
+            late = Late("");  # no keyword arguments
+ 
+        with self.assertRaises(RuntimeError):
+            late = Late(submittedd='20:10',active='20:10',complete='+20:10') # miss-spelt keyword
+ 
+        with self.assertRaises(RuntimeError):
+            late = Late(submitted='20:10',activee='20:10',complete='+20:10') # miss-spelt keyword
+ 
+        with self.assertRaises(RuntimeError):
+            late = Late(submitted='20:10',active='20:10',completee='+20:10') # miss-spelt keyword
+
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_manual.py 5.13.0-1/libs/pyext/test/py_u_test_manual.py
--- 5.12.4-1/libs/pyext/test/py_u_test_manual.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_manual.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,931 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDateTime, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import os 
+import unittest 
+
+class TestAddSuiteFamilyTask0(unittest.TestCase):
+    def setUp(self):
+        defs = Defs()
+        s = Suite('s1')
+        f = Family('f1')
+        t = Task('t1')
+        defs.add_suite(s)
+        s.add_family(f)
+        f.add_task(t)
+        self.defs = defs
+
+    def test_0(self):
+        defs = Defs()
+        defs.add_suite('s1').add_family('f1').add_task('t1')
+        self.assertEqual(self.defs, defs, "defs not equal")
+        
+    def test_1(self):
+        defs = Defs().add(
+            Suite('s1').add(
+                Family('f1').add(
+                    Task('t1'))))
+        self.assertEqual(self.defs, defs, "defs not equal")
+
+    def test_2(self):
+        defs = Defs(
+            Suite('s1',
+                  Family('f1',
+                         Task('t1'))))
+        self.assertEqual(self.defs, defs, "defs not equal")
+
+    def test_3(self):
+        defs = Defs() + (Suite('s1') + (Family('f1') + Task('t1')))
+        self.assertEqual(self.defs, defs, "defs not equal")
+
+    def test_3(self):
+        defs = Defs() + (Suite('s1') + (Family('f1') + Task('t1')))
+        self.assertEqual(self.defs, defs, "defs not equal")
+          
+class TestAddSuiteFamilyTask(unittest.TestCase):
+    def setUp(self):
+        defs = Defs()            # create an empty definition
+        suite = defs.add_suite("s1")    # create a suite and add it to the defs
+        family = suite.add_family("f1") # create a family and add it to suite
+        for i in [ "a", "b", "c" ]:     # create task ta,tb,tc
+            family.add_task( "t" + i)   # create a task and add to family
+        defs.save_as_defs("test.def")   # save defs to file "test.def"  
+         
+        self.defs = defs
+         
+    def test_me(self):
+        with Defs() as defs:
+            with defs.add_suite("s1") as suite:
+                with suite.add_family("f1") as family:
+                    for i in [ "a", "b", "c" ]:      
+                        family.add_task( "t" + i)    
+        defs.save_as_defs("test.def")    
+                     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)
+        self.assertEqual(self.defs, defs, "defs not equal")
+         
+    def test_me2(self):
+        defs = Defs().add( 
+            Suite("s1").add(
+                Family("f1").add(
+                    [ Task("t{0}".format(t)) 
+                      for t in ("a", "b", "c")] )))
+        defs.save_as_defs("test.def")   # save defs to file "test.def"  
+                     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)
+        self.assertEqual(self.defs, defs, "defs not equal")
+ 
+    def test_me3(self):
+        defs = Defs()
+        defs += Suite("s1") 
+        defs.s1 += Family("f1") 
+        defs.s1.f1 += [ Task("t{0}".format(t)) 
+                        for t in ("a", "b", "c")] 
+        defs.save_as_defs("test.def")   # save defs to file "test.def"  
+                     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)
+        self.assertEqual(self.defs, defs, "defs not equal")
+        
+    def test_me4(self):
+        defs = Defs(
+                Suite("s1",
+                    Family("f1",
+                        [ Task("t{0}".format(t)) for t in ("a", "b", "c")])))
+        defs.save_as_defs("test.def")   # save defs to file "test.def"  
+                     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)
+        self.assertEqual(self.defs, defs, "defs not equal")
+ 
+    def test_me5(self):
+        defs = Defs().add(   
+          [ Suite("s{0}".format(i)).add( 
+              [ Family("f{0}".format(i)).add( 
+                  [ Task("t{0}".format(i)) for i in range(1,6)] ) 
+                for i in range(1,7)]  )
+            for i in range(1,6) ] )
+        assert len(defs)==5, " expected 6 suites but found " + str(len(defs))
+        for suites in defs:
+            assert len(suites)==6, " expected 6 families but found " + str(len(suites))
+            for fam in suites:
+                assert len(fam)==5, " expected 6 tasks but found " + str(len(fam))
+                
+    def test_me6(self):
+        defs = Defs(
+                [ Suite("s{0}".format(i),
+                    [ Family("f{0}".format(i),
+                        [ Task("t{0}".format(i)) for i in range(1,6)] )
+                    for i in range(1,7)]  )
+                for i in range(1,6) ] )
+        assert len(defs)==5, " expected 5 suites but found " + str(len(defs))
+        for suites in defs:
+            assert len(suites)==6, " expected 6 families but found " + str(len(suites))
+            for fam in suites:
+                assert len(fam)==5, " expected 5 tasks but found " + str(len(fam))
+             
+    def tearDown(self):
+        unittest.TestCase.tearDown(self)
+        try: os.remove("test.def")
+        except: pass
+         
+class TestAddMeterEventLabel(unittest.TestCase):
+    def setUp(self):
+        defs = Defs()
+        suite = Suite("s1")
+        task = Task("t1")
+        defs.add_suite(suite)
+        suite.add_task(task)
+        task.add_event( 2 )                      # event reference with 2
+        task.add_event("wow")                    # event reference with name "wow"
+        task.add_event( 10,"Eventname2" )        # event referenced with name "Eventname2"
+        task.add_meter( "metername3",0,100 )     # name, min, max
+        task.add_label( "label_name4", "value" ) # name, value
+         
+        self.defs = defs
+         
+    def test_alternative(self):
+        defs = Defs().add(
+            Suite("s1").add(
+                Task("t1").add(
+                    Event(2),
+                    Event("wow"),
+                    Event(10,"Eventname2" ),
+                    Meter("metername3",0,100),
+                    Label("label_name4", "value"))))
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs,self.defs, "expected defs to be the same")
+ 
+    def test_alternative1(self):
+        defs = Defs() + Suite("s1")
+        defs.s1 += Task("t1") + Event(2) + Event("wow") + \
+                    Event(10,"Eventname2" ) + Meter("metername3",0,100) + \
+                    Label("label_name4", "value") 
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+         
+    def test_alternative2(self):
+        with Defs() as defs:
+            with defs.add_suite("s1") as suite:
+                with suite.add_task("t1") as t1:
+                    t1 += [ Event(2),
+                           Event("wow"),
+                           Event(10,"Eventname2" ),
+                           Meter("metername3",0,100),
+                           Label("label_name4", "value") ]
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative3(self):
+        defs = Defs( 
+                Suite('s1',
+                    Task("t1",
+                        Event(2),
+                        Event("wow"),
+                        Event(10,"Eventname2" ),
+                        Meter("metername3",0,100),
+                        Label("label_name4", "value")))) 
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+            
+class TestAddLimitInlimit(unittest.TestCase):
+     
+    def setUp(self):
+        defs = Defs()
+        s1 = defs.add_suite("s1") 
+        s1.add_limit( "limitName4", 10 ) # name, maximum token
+        f1 = s1.add_family("f1")
+        f1.add_inlimit( "limitName4","/s1/f1",2) # limit name, path to limit, tokens consumed
+        for i in range(1,4):
+            f1.add_task( "t{0}".format(i))
+             
+        self.defs = defs
+ 
+    def test_alternative(self):
+        defs = Defs().add(
+            Suite("s1").add(
+                Limit("limitName4", 10),
+                Family("f1").add(
+                    InLimit("limitName4","/s1/f1",2),
+                    [ Task("t{0}".format(t)) for t in range(1,4) ]
+                    )))
+ 
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")        
+ 
+    def test_alternative1(self):
+        defs = Defs() + Suite("s1") 
+        defs.s1 += [ Limit("limitName4", 10),Family("f1") ]
+        defs.s1.f1 += [ InLimit("limitName4","/s1/f1",2),
+                        [ Task("t{0}".format(t)) for t in range(1,4) ] ]
+ 
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")        
+         
+    def test_alternative2(self):
+        with Defs() as defs:
+            with defs.add_suite("s1") as s1:
+                s1.add_limit( "limitName4", 10 ) # name, maximum token
+                with s1.add_family("f1") as f1:
+                    f1.add_inlimit( "limitName4","/s1/f1",2) # limit name, path to limit, tokens consumed
+                    f1 += [ Task("t{0}".format(t)) for t in range(1,4) ]
+                     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative3(self):
+        defs = Defs( 
+            Suite("s1",
+                Limit("limitName4", 10),# name, maximum token
+                Family("f1",
+                    InLimit("limitName4","/s1/f1",2), # limit name, path to limit, tokens consumed
+                    [ Task("t{0}".format(t)) for t in range(1,4) ] )))
+                     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+ 
+ 
+class TestAddVariable(unittest.TestCase):
+     
+    def setUp(self):
+        defs = Defs()
+        s1 = defs.add_suite("s1") 
+        s1.add_variable("HELLO","world") # name, value
+        s1.add_variable({ "NAME":"value", "NAME2":"value2", "NAME3":"value3", "NAME4":4 }  )
+        s1.add_variable(Variable("FRED","bloggs"))
+        s1.add_variable(Variable("BILL","1"))
+         
+        defs.s1.sort_attributes("variable"); # sort since with dictionary order of addition is arbitary
+        self.defs = defs
+
+    def test_alternative0(self):
+         
+        defs = Defs(Suite("s1",HELLO="world",FRED="bloggs",BILL=1,NAME="value",NAME2="value2"))
+        defs.s1.add_variable('NAME4',4)
+        defs.s1 += Edit(NAME3="value3")
+ 
+        defs.s1.sort_attributes("variable");
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+ 
+    def test_alternative(self):
+         
+        defs = Defs().add(
+                      Suite("s1").add(
+                          Edit(HELLO="world",FRED="bloggs",BILL=1,NAME="value",NAME2="value2",NAME3="value3",NAME4=4 )
+                          ))
+ 
+        defs.s1.sort_attributes("variable");
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+ 
+    def test_alternative1(self):
+         
+        defs = Defs() + Suite("s1",Edit(HELLO="world"))
+        defs.s1 += [ Edit({ "NAME":"value", "NAME2":"value2", "NAME3":"value3", "NAME4":4 }, BILL=1),
+                     Edit(FRED="bloggs") ]
+ 
+        defs.s1.sort_attributes("variable");
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative2(self):
+         
+        defs = Defs(
+                Suite("s1",
+                    { "HELLO":"world", "NAME":"value", "NAME2":"value2", 
+                     "NAME3":"value3", "NAME4":4, "BILL":1, "FRED":"bloggs" }))
+ 
+        defs.s1.sort_attributes("variable");
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+
+class TestAddTrigger(unittest.TestCase):
+     
+    def setUp(self):
+        defs = Defs()
+        s1 = defs.add_suite("s1") 
+        t1 = s1.add_task("t1")
+        t2 = s1.add_task("t2")
+        t2.add_trigger( "t1 == active and t3 == aborted" )
+        t2.add_complete( "t3 == complete" )
+        t3 = s1.add_task("t3")
+        self.defs = defs
+
+    def test_alternative0(self):
+        
+        defs = Defs(
+                Suite("s1",
+                    Task("t1"),
+                    Task("t2",
+                        Trigger("t1 == active and t3 == aborted"),
+                        Complete("t3 == complete")),
+                    Task("t3")))
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative(self):
+        
+        defs = Defs().add(
+                 Suite("s1").add(
+                    Task("t1"),Task("t2").add(
+                        Trigger("t1 == active and t3 == aborted"),
+                        Complete("t3 == complete")),
+                    Task("t3")))
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+ 
+    def test_alternative1(self):
+         
+        defs = Defs() + Suite("s1")
+        defs.s1 += [ Task("t{0}".format(i)) for i in range(1,4) ]
+        defs.s1.t2 += [ Trigger("t1 == active and t3 == aborted"),
+                        Complete("t3 == complete") ]
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+
+class TestAddTaskChain(unittest.TestCase):
+
+    def setUp(self):
+        defs = Defs(
+                Suite("s1",
+                    Task("t1"),
+                    Task("t2",Trigger( "t1 == complete" )),
+                    Task("t3",Trigger( "t2 == complete" )),
+                    Task("t4",Trigger( "t3 == complete" ))))
+        self.defs = defs
+        
+    def test_alternative(self):
+        defs = Defs() + Suite("s1")
+        defs.s1 += [ Task("t1"),Task("t2"),
+                     Task("t3"),Task("t4") ]
+        defs.s1.t2 += Trigger( ["t1"] )
+        defs.s1.t3 += Trigger( ["t2"] )
+        defs.s1.t4 += Trigger( ["t3"] )
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+
+    def test_alternative1(self):
+        defs = Defs() + Suite("s1")
+        defs.s1 += [ Task("t1"),Task("t2"),Task("t3"),Task("t4") ]
+        defs.s1.t2 += Trigger( [ defs.s1.t1 ] )
+        defs.s1.t3 += Trigger( [ defs.s1.t2 ] )
+        defs.s1.t4 += Trigger( [ defs.s1.t3 ] )
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative1(self):
+        defs = Defs(Suite("s1"))
+        defs.s1 >> Task("t1") >> Task("t2") >> Task("t3") >> Task("t4")
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+class TestAddReverseTaskChain(unittest.TestCase):
+
+    def setUp(self):
+        defs = Defs(
+                Suite("s1",
+                    Task("t1", Trigger( "t2 == complete" )),
+                    Task("t2", Trigger( "t3 == complete" )),
+                    Task("t3", Trigger( "t4 == complete" )),
+                    Task("t4")))
+        self.defs = defs
+        
+    def test_alternative1(self):
+        defs = Defs() + Suite("s1")
+        defs.s1 << Task("t1") << Task("t2") << Task("t3") << Task("t4")
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+class TestAddLargeTrigger(unittest.TestCase):
+    
+    def setUp(self):
+        defs = Defs()
+        s1 = defs.add_suite("s1") 
+        t1 = s1.add_task("t1")
+        t2 = s1.add_task("t2")
+        t3 = s1.add_task("t3")
+        t3.add_part_trigger( "t1 == complete")
+        t3.add_part_trigger( "t2 == active", True) # here True means add as 'AND'
+        t3.add_part_trigger( "t2 == aborted", False) # here False means add as 'OR'
+        self.defs = defs
+
+    def test_alternative0(self):
+        defs = Defs( 
+                Suite("s1",
+                    Task("t1"),
+                    Task("t2"),
+                    Task("t3",
+                        Trigger("t1 == complete"), 
+                        Trigger("t2 == active"),
+                        Trigger("t2 == aborted",False))))
+        
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative(self):
+        defs = Defs().add(
+                Suite("s1").add(
+                    Task("t1"),
+                    Task("t2"),
+                    Task("t3").add(
+                        Trigger("t1 == complete"), 
+                        Trigger("t2 == active"),
+                        Trigger("t2 == aborted",False),
+                        )
+                    ))
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+
+    def test_alternative1(self):
+         
+        defs = Defs() + Suite("s1")
+        defs.s1 += [ Task("t{0}".format(i)) for i in range(1,4) ]
+        defs.s1.t3 += [ Trigger("t1 == complete"),
+                        Trigger("t2 == active"),
+                        Trigger("t2 == aborted",False) ]
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+class TestAddTimeDependencies(unittest.TestCase):
+    
+    def setUp(self):
+        defs = Defs()
+        s1 = defs.add_suite("s1") 
+        t1 = s1.add_task("date")
+        t1.add_date(1, 0, 0)       # first of every month and every year
+        t1.add_date(Date("2.*.*")) # second of every month and every year
+        t1.add_date(28,2,2026)     # 28 february 2026
+
+        t2 = s1.add_task("day")
+        t2.add_day("monday")
+        t2.add_day(Days.tuesday)
+        
+        t3 = s1.add_task("time")
+        t3.add_time("+00:30")                     # 30 minutes after suite has begun
+        t3.add_time("+00:30 20:00 01:00")         # 00:30,01:30,02:30....07:30 after suite start
+              
+        t3.add_time(0, 59, True)                  #  00:59 - 59 minutes past midnight
+        t3.add_time(Time(TimeSlot(20, 10)))       #  20:10 - 10 minutes pas eight
+        t3.add_time(Time(TimeSlot(20, 20), True)) # +20:20 - 20 minutes and 20 hours, after suite start
+
+        start = TimeSlot(0, 0)
+        finish = TimeSlot(23, 0)
+        incr = TimeSlot(0, 30)
+        time_series = TimeSeries(start, finish, incr, True)        
+        t3.add_time(Time(time_series))
+        t3.add_time(Time(0, 10))                  #  00:10 
+        t3.add_time(Time("+00:40"))               # +00:40
+        t3.add_time(Time("+00:40 20:00 01:00"))   # 00:40,01:40,02:30...17:40 after suite start
+        
+        cron = Cron()
+        cron.set_week_days( [0,1,2,3,4,5,6] )
+        cron.set_days_of_month( [1,2,3,4,5,6] )
+        cron.set_months( [1,2,3,4,5,6] )
+        cron.set_time_series( "+00:00 23:00 00:30" )
+        s1.add_task("cron").add_cron( cron );
+        
+        self.defs = defs
+        
+    def test_alternative0(self):
+        start = TimeSlot(0, 0)
+        finish = TimeSlot(23, 0)
+        incr = TimeSlot(0, 30)
+        time_series = TimeSeries(start, finish, incr, True)
+        
+        defs = Defs( 
+                Suite("s1",
+                    Task("date",
+                        Date(1, 0, 0),                   # first of every month and every year
+                        Date("2.*.*"),                   # second of every month and every yea
+                        Date(28,2,2026)),                # 28 february 2026
+                    Task("day",
+                        Day("monday"),
+                        Day(Days.tuesday)),
+                    Task("time",
+                        Time("+00:30"),                  # 30 minutes after suite has begun
+                        Time("+00:30 20:00 01:00"),      # 00:30,01:30,02:30....07:30 after suite start
+                        Time(0, 59, True),               # 00:59 - 59 minutes past midnight
+                        Time(TimeSlot(20, 10)),          # 20:10 - 10 minutes pas eight
+                        Time(TimeSlot(20, 20), True),    # +20:20 - 20 minutes and 20 hours, after suite start
+                        Time(time_series),
+                        Time(0, 10),
+                        Time("+00:40"),
+                        Time("+00:40 20:00 01:00")),
+                    Task("cron",
+                        Cron("+00:00 23:00 00:30",days_of_week=[0,1,2,3,4,5,6],days_of_month=[1,2,3,4,5,6],months=[1,2,3,4,5,6]))))
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative(self):
+        start = TimeSlot(0, 0)
+        finish = TimeSlot(23, 0)
+        incr = TimeSlot(0, 30)
+        time_series = TimeSeries(start, finish, incr, True)
+        
+        cron = Cron()
+        cron.set_week_days( [0,1,2,3,4,5,6] )
+        cron.set_days_of_month( [1,2,3,4,5,6] )
+        cron.set_months( [1,2,3,4,5,6] )
+        cron.set_time_series( "+00:00 23:00 00:30" )
+
+        defs = Defs().add(
+            Suite("s1").add(
+                Task("date").add(
+                    Date(1, 0, 0),
+                    Date("2.*.*"),
+                    Date(28,2,2026)),
+                Task("day").add(
+                    Day("monday"),
+                    Day(Days.tuesday)),
+                Task("time").add(
+                    Time("+00:30"),
+                    Time("+00:30 20:00 01:00"),
+                    Time(0, 59, True),
+                    Time(TimeSlot(20, 10)),
+                    Time(TimeSlot(20, 20), True),
+                    Time(time_series),
+                    Time(0, 10),
+                    Time("+00:40"),
+                    Time("+00:40 20:00 01:00")),
+                Task("cron").add(
+                    cron)))
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative1(self):
+        start = TimeSlot(0, 0)
+        finish = TimeSlot(23, 0)
+        incr = TimeSlot(0, 30)
+        time_series = TimeSeries(start, finish, incr, True)
+        
+        defs = Defs() + ( Suite("s1") + Task("date") + Task("day") + Task("time") + Task("cron"))
+        defs.s1.date += [ Date(1, 0, 0), Date("2.*.*"), Date(28,2,2026) ]
+        defs.s1.day += [ Day("monday"), Day(Days.tuesday) ]
+        defs.s1.time += [ Time("+00:30"), Time("+00:30 20:00 01:00"), Time(0, 59, True),
+                          Time(TimeSlot(20, 10)), Time(TimeSlot(20, 20), True),
+                          Time(time_series), Time(0, 10), Time("+00:40"),
+                          Time("+00:40 20:00 01:00") ]
+        defs.s1.cron += Cron("+00:00 23:00 00:30",
+                             days_of_week=[0,1,2,3,4,5,6],
+                             days_of_month=[1,2,3,4,5,6],
+                             months=[1,2,3,4,5,6])  
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+class TestAddDefStatus(unittest.TestCase):
+    
+    def setUp(self):
+        defs = Defs()
+        s1 = defs.add_suite("s1") 
+        s1.add_task("t1").add_defstatus(Defstatus("complete"))
+        s1.add_task("t2").add_defstatus(DState.complete)
+        
+        self.defs = defs
+
+    def test_alternative0(self):
+        defs = Defs( 
+                Suite("s1",
+                    Task("t1",Defstatus("complete")),
+                    Task("t2",Defstatus(DState.complete))))
+        
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+
+    def test_alternative(self):
+        defs = Defs().add(
+            Suite("s1").add(
+                Task("t1").add(Defstatus("complete")),
+                Task("t2").add(Defstatus(DState.complete))))
+        
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+
+    def test_alternative1(self):
+        defs = Defs() + ( Suite("s1") +  Task("t1") + Task("t2") )
+        defs.s1.t1 += Defstatus("complete") 
+        defs.s1.t2 += Defstatus(DState.complete) 
+        
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+   
+class TestAddAutocancel(unittest.TestCase):
+    
+    def setUp(self):
+        defs = Defs()
+        s1 = defs.add_suite("s1") 
+        s1.add_task("t1").add_autocancel(3)                                # delete task after 3 days after completion 
+        s1.add_task("t2").add_autocancel(1, 10, True)                      # delete task 1hr 10 min after task completion
+        s1.add_task("t3").add_autocancel(TimeSlot(2,10), True)             # delete task 2hr 10 min after task completion 
+        s1.add_task("t4").add_autocancel(Autocancel(1))                    # delete task after 1 day after task completion
+        s1.add_task("t5").add_autocancel(Autocancel( 18, 10, False))       # delete task at 6:10pm once it has completed
+        s1.add_task("t6").add_autocancel(Autocancel(TimeSlot(2,10), False))# delete task at 2:10am once it has completed
+
+        self.defs = defs
+
+    def test_alternative0(self):
+        defs = Defs( 
+                Suite("s1",
+                    Task("t1", Autocancel(3)),                    # delete task after 3 days after completion 
+                    Task("t2", Autocancel(1, 10, True)),          # delete task 1hr 10 min after task completion
+                    Task("t3", Autocancel(TimeSlot(2,10), True)), # delete task 2hr 10 min after task completion
+                    Task("t4", Autocancel(1)),                    # delete task after 1 day after task completion
+                    Task("t5", Autocancel(18, 10, False)),        # delete task at 6:10pm once it has completed
+                    Task("t6", Autocancel(2, 10, False))))        # delete task at 2:10am once it has completed
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative(self):
+        defs = Defs().add(
+            Suite("s1").add(
+                Task("t1").add(Autocancel(3)),
+                Task("t2").add(Autocancel(1, 10, True)),
+                Task("t3").add(Autocancel(TimeSlot(2,10), True)),
+                Task("t4").add(Autocancel(1)),
+                Task("t5").add(Autocancel(18, 10, False)),
+                Task("t6").add(Autocancel(2, 10, False))))
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+
+
+    def test_alternative1(self):
+        defs = Defs() + ( Suite("s1") + [ Task("t{0}".format(i)) for i in range(1,7)] )
+        defs.s1.t1 += Autocancel(3) 
+        defs.s1.t2 += Autocancel(1, 10, True) 
+        defs.s1.t3 += Autocancel(TimeSlot(2,10), True) 
+        defs.s1.t4 += Autocancel(1)     
+        defs.s1.t5 += Autocancel(18, 10, False) 
+        defs.s1.t6 += Autocancel(2, 10, False)       
+         
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+   
+class TestAddRepeat(unittest.TestCase):
+    def setUp(self):
+        def add_tasks(fam):
+            for i in range(1,3):
+                fam.add_task(Task("t{0}".format(i)))
+                
+        defs = Defs()
+        s1 = defs.add_suite("s1")
+        f1 = s1.add_family("f1")
+        f1.add_repeat( RepeatDate("YMD",20100111,20100115,2) )
+        add_tasks(f1)
+
+        f2 = s1.add_family("f2")
+        f2.add_repeat( RepeatInteger("count",0,100,2)  )
+        add_tasks(f2)
+
+        f3 = s1.add_family("f3")
+        f3.add_repeat( RepeatEnumerated("enum",["red", "green", "blue" ] )  )
+        add_tasks(f3)
+
+        f4 = s1.add_family("f4")
+        f4.add_repeat( RepeatString("enum",["a", "b", "c" ] )  )
+        add_tasks(f4)
+
+        f5 = s1.add_family("f5")
+        f5.add_repeat( RepeatDay(1)  )
+        add_tasks(f5)
+
+        f6 = s1.add_family("f6")
+        f6.add_repeat(RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00"))
+        add_tasks(f6)
+          
+        self.defs = defs
+     
+
+    def test_alternative0(self):
+        defs = Defs( 
+                Suite("s1",
+                    Family("f1",
+                       RepeatDate("YMD",20100111,20100115,2),
+                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f2",
+                       RepeatInteger("count",0,100,2),
+                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f3",
+                       RepeatEnumerated("enum",["red", "green", "blue" ] ),
+                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f4",
+                        RepeatString("enum",["a", "b", "c" ] ),
+                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f5",
+                        RepeatDay(1),
+                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f6",
+                        RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00"),
+                        [ Task("t{0}".format(i)) for i in range(1,3) ] )))
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+    def test_alternative1(self):
+        defs = Defs().add(
+                Suite("s1").add(
+                    Family("f1").add(
+                       RepeatDate("YMD",20100111,20100115,2),
+                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f2").add(
+                       RepeatInteger("count",0,100,2),
+                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f3").add(
+                       RepeatEnumerated("enum",["red", "green", "blue" ] ),
+                       [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f4").add(
+                        RepeatString("enum",["a", "b", "c" ] ),
+                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f5").add(
+                        RepeatDay(1),
+                        [ Task("t{0}".format(i)) for i in range(1,3) ] ),
+                    Family("f6").add(
+                        RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00"),
+                        [ Task("t{0}".format(i)) for i in range(1,3) ] )))
+
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+ 
+    def test_alternative2(self):
+        defs = Defs() + Suite("s1") 
+        defs.s1 += [ Family("f{0}".format(i)).add(
+                      [ Task("t{0}".format(i)) for i in range(1,3) ]) 
+                    for i in range(1,7) ]
+        defs.s1.f1 += RepeatDate("YMD",20100111,20100115,2)
+        defs.s1.f2 += RepeatInteger("count",0,100,2) 
+        defs.s1.f3 += RepeatEnumerated("enum",["red", "green", "blue" ] ) 
+        defs.s1.f4 += RepeatString("enum",["a", "b", "c" ] ) 
+        defs.s1.f5 += RepeatDay(1)
+        defs.s1.f6 += RepeatDateTime("DT", "20100111T000000", "20100115T000000", "48:00:00")
+  
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+        
+        
+class TestAddLate(unittest.TestCase):
+    def setUp(self):
+        defs = Defs()
+        suite = defs.add_suite('s1')
+        
+        late = Late()
+        late.submitted( 20,10 )         # hour, min
+        late.active( 2, 10 )            # hour, min
+        late.complete( 3, 10, True)     # hour, min, relative
+        suite.add_task('t1').add_late(late)
+        self.defs = defs
+ 
+    def test_1(self):
+        
+        # Can also pass late into the Task constructor
+        defs = Defs(
+                Suite('s1',
+                    Task('t1',
+                        Late(submitted='20:10',active='02:10',complete='+03:10'))))
+     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")   
+        
+    def test_2(self):
+        
+        # Can also pass late into the Task constructor
+        defs = Defs() + (Suite('s1') + Task('t1'))
+        defs.s1.t1 += Late(submitted='20:10',active='02:10',complete='+03:10')
+     
+        Ecf.set_debug_equality(True)
+        equals = (self.defs == defs)
+        Ecf.set_debug_equality(False)      
+        self.assertEqual(defs, self.defs, "expected defs to be the same")   
+        
+        
+class Deadlock(unittest.TestCase):
+    def setUp(self):
+        defs = Defs().add(
+        Suite("dead_lock").add(
+            Family("family").add(
+               Task("t1").add( Trigger("t2 == complete")),
+               Task("t2").add( Trigger("t1 == complete")))))
+        
+        self.defs = defs
+        
+    def test_me(self):
+        defs = Defs(
+            Suite("dead_lock",
+                Family('family',
+                    Task('t1', 
+                        Trigger("t2 == complete")),
+                    Task('t2', 
+                        Trigger("t1 == complete")))))
+        
+        self.assertEqual(defs, self.defs, "expected defs to be the same")
+       
+        
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_replace_node.py 5.13.0-1/libs/pyext/test/py_u_test_replace_node.py
--- 5.12.4-1/libs/pyext/test/py_u_test_replace_node.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_replace_node.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,44 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# SCRATCH test for ecflow python api
+
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import unittest 
+import sys
+import os
+import ecflow_test_util as Test
+
+class Test_replace(unittest.TestCase):
+
+    def test_replace_on_server_errors(self):
+        # expect error since nodes not attached to a definition
+        # The error should happen before we connect to the server,hence no need to start server
+        # Avoid suspending node first( since that will require node exist in the server)
+        node_vec = [ Suite('s1'), Family('f1'), Task('t1') ]
+        for node in node_vec:
+            print(node.name(), " +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
+            try: 
+                node.replace_on_server("locahost:3141",suspend_node_first=False)
+                self.assertFalse(False, "Expected failure since client definition is empty")
+            except RuntimeError as e:
+                self.assertTrue("client definition is empty" in str(e), "expected 'client definition is empty' in exception message  but found:\n"+ str(e))
+
+        
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/test/py_u_test_tutorial.py 5.13.0-1/libs/pyext/test/py_u_test_tutorial.py
--- 5.12.4-1/libs/pyext/test/py_u_test_tutorial.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/test/py_u_test_tutorial.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1565 @@
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #10 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+from ecflow import Alias, AttrType, Autocancel, CheckPt, ChildCmdType, Client, Clock, Cron, DState, Date, Day, Days, \
+                  Defs, Ecf, Event, Expression, Family, FamilyVec, File, Flag, FlagType, FlagTypeVec, InLimit, \
+                  JobCreationCtrl, Label, Late, Limit, Meter, Node, NodeContainer, NodeVec, PartExpression, PrintStyle, \
+                  Repeat, RepeatDate, RepeatDay, RepeatEnumerated, RepeatInteger, RepeatString, SState, State, Style, \
+                  Submittable, Suite, SuiteVec, Task, TaskVec, Time, TimeSeries, TimeSlot, Today, UrlCmd, Variable, \
+                  VariableList, Verify, WhyCmd, ZombieAttr, ZombieType, ZombieUserActionType, Trigger, Complete, Edit, Defstatus
+import ecflow_test_util as Test
+import unittest 
+import shutil   # used to remove directory tree
+import os,sys
+
+def test_def_file():
+    #return "test.def"
+    return "test_tutorial_def_" + str(os.getpid()) + ".def"
+    
+def test_compile(text):    
+    # replace test.def in the text with test_def_file() so that we have a unique file per process
+    text = text.replace('test.def',test_def_file())
+    
+    test_file = "py_u_test_tutorial_" + str(os.getpid()) + ".def"
+    file = open(test_file ,'w')
+    file.write(text)
+    file.close()
+    
+    # execfile(test_file) only work for python 2.7
+    with open(test_file) as f:
+        code = compile(f.read(), test_file, 'exec')
+        exec(code)  
+        
+    os.remove(test_file)  
+
+def do_tear_down():
+    Ecf.set_debug_equality(False)      
+    try: os.remove(test_def_file())
+    except: pass
+        
+######################################################################################################
+class TestNewSuite(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)   
+           
+        home = os.path.join(os.getenv("HOME"),"course")
+        self.defs = Defs()
+        suite = self.defs.add_suite("test")
+        suite.add_variable("ECF_HOME", home)
+        suite.add_task("t1")
+         
+        with Defs() as self.defs2: 
+            with self.defs2.add_suite("test") as suite:
+                suite.add_variable("ECF_HOME", home)
+                suite.add_task("t1") 
+         
+        with Defs() as self.defs3:  
+            self.defs3.add(
+                Suite("test",
+                    Edit(ECF_HOME=home),
+                    Task("t1")))
+             
+        self.defs4 = Defs() + (Suite("test") + Edit(ECF_HOME=home))
+        self.defs4.test += Task("t1")
+        
+        self.defs5 = Defs().add(
+                Suite("test").add(
+                    Edit(ECF_HOME=home),
+                    Task("t1")))
+        
+        #print("Creating suite definition")   
+        home = os.path.join(os.getenv("HOME"),"course")
+        defs = Defs( 
+                        Suite('test',
+                            Task('t1'),
+                            ECF_HOME=home))
+        self.assertEqual(self.defs,defs,"defs not equal\n" + str(self.defs) + "\n" + str(defs))
+
+        text = """import os
+from ecflow import Defs,Suite,Task,Edit
+   
+#xx print("Creating suite definition")
+home = os.path.join(os.getenv("HOME"),  "course")
+defs = Defs( 
+        Suite('test',
+            Edit(ECF_HOME=home),
+            Task('t1')))
+#xx print(defs)
+
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,defs,"defs not equal\n" + str(test_defs) + "\n" + str(defs))
+        
+    def test_defs_equal(self):
+        self.assertEqual(self.defs, self.defs2, "defs not the equal")
+        self.assertEqual(self.defs, self.defs3, "defs not the equal")
+        self.assertEqual(self.defs, self.defs4, "defs not the equal")
+        self.assertEqual(self.defs, self.defs5, "defs not the equal")
+
+    def tearDown(self):
+        do_tear_down()
+
+######################################################################################################
+class TestFamilies(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+         
+        home = os.path.join(os.getenv("HOME"),  "course") 
+        defs = Defs().add(
+            Suite("test").add(
+                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                Family("f1").add(
+                    Task("t1"),
+                    Task("t2"))))
+        defs.save_as_defs(test_def_file())
+         
+        self.defs = defs
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit
+         
+def create_family_f1():
+    return Family("f1",
+                Task("t1"),
+                Task("t2"))
+            
+#xx print("Creating suite definition") 
+home = os.path.join(os.getenv("HOME"),  "course") 
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f1()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+
+    def test_me(self):
+        import os
+         
+        #print("Creating suite definition")
+        home = os.path.join(os.getenv("HOME"),  "course") 
+        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
+        defs.test += Family("f1") + [ Task("t{0}".format(i)) for i in range(1,3) ]
+        defs.save_as_defs(test_def_file())
+
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))        
+ 
+    def tearDown(self):
+        do_tear_down()
+ 
+     
+class TestVariables(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+  
+        def create_family_f1():
+            return Family("f1" ).add(
+                Task("t1").add(Edit(SLEEP=20)),
+                Task("t2").add(Edit(SLEEP=20)))
+  
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs().add( Suite("test").add(
+                            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                            create_family_f1()))
+  
+        defs.save_as_defs(test_def_file())
+ 
+        self.defs = defs
+        
+    def test_me0(self):
+        text = """#import os
+from ecflow import Defs,Suite,Family,Task,Edit
+
+def create_family_f1():
+    return Family("f1",
+                Task("t1",Edit(SLEEP=20)),
+                Task("t2",Edit(SLEEP=20)))
+  
+#xx print("Creating suite definition")
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs(
+        Suite("test", 
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f1()))         
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def') 
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me2(self):
+        import os
+        home = os.path.join(os.getenv("HOME"), "course")
+  
+        with Defs() as defs: 
+            defs += Suite("test").add(
+                      Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home)) 
+            defs.test += Family("f1").add(
+                                Task("t1").add(Edit(SLEEP= 20)),
+                                Task("t2").add(Edit(SLEEP= 20)))                          
+        defs.save_as_defs(test_def_file())
+         
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+
+    def test_me3(self):
+        import os
+        home = os.path.join(os.getenv("HOME"), "course")
+  
+        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home)) 
+        defs.test += Family("f1") + (Task("t1") + Edit(SLEEP=20)) + (Task("t2") + Edit(SLEEP=20))                     
+        defs.save_as_defs(test_def_file())
+         
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+
+    def tearDown(self):
+        do_tear_down()
+         
+class TestVariableInheritance(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+         
+        def create_family_f1():
+            return Family("f1").add(
+                Edit(SLEEP=20),
+                Task("t1"),
+                Task("t2"))
+             
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs().add(Suite("test").add(
+                            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                            create_family_f1() ))
+        defs.save_as_defs(test_def_file())
+   
+        self.defs = defs;
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit
+
+def create_family_f1():
+    return Family("f1",
+            Edit(SLEEP=20),
+                Task("t1"),
+                Task("t2"))
+             
+#xx print("Creating suite definition")
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs(
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f1()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me(self):
+        import os
+         
+        def create_family_f1():
+            return Family("f1") + Edit(SLEEP=20) + Task("t1") + Task("t2")
+             
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs() + (Suite("test") + create_family_f1()) 
+        defs.test += [ Edit(ECF_HOME=home) , Edit(ECF_INCLUDE=home) ]
+        defs.save_as_defs(test_def_file())
+        
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def tearDown(self):
+        do_tear_down()
+   
+         
+class TestTriggers(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+         
+        def create_family_f1():
+            return Family("f1").add(
+                Edit(SLEEP=20),
+                Task("t1"),
+                Task("t2").add(Trigger("t1 == complete")))
+             
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs().add(Suite("test").add(
+                            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                            create_family_f1()))
+        defs.save_as_defs(test_def_file())
+  
+        self.defs = defs;
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger
+
+def create_family_f1():
+    return Family("f1",
+                Edit(SLEEP=20),
+                Task("t1"),
+                Task("t2",Trigger("t1 == complete")))
+             
+#xx print("Creating suite definition")
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f1()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+errors = defs.check()
+assert len(errors) == 0,errors
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me(self):
+        import os
+         
+        home = os.path.join(os.getenv("HOME"), "course")
+        with Suite("test") as suite:
+            suite += [ Edit(ECF_HOME=home) , Edit(ECF_INCLUDE=home) ]
+            suite += Family("f1") + Edit(SLEEP=20) + Task("t1") + Task("t2")
+            suite.f1.t2 += Trigger(["t1"]) 
+             
+        defs = Defs().add( suite )
+        defs.save_as_defs(test_def_file())
+         
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def tearDown(self):
+        do_tear_down()
+         
+         
+class TestEvents(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+ 
+        def create_family_f1():
+            return Family("f1").add(
+                        Edit(SLEEP=20),
+                        Task("t1"),
+                        Task("t2").add(
+                            Trigger("t1 == complete"),
+                            Event("a"),
+                            Event("b")),
+                        Task("t3").add(Trigger("t2:a")),
+                        Task("t4").add(Trigger("t2:b")))
+             
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs().add(
+            Suite("test").add(
+                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                create_family_f1() ))
+        defs.save_as_defs(test_def_file()) 
+  
+        self.defs = defs;
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Event
+
+def create_family_f1():
+    return Family("f1",
+                Edit(SLEEP=20),
+                Task("t1"),
+                Task("t2",
+                    Trigger("t1 == complete"),
+                    Event("a"),
+                    Event("b")),
+                Task("t3",
+                    Trigger("t2:a")),
+                Task("t4",
+                    Trigger("t2:b")))
+             
+#xx print("Creating suite definition")
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f1()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+errors = defs.check()
+assert len(errors) == 0,errors
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me(self):
+        import os
+ 
+        def create_family_f1():
+            f1 = Family("f1") + [ Edit(SLEEP=20),
+                    Task("t1"),
+                    Task("t2") + Trigger(["t1"]) + Event("a") + Event("b"),
+                    Task("t3") + Trigger("t2:a"),
+                    Task("t4") + Trigger("t2:b") ]
+            return f1
+         
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs() + Suite("test")
+        defs.test += [ Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home), create_family_f1()]
+        defs.save_as_defs(test_def_file())   
+         
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def tearDown(self):
+        do_tear_down()
+         
+         
+class TestComplete(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+ 
+        def create_family_f1():
+            return Family("f1").add(
+                Edit(SLEEP= 20),
+                Task("t1"),
+                Task("t2").add(Trigger("t1 == complete"),
+                               Event("a"), Event("b")),
+                Task("t3").add(Trigger("t2:a")),
+                Task("t4").add(Trigger("t2 == complete"), 
+                               Complete("t2:b")  ))
+        
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs().add(Suite("test").add(
+                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                create_family_f1() ))
+        defs.save_as_defs(test_def_file())   
+ 
+        self.defs = defs;
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event
+
+def create_family_f1():
+    return Family("f1",
+                Edit(SLEEP= 20),
+                Task("t1"),
+                Task("t2",
+                    Trigger("t1 == complete"),
+                    Event("a"), 
+                    Event("b")),
+                Task("t3",
+                    Trigger("t2:a")),
+                Task("t4",
+                    Trigger("t2 == complete"), 
+                    Complete("t2:b")))
+        
+#xx print("Creating suite definition")  
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f1()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+errors = defs.check()
+assert len(errors) == 0,errors
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me(self):
+        import os
+ 
+        def create_family_f1():
+            f1 = Family("f1") + Edit(SLEEP=20) 
+            f1 += [ Task("t{0}".format(i)) for i in range(1,5) ]
+            f1.t2 += [ Trigger(["t1"]), Event("a"), Event("b") ]
+            f1.t3 += Trigger("t2:a") 
+            f1.t4 += [ Trigger(["t2"]),Complete("t2:b") ]
+            return f1
+        
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
+        defs.test += create_family_f1()      
+        defs.save_as_defs(test_def_file())   
+         
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def tearDown(self):
+        do_tear_down()
+
+         
+class TestMeter(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+ 
+        def create_family_f1():
+            return Family("f1").add(
+                        Edit(SLEEP= 20),
+                        Task("t1").add(Meter("progress", 1, 100, 90)),
+                        Task("t2").add(Trigger("t1 == complete"),
+                                       Event("a"),
+                                       Event("b")),
+                        Task("t3").add(Trigger("t2:a")),
+                        Task("t4").add(Trigger("t2 == complete"),
+                                       Complete("t2:b")),
+                        Task("t5").add(Trigger("t1:progress ge 30")),
+                        Task("t6").add(Trigger("t1:progress ge 60")),
+                        Task("t7").add(Trigger("t1:progress ge 90")))  
+        
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs().add(Suite("test").add(
+                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                create_family_f1() ))
+        defs.save_as_defs(test_def_file())   
+ 
+        self.defs = defs;
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter
+
+def create_family_f1():
+    return Family("f1",
+                Edit(SLEEP= 20),
+                Task("t1", Meter("progress", 1, 100, 90)),
+                Task("t2", Trigger("t1 == complete"), Event("a"), Event("b")),
+                Task("t3", Trigger("t2:a")),
+                Task("t4", Trigger("t2 == complete"), Complete("t2:b")),
+                Task("t5", Trigger("t1:progress ge 30")),
+                Task("t6", Trigger("t1:progress ge 60")),
+                Task("t7", Trigger("t1:progress ge 90")))  
+        
+#xx print("Creating suite definition")  
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f1()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+errors = defs.check()
+assert len(errors) == 0,errors
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me(self):
+        import os
+ 
+        def create_family_f1():
+            f1 = Family("f1") + Edit(SLEEP=20) 
+            f1 += [ Task("t{0}".format(i)) for i in range(1,8)]
+            f1.t1 += Meter("progress", 1, 100, 90) 
+            f1.t2 += [ Trigger(["t1"]), Event("a"), Event("b") ]
+            f1.t3 += Trigger("t2:a")
+            f1.t4 += [ Trigger(["t2"]),Complete("t2:b") ]
+            f1.t5 += Trigger("t1:progress ge 30")  
+            f1.t6 += Trigger("t1:progress ge 60")  
+            f1.t7 += Trigger("t1:progress ge 90")  
+            return f1
+        
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs() + (Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
+        defs.test += create_family_f1()   
+        defs.save_as_defs(test_def_file())   
+         
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def tearDown(self):
+        do_tear_down()
+         
+         
+class TestTime(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+
+        def create_family_f2():
+            f2 = Family("f2")
+            f2.add_variable("SLEEP", 20)
+            f2.add_task("t1").add_time( "00:30 23:30 00:30" ) # start(hh:mm) end(hh:mm) increment(hh:mm)
+            f2.add_task("t2").add_day( "sunday" )
+   
+            # for add_date(): day,month,year; here 0 means every month, and every year
+            t3 = f2.add_task("t3")
+            t3.add_date(1, 0, 0)           # day month year, first of every month or every year
+            t3.add_time( 12, 0 )           # hour, minutes at 12 o'clock
+   
+            f2.add_task("t4").add_time( 0, 2, True ) # hour, minutes, relative to suite start
+                                                     # 2 minutes after family f2 start
+            f2.add_task("t5").add_time( 0, 2 )       # hour, minutes suite site
+                                                     # 2 minutes past midnight
+            return f2
+            
+        defs = Defs()
+        suite = defs.add_suite("test")
+        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
+        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
+
+        #suite.add_family( create_family_f1() )
+        suite.add_family( create_family_f2() )
+        errors = defs.check()
+        assert len(errors) == 0,errors
+
+        defs.save_as_defs(test_def_file())  
+ 
+        self.defs = defs;
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date
+
+def create_family_f2():
+    return Family("f2",
+            Edit(SLEEP=20),
+            Task("t1", Time("00:30 23:30 00:30")),     # start(hh:mm) end(hh:mm) increment(hh:mm)
+            Task("t2", Day("sunday")),
+            Task("t3", Date("1.*.*"), Time("12:00")),  # Date(day,month,year) - * means every day,month,year
+            Task("t4", Time("+00:02")),                # + means realative to suite begin/requeue time
+            Task("t5", Time("00:02")))                 # 2 minutes past midnight
+ 
+#xx print("Creating suite definition")  
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            #create_family_f1(),
+            create_family_f2()
+            ))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+errors = defs.check()
+assert len(errors) == 0,errors
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me(self):
+        import os
+  
+        def create_family_f2():
+            f1 = Family("f2") + Edit(SLEEP=20)
+            f1 += [ Task("t{0}".format(i)) for i in range(1,6) ]
+            f1.t1 += Time("00:30 23:30 00:30")  # start(hh:mm) end(hh:mm) increment(hh:mm)
+            f1.t2 += Day( "sunday" ) 
+            f1.t3 += [ Date("1.*.*"),    
+                       Time("12:00")]   
+            f1.t4 += Time("+00:02")  
+            f1.t5 += Time("00:02")    
+            return f1
+  
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs() + ( Suite("test") + Edit(ECF_HOME=home) + Edit(ECF_INCLUDE=home))
+        defs.test += create_family_f2()    
+        defs.save_as_defs(test_def_file())   
+          
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def test_add(self):
+        import os
+  
+        def create_family_f2():
+            return Family("f2").add(
+                Edit(SLEEP=20),
+                Task("t1").add( Time("00:30 23:30 00:30")),  
+                Task("t2").add( Day( "sunday" )),
+                Task("t3").add( Date("1.*.*"),   
+                                Time("12:00")),  
+                Task("t4").add( Time("+00:02")), 
+                Task("t5").add( Time("00:02")))  
+  
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs().add(Suite("test").add(
+                Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+                create_family_f2()))
+        defs.save_as_defs(test_def_file())   
+ 
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+        
+    def tearDown(self):
+        do_tear_down()
+     
+         
+class TestCron(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+
+        def create_family_house_keeping():
+            cron = Cron()
+            cron.set_week_days( [0] )
+            cron.set_time_series( "22:30" )
+            f2 = Family("house_keeping")
+            f2.add_task("clear_log").add_cron(cron)  
+            return f2
+            
+        defs = Defs()
+        suite = defs.add_suite("test")
+        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
+        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
+
+        #suite.add_family( create_family_f1() )
+        suite.add_family( create_family_house_keeping() )
+        errors = defs.check()
+        assert len(errors) == 0,errors
+
+        defs.save_as_defs(test_def_file())  
+ 
+        self.defs = defs;
+         
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Cron
+  
+def create_family_house_keeping():
+    return Family("house_keeping",
+                Task("clear_log",
+                    Cron("22:30",days_of_week=[0])))
+          
+print("Creating suite definition") 
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs(
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_house_keeping()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+errors = defs.check()
+assert len(errors) == 0,errors
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def tearDown(self):
+        do_tear_down()
+     
+class TestIndentation(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+
+        #version = sys.version_info 
+        #if version[1] < 7: 
+        #    #print "This example requires python version 2.7, but found : " + str(version)
+        #    exit(0)
+
+        with Defs() as defs: 
+    
+            with defs.add_suite("test") as suite:
+        
+                suite += Edit(ECF_HOME=os.path.join(os.getenv("HOME"),  "course"))
+                suite += Edit(ECF_INCLUDE =os.path.join(os.getenv("HOME"),  "course"))
+        
+            with suite.add_family("f1") as f1:
+                f1 += Edit(SLEEP=20)
+                f1 += Task("t1", Meter("progress", 1, 100, 90))
+                f1 += Task("t2", Trigger("t1 == complete"), Event("a"), Event("b"))
+                f1 += Task("t3", Trigger("t2:a"))
+                f1 += Task("t4", Trigger("t2 == complete"), Complete("t2:b"))
+                f1 += Task("t5", Trigger("t1:progress ge 30"))
+                f1 += Task("t6", Trigger("t1:progress ge 60"))
+                f1 += Task("t7", Trigger("t1:progress ge 90"))
+    
+            with suite.add_family("f2") as f2:        
+                f2 += Edit(SLEEP=20)
+                f2 += Task("t1", Time("00:30 23:30 00:30"))
+                f2 += Task("t2", Day("sunday"))
+                f2 += Task("t3", Date(1, 0, 0), Time(12, 0))
+                f2 += Task("t4", Time(0, 2, True))
+                f2 += Task("t5", Time(0, 2))
+            
+        defs.save_as_defs(test_def_file())
+        self.defs = defs;
+
+    def test_preferred(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date
+
+#xx print("Creating suite definition") 
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            Family("f1",
+                Edit(SLEEP=20),
+                Task("t1", Meter("progress", 1, 100, 90)),
+                Task("t2", Trigger("t1 == complete"),Event("a"),Event("b")),
+                Task("t3", Trigger("t2:a")),
+                Task("t4", Trigger("t2 == complete"), Complete("t2:b")),
+                Task("t5", Trigger("t1:progress ge 30")),
+                Task("t6", Trigger("t1:progress ge 60")),
+                Task("t7", Trigger("t1:progress ge 90"))),
+            Family("f2",
+                Edit(SLEEP=20),
+                Task("t1", Time( "00:30 23:30 00:30" )),
+                Task("t2", Day( "sunday" )),
+                Task("t3", Date("1.*.*"), Time("12:00")),
+                Task("t4", Time("+00:02")),
+                Task("t5", Time("00:02")))))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+assert len(defs.check()) == 0, defs.check()
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def test_me(self):
+        import os
+  
+        home = os.path.join(os.getenv("HOME"), "course")
+        with Defs() as defs:
+            with defs.add_suite("test") as suite:
+                suite += [ Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home) ]
+                with suite.add_family("f1") as f1:
+                    f1 += [ Task("t{0}".format(i)) for i in range(1,8)]
+                    f1 += Edit(SLEEP=20) 
+                    f1.t1 += Meter("progress", 1, 100, 90) 
+                    f1.t2 += [ Trigger(["t1"]), Event("a"), Event("b") ]
+                    f1.t3 += Trigger("t2:a") 
+                    f1.t4 += [ Trigger(["t2"]), Complete("t2:b") ]
+                    f1.t5 += Trigger("t1:progress ge 30") 
+                    f1.t6 += Trigger("t1:progress ge 60") 
+                    f1.t7 += Trigger("t1:progress ge 90") 
+                with suite.add_family("f2") as f2:
+                    f2 += [ Edit(SLEEP=20),[ Task("t{0}".format(i)) for i in range(1,6)] ]
+                    f2.t1 += Time( "00:30 23:30 00:30" )
+                    f2.t2 += Day( "sunday" ) 
+                    f2.t3 += [ Date("1.*.*"), Time("12:00") ]
+                    f2.t4 += Time("+00:02") 
+                    f2.t5 += Time("00:02") 
+          
+        defs.save_as_defs(test_def_file())   
+          
+        self.assertEqual(self.defs,defs,"defs not equal:\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def tearDown(self):
+        do_tear_down()
+        
+         
+class TestLabel(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+
+        def create_family_f3():
+            fam = Family('f3')
+            fam.add_task('t1').add_label("info","")
+            return fam
+            
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs()
+        suite = defs.add_suite("test")
+        suite.add_variable("ECF_HOME",    home)
+        suite.add_variable("ECF_INCLUDE", home)
+
+        suite.add_family( create_family_f3() )
+        errors = defs.check()
+        assert len(errors) == 0,errors
+
+        defs.save_as_defs(test_def_file())  
+ 
+        self.defs = defs;
+        
+    def test_me(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label
+
+def create_family_f3():
+    return Family("f3",
+                Task("t1",
+                Label("info","")))
+ 
+#xx print("Creating suite definition")  
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f3()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+assert len(defs.check()) == 0, defs.check()
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+        
+    def tearDown(self):
+        do_tear_down()
+         
+         
+class TestRepeat(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+        
+        self.ecf_home     = File.build_dir() + "/libs/pyext/test/data/course_py" + str(sys.version_info[0]) + "_" + str(os.getpid()) # allow paralled runs
+        self.ecf_includes = File.source_dir() + "/libs/pyext/test/data/includes"
+        #print("self.ecf_home ",self.ecf_home )
+ 
+        try:    os.makedirs( self.ecf_home + "/test/f4/f5")
+        except: pass
+         
+        t1_ecf = '%include <head.h>\n'
+        t1_ecf += 'ecflow_client --label=info "My name is %NAME% My value is %VALUE% My date is %DATE%\n'
+        t1_ecf += 'ecflow_client --label=date "year:%DATE_YYYY% month:%DATE_MM% day of month:%DATE_DD% day of week:%DATE_DOW%"\n'
+        t1_ecf += 'sleep %SLEEP%\n'
+        t1_ecf += '%include <tail.h>\n'
+         
+        self.t1_ecf_path = self.ecf_home + "/test/f4/f5/t1.ecf"
+        #print("self.t1_ecf_path",self.t1_ecf_path)
+        file = open(self.t1_ecf_path ,"w") 
+        file.write(t1_ecf)
+        file.close()
+    
+    def tearDown(self):
+        unittest.TestCase.tearDown(self)
+        do_tear_down()
+        os.remove(self.t1_ecf_path)
+        shutil.rmtree(self.ecf_home, ignore_errors=True)  
+     
+    def test_repeat0(self):
+    
+        def create_family_f4():
+            return Family("f4",
+                        Edit(SLEEP=2), 
+                        RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
+                        Family("f5",
+                            RepeatInteger("VALUE", 1, 10),
+                            Task("t1",
+                                RepeatDate("DATE", 20101230, 20110105),
+                                Label("info", ""),
+                                Label("date",""))))
+              
+        defs = Defs( 
+                Suite("test",
+                    Edit(ECF_HOME=self.ecf_home, ECF_INCLUDE=self.ecf_includes ),
+                    create_family_f4()))
+        #print(defs)
+ 
+        result = defs.check_job_creation()
+        self.assertEqual(result, "", "expected job creation to succeed " + result)
+ 
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
+                   RepeatString,RepeatInteger,RepeatDate
+        
+def create_family_f4():
+    return Family("f4",
+                Edit(SLEEP=2), 
+                RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
+                Family("f5",
+                    RepeatInteger("VALUE", 1, 10),
+                    Task("t1",
+                        RepeatDate("DATE", 20101230, 20110105),
+                        Label("info",""),
+                        Label("date",""))))
+ 
+#xx print("Creating suite definition")  
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f4()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+assert len(defs.check()) == 0,defs.check() 
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+
+    def test_repeat(self):
+     
+        #print("Creating suite definition") 
+        defs = Defs(
+                Suite("test",
+                    Edit(ECF_HOME=self.ecf_home,ECF_INCLUDE=self.ecf_includes),
+                    Family("f4",
+                        Edit(SLEEP=2), 
+                        RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
+                        Family("f5",
+                            RepeatInteger("VALUE", 1, 10),
+                            Task("t1",
+                                RepeatDate("DATE", 20101230, 20110105),
+                                Label("info", ""),
+                                Label("date",""))))))
+        #print(defs)
+ 
+        result = defs.check_job_creation()
+        self.assertEqual(result, "", "expected job creation to succeed " + result)
+ 
+        defs.save_as_defs(test_def_file())
+
+    def test_repeat3(self):
+     
+        defs = Defs().add( Suite("test") )
+        defs.test += [ { "ECF_INCLUDE":self.ecf_includes, "ECF_HOME":self.ecf_home }, 
+                        Family("f4") ]
+        defs.test.f4 += [   Edit(SLEEP=2),
+                            RepeatString("NAME", ["a", "b", "c", "d", "e", "f" ]),
+                            Family("f5") ]
+        defs.test.f4.f5 += [ RepeatInteger("VALUE", 1, 10),
+                            Task("t1")]
+        defs.test.f4.f5.t1 += [ RepeatDate("DATE", 20101230, 20110105),
+                                Label("info", ""),
+                                Label("date","") ]
+        #print(defs)
+        result = defs.check_job_creation()
+        self.assertEqual(result, "", "expected job creation to succeed " + result)
+ 
+        defs.save_as_defs(test_def_file())
+
+        
+class TestLimit(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+
+        def create_family_f5() :
+            f5 = Family("f5")
+            f5.add_inlimit("l1")
+            f5.add_variable("SLEEP", 20)
+            for i in range(1, 10):
+                f5.add_task( "t" + str(i) )
+            return f5
+          
+        defs = Defs()
+        suite = defs.add_suite("test")
+        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
+        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
+
+        suite.add_limit("l1", 2)
+        suite.add_family( create_family_f5() )
+        
+        defs.save_as_defs(test_def_file())
+        
+        self.defs = defs   
+        
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
+                   RepeatString,RepeatInteger,RepeatDate,InLimit,Limit
+         
+def create_family_f5() :
+    return Family("f5",
+            InLimit("l1"),
+            Edit(SLEEP=20),
+            [ Task('t{0}'.format(i)) for i in range(1,10) ] )
+     
+#xx print("Creating suite definition")  
+home = os.path.join(os.getenv("HOME"),"course")
+defs = Defs(
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            Limit("l1",2),
+            create_family_f5()))
+#xx print(defs)
+ 
+#xx print("Checking job creation: .ecf -> .job0") 
+#print(defs.check_job_creation())
+ 
+#xx print("Checking trigger expressions")
+assert len(defs.check()) == 0,defs.check()
+ 
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs(test_def_file()) 
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+
+    def tearDown(self):
+        do_tear_down()
+
+
+class TestLateAttribute(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+ 
+        def create_family_f6() :
+            f6 = Family("f6")
+            f6.add_variable("SLEEP", 120)
+            t1 = f6.add_task("t1")
+            late = Late()
+            late.complete(0,1,True)  # hour,minute,relative,    set late flag if task take longer than a minute
+            t1.add_late(late) 
+            return f6
+       
+        defs = Defs()
+        suite = defs.add_suite("test")
+        suite.add_variable("ECF_HOME",    os.path.join(os.getenv("HOME"),  "course"))
+        suite.add_variable("ECF_INCLUDE", os.path.join(os.getenv("HOME"),  "course"))
+        suite.add_family( create_family_f6() )
+        #print(defs)
+
+        assert len(defs.check()) == 0, defs.check()
+
+        defs.save_as_defs(test_def_file())
+        
+        self.defs = defs
+        
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
+                   RepeatString,RepeatInteger,RepeatDate,InLimit,Limit,Late
+        
+def create_family_f6():
+    # set late flag if task t1 takes longer than a minute
+    return Family("f6",
+                Edit(SLEEP=120),
+                Task("t1",
+                    Late(complete='+00:01')))
+     
+#xx print("Creating suite definition")   
+home = os.path.join(os.getenv("HOME"),"course")
+defs = Defs( 
+        Suite("test",
+            Edit(ECF_HOME=home),Edit(ECF_INCLUDE=home),
+            create_family_f6()))
+#xx print(defs) 
+
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+assert len(defs.check()) == 0,defs.check() 
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+
+    def tearDown(self):
+        do_tear_down()
+    
+
+class TestPythonScripting(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)
+        
+        def create_suite(name) : 
+            suite = Suite(name)
+            for i in range(1, 7) :
+                fam = suite.add_family("f" + str(i))
+                for t in ( "a", "b", "c", "d", "e" ) :
+                    fam.add_task(t)
+            return suite 
+    
+        self.defs = Defs(create_suite('s1'))   
+        
+    def test_me(self):
+        def create_suite(name) : 
+            return Suite(name,
+                    [ Family("f{0}".format(i),
+                        [ Task(t) for t in ( "a", "b", "c", "d", "e") ]) 
+                    for i in range(1,7) ])
+     
+        defs = Defs(create_suite('s1'))   
+
+        self.assertEqual(self.defs,defs,"defs not equal\n" + str(self.defs) + "\n" + str(defs))       
+  
+    def tearDown(self):
+        Ecf.set_debug_equality(False)      
+       
+
+class TestPythonScripting2(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)
+              
+        def create_sequential_suite(name) :
+            suite = Suite(name)
+            for i in range(1, 7) :
+                fam = suite.add_family("f" + str(i))
+                if i != 1: 
+                    fam.add_trigger("f" + str(i-1) + " == complete")  # or fam.add_family( "f%d == complete" % (i-1) )
+                for t in ( "a", "b", "c", "d", "e" ) :
+                    fam.add_task(t) 
+            return suite
+    
+        self.defs = Defs(create_sequential_suite('s1'))   
+        
+    def test_me(self):
+        def create_sequential_suite(name) :
+            suite = Suite(name)
+            for i in range(1, 7) :
+                fam = suite.add_family("f" + str(i))
+                if i != 1: 
+                    fam += Trigger("f" + str(i-1) + " == complete")  # or fam.add_family( "f%d == complete" % (i-1) )
+                for t in ( "a", "b", "c", "d", "e" ) :
+                    fam.add_task(t) 
+            return suite  
+     
+        defs = Defs(create_sequential_suite ('s1'))   
+
+        self.assertEqual(self.defs,defs,"defs not equal\n" + str(self.defs) + "\n" + str(defs))       
+         
+    def tearDown(self):
+        Ecf.set_debug_equality(False)      
+
+
+class TestDataAquistionSolution(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+        
+        defs = Defs()
+        suite = defs.add_suite("data_aquisition")
+        suite.add_repeat( RepeatDay(1) )
+        suite.add_variable("ECF_HOME",    os.getenv("HOME") + "/course")
+        suite.add_variable("ECF_INCLUDE", os.getenv("HOME") + "/course")
+        suite.add_variable("ECF_FILES",   os.getenv("HOME") + "/course/data")
+        suite.add_variable("SLEEP","2")
+        for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) :
+            fcity = suite.add_family(city)
+            fcity.add_task("archive")
+            for obs_type in ( "observations", "fields", "images" ):
+                type_fam = fcity.add_family(obs_type)
+                if city in ("Exeter", "Toulouse", "Offenbach"): type_fam.add_time("00:00 23:00 01:00")
+                if city in ("Washington") :                     type_fam.add_time("00:00 23:00 03:00")
+                if city in ("Tokyo") :                          type_fam.add_time("12:00")
+                if city in ("Melbourne") :                      type_fam.add_day( "monday" )
+                if city in ("Montreal") :                       type_fam.add_date(1, 0, 0)
+         
+                type_fam.add_task("get")
+                type_fam.add_task("process").add_trigger("get eq complete")
+                type_fam.add_task("store").add_trigger("get eq complete")
+                    
+        #print(defs)
+        self.defs = defs
+        
+    def test_me0(self):
+        text = """import os
+from ecflow import Defs,Suite,Family,Task,Edit,Trigger,Complete,Event,Meter,Time,Day,Date,Label, \
+                   RepeatString,RepeatInteger,RepeatDate
+
+home = os.path.join(os.getenv("HOME"), "course")
+defs = Defs(
+        Suite("data_aquisition",
+            RepeatDay(1),
+            Edit(ECF_HOME=home),
+            Edit(ECF_INCLUDE=home),
+            Edit(ECF_FILES=home + "/data"),
+            Edit(SLEEP=2)))
+for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) :
+    fcity = defs.data_aquisition.add_family(city)
+    fcity += Task("archive")
+    for obs_type in ( "observations", "fields", "images" ):
+        type_fam = fcity.add_family(obs_type)
+        if city in ("Exeter", "Toulouse", "Offenbach"): type_fam + Time("00:00 23:00 01:00")
+        if city in ("Washington") :                     type_fam + Time("00:00 23:00 03:00")
+        if city in ("Tokyo") :                          type_fam + Time("12:00")
+        if city in ("Melbourne") :                      type_fam + Day( "monday" )
+        if city in ("Montreal") :                       type_fam + Date(1, 0, 0)
+         
+        type_fam + Task("get") + Task("process",Trigger("get eq complete")) + Task("store",Trigger("get eq complete"))         
+ 
+#xx print("Checking job creation: .ecf -> .job0")  
+#print(defs.check_job_creation())
+
+#xx print("Checking trigger expressions")
+assert len(defs.check()) == 0, defs.check()
+
+#xx print("Saving definition to file 'test.def'")
+defs.save_as_defs('test.def')
+"""
+        test_compile(text)
+        test_defs = Defs(test_def_file())
+        self.assertEqual(test_defs,self.defs,"defs not equal\n" + str(test_defs) + "\n" + str(self.defs))
+
+    def test_me(self):
+        import os
+        
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs() + Suite("data_aquisition").add(
+                            RepeatDay(1),
+                            Edit(ECF_HOME=home),
+                            Edit(ECF_INCLUDE=home),
+                            Edit(ECF_FILES=home + "/data"),
+                            Edit(SLEEP=2))
+        for city in ( "Exeter", "Toulouse", "Offenbach", "Washington", "Tokyo", "Melbourne", "Montreal" ) :
+            fcity = defs.data_aquisition.add_family(city)
+            fcity += Task("archive")
+            for obs_type in ( "observations", "fields", "images" ):
+                type_fam = fcity.add_family(obs_type)
+                if city in ("Exeter", "Toulouse", "Offenbach"): type_fam + Time("00:00 23:00 01:00")
+                if city in ("Washington") :                     type_fam + Time("00:00 23:00 03:00")
+                if city in ("Tokyo") :                          type_fam + Time("12:00")
+                if city in ("Melbourne") :                      type_fam + Day( "monday" )
+                if city in ("Montreal") :                       type_fam + Date(1, 0, 0)
+         
+                type_fam += [ Task("get"),Task("process"),Task("store") ]
+                type_fam.process += Trigger("get eq complete") 
+                type_fam.store += Trigger("get eq complete")     
+
+        self.assertEqual(self.defs, defs, "defs not equal")
+
+    def tearDown(self):
+        Ecf.set_debug_equality(False)      
+
+
+class TestOperationalSolution(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+   
+        defs = Defs()
+        suite = defs.add_suite("operation_suite")
+        suite.add_repeat( RepeatDay(1) )
+        suite.add_variable("ECF_HOME",    os.getenv("HOME") + "/course")
+        suite.add_variable("ECF_INCLUDE", os.getenv("HOME") + "/course")
+        suite.add_variable("ECF_FILES",   os.getenv("HOME") + "/course/oper")
+  
+        # Defines the triggers for the first cycle
+        cycle_triggers = "1"
+        for cycle in ( "00" , "12" ):
+
+            if cycle == "12" :
+                last_step = 240
+            else:
+                last_step = 24
+ 
+            fcycle_fam = suite.add_family(cycle)
+            fcycle_fam.add_variable("CYCLE", cycle)
+            fcycle_fam.add_variable("LAST_STEP", last_step)
+      
+            if cycle_triggers != "1" :
+                fcycle_fam.add_trigger(cycle_triggers)
+                 
+            analysis_fam = fcycle_fam.add_family("analysis")
+            analysis_fam.add_task("get_observations")
+            analysis_fam.add_task("run_analysis").add_trigger("get_observations == complete")
+            analysis_fam.add_task("post_processing").add_trigger("run_analysis == complete")
+ 
+            forecast_fam = fcycle_fam.add_family("forecast")
+            forecast_fam.add_trigger("analysis == complete")
+            forecast_fam.add_task("get_input_data") 
+            run_forecast_task = forecast_fam.add_task("run_forecast") 
+            run_forecast_task.add_trigger("get_input_data == complete")
+            run_forecast_task.add_meter("step", 0, last_step, last_step)
+ 
+            archive_fam = fcycle_fam.add_family("archive")
+            fam_analsis = archive_fam.add_family("analysis")
+            fam_analsis.add_variable("TYPE","analysis")
+            fam_analsis.add_variable("STEP","0")
+            fam_analsis.add_trigger("../analysis/run_analysis == complete")
+            fam_analsis.add_task("save")
+    
+            for i in range(6, last_step+1, 6):  
+                step_fam = fam_analsis.add_family("step_" + str(i))     
+                step_fam.add_variable("TYPE", "forecast")  
+                step_fam.add_variable("STEP", i)  
+                step_fam.add_trigger("../../forecast/run_forecast:step ge " + str(i))
+                step_fam.add_task("save")
+
+            # Defines the triggers for the next cycle
+            cycle_triggers = "./" + cycle + " == complete"   
+                 
+        #print(defs)
+        self.defs = defs
+        
+    def test_sol1(self):
+        import os
+         
+        home = os.getenv("HOME") + "/course"
+        cycle_triggers = None
+        last_step = { "12": 240,
+                      "00": 24, }
+         
+        def cycle_trigger(cycle):
+            if cycle == "12": return Trigger("./00 == complete")
+            return None
+         
+        defs = Defs(
+            Suite("operation_suite",
+                RepeatDay(1),
+                Edit(ECF_HOME= home),
+                Edit(ECF_INCLUDE= home),
+                Edit(ECF_FILES= home + "/oper"),
+                [ Family(cycle,
+                    Edit(CYCLE=cycle),
+                    Edit(LAST_STEP=last_step[cycle]),
+        
+                    cycle_trigger(cycle),
+                    
+                    Family("analysis",
+                        Task("get_observations"),
+                        Task("run_analysis", Trigger(["get_observations"])),
+                        Task("post_processing", Trigger(["run_analysis"]))
+                    ),
+    
+                    Family("forecast",
+                        Trigger(["analysis"]),
+                        Task("get_input_data"),
+                        Task("run_forecast",
+                            Trigger(["get_input_data"]),
+                            Meter("step", 0, last_step[cycle])),
+                    ),
+                                           
+                    Family("archive",
+                        Family("analysis",
+                            Edit(TYPE="analysis"),
+                            Edit(STEP=0),
+                            Trigger("../analysis/run_analysis == complete"),
+                            Task("save"),
+                            [ Family("step_{0}".format(i),
+                                Edit(TYPE="forecast"),
+                                Edit(STEP=i),
+                                Trigger("../../forecast/run_forecast:step ge {0}".format(i)),
+                                Task("save"))
+                             for i in range(6, last_step[cycle]+1, 6) ]
+                        )
+                    )
+                ) for cycle in ( "00" , "12" ) ] 
+            )
+        )
+        #print(defs)
+        
+        self.assertEqual(self.defs, defs, "defs not equal")
+
+    def tearDown(self):
+        Ecf.set_debug_equality(False)      
+
+
+class TestBackArchivingSolution(unittest.TestCase):
+    def setUp(self):
+        Ecf.set_debug_equality(True)      
+    
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs()
+        suite = defs.add_suite("back_archiving")
+        suite.add_repeat( RepeatDay(1) )
+        suite.add_variable("ECF_HOME",    home)
+        suite.add_variable("ECF_INCLUDE", home)
+        suite.add_variable("ECF_FILES",   home + "/back")
+        suite.add_variable("SLEEP", "2")
+        suite.add_limit("access", 2)
+        for kind in ( "analysis", "forecast", "climatology", "observations", "images" ):
+            find_fam = suite.add_family(kind)
+            find_fam.add_repeat( RepeatDate("DATE", 19900101, 19950712) )
+            find_fam.add_variable("KIND", kind)
+            find_fam.add_task("get_old").add_inlimit("access")
+            find_fam.add_task("convert").add_trigger("get_old == complete")
+            find_fam.add_task("save_new").add_trigger("convert == complete")
+             
+        #print(defs)
+         
+        self.defs = defs
+         
+    def test_sol1(self):
+        import os
+        home = os.path.join(os.getenv("HOME"), "course")
+        defs = Defs( 
+            Suite("back_archiving",
+                RepeatDay(1),
+                Edit(ECF_HOME=home),
+                Edit(ECF_INCLUDE=home),
+                Edit(ECF_FILES= home + "/back"),
+                Edit(SLEEP=2),
+                Limit("access", 2),
+                [ Family(kind,
+                    RepeatDate( "DATE", 19900101, 19950712 ),
+                    Edit(KIND=kind),
+                    Task("get_old",  InLimit("access")),
+                    Task("convert",  Trigger("get_old == complete")),
+                    Task("save_new", Trigger("convert == complete")))
+                  for kind in ( "analysis", "forecast", "climatology", "observations", "images" ) ] ))
+        #print(defs)
+
+        self.assertEqual(self.defs, defs, "defs not equal")
+
+    def tearDown(self):
+        Ecf.set_debug_equality(False)      
+
+if __name__ == "__main__":
+    unittest.main()
+    print("All Tests pass")
diff -pruN 5.12.4-1/libs/pyext/unicode.py 5.13.0-1/libs/pyext/unicode.py
--- 5.12.4-1/libs/pyext/unicode.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/pyext/unicode.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+# Determine the python unicode
+
+import sys
+if sys.maxunicode > 65535:
+    print('UCS4 build')
+else:
+    print('UCS2 build')
diff -pruN 5.12.4-1/libs/rest/CMakeLists.txt 5.13.0-1/libs/rest/CMakeLists.txt
--- 5.12.4-1/libs/rest/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,156 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+# cpp-httplib requires at least OpenSSL 1.1.1 for https support
+# so if we have OpenSSL enabled and the version is less than this,
+# we should disable SSL capabilities from the HTTP server
+
+if (OPENSSL_FOUND)
+  if (OPENSSL_VERSION VERSION_LESS 1.1.1)
+    ecbuild_warn("HTTP_SERVER requires at least OpenSSL 1.1.1 for https support (have version ${OPENSSL_VERSION}) - disabling https in HTTP server")
+    remove_definitions(-DECF_OPENSSL)
+    set(DISABLED_SSL_IN_HTTP_SERVER 1)
+  endif ()
+endif ()
+
+set(srcs
+  # Headers
+  src/ecflow/http/Api.hpp
+  src/ecflow/http/ApiV1.hpp
+  src/ecflow/http/ApiV1Impl.hpp
+  src/ecflow/http/Base64.hpp
+  src/ecflow/http/BasicAuth.hpp
+  src/ecflow/http/Client.hpp
+  src/ecflow/http/DefsStorage.hpp
+  src/ecflow/http/HttpServer.hpp
+  src/ecflow/http/HttpServerException.hpp
+  src/ecflow/http/JSON.hpp
+  src/ecflow/http/Options.hpp
+  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/http/TokenStorage.hpp>
+  src/ecflow/http/TreeGeneration.hpp
+  src/ecflow/http/TypeToJson.hpp
+  # Sources
+  src/ecflow/http/Api.cpp
+  src/ecflow/http/ApiV1.cpp
+  src/ecflow/http/ApiV1Impl.cpp
+  src/ecflow/http/BasicAuth.cpp
+  src/ecflow/http/Client.cpp
+  src/ecflow/http/DefsStorage.cpp
+  src/ecflow/http/HttpServer.cpp
+  src/ecflow/http/JSON.cpp
+  src/ecflow/http/Options.cpp
+  src/ecflow/http/TypeToJson.cpp
+  $<$<BOOL:${OPENSSL_FOUND}>:src/ecflow/http/TokenStorage.cpp>
+)
+
+ecbuild_add_library(
+  TARGET libhttp
+  NOINSTALL
+  TYPE STATIC
+  SOURCES
+    ${srcs}
+  PUBLIC_INCLUDES
+    src
+  PUBLIC_LIBS
+    ecflow_all
+    nlohmann::json
+    httplib::httplib
+    $<$<BOOL:${ZLIB_FOUND}>:ZLIB::ZLIB>
+  PUBLIC_DEFINITIONS
+    $<$<BOOL:${ZLIB_FOUND}>:ECF_HTTP_COMPRESSION>
+)
+target_clangformat(libhttp)
+
+# ========================================================================
+# EXE ecflow_http, if OpenSSL not enabled ${OPENSSL_LIBRARIES}, is empty
+
+ecbuild_add_executable(
+  TARGET ecflow_http
+  SOURCES
+    src/ecflow/http/HttpMain.cpp
+  LIBS
+    libhttp
+    ecflow_all
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+)
+target_clangformat(ecflow_http)
+
+# Override default behaviour that add RPATHS during install
+# The only thing that seem to work is set INSTALL_RPATH to ""
+# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
+# had no effect
+#          
+SET_TARGET_PROPERTIES(ecflow_http
+  PROPERTIES
+  INSTALL_RPATH ""
+)
+
+# use, i.e. don't skip the full RPATH for the build tree
+#SET(CMAKE_SKIP_BUILD_RPATH  FALSE)
+
+# when building, don't use the install RPATH already
+# (but later on when installing)
+#SET(CMAKE_BUILD_WITH_INSTALL_RPATH FALSE) 
+
+# the RPATH to be used when installing
+#SET(CMAKE_INSTALL_RPATH "")
+
+# don't add the automatically determined parts of the RPATH
+# which point to directories outside the build tree to the install RPATH
+#SET(CMAKE_INSTALL_RPATH_USE_LINK_PATH FALSE)
+
+if (ENABLE_HTTP AND ENABLE_SERVER)
+
+  if (OPENSSL_FOUND AND NOT DISABLED_SSL_IN_HTTP_SERVER)
+
+    set(test_srcs
+      # Headers
+      test/Certificate.hpp
+      test/InvokeServer.hpp
+      test/TokenFile.hpp
+      # Sources
+      test/TestApiV1.cpp
+      test/TestHttp_main.cpp # test entry point
+    )
+
+    ecbuild_add_test(
+      TARGET
+        s_http
+      LABELS
+        integration nightly
+      SOURCES
+        ${test_srcs}
+      INCLUDES
+        ../base/test
+      LIBS
+        libhttp
+        ecflow_all
+        Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+        $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+      DEPENDS
+        ecflow_server # the server is launched to support tests
+        ecflow_http
+      TEST_DEPENDS
+        u_base
+        s_client
+    )
+    target_clangformat(s_http
+      CONDITION ENABLE_TESTS
+    )
+  else ()
+    message(WARNING "SSL not enabled - will not run HTTP server tests")
+  endif ()
+
+endif ()
+
+# ===================================================================
+# install
+# ===================================================================
+install(TARGETS ecflow_http DESTINATION bin)
diff -pruN 5.12.4-1/libs/rest/doc/openapi.yaml 5.13.0-1/libs/rest/doc/openapi.yaml
--- 5.12.4-1/libs/rest/doc/openapi.yaml	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/doc/openapi.yaml	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1403 @@
+openapi: "3.0.0"
+info:
+  version: 1.0.0
+  title: ecFlow REST API
+paths:
+  /suites:
+    get:
+      summary: List all suites
+      operationId: listSuites
+      tags:
+        - suites
+      parameters:
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: A list of suites
+          content:
+            application/json:
+              schema:
+                type: array
+                items:
+                  type: string
+                uniqueItems: true
+              example: ["foo", "bar"]
+
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+    post:
+      summary: Create a new suite
+      operationId: createSuite
+      tags:
+        - suites
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: New suite definition
+        content:
+          application/json:
+            schema:
+              type: object
+              properties:
+                definition:
+                  type: string
+                  example: "suite foo\ntask bar\nendsuite"
+                auto_add_externs:
+                  type: boolean
+                  default: false
+              required:
+              - definition
+      responses:
+        '201':
+          description: Expected response
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+  /suites/tree:
+    get:
+      summary: Show all nodes (suites, families and tasks) as a tree
+      operationId: treeSuites
+      tags:
+        - suites
+      parameters:
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+        - name: content
+          in: query
+          required: false
+          description: Specify tree content
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Full node tree
+          content:
+            application/json:
+              schema:
+                type: object
+              example:
+                foo:
+                   baz: {}
+                bar: {}
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+
+  /suites/{nodeName}/tree:
+    get:
+      summary: Show this node and its children as a tree
+      operationId: treeNodes
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to retrieve
+          schema:
+            type: string
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+        - name: content
+          in: query
+          required: false
+          description: Specify tree content
+          schema:
+            type: string
+      responses:
+        '200':
+          description: A tree of nodes
+          content:
+            application/json:
+              schema:
+                type: object
+              example:
+                baz: {}
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+  /suites/{nodeName}/status:
+    get:
+      summary: Show status of a node (suite, family or task)
+      operationId: showNodeStatus
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to retrieve
+          schema:
+            type: string
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Status of the node
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  default_status:
+                    type: string
+                  status:
+                    type: string
+                  why:
+                    type: object
+                    properties:
+                      bottom_up_why:
+                        type: array
+                        items:
+                          type: string
+                      top_down_why:
+                        type: array
+                        items: 
+                          type: string
+              example:
+                default_status: queued
+                status: complete
+                why:
+                  bottom_up_why: [ "SUITE:/foo is suspended" ]
+                  top_down_why: [ "SUITE:/foo is suspended" ]
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    put:
+      summary: Update status of a node (suite, family or task)
+      operationId: updateNodeStatus
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to update
+          schema:
+            type: string
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuthh: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: action to take on node
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/Action'
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+  /suites/{nodeName}/attributes:
+    get:
+      summary: Show attributes of a node (suite, family or task)
+      operationId: showNodeAttributes
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to show
+          schema:
+            type: string
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Description of node attributes
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Attributes"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+    put:
+      summary: Update an attribute of a node (suite, family or task)
+      operationId: updateNodeAttribute
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to update
+          schema:
+            type: string
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: attribute to update
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/Attribute'
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    post:
+      summary: Create a new attribute for a node (suite, family or task)
+      operationId: createNodeAttribute
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of node where attribute is added
+          schema:
+            type: string
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: attribute to create
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/Attribute'
+      responses:
+        '201':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    delete:
+      summary: Remove an attribute of a node (suite, family or task)
+      operationId: removeNodeAttribute
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to update
+          schema:
+            type: string
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: attribute to remove
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/Attribute'
+      responses:
+        '204':
+          description: Expected response to a valid request
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+
+  /suites/{nodeName}/definition:
+    get:
+      summary: Show ecFlow definition of a node (suite, family or task)
+      operationId: showNodeDefinition
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to retrieve
+          schema:
+            type: string
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  definition:
+                    type: string
+                    example: "suite foo\nendsuite"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    put:
+      summary: Update definition of a node (suite, family or task)
+      operationId: updateNodeDefinition
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node which definition is updated
+          schema:
+            type: string
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: New definition
+        content:
+          application/json:
+            schema:
+              type: object
+              properties:
+                definition:
+                  type: string
+                  example: "family bar\nendfamily"
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    delete:
+      summary: Remove a node (suite, family or task)
+      operationId: removeNode
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to remove
+          schema:
+            type: string
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+      responses:
+        '204':
+          description: Expected response to a valid request
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+  /suites/{nodeName}/script:
+    get:
+      summary: Show script for a task
+      operationId: showNodeScript
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to retrieve (must be a task)
+          schema:
+            type: string
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Script contents
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  script:
+                    type: string
+                  job:
+                    type: string
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+  /suites/{nodeName}/output:
+    get:
+      summary: Show output of a task
+      operationId: showNodeOutput
+      tags:
+        - nodes
+      parameters:
+        - name: nodeName
+          in: path
+          required: true
+          description: The name of the node to retrieve (must be a task)
+          schema:
+            type: string
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  job_output:
+                    type: string
+                  kill_output:
+                    type: string
+                  status_output:
+                    type: string
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+  /server/status:
+    get:
+      summary: Show ecFlow server status
+      operationId: showServerStatus
+      tags:
+        - server
+      parameters:
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                type: object
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    put:
+      summary: Update ecFlow server status
+      operationId: updateServerStatus
+      tags:
+        - server
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: action to take on ecFlow server
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/ServerAction'
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+  /server/ping:
+    get:
+      summary: Ping ecFlow server
+      operationId: pingServer
+      tags:
+        - server
+      parameters:
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  host:
+                    type: string
+                  round_trip_time:
+                    type: string
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+  /server/attributes:
+    get:
+      summary: Show ecFlow server attributes
+      operationId: showServerAttributes
+      tags:
+        - server
+      parameters:
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                type: array
+                items:
+                  $ref: '#/components/schemas/ServerAttribute'
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    put:
+      summary: Update ecFlow server attribute
+      operationId: changeServerAttribute
+      tags:
+        - server
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: attribute to change
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/ServerAttribute'
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    delete:
+      summary: Remove ecFlow server attribute
+      operationId: removeServerAttribute
+      tags:
+        - server
+      responses:
+        '204':
+          description: Expected response to a valid request
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+    post:
+      summary: Create a new ecFlow server attribute
+      operationId: createServerAttribute
+      tags:
+        - server
+      security:
+        - BasicAuth: []
+        - TokenAuth: []
+        - ApiKeyAuth: []
+        - ApiKeyAuthLegacy: []
+      requestBody:
+        required: true
+        description: attribute to create
+        content:
+          application/json:
+            schema:
+              $ref: '#/components/schemas/ServerAttribute'
+      responses:
+        '201':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Success20x"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+  /statistics:
+    get:
+      summary: Show REST api statistics
+      operationId: showApiStatistics
+      tags:
+        - api
+      parameters:
+        - name: filter
+          in: query
+          required: false
+          description: Filter results
+          schema:
+            type: string
+      responses:
+        '200':
+          description: Expected response to a valid request
+          content:
+            application/json:
+              schema:
+                type: object
+                properties:
+                  num_requests:
+                    type: integer
+                    example: 1
+                  num_errors:
+                    type: integer
+                    example: 0
+                  num_cached_requests:
+                    type: integer
+                    example: 1
+                  since:
+                    type: string
+                    example: "2022-10-06T12:00:00Z"
+        default:
+          description: unexpected error
+          content:
+            application/json:
+              schema:
+                $ref: "#/components/schemas/Error"
+
+
+components:
+  schemas:
+    ServerAction:
+      type: object
+      required:
+      - action
+      properties:
+        action:
+          type: string
+          enum: [reload_whitelist_file, reload_passwd_file, reload_custom_passwd_file]
+          example: reload_whitelist_file
+    ServerAttribute:
+      type: object
+      required:
+      - type
+      - name
+      - value
+      properties:
+        type:
+          type: string
+          enum: [variable]
+          example: variable
+        name:
+          type: string
+          example: foo
+        value:
+          type: string
+          example: bar
+    Action:
+      type: object
+      required:
+      - action
+      properties:
+        action:
+          type: string
+          enum: [abort, begin, complete, defstatus, execute, init, requeue, rerun, resume, submit, suspend]
+          example: complete
+        recursive:
+          type: boolean
+          default: false
+        force:
+          type: boolean
+          default: false
+        abort_why:
+          type: string
+        defstatus_value:
+          type: string
+    Attribute:
+      type: object
+      required:
+      - type
+      properties:
+        type:
+          type: string
+          enum: [autoarchive, autocancel, autorestore, complete, cron, day, date, event, generic, inlimit, label, late, limit, meter, queue, repeat, time, today, trigger, variable]
+          example: variable
+        name:
+          type: string
+        value:
+          type: string
+        old_value:
+          type: string
+        min:
+          type: string
+        max:
+          type: string
+    Success20x:
+      type: object
+      required:
+        - message
+      properties:
+        message:
+          type: string
+        path:
+          type: string
+    Error:
+      type: object
+      required:
+        - code
+        - message
+      properties:
+        status:
+          type: integer
+        message:
+          type: string
+        path:
+          type: string
+        method:
+          type: string
+        body:
+          type: string
+    Meter:
+      type: object
+      required:
+        - name
+        - value
+        - min
+        - max
+      properties:
+        name:
+          type: string
+        value:
+          type: integer
+        max:
+          type: integer
+        min:
+          type: integer
+    Event:
+      type: object
+      required:
+        - name
+        - value
+      properties:
+        name:
+          type: string
+        value:
+          type: string
+        initial_value:
+          type: string
+    Label:
+      type: object
+      required:
+        - name
+        - value
+      properties:
+        name:
+          type: string
+        value:
+          type: string
+    Variable:
+      type: object
+      required:
+        - name
+        - value
+      properties:
+        name:
+          type: string
+        value:
+          type: string
+        const:
+          type: boolean
+          default: false
+    Limit:
+      type: object
+      required:
+        - name
+        - value
+        - limit
+      properties:
+        name:
+          type: string
+        value:
+          type: string
+        limit:
+          type: integer
+    InLimit:
+      type: object
+      required:
+        - value
+      properties:
+        value:
+          type: string
+    Date:
+      type: object
+      required:
+        - value
+        - free
+      properties:
+        value:
+          type: string
+        free:
+          type: boolean
+    Day:
+      type: object
+      required:
+        - value
+        - free
+        - expired
+      properties:
+        value:
+          type: string
+        free:
+          type: boolean
+        expired:
+          type: boolean
+    Time:
+      type: object
+      required:
+        - value
+        - free
+      properties:
+        value:
+          type: string
+        free:
+          type: boolean
+    Today:
+      type: object
+      required:
+        - value
+        - free
+        - expired
+      properties:
+        value:
+          type: string
+        free:
+          type: boolean
+        expired:
+          type: boolean
+    Cron:
+      type: object
+      required:
+        - value
+      properties:
+        value:
+          type: string
+    Expression:
+      type: object
+      required:
+        - free
+        - value
+        - expressions
+      properties:
+        free:
+          type: boolean
+        value:
+          type: string
+        expressions:
+          type: array
+          items:
+            type:
+              string
+    Flag:
+      type: object
+      required:
+        - value
+      properties:
+        value:
+          type: string
+    Late:
+      type: object
+      required:
+        - value
+      properties:
+        value:
+          type: string
+        submitted:
+          type: string
+        active:
+          type: string
+        complete:
+          type: string
+        complete_is_relative:
+          type: boolean
+        is_late:
+          type: boolean
+    Zombie:
+      type: object
+      properties:
+        type:
+          type: string
+        action:
+          type: string
+        child_commands:
+          type: string
+        lifetime:
+          type: string
+    Queue:
+      type: object
+      required:
+        - name
+        - queue
+        - value
+        - index
+      properties:
+        name:
+          type: string
+        queue:
+          type: array
+          items:
+            type: string
+        index:
+          type: integer
+        value:
+          type: string
+    Generic:
+      type: object
+      required:
+        - name
+        - value
+      properties:
+        name:
+          type: string
+        value:
+          type: array
+          items:
+            type:
+              string
+    TimeSlot:
+      type: object
+      required:
+        - value
+      properties:
+        value:
+          type: string
+    AutoCancel:
+      type: object
+      required:
+        - relative
+        - days
+        - time
+        - value
+      properties:
+        relative:
+          type: boolean
+        value:
+          type: string
+        days:
+          type: boolean
+        time:
+          type: object
+          allOf:
+            - $ref: "#/components/schemas/TimeSlot"
+    AutoRestore:
+      type: object
+      required:
+        - value
+      properties:
+        value:
+          type: array
+          items:
+            type: string
+    AutoArchive:
+      type: object
+      required:
+        - relative
+        - days
+        - time
+        - value
+      properties:
+        relative:
+          type: boolean
+        value:
+          type: string
+        days:
+          type: boolean
+        time:
+          type: object
+          allOf:
+            - $ref: "#/components/schemas/TimeSlot"
+    RepeatDate:
+      type: object
+      required:
+        - name
+        - start
+        - end
+        - step
+        - value
+      properties:
+        name:
+          type: string
+        start:
+          type: integer
+        step:
+          type: integer
+        end:
+          type: integer
+        value:
+          type: integer
+    RepeatDateList:
+      type: object
+      required:
+        - name
+        - index
+        - value
+        - values
+      properties:
+        name:
+          type: string
+        index:
+          type: integer
+        value:
+          type: string
+        values:
+          type: array
+          items:
+            type: string
+    RepeatInteger:
+      type: object
+      required:
+        - name
+        - start
+        - step
+        - end
+        - value
+      properties:
+        name:
+          type: string
+        start:
+          type: integer
+        step:
+          type: integer
+        end:
+          type: integer
+        value:
+          type: integer
+    RepeatDay:
+      type: object
+      required:
+        - name
+        - step
+        - valid
+      properties:
+        name:
+          type: string
+        step:
+          type: integer
+        valid:
+          type: boolean
+    RepeatEnumerated:
+      type: object
+      required:
+        - name
+        - index
+        - value
+        - values
+      properties:
+        name:
+          type: string
+        index:
+          type: integer
+        value:
+          type: string
+        values:
+          type: array
+          items:
+            type: string
+    RepeatString:
+      type: object
+      required:
+        - name
+        - index
+        - value
+        - values
+      properties:
+        name:
+          type: string
+        index:
+          type: integer
+        value:
+          type: string
+        values:
+          type: array
+          items:
+            type: string
+    Attributes:
+      type: object
+      required:
+        - meters
+        - events
+        - labels
+        - variables
+        - inherited_variables
+        - limits
+        - inlimits
+        - dates
+        - days
+        - times
+        - todays
+        - crons
+        - repeat
+        - triggers
+        - completes
+        - flag
+        - late
+        - zombie
+        - queue
+        - generic
+        - autocancel
+        - autoarchive
+        - autorestore
+      properties:
+        events:
+          type: array
+          items:
+            $ref: "#/components/schemas/Event"
+        meters:
+          type: array
+          items:
+            $ref: "#/components/schemas/Meter"
+        labels:
+          type: array
+          items:
+            $ref: "#/components/schemas/Label"
+        variables:
+          type: array
+          items:
+            $ref: "#/components/schemas/Variable"
+        inherited_variables:
+          type: object
+          properties:
+            server:
+              type: array
+              items:
+                $ref: "#/components/schemas/Variable"
+        limits:
+          type: array
+          items:
+            $ref: "#/components/schemas/Limit"
+        inlimits:
+          type: array
+          items:
+            $ref: "#/components/schemas/InLimit"
+        dates:
+          type: array
+          items:
+            $ref: "#/components/schemas/Date"
+        days:
+          type: array
+          items:
+            $ref: "#/components/schemas/Day"
+        times:
+          type: array
+          items:
+            $ref: "#/components/schemas/Time"
+        todays:
+          type: array
+          items:
+            $ref: "#/components/schemas/Today"
+        crons:
+          type: array
+          items:
+            $ref: "#/components/schemas/Cron"
+        repeat:
+          type: object
+          oneOf:
+            - $ref: "#/components/schemas/RepeatDate"
+            - $ref: "#/components/schemas/RepeatDateList"
+            - $ref: "#/components/schemas/RepeatInteger"
+            - $ref: "#/components/schemas/RepeatDay"
+            - $ref: "#/components/schemas/RepeatString"
+            - $ref: "#/components/schemas/RepeatEnumerated"
+        triggers:
+          type: array
+          items:
+            $ref: "#/components/schemas/Expression"
+        completes:
+          type: array
+          items:
+            $ref: "#/components/schemas/Expression"
+        flag:
+          type: object
+          allOf:
+            - $ref: "#/components/schemas/Flag"
+        late:
+          type: object
+          allOf:
+            - $ref: "#/components/schemas/Late"
+        zombies:
+          type: array
+          items:
+            $ref: "#/components/schemas/Zombie"
+        queues:
+          type: array
+          items:
+            $ref: "#/components/schemas/Queue"
+        generics:
+          type: array
+          items:
+            $ref: "#/components/schemas/Generic"
+        autocancel:
+          allOf:
+            - $ref: "#/components/schemas/AutoCancel"
+        autorestore:
+          type: object
+          allOf:
+            - $ref: "#/components/schemas/AutoRestore"
+        autoarchive:
+          type: object
+          allOf:
+            - $ref: "#/components/schemas/AutoArchive"
+ 
+  securitySchemes:
+    BasicAuth:
+      type: http
+      scheme: basic
+    TokenAuth:
+      type: http
+      scheme: bearer
+    ApiKeyAuth:
+      type: apiKey
+      in: header
+      name: X-API-Key
+    ApiKeyAuthLegacy:
+      type: apiKey
+      in: query
+      name: key
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/Api.cpp 5.13.0-1/libs/rest/src/ecflow/http/Api.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/Api.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/Api.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/Api.hpp"
+
+#include "ecflow/http/ApiV1.hpp"
+#include "ecflow/http/DefsStorage.hpp"
+#include "ecflow/http/Options.hpp"
+
+namespace ecf::http {
+
+void setup(httplib::Server& http_server) {
+    routing(http_server);
+    update_defs_loop(opts.polling_interval);
+
+    if (opts.verbose) {
+        printf("API v1 ready\n");
+    }
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/Api.hpp 5.13.0-1/libs/rest/src/ecflow/http/Api.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/Api.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/Api.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_Api_HPP
+#define ecflow_http_Api_HPP
+
+#include "ecflow/http/HttpLibrary.hpp"
+
+namespace ecf::http {
+
+void setup(httplib::Server& server);
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_Api_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/ApiV1.cpp 5.13.0-1/libs/rest/src/ecflow/http/ApiV1.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/ApiV1.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/ApiV1.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,741 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/ApiV1.hpp"
+
+#include <atomic>
+#include <mutex>
+#include <string>
+
+#include <sys/time.h>
+
+#include "ecflow/core/Str.hpp"
+#include "ecflow/http/ApiV1Impl.hpp"
+#include "ecflow/http/Client.hpp"
+#include "ecflow/http/HttpServerException.hpp"
+#include "ecflow/http/Options.hpp"
+#include "ecflow/http/TypeToJson.hpp"
+#include "ecflow/node/Defs.hpp"
+
+namespace ecf::http {
+
+static std::chrono::system_clock::time_point api_startup;
+
+std::atomic<unsigned int> num_requests(0);
+std::atomic<unsigned int> num_errors(0);
+std::atomic<unsigned int> num_cached_requests(0);
+std::atomic<unsigned int> last_request_time(0);
+
+namespace /* __anonymous__ */ {
+
+void set_cors(httplib::Response& response) {
+    response.set_header("Access-Control-Allow-Origin", "*");
+    response.set_header("Access-Control-Allow-Credentials", "true");
+    response.set_header("Access-Control-Allow-Headers", "*");
+}
+
+void set_allowed_methods(httplib::Response& response, const std::string& methods) {
+    response.set_header("Allow", methods);
+    response.set_header("Access-Control-Allow-Methods", methods);
+}
+
+void handle_exception(const std::exception& e, const httplib::Request& request, httplib::Response& response) {
+    // Try to guess a bit more suitable return values
+    // based on client output
+    // TODO: should this actually be done? eg. do the status codes *only*
+    // reflect the API functionality or also the application (ecflow) server?
+    // if user requests an ecflow script and the script does not exists, should
+    // 404 be returned (even if the rest api path was correct)?
+
+    auto trimr = [](const std::string& str) {
+        std::string copy = str;
+        copy.erase(copy.find_last_not_of(" \n\r") + 1, std::string::npos);
+        return copy;
+    };
+
+    HttpStatusCode status_code = HttpStatusCode::client_error_bad_request;
+
+    const std::string err = trimr(std::string(e.what()));
+
+    if (err.find("authentication failed") != std::string::npos) {
+        status_code = HttpStatusCode::client_error_unauthorized;
+    }
+    else if (err.find("Could not find") != std::string::npos) {
+        status_code = HttpStatusCode::client_error_not_found;
+    }
+    else if (err.find("Cannot find") != std::string::npos) {
+        status_code = HttpStatusCode::client_error_not_found;
+    }
+    else if (err.find("cannot be found") != std::string::npos &&
+             err.find("Could not find referenced node") == std::string::npos) {
+        status_code = HttpStatusCode::client_error_not_found;
+    }
+    else if (err.find("No such file") != std::string::npos) {
+        status_code = HttpStatusCode::client_error_not_found;
+    }
+    else if (err.find("Add Suite failed: A Suite of name") != std::string::npos) {
+        status_code = HttpStatusCode::client_error_conflict;
+    }
+    else if (err.find("Ran out of end points") != std::string::npos) {
+        status_code = HttpStatusCode::server_error_bad_gateway;
+    }
+    else if (err.find("Failed to connect to ") != std::string::npos) {
+        status_code = HttpStatusCode::server_error_bad_gateway;
+    }
+    else if (err.find("Cannot replace node ") != std::string::npos) {
+        status_code = HttpStatusCode::server_error_bad_gateway;
+    }
+
+    ojson j;
+    j["code"]    = status_code;
+    j["message"] = err;
+    j["path"]    = request.path;
+    j["method"]  = request.method;
+    if (request.body.empty() == false) {
+        j["body"] = request.body;
+    }
+    response.set_content(j.dump(), "application/json");
+    response.status = status_code;
+    set_cors(response);
+}
+
+void handle_exception(const HttpServerException& e, const httplib::Request& request, httplib::Response& response) {
+    ojson j;
+    j["code"]    = e.code();
+    j["message"] = e.what();
+    j["path"]    = request.path;
+    j["method"]  = request.method;
+    if (request.body.empty() == false) {
+        j["body"] = request.body;
+    }
+
+    response.set_content(j.dump(), "application/json");
+    response.status = e.code();
+    set_cors(response);
+}
+
+void set_last_request_time() {
+    struct timeval curtime
+    {
+    };
+    gettimeofday(&curtime, nullptr);
+    last_request_time = static_cast<unsigned int>(curtime.tv_sec);
+}
+
+template <typename T>
+void trycatch(const httplib::Request& request, httplib::Response& response, T&& func) {
+    set_last_request_time();
+    try {
+        num_requests++;
+        func();
+    }
+    catch (const HttpServerException& e) {
+        num_errors++;
+        handle_exception(e, request, response);
+    }
+    catch (const std::exception& e) {
+        num_errors++;
+        handle_exception(e, request, response);
+    }
+}
+
+ojson filter_json(const ojson& j, const httplib::Request& r) {
+
+    const std::string path = r.get_param_value("filter");
+    if (path.empty()) {
+        return j;
+    }
+
+    // split filter path on dot, and reverse the elements
+    // the elements are consumed by the dive() function
+
+    std::vector<std::string> path_elems;
+    ecf::Str::split(path, path_elems, ".");
+    std::reverse(path_elems.begin(), path_elems.end());
+
+    if (path_elems.empty()) {
+        return j;
+    }
+
+    // separate array name and index from a string
+    auto get_array_info = [](std::string_view str) {
+        const auto start = str.find("[");
+        const auto stop  = str.find("]");
+        const auto key   = str.substr(0, start);
+        const int index  = std::stoi(std::string{str.substr(start + 1, stop - start)});
+        return std::make_pair(key, index);
+    };
+
+    // special case: filter is .[INDEX], means that we return the
+    // correct array element from root json element assuming it's an array
+    if (path_elems.size() == 1 && path_elems[0][0] == '[' && path_elems[0][path_elems[0].size() - 1] == ']') {
+        const auto [key, index] = get_array_info(path_elems[0]);
+        (void)key; // Note: suppress unused variable warning
+        return j[index];
+    }
+
+    // recursively find the correct element inside json document
+    std::function<ojson(const ojson&, std::vector<std::string>&)> dive = [&](const ojson& js,
+                                                                             const std::vector<std::string>& elems) {
+        if (elems.empty()) {
+            return js;
+        }
+
+        const auto elem = path_elems.back();
+        path_elems.pop_back();
+
+        try {
+            if (elem.find("[") != std::string::npos && elem.find("]") != std::string::npos) {
+                const auto [key, index] = get_array_info(elem);
+                return dive(js.at(std::string{key})[index], path_elems);
+            }
+
+            return dive(js.at(elem), path_elems);
+        }
+        catch (const ojson::exception& e [[maybe_unused]]) {
+            // filter path is not found or some other problem with user given path
+            return ojson();
+        }
+    };
+
+    return dive(j, path_elems);
+}
+
+static std::string get_tree_content_kind(const httplib::Request& request) {
+    constexpr const char* content = "content";
+    return request.has_param(content) ? request.get_param_value(content) : "basic";
+}
+
+static bool get_tree_content_id_flag(const httplib::Request& request) {
+    constexpr const char* content = "with_id";
+    return request.has_param(content) ? (request.get_param_value(content) == "true" ? true : false) : false;
+}
+
+} // namespace
+
+namespace v1 {
+
+void not_implemented(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::server_error_not_implemented;
+        set_cors(response);
+    });
+}
+
+void suites_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, POST, HEAD");
+        set_cors(response);
+    });
+}
+
+void suites_create(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        add_suite(request, response);
+        set_cors(response);
+    });
+}
+
+void suites_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        num_cached_requests++;
+        ojson j = filter_json(ecf::http::get_suites(), request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_tree_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, HEAD");
+        set_cors(response);
+    });
+}
+
+void node_tree_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        num_cached_requests++;
+        const std::string path = request.matches[1];
+        std::string tree_kind  = get_tree_content_kind(request);
+        bool with_id           = get_tree_content_id_flag(request);
+        ojson tree_content     = (tree_kind == "full") ? get_full_node_tree(path, with_id) : get_basic_node_tree(path);
+        ojson j                = filter_json(tree_content, request);
+        response.status        = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_definition_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, PUT, DELETE, HEAD");
+        set_cors(response);
+    });
+}
+
+void node_definition_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        num_cached_requests++;
+        const std::string path = request.matches[1];
+        ojson j                = filter_json(get_node_definition(path), request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_definition_update(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j = update_node_definition(request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/ojson");
+        set_cors(response);
+    });
+}
+
+void node_definition_delete(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        const std::string path = request.matches[1];
+        auto client            = get_client(request);
+        client->delete_node(path);
+
+        ojson j;
+        j["message"]    = "Node deleted successfully";
+        response.status = HttpStatusCode::success_no_content;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_status_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, PUT, HEAD");
+        set_cors(response);
+    });
+}
+
+void node_status_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        num_cached_requests++;
+        ojson j = filter_json(get_node_status(request), request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_status_update(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j         = update_node_status(request);
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_attributes_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, PUT, POST, DELETE, HEAD");
+        set_cors(response);
+    });
+}
+
+void node_attributes_create(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j         = add_node_attribute(request);
+        response.status = HttpStatusCode::success_created;
+        response.set_content(j.dump(), "application/ojson");
+        response.set_header("Location", "/v1/suites" + static_cast<std::string>(request.matches[1]) + "/attributes");
+        set_cors(response);
+    });
+}
+
+void node_attributes_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        num_cached_requests++;
+        const std::string path = request.matches[1];
+        ojson j                = filter_json(get_node_attributes(path), request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_attributes_update(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j         = update_node_attribute(request);
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_attributes_delete(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j         = delete_node_attribute(request);
+        response.status = HttpStatusCode::success_no_content;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_script_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, HEAD");
+        set_cors(response);
+    });
+}
+
+void node_script_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        const std::string path = request.matches[1];
+        auto client            = get_client(request);
+
+        ojson j;
+
+        client->file(path, "script");
+        j["script"] = client->server_reply().get_string();
+
+        try {
+            client->file(path, "job");
+            j["job"] = client->server_reply().get_string();
+        }
+        catch (const std::exception& e [[maybe_unused]]) {
+            j["job"] = "";
+        }
+
+        j               = filter_json(j, request);
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_script_update(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j         = update_script_content(request);
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void node_output_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, HEAD");
+        set_cors(response);
+    });
+}
+
+void node_output_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j         = filter_json(get_node_output(request), request);
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void server_ping_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, HEAD");
+        set_cors(response);
+    });
+}
+
+void server_ping_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        auto client = get_client(request);
+        client->pingServer();
+
+        ojson j;
+        j["host"]            = client->host() + ":" + client->port();
+        j["round_trip_time"] = to_simple_string(client->round_trip_time());
+        j                    = filter_json(j, request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void server_status_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, PUT, HEAD");
+        set_cors(response);
+    });
+}
+
+void server_status_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        auto client = get_client(request);
+
+        client->stats_server();
+        ojson j = client->server_reply().stats();
+        j       = filter_json(j, request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void server_status_update(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        auto payload = ojson::parse(request.body);
+        if (const std::string name = payload.at("action"); name == "reload_whitelist_file") {
+            get_client(request)->reloadwsfile();
+        }
+        else if (name == "reload_passwd_file") {
+            get_client(request)->reloadpasswdfile();
+        }
+        else if (name == "reload_custom_passwd_file") {
+            get_client(request)->reloadcustompasswdfile();
+        }
+        else {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request, "Invalid action: " + name);
+        }
+
+        ojson j;
+        j["message"]    = "Server updated successfully";
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void server_attributes_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, PUT, POST, DELETE, HEAD");
+        set_cors(response);
+    });
+}
+
+void server_attributes_create(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j = add_server_attribute(request);
+
+        response.status = HttpStatusCode::success_created;
+        response.set_content(j.dump(), "application/json");
+        response.set_header("Location", "/v1/server/attributes");
+        set_cors(response);
+    });
+}
+
+void server_attributes_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        num_cached_requests++;
+        ojson j = filter_json(get_server_attributes(), request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void server_attributes_update(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j = update_server_attribute(request);
+
+        response.status = HttpStatusCode::success_ok;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void server_attributes_delete(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        ojson j = delete_server_attribute(request);
+
+        response.status = HttpStatusCode::success_no_content;
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+void server_statistics_options(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status = HttpStatusCode::success_no_content;
+        set_allowed_methods(response, "GET, HEAD");
+        set_cors(response);
+    });
+}
+
+void server_statistics_read(const httplib::Request& request, httplib::Response& response) {
+    trycatch(request, response, [&]() {
+        response.status     = HttpStatusCode::success_ok;
+        const std::time_t t = std::chrono::system_clock::to_time_t(api_startup);
+        std::array<char, 80> date{};
+        std::tm tm{};
+        gmtime_r(&t, &tm);
+        strftime(date.data(), 80, "%Y-%m-%dT%H:%M:%SZ", &tm);
+
+        ojson j = {{"num_requests", num_requests.load()},
+                   {"num_errors", num_errors.load()},
+                   {"num_cached_requests", num_cached_requests.load()},
+                   {"since", std::string{date.data()}}};
+
+        j = filter_json(j, request);
+        response.set_content(j.dump(), "application/json");
+        set_cors(response);
+    });
+}
+
+} // namespace v1
+
+void routing(httplib::Server& http_server) {
+    if (opts.verbose) {
+        printf("Registering API location /v1\n");
+    }
+
+    /* .../suites */
+    {
+        std::string resource_path = R"(/v1/suites)";
+
+        http_server.Options(resource_path, v1::suites_options); // Options
+        http_server.Post(resource_path, v1::suites_create);     // Create
+        http_server.Get(resource_path, v1::suites_read);        // Read
+        http_server.Put(resource_path, v1::not_implemented);    // Update
+        http_server.Delete(resource_path, v1::not_implemented); // Delete
+    }
+
+    /* .../suites/<path>/tree */
+    {
+        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/tree)";
+        std::string resource_root = R"(/v1/suites(/)tree)";
+
+        http_server.Options(resource_path, v1::node_tree_options); // Options
+        http_server.Post(resource_path, v1::not_implemented);      // Create
+        http_server.Get(resource_root, v1::node_tree_read);        // Read
+        http_server.Get(resource_path, v1::node_tree_read);        // Read
+        http_server.Put(resource_path, v1::not_implemented);       // Updat
+        http_server.Delete(resource_path, v1::not_implemented);    // Delete
+    }
+
+    /* .../suites/<path>/definition */
+    {
+        std::string resourse_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/definition$)";
+
+        http_server.Options(resourse_path, v1::node_definition_options); // Options
+        http_server.Post(resourse_path, v1::not_implemented);            // Create
+        http_server.Get(resourse_path, v1::node_definition_read);        // Read
+        http_server.Put(resourse_path, v1::node_definition_update);      // Update
+        http_server.Delete(resourse_path, v1::node_definition_delete);   // Delete
+    }
+
+    /* .../suites/<path>/status */
+    {
+        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/status$)";
+
+        http_server.Options(resource_path, v1::node_status_options); // Options
+        http_server.Post(resource_path, v1::not_implemented);        // Create
+        http_server.Get(resource_path, v1::node_status_read);        // Read
+        http_server.Put(resource_path, v1::node_status_update);      // Update
+        http_server.Delete(resource_path, v1::not_implemented);      // Delete
+    }
+
+    /* .../suites/<path>/attributes */
+    {
+        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/attributes$)";
+
+        http_server.Options(resource_path, v1::node_attributes_options); // Options
+        http_server.Post(resource_path, v1::node_attributes_create);     // Create
+        http_server.Get(resource_path, v1::node_attributes_read);        // Read
+        http_server.Put(resource_path, v1::node_attributes_update);      // Update
+        http_server.Delete(resource_path, v1::node_attributes_delete);   // Delete
+    }
+
+    /* .../suites/<path>/script */
+    {
+        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/script$)";
+
+        http_server.Options(resource_path, v1::node_script_options); // Options
+        http_server.Post(resource_path, v1::not_implemented);        // Create
+        http_server.Get(resource_path, v1::node_script_read);        // Read
+        http_server.Put(resource_path, v1::not_implemented);         // Update
+        http_server.Delete(resource_path, v1::not_implemented);      // Delete
+    }
+
+    /* .../suites/<path>/output */
+    {
+        std::string resource_path = R"(/v1/suites([A-Za-z0-9_\/\.]+)/output$)";
+
+        http_server.Options(resource_path, v1::node_output_options); // Options
+        http_server.Post(resource_path, v1::not_implemented);        // Create
+        http_server.Get(resource_path, v1::node_output_read);        // Read
+        http_server.Put(resource_path, v1::not_implemented);         // Update
+        http_server.Delete(resource_path, v1::not_implemented);      // Delete
+    }
+
+    /* .../server/ping */
+    {
+        std::string resource_path = R"(/v1/server/ping)";
+
+        http_server.Options(resource_path, v1::server_ping_options); // Options
+        http_server.Post(resource_path, v1::not_implemented);        // Create
+        http_server.Get(resource_path, v1::server_ping_read);        // Read
+        http_server.Put(resource_path, v1::not_implemented);         // Update
+        http_server.Delete(resource_path, v1::not_implemented);      // Delete
+    }
+
+    /* .../server/status */
+    {
+        std::string resource_path = R"(/v1/server/status)";
+
+        http_server.Options("/v1/server/status", v1::server_status_options); // Options
+        http_server.Post(resource_path, v1::not_implemented);                // Create
+        http_server.Get(resource_path, v1::server_status_read);              // Read
+        http_server.Put("/v1/server/status", v1::server_status_update);      // Update
+        http_server.Delete(resource_path, v1::not_implemented);              // Delete
+    }
+
+    /* .../server/attributes */
+    {
+        std::string resource_path = R"(/v1/server/attributes)";
+
+        http_server.Options(resource_path, v1::server_attributes_options); // Options
+        http_server.Post(resource_path, v1::server_attributes_create);     // Create
+        http_server.Get(resource_path, v1::server_attributes_read);        // Read
+        http_server.Put(resource_path, v1::server_attributes_update);      // Update
+        http_server.Delete(resource_path, v1::server_attributes_delete);   // Delete
+    }
+
+    /* .../statistics */
+    {
+        std::string resource_path = R"(/v1/statistics)";
+
+        http_server.Options(resource_path, v1::server_statistics_options); // Options
+        http_server.Post(resource_path, v1::not_implemented);              // Create
+        http_server.Get(resource_path, v1::server_statistics_read);        // Read
+        http_server.Put(resource_path, v1::not_implemented);               // Update
+        http_server.Delete(resource_path, v1::not_implemented);            // Delete
+    }
+
+    api_startup = std::chrono::system_clock::now();
+    set_last_request_time();
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/ApiV1.hpp 5.13.0-1/libs/rest/src/ecflow/http/ApiV1.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/ApiV1.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/ApiV1.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,74 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_ApiV1_HPP
+#define ecflow_http_ApiV1_HPP
+
+#include "ecflow/http/DefsStorage.hpp"
+#include "ecflow/http/HttpLibrary.hpp"
+
+namespace ecf::http {
+
+void routing(httplib::Server& http_server);
+
+namespace v1 {
+
+void not_implemented(const httplib::Request& request, httplib::Response& response);
+
+void suites_options(const httplib::Request& request, httplib::Response& response);
+void suites_create(const httplib::Request& request, httplib::Response& response);
+void suites_read(const httplib::Request& request, httplib::Response& response);
+
+void node_tree_options(const httplib::Request& request, httplib::Response& response);
+void node_tree_read(const httplib::Request& request, httplib::Response& response);
+
+void node_definition_options(const httplib::Request& request, httplib::Response& response);
+void node_definition_read(const httplib::Request& request, httplib::Response& response);
+void node_definition_update(const httplib::Request& request, httplib::Response& response);
+void node_definition_delete(const httplib::Request& request, httplib::Response& response);
+
+void node_status_options(const httplib::Request& request, httplib::Response& response);
+void node_status_read(const httplib::Request& request, httplib::Response& response);
+void node_status_update(const httplib::Request& request, httplib::Response& response);
+
+void node_attributes_options(const httplib::Request& request, httplib::Response& response);
+void node_attributes_create(const httplib::Request& request, httplib::Response& response);
+void node_attributes_read(const httplib::Request& request, httplib::Response& response);
+void node_attributes_update(const httplib::Request& request, httplib::Response& response);
+void node_attributes_delete(const httplib::Request& request, httplib::Response& response);
+
+void node_script_options(const httplib::Request& request, httplib::Response& response);
+void node_script_read(const httplib::Request& request, httplib::Response& response);
+void node_script_update(const httplib::Request& request, httplib::Response& response);
+
+void node_output_options(const httplib::Request& request, httplib::Response& response);
+void node_output_read(const httplib::Request& request, httplib::Response& response);
+
+void server_ping_options(const httplib::Request& request, httplib::Response& response);
+void server_ping_read(const httplib::Request& request, httplib::Response& response);
+
+void server_status_options(const httplib::Request& request, httplib::Response& response);
+void server_status_read(const httplib::Request& request, httplib::Response& response);
+void server_status_update(const httplib::Request& request, httplib::Response& response);
+
+void server_attributes_options(const httplib::Request& request, httplib::Response& response);
+void server_attributes_create(const httplib::Request& request, httplib::Response& response);
+void server_attributes_read(const httplib::Request& request, httplib::Response& response);
+void server_attributes_update(const httplib::Request& request, httplib::Response& response);
+void server_attributes_delete(const httplib::Request& request, httplib::Response& response);
+
+void server_statistics_options(const httplib::Request& request, httplib::Response& response);
+void server_statistics_read(const httplib::Request& request, httplib::Response& response);
+
+} // namespace v1
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_ApiV1_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/ApiV1Impl.cpp 5.13.0-1/libs/rest/src/ecflow/http/ApiV1Impl.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/ApiV1Impl.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/ApiV1Impl.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1036 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/ApiV1Impl.hpp"
+
+#include <optional>
+#include <string>
+
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DState.hpp"
+#include "ecflow/core/NState.hpp"
+#include "ecflow/core/Overload.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/http/BasicAuth.hpp"
+#include "ecflow/http/Client.hpp"
+#include "ecflow/http/HttpServerException.hpp"
+#include "ecflow/http/Options.hpp"
+#if defined(ECF_OPENSSL)
+    #include "ecflow/http/TokenStorage.hpp"
+#endif
+#include "ecflow/http/DefsStorage.hpp"
+#include "ecflow/http/HttpLibrary.hpp"
+#include "ecflow/http/TreeGeneration.hpp"
+#include "ecflow/http/TypeToJson.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/DefsTreeVisitor.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/node/parser/DefsStructureParser.hpp"
+
+// For token based authentication, this user account
+// needs to have full access to server as it's acting
+// in lieu of the actual user
+
+namespace ecf::http {
+
+namespace {
+
+ojson make_json_response(std::string_view path, std::string_view message) {
+    return ojson::object({{"path", path}, {"message", message}});
+}
+
+} // namespace
+
+ojson make_node_json(node_ptr node) {
+    return ojson::object(
+        {{"type", ecf::algorithm::tolower(node->debugType())}, {"name", node->name()}, {"children", ojson::array()}});
+}
+
+void print_sparser_node(ojson& j, const std::vector<node_ptr>& nodes) {
+    for (const auto& node : nodes) {
+        const std::string type = ecf::algorithm::tolower(node->debugType());
+
+        j[node->name()] = ojson::object({});
+        if (type == "family") {
+            print_sparser_node(j[node->name()], std::dynamic_pointer_cast<Family>(node)->nodeVec());
+        }
+    }
+}
+
+void print_node(ojson& j, const std::vector<node_ptr>& nodes, bool add_id = false) {
+    j["children"].get_ptr<ojson::array_t*>()->reserve(nodes.size());
+    for (const auto& node : nodes) {
+        const std::string type = ecf::algorithm::tolower(node->debugType());
+        auto jnode             = make_node_json(node);
+
+        j["children"].push_back(jnode);
+        if (type == "family") {
+            print_node(j["children"].back(), std::dynamic_pointer_cast<Family>(node)->nodeVec(), add_id);
+        }
+    }
+}
+
+node_ptr get_node(const std::string& path) {
+    node_ptr node = get_defs()->findAbsNode(path);
+    if (node.get() == nullptr) {
+        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
+    }
+
+    return node;
+}
+
+ojson get_node_status(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+
+    auto client = get_client(request);
+    client->query("dstate", path, "");
+
+    ojson j;
+    j["status"] = client->server_reply().get_string();
+    j["path"]   = path;
+
+    if (node_ptr node = get_node(path); node) {
+        j["default_status"] = DState::to_string(node->defStatus());
+
+        std::vector<std::string> why;
+        node->bottom_up_why(why);
+        j["why"]                  = ojson::object({});
+        j["why"]["bottom_up_why"] = why;
+        why.clear();
+        node->top_down_why(why);
+        j["why"]["top_down_why"] = why;
+    }
+
+    return j;
+}
+
+template <typename T>
+void apply_to_parents(const Node* node, T&& func) {
+    for (const Node* up = node; up != nullptr; up = up->parent()) {
+        func(up);
+    }
+}
+
+ojson get_basic_node_tree(const std::string& path) {
+    BasicTree tree;
+    DefsTreeVisitor(get_defs(), tree).visit_at(path);
+    return tree.content();
+}
+
+ojson get_full_node_tree(const std::string& path, bool with_id) {
+    FullTree tree{with_id};
+    DefsTreeVisitor(get_defs(), tree).visit_at(path);
+    return tree.content();
+}
+
+ojson get_sparser_node_tree(const std::string& path) {
+    ojson j;
+
+    if (path == "/") {
+        const std::vector<suite_ptr> suites = get_defs()->suiteVec();
+        for (const auto& suite : suites) {
+            j[suite->name()] = ojson::object({});
+
+            print_sparser_node(j[suite->name()], suite->nodeVec());
+        }
+    }
+    else {
+        node_ptr node = get_node(path);
+
+        if (node == nullptr) {
+            throw HttpServerException(HttpStatusCode::client_error_not_found, "Node " + path + " not found");
+        }
+
+        const std::string type = ecf::algorithm::tolower(node->debugType());
+
+        if (type == "family") {
+            print_sparser_node(j, std::dynamic_pointer_cast<Family>(node)->nodeVec());
+        }
+        else if (type == "suite") {
+            print_sparser_node(j, std::dynamic_pointer_cast<Suite>(node)->nodeVec());
+        }
+    }
+
+    return j;
+}
+
+ojson get_node_tree(const std::string& path, bool add_id = false) {
+    ojson j;
+
+    if (path == "/") {
+        const std::vector<suite_ptr> suites = get_defs()->suiteVec();
+        j["suites"]                         = ojson::array();
+        j["suites"].get_ptr<ojson::array_t*>()->reserve(suites.size());
+
+        for (const auto& suite : suites) {
+            ojson js = make_node_json(suite);
+
+            print_node(js, suite->nodeVec(), add_id);
+
+            j["suites"].push_back(js);
+        }
+    }
+    else {
+        node_ptr node = get_node(path);
+
+        if (node == nullptr) {
+            throw HttpServerException(HttpStatusCode::client_error_not_found, "Node " + path + " not found");
+        }
+
+        j = make_node_json(node);
+
+        const std::string type = ecf::algorithm::tolower(node->debugType());
+
+        if (type == "family") {
+            print_node(j, std::dynamic_pointer_cast<Family>(node)->nodeVec(), add_id);
+        }
+        else if (type == "suite") {
+            print_node(j, std::dynamic_pointer_cast<Suite>(node)->nodeVec(), add_id);
+        }
+    }
+
+    return j;
+}
+
+ojson get_suites() {
+    auto suites = get_defs()->suiteVec();
+
+    ojson j = ojson::array();
+    for (const auto& s : suites) {
+        j.push_back(s->name());
+    }
+    return j;
+}
+
+ojson get_server_attributes() {
+
+    ojson j;
+
+    j["variables"] = get_defs()->server().user_variables();
+
+    for (auto v : get_defs()->server().server_variables()) {
+        ojson _j    = v;
+        _j["const"] = true;
+        j["variables"].push_back(_j);
+    }
+    return j;
+}
+
+ojson get_node_attributes(const std::string& path) {
+    ojson j;
+
+    node_ptr node = get_node(path);
+
+    j["meters"]      = node->meters();
+    j["limits"]      = node->limits();
+    j["inlimits"]    = node->inlimits();
+    j["events"]      = node->events();
+    j["variables"]   = node->variables();
+    j["labels"]      = node->labels();
+    j["dates"]       = node->dates();
+    j["days"]        = node->days();
+    j["crons"]       = node->crons();
+    j["times"]       = node->timeVec();
+    j["todays"]      = node->todayVec();
+    j["repeat"]      = node->repeat();
+    j["path"]        = path;
+    j["trigger"]     = node->get_trigger();
+    j["complete"]    = node->get_complete();
+    j["flag"]        = node->get_flag();
+    j["late"]        = node->get_late();
+    j["zombies"]     = node->zombies();
+    j["generics"]    = node->generics();
+    j["queues"]      = node->queues();
+    j["autocancel"]  = node->get_autocancel();
+    j["autoarchive"] = node->get_autoarchive();
+    j["autorestore"] = node->get_autorestore();
+    j["avisos"]      = node->avisos();
+    j["mirrors"]     = node->mirrors();
+
+    {
+        // Collect 'normal' variables
+        auto vars = node->variables();
+        // ... and generated variables
+        node->gen_variables(vars);
+
+        j["variables"] = vars;
+    }
+
+    apply_to_parents(node->parent(), [&j](const Node* n) {
+        // Collect 'normal' variables
+        auto vars = n->variables();
+        // ... and generated variables
+        n->gen_variables(vars);
+
+        j["inherited_variables"][n->name()] = vars;
+    });
+
+    auto server_variables = get_defs()->server().server_variables();
+    auto user_variables   = get_defs()->server().user_variables();
+
+    server_variables.insert(server_variables.end(), user_variables.begin(), user_variables.end());
+
+    j["inherited_variables"]["server"] = server_variables;
+
+    return j;
+}
+
+ojson get_node_definition(const std::string& path) {
+    ojson j;
+
+    node_ptr node = get_node(path);
+
+    j["definition"] = node->print();
+    j["path"]       = path;
+
+    return j;
+}
+
+ojson get_node_output(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+
+    auto client = get_client(request);
+
+    ojson j;
+
+    client->file(path, "jobout");
+    j["job_output"] = client->server_reply().get_string();
+
+    try {
+        client->file(path, "kill");
+        j["kill_output"] = client->server_reply().get_string();
+    }
+    catch (const std::exception& e [[maybe_unused]]) {
+        j["kill_output"] = "";
+    }
+
+    try {
+        client->file(path, "stat");
+        j["status_output"] = client->server_reply().get_string();
+    }
+    catch (const std::exception& e [[maybe_unused]]) {
+        j["status_output"] = "";
+    }
+
+    return j;
+}
+
+void add_suite(const httplib::Request& request, httplib::Response& response) {
+    const std::string path = request.matches[1];
+    const ojson payload    = ojson::parse(request.body);
+
+    const std::string defs = payload.at("definition");
+
+    DefsStructureParser parser(defs);
+
+    {
+        std::string errorMsg;
+        std::string warningMsg;
+
+        if (parser.doParse(errorMsg, warningMsg) == false) {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                      "Invalid definition: " + errorMsg + "/" + warningMsg);
+        }
+    }
+
+    node_ptr node = parser.the_node_ptr();
+
+    auto defsptr = Defs::create();
+    {
+        std::string errorMsg;
+        std::string warningMsg;
+        defsptr->restore_from_string(defs, errorMsg, warningMsg);
+    }
+
+    try {
+        if (json_type_to_string(payload.at("auto_add_externs")) == "true") {
+            defsptr->auto_add_externs(true);
+        }
+    }
+    catch (const ojson::exception& e [[maybe_unused]]) {
+        // Nothing to do...
+    }
+
+    auto client = get_client(request);
+    client->load(defsptr);
+
+    ojson j;
+    j["message"] = "Suite(s) created successfully";
+    response.set_content(j.dump(), "application/json");
+    response.status = HttpStatusCode::success_created;
+    response.set_header("Location", request.path + "/" + node->name() + "/definition");
+}
+
+ojson update_node_definition(const httplib::Request& request) {
+    const std::string path         = request.matches[1];
+    const ojson payload            = ojson::parse(request.body);
+    const std::string new_defs_str = payload.at("definition");
+    const bool force               = payload.value("force", false);
+
+    // Support "partial node adding/replacement", meaning that
+    // user can give us just the definition of a new task, and
+    // we will add that to the suite.
+
+    // this takes a long time, but we need a copy as we are changing
+    // the defs locally here
+
+    auto defs   = std::make_shared<Defs>(*get_defs());
+    auto parent = defs->findAbsNode(path);
+
+    if (parent == nullptr) {
+        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path not found");
+    }
+
+    DefsStructureParser parser(new_defs_str);
+
+    {
+        std::string errorMsg;
+        std::string warningMsg;
+
+        if (parser.doParse(errorMsg, warningMsg) == false) {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                      "Invalid definition: " + errorMsg + "/" + warningMsg);
+        }
+    }
+
+    // If a child with the same name exists already, it needs to be removed
+    // before adding it with this new definition
+    node_ptr node = parser.the_node_ptr();
+    size_t pos    = 0;
+    if (auto child = parent->findImmediateChild(node->name(), pos); child) {
+        parent->removeChild(child.get());
+    }
+
+    {
+        std::string errorMsg;
+        if (parent->isAddChildOk(node.get(), errorMsg) == false) {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request, errorMsg);
+        }
+    }
+
+    parent->addChild(node);
+
+    auto client = get_client(request);
+    client->replace(path, defs->print(), true, force);
+
+    return make_json_response(path, "Definition updated successfully");
+}
+
+namespace /* __anonymous__ */ {
+
+template <typename T>
+void add_attribute_to_node(node_ptr node, const T& attr);
+
+template <>
+void add_attribute_to_node(node_ptr node, const Meter& attr) {
+    node->addMeter(attr);
+}
+
+template <>
+void add_attribute_to_node(node_ptr node, const Event& attr) {
+    node->addEvent(attr);
+}
+
+template <>
+void add_attribute_to_node(node_ptr node, const ecf::CronAttr& attr) {
+    node->addCron(attr);
+}
+
+template <>
+void add_attribute_to_node(node_ptr node, const std::string& attr) {
+    node->add_complete(attr);
+}
+
+template <>
+void add_attribute_to_node(node_ptr node, const ecf::AutoCancelAttr& attr) {
+    node->addAutoCancel(attr);
+}
+
+template <>
+void add_attribute_to_node(node_ptr node, const ecf::AutoRestoreAttr& attr) {
+    node->add_autorestore(attr);
+}
+
+template <>
+void add_attribute_to_node(node_ptr node, const ecf::AutoArchiveAttr& attr) {
+    node->add_autoarchive(attr);
+}
+
+} // namespace
+
+template <typename T>
+void add_attribute_to_path(const T& attr, const httplib::Request& request) {
+    const std::string path = request.matches[1];
+
+    auto defs   = std::make_shared<Defs>(*get_defs());
+    auto parent = defs->findAbsNode(path);
+
+    if (parent.get() == nullptr) {
+        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
+    }
+    add_attribute_to_node(parent, attr);
+
+    auto client = get_client(request);
+    client->replace(path, defs->print(), false, false);
+}
+
+void remove_attribute_from_path(std::string_view type, const httplib::Request& request) {
+    const std::string path = request.matches[1];
+
+    auto defs   = std::make_shared<Defs>(*get_defs());
+    auto parent = defs->findAbsNode(path);
+
+    if (parent.get() == nullptr) {
+        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
+    }
+
+    if (type == "autocancel") {
+        parent->deleteAutoCancel();
+    }
+    else if (type == "autorestore") {
+        parent->deleteAutoRestore();
+    }
+    else if (type == "autoarchive") {
+        parent->deleteAutoArchive();
+    }
+
+    auto client = get_client(request);
+    client->replace(path, defs->print(), false, false);
+}
+
+template <typename T>
+void update_attribute_in_path(const T& attr, std::string_view type, const httplib::Request& request) {
+    const std::string path = request.matches[1];
+
+    auto defs   = std::make_shared<Defs>(*get_defs());
+    auto parent = defs->findAbsNode(path);
+
+    if (parent.get() == nullptr) {
+        throw HttpServerException(HttpStatusCode::client_error_not_found, "Path " + path + " not found");
+    }
+
+    if (type == "autocancel") {
+        parent->deleteAutoCancel();
+    }
+    else if (type == "autorestore") {
+        parent->deleteAutoRestore();
+    }
+    else if (type == "autoarchive") {
+        parent->deleteAutoArchive();
+    }
+
+    add_attribute_to_node(parent, attr);
+
+    auto client = get_client(request);
+    client->replace(path, defs->print(), false, false);
+}
+
+template <typename T>
+T create_from_text(const std::string& line);
+
+template <>
+ecf::AutoArchiveAttr create_from_text(const std::string& line) {
+    if (line.find_first_of(':') == std::string::npos) {
+        try {
+            return ecf::AutoArchiveAttr(std::stoi(line));
+        }
+        catch (const std::exception& e) {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                      "Invalid value for autoarchive: " + line + " (" + e.what() + ")");
+        }
+    }
+    else {
+        int hour      = 0;
+        int min       = 0;
+        bool relative = ecf::TimeSeries::getTime(line, hour, min);
+        return ecf::AutoArchiveAttr(ecf::TimeSlot(hour, min), relative);
+    }
+}
+template <>
+ecf::AutoCancelAttr create_from_text(const std::string& line) {
+    if (line.find_first_of(':') == std::string::npos) {
+        try {
+            return ecf::AutoCancelAttr(std::stoi(line));
+        }
+        catch (const std::exception& e) {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                      "Invalid value for autocancel: " + line + " (" + e.what() + ")");
+        }
+    }
+    else {
+        int hour      = 0;
+        int min       = 0;
+        bool relative = ecf::TimeSeries::getTime(line, hour, min);
+        return ecf::AutoCancelAttr(ecf::TimeSlot(hour, min), relative);
+    }
+}
+template <>
+ecf::AutoRestoreAttr create_from_text(const std::string& line) {
+    std::vector<std::string> tasks;
+    ecf::Str::split(line, tasks, " ");
+
+    return ecf::AutoRestoreAttr(tasks);
+}
+
+ojson add_node_attribute(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+    const ojson payload    = ojson::parse(request.body);
+
+    const std::string type  = payload.at("type");
+    const std::string value = json_type_to_string(payload.at("value"));
+
+    auto client = get_client(request);
+
+    if (type == "meter") {
+        const std::string name = payload.at("name");
+        int min                = stoi(json_type_to_string(payload.at("min")));
+        int max                = stoi(json_type_to_string(payload.at("max")));
+        const Meter m(name, min, max, std::numeric_limits<int>::max(), stoi(value));
+        add_attribute_to_path(m, request);
+        // Adding a meter always results to having its value == min, even if the value
+        // of argument 'value' is something different
+        client->alter(path, "change", "meter", name, value);
+    }
+    else if (type == "event") {
+        const std::string name = payload.at("name");
+        const Event e(std::numeric_limits<int>::max(), name, (value == "true") ? true : false);
+        add_attribute_to_path(e, request);
+        if (value != "set" && value != "true" && value != "clear" && value != "false") {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                      "'value' for event must be one of: set/true, clear/false");
+        }
+        std::string value_ = (value == "true" || value == "set") ? "set" : "clear";
+        client->alter(path, "change", "event", name, value_);
+    }
+    else if (type == "aviso") {
+        const std::string name = payload.at("name");
+        client->alter(path, "add", "aviso", name, value);
+    }
+    else if (type == "mirror") {
+        const std::string name = payload.at("name");
+        client->alter(path, "add", "mirror", name, value);
+    }
+    else if (type == "cron") {
+        add_attribute_to_path(ecf::CronAttr::create(value), request);
+    }
+    else if (type == "complete") {
+        add_attribute_to_path(value, request);
+    }
+    else if (type == "autocancel") {
+        add_attribute_to_path(create_from_text<ecf::AutoCancelAttr>(value), request);
+    }
+    else if (type == "autorestore") {
+        add_attribute_to_path(create_from_text<ecf::AutoRestoreAttr>(value), request);
+    }
+    else if (type == "autoarchive") {
+        add_attribute_to_path(create_from_text<ecf::AutoArchiveAttr>(value), request);
+    }
+    else if (type == "time" || type == "day" || type == "date" || type == "today" || type == "late") {
+        client->alter(path, "add", type, value);
+    }
+    else {
+        const std::string name = payload.at("name");
+        client->alter(path, "add", type, name, value);
+    }
+
+    return make_json_response(path, "Attribute added successfully");
+}
+
+namespace /* __anonymous__ */ {
+
+ojson update_node_attribute_by_task(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+
+    const ojson payload    = ojson::parse(request.body);
+    const std::string type = payload.at("type");
+    const std::string name = payload.at("name");
+
+    // this is a child command call
+    if (ecf::Child::valid_child_cmd(type) == false) {
+        throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                  "Invalid action for child command: " + name);
+    }
+
+    auto client = get_client_for_tasks(request, payload);
+
+    struct Ancillary
+    {
+        std::string type;
+        std::string action;
+        std::string value;
+    };
+    std::optional<Ancillary> ancillary;
+
+    if (type == "event") {
+        const std::string value = payload.at("value");
+        if (value != "set" && value != "true" && value != "clear" && value != "false") {
+            throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                      "'value' for event must be one of: set/true, clear/false");
+        }
+        client->child_event(name, (value == "true" || value == "set"));
+    }
+    else if (type == "meter") {
+        const std::string value = payload.at("value");
+        client->child_meter(name, std::stoi(value));
+    }
+    else if (type == "label") {
+        const std::string value = payload.at("value");
+        client->child_label(name, value);
+    }
+    else if (type == "queue") {
+        auto queue_action = payload.at("queue_action").get<std::string>();
+        auto queue_step   = payload.contains("queue_step") ? payload.at("queue_step").get<std::string>() : "";
+        auto queue_path   = payload.contains("queue_path") ? payload.at("queue_path").get<std::string>() : "";
+        std::string reply = client->child_queue(name, queue_action, queue_step, queue_path);
+
+        if (queue_action == "active" || queue_action == "no_of_aborted") {
+            ancillary = std::make_optional(Ancillary{type, queue_action, reply});
+        }
+    }
+    else {
+        throw HttpServerException(HttpStatusCode::server_error_not_implemented,
+                                  "Child action " + type + ", on attribute " + name + ", is not supported");
+    }
+
+    ojson j = make_json_response(path, "Attribute changed successfully");
+    if (ancillary) {
+        if (ancillary->action == "active") {
+            j["step"] = ancillary->value;
+        }
+        else if (ancillary->action == "no_of_aborted") {
+            j["no_of_aborted"] = ancillary->value;
+        }
+    }
+    return j;
+}
+
+ojson update_node_attribute_by_user(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+    const ojson payload    = ojson::parse(request.body);
+
+    std::string type = payload.at("type");
+
+    auto client = get_client(request);
+
+    if (type == "repeat" || type == "late" || type == "complete") {
+        const std::string value = json_type_to_string(payload.at("value"));
+        client->alter(path, "change", type, value);
+    }
+    else if (type == "today" || type == "time" || type == "late") {
+        const std::string value     = json_type_to_string(payload.at("value"));
+        const std::string old_value = json_type_to_string(payload.at("old_value"));
+        client->alter(path, "change", type, old_value, value);
+    }
+    else if (type == "day" || type == "date") {
+        const std::string value     = json_type_to_string(payload.at("value"));
+        const std::string old_value = json_type_to_string(payload.at("old_value"));
+        client->alter(path, "delete", type, old_value);
+        client->alter(path, "add", type, value);
+    }
+    else if (type == "aviso" || type == "mirror") {
+        const std::string value = json_type_to_string(payload.at("value"));
+        client->alter(path, "change", type, value);
+    }
+    else if (type == "autocancel") {
+        const std::string value = json_type_to_string(payload.at("value"));
+        update_attribute_in_path(create_from_text<ecf::AutoCancelAttr>(value), type, request);
+        trigger_defs_update();
+    }
+    else if (type == "autorestore") {
+        const std::string value = json_type_to_string(payload.at("value"));
+        update_attribute_in_path(create_from_text<ecf::AutoRestoreAttr>(value), type, request);
+        trigger_defs_update();
+    }
+    else if (type == "autoarchive") {
+        const std::string value = json_type_to_string(payload.at("value"));
+        update_attribute_in_path(create_from_text<ecf::AutoArchiveAttr>(value), type, request);
+        trigger_defs_update();
+    }
+    else if (type == "cron") {
+        const std::string value     = json_type_to_string(payload.at("value"));
+        const std::string old_value = json_type_to_string(payload.at("old_value"));
+        client->alter(path, "delete", type, old_value);
+        trigger_defs_update([&] { add_attribute_to_path(ecf::CronAttr::create(value), request); });
+    }
+    else if (type == "limit") {
+        const std::string name = payload.at("name");
+        const static std::vector<std::string> keys{"max", "value"};
+        std::string value;
+        try {
+            value = json_type_to_string(payload.at("value"));
+            type  = type + "_value";
+        }
+        catch (const ojson::out_of_range& e [[maybe_unused]]) {
+            try {
+                value = json_type_to_string(payload.at("max"));
+                type  = type + "_max";
+            }
+            catch (const ojson::out_of_range& e [[maybe_unused]]) {
+                throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                          "For limit either 'max' or 'value' must be defined");
+            }
+        }
+        client->alter(path, "change", type, name, value);
+    }
+    else {
+        const std::string name = payload.at("name");
+        std::string value      = json_type_to_string(payload.at("value"));
+        if (type == "event") {
+            if (value != "set" && value != "true" && value != "clear" && value != "false") {
+                throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                          "'value' for event must be one of: set/true, clear/false");
+            }
+            value = (value == "true" || value == "set") ? "set" : "clear";
+        }
+        client->alter(path, "change", type, name, value);
+    }
+
+    return make_json_response(path, "Attribute changed successfully");
+}
+
+} // namespace
+
+ojson update_node_attribute(const httplib::Request& request) {
+
+    const ojson payload = ojson::parse(request.body);
+
+    std::string type = payload.at("type");
+
+    //
+    // Important: updating node attributes is not a straightforward matter!
+    //
+    // Firstly, it can be done either as a child command or a user command.
+    //
+    // Secondly, for user commands, the current client framework does not cover all attribute operations:
+    //  * Some attributes can be added, changed and delete with ClientInvoker
+    //  * Some attributes can be either added, changed or deleted with ClientInvoker
+    //  * Some attributes cannot be modified in any way with ClientInvoker
+    //
+    // As we want the API to be consistent, we allow to modify all ecFlow attributes,
+    // whether the Client code supports it or not.
+    //
+
+    if (payload.contains("ECF_NAME")) {
+        return update_node_attribute_by_task(request);
+    }
+    else {
+        return update_node_attribute_by_user(request);
+    }
+}
+
+ojson delete_node_attribute(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+    const ojson payload    = ojson::parse(request.body);
+
+    const std::string type = payload.at("type");
+    auto client            = get_client(request);
+
+    if (type == "time" || type == "today" || type == "day" || type == "date" || type == "cron" || type == "late" ||
+        type == "complete") {
+        const std::string value = payload.at("value");
+        client->alter(path, "delete", type, value);
+    }
+    else if (type == "autocancel" || type == "autorestore" || type == "autoarchive") {
+        remove_attribute_from_path(type, request);
+    }
+    else {
+        const std::string name = payload.at("name");
+        client->alter(path, "delete", type, name);
+    }
+
+    return make_json_response(path, "Attribute deleted successfully");
+}
+
+ojson add_server_attribute(const httplib::Request& request) {
+    const ojson payload    = ojson::parse(request.body);
+    const std::string type = payload.at("type");
+
+    if (type != "variable") {
+        throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                  "Only variables can be added to server attributes");
+    }
+
+    const std::string name  = payload.at("name");
+    const std::string value = json_type_to_string(payload.at("value"));
+
+    auto client = get_client(request);
+    client->alter("/", "add", type, name, value);
+
+    return make_json_response("/", "Attribute added successfully");
+}
+
+ojson update_server_attribute(const httplib::Request& request) {
+    const ojson payload     = ojson::parse(request.body);
+    const std::string type  = payload.at("type");
+    const std::string name  = payload.at("name");
+    const std::string value = payload.at("value");
+
+    if (std::string x; !get_defs()->server().find_user_variable(name, x)) {
+        throw HttpServerException(HttpStatusCode::client_error_not_found, "User variable not found");
+    }
+    else if (type != "variable") {
+        throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                  "Only variables can be updated in server attributes");
+    }
+
+    auto client = get_client(request);
+    client->alter("/", "change", type, name, value);
+
+    return make_json_response("/", "Attribute changed successfully");
+}
+
+ojson delete_server_attribute(const httplib::Request& request) {
+
+    const ojson payload = ojson::parse(request.body);
+
+    const std::string type = payload.at("type");
+    const std::string name = payload.at("name");
+
+    if (std::string x; !get_defs()->server().find_user_variable(name, x)) {
+        throw HttpServerException(HttpStatusCode::client_error_not_found, "User variable not found");
+    }
+    else if (type != "variable") {
+        throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                  "Only variables can be removed from server attributes");
+    }
+
+    auto client = get_client(request);
+    client->alter("/", "delete", type, name);
+
+    return make_json_response("/", "Attribute deleted successfully");
+}
+
+namespace /* __anonymous__ */ {
+
+ojson update_node_status_by_task(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+    const ojson payload    = ojson::parse(request.body);
+    const std::string name = payload.at("action");
+
+    // this is a child command call
+    if (ecf::Child::valid_child_cmd(name) == false) {
+        throw HttpServerException(HttpStatusCode::client_error_bad_request,
+                                  "Invalid action for child command: " + name);
+    }
+
+    auto client = get_client_for_tasks(request, payload);
+
+    if (name == "init") {
+        client->child_init();
+    }
+    else if (name == "abort") {
+        client->child_abort(payload.value("abort_why", ""));
+    }
+    else if (name == "complete") {
+        client->child_complete();
+    }
+    else if (name == "wait") {
+        client->child_wait(payload.at("wait_expression"));
+    }
+    else {
+        throw HttpServerException(HttpStatusCode::server_error_not_implemented,
+                                  "Child action " + name + " not supported");
+    }
+
+    return make_json_response(path, "Status changed successfully");
+}
+
+ojson update_node_status_by_user(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+    const ojson payload    = ojson::parse(request.body);
+    const std::string name = payload.at("action");
+
+    auto client = get_client(request);
+
+    bool recursive = payload.value("recursive", false);
+    bool force     = payload.value("force", false);
+
+    if (name == "begin") {
+        client->begin(path);
+    }
+    else if (name == "resume") {
+        client->resume(path);
+    }
+    else if (name == "requeue") {
+        client->requeue(path);
+    }
+    else if (name == "suspend") {
+        client->suspend(path);
+    }
+    else if (name == "defstatus") {
+        client->alter(path, "change", name, payload.at("defstatus_value").get<std::string>());
+    }
+    else if (name == "execute") {
+        client->run(path, true);
+    }
+    else if (name == "archive") {
+        client->archive(path, force);
+    }
+    else if (name == "restore") {
+        client->restore(path);
+    }
+    else {
+        std::string name_ = name;
+        if (name_ == "abort") {
+            name_ = "aborted";
+        }
+        else if (name_ == "rerun") {
+            name_ = "queued";
+        }
+        else if (name_ == "execute") {
+            name_ = "run";
+        }
+        else if (name_ == "submit") {
+            name_ = "submitted";
+        }
+
+        client->force(path, name_, recursive);
+    }
+
+    return make_json_response(path, "Status changed successfully");
+}
+
+} // namespace
+
+ojson update_node_status(const httplib::Request& request) {
+    if (const ojson payload = ojson::parse(request.body); payload.contains("ECF_NAME")) {
+        return update_node_status_by_task(request);
+    }
+    else {
+        return update_node_status_by_user(request);
+    }
+}
+
+ojson update_script_content(const httplib::Request& request) {
+    const std::string path = request.matches[1];
+    const ojson payload    = ojson::parse(request.body);
+
+    const std::string script = payload.at("script");
+
+    std::vector<std::string> lines;
+    lines.reserve(20);
+    std::stringstream ss(script);
+
+    for (std::string line; std::getline(ss, line, '\n');) {
+        lines.push_back(line);
+    }
+
+    auto client = get_client(request);
+    client->edit_script_submit(path, {}, lines, false, false);
+
+    return make_json_response(path, "Script submitted successfully");
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/ApiV1Impl.hpp 5.13.0-1/libs/rest/src/ecflow/http/ApiV1Impl.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/ApiV1Impl.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/ApiV1Impl.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,50 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_ApiV1Impl_HPP
+#define ecflow_http_ApiV1Impl_HPP
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/http/HttpLibrary.hpp"
+#include "ecflow/http/JSON.hpp"
+
+namespace ecf::http {
+
+ojson get_basic_node_tree(const std::string& path);
+ojson get_full_node_tree(const std::string& path, bool with_id);
+ojson get_sparser_node_tree(const std::string& path);
+
+void add_suite(const httplib::Request& request, httplib::Response& response);
+
+ojson get_suites();
+
+ojson get_server_attributes();
+ojson add_server_attribute(const httplib::Request& request);
+ojson update_server_attribute(const httplib::Request& request);
+ojson delete_server_attribute(const httplib::Request& request);
+
+ojson get_node_definition(const std::string& path);
+ojson update_node_definition(const httplib::Request& request);
+
+ojson get_node_attributes(const std::string& path);
+ojson add_node_attribute(const httplib::Request& request);
+ojson update_node_attribute(const httplib::Request& request);
+ojson delete_node_attribute(const httplib::Request& request);
+
+ojson get_node_status(const httplib::Request& request);
+ojson update_node_status(const httplib::Request& request);
+
+ojson get_node_output(const httplib::Request& request);
+
+ojson update_script_content(const httplib::Request& request);
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_ApiV1Impl_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/Base64.hpp 5.13.0-1/libs/rest/src/ecflow/http/Base64.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/Base64.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/Base64.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,159 @@
+/*
+ * Base64 encoding/decoding (RFC1341)
+ * Copyright (c) 2005-2011, Jouni Malinen <j@w1.fi>
+ *
+ * This software may be distributed under the terms of the BSD license.
+ * Original license included below:
+ *
+ *
+ *   License
+ *   -------
+ *   This software may be distributed, used, and modified under the terms of BSD license:
+ *
+ *   Redistribution and use in source and binary forms, with or without modification,
+ *   are permitted provided that the following conditions are met:
+ *
+ *   1. Redistributions of source code must retain the above copyright
+ *       notice, this list of conditions and the following disclaimer.
+ *
+ *   2. Redistributions in binary form must reproduce the above copyright
+ *       notice, this list of conditions and the following disclaimer in the
+ *       documentation and/or other materials provided with the distribution.
+ *
+ *   3. Neither the name(s) of the above-listed copyright holder(s) nor the
+ *       names of its contributors may be used to endorse or promote products
+ *       derived from this software without specific prior written permission.
+ *
+ *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ *   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ *   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ *   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ *   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ *   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
+#ifndef ecflow_http_Base64_HPP
+#define ecflow_http_Base64_HPP
+
+#include <cstring>
+#include <regex>
+
+/**
+ * base64_decode - Base64 decode
+ * @src: Data to be decoded
+ * @len: Length of the data to be decoded
+ * @out_len: Pointer to output length variable
+ * Returns: Allocated buffer of out_len bytes of decoded data,
+ * or %NULL on failure
+ *
+ * Caller is responsible for freeing the returned buffer.
+ */
+
+inline unsigned char* base64_decode(const unsigned char* src, size_t len, size_t* out_len) {
+
+    static const std::string base64_table = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+
+    unsigned char dtable[256], *out, *pos, block[4], tmp;
+    size_t olen;
+    int pad = 0;
+
+    memset(dtable, 0x80, 256);
+    for (size_t i = 0; i < sizeof(base64_table) - 1; i++) {
+        auto base64_char    = static_cast<size_t>(base64_table[i]);
+        dtable[base64_char] = (unsigned char)i;
+    }
+    size_t assignment_char  = '=';
+    dtable[assignment_char] = 0;
+
+    size_t count = 0;
+    for (size_t i = 0; i < len; i++) {
+        if (dtable[src[i]] != 0x80) {
+            count++;
+        }
+    }
+
+    if (count == 0 || count % 4) {
+        return nullptr;
+    }
+
+    olen = count / 4 * 3;
+    pos = out = (unsigned char*)malloc(olen);
+    if (out == nullptr) {
+        return nullptr;
+    }
+
+    count = 0;
+    for (size_t i = 0; i < len; i++) {
+        tmp = dtable[src[i]];
+        if (tmp == 0x80) {
+            continue;
+        }
+
+        if (src[i] == '=') {
+            pad++;
+        }
+        block[count] = tmp;
+        count++;
+        if (count == 4) {
+            *pos++ = (block[0] << 2) | (block[1] >> 4);
+            *pos++ = (block[1] << 4) | (block[2] >> 2);
+            *pos++ = (block[2] << 6) | block[3];
+            count  = 0;
+            if (pad) {
+                if (pad == 1) {
+                    pos--;
+                }
+                else if (pad == 2) {
+                    pos -= 2;
+                }
+                else {
+                    /* Invalid padding */
+                    free(out);
+                    return nullptr;
+                }
+                break;
+            }
+        }
+    }
+
+    *out_len = pos - out;
+    return out;
+}
+
+/* Wrapper for std::string /partio */
+
+inline std::string base64_decode(const std::string& encoded) {
+    size_t len         = 0;
+    unsigned char* out = base64_decode(reinterpret_cast<const unsigned char*>(encoded.c_str()), encoded.size(), &len);
+    if (!out) {
+        throw std::runtime_error("Unable to decode base64");
+    }
+
+    std::string decoded(reinterpret_cast<char*>(out), len);
+    free(out);
+    return decoded;
+}
+
+/* Simple validation of base64 string.
+ * - length has to be multiple of 4
+ * - valid characters are  A-Za-z0-9+/
+ * padding of 0-2 characters at the end of string can be =
+ *
+ * /partio
+ */
+
+inline bool base64_validate(const std::string& encoded) {
+    if (encoded.size() % 4 != 0) {
+        return false;
+    }
+    static const std::regex pattern("^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{4}|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)$");
+
+    return std::regex_match(encoded, pattern);
+}
+
+#endif /* ecflow_http_Base64_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/BasicAuth.cpp 5.13.0-1/libs/rest/src/ecflow/http/BasicAuth.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/BasicAuth.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/BasicAuth.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/BasicAuth.hpp"
+
+#include "ecflow/core/PasswordEncryption.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/http/Base64.hpp"
+#include "ecflow/http/HttpServerException.hpp"
+
+namespace ecf::http {
+
+std::pair<std::string, std::string> BasicAuth::get_credentials(const std::string& token) {
+    const std::string decoded = base64_decode(token);
+    std::vector<std::string> elems;
+    ecf::Str::split(decoded, elems, ":");
+
+    return std::make_pair(elems[0], PasswordEncryption::encrypt(elems[1], elems[0]));
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/BasicAuth.hpp 5.13.0-1/libs/rest/src/ecflow/http/BasicAuth.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/BasicAuth.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/BasicAuth.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,25 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_BasicAuth_HPP
+#define ecflow_http_BasicAuth_HPP
+
+#include <string>
+
+namespace ecf::http {
+
+class BasicAuth {
+public:
+    static std::pair<std::string, std::string> get_credentials(const std::string& token);
+};
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_BasicAuth_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/Client.cpp 5.13.0-1/libs/rest/src/ecflow/http/Client.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/Client.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/Client.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,125 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/Client.hpp"
+
+#include <string>
+
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/http/BasicAuth.hpp"
+#include "ecflow/http/HttpServerException.hpp"
+#if defined(ECF_OPENSSL)
+    #include "ecflow/http/TokenStorage.hpp"
+#endif
+
+// For token based authentication, this user account
+// needs to have full access to server as it's acting
+// in lieu of the actual user
+
+namespace ecf::http {
+
+const char* const ECF_USER = getenv("ECF_USER");
+const char* const ECF_PASS = getenv("ECF_PASS");
+
+bool authenticate(const httplib::Request& request, ClientInvoker* ci) {
+
+#ifdef ECF_OPENSSL
+    auto auth_with_token = [&](const std::string& token) {
+        if (TokenStorage::instance().verify(token)) {
+            if (ECF_USER != nullptr && ECF_PASS != nullptr) {
+                ci->set_user_name(std::string(ECF_USER));
+                ci->set_password(std::string(ECF_PASS));
+            }
+            return true;
+        }
+        return false;
+    };
+#endif
+
+    const auto& header = request.headers;
+
+    // Authorization: Basic ..........
+    // Authorization: Bearer ..........
+
+    auto auth = header.find("Authorization");
+
+    if (auth != header.end()) {
+        std::vector<std::string> elems;
+        ecf::Str::split(auth->second, elems, " ");
+
+        if (elems[0] == "Basic") {
+            auto [username, password] = BasicAuth::get_credentials(elems[1]);
+            ci->set_user_name(username);
+            ci->set_password(password);
+            return true;
+        }
+        else if (elems[0] == "Bearer") {
+#ifndef ECF_OPENSSL
+            throw HttpServerException(HttpStatusCode::server_error_internal_server_error,
+                                      "Server compiled without SSL support");
+#else
+            return auth_with_token(elems[1]);
+#endif
+        }
+        return false;
+    }
+
+    // No standard authentication header set,
+    // try X-API-Key and/or queryparam
+
+    auth = header.find("X-API-Key");
+
+    if (auth != header.end()) {
+#ifndef ECF_OPENSSL
+        throw HttpServerException(HttpStatusCode::server_error_internal_server_error,
+                                  "Server compiled without SSL support");
+#else
+        return auth_with_token(auth->second);
+#endif
+    }
+
+    // allow token to be passed as a query parameter
+    if (const std::string token = request.get_param_value("key"); token.empty() == false) {
+#ifndef ECF_OPENSSL
+        throw HttpServerException(HttpStatusCode::server_error_internal_server_error,
+                                  "Server compiled without SSL support");
+#else
+        return auth_with_token(token);
+#endif
+    }
+
+    return false;
+}
+
+std::unique_ptr<ClientInvoker> get_client(const httplib::Request& request) {
+    auto ci = std::make_unique<ClientInvoker>();
+
+    if (request.method != "GET" && request.method != "OPTIONS" && request.method != "HEAD" &&
+        authenticate(request, ci.get()) == false) {
+        throw HttpServerException(HttpStatusCode::client_error_unauthorized, "Unauthorized");
+    }
+    return ci;
+}
+
+std::unique_ptr<ClientInvoker> get_client_for_tasks(const httplib::Request& request, const ojson& payload) {
+    auto ci = get_client(request);
+
+    ci->set_child_path(payload.at("ECF_NAME").get<std::string>());
+    ci->set_child_password(payload.at("ECF_PASS").get<std::string>());
+    ci->set_child_pid(json_type_to_string(payload.at("ECF_RID")));
+    ci->set_child_try_no(std::stoi(json_type_to_string(payload.at("ECF_TRYNO"))));
+    ci->set_child_timeout(payload.value("ECF_TIMEOUT", 86400));
+    ci->set_zombie_child_timeout(payload.value("ECF_ZOMBIE_TIMEOUT", 43200));
+
+    return ci;
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/Client.hpp 5.13.0-1/libs/rest/src/ecflow/http/Client.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/Client.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/Client.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_Client_HPP
+#define ecflow_http_Client_HPP
+
+#include <memory>
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/http/HttpLibrary.hpp"
+#include "ecflow/http/JSON.hpp"
+
+namespace ecf::http {
+
+std::unique_ptr<ClientInvoker> get_client(const httplib::Request& request);
+
+std::unique_ptr<ClientInvoker> get_client_for_tasks(const httplib::Request& request, const ojson& payload);
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_Client_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/DefsStorage.cpp 5.13.0-1/libs/rest/src/ecflow/http/DefsStorage.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/DefsStorage.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/DefsStorage.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,175 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <condition_variable>
+#include <mutex>
+#include <optional>
+#include <string>
+#include <thread>
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/http/Options.hpp"
+#include "ecflow/node/Defs.hpp"
+
+namespace ecf::http {
+
+extern std::atomic<unsigned int> last_request_time;
+
+std::shared_ptr<Defs> defs_ = nullptr;
+
+static std::mutex def_mutex;
+static std::mutex cv_mutex;
+static std::condition_variable defs_cv;
+std::atomic update_defs(true);
+
+namespace /* __anonymous__ */ {
+
+void print_polling_interval_notification(long long sleeptime,
+                                         long long base_sleeptime,
+                                         long long drift,
+                                         long long max_sleeptime) {
+    printf("Polling interval is now %lld (base: %lld drift: %lld max: %lld)\n",
+           sleeptime,
+           base_sleeptime,
+           drift,
+           max_sleeptime);
+}
+
+} // namespace
+
+std::shared_ptr<Defs> get_defs() {
+    std::lock_guard lock(def_mutex);
+    return defs_;
+}
+
+namespace /* __anonymous__ */ {
+
+[[noreturn]] void defs_update(int interval) {
+    ClientInvoker client;
+
+    auto get_current_time = [] {
+        struct timeval curtime;
+        gettimeofday(&curtime, nullptr);
+        return static_cast<unsigned int>(curtime.tv_sec);
+    };
+
+    auto update = [&] {
+        {
+            std::lock_guard lock(def_mutex);
+            if (defs_ != nullptr) {
+                client.sync(defs_);
+            }
+            defs_ = client.defs();
+        }
+        if (opts.verbose) {
+            printf(
+                "Defs modify_change_no: %d state_change_no: %d\n", defs_->modify_change_no(), defs_->state_change_no());
+        }
+    };
+
+    // These will throw is ecflow server is not present; we will not
+    // try to reconnect if there wasn't a connection to begin with
+    client.news_local();
+    client.sync_local();
+
+    // Implement a drift to update cycle. The basic idea is that if we
+    // don't get requests to the interface, we slowly start to increase
+    // the interval which we use to poll ecFlow server. This is done to
+    // reduce ecFlow server load when there is no activity on the REST
+    // API.
+    // For every minute that goes by without any activity on the REST API,
+    // we increase the drift by one second. The maximum drift value is
+    // 10 * polling interval, but minimum 30 seconds. Activity on the API
+    // will reset drift to zero.
+
+    const std::chrono::seconds base_sleeptime(interval);
+    std::chrono::seconds sleeptime(interval);
+    const std::chrono::seconds max_sleeptime(std::max(30, opts.max_polling_interval));
+    std::chrono::seconds previous_sleeptime(interval);
+
+    for (;;) {
+        try {
+            while (true) {
+                std::unique_lock lock(cv_mutex);
+                if (defs_cv.wait_for(lock, sleeptime, [] { return update_defs.load(); })) {
+                    // update requested by some other thread
+                    if (opts.verbose) {
+                        printf("defs update requested\n");
+                    }
+                    update();
+                    update_defs = false;
+                }
+                else {
+                    // update triggered by timeout
+                    client.news(defs_);
+                    if (client.get_news()) {
+                        update();
+                        update_defs = false;
+                    }
+                }
+
+                if (opts.max_polling_interval <= opts.polling_interval) {
+                    // drift disabled
+                    continue;
+                }
+                const auto last_request_age = static_cast<double>(get_current_time() - last_request_time.load());
+                const auto drift            = std::chrono::seconds(static_cast<int>(floor(last_request_age / 60.)));
+
+                sleeptime = min(max_sleeptime, base_sleeptime + drift);
+                if (opts.verbose && sleeptime != previous_sleeptime) {
+                    print_polling_interval_notification(
+                        sleeptime.count(), base_sleeptime.count(), drift.count(), max_sleeptime.count());
+                }
+
+                previous_sleeptime = sleeptime;
+            }
+        }
+        catch (const std::exception& e) {
+            printf("ERROR: Communication problem with ecflow server? Retrying in 5s\n");
+            std::this_thread::sleep_for(std::chrono::seconds(5));
+        }
+    }
+}
+
+} // namespace
+
+void update_defs_loop(int interval) {
+    std::thread t(defs_update, interval);
+    t.detach();
+
+    while (update_defs.load() == true) {
+        std::this_thread::sleep_for(std::chrono::milliseconds(50));
+    }
+}
+
+template <typename T>
+void trigger_defs_update_predicate(T&& func) {
+    {
+        std::lock_guard lock(cv_mutex);
+        update_defs = true;
+        defs_cv.notify_one();
+    }
+
+    while (update_defs.load() == true) {
+        std::this_thread::sleep_for(std::chrono::milliseconds(20));
+    }
+
+    func();
+}
+
+void trigger_defs_update() {
+    trigger_defs_update_predicate([] { /* No OP */ });
+}
+
+void trigger_defs_update(std::function<void()> function) {
+    trigger_defs_update_predicate(function);
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/DefsStorage.hpp 5.13.0-1/libs/rest/src/ecflow/http/DefsStorage.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/DefsStorage.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/DefsStorage.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_DefsStorage_HPP
+#define ecflow_http_DefsStorage_HPP
+
+#include <functional>
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/http/JSON.hpp"
+
+namespace ecf::http {
+
+std::shared_ptr<Defs> get_defs();
+
+void update_defs_loop(int interval);
+
+void trigger_defs_update();
+void trigger_defs_update(std::function<void()> function);
+
+} // namespace ecf::http
+
+#endif /* DefsStorage */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/HttpLibrary.hpp 5.13.0-1/libs/rest/src/ecflow/http/HttpLibrary.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/HttpLibrary.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/HttpLibrary.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,35 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_HttpLibrary_HPP
+#define ecflow_http_HttpLibrary_HPP
+
+#include <sys/socket.h>
+#if defined(MSG_NOSIGNAL)
+    // The MSG_NOSIGNAL flag should be defined by <sys/socket.h>
+    // (as per POSIX: https://pubs.opengroup.org/onlinepubs/9699919799.2018edition/functions/send.html),
+    // but that is not always the case for OSX.
+    //
+    // If MSG_NOSIGNAL is not defined, we leave it up to httplib to use default flags.
+    //
+    #define CPPHTTPLIB_SEND_FLAGS MSG_NOSIGNAL
+    #define CPPHTTPLIB_RECV_FLAGS MSG_NOSIGNAL
+#endif
+
+#ifdef ECF_OPENSSL
+    #define CPPHTTPLIB_OPENSSL_SUPPORT
+#endif
+#ifdef ECF_HTTP_COMPRESSION
+    #define CPPHTTPLIB_ZLIB_SUPPORT
+#endif
+
+#include <httplib.h>
+
+#endif /* ecflow_http_HttpLibrary_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/HttpMain.cpp 5.13.0-1/libs/rest/src/ecflow/http/HttpMain.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/HttpMain.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/HttpMain.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <csignal>
+#include <cstring>
+#include <iostream>
+
+#include "ecflow/http/HttpServer.hpp"
+
+using ecf::http::HttpServer;
+
+int main(int argc, char* argv[]) {
+    // Sometimes we get SIGPIPE through openssl, when server is trying
+    // to write to a socket which client has already closed.
+    // Ignore this signal.
+    sigset_t set;
+    sigemptyset(&set);
+    sigaddset(&set, SIGPIPE);
+
+    if (pthread_sigmask(SIG_BLOCK, &set, nullptr) != 0) {
+        throw std::runtime_error("Failed to set signal mask");
+    }
+
+    try {
+        HttpServer server(argc, argv);
+        server.run();
+    }
+    catch (std::exception& e) {
+        std::cerr << e.what() << std::endl;
+        return 1;
+    }
+    return 0;
+}
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/HttpServer.cpp 5.13.0-1/libs/rest/src/ecflow/http/HttpServer.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/HttpServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/HttpServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,261 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/HttpServer.hpp"
+
+#include <boost/program_options.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/http/Api.hpp"
+#include "ecflow/http/JSON.hpp"
+#include "ecflow/http/Options.hpp"
+
+namespace ecf::http {
+
+HttpServer::HttpServer(int argc, char** argv) {
+    parse_args(argc, argv);
+}
+
+void read_environment() {
+    if (getenv("ECF_RESTAPI_VERBOSE") != nullptr) {
+        opts.verbose = true;
+    }
+    if (getenv("ECF_RESTAPI_NOSSL") != nullptr) {
+        opts.no_ssl = true;
+    }
+    if (getenv("ECF_RESTAPI_POLLING_INTERVAL") != nullptr) {
+        opts.polling_interval = atoi(getenv("ECF_RESTAPI_POLLING_INTERVAL"));
+    }
+    if (getenv("ECF_RESTAPI_PORT") != nullptr) {
+        opts.port = atoi(getenv("ECF_RESTAPI_PORT"));
+    }
+    if (getenv("ECF_HOST") != nullptr) {
+        opts.ecflow_host = std::string(getenv("ECF_HOST"));
+    }
+    if (getenv("ECF_PORT") != nullptr) {
+        opts.ecflow_port = atoi(getenv("ECF_PORT"));
+    }
+    if (getenv("ECF_RESTAPI_TOKENS_FILE") != nullptr) {
+        opts.tokens_file = std::string(getenv("ECF_RESTAPI_TOKENS_FILE"));
+    }
+    if (getenv("ECF_RESTAPI_CERT_DIRECTORY") != nullptr) {
+        opts.cert_directory = std::string(getenv("ECF_RESTAPI_CERT_DIRECTORY"));
+    }
+    if (getenv("ECF_RESTAPI_MAX_UPDATE_INTERVAL") != nullptr) {
+        opts.max_polling_interval = atoi(getenv("ECF_RESTAPI_MAX_UPDATE_INTERVAL"));
+    }
+}
+
+void HttpServer::parse_args(int argc, char** argv) const {
+
+    // TODO[MB]: This essentially creates an Options object, thus makes more sense that move ability to Options.hpp
+
+    namespace po = boost::program_options;
+
+    po::options_description desc("Allowed options", 100);
+
+    read_environment();
+
+    // clang-format off
+
+   bool verbose = false;
+   bool no_ssl = false;
+
+   desc.add_options()
+       ("cert_directory", po::value(&opts.cert_directory), "directory where certificates are found (default: $HOME/.ecflowrc/ssl)")
+       ("ecflow_host", po::value(&opts.ecflow_host), "hostname of ecflow server (default: localhost)")
+       ("ecflow_port", po::value(&opts.ecflow_port), "port of ecflow server (default: 3141)")
+       ("help,h", "print help message")
+       ("max_polling_interval", po::value(&opts.max_polling_interval), "maximum polling interval in seconds, set to 0 to disable drift (default: 300)")
+       ("no_ssl", po::bool_switch(&no_ssl), "disable ssl (default: false)")
+       ("port,p", po::value(&opts.port), "port to listen (default: 8080)")
+       ("polling_interval", po::value(&opts.polling_interval), "interval in seconds to poll ecflow server for updates (default: 10)")
+       ("tokens_file", po::value(&opts.tokens_file), "location of api tokens file (default: api-tokens.json)")
+       ("verbose,v", po::bool_switch(&verbose), "enable verbose mode");
+
+    // clang-format on
+
+    po::variables_map opt;
+    po::store(po::command_line_parser(argc, argv).options(desc).run(), opt);
+    po::notify(opt);
+
+    if (opt.count("help")) {
+        std::cout << desc << std::endl;
+        exit(1);
+    }
+    if (verbose) {
+        opts.verbose = true;
+    }
+    if (no_ssl) {
+        opts.no_ssl = true;
+    }
+
+    setenv("ECF_HOST", opts.ecflow_host.c_str(), 1);
+    setenv("ECF_PORT", ecf::convert_to<std::string>(opts.ecflow_port).c_str(), 1);
+    // Unset these, otherwise ClientInvoker will automatically
+    // try to use them
+    unsetenv("ECF_PASSWD");
+    unsetenv("ECF_CUSTOM_PASSWD");
+}
+
+void apply_listeners(httplib::Server& http_server) {
+
+    // TODO[MB]: Needs to be further refactored
+
+    const auto dump_headers = [](const httplib::Headers& headers, std::stringstream& ss) {
+        for (const auto& [key, value] : headers) {
+            ss << key << ": " << value << "\n";
+        }
+    };
+
+    const auto format = [&dump_headers](const httplib::Request& req, const httplib::Response& res) {
+        std::stringstream ss;
+
+        ss << '\n';
+
+        ss << "*** REQUEST ***\n";
+        ss << req.method << " " << req.version << " " << req.path;
+        char sep = '?';
+        for (const auto& [parameter, value] : req.params) {
+            ss << sep << parameter << "=" << value;
+            sep = '&';
+        }
+        ss << '\n';
+
+        ss << "-=- header(s):\n";
+        dump_headers(req.headers, ss);
+
+        if (!req.body.empty()) {
+            ss << "-=- body:\n";
+            ss << req.body << "\n";
+        }
+
+        ss << '\n';
+        ss << "*** RESPONSE ***\n";
+        ss << res.status << " " << res.version << "\n";
+
+        ss << "-=- header(s):\n";
+        dump_headers(res.headers, ss);
+
+        if (!res.body.empty()) {
+            ss << "-=- body:\n";
+            ss << res.body << "\n";
+        }
+
+        return ss.str();
+    };
+
+    http_server.set_exception_handler([](const httplib::Request& req, httplib::Response& res, std::exception_ptr ep) {
+        try {
+            std::rethrow_exception(ep);
+        }
+        catch (const std::exception& e) {
+            if (opts.verbose) {
+                printf("Exception: Error 500: %s\n", e.what());
+            }
+            ojson j;
+            j["status"]  = res.status;
+            j["message"] = e.what();
+            j["path"]    = req.path;
+            j["method"]  = req.method;
+            if (req.body.empty() == false) {
+                j["body"] = req.body;
+            }
+            res.set_content(j.dump(), "application/json");
+        }
+        catch (...) {
+            if (opts.verbose) {
+                printf("Unknown exception occurred\n");
+            }
+        }
+    });
+
+    http_server.set_error_handler([](const httplib::Request& req, httplib::Response& res) {
+        if (opts.verbose) {
+            printf("error_handler called: Error: %d\n", res.status);
+        }
+
+        // Usually no need to modify response fields -- they should be configured now, as
+        // error handler is called *after* httplib finds out that status is >= 400
+        //
+        // Exception is when errorhandler is called so that it doesn't go through the
+        // registered endpoints
+
+        if (res.body.empty()) {
+            ojson j;
+            j["path"]   = req.path;
+            j["status"] = res.status;
+            res.set_content(j.dump(), "application/json");
+        }
+    });
+
+    http_server.set_logger([&format](const httplib::Request& req, const httplib::Response& res) {
+        const std::string str = format(req, res);
+        // using std::cout crashes with many threads calling
+        if (opts.verbose) {
+            printf("%s\n", str.c_str());
+        }
+    });
+}
+
+void start_server(httplib::Server& http_server) {
+    if (opts.verbose) {
+        printf("ecFlow server location is %s:%d\n", opts.ecflow_host.c_str(), opts.ecflow_port);
+    }
+
+    setup(http_server);
+
+    const std::string proto = (opts.no_ssl ? "http" : "https");
+
+    if (opts.verbose) {
+        printf("%s server listening on port %d\n", proto.c_str(), opts.port);
+    }
+
+    try {
+        bool ret = http_server.listen("0.0.0.0", opts.port);
+        if (ret == false) {
+            throw std::runtime_error("Failed to bind to port " + ecf::convert_to<std::string>(opts.port));
+        }
+    }
+    catch (const std::exception& e) {
+        if (opts.verbose) {
+            printf("Server execution stopped: %s\n", e.what());
+        }
+    }
+}
+
+void HttpServer::run() const {
+#ifdef ECF_OPENSSL
+    if (opts.no_ssl == false) {
+        if (fs::exists(opts.cert_directory + "/server.crt") == false ||
+            fs::exists(opts.cert_directory + "/server.key") == false) {
+            throw std::runtime_error("Directory " + opts.cert_directory +
+                                     " does not contain server.crt and/or server.key");
+        }
+
+        const std::string cert = opts.cert_directory + "/server.crt";
+        const std::string key  = opts.cert_directory + "/server.key";
+
+        httplib::SSLServer http_server(cert.c_str(), key.c_str());
+        apply_listeners(dynamic_cast<httplib::Server&>(http_server));
+        start_server(http_server);
+    }
+    else
+#endif
+    {
+        httplib::Server http_server;
+
+        apply_listeners(http_server);
+        start_server(http_server);
+    }
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/HttpServer.hpp 5.13.0-1/libs/rest/src/ecflow/http/HttpServer.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/HttpServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/HttpServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_HttpServer_HPP
+#define ecflow_http_HttpServer_HPP
+
+namespace ecf::http {
+
+class HttpServer {
+public:
+    HttpServer(int argc, char** argv);
+    void run() const;
+    ~HttpServer() = default;
+
+private:
+    void parse_args(int argc, char** argv) const;
+};
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_HttpServer_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/HttpServerException.hpp 5.13.0-1/libs/rest/src/ecflow/http/HttpServerException.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/HttpServerException.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/HttpServerException.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_HttpServerException_HPP
+#define ecflow_http_HttpServerException_HPP
+
+#include <exception>
+#include <string>
+
+namespace ecf::http {
+
+enum HttpStatusCode {
+    unknown              = 0,
+    information_continue = 100,
+    information_switching_protocols,
+    information_processing,
+    success_ok = 200,
+    success_created,
+    success_accepted,
+    success_non_authoritative_information,
+    success_no_content,
+    success_reset_content,
+    success_partial_content,
+    success_multi_status,
+    success_already_reported,
+    success_im_used              = 226,
+    redirection_multiple_choices = 300,
+    redirection_moved_permanently,
+    redirection_found,
+    redirection_see_other,
+    redirection_not_modified,
+    redirection_use_proxy,
+    redirection_switch_proxy,
+    redirection_temporary_redirect,
+    redirection_permanent_redirect,
+    client_error_bad_request = 400,
+    client_error_unauthorized,
+    client_error_payment_required,
+    client_error_forbidden,
+    client_error_not_found,
+    client_error_method_not_allowed,
+    client_error_not_acceptable,
+    client_error_proxy_authentication_required,
+    client_error_request_timeout,
+    client_error_conflict,
+    client_error_gone,
+    client_error_length_required,
+    client_error_precondition_failed,
+    client_error_payload_too_large,
+    client_error_uri_too_long,
+    client_error_unsupported_media_type,
+    client_error_range_not_satisfiable,
+    client_error_expectation_failed,
+    client_error_im_a_teapot,
+    client_error_misdirection_required = 421,
+    client_error_unprocessable_entity,
+    client_error_locked,
+    client_error_failed_dependency,
+    client_error_upgrade_required      = 426,
+    client_error_precondition_required = 428,
+    client_error_too_many_requests,
+    client_error_request_header_fields_too_large = 431,
+    client_error_unavailable_for_legal_reasons   = 451,
+    server_error_internal_server_error           = 500,
+    server_error_not_implemented,
+    server_error_bad_gateway,
+    server_error_service_unavailable,
+    server_error_gateway_timeout,
+    server_error_http_version_not_supported,
+    server_error_variant_also_negotiates,
+    server_error_insufficient_storage,
+    server_error_loop_detected,
+    server_error_not_extended = 510,
+    server_error_network_authentication_required
+};
+
+class HttpServerException : public std::exception {
+public:
+    HttpServerException() = delete;
+    HttpServerException(HttpStatusCode code, const std::string& msg) : code_(code), msg_(msg) {}
+
+    const char* what() const noexcept override { return msg_.c_str(); }
+    HttpStatusCode code() const { return code_; }
+
+private:
+    HttpStatusCode code_;
+    std::string msg_;
+};
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_HttpServerException_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/JSON.cpp 5.13.0-1/libs/rest/src/ecflow/http/JSON.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/JSON.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/JSON.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,43 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/JSON.hpp"
+
+#include "ecflow/core/Converter.hpp"
+
+namespace ecf::http {
+
+std::string json_type_to_string(const ojson& j) {
+    switch (j.type()) {
+        case ojson::value_t::null:
+            return "null";
+        case ojson::value_t::boolean:
+            return (j.get<bool>()) ? "true" : "false";
+        case ojson::value_t::string:
+            return j.get<std::string>();
+        case ojson::value_t::binary:
+            return j.dump();
+        case ojson::value_t::array:
+        case ojson::value_t::object:
+            return j.dump();
+        case ojson::value_t::discarded:
+            return "discarded";
+        case ojson::value_t::number_integer:
+            return ecf::convert_to<std::string>(j.get<int>());
+        case ojson::value_t::number_unsigned:
+            return ecf::convert_to<std::string>(j.get<unsigned int>());
+        case ojson::value_t::number_float:
+            return ecf::convert_to<std::string>(j.get<double>());
+        default:
+            return std::string();
+    }
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/JSON.hpp 5.13.0-1/libs/rest/src/ecflow/http/JSON.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/JSON.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/JSON.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_JSON_HPP
+#define ecflow_http_JSON_HPP
+
+#include "nlohmann/json.hpp"
+
+namespace ecf::http {
+
+using ojson = nlohmann::ordered_json;
+
+std::string json_type_to_string(const ojson& j);
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_JSON_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/Options.cpp 5.13.0-1/libs/rest/src/ecflow/http/Options.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/Options.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/Options.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,17 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/Options.hpp"
+
+namespace ecf::http {
+
+Options opts = {};
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/Options.hpp 5.13.0-1/libs/rest/src/ecflow/http/Options.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/Options.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/Options.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,35 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_Options_HPP
+#define ecflow_http_Options_HPP
+
+#include <string>
+
+namespace ecf::http {
+
+struct Options
+{
+    bool verbose{false};                                                        // ECF_RESTAPI_VERBOSE
+    bool no_ssl{false};                                                         // ECF_RESTAPI_NOSSL
+    int polling_interval{10};                                                   // ECF_RESTAPI_POLLING_INTERVAL
+    int port{8080};                                                             // ECF_RESTAPI_PORT
+    std::string ecflow_host{"localhost"};                                       // ECF_HOST
+    int ecflow_port{3141};                                                      // ECF_PORT
+    std::string tokens_file{"api-tokens.json"};                                 // ECF_RESTAPI_TOKENS_FILE
+    std::string cert_directory{std::string(getenv("HOME")) + "/.ecflowrc/ssl"}; // ECF_RESTAPI_CERT_DIRECTORY
+    int max_polling_interval{300};                                              // ECF_RESTAPI_MAX_POLLING_INTERVAL
+};
+
+extern Options opts;
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_Options_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/TokenStorage.cpp 5.13.0-1/libs/rest/src/ecflow/http/TokenStorage.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/TokenStorage.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/TokenStorage.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,238 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/TokenStorage.hpp"
+
+#include <atomic> // shared mutex only with c++14
+#include <fstream>
+#include <iomanip>
+#include <shared_mutex>
+#include <sstream>
+#include <thread>
+
+#include <openssl/evp.h>
+#include <openssl/hmac.h>
+#include <openssl/sha.h>
+
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/http/HttpServerException.hpp"
+#include "ecflow/http/JSON.hpp"
+#include "ecflow/http/Options.hpp"
+
+namespace ecf::http {
+
+std::shared_mutex m;
+
+std::atomic initialized = false;
+
+namespace {
+
+std::string hmac_sha256(const std::string& salt, const std::string& token) {
+    unsigned char hash[EVP_MAX_MD_SIZE];
+    unsigned int hash_len;
+
+    HMAC(EVP_sha256(),
+         salt.c_str(),
+         static_cast<int>(salt.size()),
+         reinterpret_cast<const unsigned char*>(token.c_str()),
+         token.size(),
+         hash,
+         &hash_len);
+    std::stringstream ss;
+    for (unsigned int i = 0; i < hash_len; i++) {
+        ss << std::hex << std::setw(2) << std::setfill('0') << static_cast<int>(hash[i]);
+    }
+    return ss.str();
+}
+
+std::string hmac_pbkdf2_sha256(const std::string& salt, const std::string& token, int num_iterations) {
+    unsigned char hash[SHA256_DIGEST_LENGTH];
+
+    PKCS5_PBKDF2_HMAC(token.c_str(),
+                      static_cast<int>(token.size()),
+                      reinterpret_cast<const unsigned char*>(salt.c_str()),
+                      static_cast<int>(salt.size()),
+                      num_iterations,
+                      EVP_sha256(),
+                      SHA256_DIGEST_LENGTH,
+                      hash);
+    std::stringstream ss;
+    for (int i = 0; i < SHA256_DIGEST_LENGTH; i++) {
+        ss << std::hex << std::setw(2) << std::setfill('0') << static_cast<int>(hash[i]);
+    }
+    return ss.str();
+}
+
+std::string hash(const std::string& method, const std::string& salt, const std::string& token) {
+    /*
+     * Hash a token with correct HMAC.
+     * Current options are:
+     * - sha256
+     * - pbkdf2:sha256
+     */
+
+    if (method == "sha256") {
+        return hmac_sha256(salt, token);
+    }
+    else if (method.find("pbkdf2:sha256") != std::string::npos) {
+        int num_iterations = 260000;
+
+        try {
+            num_iterations = std::stoi(method.substr(method.find(":", 8) + 1, std::string::npos));
+        }
+        catch (const std::exception& e) {
+            printf("ERROR: method %s has invalid number of iterations: %s\n", method.c_str(), e.what());
+        }
+        return hmac_pbkdf2_sha256(salt, token, num_iterations);
+    }
+
+    throw HttpServerException(HttpStatusCode::server_error_internal_server_error, "Unsupported HMAC: " + method);
+}
+
+bool is_supported_hmac(std::string_view method) {
+    if (method == "sha256" || method.find("pbkdf2:sha256") != std::string::npos) {
+        return true;
+    }
+    return false;
+}
+
+std::chrono::system_clock::time_point time_point_from_isostring(const std::string& str) {
+    if (str.empty()) {
+        return std::chrono::system_clock::time_point{};
+    }
+
+    std::tm tm = {};
+    strptime(str.c_str(), "%Y-%m-%dT%H:%M:%SZ", &tm);
+    return std::chrono::system_clock::from_time_t(std::mktime(&tm));
+}
+
+} // namespace
+
+TokenStorage::TokenStorage() {
+    std::thread t(&TokenStorage::ReadStorage, this);
+    t.detach();
+
+    while (initialized.load() == false) {
+        std::this_thread::sleep_for(std::chrono::milliseconds(10));
+    }
+}
+
+bool TokenStorage::verify(const std::string& token) const {
+    const auto now = std::chrono::system_clock::now();
+
+    // Take a (weak) reader lock; the background thread updating
+    // tokens from file can block us but other readers cannot
+
+    std::shared_lock lock(m);
+    for (const auto& t : tokens_) {
+        const std::string hashed = hash(t.method, t.salt, token);
+        if (hashed == t.hash && (t.expires.time_since_epoch().count() == 0 || t.expires > now) &&
+            (t.revoked.time_since_epoch().count() == 0 || t.revoked > now)) {
+            if (opts.verbose) {
+                printf("Token for '%s' authenticated successfully\n", t.description.c_str());
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
+std::vector<Token> ReadTokens(const std::string& filename) {
+    std::ifstream ifs(filename);
+    auto j = ojson::parse(ifs);
+    std::vector<Token> new_tokens;
+
+    /* Read a token from json file.
+     * Format is:
+     * [
+     * {
+     *    "hash" : "...",        # hashed and salted token, format is identical to python
+                                 # library 'werkzeug': METHOD$SALT$HASH
+          "description" : "...", # free-form description of token (application)
+          "expires_at" : NUM,    # unix epoch time when this token will expire
+                                 # OPTIONAL: if missing or zero, no expiration time is set
+          "revoked_at" : NUM     # unix epoch time when this token was revoked
+                                 # OPTIONAL: if missing or zero, no revoke time is set
+     * }
+     * ]
+     */
+
+    for (const auto& o : j) {
+        try {
+            std::chrono::system_clock::time_point expires_at; // optional
+            std::chrono::system_clock::time_point revoked_at; // optional
+
+            if (o.contains("expires_at")) {
+                expires_at = time_point_from_isostring(o.at("expires_at").get<std::string>());
+            }
+
+            if (o.contains("revoked_at")) {
+                revoked_at = time_point_from_isostring(o.at("revoked_at").get<std::string>());
+            }
+
+            const std::string& hash = o.at("hash").get<std::string>();
+
+            std::vector<std::string> elems;
+            ecf::Str::split(hash, elems, "$");
+
+            if (elems.size() != 3) {
+                throw std::invalid_argument("Invalid hash format: " + hash);
+            }
+            if (is_supported_hmac(elems[0]) == false) {
+                throw std::invalid_argument("Unsupported HMAC: " + elems[0]);
+            }
+
+            new_tokens.emplace_back(
+                elems[2], elems[1], elems[0], o.at("description").get<std::string>(), expires_at, revoked_at);
+        }
+        catch (const std::exception& e) {
+            printf("Invalid token: %s: %s\n", o.dump().c_str(), e.what());
+        }
+    }
+    if (opts.verbose) {
+        printf("Read %ld tokens\n", new_tokens.size());
+    }
+
+    return new_tokens;
+}
+
+void TokenStorage::ReadStorage() {
+    const std::chrono::seconds sleep_time(20);
+    std::chrono::system_clock::time_point last_modified;
+
+    // Scan periodically the api-token file and read the
+    // contents automatically if they are updated
+
+    while (true) {
+        try {
+            auto current_modified =
+                std::chrono::system_clock::from_time_t(fs::last_write_time(fs::path(opts.tokens_file)));
+            if (current_modified > last_modified) {
+                auto new_tokens = ReadTokens(opts.tokens_file);
+                {
+                    std::lock_guard lock(m);
+                    tokens_ = new_tokens;
+                }
+                last_modified = current_modified;
+            }
+        }
+        catch (const fs::filesystem_error& e) {
+            printf("ERROR: API token file (%s) read failed: %s\n", opts.tokens_file.c_str(), e.what());
+        }
+        catch (const ojson::exception& e) {
+            printf("ERROR: API token file (%s) parse failed: %s\n", opts.tokens_file.c_str(), e.what());
+        }
+        initialized = true;
+        std::this_thread::sleep_for(sleep_time);
+    }
+}
+
+} // namespace ecf::http
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/TokenStorage.hpp 5.13.0-1/libs/rest/src/ecflow/http/TokenStorage.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/TokenStorage.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/TokenStorage.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,66 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_TokenStorage_HPP
+#define ecflow_http_TokenStorage_HPP
+
+#include <chrono>
+#include <string>
+#include <vector>
+
+namespace ecf::http {
+
+struct Token
+{
+    std::string hash;
+    std::string salt;
+    std::string method;
+    std::string description;
+    std::chrono::system_clock::time_point expires;
+    std::chrono::system_clock::time_point revoked;
+
+    Token(const std::string& hash_,
+          const std::string& salt_,
+          const std::string& method_,
+          const std::string& description_,
+          const std::chrono::system_clock::time_point& expires_,
+          const std::chrono::system_clock::time_point& revoked_)
+        : hash(hash_),
+          salt(salt_),
+          method(method_),
+          description(description_),
+          expires(expires_),
+          revoked(revoked_) {}
+};
+
+class TokenStorage {
+public:
+    static const TokenStorage& instance() {
+        static TokenStorage instance_;
+        return instance_;
+    }
+    TokenStorage(const TokenStorage&)            = delete;
+    TokenStorage(TokenStorage&&)                 = delete;
+    TokenStorage& operator=(const TokenStorage&) = delete;
+    TokenStorage& operator=(TokenStorage&&)      = delete;
+
+    bool verify(const std::string& token) const;
+
+private:
+    TokenStorage();
+    ~TokenStorage() = default;
+    void ReadStorage();
+
+    std::vector<Token> tokens_;
+};
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_TokenStorage_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/TreeGeneration.hpp 5.13.0-1/libs/rest/src/ecflow/http/TreeGeneration.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/TreeGeneration.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/TreeGeneration.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,259 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_TreeGeneration_HPP
+#define ecflow_http_TreeGeneration_HPP
+
+#include <vector>
+
+#include "ecflow/http/JSON.hpp"
+#include "ecflow/http/TypeToJson.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+namespace ecf::http {
+
+struct BasicTree
+{
+    BasicTree() : root_(ojson::object({})), stack_{&root_} {}
+
+    void begin_visit(const Suite& suite) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[suite.name()] = ojson::object({});
+        stack_.push_back(&current);
+    }
+    void end_visit(const Suite& suite [[maybe_unused]]) { stack_.pop_back(); }
+
+    void begin_visit(const Family& family) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[family.name()] = ojson::object({});
+        stack_.push_back(&current);
+    }
+    void end_visit(const Family& family [[maybe_unused]]) { stack_.pop_back(); }
+
+    void begin_visit(const Task& task) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[task.name()] = ojson::object({});
+        stack_.push_back(&current);
+    }
+    void end_visit(const Task& task [[maybe_unused]]) { stack_.pop_back(); }
+
+    void begin_visit(const Alias& alias) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[alias.name()] = ojson::object({});
+        stack_.push_back(&current);
+    }
+    void end_visit(const Alias& alias [[maybe_unused]]) { stack_.pop_back(); }
+
+    const ojson& content() const { return root_; }
+
+private:
+    ojson root_;
+    std::vector<ojson*> stack_;
+};
+
+struct FullTree
+{
+    FullTree(bool with_id) : root_(ojson::object({})), stack_{&root_}, with_id_{with_id} {}
+
+    void begin_visit(const Suite& suite) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[suite.name()] = ojson::object({});
+
+        current["type"] = "suite";
+        if (with_id_) {
+            current["id"] = suite.absNodePath();
+        }
+        publish_state(suite, current);
+        publish_attributes(suite, current);
+
+        ojson& children = current["children"] = ojson::object({});
+        stack_.push_back(&children);
+    }
+
+    void end_visit(const Suite& suite [[maybe_unused]]) { stack_.pop_back(); }
+
+    void begin_visit(const Family& family) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[family.name()] = ojson::object({});
+
+        current["type"] = "family";
+        if (with_id_) {
+            current["id"] = family.absNodePath();
+        }
+        publish_state(family, current);
+        publish_attributes(family, current);
+
+        ojson& children = current["children"] = ojson::object({});
+        stack_.push_back(&children);
+    }
+
+    void end_visit(const Family& family [[maybe_unused]]) { stack_.pop_back(); }
+
+    void begin_visit(const Task& task) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[task.name()] = ojson::object({});
+
+        current["type"] = "task";
+        if (with_id_) {
+            current["id"] = task.absNodePath();
+        }
+        publish_state(task, current);
+        publish_attributes(task, current);
+
+        ojson& children = current["aliases"] = ojson::object({});
+        stack_.push_back(&children);
+    }
+
+    void end_visit(const Task& task [[maybe_unused]]) { stack_.pop_back(); }
+
+    void begin_visit(const Alias& alias) {
+        ojson& parent_ = *stack_.back();
+        ojson& current = parent_[alias.name()] = ojson::object({});
+        stack_.push_back(&current);
+
+        current["type"] = "alias";
+        if (with_id_) {
+            current["id"] = alias.absNodePath();
+        }
+        publish_state(alias, current);
+        publish_attributes(alias, current);
+    }
+
+    void end_visit(const Alias& alias [[maybe_unused]]) { stack_.pop_back(); }
+
+    const ojson& content() const { return root_; }
+
+private:
+    static void publish_state(const Node& node, ojson& parent) {
+        ojson& state = parent["state"] = ojson::object({});
+
+        state["node"]    = NState::toString(node.state());
+        state["default"] = DState::toString(node.dstate());
+    }
+
+    template <typename T>
+    static ojson publish_atribute(const T& attr, std::string_view type) {
+        auto j = ojson::object({});
+        to_json(j, attr);
+        j["type"] = type;
+        return j;
+    }
+
+    static void publish_attributes(const Node& node, ojson& parent) {
+        ojson& array = parent["attributes"] = ojson::array();
+
+        for (const auto& attr : node.labels()) {
+            array.emplace_back(publish_atribute(attr, "label"));
+        }
+        for (const auto& attr : node.meters()) {
+            array.emplace_back(publish_atribute(attr, "meter"));
+        }
+        for (const auto& attr : node.events()) {
+            array.emplace_back(publish_atribute(attr, "event"));
+        }
+        for (const auto& attr : node.variables()) {
+            array.emplace_back(publish_atribute(attr, "variable"));
+        }
+        for (const auto& attr : node.limits()) {
+            array.emplace_back(publish_atribute(*attr, "limit"));
+        }
+        for (const auto& attr : node.inlimits()) {
+            array.emplace_back(publish_atribute(attr, "inlimit"));
+        }
+        for (const auto& attr : node.dates()) {
+            array.emplace_back(publish_atribute(attr, "date"));
+        }
+        for (const auto& attr : node.days()) {
+            array.emplace_back(publish_atribute(attr, "day"));
+        }
+        for (const auto& attr : node.crons()) {
+            array.emplace_back(publish_atribute(attr, "cron"));
+        }
+        for (const auto& attr : node.timeVec()) {
+            array.emplace_back(publish_atribute(attr, "time"));
+        }
+        for (const auto& attr : node.todayVec()) {
+            array.emplace_back(publish_atribute(attr, "today"));
+        }
+        {
+            if (const auto* attr = node.get_late(); attr) {
+                array.emplace_back(publish_atribute(*attr, "late"));
+            }
+        }
+        {
+            if (const auto* attr = node.get_autocancel(); attr) {
+                array.emplace_back(publish_atribute(*attr, "autocancel"));
+            }
+        }
+        {
+            if (const auto* attr = node.get_autoarchive(); attr) {
+                array.emplace_back(publish_atribute(*attr, "autoarchive"));
+            }
+        }
+        {
+            if (const auto* attr = node.get_autorestore(); attr) {
+                array.emplace_back(publish_atribute(*attr, "autorestore"));
+            }
+        }
+        {
+            if (const auto& attr = node.repeat(); !attr.empty()) {
+                array.emplace_back(publish_atribute(attr, "repeat"));
+            }
+        }
+        {
+            if (const auto& attr = node.completeExpression(); !attr.empty()) {
+                auto j          = ojson::object({});
+                j["expression"] = attr;
+                j["type"]       = "complete";
+                array.emplace_back(j);
+            }
+        }
+        {
+            if (const auto& attr = node.triggerExpression(); !attr.empty()) {
+                auto j          = ojson::object({});
+                j["expression"] = attr;
+                j["type"]       = "trigger";
+                array.emplace_back(j);
+            }
+        }
+        for (const auto& attr : node.queues()) {
+            array.emplace_back(publish_atribute(attr, "queue"));
+        }
+        for (const auto& attr : node.zombies()) {
+            array.emplace_back(publish_atribute(attr, "zombie"));
+        }
+        for (const auto& attr : node.generics()) {
+            array.emplace_back(publish_atribute(attr, "generic"));
+        }
+
+        if (auto flag = node.get_flag(); flag.flag()) {
+            array.emplace_back(publish_atribute(flag, "flag"));
+        }
+
+        for (const auto& aviso : node.avisos()) {
+            array.emplace_back(publish_atribute(aviso, "aviso"));
+        }
+        for (const auto& mirror : node.mirrors()) {
+            array.emplace_back(publish_atribute(mirror, "mirror"));
+        }
+    }
+
+private:
+    ojson root_;
+    std::vector<ojson*> stack_;
+    bool with_id_;
+};
+
+} // namespace ecf::http
+
+#endif /* ecflow_http_TreeGeneration_HPP */
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/TypeToJson.cpp 5.13.0-1/libs/rest/src/ecflow/http/TypeToJson.cpp
--- 5.12.4-1/libs/rest/src/ecflow/http/TypeToJson.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/TypeToJson.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,372 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/http/TypeToJson.hpp"
+
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/SState.hpp"
+#include "ecflow/core/User.hpp"
+
+using ecf::http::ojson;
+
+void to_json(ojson& j, const ::Meter& a) {
+    j = ojson({{"name", a.name()}, {"min", a.min()}, {"max", a.max()}, {"value", a.value()}});
+}
+
+void to_json(ojson& j, const ::Label& a) {
+    j = ojson({{"name", a.name()}, {"value", a.new_value().empty() ? a.value() : a.new_value()}});
+}
+
+void to_json(ojson& j, const ::Variable& a) {
+    j = ojson({{"name", a.name()}, {"value", a.theValue()}, {"const", false}});
+}
+
+void to_json(ojson& j, const ::Event& a) {
+    j = ojson({{"name", a.name()}, {"value", a.value()}, {"initial_value", a.initial_value()}});
+}
+
+void to_json(ojson& j, const limit_ptr& a) {
+    to_json(j, *a);
+}
+
+void to_json(ojson& j, const Limit& a) {
+    j = ojson({{"name", a.name()}, {"value", a.value()}, {"limit", a.theLimit()}});
+}
+
+void to_json(ojson& j, const ::InLimit& a) {
+    j = ojson({{"value", a.toString()}});
+}
+
+void to_json(ojson& j, const ::DateAttr& a) {
+    std::string value = a.toString();
+    value             = value.substr(5, std::string::npos); // remove prefix "date "
+    j                 = ojson({{"value", value}, {"free", a.isSetFree()}});
+}
+
+void to_json(ojson& j, const ::DayAttr& a) {
+    std::string value = a.toString();
+    value             = value.substr(4, std::string::npos); // remove prefix "day "
+    j                 = ojson({{"value", value}, {"free", a.isSetFree()}, {"expired", a.expired()}});
+}
+
+void to_json(ojson& j, const ::RepeatDateList& a) {
+    std::vector<std::string> lst;
+    for (int i = 0; i < a.indexNum(); i++) {
+        lst.push_back(a.value_as_string(i));
+    }
+    j = ojson({{"name", a.name()}, {"index", a.index_or_value()}, {"value", a.valueAsString()}, {"values", lst}});
+}
+
+void to_json(ojson& j, const ::RepeatDate& a) {
+    j = ojson({{"name", a.name()}, {"start", a.start()}, {"end", a.end()}, {"step", a.step()}, {"value", a.value()}});
+}
+
+void to_json(ojson& j, const RepeatDateTime& a) {
+    j = ojson({{"name", a.name()},
+               {"start", ecf::Instant::format(a.start_instant())},
+               {"end", ecf::Instant::format(a.end_instant())},
+               {"step", ecf::Duration::format(a.step_duration())},
+               {"value", ecf::Instant::format(a.value_instant())}});
+}
+
+void to_json(ojson& j, const ::RepeatDay& a) {
+    j = ojson({{"name", a.name()}, {"value", a.value()}, {"valid", a.valid()}});
+}
+
+void to_json(ojson& j, const ::RepeatInteger& a) {
+    j = ojson({{"name", a.name()}, {"start", a.start()}, {"end", a.end()}, {"step", a.step()}, {"value", a.value()}});
+}
+
+void to_json(ojson& j, const ::RepeatEnumerated& a) {
+    std::vector<std::string> lst;
+    for (int i = 0; i < a.indexNum(); i++) {
+        lst.push_back(a.value_as_string(i));
+    }
+    j = ojson({{"name", a.name()}, {"index", a.index_or_value()}, {"value", a.valueAsString()}, {"values", lst}});
+}
+
+void to_json(ojson& j, const ::RepeatString& a) {
+    std::vector<std::string> lst;
+    for (int i = 0; i < a.indexNum(); i++) {
+        lst.push_back(a.value_as_string(i));
+    }
+    j = ojson({{"name", a.name()}, {"index", a.index_or_value()}, {"value", a.valueAsString()}, {"values", lst}});
+}
+
+namespace {
+
+template <typename T, typename... Rest>
+void repeat_to_json(ojson& j, const RepeatBase* b) {
+    if (auto rr = dynamic_cast<const T*>(b)) {
+        to_json(j, *rr);
+        return;
+    }
+
+    if constexpr (sizeof...(Rest) >= 1) {
+        repeat_to_json<Rest...>(j, b);
+    }
+}
+
+} // namespace
+
+void to_json(ojson& j, const Repeat& a) {
+    const RepeatBase* b = a.repeatBase();
+    repeat_to_json<RepeatDate,
+                   RepeatDateTime,
+                   RepeatDateList,
+                   RepeatInteger,
+                   RepeatDay,
+                   RepeatString,
+                   RepeatEnumerated>(j, b);
+}
+
+void to_json(ojson& j, const ::Stats& s) {
+    j["version"]                   = s.version_;
+    j["status"]                    = SState::to_string(s.status_);
+    j["host"]                      = s.host_;
+    j["port"]                      = s.port_;
+    j["up_since"]                  = s.up_since_;
+    j["job_sub_interval"]          = s.job_sub_interval_;
+    j["ECF_HOME"]                  = s.ECF_HOME_;
+    j["ECF_LOG"]                   = s.ECF_LOG_;
+    j["ECF_CHECK"]                 = s.ECF_CHECK_;
+    j["ECF_SSL"]                   = s.ECF_SSL_;
+    j["checkpt_interval"]          = s.checkpt_interval_;
+    j["checkpt_mode"]              = s.checkpt_mode_;
+    j["checkpt_save_time_alarm"]   = s.checkpt_save_time_alarm_;
+    j["no_of_suites"]              = s.no_of_suites_;
+    j["request_stats"]             = s.request_stats_;
+    j["locked_by_user"]            = s.locked_by_user_;
+    j["checkpt"]                   = s.checkpt_;
+    j["restore_defs_from_checkpt"] = s.restore_defs_from_checkpt_;
+    j["restart_server"]            = s.restart_server_;
+    j["shutdown_server"]           = s.shutdown_server_;
+    j["halt_server"]               = s.halt_server_;
+    j["ping"]                      = s.ping_;
+    j["debug_server_on"]           = s.debug_server_on_;
+    j["debug_server_off"]          = s.debug_server_off_;
+    j["get_defs"]                  = s.get_defs_;
+    j["server_version"]            = s.server_version_;
+    j["sync"]                      = s.sync_;
+    j["sync_full"]                 = s.sync_full_;
+    j["sync_clock"]                = s.sync_clock_;
+    j["news"]                      = s.news_;
+    j["task_init"]                 = s.task_init_;
+    j["task_complete"]             = s.task_complete_;
+    j["task_wait"]                 = s.task_wait_;
+    j["task_abort"]                = s.task_abort_;
+    j["task_event"]                = s.task_event_;
+    j["task_meter"]                = s.task_meter_;
+    j["task_label"]                = s.task_label_;
+    j["task_queue"]                = s.task_queue_;
+    j["zombie_fob"]                = s.zombie_fob_;
+    j["zombie_fail"]               = s.zombie_fail_;
+    j["zombie_adopt"]              = s.zombie_adopt_;
+    j["zombie_remove"]             = s.zombie_remove_;
+    j["zombie_get"]                = s.zombie_get_;
+    j["zombie_block"]              = s.zombie_block_;
+    j["zombie_kill"]               = s.zombie_kill_;
+    j["load_defs"]                 = s.load_defs_;
+    j["begin_cmd"]                 = s.begin_cmd_;
+    j["requeue_node"]              = s.requeue_node_;
+    j["node_job_gen"]              = s.node_job_gen_;
+    j["node_check_job_gen_only"]   = s.node_check_job_gen_only_;
+    j["node_delete"]               = s.node_delete_;
+    j["node_suspend"]              = s.node_suspend_;
+    j["node_resume"]               = s.node_resume_;
+    j["node_kill"]                 = s.node_kill_;
+    j["node_status"]               = s.node_status_;
+    j["node_edit_history"]         = s.node_edit_history_;
+    j["node_archive"]              = s.node_archive_;
+    j["node_restore"]              = s.node_restore_;
+    j["log_cmd"]                   = s.log_cmd_;
+    j["log_msg_cmd"]               = s.log_msg_cmd_;
+    j["order_node"]                = s.order_node_;
+    j["run_node"]                  = s.run_node_;
+    j["replace"]                   = s.replace_;
+    j["force"]                     = s.force_;
+    j["free_dep"]                  = s.free_dep_;
+    j["suites"]                    = s.suites_;
+    j["edit_script"]               = s.edit_script_;
+    j["alter_cmd"]                 = s.alter_cmd_;
+    j["ch_cmd"]                    = s.ch_cmd_;
+    j["plug"]                      = s.plug_;
+    j["move"]                      = s.move_;
+    j["group_cmd"]                 = s.group_cmd_;
+    j["server_load_cmd"]           = s.server_load_cmd_;
+    j["stats"]                     = s.stats_;
+    j["check"]                     = s.check_;
+    j["query"]                     = s.query_;
+    j["reload_white_list_file"]    = s.reload_white_list_file_;
+    j["reload_passwd_file"]        = s.reload_passwd_file_;
+    j["file_ecf"]                  = s.file_ecf_;
+    j["file_job"]                  = s.file_job_;
+    j["file_jobout"]               = s.file_jobout_;
+    j["file_cmdout"]               = s.file_cmdout_;
+    j["file_manual"]               = s.file_manual_;
+}
+
+void to_json(ojson& j, const ::Expression* a) {
+    if (!a) {
+        return;
+    }
+
+    to_json(j, *a);
+}
+
+void to_json(ojson& j, const ::Expression& a) {
+    const std::vector<PartExpression>& exprs = a.expr();
+    std::vector<ojson> str;
+
+    for (const auto& expr : exprs) {
+        std::string typestr("FIRST");
+        if (expr.andExpr()) {
+            typestr = "AND";
+        }
+        else if (expr.orExpr()) {
+            typestr = "OR";
+        }
+
+        ojson jj = ojson::object({{"expression", expr.expression()}, {"type", typestr}});
+
+        str.push_back(jj);
+    }
+
+    std::string value;
+    a.print(value, "complete");
+    value = value.substr(11, value.size() - 12);
+    j     = ojson::object({{"free", a.isFree()}, {"expressions", str}, {"value", value}});
+}
+
+void to_json(ojson& j, const ::QueueAttr& a) {
+    j["name"]  = a.name();
+    j["index"] = a.index();
+    j["value"] = a.value();
+    j["queue"] = a.list();
+}
+
+void to_json(ojson& j, const ::ZombieAttr& a) {
+    j["type"]           = ecf::Child::to_string(a.zombie_type());
+    j["action"]         = ecf::User::to_string(a.action());
+    j["child_commands"] = ecf::Child::to_string(a.child_cmds());
+    j["lifetime"]       = a.zombie_lifetime();
+}
+
+void to_json(ojson& j, const ::GenericAttr& a) {
+    j["name"]   = a.name();
+    j["values"] = a.values();
+}
+
+namespace ecf {
+
+void to_json(ojson& j, const ecf::TimeAttr& a) {
+    std::string value = a.toString();
+    value             = value.substr(5, std::string::npos); // remove prefix "date "
+    j                 = ojson({{"value", value}});
+}
+
+void to_json(ojson& j, const ecf::TodayAttr& a) {
+    j = ojson(
+        {{"value", a.time_series().toString()}, {"free", a.isSetFree()}, {"expired", !a.time_series().is_valid()}});
+}
+
+void to_json(ojson& j, const ecf::CronAttr& a) {
+    std::string value = a.toString();
+    value             = value.substr(5, std::string::npos); // remove prefix "cron "
+    j                 = ojson({{"value", value}});
+}
+
+void to_json(ojson& j, const ecf::Flag& a) {
+    j["value"] = a.to_string();
+}
+
+void to_json(ojson& j, const ecf::LateAttr* a) {
+    if (!a) {
+        return;
+    }
+
+    to_json(j, *a);
+}
+
+void to_json(ojson& j, const ecf::LateAttr& a) {
+    j["submitted"]            = a.submitted();
+    j["active"]               = a.active();
+    j["complete"]             = a.complete();
+    j["complete_is_relative"] = a.complete_is_relative();
+    j["is_late"]              = a.isLate();
+    const std::string value   = a.toString().substr(5, std::string::npos); // remove prefix "late "
+    j["value"]                = value;
+}
+
+void to_json(ojson& j, const ecf::TimeSlot& a) {
+    j["value"] = a.toString();
+}
+
+void to_json(ojson& j, const ecf::AutoCancelAttr* a) {
+    if (!a) {
+        return;
+    }
+
+    to_json(j, *a);
+}
+
+void to_json(ojson& j, const ecf::AutoCancelAttr& a) {
+    j["relative"]     = a.relative();
+    j["days"]         = a.days();
+    j["time"]         = a.time();
+    std::string value = a.toString().substr(11, std::string::npos);
+    j["value"]        = value;
+}
+
+void to_json(ojson& j, const ecf::AutoRestoreAttr* a) {
+    if (!a) {
+        return;
+    }
+
+    to_json(j, *a);
+}
+void to_json(ojson& j, const ecf::AutoRestoreAttr& a) {
+    std::string value = a.toString().substr(12, std::string::npos);
+    j["value"]        = value;
+}
+
+void to_json(ojson& j, const ecf::AutoArchiveAttr* a) {
+    if (!a) {
+        return;
+    }
+
+    to_json(j, *a);
+}
+void to_json(ojson& j, const ecf::AutoArchiveAttr& a) {
+    j["relative"]     = a.relative();
+    j["days"]         = a.days();
+    j["time"]         = a.time();
+    std::string value = a.toString().substr(12, std::string::npos);
+    j["value"]        = value;
+}
+
+void to_json(ojson& j, const ecf::AvisoAttr& a) {
+    j["name"]     = a.name();
+    j["listener"] = a.listener();
+    j["url"]      = a.url();
+    j["schema"]   = a.schema();
+    j["polling"]  = a.polling();
+}
+
+void to_json(ojson& j, const ecf::MirrorAttr& a) {
+    j["name"]        = a.name();
+    j["remote_path"] = a.remote_path();
+    j["remote_host"] = a.remote_host();
+    j["remote_port"] = a.remote_port();
+    j["polling"]     = a.polling();
+    j["ssl"]         = a.ssl();
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/rest/src/ecflow/http/TypeToJson.hpp 5.13.0-1/libs/rest/src/ecflow/http/TypeToJson.hpp
--- 5.12.4-1/libs/rest/src/ecflow/http/TypeToJson.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/src/ecflow/http/TypeToJson.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,91 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_TypeToJson_HPP
+#define ecflow_http_TypeToJson_HPP
+
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/attribute/ClockAttr.hpp"
+#include "ecflow/attribute/CronAttr.hpp"
+#include "ecflow/attribute/DateAttr.hpp"
+#include "ecflow/attribute/DayAttr.hpp"
+#include "ecflow/attribute/GenericAttr.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/attribute/RepeatAttr.hpp"
+#include "ecflow/attribute/TimeAttr.hpp"
+#include "ecflow/attribute/TodayAttr.hpp"
+#include "ecflow/attribute/Variable.hpp"
+#include "ecflow/attribute/ZombieAttr.hpp"
+#include "ecflow/base/Stats.hpp"
+#include "ecflow/core/TimeSlot.hpp"
+#include "ecflow/http/JSON.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/AvisoAttr.hpp"
+#include "ecflow/node/Expression.hpp"
+#include "ecflow/node/Flag.hpp"
+#include "ecflow/node/InLimit.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/LimitFwd.hpp"
+#include "ecflow/node/MirrorAttr.hpp"
+
+/**
+ * IMPORTANT
+ *
+ * The following `to_json` functions are used by nlohmann::json library to convert the given object to a JSON object.
+ *
+ * These functions are effectively customization points, found using ADL (Argument-Dependent Lookup), and so need to be
+ * declared in the same namespace as the object.
+ */
+
+void to_json(ecf::http::ojson&, const ::Meter&);
+void to_json(ecf::http::ojson&, const ::Label&);
+void to_json(ecf::http::ojson&, const ::Variable&);
+void to_json(ecf::http::ojson&, const ::Event&);
+void to_json(ecf::http::ojson&, const ::limit_ptr&);
+void to_json(ecf::http::ojson&, const ::Limit&);
+void to_json(ecf::http::ojson&, const ::InLimit&);
+void to_json(ecf::http::ojson&, const ::DateAttr&);
+void to_json(ecf::http::ojson&, const ::DayAttr&);
+void to_json(ecf::http::ojson&, const ::RepeatDate&);
+void to_json(ecf::http::ojson&, const ::RepeatDateTime&);
+void to_json(ecf::http::ojson&, const ::RepeatDay&);
+void to_json(ecf::http::ojson&, const ::RepeatDateList&);
+void to_json(ecf::http::ojson&, const ::RepeatInteger&);
+void to_json(ecf::http::ojson&, const ::RepeatEnumerated&);
+void to_json(ecf::http::ojson&, const ::RepeatString&);
+void to_json(ecf::http::ojson&, const ::Repeat&);
+void to_json(ecf::http::ojson&, const ::Stats&);
+void to_json(ecf::http::ojson&, const ::Expression*);
+void to_json(ecf::http::ojson&, const ::Expression&);
+void to_json(ecf::http::ojson&, const ::QueueAttr&);
+void to_json(ecf::http::ojson&, const ::ZombieAttr&);
+void to_json(ecf::http::ojson&, const ::GenericAttr&);
+namespace ecf {
+void to_json(ecf::http::ojson&, const ecf::TimeAttr&);
+void to_json(ecf::http::ojson&, const ecf::TodayAttr&);
+void to_json(ecf::http::ojson&, const ecf::CronAttr&);
+void to_json(ecf::http::ojson&, const ecf::Flag&);
+void to_json(ecf::http::ojson&, const ecf::LateAttr*);
+void to_json(ecf::http::ojson&, const ecf::LateAttr&);
+void to_json(ecf::http::ojson&, const ecf::TimeSlot&);
+void to_json(ecf::http::ojson&, const ecf::AutoCancelAttr*);
+void to_json(ecf::http::ojson&, const ecf::AutoCancelAttr&);
+void to_json(ecf::http::ojson&, const ecf::AutoArchiveAttr*);
+void to_json(ecf::http::ojson&, const ecf::AutoArchiveAttr&);
+void to_json(ecf::http::ojson&, const ecf::AutoRestoreAttr*);
+void to_json(ecf::http::ojson&, const ecf::AutoRestoreAttr&);
+void to_json(ecf::http::ojson&, const ecf::AvisoAttr&);
+void to_json(ecf::http::ojson&, const ecf::MirrorAttr&);
+} // namespace ecf
+
+#endif /* ecflow_http_TypeToJson_HPP */
diff -pruN 5.12.4-1/libs/rest/test/Certificate.hpp 5.13.0-1/libs/rest/test/Certificate.hpp
--- 5.12.4-1/libs/rest/test/Certificate.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/test/Certificate.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,188 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+///
+/// Based on https://gist.github.com/nathan-osman/5041136
+///
+
+#ifndef ecflow_http_test_Certificate_HPP
+#define ecflow_http_test_Certificate_HPP
+
+#include <cstdio>
+#include <iostream>
+
+#include <openssl/evp.h>
+#include <openssl/pem.h>
+#include <openssl/rsa.h>
+#include <openssl/x509.h>
+
+class Certificate {
+public:
+    Certificate() = delete;
+    explicit Certificate(const std::string& path);
+    ~Certificate();
+
+private:
+    std::string path_;
+    EVP_PKEY* generate_key();
+    X509* generate_x509(EVP_PKEY* pkey);
+    void write_to_disk(EVP_PKEY* pkey, X509* x509);
+};
+
+inline Certificate::Certificate(const std::string& path) : path_(path) {
+    // std::cout << "Generating RSA key..." << std::endl;
+
+    EVP_PKEY* pkey = generate_key();
+
+    /* Generate the certificate. */
+    // std::cout << "Generating x509 certificate..." << std::endl;
+
+    X509* x509 = generate_x509(pkey);
+    if (!x509) {
+        EVP_PKEY_free(pkey);
+        throw std::runtime_error("Unable to create certificate");
+        ;
+    }
+
+    /* Write the private key and certificate out to disk. */
+    // std::cout << "Writing key and certificate to disk..." << std::endl;
+
+    write_to_disk(pkey, x509);
+}
+
+inline Certificate::~Certificate() {
+    if (remove((path_ + "/server.crt").c_str()) != 0) {
+        std::cerr << "Failed to remove file server.crt" << std::endl;
+    }
+    else {
+        std::cout << "Removed file " << (path_ + "/server.crt") << std::endl;
+    }
+
+    if (remove((path_ + "/server.key").c_str()) != 0) {
+        std::cerr << "Failed to remove file server.key" << std::endl;
+    }
+    else {
+        std::cout << "Removed file " << (path_ + "/server.key") << std::endl;
+    }
+}
+
+/* Generates a 2048-bit RSA key. */
+inline EVP_PKEY* Certificate::generate_key() {
+    const int KEY_LEN = 2048;
+#if OPENSSL_VERSION_MAJOR >= 3
+    EVP_PKEY* pkey = EVP_RSA_gen(KEY_LEN);
+    if (!pkey) {
+        throw std::runtime_error("Unable to create EVP_PKEY structure");
+    }
+#else
+    /* Allocate memory for the EVP_PKEY structure. */
+    EVP_PKEY* pkey = EVP_PKEY_new();
+
+    /* Generate the RSA key and assign it to pkey. */
+    RSA* rsa    = RSA_new();
+    BIGNUM* bne = BN_new();
+
+    if (!BN_set_word(bne, 65537)) {
+        throw std::runtime_error("Unable to set BIGNUM");
+    }
+
+    if (!RSA_generate_key_ex(rsa, KEY_LEN, bne, NULL)) {
+        throw std::runtime_error("Unable to generate 2048-bit RSA key");
+    }
+
+    // RSA * rsa = RSA_generate_key(2048, RSA_F4, NULL, NULL);
+    if (!EVP_PKEY_assign_RSA(pkey, rsa)) {
+        EVP_PKEY_free(pkey);
+        throw std::runtime_error("Unable to generate 2048-bit RSA key");
+    }
+#endif
+
+    /* The key has been generated, return it. */
+    return pkey;
+}
+
+/* Generates a self-signed x509 certificate. */
+inline X509* Certificate::generate_x509(EVP_PKEY* pkey) {
+    /* Allocate memory for the X509 structure. */
+    X509* x509 = X509_new();
+    if (!x509) {
+        EVP_PKEY_free(pkey);
+        throw std::runtime_error("Unable to create X509 structure");
+    }
+
+    /* Set the serial number. */
+    ASN1_INTEGER_set(X509_get_serialNumber(x509), 1);
+
+    /* This certificate is valid from now until exactly one year from now. */
+    X509_gmtime_adj(X509_get_notBefore(x509), 0);
+    X509_gmtime_adj(X509_get_notAfter(x509), 31536000L);
+
+    /* Set the public key for our certificate. */
+    X509_set_pubkey(x509, pkey);
+
+    /* We want to copy the subject name to the issuer name. */
+    X509_NAME* name = X509_get_subject_name(x509);
+
+    /* Set the country code and common name. */
+    X509_NAME_add_entry_by_txt(name, "C", MBSTRING_ASC, (unsigned char*)"CA", -1, -1, 0);
+    X509_NAME_add_entry_by_txt(name, "O", MBSTRING_ASC, (unsigned char*)"ecflow-test", -1, -1, 0);
+    X509_NAME_add_entry_by_txt(name, "CN", MBSTRING_ASC, (unsigned char*)"localhost", -1, -1, 0);
+
+    /* Now set the issuer name. */
+    X509_set_issuer_name(x509, name);
+
+    /* Actually sign the certificate with our key. */
+    if (!X509_sign(x509, pkey, EVP_sha1())) {
+        X509_free(x509);
+        EVP_PKEY_free(pkey);
+        throw std::runtime_error("Error signing certificate");
+    }
+
+    return x509;
+}
+
+inline void Certificate::write_to_disk(EVP_PKEY* pkey, X509* x509) {
+    /* Open the PEM file for writing the key to disk. */
+
+    FILE* pkey_file = fopen((path_ + "/server.key").c_str(), "wb");
+    if (!pkey_file) {
+        EVP_PKEY_free(pkey);
+        throw std::runtime_error("Unable to open " + path_ + "/server.key for writing");
+    }
+
+    /* Write the key to disk. */
+    bool ret = PEM_write_PrivateKey(pkey_file, pkey, NULL, NULL, 0, NULL, NULL);
+    fclose(pkey_file);
+
+    EVP_PKEY_free(pkey);
+
+    if (!ret) {
+        X509_free(x509);
+        throw std::runtime_error("Unable to write private key to disk");
+    }
+
+    /* Open the PEM file for writing the certificate to disk. */
+    FILE* x509_file = fopen((path_ + "/server.crt").c_str(), "wb");
+    if (!x509_file) {
+        X509_free(x509);
+        throw std::runtime_error("Unable to open " + path_ + "/server.crt for writing");
+    }
+
+    /* Write the certificate to disk. */
+    ret = PEM_write_X509(x509_file, x509);
+    fclose(x509_file);
+
+    X509_free(x509);
+    if (!ret) {
+        throw std::runtime_error("Unable to write private key to disk");
+    }
+}
+
+#endif /* #ifndef ecflow_http_test_Certificate_HPP */
diff -pruN 5.12.4-1/libs/rest/test/InvokeServer.hpp 5.13.0-1/libs/rest/test/InvokeServer.hpp
--- 5.12.4-1/libs/rest/test/InvokeServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/test/InvokeServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_test_InvokeServer_HPP
+#define ecflow_http_test_InvokeServer_HPP
+
+#include <iostream>
+#include <thread>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestHelper.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/EcfPortLock.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/server/Server.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+class InvokeServer {
+public:
+    InvokeServer() {
+        std::string port(getenv("ECF_PORT"));
+        /// Remove check pt and backup check pt file, else server will load it & remove log file
+        ecf::Host h;
+        fs::remove(h.ecf_checkpt_file(port));
+        fs::remove(h.ecf_backup_checkpt_file(port));
+        fs::remove(h.ecf_log_file(port));
+
+        std::string theServerInvokePath = ecf::File::find_ecf_server_path();
+
+        BOOST_REQUIRE_MESSAGE(!theServerInvokePath.empty(), "The server program could not be found");
+        BOOST_REQUIRE_MESSAGE(fs::exists(theServerInvokePath), "Server exe does not exist at:" << theServerInvokePath);
+
+        BOOST_TEST_MESSAGE("Using eclow_server from " << theServerInvokePath);
+
+        std::thread t([&] { system(theServerInvokePath.c_str()); });
+
+        t.detach();
+
+        sleep(1);
+
+        ClientInvoker theClient("localhost", port);
+        if (theClient.wait_for_server_reply()) {
+            theClient.restartServer();
+            server_started = true;
+        }
+        else {
+            server_started = false;
+        }
+    }
+
+    ~InvokeServer() {
+        std::string port(getenv("ECF_PORT"));
+
+        BOOST_TEST_MESSAGE("*****InvokeServer:: Closing server on port " << port);
+        {
+            ClientInvoker theClient("localhost", port);
+            BOOST_REQUIRE_NO_THROW(theClient.terminateServer());
+            BOOST_REQUIRE_MESSAGE(theClient.wait_for_server_death(), "Failed to terminate server after 60 seconds\n");
+        }
+
+        ecf::Host h;
+        fs::remove(h.ecf_log_file(port));
+        BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_log_file(port)), "log file " << h.ecf_log_file(port) << " not deleted\n");
+
+        fs::remove(h.ecf_checkpt_file(port));
+        fs::remove(h.ecf_backup_checkpt_file(port));
+        BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_checkpt_file(port)),
+                            "file " << h.ecf_checkpt_file(port) << " not deleted\n");
+        BOOST_CHECK_MESSAGE(!fs::exists(h.ecf_backup_checkpt_file(port)),
+                            "file " << h.ecf_backup_checkpt_file(port) << " not deleted\n");
+    }
+
+    bool server_started{false};
+};
+
+#endif /* ecflow_http_test_InvokeServer_HPP */
diff -pruN 5.12.4-1/libs/rest/test/TestApiV1.cpp 5.13.0-1/libs/rest/test/TestApiV1.cpp
--- 5.12.4-1/libs/rest/test/TestApiV1.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/test/TestApiV1.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,987 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifdef ECF_OPENSSL
+    #define CPPHTTPLIB_OPENSSL_SUPPORT
+#endif
+
+#include <httplib.h>
+
+#include <boost/test/unit_test.hpp>
+
+#include "Certificate.hpp"
+#include "InvokeServer.hpp"
+#include "TokenFile.hpp"
+#include "ecflow/http/HttpServer.hpp"
+#include "ecflow/http/HttpServerException.hpp"
+#include "ecflow/http/JSON.hpp"
+
+BOOST_AUTO_TEST_SUITE(S_Http)
+
+BOOST_AUTO_TEST_SUITE(T_ApiV1)
+
+using ecf::http::HttpServer;
+using ecf::http::HttpStatusCode;
+using ecf::http::ojson;
+
+const std::string API_HOST("localhost");
+const std::string API_KEY("3a8c3f7ac204d9c6370b5916bd8b86166c208e10776285edcbc741d56b5b4c1e");
+
+std::unique_ptr<Certificate> create_certificate() {
+    const char* cert_dir = getenv("ECF_API_CERT_DIRECTORY");
+    const std::string path_to_cert =
+        (cert_dir == nullptr) ? std::string(getenv("HOME")) + "/.ecflowrc/ssl/" : std::string(cert_dir);
+
+    std::unique_ptr<Certificate> cert;
+
+    BOOST_TEST_MESSAGE("Certificates at " << path_to_cert);
+
+    if (fs::exists(path_to_cert + "/server.crt") == false || fs::exists(path_to_cert + "/server.key") == false) {
+        if (fs::exists(path_to_cert) == false) {
+            fs::create_directories(path_to_cert);
+        }
+
+        cert = std::make_unique<Certificate>(path_to_cert);
+
+        setenv("ECF_API_CERT_DIRECTORY", path_to_cert.c_str(), 1);
+        return cert;
+    }
+    return cert;
+}
+
+std::unique_ptr<TokenFile> create_token_file() {
+    fs::path cwd(fs::current_path());
+    std::string tokens_file = cwd.string() + "/api-tokens.json";
+
+    auto tokenfile = std::make_unique<TokenFile>(tokens_file);
+    BOOST_TEST_MESSAGE("Token file " << tokens_file);
+    return tokenfile;
+}
+
+void start_api_server() {
+
+    if (getenv("NO_API_SERVER") != nullptr)
+        return; // for debugging
+    std::thread t([] {
+        int argc     = 3;
+        char* argv[] = {(char*)"ecflow_http", (char*)"--polling_interval", (char*)"1", NULL};
+
+        HttpServer server(argc, argv);
+        server.run();
+    });
+
+    sleep(1);
+    t.detach();
+}
+
+std::unique_ptr<InvokeServer> start_ecflow_server() {
+    if (getenv("NO_ECFLOW_SERVER") != nullptr)
+        return nullptr;
+
+    auto srv = std::make_unique<InvokeServer>();
+
+    BOOST_REQUIRE_MESSAGE(srv->server_started, "Server failed to start on port " << getenv("ECF_PORT"));
+    BOOST_TEST_MESSAGE("ecflow server at localhost:" << getenv("ECF_PORT"));
+    return srv;
+}
+
+struct SetupTest
+{
+    SetupTest() : tokenfile(create_token_file()), cert(create_certificate()) {
+        sigset_t set;
+        sigemptyset(&set);
+        sigaddset(&set, SIGPIPE);
+
+        if (pthread_sigmask(SIG_BLOCK, &set, NULL) != 0) {
+            throw std::runtime_error("Failed to set signal mask");
+        }
+
+        setenv("ECF_PORT", "3199", 0);
+        setenv("ECF_HOST", "localhost", 1);
+    }
+    void setup() {
+        // This needs to be initialized in setup() instead
+        // of constructor... really don't know why
+        srv = start_ecflow_server();
+        start_api_server();
+        printf("======= TESTS STARTING ========\n");
+    }
+    ~SetupTest() { printf("======= TESTS FINISHED ========\n"); }
+
+    std::unique_ptr<TokenFile> tokenfile{nullptr};
+    std::unique_ptr<Certificate> cert{nullptr};
+    std::unique_ptr<InvokeServer> srv{nullptr};
+};
+
+BOOST_TEST_GLOBAL_FIXTURE(SetupTest);
+
+httplib::Response handle_response(const httplib::Result& r,
+                                  HttpStatusCode expected_code = HttpStatusCode::success_ok,
+                                  bool throw_on_error          = false) {
+    if (r) {
+        BOOST_TEST_MESSAGE("Return code: " << r->status);
+        BOOST_TEST_MESSAGE("Return value: " << r->body);
+    }
+    else {
+        BOOST_TEST_MESSAGE("Null reply from server");
+    }
+
+    if (throw_on_error) {
+        if (!r) {
+            throw std::runtime_error("NULL reply from server");
+        }
+        else if (r->status != expected_code) {
+            throw std::runtime_error(
+                "Expected status code: " + ecf::convert_to<std::string>(static_cast<int>(expected_code)) +
+                " got: " + ecf::convert_to<std::string>(r->status));
+        }
+    }
+    else {
+        BOOST_REQUIRE_MESSAGE(r, "ERROR: no response");
+        BOOST_REQUIRE_MESSAGE(r->status == expected_code,
+                              "ERROR: status code is not " +
+                                  ecf::convert_to<std::string>(static_cast<int>(expected_code)));
+    }
+
+    return httplib::Response(*r);
+}
+
+httplib::Result request(const std::string& method,
+                        const std::string& resource,
+                        const std::string& payload             = "",
+                        const std::string& token               = "",
+                        const httplib::Headers& custom_headers = {}) {
+    httplib::SSLClient c(API_HOST, 8080);
+
+    c.enable_server_certificate_verification(false);
+    c.set_connection_timeout(3);
+
+    BOOST_TEST_MESSAGE("Request URL: " << method << " " << API_HOST << resource);
+    BOOST_TEST_MESSAGE("Request body: " << payload);
+
+    httplib::Headers h = {{"Content-type", "application/json"}};
+
+    if ((method == "post" || method == "put" || method == "delete") && token.empty() == false) {
+        h.insert(std::make_pair("Authorization", "Bearer " + token));
+    }
+
+    for (const auto& kv : custom_headers) {
+        h.insert(kv);
+    }
+
+    c.set_default_headers(h);
+
+    if (method == "get" || method == "head")
+        return c.Get(resource);
+    else if (method == "post")
+        return c.Post(resource, payload, "application/json");
+    else if (method == "put")
+        return c.Put(resource, payload, "application/json");
+    else if (method == "delete")
+        return c.Delete(resource, payload, "application/json");
+
+    BOOST_FAIL("Unknown HTTP method");
+
+    return httplib::Result(nullptr, httplib::Error::Unknown); // to silence compiler warnings
+}
+
+template <typename T>
+bool wait_until(T&& func, int wait_time = 1, int wait_count = 10) {
+    int c = 0;
+
+    while (func() == false) {
+        c++;
+        if (c > wait_count) {
+            BOOST_FAIL("Test failed");
+        }
+        sleep(wait_time);
+    }
+    return true;
+}
+
+bool check_for_path(const std::string& path) {
+    try {
+        handle_response(request("head", path), HttpStatusCode::success_ok, true);
+        return true;
+    }
+    catch (...) {
+        return false;
+    }
+}
+
+bool check_for_element(const std::string& path,
+                       const std::string& key_name,
+                       const std::string& attr_name,
+                       const std::string& value) {
+
+    try {
+        auto r = handle_response(request("get", path), HttpStatusCode::success_ok, true);
+        auto j = ojson::parse(r.body);
+
+        if (j.is_null()) {
+            return false;
+        }
+        else if (j.is_array() == false) {
+            j = ojson::array({j});
+            std::cout << "json is " << j << std::endl;
+        }
+
+        for (const auto& x : j) {
+            // std::cout << x << std::endl;
+            if (attr_name.empty() == false) {
+                // { "name": "foo", "value": "bar"}
+                // std::cout << "expecting: " << attr_name << "=" << value << " got: " << x["name"].get<std::string>()
+                // << "=" << json_type_to_string(x[key_name]) << std::endl;
+                if (attr_name == x["name"] && value == ecf::http::json_type_to_string(x[key_name]))
+                    return true;
+            }
+            else if (key_name.empty() == false) {
+                // { "foo" : "bar" }
+                // std::cout << "expecting: " << key_name << "='" << value << " got: " << key_name << "='" <<
+                // json_type_to_string(x[key_name]) << "'" << std::endl;
+
+                if (ecf::http::json_type_to_string(x[key_name]) == value)
+                    return true;
+            }
+            else {
+                // "bar"
+                // std::cout << "expecting: '" << value << "' got: '" << json_type_to_string(x) << "'" << std::endl;
+
+                if (value == ecf::http::json_type_to_string(x))
+                    return true;
+            }
+        }
+    }
+    catch (const std::exception& e) {
+        BOOST_TEST_MESSAGE(e.what());
+    }
+    // BOOST_TEST_MESSAGE("Attribute " << attr_name << " --> " << key_name << "=" << value << " at path " << path << "
+    // not found");
+    return false;
+}
+
+BOOST_AUTO_TEST_CASE(test_server) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    wait_until([] { return check_for_element("/v1/server/status?filter=status", "", "", "RUNNING"); });
+
+    handle_response(request("get", "/v1/server/ping"));
+
+    handle_response(
+        request("post", "/v1/server/attributes", R"({"type":"variable","name":"foo","value":"bar"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "foo", "bar"); });
+
+    handle_response(
+        request("put", "/v1/server/attributes", R"({"type":"variable","name":"foo","value":"baz"})", API_KEY));
+    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "foo", "baz"); });
+
+    handle_response(request("delete", "/v1/server/attributes", R"({"type":"variable","name":"foo"})", API_KEY),
+                    HttpStatusCode::success_no_content);
+    wait_until(
+        [] { return false == check_for_element("/v1/server/attributes?filter=variables", "value", "foo", "bar"); });
+}
+
+BOOST_AUTO_TEST_CASE(test_suite) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    // remove test-suite if it exists; disregard any problems with the call
+    request("delete", "/v1/suites/test/definition", "", API_KEY);
+    wait_until([] { return false == check_for_path("/v1/suites/test/definition"); });
+
+    handle_response(request("post",
+                            "/v1/suites",
+                            R"({"definition" : "suite test\n  family a\n    task a\n  endfamily\nendsuite"})",
+                            API_KEY),
+                    HttpStatusCode::success_created);
+    wait_until([] { return check_for_path("/v1/suites/test/definition"); });
+
+    auto result = handle_response(request("get", "/v1/suites"));
+
+    auto content = ojson::parse(result.body);
+    bool found   = false;
+
+    for (const auto& suite : content) {
+        if (suite.get<std::string>() == "test") {
+            found = true;
+            break;
+        }
+    }
+    BOOST_REQUIRE(found);
+
+    result  = handle_response(request("get", "/v1/suites/tree"));
+    content = ojson::parse(result.body);
+    found   = false;
+
+    for (const auto& suite : content.items()) {
+        if (suite.key() == "test") {
+            found = true;
+            break;
+        }
+    }
+
+    BOOST_REQUIRE(found);
+
+    result  = handle_response(request("get", "/v1/suites/test/a/tree"));
+    content = ojson::parse(result.body);
+    found   = false;
+
+    for (const auto& node : content.items()) {
+        if (node.key() == "a") {
+            found = true;
+            break;
+        }
+    }
+
+    BOOST_REQUIRE(found);
+
+    handle_response(request("put", "/v1/suites/test/status", R"({"action":"begin"})", API_KEY));
+
+    auto response = ojson::parse(handle_response(request("get", "/v1/suites/test/definition")).body);
+
+    const std::string& correct = "suite test\n  family a\n    task a\n  endfamily\nendsuite\n";
+
+    BOOST_REQUIRE(response.at("definition").get<std::string>() == correct);
+
+    handle_response(request("put", "/v1/suites/test/status", R"({"action":"suspend"})", API_KEY));
+    wait_until([] { return check_for_element("/v1/suites/test/status?filter=status", "", "", "suspended"); });
+}
+
+BOOST_AUTO_TEST_CASE(test_node_basic_tree) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    // (0) Clean up -- in case there is any left-over from passed/failed tests
+    request("delete", "/v1/suites/basic_suite/definition", "", API_KEY);
+    wait_until([] { return false == check_for_path("/v1/suites/basic_suite/definition"); });
+
+    // (1) Publish 'basic_suite' suite
+
+    std::string suite_definition =
+        R"({"definition" : "suite basic_suite\n  family f\n    task t\n      label l \"value\"\n      meter m 0 100 50\n      event e\n  endfamily\nendsuite\n# comment"})";
+    handle_response(request("post", "/v1/suites", suite_definition, API_KEY), HttpStatusCode::success_created);
+    wait_until([] { return check_for_path("/v1/suites/basic_suite/definition"); });
+
+    // (2) Retrieve 'basic_suite' suite tree
+    {
+        auto result  = handle_response(request("get", "/v1/suites/tree"));
+        auto content = ojson::parse(result.body);
+
+        BOOST_REQUIRE(content.contains("basic_suite"));
+        BOOST_REQUIRE(content["basic_suite"].contains("f"));
+        BOOST_REQUIRE(content["basic_suite"]["f"].contains("t"));
+    }
+
+    // (3) Retrieve 'basic_suite' suite tree, explicitly specifying basic content
+    {
+        auto result  = handle_response(request("get", "/v1/suites/tree?content=basic"));
+        auto content = ojson::parse(result.body);
+
+        BOOST_REQUIRE(content.contains("basic_suite"));
+        BOOST_REQUIRE(content["basic_suite"].contains("f"));
+        BOOST_REQUIRE(content["basic_suite"]["f"].contains("t"));
+    }
+
+    // (4) Retrieve specific node tree
+    {
+        auto result  = handle_response(request("get", "/v1/suites/basic_suite/f/tree?content=basic"));
+        auto content = ojson::parse(result.body);
+
+        BOOST_REQUIRE(content.contains("f"));
+        BOOST_REQUIRE(content["f"].contains("t"));
+    }
+
+    // (5) Clean up
+    request("delete", "/v1/suites/basic_suite/definition", "", API_KEY);
+    wait_until([] { return false == check_for_path("/v1/suites/basic_suite/definition"); });
+}
+
+BOOST_AUTO_TEST_CASE(test_node_full_tree) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    // (0) Clean up -- in case there is any left-over from passed/failed tests
+    request("delete", "/v1/suites/full_suite/definition", "", API_KEY);
+    wait_until([] { return false == check_for_path("/v1/suites/full_suite/definition"); });
+
+    // (1) Publish 'full_tree' suite
+
+    std::string suite_definition =
+        R"({"definition" : "suite full_suite\n  family f\n    task t\n      label l \"value\"\n      meter m 0 100 50\n      event e\n  endfamily\nendsuite\n# comment"})";
+    handle_response(request("post", "/v1/suites", suite_definition, API_KEY), HttpStatusCode::success_created);
+    wait_until([] { return check_for_path("/v1/suites/full_suite/definition"); });
+
+    // (2) Retrieve 'full_suite' suite tree, explicitly specifying full content
+    {
+        auto result  = handle_response(request("get", "/v1/suites/tree?content=full"));
+        auto content = ojson::parse(result.body);
+
+        BOOST_REQUIRE(content.contains("full_suite"));
+        BOOST_REQUIRE(content["full_suite"].contains("type"));
+        BOOST_REQUIRE(content["full_suite"]["type"] == "suite");
+        BOOST_REQUIRE(content["full_suite"].contains("state"));
+        BOOST_REQUIRE(content["full_suite"]["state"].contains("node"));
+        BOOST_REQUIRE(content["full_suite"]["state"].contains("default"));
+        BOOST_REQUIRE(content["full_suite"].contains("children"));
+
+        BOOST_REQUIRE(content["full_suite"]["children"].contains("f"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"].contains("type"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["type"] == "family");
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"].contains("state"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["state"].contains("node"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["state"].contains("default"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"].contains("children"));
+
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"].contains("t"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("type"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["type"] == "task");
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("state"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["state"].contains("node"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["state"].contains("default"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("attributes"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["attributes"].size() == 3);
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"].contains("aliases"));
+        BOOST_REQUIRE(content["full_suite"]["children"]["f"]["children"]["t"]["aliases"].size() == 0);
+    }
+
+    // (2) Retrieve 'full_suite' suite tree, explicitly specifying full content
+    {
+        auto result  = handle_response(request("get", "/v1/suites/full_suite/f/tree?content=full"));
+        auto content = ojson::parse(result.body);
+
+        BOOST_REQUIRE(content.contains("f"));
+        BOOST_REQUIRE(content["f"].contains("state"));
+        BOOST_REQUIRE(content["f"]["state"].contains("node"));
+        BOOST_REQUIRE(content["f"]["state"].contains("default"));
+        BOOST_REQUIRE(content["f"].contains("children"));
+
+        BOOST_REQUIRE(content["f"]["children"].contains("t"));
+        BOOST_REQUIRE(content["f"]["children"]["t"].contains("state"));
+        BOOST_REQUIRE(content["f"]["children"]["t"]["state"].contains("node"));
+        BOOST_REQUIRE(content["f"]["children"]["t"]["state"].contains("default"));
+        BOOST_REQUIRE(content["f"]["children"]["t"].contains("attributes"));
+        BOOST_REQUIRE(content["f"]["children"]["t"]["attributes"].size() == 3);
+        BOOST_REQUIRE(content["f"]["children"]["t"].contains("aliases"));
+        BOOST_REQUIRE(content["f"]["children"]["t"]["aliases"].size() == 0);
+    }
+
+    // (4) Clean up
+    request("delete", "/v1/suites/full_suite/definition", "", API_KEY);
+    wait_until([] { return false == check_for_path("/v1/suites/full_suite/definition"); });
+}
+
+BOOST_AUTO_TEST_CASE(test_token_authentication) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
+
+    handle_response(request("put",
+                            "/v1/server/attributes",
+                            R"({"type":"variable","name":"xfoo","value":"xbaz"})",
+                            "",
+                            {{"X-API-Key", API_KEY}}));
+    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
+
+    handle_response(
+        request("delete", "/v1/server/attributes?key=" + API_KEY, R"({"type":"variable","name":"xfoo"})", ""),
+        HttpStatusCode::success_no_content);
+    wait_until(
+        [] { return false == check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
+
+    const std::string pbkdf2_API_KEY("351db772d94310a6d57aa7144448f4c108e7ee2e2a00a74edbdf8edb11bee71b");
+    handle_response(
+        request("post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", pbkdf2_API_KEY),
+        HttpStatusCode::success_created);
+    wait_until([] { return check_for_element("/v1/server/attributes?filter=variables", "value", "xfoo", "xbar"); });
+
+    const std::string expired_API_KEY("764073a74875ada28859454e58881229a5149ae400589fc617234d8d96c6d91a");
+    handle_response(
+        request(
+            "post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", expired_API_KEY),
+        HttpStatusCode::client_error_unauthorized);
+
+    const std::string revoked_API_KEY("5c6f6a003f3292c4d7671c9ad8ca10fb76e2273e584992f0d1f8fdf4abcdc81e");
+    handle_response(
+        request(
+            "post", "/v1/server/attributes", R"({"type":"variable","name":"xfoo","value":"xbar"})", revoked_API_KEY),
+        HttpStatusCode::client_error_unauthorized);
+}
+
+BOOST_AUTO_TEST_CASE(test_family_add, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_suite")) {
+    handle_response(
+        request("put", "/v1/suites/test/definition", R"({"definition": "family dynamic\nendfamily"})", API_KEY));
+    wait_until([] { return check_for_path("/v1/suites/test/dynamic/definition"); });
+}
+
+// STATUS
+
+BOOST_AUTO_TEST_CASE(test_status, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    const std::map<std::string, std::string> statuses{
+        {"abort", "aborted"}, {"complete", "complete"}, {"requeue", "queued"}, {"suspend", "suspended"}};
+
+    for (const auto& status : statuses) {
+        ojson j = {{"action", status.first}};
+        handle_response(request("put", "/v1/suites/test/dynamic/status", j.dump(), API_KEY));
+
+        wait_until(
+            [&] { return check_for_element("/v1/suites/test/dynamic/status?filter=status", "", "", status.second); });
+    }
+
+    handle_response(request(
+        "put", "/v1/suites/test/dynamic/status", R"({"action":"defstatus","defstatus_value":"complete"})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/status?filter=default_status", "", "", "complete"); });
+
+    handle_response(request("put", "/v1/suites/test/a/status", R"({"action":"archive"})", API_KEY));
+    wait_until([] { return false == check_for_path("/v1/suites/test/a/a/definition"); });
+
+    handle_response(request("put", "/v1/suites/test/a/status", R"({"action":"restore"})", API_KEY));
+    wait_until([] { return check_for_path("/v1/suites/test/a/a/definition"); });
+}
+
+// VARIABLE
+
+BOOST_AUTO_TEST_CASE(test_variable, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request(
+            "post", "/v1/suites/test/dynamic/attributes", R"({"type":"variable","name":"foo","value":"bar"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=variables", "value", "foo", "bar"); });
+
+    handle_response(request(
+        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"variable","name":"foo","value":"baz"})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=variables", "value", "foo", "baz"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"variable","name":"foo"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=variables", "value", "foo", "baz");
+    });
+}
+
+// METER
+
+BOOST_AUTO_TEST_CASE(test_meter, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(request("post",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"meter","name":"foo","value":"10","min":"0","max":"20"})",
+                            API_KEY),
+                    HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=meters", "value", "foo", "10"); });
+
+    handle_response(
+        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"meter","name":"foo","value":"15"})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=meters", "value", "foo", "15"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"meter","name":"foo"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=meters", "value", "foo", "15");
+    });
+}
+
+// LIMIT
+
+BOOST_AUTO_TEST_CASE(test_limit, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"limit","name":"foo","value":"0"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=limits", "value", "foo", "0"); });
+
+    handle_response(
+        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"limit","name":"foo","value":"6"})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=limits", "value", "foo", "6"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"limit","name":"foo"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=limits", "value", "foo", "6");
+    });
+}
+
+// EVENT
+
+BOOST_AUTO_TEST_CASE(test_event, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request(
+            "post", "/v1/suites/test/dynamic/attributes", R"({"type":"event","name":"foo","value":"set"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=events", "value", "foo", "true"); });
+
+    handle_response(request(
+        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"event","name":"foo","value":false})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=events", "value", "foo", "false"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"event","name":"foo"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=events", "value", "foo", "false");
+    });
+}
+
+// LABEL
+
+BOOST_AUTO_TEST_CASE(test_label, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request(
+            "post", "/v1/suites/test/dynamic/attributes", R"({"type":"label","name":"foo","value":"bar"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=labels", "value", "foo", "bar"); });
+
+    handle_response(request(
+        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"label","name":"foo","value":"baz"})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=labels", "value", "foo", "baz"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"label","name":"foo"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=labels", "value", "foo", "baz");
+    });
+}
+
+// TIME
+
+BOOST_AUTO_TEST_CASE(test_time, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"time","value":"+00:20"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=times", "value", "", "+00:20"); });
+
+    handle_response(request("put",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"time","old_value":"+00:20","value":"+00:25"})",
+                            API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=times", "value", "", "+00:25"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"time","value":"+00:25"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=times", "value", "", "+00:25");
+    });
+}
+
+// DAY
+
+BOOST_AUTO_TEST_CASE(test_day, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"day","value":"monday"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=days", "value", "", "monday"); });
+
+    handle_response(request("put",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"day","old_value":"monday","value":"tuesday"})",
+                            API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=days", "value", "", "tuesday"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"day","value":"tuesday"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=days", "value", "", "tuesday");
+    });
+}
+
+// DATE
+
+BOOST_AUTO_TEST_CASE(test_date, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"date","value":"1.*.*"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=dates", "value", "", "1.*.*"); });
+
+    handle_response(request("put",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"date","old_value":"1.*.*","value":"2.*.*"})",
+                            API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=dates", "value", "", "2.*.*"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"date","value":"2.*.*"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=dates", "value", "", "2.*.*");
+    });
+}
+
+// TODAY
+
+BOOST_AUTO_TEST_CASE(test_today, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"today","value":"03:00"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=todays", "value", "", "03:00"); });
+
+    handle_response(request("put",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"today","old_value":"03:00","value":"03:00 05:00 01:00"})",
+                            API_KEY));
+    wait_until([] {
+        return check_for_element("/v1/suites/test/dynamic/attributes?filter=todays", "value", "", "03:00 05:00 01:00");
+    });
+
+    handle_response(
+        request(
+            "delete", "/v1/suites/test/dynamic/attributes", R"({"type":"today","value":"03:00 05:00 01:00"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false ==
+               check_for_element("/v1/suites/test/dynamic/attributes?filter=todays", "value", "", "03:00 05:00 01:00");
+    });
+}
+
+// CRON
+
+BOOST_AUTO_TEST_CASE(test_cron, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"cron","value":"-w 0,1 10:00"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until([] {
+        return check_for_element("/v1/suites/test/dynamic/attributes?filter=crons", "value", "", "-w 0,1 10:00");
+    });
+
+    handle_response(request("put",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"cron","old_value":"-w 0,1 10:00","value":"23:00"})",
+                            API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=crons", "value", "", "23:00"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"cron","value":"23:00"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=crons", "value", "", "23:00");
+    });
+}
+
+// LATE
+
+BOOST_AUTO_TEST_CASE(test_late, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(request("post",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"late","value":"-s +00:01 -a 14:30 -c +00:01"})",
+                            API_KEY),
+                    HttpStatusCode::success_created);
+    wait_until([] {
+        return check_for_element(
+            "/v1/suites/test/dynamic/attributes?filter=late", "value", "", "-s +00:01 -a 14:30 -c +00:01");
+    });
+
+    handle_response(request("put",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"late","old_value":"-s +00:01 -a 14:30 -c +00:01","value":"-c +00:01"})",
+                            API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=late", "value", "", "-c +00:01"); });
+
+    handle_response(
+        request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"late","value":"-c +00:01"})", API_KEY),
+        HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=late", "value", "", "-c +00:01");
+    });
+}
+
+// COMPLETE
+
+BOOST_AUTO_TEST_CASE(test_complete, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(request("post",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"complete","value":"/test/a eq complete"})",
+                            API_KEY),
+                    HttpStatusCode::success_created);
+    wait_until([] {
+        return check_for_element(
+            "/v1/suites/test/dynamic/attributes?filter=complete", "value", "", "/test/a eq complete");
+    });
+
+    handle_response(request(
+        "put", "/v1/suites/test/dynamic/attributes", R"({"type":"complete","value":"/test/a eq active"})", API_KEY));
+    wait_until([] {
+        return check_for_element(
+            "/v1/suites/test/dynamic/attributes?filter=complete", "value", "", "/test/a eq active");
+    });
+
+    handle_response(request("delete",
+                            "/v1/suites/test/dynamic/attributes",
+                            R"({"type":"complete","value":"/test/a eq active"})",
+                            API_KEY),
+                    HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=complete", "value", "", "");
+    });
+}
+
+// AUTOCANCEL
+
+BOOST_AUTO_TEST_CASE(test_autocancel, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"autocancel","value":"+01:00"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until([] {
+        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autocancel", "value", "", "+01:00");
+    });
+
+    handle_response(
+        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"autocancel","value":"0"})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=autocancel", "value", "", "0"); });
+
+    handle_response(request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"autocancel"})", API_KEY),
+                    HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=autocancel", "value", "", "0");
+    });
+}
+
+// AUTOARCHIVE
+
+BOOST_AUTO_TEST_CASE(test_autoarchive, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"autoarchive","value":"+01:00"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until([] {
+        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autoarchive", "value", "", "+01:00");
+    });
+
+    handle_response(
+        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"autoarchive","value":"0"})", API_KEY));
+    wait_until(
+        [] { return check_for_element("/v1/suites/test/dynamic/attributes?filter=autoarchive", "value", "", "0"); });
+
+    handle_response(request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"autoarchive"})", API_KEY),
+                    HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false == check_for_element("/v1/suites/test/dynamic/attributes?filter=autoarchive", "value", "", "");
+    });
+}
+
+// AUTORESTORE
+
+BOOST_AUTO_TEST_CASE(test_autorestore, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(
+        request("post", "/v1/suites/test/dynamic/attributes", R"({"type":"autorestore","value":"/test/a"})", API_KEY),
+        HttpStatusCode::success_created);
+    wait_until([] {
+        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autorestore", "value", "", "/test/a");
+    });
+
+    handle_response(
+        request("put", "/v1/suites/test/dynamic/attributes", R"({"type":"autorestore","value":"/test"})", API_KEY));
+    wait_until([] {
+        return check_for_element("/v1/suites/test/dynamic/attributes?filter=autorestore", "value", "", "/test");
+    });
+
+    handle_response(request("delete", "/v1/suites/test/dynamic/attributes", R"({"type":"autorestore"})", API_KEY),
+                    HttpStatusCode::success_no_content);
+    wait_until([] {
+        return false ==
+               check_for_element("/v1/suites/test/dynamic/attributes?filter=autorestore", "value", "", "/test");
+    });
+}
+
+// OUTPUT
+
+BOOST_AUTO_TEST_CASE(test_output, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+    handle_response(request("get", "/v1/suites/test/a/a/output"), HttpStatusCode::client_error_not_found);
+}
+
+// SCRIPT
+
+BOOST_AUTO_TEST_CASE(test_script, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_family_add")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+    handle_response(request("get", "/v1/suites/test/a/a/script"), HttpStatusCode::client_error_not_found);
+}
+
+// DELETE FAMILY
+
+BOOST_AUTO_TEST_CASE(test_suite_family_delete, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_autorestore")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    handle_response(request("delete", "/v1/suites/test/dynamic/definition", "", API_KEY),
+                    HttpStatusCode::success_no_content);
+    wait_until([] { return false == check_for_path("/v1/suites/test/dynamic/definition"); });
+    wait_until([] { return check_for_path("/v1/suites/test/definition"); });
+
+    handle_response(request("delete", "/v1/suites/test/definition", "", API_KEY), HttpStatusCode::success_no_content);
+    wait_until([] { return false == check_for_path("/v1/suites/test/definition"); });
+}
+
+BOOST_AUTO_TEST_CASE(test_statistics, *boost::unit_test::depends_on("S_Http/T_ApiV1/test_server")) {
+    std::cout << "======== " << boost::unit_test::framework::current_test_case().p_name << " =========" << std::endl;
+
+    auto response = handle_response(request("get", "/v1/statistics"));
+    auto j        = ojson::parse(response.body);
+
+    BOOST_REQUIRE(j["num_requests"].get<int>() > 0);
+    BOOST_REQUIRE(j["num_errors"].get<int>() > 0);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/rest/test/TestHttp_main.cpp 5.13.0-1/libs/rest/test/TestHttp_main.cpp
--- 5.12.4-1/libs/rest/test/TestHttp_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/test/TestHttp_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Http
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/rest/test/TokenFile.hpp 5.13.0-1/libs/rest/test/TokenFile.hpp
--- 5.12.4-1/libs/rest/test/TokenFile.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/test/TokenFile.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,67 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_http_test_TokenFile_HPP
+#define ecflow_http_test_TokenFile_HPP
+
+#include <ostream>
+#include <string>
+
+#include "nlohmann/json.hpp"
+
+class TokenFile {
+public:
+    TokenFile() = delete;
+    explicit TokenFile(const std::string& tokenfile);
+    ~TokenFile();
+
+private:
+    std::string tokenfile_;
+};
+
+inline TokenFile::TokenFile(const std::string& tokenfile) : tokenfile_(tokenfile) {
+    // write api token file
+    // api-keys: 3a8c3f7ac204d9c6370b5916bd8b86166c208e10776285edcbc741d56b5b4c1e
+    //           351db772d94310a6d57aa7144448f4c108e7ee2e2a00a74edbdf8edb11bee71b
+    //           764073a74875ada28859454e58881229a5149ae400589fc617234d8d96c6d91a
+    //           5c6f6a003f3292c4d7671c9ad8ca10fb76e2273e584992f0d1f8fdf4abcdc81e
+
+    nlohmann::json j = {
+        {{"hash", "sha256$22660ab1789dc30e$7e24f61129294505b6ac310ebe891df9800f4854a67bac953bb86bf9fd726813"},
+         {"description", "test-app-1"},
+         {"expires_at", ""}},
+        {{"hash",
+          "pbkdf2:sha256:20000$Iqbh8Bz86hYHpkpn$ea95e8fb276c602fe4a4b56569fbcc321be5b31a3caa6bb3a9001e595349887f"},
+         {"description", "test-app-2"},
+         {"expires_at", "2100-01-01T00:00:00Z"}},
+        {{"hash",
+          "pbkdf2:sha256:20000$Iqbh8Bz86hYHpkpn$ea95e8fb276c602fe4a4b56569fbcc321be5b31a3caa6bb3a9001e595349887f"},
+         {"description", "test-app-3"},
+         {"expires_at", "2000-01-01T00:00:00Z"}},
+        {{"hash",
+          "pbkdf2:sha256:20000$Iqbh8Bz86hYHpkpn$ea95e8fb276c602fe4a4b56569fbcc321be5b31a3caa6bb3a9001e595349887f"},
+         {"description", "test-app-4"},
+         {"revoked_at", "2000-01-01T00:00:00Z"}}};
+
+    std::ofstream o(tokenfile_);
+    o << std::setw(4) << j << std::endl;
+    setenv("ECF_API_TOKEN_FILE", tokenfile_.c_str(), 1);
+}
+
+inline TokenFile::~TokenFile() {
+    if (remove(tokenfile_.c_str()) != 0) {
+        std::cerr << "Failed to remove token file " << tokenfile_ << std::endl;
+    }
+    else {
+        BOOST_TEST_MESSAGE("Removed token file " << tokenfile_);
+    }
+}
+
+#endif /* #ifndef ecflow_http_test_TokenFile_HPP */
diff -pruN 5.12.4-1/libs/rest/test/requirements.txt 5.13.0-1/libs/rest/test/requirements.txt
--- 5.12.4-1/libs/rest/test/requirements.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/rest/test/requirements.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+requests
+pytest
+pytest-dependency
diff -pruN 5.12.4-1/libs/server/CMakeLists.txt 5.13.0-1/libs/server/CMakeLists.txt
--- 5.12.4-1/libs/server/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,102 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+# =======================================================
+# EXE ecflow_server, if OpenSSL not enabled ${OPENSSL_LIBRARIES}, is empty
+
+ecbuild_add_executable(
+  TARGET
+    ecflow_server
+  SOURCES
+    src/ecflow/server/ServerMain.cpp
+  LIBS
+    ecflow_all
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    Threads::Threads
+)
+target_clangformat(ecflow_server)
+
+# Override default behaviour that add RPATHS during install
+# The only thing that seem to work is set INSTALL_RPATH to ""
+# Using SKIP_BUILD_RPATH,BUILD_WITH_INSTALL_RPATH,INSTALL_RPATH_USE_LINK_PATH
+# had no effect
+#          
+SET_TARGET_PROPERTIES(ecflow_server
+  PROPERTIES
+    INSTALL_RPATH ""
+)
+
+# use, i.e. don't skip the full RPATH for the build tree
+#SET(CMAKE_SKIP_BUILD_RPATH  FALSE)
+
+# when building, don't use the install RPATH already
+# (but later on when installing)
+#SET(CMAKE_BUILD_WITH_INSTALL_RPATH FALSE) 
+
+# the RPATH to be used when installing
+#SET(CMAKE_INSTALL_RPATH "")
+
+# don't add the automatically determined parts of the RPATH
+# which point to directories outside the build tree to the install RPATH
+#SET(CMAKE_INSTALL_RPATH_USE_LINK_PATH FALSE)
+
+                          
+# ================================================================================                         
+# TEST
+ecbuild_add_test(
+  TARGET
+    u_server
+  LABELS
+    unit nightly
+  INCLUDES
+    src
+  SOURCES
+    test/TestCheckPtSaver.cpp
+    test/TestServerEnvironment.cpp
+    test/TestServer_main.cpp # test entry point
+    test/TestServer.cpp
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    Threads::Threads
+  TEST_DEPENDS
+    u_base
+)
+
+target_clangformat(u_server CONDITION ENABLE_TESTS)
+
+# ================================================================================
+# TEST
+ecbuild_add_test(
+  TARGET
+    s_periodic_scheduler
+  LABELS
+    integration nightly
+  INCLUDES
+    src
+  SOURCES
+    test/TestPeriodicScheduler.cpp
+    test/TestPeriodicScheduler_main.cpp # test entry point
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    Threads::Threads
+  TEST_DEPENDS
+    u_base
+)
+
+target_clangformat(s_periodic_scheduler CONDITION ENABLE_TESTS)
+
+# ===================================================================
+# install
+# ===================================================================
+install (TARGETS ecflow_server DESTINATION bin)
diff -pruN 5.12.4-1/libs/server/server_environment.cfg 5.13.0-1/libs/server/server_environment.cfg
--- 5.12.4-1/libs/server/server_environment.cfg	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/server_environment.cfg	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,185 @@
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+#
+# This file is used to define the standard defaults for ECF.
+# Most are *variables* used in the server
+# Some like ECF_TASK_THRESHOLD are used to debug job generation
+ 
+# ******************************************************************
+# Warning: Do *NOT* use quotes around the value part.
+#   WRONG: ECF_MICRODEF = "%"
+#   RIGHT: ECF_MICRODEF = %
+# ******************************************************************
+
+#  *******************************************************************
+#  * ECF_HOME is typically the home/root for all '.ecf' files
+#  * Can be overridden with a environment variable of the same name
+#  *******************************************************************
+ECF_HOME  = .
+
+
+#  ******************************************************************
+#  * The name of check point file. i.e defs file with state
+#  * Can be overridden with a environment variable of the same name
+#  * default: is <host>.<port>.ecf.check
+#  * Note: Any settings will be prepended with <host>.<port>.
+#  ******************************************************************
+ECF_CHECK = ecf.check
+
+
+#  ******************************************************************
+#  * The name of the backup checkpoint file
+#  * Can be overridden with a environment variable of the same name
+#  * default: is <host>.<port>.ecf.check.b
+#  * Note: Any settings will be prepended with <host>.<port>.
+#  ******************************************************************
+ECF_CHECKOLD = ecf.check.b
+
+
+#  ******************************************************************
+#  * The intervals within the server that the checkpoint file should 
+#  * be saved.
+#  * Can be overridden with a environment variable of the same name
+#  ******************************************************************
+ECF_CHECKINTERVAL = 120  
+
+
+#  ******************************************************************
+#  * Check point configuration:
+#  * 
+#  * Mode must be one of: 
+#  *   CHECK_NEVER    /* No auto checkpointing                       */
+#  *   CHECK_ON_TIME  /* At intervals specified by ECF_CHECKINTERVAL */
+#  *   CHECK_ALWAYS   /* After any change                            */
+#  * The checkpoint filenames can be configured using environment variables
+#  ******************************************************************
+ECF_CHECKMODE = CHECK_ON_TIME
+
+
+#  ******************************************************************
+#  * The port number, this must be consistent between client and server
+#  * If we get "Address in use" then both client/server number should changed.
+#  * Also if two servers are started on the same machine with same port
+#  * then we will also get "Address in use" error and server will bomb out.
+#  * Can be overridden with a environment variable of the same name
+#  ******************************************************************
+ECF_PORT = 3141
+
+
+#  ******************************************************************
+#  * The name of log file.
+#  * default log file name is: <host>.<port>.ecf.log, i.e machine1.3141.ecf.log
+#  * this is required since we can have multiple servers for a single
+#  * machine, where each server will have a separate port number.
+#  * Can be overridden with a environment variable of the same name
+#  *
+#  * Note: Any settings will be prepended with <host>.<port>.
+#  ******************************************************************
+ECF_LOG = ecf.log
+ 
+ 
+#  ******************************************************************
+#  * The period in second for which we should traverse dependencies
+#  * and submit jobs. This should *RARELY* need changing, as it can affect
+#  * correspondence with real time
+#  ******************************************************************
+ECF_INTERVAL = 60       
+ 
+
+#  ******************************************************************
+#  * The standard command use for job submission. 
+#  * Provides DEFAULT can be overridden by user variable
+#  ******************************************************************
+ECF_JOB_CMD = %ECF_JOB% 1> %ECF_JOBOUT% 2>&1
+
+
+#  ******************************************************************
+#  * Define variable for killing any jobs. 
+#  * Provides DEFAULT can be overridden by user variable
+#  * The output of the command should be written to %ECF_JOB%.kill
+#  * ecmwf: ${ECF_KILL:=/home/ma/emos/bin/ecfkill} %USER% %HOST% %ECF_RID% %ECF_JOB% > %ECF_JOB%.kill 2>&1
+#  ******************************************************************
+ECF_KILL_CMD = kill -15 %ECF_RID%  
+
+
+#  ******************************************************************
+#  * This is run by the SERVER 
+#  * define variable of obtaining status. 
+#  * Provides DEFAULT can be overridden by user variable
+#  * The output of the command should be written to %ECF_JOB%.stat
+#  * ecmwf: ${ECF_STAT:=trimurti} %USER% %HOST% %ECF_RID% %ECF_JOB% status> %ECF_JOB%.stat 2>&1
+#  ******************************************************************
+ECF_STATUS_CMD = ps --pid %ECF_RID% -f > %ECF_JOB%.stat 2>&1
+
+#  ******************************************************************
+#  * This is run by the CLIENT .  check from GUI
+#  ******************************************************************
+ECF_CHECK_CMD = ps --pid %ECF_RID% -f
+
+
+#  ******************************************************************
+#  * define variables used for url command. 
+#  * Provides DEFAULT can be overriden by user variables
+#  ******************************************************************
+ECF_URL_CMD    = ${BROWSER:=firefox} -new-tab %ECF_URL_BASE%/%ECF_URL%
+ECF_URL_BASE   = https://confluence.ecmwf.int 
+ECF_URL        = display/ECFLOW/ecflow+home
+
+#  ******************************************************************
+#  * Defines the character used in ECF_ pre-processing. i.e identifies includes
+#  * and is also used in variable substitution in '.ecf' scripts
+#  ******************************************************************
+ECF_MICRODEF = %
+
+#  ******************************************************************
+#  * The ECF_LISTS is used to identify a file, that lists the user 
+#  * who can access the server via client commands. Each client command 
+#  * (ignoring task based commands, i.e init, complete, event, meter, label)
+#  * will encode the user name of the process initiating the client request
+#  * This is then compared with list of users in the ecf.lists file.
+#  * If this file is empty, then no authentication is done
+#  * Each server can potionally have a different list.
+#  * default: <host>.<port>.ecf.lists
+#  * Note: Any settings will be prepended with <host>.<port>.
+#  ******************************************************************
+ECF_LISTS = ecf.lists
+
+#  ******************************************************************
+#  * Password file: Use when every user needs password authentication
+#  * Each server can potionally have a different password file.
+#  * default: <host>.<port>.ecf.passwd
+#  * Note: Any settings will be prepended with <host>.<port>.
+#  ******************************************************************
+ECF_PASSWD = ecf.passwd
+
+
+#  ******************************************************************
+#  * Password file:, when only a few users need password, typically
+#  * when a users UID on the remote client, does not match that on the server
+#  * Each server can potionally have a different password file.
+#  * default: <host>.<port>.ecf.custom_passwd
+#  * Note: Any settings will be prepended with <host>.<port>.
+#  ******************************************************************
+ECF_CUSTOM_PASSWD = ecf.custom_passwd
+
+# ***************************************************************************
+# * ECF_TASK_THRESHOLD:
+# * Report on an task taking longer than the threshold. !!
+# *    export ECF_TASK_THRESHOLD=4000
+# ***************************************************************************
+ECF_TASK_THRESHOLD = 4000    
+
+# ***************************************************************************
+# * ECF_PRUNE_NODE_LOG:
+# * Node log/edit history older than 30 days will be automatically
+# * pruned when the server LOADS the checkpoint file.
+# * To disable pruning, set to 0, or set the environment variable of the same
+# * name to zero.
+# ***************************************************************************
+ECF_PRUNE_NODE_LOG = 30          
+         
\ No newline at end of file
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/BaseServer.cpp 5.13.0-1/libs/server/src/ecflow/server/BaseServer.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/BaseServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/BaseServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,520 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/BaseServer.hpp" // Must come before boost/serialization headers.
+
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/date_time/posix_time/posix_time.hpp>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprDuplicate.hpp"
+#include "ecflow/node/Operations.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+#include "ecflow/service/Registry.hpp"
+
+using boost::asio::ip::tcp;
+
+using namespace std;
+using namespace ecf;
+
+/// Constructor opens the acceptor and starts waiting for the first incoming connection.
+BaseServer::BaseServer(boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
+    : io_service_(io_service),
+      signals_(io_service),
+      defs_(Defs::create()), // ECFLOW-182
+      traverser_(this, io_service, serverEnv),
+      checkPtSaver_(this, io_service, &serverEnv),
+      serverState_(SState::HALTED),
+      serverEnv_(serverEnv) {
+    if (serverEnv_.debug())
+        cout << "-->Server::server starting server on port " << serverEnv.port() << endl;
+
+    // Must be set before checkpt file is loaded.
+    defs_->ecf_prune_node_log(serverEnv.ecf_prune_node_log());
+
+    LogFlusher logFlusher;
+
+    // Register to handle the signals.
+    // Support for emergency check pointing during system session.
+    signals_.add(SIGTERM);
+    signals_.async_wait([this](boost::system::error_code /*ec*/, int /*signo*/) { sigterm_signal_handler(); });
+
+    ecf::service::TheOneServer::set_server(this);
+
+    // Update stats, this is returned via --stats command option
+    stats().host_                    = serverEnv.hostPort().first;
+    stats().port_                    = serverEnv.hostPort().second;
+    stats().job_sub_interval_        = serverEnv.submitJobsInterval();
+    stats().checkpt_interval_        = serverEnv.checkPtInterval();
+    stats().checkpt_save_time_alarm_ = serverEnv.checkpt_save_time_alarm();
+    stats().checkpt_mode_            = serverEnv.checkMode();
+    stats().up_since_                = to_simple_string(Calendar::second_clock_time());
+    stats().version_                 = Version::description();
+    stats().status_                  = static_cast<int>(serverState_);
+    stats().ECF_HOME_                = serverEnv.ecf_home();
+    stats().ECF_CHECK_               = serverEnv.checkPtFilename();
+    stats().ECF_LOG_                 = Log::instance()->path();
+
+    // Update log file:
+    ecf::log(Log::MSG, "Server initial state is HALTED");
+
+    // The defs_ *MUST* be updated with the server state
+    // When we load from the check pt file we call update_defs_server_state();
+    if (!load_check_pt_file_on_startup()) {
+
+        // No check pt files loaded, update defs, with server state
+        update_defs_server_state(); // works on def_
+    }
+
+    /// Setup globals used to detect incremental changes to the definition
+    Ecf::set_server(true);
+}
+
+BaseServer::~BaseServer() {
+    if (serverEnv_.debug())
+        cout << "<--BaseServer::~Baseserver exiting server on port " << serverEnv_.port() << endl;
+
+    // Defs destructor may get called after we have returned from main. See ECFLOW-1291
+    // In this case the static memory used in ExprDuplicate will not be reclaimed. hence do it here:
+    // Duplicate AST are held in a static map. Delete them, to avoid valgrind and ASAN from complaining
+    ExprDuplicate reclaim_cloned_ast_memory;
+
+    defs_.reset();
+
+#ifdef DEBUG
+    if (defs_.use_count() != 0) {
+        cout << "Server::~server() defs_.use_count() = " << defs_.use_count()
+             << " something is still hold onto the defs, asserting\n";
+    }
+#endif
+    assert(defs_.use_count() == 0);
+}
+
+void BaseServer::handle_terminate() {
+    // if (serverEnv_.debug()) cout << boost::this_thread::get_id() << "   Server::handle_terminate() : cancelling
+    // checkpt and traverser timers, and signals" << endl;
+    if (serverEnv_.debug())
+        cout << "   Server::handle_terminate() : cancelling checkpt and traverser timers, and signals" << endl;
+
+    // Cancel signal
+    signals_.clear();
+    signals_.cancel();
+
+    // Cancel async timers for check pointing and traversal
+    traverser_.terminate();
+    checkPtSaver_.terminate();
+}
+
+// ============================== other privates ===========================================
+
+bool BaseServer::load_check_pt_file_on_startup() {
+    // On start up we want different behaviour.
+    // If check pt file exists and we can't load then we want to exit
+    // This avoids the server from overwriting the check point file
+    // Which may be from a different version. let the user handle it.
+    LogToCout logToCout;
+    bool checkpt_failed = false;
+    if (restore_from_checkpt(serverEnv_.checkPtFilename(), checkpt_failed)) {
+        return true;
+    }
+    bool backup_checkpt_failed = false;
+    if (restore_from_checkpt(serverEnv_.oldCheckPtFilename(), backup_checkpt_failed)) {
+        return true;
+    }
+
+    if (backup_checkpt_failed && !fs::exists(serverEnv_.checkPtFilename())) {
+        throw std::runtime_error("Cannot start server, please handle the backup checkpoint file first");
+    }
+
+    if (checkpt_failed && !fs::exists(serverEnv_.oldCheckPtFilename())) {
+        throw std::runtime_error("Cannot start server, please handle the checkpoint file first");
+    }
+    return false;
+}
+
+void BaseServer::loadCheckPtFile() {
+    // if the check point file starts with an absolute file load that first
+    // otherwise check in ECF_HOME then load it. Repeat for back up check point file
+    // The server environment has already asserted that we can *NOT* have an empty check point file
+    bool ignore;
+    if (restore_from_checkpt(serverEnv_.checkPtFilename(), ignore)) {
+        return;
+    }
+
+    if (restore_from_checkpt(serverEnv_.oldCheckPtFilename(), ignore)) {
+        return;
+    }
+}
+
+bool BaseServer::restore_from_checkpt(const std::string& filename, bool& failed) {
+    // cout << "BaseServer::restore_from_checkpt " << filename;
+    if (fs::exists(filename)) {
+        // cout << " file exists\n";
+
+        std::string s = "Loading check point file ";
+        s += filename;
+        s += " port:";
+        s += serverEnv_.the_port();
+        log(Log::MSG, s);
+
+        try {
+            defs_->restore(filename);   // this can throw
+            defs_->handle_migration();  // handle any migration of checkpt file.
+            update_defs_server_state(); // works on def_
+            LOG(Log::MSG,
+                "Loading of *DEFS* check point file SUCCEDED. Loaded " << defs_->suiteVec().size() << " suites");
+
+            // fast forward any time attributes, if suite clock is *ONLY* 1 hour behind real time
+            // This may remove autocancelled nodes, may autoarchive, may set late attribute,
+            // may expire time based attributes which will start jobs when server starts
+            if (defs_->catch_up_to_real_time()) {
+                log(Log::MSG,
+                    "Suite time attributes updated to catch up with real time. Down time was less than 1 hour");
+            }
+            return true;
+        }
+        catch (exception& e) {
+            LOG(Log::ERR, "Failed to load *DEFS* check point file " << filename << ", because: " << e.what());
+        }
+    }
+    //   else {
+    //      cout << " does *not* exist\n";
+    //   }
+    return false;
+}
+
+void BaseServer::update_defs_server_state() {
+    /// The Job submission interval, and host port are not persisted, on the DEFS
+    /// Hence when restoring from a checkpoint file, Be sure to update server state
+
+    // Do any *one* time setup on the defs
+
+    // Set the server environment *ON* the defs, so that generate variables can be created.
+    // gets the environment as read in by the server, and make available for defs
+    // ECF_HOME .
+    // ECF_CHECK ecf.check
+    // ECF_CHECKOLD ecf.check.b
+    std::vector<std::pair<std::string, std::string>> envVec;
+    serverEnv_.variables(envVec);
+    defs_->set_server().add_or_update_server_variables(envVec);
+
+    defs_->set_server().hostPort(serverEnv_.hostPort());
+    defs_->set_server().set_state(serverState_);
+
+    // let the defs store the job submission interval, & whether we want job generation.testing can disable this
+    defs_->set_server().jobSubmissionInterval(serverEnv_.submitJobsInterval());
+    defs_->set_server().jobGeneration(serverEnv_.jobGeneration());
+    LOG_ASSERT(defs_->server().jobSubmissionInterval() != 0, "");
+
+    // Since we have reloaded Defs, make sure clients, re-sync by resetting change and modify numbers on server
+    defs_->set_state_change_no(Ecf::state_change_no());
+    defs_->set_modify_change_no(Ecf::modify_change_no());
+
+    /// System needs defs to handle process that have died, and need to flagged as aborted
+    ecf::System::instance()->setDefs(defs_);
+}
+
+void BaseServer::set_server_state(SState::State ss) {
+    serverState_    = ss;
+    stats().status_ = static_cast<int>(serverState_);
+    defs_->set_server().set_state(serverState_);
+}
+
+/// ======================================================================================
+/// AbstractServer function.
+/// ======================================================================================
+
+std::pair<std::string, std::string> BaseServer::hostPort() const {
+    return serverEnv_.hostPort();
+}
+
+void BaseServer::updateDefs(defs_ptr defs, bool force) {
+    if (serverEnv_.debug())
+        std::cout << "   BaseServer::updateDefs: Loading new suites" << endl;
+
+    // After the absorb, input defs will be left with NO suites.
+    defs_->absorb(defs.get(), force);
+
+    defs_->set_most_significant_state();
+    LOG_ASSERT(defs_->server().jobSubmissionInterval() != 0, "");
+
+    if (serverState_ == SState::RUNNING) {
+        ecf::visit_all(*defs_, BootstrapDefs{});
+    }
+}
+
+void BaseServer::clear_defs() {
+    if (serverEnv_.debug())
+        cout << "   BaseServer::clear_defs()" << endl;
+
+    defs_->clear();
+}
+
+bool BaseServer::checkPtDefs(ecf::CheckPt::Mode m, int check_pt_interval, int check_pt_save_time_alarm) {
+    if (serverEnv_.debug())
+        cout << "   BaseServer::checkPtDefs() mode(" << m << ") check_pt_interval(" << check_pt_interval
+             << ") check_pt_save_time_alarm(" << check_pt_save_time_alarm << ")" << endl;
+
+    if (m == ecf::CheckPt::UNDEFINED && check_pt_interval == 0 && check_pt_save_time_alarm == 0) {
+        return checkPtSaver_.explicitSave(); // will always save
+    }
+    else {
+        if (m != ecf::CheckPt::UNDEFINED) {
+            serverEnv_.set_check_mode(m);
+            stats().checkpt_mode_ = serverEnv_.checkMode();
+        }
+        if (check_pt_interval > 0) {
+            serverEnv_.set_checkpt_interval(check_pt_interval);
+            stats().checkpt_interval_ = check_pt_interval;
+        }
+        if (check_pt_save_time_alarm > 0) {
+            serverEnv_.set_checkpt_save_time_alarm(check_pt_save_time_alarm);
+            stats().checkpt_save_time_alarm_ = check_pt_save_time_alarm;
+        }
+    }
+    return true;
+}
+
+void BaseServer::restore_defs_from_checkpt() {
+    if (serverEnv_.debug())
+        cout << "   BaseServer::restore_defs_from_checkpt()" << endl;
+
+    if (serverState_ != SState::HALTED) {
+        throw std::runtime_error("Cannot restore from checkpt the server must be halted first");
+    }
+
+    if (!defs_->suiteVec().empty()) {
+        // suites must be deleted manually first
+        throw std::runtime_error("Cannot restore from checkpt the server suites must be deleted first");
+    }
+
+    loadCheckPtFile();
+}
+
+void BaseServer::nodeTreeStateChanged() {
+    if (serverEnv_.debug())
+        cout << "   BaseServer::nodeTreeStateChanged()" << endl;
+
+    // will only actually save if configuration allows it
+    checkPtSaver_.saveIfAllowed();
+}
+
+bool BaseServer::allowTaskCommunication() const {
+    return (serverState_ != SState::HALTED) ? true : false;
+}
+
+void BaseServer::shutdown() {
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    if (serverEnv_.debug())
+        cout << "   BaseServer::shutdown. Stop Scheduling new jobs only" << endl;
+
+    // Stop server from creating new jobs. Don't stop the checkPtSaver_ since
+    // the jobs communication with server can still change state. Which we want
+    // to check point.
+    traverser_.stop();
+
+    // Continue check pointing since, we allow tasks communication. This can change node
+    // tree state. Which we *must* be able to checkpoint.
+    // If we go from HALTED --> SHUTDOWN, then check pointing  needs to be enabled
+    checkPtSaver_.start();
+
+    // Will update defs as well to stop job scheduling
+    set_server_state(SState::SHUTDOWN);
+}
+
+void BaseServer::halted() {
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    if (serverEnv_.debug())
+        cout << "   BaseServer::halted. Stop Scheduling new jobs *and* block task communication. Stop check pointing. "
+                "Only accept user request"
+             << endl;
+
+    // Stop server from creating new jobs. i.e Job scheduling.
+    traverser_.stop();
+
+    // *** CRITICAL*** when the server is halted, we ***MUST NOT*** do any further check pointing
+    // In a typical operational scenario where we have a home, and backup servers.
+    // The checkpoint file is copied to the backup servers periodically (via a task)
+    // hence we want to preserve the state of the last checkpoint.
+    // Added after discussion with Axel.
+    checkPtSaver_.stop();
+
+    ecf::visit_all(*defs_, ShutdownDefs{});
+
+    // Stop the task communication with server. Hence nodes can be stuck
+    // in submitted/active states. Task based command will continue attempting,
+    // communication with the server for up to 24hrs.
+    // Will update defs as well to stop job scheduling
+    set_server_state(SState::HALTED);
+}
+
+void BaseServer::restart() {
+    ///           User Request    Task Request   Job Scheduling   Check-pointing
+    /// RUNNING      yes               yes              yes            yes
+    /// SHUTDOWN     yes               yes              no             yes
+    /// HALTED       yes               no               no             no
+    if (serverEnv_.debug())
+        std::cout << "   BaseServer::restart" << endl;
+
+    // The server state *MUST* be set, *before* traverser_.start(), since that can kick off job traversal.
+    // Job Scheduling can only be done under RUNNING state, hence must be before traverser_.start();
+    //
+    // If we placed set_server_state(SState::RUNNING); after we can miss time slots
+    //    See:: SUP 571- Time dependency after halt/checkpoint
+    set_server_state(SState::RUNNING);
+
+    traverser_.start();
+    checkPtSaver_.start();
+
+    ecf::visit_all(*defs_, BootstrapDefs{});
+}
+
+void BaseServer::traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
+                                                     bool user_cmd_context) const {
+    traverser_.traverse_node_tree_and_job_generate(time_now, user_cmd_context);
+}
+
+bool BaseServer::reloadWhiteListFile(std::string& errorMsg) {
+    if (serverEnv_.debug())
+        cout << "   BaseServer::reloadWhiteListFile" << endl;
+    return serverEnv_.reloadWhiteListFile(errorMsg);
+}
+
+bool BaseServer::reloadPasswdFile(std::string& errorMsg) {
+    if (serverEnv_.debug())
+        cout << "   BaseServer::reloadPasswdFile" << endl;
+    return serverEnv_.reloadPasswdFile(errorMsg);
+}
+
+bool BaseServer::reloadCustomPasswdFile(std::string& errorMsg) {
+    if (serverEnv_.debug())
+        cout << "   BaseServer::reloadCustomPasswdFile " << endl;
+    return serverEnv_.reloadCustomPasswdFile(errorMsg);
+}
+
+bool BaseServer::authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) {
+    return serverEnv_.authenticateReadAccess(user, custom_user, passwd);
+}
+bool BaseServer::authenticateReadAccess(const std::string& user,
+                                        bool custom_user,
+                                        const std::string& passwd,
+                                        const std::string& path) {
+    return serverEnv_.authenticateReadAccess(user, custom_user, passwd, path);
+}
+bool BaseServer::authenticateReadAccess(const std::string& user,
+                                        bool custom_user,
+                                        const std::string& passwd,
+                                        const std::vector<std::string>& paths) {
+    return serverEnv_.authenticateReadAccess(user, custom_user, passwd, paths);
+}
+
+bool BaseServer::authenticateWriteAccess(const std::string& user) {
+    return serverEnv_.authenticateWriteAccess(user);
+}
+bool BaseServer::authenticateWriteAccess(const std::string& user, const std::string& path) {
+    return serverEnv_.authenticateWriteAccess(user, path);
+}
+bool BaseServer::authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) {
+    return serverEnv_.authenticateWriteAccess(user, paths);
+}
+
+bool BaseServer::lock(const std::string& user) {
+    if (serverEnv_.debug())
+        std::cout << "   BaseServer::lock " << user << endl;
+
+    if (userWhoHasLock_.empty()) {
+        userWhoHasLock_           = user;
+        stats().locked_by_user_   = user;
+        server_state_to_preserve_ = state();
+        shutdown();
+        return true;
+    }
+    else if (userWhoHasLock_ == user && serverState_ == SState::SHUTDOWN) {
+        // Same user attempting multiple locks
+        return true;
+    }
+    return false;
+}
+void BaseServer::unlock() {
+    if (serverEnv_.debug())
+        std::cout << "   BaseServer::unlock " << userWhoHasLock_ << endl;
+
+    userWhoHasLock_.clear();
+    stats().locked_by_user_.clear();
+
+    switch (server_state_to_preserve_) {
+        case SState::RUNNING:
+            restart();
+            break;
+        case SState::SHUTDOWN:
+            shutdown();
+            break;
+        case SState::HALTED:
+            halted();
+            break;
+    }
+}
+const std::string& BaseServer::lockedUser() const {
+    return userWhoHasLock_;
+}
+
+int BaseServer::poll_interval() const {
+    return serverEnv_.submitJobsInterval();
+}
+
+void BaseServer::debug_server_on() {
+    serverEnv_.set_debug(true);
+    std::cout << "\nEnable DEBUG, start with DUMP of server environment:\n\n";
+    std::cout << serverEnv_.dump() << endl;
+}
+
+void BaseServer::debug_server_off() {
+    serverEnv_.set_debug(false);
+}
+
+bool BaseServer::debug() const {
+    return serverEnv_.debug();
+}
+
+void BaseServer::sigterm_signal_handler() {
+    if (io_service_.stopped()) {
+        if (serverEnv_.debug())
+            cout << "-->BaseServer::sigterm_signal_handler(): io_service is stopped returning " << endl;
+        return;
+    }
+
+    if (serverEnv_.debug())
+        cout << "BaseServer::sigterm_signal_handler(): Received SIGTERM : starting check pointing" << endl;
+    ecf::log(Log::MSG, "BaseServer::sigterm_signal_handler(): Received SIGTERM : starting check pointing");
+
+    defs_->flag().set(ecf::Flag::ECF_SIGTERM);
+    checkPtDefs();
+
+    ecf::log(Log::MSG, "BaseServer::sigterm_signal_handler(): finished check pointing");
+    if (serverEnv_.debug())
+        cout << "BaseServer::sigterm_signal_handler(): finished check pointing" << endl;
+
+    // We need re-wait each time signal handler is called
+    signals_.async_wait([this](boost::system::error_code /*ec*/, int /*signo*/) { sigterm_signal_handler(); });
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/BaseServer.hpp 5.13.0-1/libs/server/src/ecflow/server/BaseServer.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/BaseServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/BaseServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,111 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_BaseServer_HPP
+#define ecflow_server_BaseServer_HPP
+
+#include <boost/asio.hpp>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/server/CheckPtSaver.hpp"
+#include "ecflow/server/NodeTreeTraverser.hpp"
+
+class ServerEnvironment;
+
+///
+/// \brief ecFlow Server, with implementation based on Boost.asio
+///
+/// The port numbers are divided into three ranges:
+///  o the Well Known Ports, (require root permission)  0   -1023
+///  o the Registered Ports,                            1024-49151
+///  o Dynamic and/or Private Ports.                    49151-65535
+///
+
+class BaseServer : public AbstractServer {
+public:
+    /// Constructor opens the acceptor and starts waiting for the first incoming
+    /// connection.
+    explicit BaseServer(boost::asio::io_service& io_service, ServerEnvironment&);
+    ~BaseServer() override;
+
+    void handle_terminate();
+
+    // abort server if check pt files exist, but can't be loaded
+    bool load_check_pt_file_on_startup();
+    void loadCheckPtFile();
+    bool restore_from_checkpt(const std::string& filename, bool& failed);
+    void update_defs_server_state();
+    void set_server_state(SState::State);
+
+    /// AbstractServer functions
+    SState::State state() const override { return serverState_; }
+    std::pair<std::string, std::string> hostPort() const override;
+    defs_ptr defs() const override { return defs_; }
+    void updateDefs(defs_ptr, bool force) override;
+    void clear_defs() override;
+    bool checkPtDefs(ecf::CheckPt::Mode m         = ecf::CheckPt::UNDEFINED,
+                     int check_pt_interval        = 0,
+                     int check_pt_save_time_alarm = 0) override;
+    void restore_defs_from_checkpt() override;
+    void nodeTreeStateChanged() override;
+    bool allowTaskCommunication() const override;
+    void shutdown() override;
+    void halted() override;
+    void restart() override;
+    bool reloadWhiteListFile(std::string& errorMsg) override;
+    bool reloadPasswdFile(std::string& errorMsg) override;
+    bool reloadCustomPasswdFile(std::string& errorMsg) override;
+    bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) override;
+    bool authenticateReadAccess(const std::string& user,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::string& path) override;
+    bool authenticateReadAccess(const std::string& user,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::vector<std::string>& paths) override;
+    bool authenticateWriteAccess(const std::string& user) override;
+    bool authenticateWriteAccess(const std::string& user, const std::string& path) override;
+    bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) override;
+    bool lock(const std::string& user) override;
+    void unlock() override;
+    const std::string& lockedUser() const override;
+    void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now,
+                                             bool user_cmd_context) const override;
+    int poll_interval() const override;
+    void debug_server_on() override;
+    void debug_server_off() override;
+    bool debug() const override;
+
+    // used in signal, for emergency check point during system session
+    void sigterm_signal_handler();
+
+protected:
+    /// The io_service used to perform asynchronous operations.
+    boost::asio::io_service& io_service_;
+
+    /// The signal_set is used to register for automatic check pointing
+    boost::asio::signal_set signals_;
+
+    defs_ptr defs_; // shared because is deleted in Test, and used in System::instance()
+    NodeTreeTraverser traverser_;
+    friend class NodeTreeTraverser;
+
+    CheckPtSaver checkPtSaver_;
+    friend class CheckPtSaver;
+
+    SState::State serverState_;
+    SState::State server_state_to_preserve_{SState::RUNNING}; // preserve state over plug cmd ECFLOW-1606
+
+    ServerEnvironment& serverEnv_;
+    std::string userWhoHasLock_;
+};
+
+#endif /* ecflow_server_BaseServer_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/CheckPtSaver.cpp 5.13.0-1/libs/server/src/ecflow/server/CheckPtSaver.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/CheckPtSaver.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/CheckPtSaver.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,205 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/CheckPtSaver.hpp"
+
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/server/BaseServer.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+// #define DEBUG_CHECKPT 1
+// #define DEBUG_CHECKPT_SAVE_ALLOWED 1
+
+#ifdef DEBUG_CHECKPT
+    #include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib, for to_simple_string
+#endif
+
+using namespace ecf;
+
+//-------------------------------------------------------------------------------------
+CheckPtSaver::CheckPtSaver(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment* serverEnv)
+    : server_(s),
+      timer_(io, boost::posix_time::seconds(0)),
+      firstTime_(true),
+      running_(false),
+      serverEnv_(serverEnv),
+      state_change_no_(Ecf::state_change_no()),
+      modify_change_no_(Ecf::modify_change_no()) {
+#ifdef DEBUG_CHECKPT
+    std::cout << "      CheckPtSaver::CheckPtSaver period = " << serverEnv_->checkPtInterval() << "\n";
+#endif
+}
+
+CheckPtSaver::~CheckPtSaver() {
+#ifdef DEBUG_CHECKPT
+    std::cout << "      ~CheckPtSaver::CheckPtSaver\n";
+#endif
+}
+
+void CheckPtSaver::start() {
+#ifdef DEBUG_CHECKPT
+    std::cout << "      CheckPtSaver::start() check_mode: " << serverEnv_->check_mode_str()
+              << " interval = " << serverEnv_->checkPtInterval()
+              << " time = " << to_simple_string(boost::posix_time::second_clock::universal_time()) << "\n";
+#endif
+
+    // Only save check pt periodically if configuration allows it
+    if (serverEnv_->checkMode() != ecf::CheckPt::ON_TIME) {
+#ifdef DEBUG_CHECKPT
+        std::cout << "      CheckPtSaver::start() aborted as configuration does not allow it" << std::endl;
+#endif
+        return;
+    }
+
+    running_ = true;
+
+    // * important * The time should only be started *ONCE*. Otherwise we will end up with
+    //               with explicit save each time server is halted/started.
+    if (firstTime_) {
+        firstTime_ = false;
+        timer_.expires_from_now(boost::posix_time::seconds(serverEnv_->checkPtInterval()));
+        timer_.async_wait(
+            server_->io_service_.wrap([this](const boost::system::error_code& error) { periodicSaveCheckPt(error); }));
+    }
+}
+
+void CheckPtSaver::stop() { // The server is stopped by cancelling all outstanding asynchronous
+                            // operations. Once all operations have finished the io_service::run() call
+                            // will exit.
+#ifdef DEBUG_CHECKPT
+    std::cout << "      CheckPtSaver::stop() check_mode: " << serverEnv_->check_mode_str()
+              << " interval = " << serverEnv_->checkPtInterval() << "\n";
+#endif
+    running_ = false;
+}
+
+void CheckPtSaver::terminate() {
+    timer_.cancel();
+}
+
+bool CheckPtSaver::explicitSave(bool from_server) const {
+    try {
+#ifdef DEBUG_CHECKPT
+        std::cout << "      CheckPtSaver::explicitSave() Saving checkpt file " << serverEnv_->checkPtFilename() << "\n";
+#endif
+        // In order to detect *SLOW* operations (i.e. disk related), which *AFFECT* server performance,
+        // the following timer measures how long we take to store the CheckPoint file.
+        // After the Definitions are stored, if a configured warning threshold is passed a warning is issues.
+        DurationTimer timer;
+
+        fs::path checkPtFile(serverEnv_->checkPtFilename());
+        fs::path oldCheckPtFile(serverEnv_->oldCheckPtFilename());
+        CheckPtSaver::storeWithBackup(checkPtFile, oldCheckPtFile, [&](const fs::path& file_path) {
+            server_->defs_->save_as_checkpt(file_path.string());
+        });
+
+        state_change_no_  = Ecf::state_change_no();  // For periodic update only save checkPt if it has changed
+        modify_change_no_ = Ecf::modify_change_no(); // For periodic update only save checkPt if it has changed
+
+        if (from_server) {
+            // Create new time stamp otherwise we end up using the time stamp from the last command
+            Log::instance()->cache_time_stamp();
+            std::string msg = Str::SVR_CMD();
+            msg += CtsApi::checkPtDefsArg();
+            std::stringstream ss;
+            ss << msg << " in " << timer.duration() << " seconds";
+            log(Log::MSG, ss.str());
+        }
+
+        /// If Save take longer than checkpt_save_time_alarm, then set a flag on server
+        /// So that user can be aware of it.
+        if (static_cast<size_t>(timer.duration()) > server_->serverEnv_.checkpt_save_time_alarm()) {
+            server_->defs_->flag().set(ecf::Flag::LATE);
+            std::stringstream ss;
+            ss << "Check pt save time(" << timer.duration() << ") is greater than alarm time("
+               << server_->serverEnv_.checkpt_save_time_alarm()
+               << "). Excessive save times can interfere with scheduling!";
+            log(Log::WAR, ss.str());
+        }
+#ifdef DEBUG_CHECKPT
+        std::cout << " backup and save took " << durationTimer.duration() << " seconds\n";
+#endif
+    }
+    catch (std::exception& e) {
+        std::string msg = "Could not save checkPoint file! ";
+        msg += e.what();
+        server_->defs_->flag().set(ecf::Flag::CHECKPT_ERROR);
+        server_->defs()->set_server().add_or_update_user_variables("ECF_CHECKPT_ERROR", msg);
+        LOG(Log::ERR, msg);
+        return false;
+    }
+
+    return true;
+}
+
+void CheckPtSaver::periodicSaveCheckPt(const boost::system::error_code& error) {
+#ifdef DEBUG_CHECKPT
+    std::cout << "      CheckPtSaver::periodicSaveCheckPt() interval = " << serverEnv_->checkPtInterval()
+              << "  time: " << to_simple_string(boost::posix_time::second_clock::universal_time()) << "\n";
+#endif
+    if (error == boost::asio::error::operation_aborted) {
+#ifdef DEBUG_CHECKPT
+        std::cout << "      CheckPtSaver::periodicSaveCheckPt : boost::asio::error::operation_aborted : time "
+                     "cancelled: Node running("
+                  << running_ << ")  interval = " << serverEnv_->checkPtInterval() << "\n";
+#endif
+        return;
+    }
+    else if (error) {
+        LogFlusher logFlusher;
+        LogToCout toCoutAsWell;
+        LOG(Log::ERR, "CheckPtSaver::periodicSaveCheckPt " << error.message());
+        return;
+    }
+
+    if (running_) {
+        // state changed
+        if (state_change_no_ != Ecf::state_change_no() || modify_change_no_ != Ecf::modify_change_no()) {
+            doSave();
+        }
+    }
+
+    /// Appears that expires_from_now is more accurate then expires_at
+    timer_.expires_from_now(boost::posix_time::seconds(serverEnv_->checkPtInterval()));
+    timer_.async_wait(
+        server_->io_service_.wrap([this](const boost::system::error_code& error) { periodicSaveCheckPt(error); }));
+}
+
+void CheckPtSaver::doSave() const {
+#ifdef DEBUG_CHECKPT
+    std::cout << "      CheckPtSaver::doSave()\n";
+#endif
+    // Check to see if configuration allows save
+    if (serverEnv_->checkMode() == ecf::CheckPt::NEVER) {
+#ifdef DEBUG_CHECKPT
+        std::cout << "     CheckPtSaver::doSave() configuration does not allow save \n";
+#endif
+        return;
+    }
+    (void)explicitSave(true /* from the server, hence log */);
+}
+
+void CheckPtSaver::saveIfAllowed() {
+    // Call on each state change. Hence will get many times
+#ifdef DEBUG_CHECKPT_SAVE_ALLOWED
+    std::cout << "      CheckPtSaver::saveIfAllowed()\n";
+#endif
+
+    // Check to see if configuration allows immediate save.
+    if (serverEnv_->checkMode() == ecf::CheckPt::ALWAYS) {
+        doSave();
+    }
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/CheckPtSaver.hpp 5.13.0-1/libs/server/src/ecflow/server/CheckPtSaver.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/CheckPtSaver.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/CheckPtSaver.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,126 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_CheckPtSaver_HPP
+#define ecflow_server_CheckPtSaver_HPP
+
+#include <boost/asio.hpp>
+
+#include "ecflow/core/Filesystem.hpp"
+
+class ServerEnvironment;
+class BaseServer;
+
+///
+/// \brief This class will save the defs file periodically. The period is obtained from
+/// ServerEnvironment. The save of the check point file is controlled by
+/// the settings in ServerEnvironment
+///
+/// The checkpoint files is the defs file, with state. However its saved in
+/// boost serialisation format(i.e can be text,binary,portable binary)
+///
+
+class CheckPtSaver {
+public:
+    CheckPtSaver(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment*);
+    // Disable copy (and move) semantics
+    CheckPtSaver(const CheckPtSaver&)                  = delete;
+    const CheckPtSaver& operator=(const CheckPtSaver&) = delete;
+
+    ~CheckPtSaver();
+
+    /// Start periodical save of the checkpoint file
+    void start();
+
+    /// Stop periodical save of the checkPoint file
+    void stop();
+
+    /// terminate: This will cancel the timer and any pending async operation
+    /// If timer has already expired, then the handler function will be
+    /// passed an operation aborted error code.
+    /// Called when the server is exiting. We must be sure to cancel all
+    /// async handlers or the server, will not stop.
+    void terminate();
+
+    /// Will always save the check pt file. Independent of any server environment
+    /// The input argument is used in logging. When check pointing via user command
+    /// we log the request. However we also check point automatically via the server
+    /// This allows us to distinguish the two cases in the log file:
+    /// Return true if no errors, otherwise false
+    bool explicitSave(bool from_server = false) const;
+
+    /// This function is called after node state changes. Check for save
+    /// CheckPt::ON_TIME - will do nothing since we will save periodically
+    /// CheckPt::NEVER   - will return immediately
+    /// CheckPt::ALWAYS  - will save immediately, may cause performance issues with large Node trees
+    void saveIfAllowed();
+
+    /**
+     * Stores a set of data in the current file location, ensuring a backup file retains the previous version.
+     *
+     * @tparam STORE the type of the function that stores the data
+     * @param current the file path to the current data, which will become the backup
+     * @param backup the file path to the previous backup, to be discarded
+     * @param store the function that actually performs the storage
+     */
+    template <typename STORE>
+    static void storeWithBackup(const fs::path& current, const fs::path& backup, STORE store) {
+        // 1. Save the Definitions to a temporary CheckPoint file
+        //
+        // In case an issue occurs while saving the CheckPoint file (e.g. thrown
+        // exception, or server crash), the procedure is always interrupted without
+        // changes to the current+old CheckPoint files in order to facilitate recovery.
+        //
+        fs::path temporary = fs::unique_path(current.string() + "%%%%-%%%%-%%%%-%%%%");
+        store(temporary.string());
+
+        // 2. Backup the current CheckPoint files
+        //
+        // Important: The current checkpoint is only backed up if it exists
+        // and has size greater than zero bytes. This approach avoid backing up
+        // empty files, resulting from a full file system, and overriding relevant
+        // old content that might be otherwise available.
+        //
+        // The backup effectively replaces the old with the current CheckPoint file.
+        //
+        if (fs::exists(current) && fs::file_size(current) > 0) {
+            fs::remove(backup);
+            fs::rename(current, backup);
+        }
+
+        // 3. Promote the temporary to current CheckPoint file
+        fs::rename(temporary, current);
+    }
+
+private:
+    /// save the node tree in the server to a checkPt file.
+    /// this is controlled by the configuration. If the configuration does not
+    /// allow a save, does nothing
+    void doSave() const;
+
+    /// Called periodically to save checkPoint file
+    /// We use error parameter, since when we cancel the timer via, terminate
+    /// we do NOT want to do an explicit save *PLUS* we want to return without
+    /// starting another async operation. Otherwise the server will not return
+    ///
+    /// This will call doSave() but *ONLY* if there has been a state change
+    /// This avoids writing out a checkpt file, unnecessarily & filling up log file
+    void periodicSaveCheckPt(const boost::system::error_code& error);
+
+    BaseServer* server_;
+    boost::asio::deadline_timer timer_;
+    bool firstTime_;
+    bool running_;
+    const ServerEnvironment* serverEnv_;
+    mutable unsigned int state_change_no_;  // detect state change in defs
+    mutable unsigned int modify_change_no_; // detect state change in defs
+};
+
+#endif /* ecflow_server_CheckPtSaver_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/NodeTreeTraverser.cpp 5.13.0-1/libs/server/src/ecflow/server/NodeTreeTraverser.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/NodeTreeTraverser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/NodeTreeTraverser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,402 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/NodeTreeTraverser.hpp"
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/server/BaseServer.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+// #define DEBUG_TRAVERSER 1
+// #define DEBUG_POLL 1
+
+#ifdef DEBUG_TRAVERSER
+    #include <iostream>
+#endif
+using namespace std;
+using namespace ecf;
+using namespace boost::posix_time;
+
+// ***********************************************************************
+// It was noticed that having a poll of 60 seconds was not very accurate
+// even when the server was not active, could be out by as much as 25 seconds
+// Hence we poll every second, and check it against the minute boundary
+// ************************************************************************
+
+NodeTreeTraverser::NodeTreeTraverser(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment& serverEnv)
+    : server_(s),
+      serverEnv_(serverEnv),
+      timer_(io, boost::posix_time::seconds(0)),
+      interval_(0, 0, serverEnv_.submitJobsInterval(), 0),
+#ifdef DEBUG_TRAVERSER
+      count_(0),
+#endif
+      firstTime_(true),
+      running_(false) {
+#ifdef DEBUG_TRAVERSER
+    std::cout << "NodeTreeTraverser::NodeTreeTraverser period = " << serverEnv_.submitJobsInterval() << "\n";
+#endif
+}
+
+NodeTreeTraverser::~NodeTreeTraverser() {
+#ifdef DEBUG_TRAVERSER
+    std::cout << "~NodeTreeTraverser::NodeTreeTraverser\n";
+#endif
+}
+
+void NodeTreeTraverser::start() {
+#ifdef DEBUG_TRAVERSER
+    {
+        LogToCout toCoutAsWell;
+        LOG(Log::DBG,
+            "NodeTreeTraverser::start() server_state(" << SState::to_string(server_->state()) << ") running("
+                                                       << running_ << ")  count(" << count_ << ") firstTime_("
+                                                       << firstTime_ << ")");
+    }
+#endif
+
+    if (!running_) {
+#ifdef DEBUG_TRAVERSER
+        count_ = 0;
+#endif
+        running_ = true;
+        if (firstTime_) {
+            // If the server is stopped/started we want to avoid skewing the calendar, since each time
+            // we call traverse, the calendar is updated with the server poll. hence we must make sure
+            // we only start it once here
+            last_time_      = Calendar::second_clock_time();
+            next_poll_time_ = last_time_;
+            firstTime_      = false;
+
+            /// ==========================================================================
+            /// Make sure we *ALIGN* the poll period exactly *** to the minute*** boundary
+            /// ==========================================================================
+            if (60 == serverEnv_.submitJobsInterval()) {
+
+                time_duration time_of_day      = last_time_.time_of_day();
+                int seconds_to_minute_boundary = 60 - time_of_day.seconds();
+
+#ifdef DEBUG_TRAVERSER
+                std::cout << "  NodeTreeTraverser::start: time_of_day(" << to_simple_string(time_of_day)
+                          << ") seconds_to_minute_boundary(" << seconds_to_minute_boundary << ")\n";
+#endif
+
+                if (seconds_to_minute_boundary != 0) {
+
+                    // Make sure subsequent polls are *ALIGNED* to minute boundary
+                    next_poll_time_ = last_time_ + seconds(seconds_to_minute_boundary);
+#ifdef DEBUG_TRAVERSER
+                    std::cout << "  NodeTreeTraverser::start: next_poll_time_(" << to_simple_string(next_poll_time_)
+                              << ")\n";
+#endif
+
+                    // ************************************************************************************************
+                    // ** This relies on next_poll_time_ being set first, to ensure job generation does not take longer
+                    // ************************************************************************************************
+#ifdef DEBUG_TRAVERSER
+                    std::cout << "  NodeTreeTraverser::start: Do an immediate job generation. Since we don't want to "
+                                 "wait for minute boundary, when starting.\n";
+#endif
+                    update_suite_calendar_and_traverse_node_tree(last_time_);
+                }
+            }
+
+            start_timer();
+        }
+    }
+}
+
+void NodeTreeTraverser::stop() {
+#ifdef DEBUG_TRAVERSER
+    {
+        LogToCout toCoutAsWell;
+        LOG(Log::DBG, "   NodeTreeTraverser::stop() count(" << count_ << ")");
+    }
+#endif
+
+    running_ = false;
+}
+
+void NodeTreeTraverser::terminate() {
+#ifdef DEBUG_TRAVERSER
+    {
+        LogToCout toCoutAsWell;
+        LOG(Log::DBG, "   NodeTreeTraverser::terminate() count(" << count_ << ")");
+    }
+#endif
+
+    timer_.cancel();
+}
+
+void NodeTreeTraverser::do_traverse() {
+    // since we poll every second, if less than next poll (every 60 seconds) continue.
+    ptime time_now = Calendar::second_clock_time();
+    if (time_now < next_poll_time_) {
+
+        // minimise the number of node tree traversal, to once every second, but only *IF* required
+        // Note: if we are a few seconds to the poll time, but job generation takes a while
+        //       we can get warning about the interval took to long. See below:
+
+        // LOG(Log::DBG,"get_job_generation_count() = " << server_->get_job_generation_count());
+        if (server_->get_job_generation_count() > 0) {
+            traverse_node_tree_and_job_generate(time_now, false /* not in command context */);
+        }
+
+        start_timer(); // timer fires *EVERY* second
+        return;
+    }
+    // time_now >= next_poll_time_
+
+    LogFlusher logFlusher;
+
+    // We have SOFT real time, we poll every second, BUT only update the suite calendar at job submission interval.
+    // However, we cannot guarantee to hit exactly at the next poll time
+    // *** traverse node tree and increment next_poll_time_ ***
+    time_duration duration          = time_now - last_time_;
+    int diff_from_last_time         = duration.total_seconds();
+    int submitJobsIntervalInSeconds = serverEnv_.submitJobsInterval();
+
+#ifdef DEBUG_TRAVERSER
+    int real_diff = diff_from_last_time - submitJobsIntervalInSeconds;
+    std::stringstream ss;
+    ss << "   NodeTreeTraverser::traverse() diff_from_last_time:" << diff_from_last_time << " running:" << running_
+       << " count:" << count_ << " real_diff:" << real_diff << "  time_now:" << to_simple_string(time_now);
+    if (diff_from_last_time == 0)
+        ss << ": FIRST time: ";
+#endif
+
+    /// Update server stat's. ie records number of requests for each poll period
+    server_->update_stats(diff_from_last_time);
+
+    /// The poll times will *vary* since we are trying to keep up with the hard real time.
+    if (diff_from_last_time > submitJobsIntervalInSeconds) {
+
+        /// This will happen from time to time, hence only report, for real wayward times
+        int diff = diff_from_last_time - submitJobsIntervalInSeconds;
+        if (diff > (submitJobsIntervalInSeconds * 0.25)) {
+            LOG(Log::WAR,
+                ": interval is (" << submitJobsIntervalInSeconds << " seconds) but took (" << diff_from_last_time
+                                  << " seconds)");
+        }
+    }
+
+    /// Remove any stale zombies
+    server_->zombie_ctrl().remove_stale_zombies(time_now);
+
+#ifdef DEBUG_TRAVERSER
+    time_duration traverse_duration = Calendar::second_clock_time() - time_now;
+    ss << " Traverse duration:" << traverse_duration.total_seconds();
+#endif
+
+    // We poll *EVERY second but update the next_poll_time_ to be consistent with the job submission interval
+    // Hence the next poll times *will* vary( SOFT REAL TIME ).
+    // Note: On server start, we modified the next_poll_time_ to hit the minute boundary.
+    //
+    //         FIRST          time_now(skip)                                   time_now(traverse node tree)
+    //           |                |         L                                      |         S
+    //           V                V------------------------|                       V-----------------|
+    // ==========0====================0====================0====================0====================0
+    //           ^                    ^                    ^                    ^                    ^
+    //           |                    |                    |                    |                    |
+    //         last_time_       next_poll_time_       next_poll_time_      next_poll_time_      next_poll_time_
+    //         next_poll_time_
+    //                                ^                                         ^
+    //                                |                                         |
+    //                             last_time_                                last_time_
+    //                             reset to previous next_poll_time_, to avoid yo-yoing, messages about poll being
+    //                             long/short
+    //
+    // Update next_poll_time_: WE  *ONLY* get here if time_now >= next_poll_time
+
+    if (time_now > next_poll_time_) {
+
+        /// Continue updating next_poll_time_ by interval_ until it is greater time_now
+#ifdef DEBUG_TRAVERSER
+        {
+            ss << ": Shorten the poll time : Current time(" << to_simple_string(time_now) << ") > current poll_time("
+               << to_simple_string(next_poll_time_) << ")";
+            time_duration diff = time_now - next_poll_time_;
+            ss << " by " << diff.total_seconds() << " seconds: ";
+        }
+#endif
+
+        while (next_poll_time_ <= time_now) {
+            next_poll_time_ += interval_;
+        }
+    }
+    else {
+
+        /// Hit the poll time: Should get here when traverse called for the *FIRST* time ( since time_now ==
+        /// next_poll_time_)
+#ifdef DEBUG_TRAVERSER
+        ss << ": On poll time: ";
+#endif
+
+        next_poll_time_ += interval_;
+    }
+
+    // At begin time for very large suites, slow disk, and in test, during job generation we can miss the next poll
+    // time(i.e a,b) This means that on the next poll time because last_time was not updated, to be immediately behind
+    // the next poll time by 'interval_' seconds an erroneous report is logged about missing the poll time
+    //
+    //         FIRST                                                               Time_now
+    //           |                                                                    |
+    //           V                    a                    b                    c     X
+    // ==========0====================0====================0====================0====================0
+    //           ^                    ^                    ^                    ^                    ^
+    //           |                    |                    |                    |                    |
+    //         last_time_       next_poll_time_       next_poll_time_      next_poll_time_      next_poll_time_
+    //
+    // Hence we need to ensure that last_time is always less that next_poll_time_ by interval_
+    // In the diagram above missed poll time a and b, then we need to set last_time_ to 'c' and *NOT* 'a' | 'b'
+    last_time_ = next_poll_time_ - interval_;
+
+#ifdef DEBUG_TRAVERSER
+    {
+        ss << " Next Poll at:" << to_simple_string(next_poll_time_);
+        LogToCout toCoutAsWell;
+        LOG(Log::DBG, ss.str());
+    }
+#endif
+
+    // Start node tree traversal.
+    // ************************************************************************************************
+    // ** This relies on next_poll_time_ being set first, to ensure job generation does not take longer
+    // ************************************************************************************************
+    update_suite_calendar_and_traverse_node_tree(time_now);
+
+    start_timer(); // timer fires *EVERY* second
+}
+
+void NodeTreeTraverser::start_timer() {
+    /// Appears that expires_from_now is more accurate then expires_at i.e timer_.expires_at( timer_.expires_at() +
+    /// boost::posix_time::seconds( poll_at ) );
+    timer_.expires_from_now(boost::posix_time::seconds(1));
+    timer_.async_wait(server_->io_service_.wrap([this](const boost::system::error_code& error) { traverse(error); }));
+}
+
+void NodeTreeTraverser::traverse(const boost::system::error_code& error) {
+    if (error == boost::asio::error::operation_aborted) {
+#ifdef DEBUG_TRAVERSER
+        {
+            LogToCout toCoutAsWell;
+            LOG(Log::DBG, "NodeTreeTraverser::traverse Timer was cancelled");
+        }
+#endif
+        return;
+    }
+    else if (error) {
+        LogToCout toCoutAsWell;
+        std::string msg = "NodeTreeTraverser::traverse error: ";
+        msg += error.message();
+        ecf::log(Log::ERR, msg);
+        return;
+    }
+
+    do_traverse();
+}
+
+void NodeTreeTraverser::update_suite_calendar_and_traverse_node_tree(const boost::posix_time::ptime& time_now) {
+    // *****************************************************************************
+    // JOB SUBMISSION SEEMS TO WORK BEST IF THE CALENDAR INCREMENT HAPPENS FIRST
+    // HOWEVER THIS MEANS WE MAY MISS THE VERY FIRST JOB SUBMISSION. ??
+    // Note: events, meters and task completion kickoff another job submission
+    //       There seems to be greater stability in terms of testing as it allows
+    //       process to complete, before the calendar is incremented.
+    // *****************************************************************************
+
+    // This functions gets called every 60 seconds or so, update calendar && time
+    // dependent variables in case any jobs depend on them. By default, the calendar
+    // update interval is the same as submitJobsInterval for non-real calendars,
+    // however for testing both real/non-real calendars the calendar increment can be
+    // changed to speed up calendar. This is done by setting the calendar increment
+    // on the suite (i.e. via the defs file) which will _override_ this setting.
+    //
+    // Additionally, by passing in the flag running_, it allows suites which want to
+    // stop the calendar updates, when the server is stopped to do so.
+    // For real time calendars we make one system call here, instead of many times in each suite
+    //
+    // In the case where defs/node tree is suspended, updateCalendar will continue
+    // to mark those time dependencies that are free, as free.
+    // This information is then used during the resume.
+#ifdef DEBUG_TRAVERSER
+    ++count_;
+#endif
+    CalendarUpdateParams calParams(time_now, interval_ /* calendar increment */, running_);
+    server_->defs_->updateCalendar(calParams);
+
+    traverse_node_tree_and_job_generate(time_now, false /* not in command context */);
+}
+
+void NodeTreeTraverser::traverse_node_tree_and_job_generate(const boost::posix_time::ptime& start_time,
+                                                            bool user_cmd_context) const {
+    // **************************************************************************************
+    // This can be called at the end of a user command (force, alter, requeue, etc.).
+    // Hence, start_time may be >= poll_time.
+    //
+    // Note: for child command we just call increment_job_generation_count()
+    // **************************************************************************************
+
+    if (running_) {
+#ifdef DEBUG_JOB_SUBMISSION
+        jobsParam.logDebugMessage(" from NodeTreeTraverser::traverse_node_tree_and_job_generate()");
+#endif
+
+        // ** In the *NON* command context, we should always have start_time < next_poll_time_
+        if (user_cmd_context && start_time >= next_poll_time_) {
+            server_->increment_job_generation_count();
+            return;
+        }
+
+        server_->reset_job_generation_count();
+
+        // Pass submit jobs interval, so that we can check jobs submission occurs within the allocated time.
+        // By default, job generation is enabled.
+        // However, for testing, we allow job generation to be disabled.
+        JobsParam jobsParam(serverEnv_.submitJobsInterval(), serverEnv_.jobGeneration());
+
+        // If job generation takes longer than the time to *reach* next_poll_time_, then time out.
+        // Hence, we start out with 60 seconds, and time for job generation should decrease. Until reset back to 60
+        // Should allow greater child communication.
+        // By setting set_next_poll_time, we enable timeout of job generation.
+        // ** IMPLIES => next_poll_time_ must be set first, before *THIS* function is called **
+        // Note: There are other place where we may not want to timeout job generation.
+        jobsParam.set_next_poll_time(next_poll_time_);
+
+        Jobs jobs(server_->defs_);
+        if (!jobs.generate(jobsParam)) {
+            ecf::log(Log::ERR, jobsParam.getErrorMsg());
+        }
+        if (jobsParam.timed_out_of_job_generation()) {
+            // Implies we timed out, hence time_out_time >= next_poll_time_
+            const ptime& time_out_time = jobsParam.time_out_time();
+
+            // Timeout could occur because job generation started just a few seconds before the poll time.
+            // Excessive warnings are avoided by issuing warnings only if `time_out_time > next_poll_time_`.
+            // Notice: the following implementation considers 5 seconds of leeway.
+            if (!time_out_time.is_special() && time_out_time > next_poll_time_) {
+                const int leeway       = 5;
+                time_duration duration = time_out_time - next_poll_time_;
+                if (duration.total_seconds() >= leeway || serverEnv_.submitJobsInterval() != 60) {
+
+                    std::stringstream ss;
+                    ss << "Job generation *timed* out: start time:" << start_time << "  time_out_time:" << time_out_time
+                       << "  poll_time:" << next_poll_time_;
+                    ecf::log(Log::WAR, ss.str());
+                }
+            }
+        }
+    }
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/NodeTreeTraverser.hpp 5.13.0-1/libs/server/src/ecflow/server/NodeTreeTraverser.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/NodeTreeTraverser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/NodeTreeTraverser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,90 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_NodeTreeTraverser_HPP
+#define ecflow_server_NodeTreeTraverser_HPP
+
+///
+/// \brief This class will traverse the node tree periodically, It is tied to a server.
+/// This implementation uses a strand to ensure sequential processing of the node dependency traversal
+/// in the presence of multiple threads, without the need of explicit locking. i.e mutex's
+///
+/// For testing we make the distinction between the poll period, and calendar update interval
+/// Some suites require a real time calendar. Hence we must make sure that
+/// poll interval is in sync with real time.
+///
+
+#include <boost/asio.hpp>
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+class BaseServer;
+class ServerEnvironment;
+// #define DEBUG_TRAVERSER 1
+
+class NodeTreeTraverser {
+public:
+    NodeTreeTraverser(BaseServer* s, boost::asio::io_service& io, const ServerEnvironment& serverEnv);
+    // Disable copy (and move) semantics
+    NodeTreeTraverser(const NodeTreeTraverser&)                  = delete;
+    const NodeTreeTraverser& operator=(const NodeTreeTraverser&) = delete;
+
+    ~NodeTreeTraverser();
+
+    /// If first time Starts traversing Node tree and resolving dependencies.
+    /// This essentially starts Jobs scheduling. Calling start more than once does nothing.
+    /// On subsequent calls to start resume is called. Which may cause immediate
+    /// job generation. (i.e for those nodes whose node are free of time dependencies)
+    /// Timer will be aligned to the minute boundary
+    void start();
+
+    /// Suspends job scheduling (for real time calendars/suite)
+    /// Shutdown & suspend (are very similar) shutdown operate at the top/level.
+    /// Both should have effect of stopping job submission and not the event loop
+    ///
+    /// During a system session, a node can be placed into suspend mode.
+    /// In suspend mode, no jobs are submitted. (**** However node which are
+    /// free to run are marked****).
+    ///
+    /// When the session is resumed, those node than were marked, have
+    /// the task's submitted. ( This means that job dependent on a time dependency
+    /// does not need to be held for the following day)
+    void stop();
+
+    /// terminate: This will cancel the timer and any pending async operation
+    /// If timer has already expired, then the handler function will be
+    /// passed an operation aborted error code.
+    /// Called when the server is exiting. We must be sure to cancel all
+    /// async handlers or the server, will not stop.
+    void terminate();
+
+    /// This can be called at the end of a *USER* command(force,alter,requeue,etc), hence time_now may be >= poll_time
+    /// If this is the case, we will defer job generation
+    void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now, bool user_cmd_context) const;
+
+private:
+    void traverse(const boost::system::error_code& error);
+    void do_traverse();
+    void start_timer();
+    void update_suite_calendar_and_traverse_node_tree(const boost::posix_time::ptime& time_now);
+
+    BaseServer* server_;
+    const ServerEnvironment& serverEnv_;
+    boost::asio::deadline_timer timer_;
+    boost::posix_time::ptime last_time_;        // ensure poll is in sync
+    boost::posix_time::ptime next_poll_time_;   // Keep as sync as possible with hard real times
+    boost::posix_time::time_duration interval_; // Job submission interval
+#ifdef DEBUG_TRAVERSER
+    int count_;
+#endif
+    bool firstTime_;
+    bool running_;
+};
+
+#endif /* ecflow_server_NodeTreeTraverser_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/PeriodicScheduler.cpp 5.13.0-1/libs/server/src/ecflow/server/PeriodicScheduler.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/PeriodicScheduler.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/PeriodicScheduler.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/PeriodicScheduler.hpp"
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/PeriodicScheduler.hpp 5.13.0-1/libs/server/src/ecflow/server/PeriodicScheduler.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/PeriodicScheduler.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/PeriodicScheduler.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,258 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_PeriodicScheduler_HPP
+#define ecflow_server_PeriodicScheduler_HPP
+
+#include <chrono>
+#include <iostream>
+
+#include <boost/asio.hpp>
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/core/Log.hpp"
+
+namespace ecf {
+
+class Timer {
+public:
+    explicit Timer(boost::asio::io_service& io) : io_service_{io}, timer_{io_service_, boost::posix_time::seconds(0)} {}
+    Timer(const Timer&) = delete;
+
+    Timer& operator=(const Timer&) = delete;
+
+    void cancel() { timer_.cancel(); }
+
+    template <typename CALLBACK>
+    void set(CALLBACK callback, std::chrono::seconds expiry) {
+        /// Appears that `expires_from_now` is more accurate `then expires_at`
+        ///   i.e. timer_.expires_at( timer_.expires_at() + boost::posix_time::seconds( poll_at ) );
+        timer_.expires_from_now(boost::posix_time::seconds(expiry.count()));
+        timer_.async_wait(io_service_.wrap(callback));
+    }
+
+private:
+    boost::asio::io_service& io_service_;
+    boost::asio::deadline_timer timer_;
+};
+
+///
+/// \brief PeriodicScheduler class sets up the periodic execution of a given task.
+///
+/// The implementation considers *SOFT* real-time by using an 1-second polling
+/// mechanism, to coarsely detect the 1-minute boundary.
+/// In practice, the task is scheduled loosely at 1-second intervals, and
+/// provided with a flag indicating whenever the 1-minute boundary is crossed.
+///
+/// Important: Since the task might take a significant time to run, some
+/// slots could be missed, without consequence.
+///
+/// The Task is expected to implement the following `operator()`:
+///
+/// ```
+/// struct Task {
+///   using instant_t  = ecf::PeriodicScheduler<Task>::instant_t;
+///   void operator()(instant_t now, instant_t last, instant_t next, bool is_boundary) {
+///     /* activity execution details */
+///   }
+/// };
+/// ```
+///
+
+template <typename TASK>
+class PeriodicScheduler {
+public:
+    using clock_t    = std::chrono::system_clock;
+    using instant_t  = clock_t::time_point;
+    using duration_t = clock_t::duration;
+
+public:
+    PeriodicScheduler(const PeriodicScheduler&) = delete;
+    PeriodicScheduler(boost::asio::io_service& io, std::chrono::seconds interval, TASK& activity)
+        : timer_(io),
+          last_execution_(),
+          next_execution_(),
+          execution_interval_(interval),
+          first_(true),
+          running_(false),
+          activity_(activity) {}
+
+    ~PeriodicScheduler() = default;
+
+    PeriodicScheduler& operator=(const PeriodicScheduler&) = delete;
+
+    void start();
+    void stop();
+    void terminate();
+
+    void poll(const boost::system::error_code& error);
+
+    void execute();
+
+private:
+    void reset_timer();
+
+private:
+    Timer timer_;
+    instant_t last_execution_;
+    instant_t next_execution_;
+    duration_t execution_interval_;
+
+    bool first_;
+    bool running_;
+
+    TASK& activity_;
+};
+
+template <typename TASK>
+void PeriodicScheduler<TASK>::reset_timer() {
+    timer_.set([this](const boost::system::error_code& error) { poll(error); }, std::chrono::seconds(1));
+}
+
+template <typename TASK>
+void PeriodicScheduler<TASK>::start() {
+    if (running_) {
+        // Nothing to do...
+        return;
+    }
+
+    running_ = true;
+    if (first_) {
+        first_ = false;
+
+        auto now = clock_t::now();
+
+        last_execution_ = now;
+        next_execution_ = last_execution_ + execution_interval_;
+
+        activity_(now, last_execution_, next_execution_, true);
+
+        reset_timer();
+    }
+}
+
+template <typename TASK>
+void PeriodicScheduler<TASK>::stop() {
+    running_ = false;
+}
+
+template <typename TASK>
+void PeriodicScheduler<TASK>::terminate() {
+    timer_.cancel();
+}
+
+template <typename TASK>
+void PeriodicScheduler<TASK>::poll(const boost::system::error_code& error) {
+    if (error) {
+        if (error == boost::asio::error::operation_aborted) {
+            // This was intentional! Nothing to do...
+            return;
+        }
+
+        LogToCout toCoutAsWell;
+        std::string msg = "NodeTreeTraverser::traverse error: ";
+        msg += error.message();
+        ecf::log(Log::ERR, msg);
+        return;
+    }
+
+    execute();
+}
+
+template <typename TASK>
+void PeriodicScheduler<TASK>::execute() {
+    auto now = clock_t::now();
+
+    // (A) Handle the case where `now < next_execution_instant_`
+
+    if (now < next_execution_) {
+        reset_timer();
+
+        // When `now` is before the next planned execution,
+        // the activity is called with the indication `is_boundary = false`
+        activity_(now, last_execution_, next_execution_, false);
+        return;
+    }
+
+    // (B) Handle the case where `now >= next_execution_instant_`
+
+    // (B.1) Log a warning in case the execution slot was missing due to _severe_ execution delay
+    {
+        auto since_last_execution = std::chrono::duration_cast<std::chrono::seconds>(now - last_execution_);
+        if (since_last_execution > execution_interval_) {
+            /// This is tolerable from time to time, so it is only reported for troublesome times
+            auto delay = since_last_execution - execution_interval_;
+            if (delay > (execution_interval_ * 0.25)) {
+                LogFlusher logFlusher;
+                LOG(Log::WAR,
+                    ": interval is " << execution_interval_.count() << " seconds, but last request took "
+                                     << since_last_execution.count() << " seconds.");
+            }
+        }
+    }
+
+    // (B.2) Update last/next execution times, reset the timer and run the activity
+
+    // We poll *EVERY second but update the next_poll_time_ to be consistent with the job submission interval
+    // Hence the next poll times *will* vary (SOFT REAL TIME).
+    // Note: On server start, we modified the next_poll_time_ to hit the minute boundary.
+    //
+    //         FIRST          time_now(skip)                                   time_now(traverse node tree)
+    //           |                |         L                                      |         S
+    //           V                V------------------------|                       V-----------------|
+    // ==========0====================0====================0====================0====================0
+    //           ^                    ^                    ^                    ^                    ^
+    //           |                    |                    |                    |                    |
+    //         last_time_       next_poll_time_       next_poll_time_      next_poll_time_      next_poll_time_
+    //         next_poll_time_
+    //                                ^                                         ^
+    //                                |                                         |
+    //                             last_time_                                last_time_
+    //                             reset to previous next_poll_time_, to avoid yo-yoing, messages about poll being
+    //                             long/short
+    //
+    // Update next_poll_time_: WE  *ONLY* get here if time_now >= next_poll_time
+
+    if (now > next_execution_) {
+        /// Update next execution time, by adding execution interval, until it is in the future
+        while (next_execution_ <= now) {
+            next_execution_ += execution_interval_;
+        }
+    }
+    else {
+        /// We hit the poll time!
+        /// Note: this also happens when calling for the *FIRST* time (i.e. now == next execution time)
+        next_execution_ += execution_interval_;
+    }
+
+    // At begin time for very large suites, slow disk, and in test, during job generation we can miss the next poll
+    // time(i.e a,b) This means that on the next poll time because last_time was not updated, to be immediately behind
+    // the next poll time by 'interval_' seconds an erroneous report is logged about missing the poll time
+    //
+    //         FIRST                                                               Time_now
+    //           |                                                                    |
+    //           V                    a                    b                    c     X
+    // ==========0====================0====================0====================0====================0
+    //           ^                    ^                    ^                    ^                    ^
+    //           |                    |                    |                    |                    |
+    //         last_time_       next_poll_time_       next_poll_time_      next_poll_time_      next_poll_time_
+    //
+    // Hence we need to ensure that last_time is always less that next_poll_time_ by interval_
+    // In the diagram above missed poll time a and b, then we need to set last_time_ to 'c' and *NOT* 'a' | 'b'
+    last_execution_ = next_execution_ - execution_interval_;
+
+    reset_timer();
+
+    activity_(now, last_execution_, next_execution_, true);
+}
+
+} // namespace ecf
+
+#endif /* ecflow_server_PeriodicActivity_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/Server.cpp 5.13.0-1/libs/server/src/ecflow/server/Server.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/Server.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/Server.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/Server.hpp"
+
+Server::Server(boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
+    : BaseServer(io_service, serverEnv),
+      tcp_server_(this, io_service, serverEnv) {
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/Server.hpp 5.13.0-1/libs/server/src/ecflow/server/Server.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/Server.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/Server.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,27 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_Server_HPP
+#define ecflow_server_Server_HPP
+
+#include "ecflow/server/BaseServer.hpp"
+#include "ecflow/server/TcpServer.hpp"
+
+class Server : public BaseServer {
+public:
+    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
+    explicit Server(boost::asio::io_service& io_service, ServerEnvironment&);
+    ~Server() override = default;
+
+private:
+    TcpServer tcp_server_;
+};
+
+#endif /* ecflow_server_Server_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/ServerEnvironment.cpp 5.13.0-1/libs/server/src/ecflow/server/ServerEnvironment.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/ServerEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/ServerEnvironment.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,833 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/ServerEnvironment.hpp"
+
+#include <cstdlib> // for getenv()
+#include <iostream>
+
+#include <boost/program_options.hpp>
+
+#include "ecflow/core/Calendar.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Pid.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/node/JobProfiler.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/server/ServerOptions.hpp"
+
+using namespace ecf;
+using namespace std;
+using namespace boost;
+namespace po = boost::program_options;
+
+static std::string the_check_mode(ecf::CheckPt::Mode mode) {
+    switch (mode) {
+        case ecf::CheckPt::NEVER:
+            return "CHECK_NEVER";
+            break;
+        case ecf::CheckPt::ON_TIME:
+            return "CHECK_ON_TIME";
+            break;
+        case ecf::CheckPt::ALWAYS:
+            return "CHECK_ALWAYS";
+            break;
+        case ecf::CheckPt::UNDEFINED:
+            return "UNDEFINED";
+            break;
+    }
+    cout << "ServerEnvironment.cpp theCheckMode: assert failed\n";
+    assert(false);
+    return std::string();
+}
+
+// This can be overridden by calling "server --ecfinterval 3" for test purposes
+const int defaultSubmitJobsInterval = 60;
+
+////////////////////////////////////////////////////////////////////////////////////////////
+// class ServerEnvironment:
+///////////////////////////////////////////////////////////////////////////////////////////
+
+ServerEnvironment::ServerEnvironment(int argc, char* argv[])
+    : serverHost_(host_name_.name()),
+      serverPort_(0),
+      checkPtInterval_(0),
+      checkpt_save_time_alarm_(CheckPt::default_save_time_alarm()),
+      submitJobsInterval_(defaultSubmitJobsInterval),
+      ecf_prune_node_log_(0),
+      jobGeneration_(true),
+      debug_(false),
+      help_option_(false),
+      version_option_(false),
+      checkMode_(ecf::CheckPt::ON_TIME),
+      tcp_protocol_(boost::asio::ip::tcp::v4()) {
+    Ecf::set_server(true);
+
+    init(argc, argv, "server_environment.cfg");
+    if (debug_)
+        std::cout << dump() << "\n";
+}
+
+// This is ONLY used in test
+ServerEnvironment::ServerEnvironment(int argc, char* argv[], const std::string& path_to_config_file)
+    : serverHost_(host_name_.name()),
+      serverPort_(0),
+      checkPtInterval_(0),
+      checkpt_save_time_alarm_(CheckPt::default_save_time_alarm()),
+      submitJobsInterval_(defaultSubmitJobsInterval),
+      ecf_prune_node_log_(0),
+      jobGeneration_(true),
+      debug_(false),
+      help_option_(false),
+      version_option_(false),
+      checkMode_(ecf::CheckPt::ON_TIME),
+      tcp_protocol_(boost::asio::ip::tcp::v4()) {
+    Ecf::set_server(true);
+
+    init(argc, argv, path_to_config_file);
+    if (debug_)
+        std::cout << dump() << "\n";
+}
+
+void ServerEnvironment::init(int argc, char* argv[], const std::string& path_to_config_file) {
+    std::string log_file_name;
+    try {
+        read_config_file(log_file_name, path_to_config_file);
+        read_environment_variables(log_file_name); // overrides any settings in the config file
+    }
+    catch (std::exception& e) {
+        std::string msg           = "Exception in ServerEnvironment::ServerEnvironment() : ";
+        std::string exception_msg = e.what();
+        // On ecgate, wrong locale, causes an exception where msg is empty
+        if (exception_msg.empty())
+            msg += "Invalid locale? Check locale using 'locale -a', then export/set LANG environment";
+        else
+            msg += e.what();
+        throw ServerEnvironmentException(msg);
+    }
+
+    // get server process id. This may be visualised in xecf. makes it easier to kill server
+    try {
+        ecf_pid_ = Pid::getpid();
+    }
+    catch (...) {
+        throw ServerEnvironmentException("ServerEnvironment::ServerEnvironment:: Could not convert PID to a string\n");
+    }
+    // std::cout << "PID = " << ecf_pid_ << "\n";
+
+    // The options(argc/argv) must be read after the environment, since they override everything else
+    ServerOptions options(argc, argv, this);
+    help_option_ = options.help_option();
+    if (help_option_)
+        return; // User is printing the help
+    version_option_ = options.version_option();
+    if (version_option_)
+        return; // User is printing the version
+
+    /// Config, Environment, or Options may have updated port, update port dependent file names
+    /// If we have default names make unique, by prefixing host and port
+    assert(!ecf_checkpt_file_.empty());        // expect name of form "ecf.check"
+    assert(!ecf_backup_checkpt_file_.empty()); // expect name of form "ecf.check.b"
+    assert(!log_file_name.empty());            // expect name of form "ecf.log"
+    assert(!ecf_white_list_file_.empty());     // expect name of form "ecf.lists"
+    assert(!ecf_passwd_file_.empty());         // expect name of form "ecf.passwd"
+    assert(!ecf_passwd_custom_file_.empty());  // expect name of form "ecf.custom_passwd"
+
+    std::string port = ecf::convert_to<std::string>(serverPort_);
+
+    // If path is absolute leave as is
+    if (ecf_checkpt_file_ == Ecf::CHECKPT())
+        ecf_checkpt_file_ = host_name_.prefix_host_and_port(port, ecf_checkpt_file_);
+    if (ecf_checkpt_file_[0] != '/') {
+        // Prepend with ECF_HOME
+        std::string check_pt = ecf_home();
+        check_pt += Str::PATH_SEPERATOR();
+        check_pt += ecf_checkpt_file_;
+        ecf_checkpt_file_ = check_pt;
+    }
+
+    // If path is absolute leave as is
+    if (ecf_backup_checkpt_file_ == Ecf::BACKUP_CHECKPT())
+        ecf_backup_checkpt_file_ = host_name_.prefix_host_and_port(port, ecf_backup_checkpt_file_);
+    if (ecf_backup_checkpt_file_[0] != '/') {
+        std::string check_pt = ecf_home();
+        check_pt += Str::PATH_SEPERATOR();
+        check_pt += ecf_backup_checkpt_file_;
+        ecf_backup_checkpt_file_ = check_pt;
+    }
+
+    if (ecf_white_list_file_ == Str::WHITE_LIST_FILE())
+        ecf_white_list_file_ = host_name_.prefix_host_and_port(port, ecf_white_list_file_);
+
+    if (ecf_passwd_file_ == Str::ECF_PASSWD())
+        ecf_passwd_file_ = host_name_.prefix_host_and_port(port, ecf_passwd_file_);
+
+    if (ecf_passwd_custom_file_ == Str::ECF_CUSTOM_PASSWD())
+        ecf_passwd_custom_file_ = host_name_.prefix_host_and_port(port, ecf_passwd_custom_file_);
+
+    // Change directory to ECF_HOME and check thats its accessible
+    change_dir_to_ecf_home_and_check_accesibility();
+
+    // LOG FILE ================================================================================
+    if (log_file_name == Ecf::LOG_FILE())
+        log_file_name = host_name_.prefix_host_and_port(port, log_file_name);
+
+    // Create the Log file. The log file is obtained from the environment. Hence **must** be done last.
+    // From ecflow version 4.9.0 we no longer flush for each command. This can enabled/disabled
+    Log::create(log_file_name);
+
+    // Init log file:
+    LOG(Log::MSG, ""); // previous log may not end in newline
+    LOG(Log::MSG, "Started at " << to_simple_string(Calendar::second_clock_time()) << " universal time");
+    if (tcp_protocol_.family() == 2 /*PF_INET*/)
+        LOG(Log::MSG, "Host(" << hostPort().first << ")  Port(" << hostPort().second << ") using TCP/IP v4");
+    else
+        LOG(Log::MSG, "Host(" << hostPort().first << ")  Port(" << hostPort().second << ") using TCP/IP v6");
+    LOG(Log::MSG, "ECF_HOME " << ecf_home());
+    LOG(Log::MSG, "Job scheduling interval: " << submitJobsInterval_);
+}
+
+ServerEnvironment::~ServerEnvironment() {
+    /// Destroy singleton to avoid valgrind from complaining
+    Log::destroy();
+    System::destroy();
+}
+
+bool ServerEnvironment::valid(std::string& errorMsg) const {
+    /// This must be called *AFTER* the constructor
+    //   cout << "*****************************************************************************\n";
+    //   cout << "ServerEnvironment::valid\n";
+    //   cout << "*****************************************************************************\n";
+
+    if (serverHost_.empty()) {
+        errorMsg = "Could not determine the server host.";
+        return false;
+    }
+    std::stringstream ss;
+    if (serverPort_ == 0 || serverPort_ <= 1023 || serverPort_ >= 49151) {
+
+        ss << "Server port " << serverPort_ << " not set correctly. \n";
+        ss << "The port numbers are divided into three ranges.\n";
+        ss << "   o the Well Known Ports, (require root permission)      0 -1023\n";
+        ss << "   o the Registered Ports,                             1024 -49151\n";
+        ss << "   o Dynamic and/or Private Ports.                    49151 -65535\n\n";
+        ss << "Please set in the range 1024-49151 via argument or \n";
+        ss << "Server/src/environment.cfg.h or set the environment variable ECF_PORT. \n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (ecfHome_.empty()) {
+        ss << "No ECF_HOME specified. Please set in Server/server_environment.cfg or\n";
+        ss << "set the environment variable ECF_HOME\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (!Log::instance() || Log::instance()->path().empty()) {
+        ss << "No log file name specified. Please set in Server/server_environment.cfg or\n";
+        ss << "set the environment variable ECF_LOG\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (checkPtInterval_ == 0) {
+        ss << "Checkpoint interval not set. Please set in Server/server_environment.cfg or\n";
+        ss << "set the environment variable ECF_CHECKINTERVAL. The value must be\n";
+        ss << "convertible to a integer\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (submitJobsInterval_ < 1 || submitJobsInterval_ > 60) {
+        ss << "Submit jobs interval not set correctly. Please set in Server/server_environment.cfg\n";
+        ss << "or provide as an argument. It must be in the range [1-60] \n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (ecf_prune_node_log_ < 0) {
+        ss << "ECF_PRUNE_NODE_LOG not set correctly. Please set in Server/server_environment.cfg\n";
+        ss << "or via environment variable of same name. It must be in the range [1-356] \n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (ecf_checkpt_file_.empty()) {
+        ss << "No checkpoint file name specified. Please set in Server/server_environment.cfg or\n";
+        ss << "set the environment variable ECF_CHECK\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (ecf_backup_checkpt_file_.empty()) {
+        ss << "No old checkpoint file name specified. Please set in Server/server_environment.cfg or\n";
+        ss << "set the environment variable ECF_CHECKOLD\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (checkMode_ == ecf::CheckPt::UNDEFINED) {
+        ss << "No ECF_CHECKMODE specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (ecf_cmd_.empty()) {
+        ss << "No ECF_JOB_CMD specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (killCmd_.empty()) {
+        ss << "No ECF_KILL_CMD specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (statusCmd_.empty()) {
+        ss << "No ECF_STATUS_CMD specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (checkCmd_.empty()) {
+        ss << "No ECF_CHECK_CMD specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (urlCmd_.empty()) {
+        ss << "No ECF_URL_CMD specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (urlBase_.empty()) {
+        ss << "No ECF_URL_BASE specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (url_.empty()) {
+        ss << "No ECF_URL specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+    if (ecf_micro_.empty()) {
+        ss << "No ECF_MICRODEF specified. Please set in Server/server_environment.cfg\n";
+        errorMsg = ss.str();
+        return false;
+    }
+
+    if (!ecf_passwd_file_.empty() && fs::exists(ecf_passwd_file_)) {
+        if (!passwd_file_.load(ecf_passwd_file_, debug(), errorMsg)) {
+            std::cout << "Error: could not parse ECF_PASSWD file " << ecf_passwd_file_ << "\n" << errorMsg << "\n";
+            return false;
+        }
+        if (!passwd_file_.check_at_least_one_user_with_host_and_port(serverHost_, the_port())) {
+            std::cout << "Error: password file " << ecf_passwd_file_;
+            std::cout << " does not contain any users, which match the host and port of this server\n";
+            return false;
+        }
+    }
+
+    if (!ecf_passwd_custom_file_.empty() && fs::exists(ecf_passwd_custom_file_)) {
+        if (!passwd_custom_file_.load(ecf_passwd_custom_file_, debug(), errorMsg)) {
+            std::cout << "Error: could not parse ECF_CUSTOM_PASSWD file " << ecf_passwd_custom_file_ << "\n"
+                      << errorMsg << "\n";
+            return false;
+        }
+        if (!passwd_custom_file_.check_at_least_one_user_with_host_and_port(serverHost_, the_port())) {
+            std::cout << "Error: custom password file " << ecf_passwd_custom_file_;
+            std::cout << " does not contain any users, which match the host and port of this server\n";
+            return false;
+        }
+    }
+
+    // If the white list file is empty or does not exist, *ON* server start, its perfectly valid
+    // i.e any user is free to access the server
+    if (ecf_white_list_file_.empty())
+        return true;
+    if (!fs::exists(ecf_white_list_file_))
+        return true;
+
+    /// read in the ecf white list file that specifies valid users and their access rights
+    /// If the file can't be opened returns false and an error message and false;
+    /// Automatically add server admin(user) with write access, as this will allow admin reload
+    return load_whitelist_file(errorMsg);
+}
+
+std::pair<std::string, std::string> ServerEnvironment::hostPort() const {
+    return std::make_pair(serverHost_, the_port());
+}
+
+std::string ServerEnvironment::the_port() const {
+    return ecf::convert_to<std::string>(serverPort_);
+}
+
+void ServerEnvironment::variables(std::vector<std::pair<std::string, std::string>>& theRetVec) const {
+    // Variables read in from the environment
+    // Need to setup client environment.
+    // The server sets these variable for use by the client. i.e when creating the jobs
+    // The clients then uses them to communicate back with the server.
+    theRetVec.emplace_back(Str::ECF_PORT(), the_port());
+    theRetVec.emplace_back(Str::ECF_HOST(), serverHost_);
+
+    theRetVec.emplace_back(Str::ECF_HOME(), ecfHome_);
+    theRetVec.emplace_back(std::string("ECF_LOG"), Log::instance()->path());
+    theRetVec.emplace_back(std::string("ECF_CHECK"), ecf_checkpt_file_);
+    theRetVec.emplace_back(std::string("ECF_CHECKOLD"), ecf_backup_checkpt_file_);
+    theRetVec.emplace_back(std::string("ECF_INTERVAL"), ecf::convert_to<std::string>(submitJobsInterval_));
+
+    // These variable are read in from the environment, but are not exposed
+    // since they only affect the server
+    // ECF_CHECKINTERVAL
+
+    theRetVec.emplace_back(std::string("ECF_LISTS"),
+                           ecf_white_list_file_); // read only variable, changing it has no effect
+    theRetVec.emplace_back(std::string("ECF_PASSWD"),
+                           ecf_passwd_file_); // read only variable, changing it has no effect
+    theRetVec.emplace_back(std::string("ECF_CUSTOM_PASSWD"),
+                           ecf_passwd_custom_file_); // read only variable, changing it has no effect
+
+    // variables that can be overridden, in the suite definition
+    theRetVec.emplace_back(std::string("ECF_JOB_CMD"), ecf_cmd_);
+    theRetVec.emplace_back(std::string("ECF_KILL_CMD"), killCmd_);
+    theRetVec.emplace_back(std::string("ECF_STATUS_CMD"), statusCmd_);
+    theRetVec.emplace_back(std::string("ECF_CHECK_CMD"), checkCmd_);
+    theRetVec.emplace_back(std::string("ECF_URL_CMD"), urlCmd_);
+    theRetVec.emplace_back(std::string("ECF_URL_BASE"), urlBase_);
+    theRetVec.emplace_back(std::string("ECF_URL"), url_);
+    theRetVec.emplace_back(std::string("ECF_MICRO"), ecf_micro_);
+
+    // Reference variable, these should be read only
+    theRetVec.emplace_back(std::string("ECF_PID"), ecf_pid_);           // server PID
+    theRetVec.emplace_back(std::string("ECF_VERSION"), Version::raw()); // server version
+
+#ifdef ECF_OPENSSL
+    if (ssl_.enabled()) {
+        theRetVec.emplace_back(
+            std::string("ECF_SSL"),
+            ssl_.ssl()); // 1 means shared ssl certificate, <host>.<port> means server specific certificates
+    }
+#endif
+}
+
+bool ServerEnvironment::reloadWhiteListFile(std::string& errorMsg) {
+    if (debug())
+        cout << "ServerEnvironment::reloadWhiteListFile:(" << ecf_white_list_file_ << ") CWD("
+             << fs::current_path().string() << ")\n";
+    if (ecf_white_list_file_.empty()) {
+        errorMsg += "The ECF_LISTS file ";
+        errorMsg += ecf_white_list_file_;
+        errorMsg += " has not been specified.";
+        return false;
+    }
+    if (!fs::exists(ecf_white_list_file_)) {
+        errorMsg += "The ECF_LISTS file ";
+        errorMsg += ecf_white_list_file_;
+        errorMsg += " does not exist. Server CWD : " + fs::current_path().string();
+        return false;
+    }
+
+    return load_whitelist_file(errorMsg);
+}
+
+bool ServerEnvironment::load_whitelist_file(std::string& errorMsg) const {
+    // Only override valid users if we successfully opened and parsed file
+    if (white_list_file_.load(ecf_white_list_file_, debug(), errorMsg)) {
+        // If user accidentally remove the server/user from white list,
+        // they will not be able reload white list, since it requires write access.
+        // (Requires terminate, modify white list, restart to fix)
+        // Hence always allow server user write access *IF* required for non empty file
+        white_list_file_.allow_write_access_for_server_user();
+        return true;
+    }
+    return false;
+}
+
+bool ServerEnvironment::reloadPasswdFile(std::string& errorMsg) {
+    if (debug())
+        cout << "ServerEnvironment::reloadPasswdFile:(" << ecf_passwd_file_ << ") CWD(" << fs::current_path().string()
+             << ")\n";
+    if (ecf_passwd_file_.empty()) {
+        errorMsg += "The ECF_PASSWD file ";
+        errorMsg += ecf_passwd_file_;
+        errorMsg += " has not been specified.";
+        return false;
+    }
+    if (!fs::exists(ecf_passwd_file_)) {
+        errorMsg += "The ECF_PASSWD file ";
+        errorMsg += ecf_passwd_file_;
+        errorMsg += " does not exist. Server CWD : " + fs::current_path().string();
+        return false;
+    }
+
+    // Only override valid users if we successfully opened and parsed file
+    return passwd_file_.load(ecf_passwd_file_, debug(), errorMsg);
+}
+
+bool ServerEnvironment::reloadCustomPasswdFile(std::string& errorMsg) {
+    if (debug())
+        cout << "ServerEnvironment::reloadPasswdFile:(" << ecf_passwd_custom_file_ << ") CWD("
+             << fs::current_path().string() << ")\n";
+    if (ecf_passwd_custom_file_.empty()) {
+        errorMsg += "The ECF_CUSTOM_PASSWD file ";
+        errorMsg += ecf_passwd_custom_file_;
+        errorMsg += " has not been specified.";
+        return false;
+    }
+    if (!fs::exists(ecf_passwd_custom_file_)) {
+        errorMsg += "The ECF_CUSTOM_PASSWD file ";
+        errorMsg += ecf_passwd_custom_file_;
+        errorMsg += " does not exist. Server CWD : " + fs::current_path().string();
+        return false;
+    }
+
+    // Only override valid users if we successfully opened and parsed file
+    return passwd_custom_file_.load(ecf_passwd_custom_file_, debug(), errorMsg);
+}
+
+bool ServerEnvironment::authenticateReadAccess(const std::string& user,
+                                               bool custom_user,
+                                               const std::string& passwd) const {
+    if (!custom_user) {
+        if (!passwd_file_.authenticate(user, passwd))
+            return false;
+    }
+    else {
+        if (!passwd_custom_file_.authenticate(user, passwd))
+            return false;
+    }
+
+    // if *NO* users specified then all users are valid
+    return white_list_file_.verify_read_access(user);
+}
+
+bool ServerEnvironment::authenticateReadAccess(const std::string& user,
+                                               bool custom_user,
+                                               const std::string& passwd,
+                                               const std::string& path) const {
+    if (!custom_user) {
+        if (!passwd_file_.authenticate(user, passwd))
+            return false;
+    }
+    else {
+        if (!passwd_custom_file_.authenticate(user, passwd))
+            return false;
+    }
+
+    return white_list_file_.verify_read_access(user, path);
+}
+
+bool ServerEnvironment::authenticateReadAccess(const std::string& user,
+                                               bool custom_user,
+                                               const std::string& passwd,
+                                               const std::vector<std::string>& paths) const {
+    if (!custom_user) {
+        if (!passwd_file_.authenticate(user, passwd))
+            return false;
+    }
+    else {
+        if (!passwd_custom_file_.authenticate(user, passwd))
+            return false;
+    }
+
+    return white_list_file_.verify_read_access(user, paths);
+}
+
+bool ServerEnvironment::authenticateWriteAccess(const std::string& user) const {
+    // if *NO* users specified then all users have write access
+    return white_list_file_.verify_write_access(user);
+}
+bool ServerEnvironment::authenticateWriteAccess(const std::string& user, const std::string& path) const {
+    return white_list_file_.verify_write_access(user, path);
+}
+bool ServerEnvironment::authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) const {
+    return white_list_file_.verify_write_access(user, paths);
+}
+
+// ============================================================================================
+// Privates:
+// ============================================================================================
+
+void ServerEnvironment::read_config_file(std::string& log_file_name, const std::string& path_to_config_file) {
+    if (debug())
+        cout << "ServerEnvironment::read_config_file() current_path = " << fs::current_path() << "\n";
+
+    try {
+        std::string theCheckMode;
+        int the_task_threshold = 0;
+
+        // read the environment from the config file.
+        // **** Port *must* be read before log file, and check pt files
+        po::options_description config_file_options("Configuration");
+        config_file_options.add_options()(
+            "ECF_HOME", po::value<std::string>(&ecfHome_)->default_value("."), "ECF_HOME, the home for all ECF files")(
+            "ECF_PORT",
+            po::value<int>(&serverPort_)->default_value(3141),
+            "The port number. Clients must use same port.")(
+            "ECF_CHECK",
+            po::value<std::string>(&ecf_checkpt_file_)->default_value(Ecf::CHECKPT()),
+            "Check point file name")(
+            "ECF_CHECKOLD",
+            po::value<std::string>(&ecf_backup_checkpt_file_)->default_value(Ecf::BACKUP_CHECKPT()),
+            "Backup checkpoint file name")(
+            "ECF_LOG", po::value<std::string>(&log_file_name)->default_value(Ecf::LOG_FILE()), "Log file name")(
+            "ECF_CHECKINTERVAL",
+            po::value<int>(&checkPtInterval_)->default_value(CheckPt::default_interval()),
+            "The interval in seconds to save check point file")(
+            "ECF_INTERVAL",
+            po::value<int>(&submitJobsInterval_)->default_value(defaultSubmitJobsInterval),
+            "Check time dependencies and submit any jobs")(
+            "ECF_CHECKMODE",
+            po::value<std::string>(&theCheckMode),
+            "The check mode, must be one of CHECK_NEVER, CHECK_ON_TIME, CHECK_ALWAYS")(
+            "ECF_JOB_CMD",
+            po::value<std::string>(&ecf_cmd_)->default_value(Ecf::JOB_CMD()),
+            "Command to be executed to submit a job.")(
+            "ECF_KILL_CMD",
+            po::value<std::string>(&killCmd_)->default_value(Ecf::KILL_CMD()),
+            "Command to be executed to kill a job.")(
+            "ECF_STATUS_CMD",
+            po::value<std::string>(&statusCmd_)->default_value(Ecf::STATUS_CMD()),
+            "Command to be obtain the job status from server.")(
+            "ECF_CHECK_CMD",
+            po::value<std::string>(&checkCmd_)->default_value(Ecf::CHECK_CMD()),
+            "Command to be obtain the job status from client.")(
+            "ECF_URL_CMD",
+            po::value<std::string>(&urlCmd_)->default_value(Ecf::URL_CMD()),
+            "Command to be obtain url.")(
+            "ECF_URL_BASE", po::value<std::string>(&urlBase_)->default_value(Ecf::URL_BASE()), "Defines url base.")(
+            "ECF_URL", po::value<std::string>(&url_)->default_value(Ecf::URL()), "The default url.")(
+            "ECF_MICRODEF",
+            po::value<std::string>(&ecf_micro_)->default_value(Ecf::MICRO()),
+            "Preprocessor character for variable substitution and including files")(
+            "ECF_LISTS",
+            po::value<std::string>(&ecf_white_list_file_)->default_value(Str::WHITE_LIST_FILE()),
+            "Path name to file the list valid users and their access rights")(
+            "ECF_PASSWD",
+            po::value<std::string>(&ecf_passwd_file_)->default_value(Str::ECF_PASSWD()),
+            "Path name to passwd file")(
+            "ECF_CUSTOM_PASSWD",
+            po::value<std::string>(&ecf_passwd_custom_file_)->default_value(Str::ECF_CUSTOM_PASSWD()),
+            "Path name to custom passwd file, for user who don't use login name")(
+            "ECF_TASK_THRESHOLD",
+            po::value<int>(&the_task_threshold)->default_value(JobProfiler::task_threshold_default()),
+            "The defaults thresholds when profiling job generation")(
+            "ECF_PRUNE_NODE_LOG",
+            po::value<int>(&ecf_prune_node_log_)->default_value(30),
+            "Node log, older than 180 days automatically pruned when checkpoint file loaded");
+
+        ifstream ifs(path_to_config_file.c_str());
+        if (!ifs) {
+            if (debug())
+                cout << "Could not load server_environment.cfg " << path_to_config_file << "\n";
+        }
+
+        /// This is *NOT* redundant, when the file is empty/not present, then the default value
+        /// defined above are set.
+        po::variables_map vm;
+        po::store(parse_config_file(ifs, config_file_options), vm);
+        po::notify(vm);
+
+        if (theCheckMode == "CHECK_ON_TIME")
+            checkMode_ = ecf::CheckPt::ON_TIME;
+        else if (theCheckMode == "CHECK_NEVER")
+            checkMode_ = ecf::CheckPt::NEVER;
+        else if (theCheckMode == "CHECK_ALWAYS")
+            checkMode_ = ecf::CheckPt::ALWAYS;
+
+        if (the_task_threshold != 0) {
+            JobProfiler::set_task_threshold(the_task_threshold);
+        }
+    }
+    catch (std::exception& e) {
+        cerr << "ServerEnvironment::read_config_file() " << e.what() << "\n";
+    }
+}
+
+void ServerEnvironment::read_environment_variables(std::string& log_file_name) {
+    if (debug())
+        cout << "ServerEnvironment::read_environment_variables()\n";
+
+    char* serverPort = getenv(Str::ECF_PORT().c_str());
+    if (serverPort) {
+        std::string port = serverPort;
+        try {
+            serverPort_ = ecf::convert_to<int>(port);
+        }
+        catch (const ecf::bad_conversion&) {
+            std::stringstream ss;
+            ss << "ServerEnvironment::read_environment_variables(): ECF_PORT is defined(" << port
+               << ") but value is *not* convertible to an integer\n";
+            throw ServerEnvironmentException(ss.str());
+        }
+    }
+    char* checkPtInterval = getenv("ECF_CHECKINTERVAL");
+    if (checkPtInterval) {
+        std::string interval = checkPtInterval;
+        try {
+            checkPtInterval_ = ecf::convert_to<int>(interval);
+        }
+        catch (const ecf::bad_conversion&) {
+            std::stringstream ss;
+            ss << "ServerEnvironment::read_environment_variables(): ECF_CHECKINTERVAL is defined(" << interval
+               << ") but value is *not* convertible to an integer\n";
+            throw ServerEnvironmentException(ss.str());
+        }
+    }
+
+    char* ecfHome = getenv(Str::ECF_HOME().c_str());
+    if (ecfHome)
+        ecfHome_ = ecfHome;
+    if (ecfHome_ == ".") { // expand to absolute paths
+        ecfHome_ = fs::current_path().string();
+    }
+
+    char* logFileName = getenv("ECF_LOG");
+    if (logFileName)
+        log_file_name = logFileName;
+
+    char* checkPtFileName = getenv("ECF_CHECK");
+    if (checkPtFileName)
+        ecf_checkpt_file_ = checkPtFileName;
+
+    char* oldCheckPtFileName = getenv("ECF_CHECKOLD");
+    if (oldCheckPtFileName)
+        ecf_backup_checkpt_file_ = oldCheckPtFileName;
+
+    char* smsWhiteListFile = getenv("ECF_LISTS");
+    if (smsWhiteListFile)
+        ecf_white_list_file_ = smsWhiteListFile;
+
+    char* passwd = getenv("ECF_PASSWD");
+    if (passwd)
+        ecf_passwd_file_ = passwd;
+
+    char* custom_passwd = getenv("ECF_CUSTOM_PASSWD");
+    if (custom_passwd)
+        ecf_passwd_custom_file_ = custom_passwd;
+
+    char* ecf_prune_node_log = getenv("ECF_PRUNE_NODE_LOG");
+    if (ecf_prune_node_log) {
+        try {
+            ecf_prune_node_log_ = ecf::convert_to<int>(ecf_prune_node_log);
+        }
+        catch (const ecf::bad_conversion&) {
+            std::stringstream ss;
+            ss << "ServerEnviroment::read_environment_variables: ECF_PRUNE_NODE_LOG must be convertible to an integer, "
+                  "But found: "
+               << ecf_prune_node_log;
+            throw ServerEnvironmentException(ss.str());
+        }
+    }
+
+    if (getenv("ECF_DEBUG_SERVER")) {
+        debug_ = true; // can also be enabled via --debug option
+    }
+
+#ifdef ECF_OPENSSL
+    // IF ECF_SSL= 1 search server.crt
+    // ELSE          search <host>.<port>.crt
+    ssl_.enable_if_defined(serverHost_, the_port());
+#endif
+
+    char* threshold = getenv("ECF_TASK_THRESHOLD");
+    if (threshold) {
+        std::string task_threshold = threshold;
+        try {
+            JobProfiler::set_task_threshold(ecf::convert_to<int>(task_threshold));
+        }
+        catch (...) {
+            std::stringstream ss;
+            ss << "ServerEnvironment::read_environment_variables(): ECF_TASK_THRESHOLD is defined(" << threshold
+               << ") but value is *not* convertible to an integer\n";
+            throw ServerEnvironmentException(ss.str());
+        }
+    }
+}
+
+void ServerEnvironment::change_dir_to_ecf_home_and_check_accesibility() {
+    if (chdir(ecfHome_.c_str()) != 0) {
+        std::stringstream ss;
+        ss << "Can't chdir to ECF_HOME " << ecfHome_ << "\n";
+        throw ServerEnvironmentException(ss.str());
+    }
+    if (access(ecfHome_.c_str(), X_OK | R_OK | W_OK) != 0) {
+        // R_OK test for read permission
+        // W_OK test for write permission
+        // X_OK test for execute or search permission
+        // F_OK  test whether the directories leading to the file can be searched and the file exists.
+        std::stringstream ss;
+        ss << "Access restriction on ECF_HOME " << ecfHome_ << "\n";
+        throw ServerEnvironmentException(ss.str());
+    }
+}
+
+std::string ServerEnvironment::check_mode_str() const {
+    return the_check_mode(checkMode_);
+}
+
+std::string ServerEnvironment::dump() const {
+    std::stringstream ss;
+    ss << "ECF_HOME = '" << ecfHome_ << "'\n";
+    ss << "ECF_LOG = '" << Log::instance()->path() << "'\n";
+    ss << "ECF_PORT = '" << serverPort_ << "'\n";
+    ss << "ECF_CHECK = '" << ecf_checkpt_file_ << "'\n";
+    ss << "ECF_CHECKOLD = '" << ecf_backup_checkpt_file_ << "'\n";
+    ss << "ECF_CHECKINTERVAL = '" << checkPtInterval_ << "'\n";
+    ss << "ECF_INTERVAL = '" << submitJobsInterval_ << "'\n";
+    ss << "ECF_CHECKMODE = '" << the_check_mode(checkMode_) << "'\n";
+    ss << "ECF_JOB_CMD = '" << ecf_cmd_ << "'\n";
+    ss << "ECF_KILL_CMD = '" << killCmd_ << "'\n";
+    ss << "ECF_STATUS_CMD = '" << statusCmd_ << "'\n";
+    ss << "ECF_CHECK_CMD = '" << checkCmd_ << "'\n";
+    ss << "ECF_URL_CMD = '" << urlCmd_ << "'\n";
+    ss << "ECF_URL_BASE = '" << urlBase_ << "'\n";
+    ss << "ECF_URL = '" << url_ << "'\n";
+    ss << "ECF_MICRO = '" << ecf_micro_ << "'\n";
+    ss << "ECF_PRUNE_NODE_LOG = '" << ecf_prune_node_log_ << "'\n";
+    ss << "check pt save time alarm " << checkpt_save_time_alarm_ << "\n";
+    ss << "Job generation " << jobGeneration_ << "\n";
+    ss << "Server host name " << serverHost_ << "\n";
+    ss << "ECF_PASSWD = " << ecf_passwd_file_ << "\n";
+    ss << "ECF_CUSTOM_PASSWD = " << ecf_passwd_custom_file_ << "\n";
+    if (tcp_protocol_.family() == 2 /*PF_INET*/)
+        ss << "TCP Protocol  v4 \n";
+    else if (tcp_protocol_.family() == 10 /*PF_INET6*/)
+        ss << "TCP Protocol  v6 \n";
+
+#ifdef ECF_OPENSSL
+    ss << "ECF_SSL = " << ssl_ << "\n";
+#endif
+
+    ss << white_list_file_.dump_valid_users();
+    return ss.str();
+}
+
+std::vector<std::string> ServerEnvironment::expected_variables() {
+    std::vector<std::string> expected_variables;
+    expected_variables.push_back(Str::ECF_HOME());
+    expected_variables.emplace_back("ECF_LOG");
+    expected_variables.emplace_back("ECF_CHECK");
+    expected_variables.emplace_back("ECF_CHECKOLD");
+    expected_variables.emplace_back("ECF_JOB_CMD");
+    expected_variables.emplace_back("ECF_KILL_CMD");
+    expected_variables.emplace_back("ECF_STATUS_CMD");
+    expected_variables.emplace_back("ECF_CHECK_CMD");
+    expected_variables.emplace_back("ECF_URL_CMD");
+    expected_variables.emplace_back("ECF_URL_BASE");
+    expected_variables.emplace_back("ECF_URL");
+    expected_variables.emplace_back("ECF_MICRO");
+    expected_variables.emplace_back("ECF_PID");
+    expected_variables.emplace_back("ECF_VERSION");
+    expected_variables.emplace_back("ECF_LISTS");
+    expected_variables.push_back(Str::ECF_PORT());
+    expected_variables.push_back(Str::ECF_HOST());
+    expected_variables.emplace_back("ECF_INTERVAL");
+    expected_variables.emplace_back("ECF_PASSWD");
+    expected_variables.emplace_back("ECF_CUSTOM_PASSWD");
+#ifdef ECF_OPENSSL
+    if (getenv("ECF_SSL"))
+        expected_variables.emplace_back("ECF_SSL");
+#endif
+    return expected_variables;
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/ServerEnvironment.hpp 5.13.0-1/libs/server/src/ecflow/server/ServerEnvironment.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/ServerEnvironment.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/ServerEnvironment.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,243 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_ServerEnvironment_HPP
+#define ecflow_server_ServerEnvironment_HPP
+
+///
+/// \brief The server environment is read from the configuration file. This defines
+/// the defaults for the server,and is configurable by the user, at run time
+/// Alternatively some variable can be set via environment. See environment.cfg
+///
+/// The server must be created before the log file. Since the log is initialised
+/// with the log file name from the server environment
+///
+
+#include <string>
+#include <vector>
+
+#include <boost/asio.hpp>
+
+#include "ecflow/core/CheckPt.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/PasswdFile.hpp"
+#include "ecflow/core/WhiteListFile.hpp"
+
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/Openssl.hpp"
+#endif
+
+// Added ServerEvinronmentException so that it can be in the same scope as server
+// in ServerMain. Previously we had a separate try block
+// Also distinguish between server and environment errors
+class ServerEnvironmentException : public std::runtime_error {
+public:
+    explicit ServerEnvironmentException(const std::string& msg) : std::runtime_error(msg) {}
+};
+
+class ServerEnvironment {
+public:
+    ServerEnvironment(int argc, char* argv[]);
+    ServerEnvironment(int argc, char* argv[], const std::string& path_to_config_file); // *only used in test*
+    // Disable copy (and move) semantics
+    ServerEnvironment(const ServerEnvironment&)                  = delete;
+    const ServerEnvironment& operator=(const ServerEnvironment&) = delete;
+
+    ~ServerEnvironment();
+
+    /// return true if option are valid false and error message otherwise
+    bool valid(std::string& errorMsg) const;
+
+    /// return the directory path associated with smshome
+    /// but can be overridden by the environment variable ECF_HOME
+    std::string ecf_home() const { return ecfHome_; }
+
+    /// returns the server host and port
+    std::pair<std::string, std::string> hostPort() const;
+
+#ifdef ECF_OPENSSL
+    /// return true if ssl enable via command line, AND SSL libraries are found
+    ecf::Openssl& openssl() { return ssl_; }
+    bool ssl() const { return ssl_.enabled(); }
+    void enable_ssl() { ssl_.enable(serverHost_, the_port()); } // search server.crt first, then <host>.<port>.crt
+#endif
+
+    /// returns the server port. This has a default value defined in server_environment.cfg
+    /// but can be overridden by the environment variable ECF_PORT
+    int port() const { return serverPort_; }
+    std::string the_port() const;
+
+    /// returns the TCP protocol. default is TCPv4. Can be changed via command line to TCPv6
+    boost::asio::ip::tcp tcp_protocol() const { return tcp_protocol_; }
+
+    /// Return true if job generation is enabled. By default job generation is enabled however
+    /// for test/debug we can elect to disable, it.
+    bool jobGeneration() const { return jobGeneration_; }
+
+    /// Whenever we save the checkpt, we time how long this takes.
+    /// For very large definition the time can be significant and start to interfere with
+    /// the scheduling. (i.e since write to disk is blocking).
+    /// The default is defined by CheckPt::default_save_time_alarm(). When the save time exceeds this, the late flag is
+    /// set on the definition. This needs to be manually reset.
+    size_t checkpt_save_time_alarm() const { return checkpt_save_time_alarm_; }
+    void set_checkpt_save_time_alarm(size_t t) { checkpt_save_time_alarm_ = t; }
+
+    /// returns the path of the checkpoint file. This has a default name set in server_environment.cfg
+    /// but can be overridden by the environment variable ECF_CHECK
+    /// if the check point file starts with an absolute path return as is:
+    /// otherwise returns ECF_HOME/ecf_checkpt_file_
+    const std::string& checkPtFilename() const { return ecf_checkpt_file_; }
+
+    /// returns the path of the old checkPointFile. This has a default name set in server_environment.cfg
+    /// but can be overridden by the environment variable ECF_CHECKOLD
+    /// if the check point file starts with an absolute path return as is:
+    /// otherwise returns ECF_HOME/ecf_backup_checkpt_file_
+    const std::string& oldCheckPtFilename() const { return ecf_backup_checkpt_file_; }
+
+    /// returns the checkPt interval. This is the time in seconds, at which point the server
+    /// serializes the defs node tree. This is called the check point file.
+    /// This has a default value set in environment.cfg
+    /// but can be overridden by the environment variable ECF_CHECKINTERVAL
+    /// if set via environment variable it must be convertible to an integer
+    int checkPtInterval() const { return checkPtInterval_; }
+
+    /// set the check point interval. Typically set via client interface
+    /// value should > 0 for valid values.
+    void set_checkpt_interval(int v) {
+        if (v > 0)
+            checkPtInterval_ = v;
+    }
+
+    /// returns the check mode. This specifies options for saving of the checkPoint file:
+    ecf::CheckPt::Mode checkMode() const { return checkMode_; }
+    void set_check_mode(ecf::CheckPt::Mode m) { checkMode_ = m; }
+    std::string check_mode_str() const;
+
+    /// returns the number of seconds at which we should check time dependencies
+    /// this includes evaluating trigger dependencies and submit the corresponding jobs.
+    /// This is set at 60 seconds. But will vary for debug/test purposes only.
+    /// For Testing the state change queued->submitted->active duration < submitJobsInterval
+    /// If this state change happens at the job submission boundary then
+    /// time series can get a skew.
+    int submitJobsInterval() const { return submitJobsInterval_; }
+
+    /// Returns ECF_PRUNE_NODE_LOG as an integer representing days
+    /// Node log/edit history older than this is pruned when loading the checkpoint file
+    /// Default value is 30 days. To alter change config file or set an environment variable.
+    /// A value of 0, means no pruning. i.e keep old edit history .
+    int ecf_prune_node_log() const { return ecf_prune_node_log_; }
+
+    /// returns server variables, as vector of pairs.
+    /// Some of these variables hold environment variables
+    /// Note:: additional variable are created for use by clients, i.e like
+    ///        ECF_PORT(jobs, server, client)
+    ///        ECF_HOST(jobs).   ECF_HOST is the server machine host name
+    void variables(std::vector<std::pair<std::string, std::string>>&) const;
+
+    /// Ask the server to reload file the hold list of users and their access rights
+    /// The white list file is specified by the environment variable ECF_LISTS
+    /// This allows/disallows user access on the live server
+    /// Return true if file is reloaded ok, else false and error message if:
+    /// 	a/ File does not exist
+    ///  	b/ File is empty
+    ///  	c/ Errors in parsing file
+    /// If errors arise the exist user still stay in affect
+    bool reloadWhiteListFile(std::string& errorMsg);
+
+    bool reloadPasswdFile(std::string& errorMsg);
+    bool reloadCustomPasswdFile(std::string& errorMsg);
+
+    /// There are several kinds of authentification:
+    ///     a/ None
+    ///     b/ List mode.   ASCII file based on ECF_LISTS is defined
+    ///     c/ Secure mode. binary file based ECF_PASSWD is defined
+    /// At the moment we will only implement options a/ and b/
+    //
+    /// Returns true if the given user has access to the server, false otherwise
+    bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) const;
+    bool authenticateReadAccess(const std::string& user,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::string& path) const;
+    bool authenticateReadAccess(const std::string& user,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::vector<std::string>& paths) const;
+    bool authenticateWriteAccess(const std::string& user) const;
+    bool authenticateWriteAccess(const std::string& user, const std::string& path) const;
+    bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) const;
+
+    /// return true if help option was selected
+    bool help_option() const { return help_option_; }
+    bool version_option() const { return version_option_; }
+
+    /// debug is enabled via --debug or server invocation
+    bool debug() const { return debug_; }
+    void set_debug(bool f) { debug_ = f; }
+
+    std::string dump() const;
+
+    static std::vector<std::string> expected_variables();
+
+private:
+    void init(int argc, char* argv[], const std::string& path_to_config_file);
+
+    ///  defaults are read from a config file
+    void read_config_file(std::string& log_file_name, const std::string& path_to_config_file);
+
+    /// Get the standard environment variables, overwrite any settings from config file
+    void read_environment_variables(std::string& log_file_name);
+
+    void change_dir_to_ecf_home_and_check_accesibility();
+
+    bool load_whitelist_file(std::string& err) const;
+
+private:
+    ecf::Host host_name_;
+    std::string serverHost_; // must be after host_name_, since used in init
+    int serverPort_;
+    int checkPtInterval_;
+    int checkpt_save_time_alarm_;
+    int submitJobsInterval_;
+    int ecf_prune_node_log_;
+    bool jobGeneration_; // used in debug/test mode only
+    bool debug_;
+    bool help_option_;
+    bool version_option_;
+    ecf::CheckPt::Mode checkMode_;
+    std::string ecfHome_;
+    std::string ecf_checkpt_file_;
+    std::string ecf_backup_checkpt_file_;
+    std::string ecf_pid_;
+    std::string killCmd_;
+    std::string statusCmd_;
+    std::string checkCmd_;
+    std::string urlCmd_;
+    std::string urlBase_;
+    std::string url_;
+    std::string ecf_cmd_;
+    std::string ecf_micro_;
+    std::string ecf_white_list_file_;
+    mutable WhiteListFile white_list_file_;
+
+    std::string ecf_passwd_file_;
+    std::string ecf_passwd_custom_file_;
+    mutable PasswdFile passwd_file_;
+    mutable PasswdFile passwd_custom_file_;
+
+#ifdef ECF_OPENSSL
+    ecf::Openssl ssl_;
+#endif
+
+    boost::asio::ip::tcp tcp_protocol_; // defaults to IPv4 TCP protocol
+    friend class ServerOptions;
+};
+
+#endif /* ecflow_server_ServerEnvironment_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/ServerMain.cpp 5.13.0-1/libs/server/src/ecflow/server/ServerMain.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/ServerMain.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/ServerMain.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,110 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/server/Server.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+#ifdef ECF_OPENSSL
+    #include "ecflow/server/SslServer.hpp"
+#endif
+
+using namespace ecf;
+using namespace std;
+
+///
+/// \brief The Server entrypoint
+///
+
+int run_server(boost::asio::io_service& io_service, const ServerEnvironment& server_environment) {
+    for (;;) {
+        try {
+            /// Start the server
+            /// The io_service::run() call will block until all asynchronous operations
+            /// have finished. While the server is running, there is always at least one
+            /// asynchronous operation outstanding: the asynchronous accept call waiting
+            /// for new incoming connections.
+            io_service.run();
+            if (server_environment.debug())
+                cout << "Normal exit from server\n";
+            break;
+        }
+        catch (std::exception& e) {
+            // deal with errors from the handlers
+            std::string msg = "run_server:: ";
+            msg += e.what();
+            std::cerr << msg << endl;
+            ecf::log(Log::ERR, msg);
+        }
+        if (server_environment.debug())
+            cout << "Server EXITING: <------------------------------------------------ port:"
+                 << server_environment.port() << endl;
+    }
+    return 0;
+}
+
+int main(int argc, char* argv[]) {
+
+    try {
+        // Get the environment settings, and parse argument line and init the log file
+        ServerEnvironment server_environment(argc, argv); // This can throw ServerEnvironmentException
+        if (server_environment.help_option())
+            return 0;
+        if (server_environment.version_option())
+            return 0;
+        std::string errorMsg;
+        if (!server_environment.valid(errorMsg)) {
+            cerr << errorMsg;
+            ecf::log(Log::ERR, errorMsg);
+            return 1;
+        }
+
+        if (server_environment.debug())
+            cout << "Server started: ------------------------------------------------>port:"
+                 << server_environment.port() << endl;
+
+        boost::asio::io_service io_service;
+#ifdef ECF_OPENSSL
+        if (server_environment.ssl()) {
+            SslServer theServer(io_service, server_environment); // This can throw exception, bind address in use.
+            return run_server(io_service, server_environment);
+        }
+        else {
+            Server theServer(io_service, server_environment); // This can throw exception, bind address in use.
+            return run_server(io_service, server_environment);
+        }
+#else
+        Server theServer(io_service, server_environment); // This can throw exception, bind address in use.
+        return run_server(io_service, server_environment);
+#endif
+    }
+    catch (ServerEnvironmentException& e) {
+        // *** deal with server options and environment exceptions
+        std::cerr << "Could not load the server environment or options :\n" << e.what() << "\n";
+        std::cerr << "Invalid locale? Check locale using 'locale -a', then export/set LANG environment\n";
+    }
+    catch (std::exception& e) {
+        // *** deal with errors from the server constructor ****
+        std::string msg = "Exception in ServerMain:: ";
+        msg += e.what();
+        std::cerr << msg << endl;
+        ecf::log(Log::ERR, msg);
+
+        // dump server environment
+        cerr << "\nServer environment:\n";
+        ServerEnvironment server_env(argc, argv); // This can throw ServerEnvironmentException
+        std::cerr << server_env.dump();
+    }
+    catch (...) {
+        std::string msg = "ServerMain:: unknown exception";
+        std::cerr << msg << endl;
+        ecf::log(Log::ERR, msg);
+    }
+    return 1;
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/ServerOptions.cpp 5.13.0-1/libs/server/src/ecflow/server/ServerOptions.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/ServerOptions.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/ServerOptions.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,179 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/ServerOptions.hpp"
+
+#include <iostream>
+
+#include "ecflow/core/Version.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+#ifdef ECF_OPENSSL
+    #include "ecflow/base/Openssl.hpp"
+#endif
+
+using namespace std;
+using namespace ecf;
+namespace po = boost::program_options;
+
+ServerOptions::ServerOptions(int argc, char* argv[], ServerEnvironment* env) {
+    std::stringstream ss;
+    ss << "\n" << Version::description() << "\nServer options";
+    po::options_description desc(ss.str(), po::options_description::m_default_line_length + 80);
+
+    desc.add_options()("help,h",
+                       "The server reads the LANG for the locale. Please ensure that\n"
+                       "locale is valid otherwise the server will abort on startup.\n"
+                       "For a list of valid locale use 'locale -a'.\n"
+                       "\n"
+                       "The server will read the following environment variables:\n"
+                       "ECF_PORT:\n"
+                       "  Defines the port that the server will listen to.\n"
+                       "  The port number must be consistent between client and server\n"
+                       "  If two servers are started on the same machine with same port\n"
+                       "  then a 'Address in use' error is shown and server will exit.\n"
+                       "  The default value for client/server is 3141\n"
+                       "ECF_HOME:\n"
+                       "  This is the home/root for all '.ecf' scripts.\n"
+                       "  When the server starts it will change directory to ECF_HOME,\n"
+                       "  hence the directory must be accessible and writable.\n"
+                       "  The default value is the current working directory\n"
+                       "ECF_LOG:\n"
+                       "  Overrides the name of log file.\n"
+                       "  The default log file name is: <host>.<port>.ecf.log, i.e. machine1.3141.ecf.log\n"
+                       "  this is required since we can have multiple servers for a single machine.\n"
+                       "  Where each server will have a separate port number.\n"
+                       "  Note: Any settings will be prepended with <host>.<port>.\n"
+                       "ECF_CHECK:\n"
+                       "  Defines the name of the check point file.\n"
+                       "  This stores the state of the definition in memory,\n"
+                       "  and allows recovery from crash. By default the server on start up will load\n"
+                       "  the check point file or back up check point file if they exist.\n"
+                       "  The default is <host>.<port>.ecf.check\n"
+                       "  Any settings will be prepended with <host>.<port>.\n"
+                       "ECF_CHECKOLD:\n"
+                       "  The name of the backup checkpoint file\n"
+                       "  default is <host>.<port>.ecf.check.b\n"
+                       "  Any settings will be prepended with <host>.<port>.\n"
+                       "ECF_CHECKINTERVAL:\n"
+                       "  The interval in seconds within the server that the checkpoint file is saved\n"
+                       "  Values less than 60 seconds are not recommended\n"
+                       "  The default value is 120 seconds\n"
+                       "ECF_LISTS:\n"
+                       "  This variable is used to identify a file, that lists the user\n"
+                       "  who can access the server via client commands. Each client command\n"
+                       "  (ignoring child commands, i.e init, complete, event, meter, label, wait)\n"
+                       "  will encode the user name of the process initiating the client request\n"
+                       "  This is then compared with list of users in the ecf.lists file.\n"
+                       "  If this file is empty, then no authentication is done.\n"
+                       "  Each server can potentially have a different list.\n"
+                       "  The default is <host>.<port>.ecf.lists if no ECF_LISTS is specified.\n"
+                       "  Note: If the path to a ecf.lists is specified as i.e /var/tmp/ecflow/ecf.lists\n"
+                       "        then no prefix is added, the path is kept as is.\n"
+                       "        However if 'ECF_LISTS=ecf.lists' then this matches the default, and the\n"
+                       "        server will expect <host>.<port>.ecf.lists \n"
+                       "ECF_TASK_THRESHOLD:\n"
+                       "  The Job generation process is expected to take less than 60 seconds\n"
+                       "  This is used to aid debugging of task taking excessive times for job generation\n"
+                       "  The causes can be:\n"
+                       "    a/ Slow disk I/0, or when server is run an a virtual machine\n"
+                       "    b/ Insufficient memory, when compared to the size of the scripts/definition\n"
+                       "    c/ Large number of jobs submitted at the same time, and/or very large scripts\n"
+                       "  Any task taking longer than the specified time in milliseconds will be logged.\n"
+                       "  WAR:[..] Job generation for task /suite/family/dodgy_task took 5000ms,\n"
+                       "  Exceeds ECF_TASK_THRESHOLD. The default threshold is 4000 milliseconds\n"
+                       "  Note: 1000 milliseconds = 1 second\n"
+                       "    export ECF_TASK_THRESHOLD=1500\n"
+                       "ECF_PRUNE_NODE_LOG:\n"
+                       "  The node log history is stored in memory and written to the checkpoint file as backup.\n"
+                       "  Overtime this can build up. If the server is restored from a checkpoint file, then all\n"
+                       "  node log/edit history older than 30 days is automatically pruned, thus saving space\n"
+                       "  in memory and disk. The environment variable of this name can be used to alter the days.\n"
+                       "  If set to zero all edit history is preserved.\n"
+#ifdef ECF_OPENSSL
+                       "ECF_SSL:\n"
+                       "  Enables encrypted communication between client and server.\n"
+                       "  You will need to ensure open ssl in installed on your system\n"
+                       "  In order to use openssl, we need set up some certificates.\n"
+                       "  (These will be self signed certificates, rather than a certificate authority).\n"
+#endif
+                       "\n"
+                       "These defaults along with several other can be specified in the file\n"
+                       "server_environment.cfg. The file should be placed in the current working\n"
+                       "directory. It can be found in ecFlow source tree under Server/ directory.\n"
+                       "Please read this file to see the available options.\n"
+                       "Note: Environment variables _override_ any settings made in the\n"
+                       "server_environment.cfg file.")(
+        "port",
+        po::value<int>(),
+        "<int> <Allowed range 1024-49151> The socket/port the server is listening too. default = 3141\n"
+        "If set will override the environment variable ECF_PORT")(
+        "ecfinterval", po::value<int>(), "<int> <Allowed range 1-60>  Submit jobs interval. For DEBUG/Test only")(
+        "v6", "Use IPv6 TCP protocol. Default is IPv4")
+#ifdef ECF_OPENSSL
+        ("ssl", ecf::Openssl::ssl_info())
+#endif
+            ("dis_job_gen", "Disable job generation. For DEBUG/Test only.")("debug,d", "Enable debug output.")(
+                "version,v",
+                "Show ecflow version number,boost library version, compiler used and compilation date, then exit");
+
+    po::store(po::parse_command_line(argc, argv, desc), vm_);
+    po::notify(vm_);
+
+    if (vm_.count("help"))
+        cout << desc << "\n";
+
+    if (vm_.count("version")) {
+        cout << Version::description() << "\n";
+    }
+
+    if (vm_.count("debug"))
+        env->debug_ = true;
+
+    if (vm_.count("port")) {
+        if (env->debug_)
+            cout << "ServerOptions:: The port number set to '" << vm_["port"].as<int>() << "'\n";
+        env->serverPort_ = vm_["port"].as<int>();
+    }
+    if (vm_.count("ecfinterval")) {
+        if (env->debug_)
+            cout << "ServerOptions: The ecfinterval set to '" << vm_["ecfinterval"].as<int>() << "'\n";
+        env->submitJobsInterval_ = vm_["ecfinterval"].as<int>();
+    }
+    if (vm_.count("v6")) {
+        if (env->debug_)
+            cout << "ServerOptions: The tcp protocol set to v6\n";
+        env->tcp_protocol_ = boost::asio::ip::tcp::v6();
+    }
+    if (vm_.count("dis_job_gen")) {
+        if (env->debug_)
+            cout << "ServerOptions: The dis_job_gen is set\n";
+        env->jobGeneration_ = false;
+    }
+#ifdef ECF_OPENSSL
+    if (vm_.count("ssl")) {
+        if (env->debug_)
+            cout << "ServerOptions: ssl server \n";
+        env->enable_ssl(); // search server.crt first, then <host>.<port>.crt
+    }
+#endif
+}
+
+bool ServerOptions::help_option() const {
+    if (vm_.count("help"))
+        return true;
+    return false;
+}
+
+bool ServerOptions::version_option() const {
+    if (vm_.count("version"))
+        return true;
+    return false;
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/ServerOptions.hpp 5.13.0-1/libs/server/src/ecflow/server/ServerOptions.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/ServerOptions.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/ServerOptions.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,37 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_ServerOptions_HPP
+#define ecflow_server_ServerOptions_HPP
+
+///
+/// \brief This class will parse the server arguments.
+/// It will update the ServerEnvironment
+///
+
+#include <boost/program_options.hpp>
+class ServerEnvironment;
+
+class ServerOptions {
+public:
+    ServerOptions(int argc, char* argv[], ServerEnvironment*);
+    // Disable copy (and move) semantics
+    ServerOptions(const ServerOptions&)                  = delete;
+    const ServerOptions& operator=(const ServerOptions&) = delete;
+
+    /// return true if help selected, else false
+    bool help_option() const;
+    bool version_option() const;
+
+private:
+    boost::program_options::variables_map vm_;
+};
+
+#endif /*ecflow_server_ServerOptions_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/SslServer.cpp 5.13.0-1/libs/server/src/ecflow/server/SslServer.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/SslServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/SslServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/SslServer.hpp"
+
+#include "ecflow/server/ServerEnvironment.hpp"
+
+SslServer::SslServer(boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
+    : BaseServer(io_service, serverEnv),
+      server_(this, io_service, serverEnv) {
+}
+
+const std::string& SslServer::ssl() const {
+    return serverEnv_.openssl().ssl();
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/SslServer.hpp 5.13.0-1/libs/server/src/ecflow/server/SslServer.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/SslServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/SslServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_SslServer_HPP
+#define ecflow_server_SslServer_HPP
+
+#include "ecflow/server/BaseServer.hpp"
+#include "ecflow/server/SslTcpServer.hpp"
+
+class SslServer : public BaseServer {
+public:
+    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
+    explicit SslServer(boost::asio::io_service& io_service, ServerEnvironment&);
+    ~SslServer() override = default;
+
+private:
+    /// AbstractServer functions
+    const std::string& ssl() const override;
+
+    SslTcpServer server_;
+};
+
+#endif
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/SslTcpServer.cpp 5.13.0-1/libs/server/src/ecflow/server/SslTcpServer.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/SslTcpServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/SslTcpServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,148 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/SslTcpServer.hpp"
+
+#include <iostream>
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+#include "ecflow/server/SslServer.hpp"
+
+using boost::asio::ip::tcp;
+using namespace std;
+using namespace ecf;
+
+SslTcpServer::SslTcpServer(SslServer* server, boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
+    : TcpBaseServer(server, io_service, serverEnv) {
+    server_->stats().ECF_SSL_ = serverEnv.openssl().info();
+
+    serverEnv.openssl().init_for_server();
+
+    start_accept();
+}
+
+void SslTcpServer::start_accept() {
+    if (serverEnv_.debug())
+        cout << "   SslTcpServer::start_accept()" << endl;
+
+    ssl_connection_ptr new_conn =
+        std::make_shared<ssl_connection>(boost::ref(io_service_), boost::ref(serverEnv_.openssl().context()));
+
+    acceptor_.async_accept(new_conn->socket_ll(),
+                           [this, new_conn](const boost::system::error_code& e) { handle_accept(e, new_conn); });
+}
+
+void SslTcpServer::handle_accept(const boost::system::error_code& e, ssl_connection_ptr conn) {
+    if (serverEnv_.debug())
+        cout << "   SslTcpServer::handle_accept" << endl;
+
+    // Check whether the server was stopped by a signal before this completion
+    // handler had a chance to run.
+    if (!acceptor_.is_open()) {
+        if (serverEnv_.debug())
+            cout << "   SslTcpServer::handle_accept:  acceptor is closed, returning" << endl;
+        return;
+    }
+
+    if (!e) {
+        // Read and interpret message from the client
+        conn->socket().async_handshake(
+            boost::asio::ssl::stream_base::server,
+            [this, conn](const boost::system::error_code& error) { this->handle_handshake(error, conn); });
+    }
+    else {
+        if (serverEnv_.debug())
+            cout << "   SslTcpServer::handle_accept " << e.message() << endl;
+        if (e != boost::asio::error::operation_aborted) {
+            // An error occurred. Log it
+            LogToCout toCoutAsWell;
+            LogFlusher logFlusher;
+            LOG(Log::ERR, "   SslTcpServer::handle_accept error occurred  " << e.message());
+        }
+    }
+
+    // Start an accept operation for a new connection.
+    // *NOTE* previously we had *ONLY* called this if there was no errors
+    //        However this would means that server would run out work.
+    //        When there were errors.!
+    // Moved here to follow the examples used in ASIO.
+    // However can this get into an infinite loop ???
+    start_accept();
+}
+
+void SslTcpServer::handle_handshake(const boost::system::error_code& e, ssl_connection_ptr new_conn) {
+    if (serverEnv_.debug())
+        cout << "   SslTcpServer::handle_handshake" << endl;
+
+    if (!e) {
+        // Successfully accepted a new connection. Determine what the
+        // client sent to us. The connection::async_read() function will
+        // automatically. serialise the inbound_request_ data structure for us.
+        new_conn->async_read(inbound_request_, [this, new_conn](const boost::system::error_code& error) {
+            this->handle_read(error, new_conn);
+        });
+    }
+    else {
+        // An error occurred.
+        LogToCout toCoutAsWell;
+        LOG(Log::ERR, "SslTcpServer::handle_handshake: " << e.message());
+    }
+}
+
+void SslTcpServer::handle_read(const boost::system::error_code& e, ssl_connection_ptr conn) {
+    /// Handle completion of a write operation.
+    // **********************************************************************************
+    // This function *must* finish with write, otherwise it ends up being called recursively
+    // ***********************************************************************************
+    if (!e) {
+
+        handle_request(); // populates outbound_response_
+
+        // Always *Reply* back to the client, Otherwise client will get EOF
+        conn->async_write(outbound_response_,
+                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
+    }
+    else {
+        handle_read_error(e); // populates outbound_response_
+        conn->async_write(outbound_response_,
+                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
+    }
+}
+
+void SslTcpServer::handle_write(const boost::system::error_code& e, ssl_connection_ptr conn) {
+    // Handle completion of a write operation.
+    // Nothing to do. The socket will be closed automatically when the last
+    // reference to the connection object goes away.
+    if (serverEnv_.debug())
+        cout << "   SslTcpServer::handle_write: client request " << inbound_request_ << " replying with  "
+             << outbound_response_ << endl;
+
+    if (e) {
+        LogFlusher logFlusher;
+        ecf::LogToCout logToCout;
+        std::stringstream ss;
+        ss << "SslTcpServer::handle_write: " << e.message() << " : for request " << inbound_request_;
+        log(Log::ERR, ss.str());
+        return;
+    }
+
+    // Do any necessary clean up after outbound_response_  has run. i.e like re-claiming memory
+    outbound_response_.cleanup();
+
+    (void)shutdown_socket(conn, "SslTcpServer::handle_write:");
+
+    // If asked to terminate we do it here rather than in handle_read.
+    // So that we have responded to the client.
+    // *HOWEVER* only do this if the request was successful.
+    //           we do this by checking that the out bound response was ok
+    //           i.e a read only user should not be allowed to terminate server.
+    handle_terminate_request();
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/SslTcpServer.hpp 5.13.0-1/libs/server/src/ecflow/server/SslTcpServer.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/SslTcpServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/SslTcpServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_SslTcpServer_HPP
+#define ecflow_server_SslTcpServer_HPP
+
+#include "ecflow/base/ssl_connection.hpp"
+#include "ecflow/server/TcpBaseServer.hpp"
+class SslServer;
+
+class SslTcpServer : public TcpBaseServer {
+public:
+    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
+    explicit SslTcpServer(SslServer*, boost::asio::io_service& io_service, ServerEnvironment&);
+    ~SslTcpServer() = default;
+
+private:
+    /// ssl and connection functions
+    void handle_handshake(const boost::system::error_code& error, ssl_connection_ptr conn);
+
+    /// Handle completion of a accept operation.
+    void handle_accept(const boost::system::error_code& e, ssl_connection_ptr conn);
+
+    /// Handle completion of a write operation.
+    void handle_write(const boost::system::error_code& e, ssl_connection_ptr conn);
+
+    /// Handle completion of a read operation.
+    void handle_read(const boost::system::error_code& e, ssl_connection_ptr conn);
+
+    void start_accept();
+};
+
+#endif /* ecflow_server_SslTcpServer_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/TcpBaseServer.cpp 5.13.0-1/libs/server/src/ecflow/server/TcpBaseServer.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/TcpBaseServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/TcpBaseServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,153 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/TcpBaseServer.hpp"
+
+#include <iostream>
+
+#include "ecflow/base/cts/task/AbortCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/task/CompleteCmd.hpp"      // required to enforce cereal registration
+#include "ecflow/base/cts/task/CtsWaitCmd.hpp"       // required to enforce cereal registration
+#include "ecflow/base/cts/task/EventCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/task/InitCmd.hpp"          // required to enforce cereal registration
+#include "ecflow/base/cts/task/LabelCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/task/MeterCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/task/QueueCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/AlterCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/BeginCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/CFileCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/CSyncCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/CheckPtCmd.hpp"       // required to enforce cereal registration
+#include "ecflow/base/cts/user/ClientHandleCmd.hpp"  // required to enforce cereal registration
+#include "ecflow/base/cts/user/CtsCmd.hpp"           // required to enforce cereal registration
+#include "ecflow/base/cts/user/CtsNodeCmd.hpp"       // required to enforce cereal registration
+#include "ecflow/base/cts/user/DeleteCmd.hpp"        // required to enforce cereal registration
+#include "ecflow/base/cts/user/EditScriptCmd.hpp"    // required to enforce cereal registration
+#include "ecflow/base/cts/user/ForceCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/FreeDepCmd.hpp"       // required to enforce cereal registration
+#include "ecflow/base/cts/user/GroupCTSCmd.hpp"      // required to enforce cereal registration
+#include "ecflow/base/cts/user/LoadDefsCmd.hpp"      // required to enforce cereal registration
+#include "ecflow/base/cts/user/LogCmd.hpp"           // required to enforce cereal registration
+#include "ecflow/base/cts/user/LogMessageCmd.hpp"    // required to enforce cereal registration
+#include "ecflow/base/cts/user/MoveCmd.hpp"          // required to enforce cereal registration
+#include "ecflow/base/cts/user/OrderNodeCmd.hpp"     // required to enforce cereal registration
+#include "ecflow/base/cts/user/PathsCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/PlugCmd.hpp"          // required to enforce cereal registration
+#include "ecflow/base/cts/user/QueryCmd.hpp"         // required to enforce cereal registration
+#include "ecflow/base/cts/user/ReplaceNodeCmd.hpp"   // required to enforce cereal registration
+#include "ecflow/base/cts/user/RequeueNodeCmd.hpp"   // required to enforce cereal registration
+#include "ecflow/base/cts/user/RunNodeCmd.hpp"       // required to enforce cereal registration
+#include "ecflow/base/cts/user/ServerVersionCmd.hpp" // required to enforce cereal registration
+#include "ecflow/base/cts/user/ShowCmd.hpp"          // required to enforce cereal registration
+#include "ecflow/base/cts/user/ZombieCmd.hpp"        // required to enforce cereal registration
+#include "ecflow/base/stc/PreAllocatedReply.hpp"
+#include "ecflow/core/Version.hpp"
+#include "ecflow/server/BaseServer.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+using boost::asio::ip::tcp;
+
+using namespace std;
+using namespace ecf;
+
+TcpBaseServer::TcpBaseServer(BaseServer* server, boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
+    : server_(server),
+      io_service_(io_service),
+      serverEnv_(serverEnv),
+      acceptor_(io_service) {
+    // Open the acceptor with the option to reuse the address (i.e. SO_REUSEADDR).
+    boost::asio::ip::tcp::endpoint endpoint(serverEnv.tcp_protocol(), serverEnv.port());
+    acceptor_.open(endpoint.protocol());
+    acceptor_.set_option(boost::asio::ip::tcp::acceptor::reuse_address(true));
+    acceptor_.bind(endpoint);
+    acceptor_.listen(); // address is use error, when it comes, bombs out here
+}
+
+void TcpBaseServer::handle_request() {
+    // See what kind of message we got from the client
+    if (serverEnv_.debug())
+        std::cout << "   TcpBaseServer::handle_request  : client request " << inbound_request_ << endl;
+
+    try {
+        // Service the in bound request, handling the request will populate the outbound_response_
+        // Note:: Handle request will first authenticate
+        outbound_response_.set_cmd(inbound_request_.handleRequest(server_));
+    }
+    catch (exception& e) {
+        outbound_response_.set_cmd(PreAllocatedReply::error_cmd(e.what()));
+    }
+
+    // Do any necessary clean up after inbound_request_ has run. i.e like re-claiming memory
+    inbound_request_.cleanup();
+}
+
+void TcpBaseServer::handle_read_error(const boost::system::error_code& e) {
+    // An error occurred.
+    // o/ If client has been killed/disconnected/timed out
+    //       TcpServer::handle_read : End of file
+    //
+    // o/ If a *new* client talks to an *old* server, with an unrecognised request/command i.e mixing 4/5 series
+    //    we will see:
+    //       Connection::handle_read_data .............
+    //       TcpServer::handle_read : Invalid argument
+    LogToCout toCoutAsWell;
+    LogFlusher logFlusher;
+    LOG(Log::ERR, "TcpBaseServer::handle_read_error: " << e.message());
+
+    // *Reply* back to the client, This may fail in the client;
+    std::pair<std::string, std::string> host_port = server_->hostPort();
+    std::string msg                               = " ->Server:";
+    msg += host_port.first;
+    msg += "@";
+    msg += host_port.second;
+    msg += " (";
+    msg += Version::raw();
+    msg += ") replied with: ";
+    msg += e.message();
+    outbound_response_.set_cmd(PreAllocatedReply::error_cmd(msg));
+}
+
+void TcpBaseServer::handle_terminate_request() {
+    // If asked to terminate we do it here rather than in handle_read.
+    // So that we have responded to the client.
+    // *HOWEVER* only do this if the request was successful.
+    //           we do this by checking that the out bound response was ok
+    //           i.e a read only user should not be allowed to terminate server.
+    if (inbound_request_.terminateRequest()) {
+        if (serverEnv_.debug())
+            cout << "   <-- TcpBaseServer::handle_terminate_request  exiting server via terminate() port "
+                 << serverEnv_.port() << endl;
+        terminate();
+    }
+}
+
+void TcpBaseServer::terminate() {
+    // The server is terminated by cancelling all outstanding asynchronous
+    // operations. Once all operations have finished the io_service::run() call  will exit.
+    if (serverEnv_.debug())
+        cout << "   Server::terminate(): posting call to Server::handle_terminate" << endl;
+
+    // Post a call to the stop function so that Server::stop() is safe to call from any thread.
+    io_service_.post([this]() { handle_terminate(); });
+}
+
+void TcpBaseServer::handle_terminate() {
+    // if (serverEnv_.debug()) cout << boost::this_thread::get_id() << "   Server::handle_terminate() : cancelling
+    // checkpt and traverser timers, and signals" << endl;
+    if (serverEnv_.debug())
+        cout << "   Server::handle_terminate() : cancelling checkpt and traverser timers, and signals" << endl;
+
+    server_->handle_terminate();
+
+    acceptor_.close();
+
+    // Stop the io_service object's event processing loop. Will cause run to return immediately
+    io_service_.stop();
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/TcpBaseServer.hpp 5.13.0-1/libs/server/src/ecflow/server/TcpBaseServer.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/TcpBaseServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/TcpBaseServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,74 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_TcpBaseServer_HPP
+#define ecflow_server_TcpBaseServer_HPP
+
+#include <boost/asio.hpp>
+
+#include "ecflow/base/ClientToServerRequest.hpp"
+#include "ecflow/base/ServerToClientResponse.hpp"
+#include "ecflow/core/Log.hpp"
+
+class BaseServer;
+class ServerEnvironment;
+
+class TcpBaseServer {
+public:
+    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
+    explicit TcpBaseServer(BaseServer*, boost::asio::io_service& io_service, ServerEnvironment&);
+    ~TcpBaseServer() = default;
+
+    void handle_request();
+    void handle_read_error(const boost::system::error_code& e);
+
+    /// Terminate the server gracefully. Need to cancel all timers, close all sockets
+    /// Server will hang if there are any pending async handlers
+    void handle_terminate_request();
+    void terminate();
+    void handle_terminate();
+
+    template <typename T>
+    bool shutdown_socket(T conn, const std::string& msg) const {
+        // For portable behaviour with respect to graceful closure of a connected socket,
+        // call shutdown() before closing the socket.
+        //
+        //    conn->socket().shutdown(boost::asio::ip::tcp::socket::shutdown_both)
+        // This *CAN* throw an error if the client side socket is not connected. client may have been killed *OR* timed
+        // out i.e "shutdown: Transport endpoint is not connected"
+        //
+        // Since this can happen, instead of throwing, we use non-throwing version & just report it
+        boost::system::error_code ec;
+        conn->socket_ll().shutdown(boost::asio::ip::tcp::socket::shutdown_both, ec);
+        if (ec) {
+            ecf::LogToCout logToCout;
+            ecf::LogFlusher logFlusher;
+            std::stringstream ss;
+            ss << msg << " socket shutdown both failed: " << ec.message() << " : for request " << inbound_request_;
+            ecf::log(ecf::Log::ERR, ss.str());
+            return false;
+        }
+        return true;
+    }
+
+protected:
+    BaseServer* server_;
+    boost::asio::io_service& io_service_;
+    ServerEnvironment& serverEnv_;
+
+    /// The acceptor object used to accept incoming socket connections.
+    boost::asio::ip::tcp::acceptor acceptor_;
+
+    /// The data, typically loaded once, and then sent to many clients
+    ClientToServerRequest inbound_request_;
+    ServerToClientResponse outbound_response_;
+};
+
+#endif /* ecflow_server_TcpBaseServer_HPP */
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/TcpServer.cpp 5.13.0-1/libs/server/src/ecflow/server/TcpServer.cpp
--- 5.12.4-1/libs/server/src/ecflow/server/TcpServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/TcpServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,136 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/server/TcpServer.hpp"
+
+#include <iostream>
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/server/Server.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+using boost::asio::ip::tcp;
+
+using namespace std;
+using namespace ecf;
+
+TcpServer::TcpServer(Server* server, boost::asio::io_service& io_service, ServerEnvironment& serverEnv)
+    : TcpBaseServer(server, io_service, serverEnv) {
+    // timer_.stop(); // for timing of commands.
+
+    start_accept();
+}
+
+void TcpServer::start_accept() {
+    if (serverEnv_.debug())
+        cout << "   TcpServer::start_accept()" << endl;
+    connection_ptr new_conn = std::make_shared<connection>(boost::ref(io_service_));
+    acceptor_.async_accept(new_conn->socket_ll(),
+                           [this, new_conn](const boost::system::error_code& e) { handle_accept(e, new_conn); });
+}
+
+void TcpServer::handle_accept(const boost::system::error_code& e, connection_ptr conn) {
+    if (serverEnv_.debug())
+        cout << "   TcpServer::handle_accept" << endl;
+
+    // Check whether the server was stopped by a signal before this completion
+    // handler had a chance to run.
+    if (!acceptor_.is_open()) {
+        if (serverEnv_.debug())
+            cout << "   TcpServer::handle_accept:  acceptor is closed, returning" << endl;
+        return;
+    }
+
+    if (!e) {
+        // Read and interpret message from the client
+        // Successfully accepted a new connection. Determine what the
+        // client sent to us. The connection::async_read() function will
+        // automatically. serialise the inbound_request_ data structure for us.
+        conn->async_read(inbound_request_,
+                         [this, conn](const boost::system::error_code& error) { this->handle_read(error, conn); });
+    }
+    else {
+        if (serverEnv_.debug())
+            cout << "   TcpServer::handle_accept " << e.message() << endl;
+        if (e != boost::asio::error::operation_aborted) {
+            // An error occurred. Log it
+            LogToCout toCoutAsWell;
+            LogFlusher logFlusher;
+            LOG(Log::ERR, "   TcpServer::handle_accept error occurred  " << e.message());
+        }
+    }
+
+    // Start an accept operation for a new connection.
+    // *NOTE* previously we had *ONLY* called this if there was no errors
+    //        However this would means that server would run out work.
+    //        When there were errors.!
+    // Moved here to follow the examples used in ASIO.
+    // However can this get into an infinite loop ???
+    start_accept();
+}
+
+void TcpServer::handle_read(const boost::system::error_code& e, connection_ptr conn) {
+    // start read
+    // timer_.start();
+
+    /// Handle completion of a write operation.
+    // **********************************************************************************
+    // This function *must* finish with write, otherwise it ends up being called recursively
+    // ***********************************************************************************
+    if (!e) {
+
+        handle_request(); // populates outbound_response_
+        // log(Log::DBG," handle_read()  n"  + timer_.format(3,Str::cpu_timer_format()));
+
+        // start write
+        // timer_.start();
+
+        // Always *Reply* back to the client, Otherwise client will get EOF
+        conn->async_write(outbound_response_,
+                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
+    }
+    else {
+        handle_read_error(e); // populates outbound_response_
+        conn->async_write(outbound_response_,
+                          [this, conn](const boost::system::error_code& error) { this->handle_write(error, conn); });
+    }
+}
+
+void TcpServer::handle_write(const boost::system::error_code& e, connection_ptr conn) {
+    // Handle completion of a write operation.
+    // Nothing to do. The socket will be closed automatically when the last
+    // reference to the connection object goes away.
+    if (serverEnv_.debug())
+        cout << "   TcpServer::handle_write: client request " << inbound_request_ << " replying with  "
+             << outbound_response_ << endl;
+
+    if (e) {
+        LogFlusher logFlusher;
+        ecf::LogToCout logToCout;
+        std::stringstream ss;
+        ss << "TcpServer::handle_write: " << e.message() << " : for request " << inbound_request_;
+        log(Log::ERR, ss.str());
+        return;
+    }
+
+    // Do any necessary clean up after outbound_response_  has run. i.e like re-claiming memory
+    outbound_response_.cleanup();
+
+    (void)shutdown_socket(conn, "TcpServer::handle_write:");
+
+    // If asked to terminate we do it here rather than in handle_read.
+    // So that we have responded to the client.
+    // *HOWEVER* only do this if the request was successful.
+    //           we do this by checking that the out bound response was ok
+    //           i.e a read only user should not be allowed to terminate server.
+    handle_terminate_request();
+
+    // log(Log::DBG," handle_write() "  + timer_.format(3,Str::cpu_timer_format()));
+}
diff -pruN 5.12.4-1/libs/server/src/ecflow/server/TcpServer.hpp 5.13.0-1/libs/server/src/ecflow/server/TcpServer.hpp
--- 5.12.4-1/libs/server/src/ecflow/server/TcpServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/src/ecflow/server/TcpServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,39 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_server_TcpServer_HPP
+#define ecflow_server_TcpServer_HPP
+
+#include "ecflow/base/Connection.hpp"
+#include "ecflow/server/TcpBaseServer.hpp"
+class Server;
+
+class TcpServer : public TcpBaseServer {
+public:
+    /// Constructor opens the acceptor and starts waiting for the first incoming connection.
+    explicit TcpServer(Server*, boost::asio::io_service& io_service, ServerEnvironment&);
+    ~TcpServer() = default;
+
+private:
+    /// Handle completion of a accept operation.
+    void handle_accept(const boost::system::error_code& e, connection_ptr conn);
+
+    /// Handle completion of a write operation.
+    void handle_write(const boost::system::error_code& e, connection_ptr conn);
+
+    /// Handle completion of a read operation.
+    void handle_read(const boost::system::error_code& e, connection_ptr conn);
+
+    void start_accept();
+
+    // boost::timer::cpu_timer timer_; // time_cmds for debug
+};
+
+#endif /* ecflow_server_TcpServer_HPP */
diff -pruN 5.12.4-1/libs/server/test/TestCheckPtSaver.cpp 5.13.0-1/libs/server/test/TestCheckPtSaver.cpp
--- 5.12.4-1/libs/server/test/TestCheckPtSaver.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/test/TestCheckPtSaver.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,132 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/server/CheckPtSaver.hpp"
+
+// TODO: Move the following trace_*_function to a common test module/library
+static void trace_test() {
+    std::cout << "..." << boost::unit_test::framework::current_test_case().full_name() << "\n";
+}
+
+/**
+ * A self cleaning test file, useful to automate test data storage/cleanup, with automatic generation of file names.
+ */
+class TestFile {
+public:
+    /**
+     * Create a handle for a 'non-existent' data file
+     */
+    explicit TestFile(const std::string& basename) : absolute_path_(TestFile::unique_absolute_path(basename)) {}
+
+    /**
+     * Create a handle for a data file, with the given content
+     */
+    TestFile(const std::string& basename, const std::string& content)
+        : absolute_path_(TestFile::unique_absolute_path(basename)) {
+        f_store(absolute_path_.string(), content);
+    }
+    ~TestFile() { fs::remove(absolute_path_); }
+
+    [[nodiscard]] const fs::path& path() const { return absolute_path_; }
+    [[nodiscard]] std::string load() const { return f_load(absolute_path_); }
+
+    static fs::path unique_absolute_path(const std::string& basename) {
+        return fs::absolute(fs::unique_path(basename));
+    }
+
+private:
+    static void f_store(const fs::path& outfile, const std::string& data) {
+        std::ofstream ofs(outfile.string());
+        ofs << data;
+    }
+
+    static std::string f_load(const fs::path& infile) {
+        std::ifstream ifs(infile.string());
+        std::string buffer((std::istreambuf_iterator<char>(ifs)), std::istreambuf_iterator<char>());
+        return buffer;
+    }
+
+private:
+    fs::path absolute_path_;
+};
+
+void handle_store(const fs::path& temporary) {
+    std::ofstream ofs(temporary.string());
+    ofs << "2";
+}
+
+BOOST_AUTO_TEST_SUITE(U_Server)
+
+BOOST_AUTO_TEST_SUITE(T_CheckPtSaver)
+
+BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case0) {
+    trace_test();
+
+    // Case 0: neither current and backup exist
+
+    TestFile current("current_%%%%-%%%%-%%%%"); // Important: no actual file is created
+    TestFile backup("backup_%%%%-%%%%-%%%%");   // Important: no actual file is created
+
+    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
+
+    BOOST_CHECK_EQUAL(current.load(), "2");
+    BOOST_CHECK(!fs::exists(backup.path()));
+}
+
+BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case1) {
+    trace_test();
+
+    // Case 1: current and backup both exist and are non-empty
+
+    TestFile current("current_%%%%-%%%%-%%%%", "1");
+    TestFile backup("backup_%%%%-%%%%-%%%%", "X");
+
+    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
+
+    BOOST_CHECK_EQUAL(current.load(), "2");
+    BOOST_CHECK_EQUAL(backup.load(), "1");
+}
+
+BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case2) {
+    trace_test();
+
+    // Case 2: current and backup both exist, and current is empty
+
+    TestFile current("current_%%%%-%%%%-%%%%", ""); // Important: file is created empty
+    TestFile backup("backup_%%%%-%%%%-%%%%", "X");
+
+    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
+
+    BOOST_CHECK_EQUAL(current.load(), "2");
+    BOOST_CHECK_EQUAL(backup.load(), "X");
+}
+
+BOOST_AUTO_TEST_CASE(test_checkpt_store_successful_case3) {
+    trace_test();
+
+    // Case 3: current exists, but no backup is available
+
+    TestFile current("current_%%%%-%%%%-%%%%", "1");
+    TestFile backup("backup_%%%%-%%%%-%%%%"); // Important: no actual file is created
+
+    CheckPtSaver::storeWithBackup(current.path(), backup.path(), handle_store);
+
+    BOOST_CHECK_EQUAL(current.load(), "2");
+    BOOST_CHECK_EQUAL(backup.load(), "1");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/server/test/TestPeriodicScheduler.cpp 5.13.0-1/libs/server/test/TestPeriodicScheduler.cpp
--- 5.12.4-1/libs/server/test/TestPeriodicScheduler.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/test/TestPeriodicScheduler.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,108 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <array>
+#include <iomanip>
+#include <iostream>
+#include <thread>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/server/PeriodicScheduler.hpp"
+
+std::ostream& operator<<(std::ostream& os, const std::chrono::system_clock::time_point& tp) {
+    // Create time stamp
+    std::time_t time = std::chrono::system_clock::to_time_t(tp);
+    std::tm tm       = *std::gmtime(&time);
+    std::array<char, 100> buffer{};
+    std::strftime(buffer.data(), buffer.size(), "%Y-%m-%dT%H:%M:%S", &tm);
+
+    // Extract milliseconds
+    auto total_seconds = std::chrono::duration_cast<std::chrono::seconds>(tp.time_since_epoch());
+    auto total_millis  = std::chrono::duration_cast<std::chrono::milliseconds>(tp.time_since_epoch());
+    auto millis        = total_millis - std::chrono::duration_cast<std::chrono::milliseconds>(total_seconds);
+
+    os << buffer.data() << "." << std::setw(3) << std::setfill('0') << millis.count();
+
+    return os;
+}
+
+BOOST_AUTO_TEST_SUITE(TestPeriodicScheduler)
+
+struct Collector
+{
+    using instant_t  = ecf::PeriodicScheduler<Collector>::instant_t;
+    using instants_t = std::vector<instant_t>;
+
+    void operator()(instant_t now, instant_t last, instant_t next, bool is_boundary = true) {
+        std::cout << "Call at " << now << ", with is_boundary? " << (is_boundary ? "true" : "false") << ". Last call was at " << last
+                  << ". Next call at " << next << "." << std::endl;
+
+        // Activity must be called at minute boundary!
+        if (is_boundary && !instants.empty()) {
+            auto seconds = std::chrono::duration_cast<std::chrono::seconds>(now.time_since_epoch() % 86400) % 60;
+            BOOST_CHECK(seconds == std::chrono::seconds(0));
+        }
+        instants.push_back(now);
+    }
+
+    instants_t instants;
+};
+
+struct LongLasting
+{
+    using instant_t = ecf::PeriodicScheduler<LongLasting>::instant_t;
+
+    template <typename DURATION>
+    explicit LongLasting(const DURATION& duration) : how_long_{std::chrono::duration_cast<std::chrono::milliseconds>(duration)} {}
+
+    void operator()(instant_t now, instant_t last, instant_t next, bool is_boundary = true) {
+        std::cout << "Call at " << now << ", with is_boundary? " << (is_boundary ? "true" : "false") << ". Last call was at " << last
+                  << ". Next call at " << next << "." << std::endl;
+
+        std::this_thread::sleep_for(how_long_);
+    }
+
+    std::chrono::milliseconds how_long_;
+};
+
+BOOST_AUTO_TEST_CASE(test_periodic_scheduler_over_one_minute) {
+    // Setup time collector
+    Collector collector;
+    boost::asio::io_service io_service;
+    ecf::PeriodicScheduler scheduler(io_service, std::chrono::seconds(30), collector);
+    scheduler.start();
+
+    // Arrange time collector termination
+    ecf::Timer teardown(io_service);
+    teardown.set([&scheduler](const boost::system::error_code& error) { scheduler.terminate(); }, std::chrono::seconds(62));
+
+    // Run services
+    io_service.run();
+
+    BOOST_CHECK_EQUAL(collector.instants.size(), static_cast<size_t>(62));
+}
+
+BOOST_AUTO_TEST_CASE(test_periodic_scheduler_with_long_lasting_activity) {
+    // Setup time collector
+    LongLasting activity{std::chrono::milliseconds(2499)};
+    boost::asio::io_service io_service;
+    ecf::PeriodicScheduler scheduler(io_service, std::chrono::seconds(10), activity);
+    scheduler.start();
+
+    // Arrange time collector termination
+    ecf::Timer teardown(io_service);
+    teardown.set([&scheduler](const boost::system::error_code& error) { scheduler.terminate(); }, std::chrono::seconds(60));
+
+    // Run services
+    io_service.run();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/server/test/TestPeriodicScheduler_main.cpp 5.13.0-1/libs/server/test/TestPeriodicScheduler_main.cpp
--- 5.12.4-1/libs/server/test/TestPeriodicScheduler_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/test/TestPeriodicScheduler_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE TestPeriodicScheduler
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/server/test/TestServer.cpp 5.13.0-1/libs/server/test/TestServer.cpp
--- 5.12.4-1/libs/server/test/TestServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/test/TestServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,210 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/EcfPortLock.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/server/Server.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Server)
+
+BOOST_AUTO_TEST_SUITE(T_Server)
+
+// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+// make public the function we wish to test:
+// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+class TestServer : public Server {
+public:
+    explicit TestServer(boost::asio::io_service& io_service, ServerEnvironment& s) : Server(io_service, s) {}
+    ~TestServer() override = default;
+
+    // abort server if check pt files exist, but can't be loaded
+    //   bool load_check_pt_file_on_startup();
+    //   void loadCheckPtFile();
+    //   bool restore_from_checkpt(const std::string& filename, bool& failed);
+    //   void set_server_state(SState::State);
+
+    /// AbstractServer functions
+    SState::State state() const override { return Server::state(); }
+    std::pair<std::string, std::string> hostPort() const override { return Server::hostPort(); }
+    defs_ptr defs() const override { return Server::defs(); }
+    // virtual void updateDefs(defs_ptr,bool force);
+    void clear_defs() override { Server::clear_defs(); }
+    //   virtual void checkPtDefs(ecf::CheckPt::Mode m = ecf::CheckPt::UNDEFINED,
+    //                               int check_pt_interval = 0,
+    //                               int check_pt_save_time_alarm = 0);
+    void restore_defs_from_checkpt() override { Server::restore_defs_from_checkpt(); }
+    void nodeTreeStateChanged() override { Server::nodeTreeStateChanged(); }
+    bool allowTaskCommunication() const override { return Server::allowTaskCommunication(); }
+    void shutdown() override { Server::shutdown(); }
+    void halted() override { Server::halted(); }
+    void restart() override { Server::restart(); }
+
+    bool reloadWhiteListFile(std::string& errorMsg) override { return Server::reloadWhiteListFile(errorMsg); }
+    bool reloadPasswdFile(std::string& errorMsg) override { return Server::reloadPasswdFile(errorMsg); }
+
+    bool authenticateReadAccess(const std::string& user, bool custom_user, const std::string& passwd) override {
+        return Server::authenticateReadAccess(user, custom_user, passwd);
+    }
+    bool authenticateReadAccess(const std::string& user,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::string& path) override {
+        return Server::authenticateReadAccess(user, custom_user, passwd, path);
+    }
+    bool authenticateReadAccess(const std::string& user,
+                                bool custom_user,
+                                const std::string& passwd,
+                                const std::vector<std::string>& paths) override {
+        return Server::authenticateReadAccess(user, custom_user, passwd, paths);
+    }
+
+    bool authenticateWriteAccess(const std::string& user) override { return Server::authenticateWriteAccess(user); }
+    bool authenticateWriteAccess(const std::string& user, const std::string& path) override {
+        return Server::authenticateWriteAccess(user, path);
+    }
+    bool authenticateWriteAccess(const std::string& user, const std::vector<std::string>& paths) override {
+        return Server::authenticateWriteAccess(user, paths);
+    }
+
+    bool lock(const std::string& user) override { return Server::lock(user); }
+    void unlock() override { Server::unlock(); }
+    const std::string& lockedUser() const override { return Server::lockedUser(); }
+    //   virtual void traverse_node_tree_and_job_generate(const boost::posix_time::ptime& time_now, bool
+    //   user_cmd_context) const;
+    int poll_interval() const override { return Server::poll_interval(); }
+    //   virtual void debug_server_on();
+    //   virtual void debug_server_off();
+    //   virtual bool debug() const;
+};
+
+void test_the_server(const std::string& port) {
+    std::string server_port = "--port=" + port;
+    int argc                = 3;
+    char* argv[]            = {const_cast<char*>("ServerEnvironment"),
+                               const_cast<char*>(server_port.c_str()),
+                               const_cast<char*>("--ecfinterval=12")};
+
+    ServerEnvironment server_environment(argc, argv); // This can throw ServerEnvironmentException
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(server_environment.valid(errorMsg), errorMsg);
+
+    {
+        boost::asio::io_service io_service;
+        TestServer theServer(io_service, server_environment); // This can throw exception, bind address in use.
+
+        BOOST_REQUIRE_MESSAGE(theServer.defs(), "Expected defs to be created");
+
+        const std::vector<Variable>& server_variables = theServer.defs()->server().server_variables();
+        BOOST_REQUIRE_MESSAGE(!server_variables.empty(), "Expected defs to be updated with the server variables");
+
+        // for(size_t i = 0; i < server_variables.size(); ++i)  cout << server_variables[i].dump() << "\n";
+        const std::string& ecf_port = theServer.defs()->server().find_variable("ECF_PORT");
+        BOOST_REQUIRE_MESSAGE(ecf_port == port,
+                              "Expected port " << port << " but found " << ecf_port
+                                               << " defs server variables, should be in sync with server");
+
+        const std::string& interval = theServer.defs()->server().find_variable("ECF_INTERVAL");
+        BOOST_REQUIRE_MESSAGE(interval == "12",
+                              "Expected interval 12 but found "
+                                  << interval << " defs server variables, should be in sync with server");
+        BOOST_REQUIRE_MESSAGE(theServer.poll_interval() == 12,
+                              "Expected poll interval 12 but found " << theServer.poll_interval());
+
+        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::HALTED,
+                              "Expected halted at server start but found " << SState::to_string(theServer.state()));
+        theServer.halted();
+        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::HALTED, "Expected halted ");
+        theServer.shutdown();
+        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::SHUTDOWN, "Expected shutdown ");
+        theServer.restart();
+        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::RUNNING, "Expected shutdown ");
+
+        BOOST_REQUIRE_MESSAGE(theServer.lock("fred"), "Expected to lock user fred");
+        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::SHUTDOWN, "Locking should shutdown server");
+        BOOST_REQUIRE_MESSAGE(theServer.lockedUser() == "fred",
+                              "Expected locked user 'fred' but found " << theServer.lockedUser());
+        theServer.unlock();
+        BOOST_REQUIRE_MESSAGE(theServer.lockedUser().empty(),
+                              "Expected no locked user but found " << theServer.lockedUser());
+        BOOST_REQUIRE_MESSAGE(theServer.state() == SState::RUNNING, "Expected unlock to restart server ");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_server) {
+    cout << "Server:: ...test_server\n";
+
+    // Create a unique port number, allowing debug and release,gnu,clang,intel to run at the same time
+    // Hence the lock file is not always sufficient.
+    // ECF_FREE_PORT should be unique among  gnu,clang,intel, etc
+    std::string the_port1 = "3144";
+    char* test_ecf_port   = getenv("ECF_FREE_PORT"); // from metabuilder, allow parallel tests
+    if (test_ecf_port)
+        the_port1 = test_ecf_port;
+    cout << "  Find free port to start server, starting with port " << the_port1 << "\n";
+
+    auto the_port = ecf::convert_to<int>(the_port1);
+    while (!EcfPortLock::is_free(the_port))
+        the_port++;
+    std::string port = ecf::convert_to<std::string>(the_port);
+    EcfPortLock::create(port);
+    cout << "  Found free port: " << port << " ";
+
+    Host h;
+    int count = 0;
+    while (1) {
+        try {
+            test_the_server(port);
+            cout << "\n";
+            break;
+        }
+        catch (...) {
+            count++;
+
+            // cleanup
+            fs::remove(h.ecf_log_file(port));
+            EcfPortLock::remove(port);
+
+            cout << " : port " << port << " is used, trying next port\n";
+
+            the_port = ecf::convert_to<int>(port);
+            the_port++;
+
+            while (!EcfPortLock::is_free(the_port))
+                the_port++;
+            port = ecf::convert_to<std::string>(the_port);
+            EcfPortLock::create(port);
+            cout << "  Found free port: " << port << "\n";
+
+            BOOST_REQUIRE_MESSAGE(count < 20, "Could not find new port after 20 attempts");
+        }
+    }
+
+    // cleanup
+    fs::remove(h.ecf_log_file(port));
+    EcfPortLock::remove(port);
+
+    /// Destroy Log singleton to avoid valgrind from complaining
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/server/test/TestServerEnvironment.cpp 5.13.0-1/libs/server/test/TestServerEnvironment.cpp
--- 5.12.4-1/libs/server/test/TestServerEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/test/TestServerEnvironment.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,367 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <iostream>
+#include <stdexcept>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/CheckPt.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/JobProfiler.hpp"
+#include "ecflow/server/ServerEnvironment.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(U_Server)
+
+BOOST_AUTO_TEST_SUITE(T_ServerEnvironment)
+
+BOOST_AUTO_TEST_CASE(test_server_environment_ecfinterval) {
+    cout << "Server:: ...test_server_environment_ecfinterval\n";
+
+    // ecflow server interval is valid for range [1-60]
+    std::string port = Str::DEFAULT_PORT_NUMBER();
+    for (int i = -10; i < 70; ++i) {
+        string errorMsg;
+        string argument = "--ecfinterval=" + ecf::convert_to<std::string>(i);
+
+        int argc     = 2;
+        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>(argument.c_str())};
+        ServerEnvironment serverEnv(argc, argv);
+        bool valid = serverEnv.valid(errorMsg);
+        if (i > 0 && i < 61) {
+            BOOST_REQUIRE_MESSAGE(valid, "Server environment ecfinterval valid range is [1-60] " << errorMsg);
+            BOOST_CHECK_MESSAGE(serverEnv.submitJobsInterval() == i,
+                                "Expected submit jobs interval of " << i << " but found "
+                                                                    << serverEnv.submitJobsInterval());
+        }
+        else
+            BOOST_CHECK_MESSAGE(!valid, "Server environment ecfinterval valid range is [1-60] " << errorMsg);
+
+        port = serverEnv.the_port();
+    }
+
+    Host h;
+    fs::remove(h.ecf_log_file(port));
+}
+
+BOOST_AUTO_TEST_CASE(test_server_environment_port) {
+    cout << "Server:: ...test_server_environment_port\n";
+
+    // The port numbers are divided into three ranges.\n";
+    //  o the Well Known Ports, (require root permission)      0 -1023\n";
+    //  o the Registered Ports,                             1024 -49151\n";
+    //  o Dynamic and/or Private Ports.                    49151 -65535\n\n";
+    //  Please set in the range 1024-49151 via argument or \n";
+    Host h;
+    int argc = 2;
+    {
+        std::string errorMsg;
+        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=0")};
+        ServerEnvironment serverEnv(argc, argv);
+        BOOST_CHECK_MESSAGE(!serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
+        fs::remove(h.ecf_log_file(serverEnv.the_port()));
+    }
+    {
+        std::string errorMsg;
+        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=1000")};
+        ServerEnvironment serverEnv(argc, argv);
+        BOOST_CHECK_MESSAGE(!serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
+        fs::remove(h.ecf_log_file(serverEnv.the_port()));
+    }
+    {
+        std::string errorMsg;
+        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=49151")};
+        ServerEnvironment serverEnv(argc, argv);
+        BOOST_CHECK_MESSAGE(!serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
+        fs::remove(h.ecf_log_file(serverEnv.the_port()));
+    }
+
+    {
+        std::string errorMsg;
+        char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=3144")};
+        ServerEnvironment serverEnv(argc, argv);
+        BOOST_CHECK_MESSAGE(serverEnv.valid(errorMsg), " Server environment not valid " << errorMsg);
+        BOOST_CHECK_MESSAGE(serverEnv.port() == 3144, "Expected 3144 but found " << serverEnv.port());
+        fs::remove(h.ecf_log_file(serverEnv.the_port()));
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_server_environment_log_file) {
+    // Regression test log file creation
+    cout << "Server:: ...test_server_environment_log_file\n";
+
+    int argc     = 2;
+    char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=3144")};
+    ServerEnvironment serverEnv(argc, argv);
+
+    BOOST_CHECK_MESSAGE(Log::instance(), "Log singleton not created");
+    BOOST_CHECK_MESSAGE(fs::exists(Log::instance()->path()), "Log file not created");
+
+    // Check that server variable ECF_LOG created and value is correct
+    std::vector<std::pair<std::string, std::string>> server_vars;
+    serverEnv.variables(server_vars);
+
+    bool found_var = false;
+    typedef std::pair<std::string, std::string> mpair;
+    for (const mpair& p : server_vars) {
+        if (Str::ECF_LOG() == p.first) {
+            BOOST_CHECK_MESSAGE(p.second == Log::instance()->path(),
+                                "Expected " << Log::instance()->path() << " but found " << p.second);
+            found_var = true;
+            break;
+        }
+    }
+    BOOST_CHECK_MESSAGE(found_var, "Failed to find server variable ECF_LOG");
+
+    // tear down remove the log file created by ServerEnvironment
+    Host h;
+    fs::remove(h.ecf_log_file(serverEnv.the_port()));
+
+    /// Destroy Log singleton to avoid valgrind from complaining
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_server_config_file) {
+    // Regression test to make sure the server environment variable don't get removed
+    cout << "Server:: ...test_server_config_file\n";
+
+    int argc     = 1;
+    char* argv[] = {const_cast<char*>("ServerEnvironment")};
+
+    ServerEnvironment serverEnv(argc, argv, File::test_data("Server/server_environment.cfg", "Server"));
+
+    std::vector<std::string> expected_variables = ServerEnvironment::expected_variables();
+
+    std::vector<std::pair<std::string, std::string>> server_vars;
+    serverEnv.variables(server_vars);
+    for (const std::string& expected_var : expected_variables) {
+
+        bool found_var = false;
+        typedef std::pair<std::string, std::string> s_pair;
+        for (const s_pair& p : server_vars) {
+            if (expected_var == p.first) {
+                found_var = true;
+                break;
+            }
+        }
+        BOOST_CHECK_MESSAGE(found_var, "Failed to find server var " << expected_var);
+    }
+
+    {
+        // check other way, so that this test gets updated
+        typedef std::pair<std::string, std::string> mpair;
+        for (const mpair& p : server_vars) {
+            bool found_var = false;
+            for (const std::string& expected_var : expected_variables) {
+                if (expected_var == p.first) {
+                    found_var = true;
+                    break;
+                }
+            }
+            BOOST_CHECK_MESSAGE(found_var, "Failed to update test for server var " << p.first);
+        }
+    }
+
+    // Check the values in the server config file, are the *SAME* as the defaults, when config is *NOT* present
+    // Please note do *NOT* use quotes for the values, otherwise quotes get added.
+    // WRONG: ECF_MICRODEF = "%"
+    // RIGHT: ECF_MICRODEF = %
+    // o IGNORE ECF_CHECK: We *ONLY check those value in the config, that should not be altered.
+    //                     since we add root path, and append with host/port
+    // o ignore ECF_CHECKMODE: not a server variable
+    //
+    typedef std::pair<std::string, std::string> mpair;
+    for (const mpair& p : server_vars) {
+        // std::cout << "server variables " << p.first << "  " << p.second << "\n";
+        if (Str::ECF_HOME() == p.first) {
+            BOOST_CHECK_MESSAGE(p.second == fs::current_path().string(),
+                                "for ECF_HOME expected " << fs::current_path().string() << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_PORT") == p.first && !getenv("ECF_PORT")) {
+            BOOST_CHECK_MESSAGE(p.second == Str::DEFAULT_PORT_NUMBER(),
+                                "for ECF_PORT expected " << Str::DEFAULT_PORT_NUMBER() << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_CHECKINTERVAL") == p.first) {
+            std::string expected = ecf::convert_to<std::string>(CheckPt::default_interval());
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_CHECKINTERVAL expected " << CheckPt::default_interval() << " but found "
+                                                                  << p.second);
+            continue;
+        }
+        if (string("ECF_INTERVAL") == p.first) {
+            std::string expected = "60";
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_INTERVAL expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_JOB_CMD") == p.first) {
+            std::string expected = Ecf::JOB_CMD();
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_JOB_CMD expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_KILL_CMD") == p.first) {
+            std::string expected = Ecf::KILL_CMD();
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_KILL_CMD expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_STATUS_CMD") == p.first) {
+            std::string expected = Ecf::STATUS_CMD();
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_STATUS_CMD expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_CHECK_CMD") == p.first) {
+            std::string expected = Ecf::CHECK_CMD();
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_CHECK_CMD expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_URL_CMD") == p.first) {
+            std::string expected = Ecf::URL_CMD();
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_URL_CMD expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_URL_BASE") == p.first) {
+            std::string expected = Ecf::URL_BASE();
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_URL_BASE expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_URL") == p.first) {
+            std::string expected = Ecf::URL();
+            BOOST_CHECK_MESSAGE(p.second == expected, "for ECF_URL expected " << expected << " but found " << p.second);
+            continue;
+        }
+        if (string("ECF_MICRODEF") == p.first) {
+            std::string expected = Ecf::MICRO();
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_MICRODEF expected " << expected << " but found " << p.second);
+            continue;
+        }
+
+        if (string("ECF_PASSWD") == p.first) {
+
+            Host host;
+            std::string port = Str::DEFAULT_PORT_NUMBER();
+            if (getenv("ECF_PORT"))
+                port = getenv("ECF_PORT");
+            std::string expected = host.prefix_host_and_port(port, Str::ECF_PASSWD());
+
+            BOOST_CHECK_MESSAGE(p.second == expected,
+                                "for ECF_PASSWD expected " << expected << " but found " << p.second);
+            continue;
+        }
+    }
+
+    // tear down remove the log file created by ServerEnvironment
+    Host host;
+    fs::remove(host.ecf_log_file(serverEnv.the_port()));
+}
+
+BOOST_AUTO_TEST_CASE(test_server_environment_variables) {
+    // Regression test to make sure the server environment variable don't get removed
+    cout << "Server:: ...test_server_environment_variables\n";
+
+    int argc     = 2;
+    char* argv[] = {const_cast<char*>("ServerEnvironment"), const_cast<char*>("--port=3144")};
+    ServerEnvironment serverEnv(argc, argv);
+
+    std::vector<std::string> expected_variables = ServerEnvironment::expected_variables();
+
+    std::vector<std::pair<std::string, std::string>> server_vars;
+    serverEnv.variables(server_vars);
+    for (const std::string& expected_var : expected_variables) {
+
+        bool found_var = false;
+        typedef std::pair<std::string, std::string> mpair;
+        for (const mpair& p : server_vars) {
+            if (expected_var == p.first) {
+                found_var = true;
+                break;
+            }
+        }
+        BOOST_CHECK_MESSAGE(found_var, "Failed to find server var " << expected_var);
+    }
+
+    // check other way, so that this test gets updated
+    typedef std::pair<std::string, std::string> mpair;
+    for (const mpair& p : server_vars) {
+        bool found_var = false;
+        for (const std::string& expected_var : expected_variables) {
+            if (expected_var == p.first) {
+                found_var = true;
+                break;
+            }
+        }
+        BOOST_CHECK_MESSAGE(found_var, "Failed to update test for server var " << p.first);
+    }
+
+    // tear down remove the log file created by ServerEnvironment
+    Host h;
+    fs::remove(h.ecf_log_file(serverEnv.the_port()));
+
+    /// Destroy Log singleton to avoid valgrind from complaining
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_server_profile_threshold_environment_variable) {
+    cout << "Server:: ...test_server_profile_threshold_environment_variable\n";
+    int argc     = 1;
+    char* argv[] = {const_cast<char*>("ServerEnvironment")};
+    {
+        auto* put = const_cast<char*>("ECF_TASK_THRESHOLD=9");
+        BOOST_CHECK_MESSAGE(putenv(put) == 0, "putenv failed for " << put);
+    }
+    ServerEnvironment serverEnv(argc, argv);
+    BOOST_CHECK_MESSAGE(JobProfiler::task_threshold() == 9,
+                        "Expected task threshold of 9 but found " << JobProfiler::task_threshold());
+
+    // ==================================================================================
+    // Note test for errors
+    vector<string> dodgy_thresholds;
+    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=x");
+    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=,");
+    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=:");
+    dodgy_thresholds.emplace_back("ECF_TASK_THRESHOLD=,,");
+
+    for (auto& dodgy_threshold : dodgy_thresholds) {
+        // cout << "check -------> " << dodgy_thresholds[i] << endl;
+        BOOST_CHECK_MESSAGE(putenv(const_cast<char*>(dodgy_threshold.c_str())) == 0,
+                            "putenv failed for " << dodgy_threshold);
+        BOOST_CHECK_THROW(ServerEnvironment serverEnv(argc, argv), std::runtime_error);
+    }
+
+    unsetenv(const_cast<char*>(
+        "ECF_TASK_THRESHOLD")); // remove from env, otherwise valgrind complains, *AND* affects other tests
+
+    Host h;
+    fs::remove(h.ecf_log_file(serverEnv.the_port()));
+
+    /// Destroy Log singleton to avoid valgrind from complaining
+    Log::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/server/test/TestServer_main.cpp 5.13.0-1/libs/server/test/TestServer_main.cpp
--- 5.12.4-1/libs/server/test/TestServer_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/server/test/TestServer_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Server
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/service/CMakeLists.txt 5.13.0-1/libs/service/CMakeLists.txt
--- 5.12.4-1/libs/service/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,109 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+# ecflow_services
+# --------------------------------------------------
+
+# u_service_executor
+# --------------------------------------------------
+
+ecbuild_add_test(
+  TARGET
+    u_service_executor
+  LABELS
+    unit nightly
+  SOURCES
+    # Sources
+    test/executor/TestExecutor_main.cpp # test entry point
+    test/executor/TestPeriodicTaskExecutor.cpp
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+)
+target_clangformat(u_service_executor
+  CONDITION ENABLE_TESTS
+)
+
+# u_service_auth
+# --------------------------------------------------
+
+ecbuild_add_test(
+  TARGET
+    u_service_auth
+  LABELS
+    unit nightly
+  SOURCES
+    # Headers -- utilities
+    test/TestContentProvider.hpp
+    # Sources -- utilities
+    test/TestContentProvider.cpp
+  # Sources
+    test/auth/TestAuth_main.cpp # test entry point
+    test/auth/TestAuth.cpp
+  INCLUDES
+    test
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+    Boost::filesystem
+)
+target_clangformat(u_service_auth
+  CONDITION ENABLE_TESTS
+)
+
+# u_service_aviso
+# --------------------------------------------------
+
+ecbuild_add_test(
+  TARGET
+    u_service_aviso
+  LABELS
+    unit nightly
+  SOURCES
+    # Headers -- utilities
+    test/TestContentProvider.hpp
+    # Sources -- utilities
+    test/TestContentProvider.cpp
+    # Sources
+    test/aviso/TestAviso_main.cpp # test entry point
+    test/aviso/TestAviso.cpp
+    test/aviso/TestAvisoService.cpp
+  INCLUDES
+    test
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+    Boost::filesystem
+)
+target_clangformat(u_service_aviso
+  CONDITION ENABLE_TESTS
+)
+
+# u_service_mirror
+# --------------------------------------------------
+
+ecbuild_add_test(
+  TARGET
+    u_service_mirror
+  LABELS
+    unit nightly
+  SOURCES
+    # Sources
+    test/mirror/TestMirror_main.cpp # test entry point
+    test/mirror/TestMirror.cpp
+    test/mirror/TestMirrorClient.cpp
+    test/mirror/TestMirrorService.cpp
+  LIBS
+    ecflow_all
+    Boost::boost # Boost header-only libraries must be available (namely unit_test_framework)
+)
+target_clangformat(u_service_mirror
+  CONDITION ENABLE_TESTS
+)
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/Controller.cpp 5.13.0-1/libs/service/src/ecflow/service/Controller.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/Controller.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/Controller.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/Controller.hpp"
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/Controller.hpp 5.13.0-1/libs/service/src/ecflow/service/Controller.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/Controller.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/Controller.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,100 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_Controller_HPP
+#define ecflow_service_Controller_HPP
+
+#include <mutex>
+#include <unordered_map>
+#include <variant>
+#include <vector>
+
+#include "ecflow/service/Log.hpp"
+
+namespace ecf::service {
+
+template <typename Service>
+class Controller {
+public:
+    using service_t       = Service;
+    using subscription_t  = typename service_t::subscription_t;
+    using subscriptions_t = std::vector<subscription_t>;
+    using notification_t  = typename Service::notification_t;
+    using notifications_t = std::vector<notification_t>;
+
+    template <typename... Args>
+    explicit Controller(Args&&... args) : running_{std::forward<Args>(args)...} {}
+
+    // Attribute-facing API
+
+    void subscribe(const subscription_t& s) {
+        SLOG(D, "Controller: subscribe " << s);
+
+        {
+            std::scoped_lock lock(subscribe_);
+            subscriptions_.push_back(s);
+        }
+    }
+
+    notifications_t get_notifications(const std::string& name) {
+        SLOG(D, "Controller::get_notifications for " << name);
+
+        notifications_t found;
+
+        {
+            std::scoped_lock lock(notify_);
+            found = notifications_;
+            notifications_.clear();
+        }
+
+        return found;
+    }
+
+    // Background Thread-facing API
+
+    subscriptions_t get_subscriptions() {
+        SLOG(D, "Controller: collect subscriptions");
+
+        subscriptions_t found;
+        {
+            std::scoped_lock lock(subscribe_);
+            found = subscriptions_;
+            subscriptions_.clear();
+        }
+
+        return found;
+    }
+
+    void notify(const notification_t& notification) {
+        SLOG(D, "Controller: notify " << notification);
+
+        {
+            std::scoped_lock lock(notify_);
+            notifications_.push_back(notification);
+        }
+    }
+
+    void start() { running_.start(); };
+    void stop() { running_.stop(); };
+    void terminate() { running_.terminate(); };
+
+private:
+    std::mutex subscribe_;
+    std::mutex notify_;
+
+    std::vector<subscription_t> subscriptions_;
+    std::vector<notification_t> notifications_;
+
+    service_t running_;
+};
+
+} // namespace ecf::service
+
+#endif /* ecflow_service_Controller_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/Log.hpp 5.13.0-1/libs/service/src/ecflow/service/Log.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/Log.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/Log.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_Log_HPP
+#define ecflow_service_Log_HPP
+
+#include <functional>
+#include <iostream>
+#include <thread>
+
+#include "ecflow/core/Log.hpp"
+
+#define SLOG(LEVEL, MESSAGE)                                                     \
+    [&]() {                                                                      \
+        using namespace ecf::service::log;                                       \
+        LOG(LevelTraits<Level::LEVEL>::mapping_type,                             \
+            MESSAGE << " {" << LevelTraits<Level::LEVEL>::name << "}" << Meta{}); \
+    }()
+
+namespace ecf::service {
+
+namespace log {
+
+enum class Level { D /*ebug*/, I /*nformation*/, W /*arning*/, E /*rror*/, F /*atal*/ };
+
+template <Level L>
+struct LevelTraits;
+
+template <>
+struct LevelTraits<Level::D>
+{
+    static constexpr const char* name               = "D";
+    static constexpr ecf::Log::LogType mapping_type = ecf::Log::LogType::DBG;
+};
+
+template <>
+struct LevelTraits<Level::I>
+{
+    static constexpr const char* name               = "I";
+    static constexpr ecf::Log::LogType mapping_type = ecf::Log::LogType::LOG;
+};
+
+template <>
+struct LevelTraits<Level::W>
+{
+    static constexpr const char* name               = "W";
+    static constexpr ecf::Log::LogType mapping_type = ecf::Log::LogType::WAR;
+};
+
+template <>
+struct LevelTraits<Level::E>
+{
+    static constexpr const char* name               = "E";
+    static constexpr ecf::Log::LogType mapping_type = ecf::Log::LogType::ERR;
+};
+
+template <>
+struct LevelTraits<Level::F>
+{
+    static constexpr const char* name               = "F";
+    static constexpr ecf::Log::LogType mapping_type = ecf::Log::LogType::ERR;
+};
+
+struct Meta
+{
+    std::thread::id id = std::this_thread::get_id();
+};
+
+inline std::ostream& operator<<(std::ostream& os, const Meta& meta) {
+    os << '[' << meta.id << ']';
+    return os;
+}
+
+} // namespace log
+
+} // namespace ecf::service
+
+#endif /* ecflow_service_Log_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/Registry.cpp 5.13.0-1/libs/service/src/ecflow/service/Registry.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/Registry.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/Registry.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/Registry.hpp"
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/Registry.hpp 5.13.0-1/libs/service/src/ecflow/service/Registry.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/Registry.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/Registry.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_Registry_HPP
+#define ecflow_service_Registry_HPP
+
+#include <mutex>
+#include <unordered_map>
+#include <variant>
+#include <vector>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/service/Log.hpp"
+
+namespace ecf::service {
+
+class TheOneServer {
+public:
+    static void set_server(AbstractServer* server) { TheOneServer::instance().server_ = server; }
+    static AbstractServer* server() { return TheOneServer::instance().server_; }
+
+private:
+    TheOneServer() = default;
+
+    static TheOneServer& instance() {
+        static TheOneServer the_one_server;
+        return the_one_server;
+    }
+
+    AbstractServer* server_ = nullptr;
+};
+
+} // namespace ecf::service
+
+#endif /* ecflow_service_Registry_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/auth/Credentials.cpp 5.13.0-1/libs/service/src/ecflow/service/auth/Credentials.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/auth/Credentials.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/auth/Credentials.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,91 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/auth/Credentials.hpp"
+
+#include <fstream>
+
+#include <nlohmann/json.hpp>
+
+#include "ecflow/core/Message.hpp"
+
+namespace ecf::service::auth {
+
+void Credentials::add(std::string key, std::string value) {
+    entries_.push_back({std::move(key), std::move(value)});
+}
+
+std::optional<std::string> Credentials::value(std::string_view key) const {
+    for (const auto& entry : entries_) {
+        if (entry.key == key) {
+            return entry.value;
+        }
+    }
+    return std::nullopt;
+}
+
+std::optional<Credentials::UserCredentials> Credentials::user() const {
+    if (auto username = value("username"); username) {
+        if (auto password = value("password"); password) {
+            return UserCredentials{std::move(*username), std::move(*password)};
+        }
+    }
+    return std::nullopt;
+}
+
+std::optional<Credentials::KeyCredentials> Credentials::key() const {
+    if (auto key = value("key"); key) {
+        return KeyCredentials{std::move(*key)};
+    }
+    return std::nullopt;
+}
+
+namespace {
+
+Credentials load_from_stream(std::istream& input) {
+    using json = nlohmann::ordered_json;
+
+    json content;
+    try {
+        content = json::parse(input);
+    }
+    catch (const json::parse_error& e) {
+        throw std::runtime_error(Message("Credentials: Unable to parse content, due to ", e.what()).str());
+    }
+
+    Credentials credentials;
+    for (auto field: content.items()) {
+        try {
+            credentials.add(field.key(), field.value());
+        } catch (const json::type_error& e) {
+            throw std::runtime_error(Message("Credentials: Unable to retrieve content, due to ", e.what()).str());
+        }
+    }
+
+    if (!credentials.user() && !credentials.key()) {
+        throw std::runtime_error("Credentials: Invalid content found (neither user nor key credentials provided)");
+    }
+
+    return credentials;
+}
+
+} // namespace
+
+Credentials Credentials::load(const std::string& filepath) {
+    std::ifstream stream(filepath);
+    return load_from_stream(stream);
+}
+
+Credentials Credentials::load_content(const std::string& content) {
+    std::istringstream stream(content);
+    return load_from_stream(stream);
+}
+
+} // namespace ecf::service::auth
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/auth/Credentials.hpp 5.13.0-1/libs/service/src/ecflow/service/auth/Credentials.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/auth/Credentials.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/auth/Credentials.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,57 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_auth_Credentials_HPP
+#define ecflow_service_auth_Credentials_HPP
+
+#include <optional>
+#include <string>
+#include <vector>
+
+namespace ecf::service::auth {
+
+class Credentials {
+public:
+    struct UserCredentials
+    {
+        std::string username;
+        std::string password;
+    };
+
+    struct KeyCredentials
+    {
+        std::string key;
+    };
+
+    Credentials() = default;
+
+    void add(std::string key, std::string value);
+
+    [[nodiscard]] std::optional<std::string> value(std::string_view key) const;
+
+    [[nodiscard]] std::optional<UserCredentials> user() const;
+    [[nodiscard]] std::optional<KeyCredentials> key() const;
+
+    static Credentials load(const std::string& filepath);
+    static Credentials load_content(const std::string& content);
+
+private:
+    struct Entry
+    {
+        std::string key;
+        std::string value;
+    };
+
+    std::vector<Entry> entries_;
+};
+
+} // namespace ecf::service::auth
+
+#endif /* ecflow_service_auth_Credentials_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/Aviso.cpp 5.13.0-1/libs/service/src/ecflow/service/aviso/Aviso.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/Aviso.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/Aviso.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,397 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/aviso/Aviso.hpp"
+
+#include <cassert>
+#include <fstream>
+#include <httplib.h>
+#include <iostream>
+#include <memory>
+#include <regex>
+
+#include <nlohmann/json.hpp>
+
+#include "ecflow/core/Overload.hpp"
+#include "ecflow/service/Log.hpp"
+
+namespace ecf::service::aviso {
+
+/* AvisoSubscribe */
+
+std::ostream& operator<<(std::ostream& os, const AvisoSubscribe& request) {
+    os << "AvisoSubscribe{";
+    os << "path: " << request.path();
+    os << ", listener_cfg: " << request.listener_cfg();
+    os << ", address: " << request.address();
+    os << ", schema: " << request.schema();
+    os << ", polling: " << request.polling();
+    os << ", revision: " << request.revision();
+    os << "}";
+    return os;
+}
+
+/* AvisoUnsubscribe */
+
+std::ostream& operator<<(std::ostream& os, const AvisoUnsubscribe& request) {
+    os << "AvisoUnsubscribe{";
+    os << "path: " << request.path();
+    os << "}";
+    return os;
+}
+
+/* AvisoRequest */
+
+std::ostream& operator<<(std::ostream& os, const AvisoRequest& request) {
+    os << "AvisoRequest{";
+    std::visit(
+        ecf::overload{[&os](const AvisoSubscribe& r) { os << r; }, [&os](const AvisoUnsubscribe& r) { os << r; }},
+        request);
+    os << "}";
+    return os;
+}
+
+/* AvisoNotification */
+
+std::ostream& operator<<(std::ostream& os, const AvisoNotification& notification) {
+    os << "AvisoNotification{";
+    os << "key: " << notification.key();
+    os << ", value: " << notification.value();
+    os << ", revision: " << notification.revision();
+    os << "}";
+    return os;
+}
+
+/* AvisoNoMatch */
+
+std::ostream& operator<<(std::ostream& os, const AvisoNoMatch& no_match) {
+    os << "AvisoNoMatch{}";
+    return os;
+}
+
+/* AvisoError */
+
+std::ostream& operator<<(std::ostream& os, const AvisoError& error) {
+    os << "AvisoError{";
+    os << "reason: " << error.reason();
+    os << "}";
+    return os;
+}
+
+/* Listener */
+
+// N/A
+
+/* ConfiguredListener */
+
+ConfiguredListener ConfiguredListener::make_configured_listener(const AvisoSubscribe& listen_request) {
+
+    std::ifstream schema_stream(listen_request.schema());
+
+    return make_configured_listener(listen_request.path(),
+                                    listen_request.listener_cfg(),
+                                    listen_request.address(),
+                                    schema_stream,
+                                    listen_request.polling(),
+                                    listen_request.revision());
+}
+
+ConfiguredListener ConfiguredListener::make_configured_listener(const std::string& path,
+                                                                const std::string& listener_cfg,
+                                                                const std::string& address,
+                                                                const std::string& schema_content,
+                                                                uint32_t polling,
+                                                                uint64_t revision) {
+
+    std::istringstream schema_stream(schema_content);
+
+    return make_configured_listener(path, listener_cfg, address, schema_stream, polling, revision);
+}
+
+ConfiguredListener ConfiguredListener::make_configured_listener(const std::string& path,
+                                                                const std::string& listener_cfg,
+                                                                const std::string& address,
+                                                                std::istream& schema_stream,
+                                                                uint32_t polling,
+                                                                uint64_t revision) {
+    using json = nlohmann::ordered_json;
+
+    json data;
+    try {
+        data = json::parse(listener_cfg);
+    }
+    catch (const json::parse_error& e) {
+        throw std::runtime_error("Failed to parse listener configuration: " + std::string(e.what()) + " " +
+                                 listener_cfg);
+    }
+
+    ListenerSchema schema;
+    try {
+        schema = ListenerSchema::load(schema_stream);
+    }
+    catch (const std::exception& e) {
+        throw std::runtime_error("Failed to load listener schema: " + std::string(e.what()));
+    }
+
+    if (!data.contains("event")) {
+        throw std::runtime_error("Listener configuration does not specify 'event'");
+    }
+    if (!data.contains("request")) {
+        throw std::runtime_error("Listener configuration does not specify 'request'");
+    }
+
+    std::string event    = data["event"];
+    const auto& listener = schema.get_listener(event);
+    if (!listener) {
+        throw std::runtime_error("Listener could not be found in schema");
+    }
+
+    ConfiguredListener configured{address,
+                                  path,
+                                  std::string{listener->name()},
+                                  std::string{listener->base()},
+                                  std::string{listener->stem()},
+                                  polling,
+                                  revision};
+
+    SLOG(I,
+         "Aviso: configured with: " << path << " for " << event << " at " << address << " with revision " << revision);
+
+    auto request = data["request"];
+    for (json::iterator entry = request.begin(); entry != request.end(); ++entry) {
+
+        auto value = entry.value();
+        if (value.is_string()) {
+            configured.with_parameter(entry.key(), value.template get<std::string>());
+        }
+        else if (value.is_number_integer()) {
+            configured.with_parameter(entry.key(), std::to_string(value.template get<int64_t>()));
+        }
+        else if (value.is_array()) {
+            std::vector<std::string> values_as_atrings;
+            for (const auto& v : value) {
+                if (v.is_string()) {
+                    values_as_atrings.push_back(v.template get<std::string>());
+                }
+                else if (v.is_number_integer()) {
+                    values_as_atrings.push_back(std::to_string(v.template get<int64_t>()));
+                }
+                else {
+                    std::terminate(); // Unsupported type!
+                }
+            }
+
+            configured.with_parameter(entry.key(), values_as_atrings);
+        }
+    }
+
+    return configured;
+}
+
+ConfiguredListener::ConfiguredListener(const std::string& address,
+                                       const std::string& path,
+                                       const std::string& name,
+                                       const std::string& base,
+                                       const std::string& stem,
+                                       uint32_t polling,
+                                       uint64_t revision)
+    : Listener(name, base, stem),
+      path_{path},
+      address_{address},
+      resolved_base_{base},
+      polling_{polling},
+      revision_{revision} {
+}
+
+void ConfiguredListener::with_parameter(const std::string& parameter, const std::string& value) {
+    const std::string LBRACE  = R"(\{)";
+    const std::string RBRACE  = R"(\})";
+    const std::string pattern = LBRACE + parameter + RBRACE;
+
+    const auto re = std::regex(pattern);
+
+    resolved_base_         = std::regex_replace(resolved_base_, re, value);
+    parameters_[parameter] = value;
+}
+
+void ConfiguredListener::with_parameter(const std::string& parameter, int64_t value) {
+    with_parameter(parameter, std::to_string(value));
+}
+
+void ConfiguredListener::with_parameter(const std::string& parameter, const std::vector<std::string>& values) {
+    parameters_[parameter] = values;
+}
+
+std::optional<AvisoNotification>
+ConfiguredListener::accepts(const std::string& key, const std::string& value, uint64_t revision) const {
+    // 1. turn `full` key into regex
+    auto original_full = full();
+
+    // A. Find placeholders
+    // TODO can be done only once
+    std::vector<std::string> placeholders;
+    {
+        std::regex re(R"(\{([^}]+)\})");
+
+        auto m_bgn = std::sregex_iterator(std::begin(original_full), std::end(original_full), re);
+        auto m_end = std::sregex_iterator();
+
+        for (auto i = m_bgn; i != m_end; ++i) {
+            std::smatch m = *i;
+            placeholders.push_back(m[1]);
+        }
+    }
+
+    // B. Create matching regex, by replacing placeholders
+    // TODO can be done only once
+    auto replaced_full = full();
+
+    for (const auto& placeholder : placeholders) {
+        const std::string LBRACE  = R"(\{)";
+        const std::string RBRACE  = R"(\})";
+        const std::string pattern = LBRACE + placeholder + RBRACE;
+
+        const auto re = std::regex(pattern);
+
+        const std::string value = R"(([\d\w]*))";
+
+        replaced_full = std::regex_replace(replaced_full, re, value);
+    }
+
+    // C. Extract result from match
+    auto actual_parameters = std::vector<std::pair<std::string, std::string>>{};
+
+    {
+        const auto re = std::regex(replaced_full);
+
+        auto m_bgn = std::sregex_iterator(std::begin(key), std::end(key), re);
+        auto m_end = std::sregex_iterator();
+
+        for (auto i = m_bgn; i != m_end; ++i) {
+            std::smatch m = *i;
+            // SLOG(D, "Extracted parameters:" << m.str());
+            for (size_t i = 1; i != m.size(); ++i) {
+                actual_parameters.emplace_back(placeholders[i - 1], m[i]);
+            }
+        }
+    }
+
+    if (placeholders.size() != actual_parameters.size()) {
+        SLOG(D, "Aviso: Match [✗] --> <Notification> " << key << " = " << value << " (revision: " << revision << ")");
+        return std::nullopt;
+    }
+
+    // D. Check parameters
+    bool applicable = true;
+    {
+        for (const auto& [k, v] : actual_parameters) {
+            // SLOG(D, "-> " << k << " = " << v);
+            if (auto found = parameters_.find(k); found != std::end(parameters_)) {
+
+                auto actual = v;
+
+                auto validate =
+                    ecf::overload{[&actual](const std::string& expected) { return expected == actual; },
+                                  [&actual](std::int64_t expected) { return std::to_string(expected) == actual; },
+                                  [&actual](const std::vector<std::string>& valid) {
+                                      return std::any_of(valid.begin(), valid.end(), [&actual](const auto& expected) {
+                                          return expected == actual;
+                                      });
+                                  }};
+
+                applicable = std::visit(validate, found->second);
+                if (!applicable) {
+                    break;
+                }
+            }
+        }
+    }
+
+    if (applicable) {
+        AvisoNotification notification{key, value, revision};
+        for (const auto& [k, v] : actual_parameters) {
+            notification.add_parameter(k, v);
+        }
+        SLOG(D, "Aviso: Match [✓] --> <Notification> " << key << " = " << value << " (revision: " << revision << ")");
+        return notification;
+    }
+    else {
+        SLOG(D, "Aviso: Match [✗] --> <Notification> " << key << " = " << value << " (revision: " << revision << ")");
+        return std::nullopt;
+    }
+}
+
+std::ostream& operator<<(std::ostream& os, const ConfiguredListener& listener) {
+    os << "ConfiguredListener{";
+    os << "name: " << listener.name();
+    os << ", full: " << listener.full();
+    os << ", path: " << listener.path();
+    os << ", address: " << listener.address();
+    os << ", polling: " << listener.polling();
+    os << ", revision: " << listener.revision() << "}";
+    return os;
+}
+
+/* ListenerSchema */
+
+std::optional<Listener> ListenerSchema::get_listener(const std::string& name) const {
+    if (auto found = listeners_.find(name); found != listeners_.end()) {
+        return found->second;
+    }
+    return std::nullopt;
+}
+
+ListenerSchema ListenerSchema::load_from_string(const std::string& schema_content) {
+    std::istringstream schema_stream(schema_content);
+    return load(schema_stream);
+}
+
+ListenerSchema ListenerSchema::load(const std::string& schema_path) {
+    std::ifstream schema_stream(schema_path);
+    return load(schema_stream);
+}
+
+ListenerSchema ListenerSchema::load(std::istream& schema_stream) {
+    using json = nlohmann::ordered_json;
+
+    json data;
+    try {
+        data = json::parse(schema_stream);
+    }
+    catch (const json::parse_error& e) {
+        throw std::runtime_error("Failed to parse listener schema: " + std::string(e.what()));
+    }
+
+    ListenerSchema schema{};
+
+    for (json::iterator entry = data.begin(); entry != data.end(); ++entry) {
+        if (auto& value = entry.value(); value.is_object() && value.contains("endpoint")) {
+            for (const auto& endpoint : value["endpoint"]) {
+                for (const auto& engine : endpoint["engine"]) {
+                    if (engine == "etcd_rest") {
+                        std::string name = entry.key();
+                        std::string base = endpoint["base"];
+                        std::string stem = endpoint["stem"];
+                        schema.add_listener(Listener(name, base, stem));
+                    }
+                }
+            }
+        }
+    }
+
+    return schema;
+}
+
+void ListenerSchema::add_listener(const Listener& listener) {
+    auto name        = std::string(listener.name());
+    listeners_[name] = listener;
+}
+
+} // namespace ecf::service::aviso
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/Aviso.hpp 5.13.0-1/libs/service/src/ecflow/service/aviso/Aviso.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/Aviso.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/Aviso.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,279 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_aviso_Aviso_HPP
+#define ecflow_service_aviso_Aviso_HPP
+
+#include <cstdint>
+#include <optional>
+#include <string>
+#include <string_view>
+#include <unordered_map>
+#include <variant>
+#include <vector>
+
+namespace ecf::service::aviso {
+
+/**
+ *
+ * An AvisoSubscribe is a request to start listening for notifications based a given configuration.
+ *
+ * This class holds information used to fully configure an Aviso Listener, including:
+ *  - the listener configuration,
+ *  - the address of the ETCD server,
+ *  - the schema used to specify the notifications
+ *
+ */
+class AvisoSubscribe {
+public:
+    explicit AvisoSubscribe(std::string_view path,
+                            std::string_view listener_cfg,
+                            std::string_view address,
+                            std::string_view schema,
+                            uint32_t polling,
+                            uint64_t revision,
+                            std::string_view auth)
+        : path_{path},
+          listener_cfg_{listener_cfg},
+          address_{address},
+          schema_{schema},
+          polling_{polling},
+          revision_{revision},
+          auth_{auth} {}
+
+    const std::string& path() const { return path_; }
+    const std::string& listener_cfg() const { return listener_cfg_; }
+    const std::string& address() const { return address_; }
+    const std::string& schema() const { return schema_; }
+    uint32_t polling() const { return polling_; }
+    uint64_t revision() const { return revision_; }
+    const std::string& auth() const { return auth_; }
+
+    friend std::ostream& operator<<(std::ostream&, const AvisoSubscribe&);
+
+private:
+    std::string path_;
+    std::string listener_cfg_;
+    std::string address_;
+    std::string schema_;
+    uint32_t polling_;
+    uint64_t revision_;
+    std::string auth_;
+};
+
+/**
+ *
+ * An AvisoUnsubscribe is a request to stop listening for notifications.
+ *
+ */
+class AvisoUnsubscribe {
+public:
+    explicit AvisoUnsubscribe(std::string_view path) : path_{path} {}
+
+    const std::string& path() const { return path_; }
+
+    friend std::ostream& operator<<(std::ostream& os, const AvisoUnsubscribe& request);
+
+private:
+    std::string path_;
+};
+
+/**
+ *
+ * An AvisoRequest allows to either subscribe or unsubscribe to notifications.
+ *
+ * n.b. This request is sent from the main thread to the worker thread.
+ *
+ */
+using AvisoRequest = std::variant<AvisoSubscribe, AvisoUnsubscribe>;
+
+std::ostream& operator<<(std::ostream& os, const AvisoRequest& request);
+
+/**
+ *
+ * An AvisoNotification represents a notification of a match found related to a key-value pair in ETCD.
+ *
+ */
+class AvisoNotification {
+public:
+    AvisoNotification() = default;
+    AvisoNotification(std::string_view key, std::string_view value, uint64_t revision)
+        : key_{key},
+          value_{value},
+          revision_{revision},
+          parameters_{} {}
+
+    std::string_view key() const { return key_; }
+    std::string_view value() const { return value_; }
+    uint64_t revision() const { return revision_; }
+
+    void add_parameter(const std::string& parameter, const std::string& value) {
+        parameters_.emplace_back(parameter, value);
+    }
+
+    friend std::ostream& operator<<(std::ostream&, const AvisoNotification&);
+
+private:
+    std::string key_;
+    std::string value_;
+    uint64_t revision_;
+    std::vector<std::pair<std::string, std::string>> parameters_{};
+};
+
+/**
+ *
+ * An AvisoNoMatch represents a notification of successfull polling without any match found.
+ *
+ */
+class AvisoNoMatch {
+    friend std::ostream& operator<<(std::ostream&, const AvisoNoMatch&);
+};
+
+/**
+ *
+ * An AvisoError represents a notification of an error found during polling.
+ *
+ */
+class AvisoError {
+public:
+    explicit AvisoError(std::string_view reason) : reason_{reason} {}
+
+    [[nodiscard]] std::string_view reason() const { return reason_; }
+
+    friend std::ostream& operator<<(std::ostream&, const AvisoError&);
+
+private:
+    std::string reason_;
+};
+
+/**
+ * A Listener represents an Aviso Listener, loaded from the Schema with placeholders as part of the `base` and
+ * `stem`.
+ */
+class Listener {
+public:
+    Listener() = default;
+    Listener(std::string_view name, std::string_view base, std::string_view stem)
+        : name_{name},
+          base_{base},
+          stem_{stem} {}
+
+    std::string_view name() const { return name_; }
+    std::string_view base() const { return base_; }
+    std::string_view stem() const { return stem_; }
+
+    std::string full() const { return base_ + '/' + stem_; }
+
+private:
+    std::string name_{};
+    std::string base_{};
+    std::string stem_{};
+};
+
+/**
+ * A ConfiguredListener is an Aviso Listener with complete configuration, including ETCD server connection data and
+ * all placeholders instantiated.
+ *
+ * A ConfiguredListener object is responsible for connecting to the ETCS server, collect all relevant notifications
+ * and check if any notification matches the listener's configuration.
+ */
+class ConfiguredListener : private Listener {
+public:
+    /**
+     * Create a ConfiguredListener from an AvisoRequest.
+     *
+     * @param request The AvisoRequest to create the ConfiguredListener from.
+     * @return The ConfiguredListener.
+     */
+    static ConfiguredListener make_configured_listener(const AvisoSubscribe& request);
+
+    static ConfiguredListener make_configured_listener(const std::string& path,
+                                                       const std::string& listener_cfg,
+                                                       const std::string& address,
+                                                       const std::string& schema_content,
+                                                       uint32_t polling,
+                                                       uint64_t revision);
+
+    static ConfiguredListener make_configured_listener(const std::string& path,
+                                                       const std::string& listener_cfg,
+                                                       const std::string& address,
+                                                       std::istream& schema_stream,
+                                                       uint32_t polling,
+                                                       uint64_t revision);
+
+public:
+    ConfiguredListener(const std::string& address,
+                       const std::string& path,
+                       const std::string& name,
+                       const std::string& base,
+                       const std::string& stem,
+                       uint32_t polling,
+                       uint64_t revision);
+
+    void with_parameter(const std::string& parameter, const std::string& value);
+    void with_parameter(const std::string& parameter, int64_t value);
+    void with_parameter(const std::string& parameter, const std::vector<std::string>& value);
+
+    const std::string& path() const { return path_; }
+    const std::string& address() const { return address_; }
+
+    uint32_t polling() const { return polling_; }
+    uint64_t revision() const { return revision_; }
+    void update_revision(uint64_t revision) { revision_ = std::max(revision, revision_); }
+
+    using Listener::base;
+    using Listener::name;
+    using Listener::stem;
+
+    using Listener::full;
+
+    const std::string& resolved_base() const { return resolved_base_; }
+
+    std::string prefix() const { return resolved_base_ + '/'; }
+
+    std::optional<AvisoNotification> accepts(const std::string& key, const std::string& value, uint64_t revision) const;
+
+    friend std::ostream& operator<<(std::ostream& os, const ConfiguredListener& listener);
+
+private:
+    std::string path_;
+    std::string address_;
+    std::string resolved_base_;
+    uint32_t polling_;
+    uint64_t revision_;
+
+    using parameters_t = std::variant<std::string, std::int64_t, std::vector<std::string>>;
+    std::unordered_map<std::string, parameters_t> parameters_ = {};
+};
+
+/**
+ * A ListenerSchema is the specification of available Listeners.
+ *
+ * The specification of each Listener, describes the name, the base and the stem (with eventual placeholders).
+ * The specification is loaded from a schema file.
+ */
+class ListenerSchema {
+public:
+    std::optional<Listener> get_listener(const std::string& name) const;
+
+    static ListenerSchema load_from_string(const std::string& schema_content);
+
+    static ListenerSchema load(const std::string& schema_path);
+    static ListenerSchema load(std::istream& schema_stream);
+
+private:
+    void add_listener(const Listener& listener);
+
+    std::unordered_map<std::string, Listener> listeners_{};
+};
+
+} // namespace ecf::service::aviso
+
+#endif /* ecflow_service_aviso_Aviso_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/AvisoService.cpp 5.13.0-1/libs/service/src/ecflow/service/aviso/AvisoService.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/AvisoService.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/AvisoService.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,166 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/aviso/AvisoService.hpp"
+
+#include "ecflow/core/Overload.hpp"
+#include "ecflow/service/Registry.hpp"
+#include "ecflow/service/auth/Credentials.hpp"
+#include "ecflow/service/aviso/etcd/Client.hpp"
+
+namespace ecf::service::aviso {
+
+std::ostream& operator<<(std::ostream& os, const AvisoResponse& r) {
+    std::visit(ecf::overload{[&os](const NotificationPackage<ConfiguredListener, AvisoNotification>& p) { os << p; },
+                             [&os](const AvisoNoMatch& a) { os << a; },
+                             [&os](const AvisoError& a) { os << a; }},
+               r);
+    return os;
+}
+
+void AvisoService::start() {
+
+    // Update list of listeners
+
+    auto new_subscriptions = subscribe_();
+    for (auto&& subscription : new_subscriptions) {
+        std::visit(ecf::overload{[this](const AvisoSubscribe& subscription) { this->register_listener(subscription); },
+                                 [this](const AvisoUnsubscribe& subscription) {
+                                     this->unregister_listener(subscription.path());
+                                 }},
+                   subscription);
+    }
+
+    // Start polling...
+
+    std::uint32_t expiry = 40;
+
+    if (!listeners_.empty()) {
+        std::vector<std::uint32_t> polling_intervals;
+        auto found = std::max_element(std::begin(listeners_), std::end(listeners_), [](const auto& a, const auto& b) {
+            return a.listener().polling() < b.listener().polling();
+        });
+        expiry     = found->listener().polling();
+    }
+
+    SLOG(D, "AvisoService: start polling, with polling interval: " << expiry << " s");
+    executor_.start(std::chrono::seconds{expiry});
+}
+
+void AvisoService::operator()(const std::chrono::system_clock::time_point& now) {
+
+    // Update list of listeners
+
+    auto new_subscriptions = subscribe_();
+    for (auto&& subscription : new_subscriptions) {
+        std::visit(ecf::overload{[this](const AvisoSubscribe& subscription) { this->register_listener(subscription); },
+                                 [this](const AvisoUnsubscribe& subscription) {
+                                     this->unregister_listener(subscription.path());
+                                 }},
+                   subscription);
+    }
+
+    // Check notification for each listener
+    {
+        for (auto& entry : listeners_) {
+            SLOG(D,
+                 "AvisoService: polling " << entry.listener().address() << " for Aviso " << entry.listener().path()
+                                          << " (key: " << entry.listener().prefix()
+                                          << ", rev: " << entry.listener().revision() << ")");
+
+            // Poll notifications on the key prefix
+
+            std::vector<std::pair<std::string, std::string>> updated_keys;
+            try {
+                // For the associated host(+port)
+                aviso::etcd::Client client{entry.listener().address(), entry.auth_token};
+                updated_keys = client.poll(entry.listener().prefix(), entry.listener().revision() + 1);
+            }
+            catch (const std::exception& e) {
+                notify_(AvisoError(e.what())); // Notification regarding failure to contact the server
+                return;
+            }
+
+            auto matched = false;
+            // Pass updated keys to the listener
+            for (auto&& [key, value] : updated_keys) {
+                if (key == "latest_revision") {
+                    auto revision = value;
+                    SLOG(D, "AvisoService: updating revision for " << entry.listener().path() << " to " << revision);
+                    entry.listener().update_revision(std::stoll(value));
+                    SLOG(D,
+                         "AvisoService: revision for " << entry.listener().path() << " is now "
+                                                       << entry.listener().revision());
+                    continue;
+                }
+
+                if (auto notification = entry.listener().accepts(key, value, entry.listener().revision());
+                    notification) {
+                    NotificationPackage<ConfiguredListener, AvisoNotification> n{
+                        std::string{entry.listener().path()}, entry.listener(), *notification};
+                    notify_(n); // Notification regarding a successful match
+                    matched = true;
+                }
+            }
+
+            if (!matched) {
+                notify_(AvisoNoMatch{}); // Notification regarding no match
+            }
+        }
+    }
+}
+
+void AvisoService::register_listener(const AvisoSubscribe& listen) {
+    auto listener   = ConfiguredListener::make_configured_listener(listen);
+    auto address    = listener.address();
+    auto key_prefix = listener.prefix();
+
+    SLOG(D, "AvisoService: creating listener {" << listener.path() << ", " << address << ", " << key_prefix << "}");
+
+    auto& inserted = listeners_.emplace_back(listener);
+
+    if (auto auth = listen.auth(); !auth.empty()) {
+        auto credentials = ecf::service::auth::Credentials::load(auth);
+        if (auto key_credentials = credentials.key(); key_credentials) {
+            inserted.auth_token = key_credentials->key;
+        }
+        else {
+            SLOG(I, "AvisoService: no key found in auth token for listener {" << listener.path() << "}");
+        }
+    }
+}
+
+void AvisoService::unregister_listener(const std::string& unlisten_path) {
+
+    SLOG(D, "AvisoService: removing listener: {" << unlisten_path << "}");
+
+    listeners_.erase(
+        std::remove_if(std::begin(listeners_),
+                       std::end(listeners_),
+                       [&unlisten_path](auto&& entry) { return entry.listener().path() == unlisten_path; }),
+        std::end(listeners_));
+}
+
+AvisoController::AvisoController()
+    : base_t{[this](const AvisoController::notification_t& notification) {
+                 this->notify(notification);
+
+                 if (auto* server = TheOneServer::server(); server) {
+                     // The following forces the server to increment the job generation count and traverse the defs
+                     server->increment_job_generation_count();
+                 }
+                 else {
+                     SLOG(E, "AvisoController: no server available, thus unable to increment job generation count");
+                 }
+             },
+             [this]() { return this->get_subscriptions(); }} {
+}
+
+} // namespace ecf::service::aviso
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/AvisoService.hpp 5.13.0-1/libs/service/src/ecflow/service/aviso/AvisoService.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/AvisoService.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/AvisoService.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,119 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_AvisoService_HPP
+#define ecflow_service_AvisoService_HPP
+
+#include <mutex>
+#include <optional>
+#include <unordered_map>
+#include <variant>
+#include <vector>
+
+#include "ecflow/base/AbstractServer.hpp"
+#include "ecflow/service/Controller.hpp"
+#include "ecflow/service/Log.hpp"
+#include "ecflow/service/aviso/Aviso.hpp"
+#include "ecflow/service/executor/PeriodicTaskExecutor.hpp"
+
+namespace ecf::service::aviso {
+
+template <typename Configuration, typename Notification>
+struct NotificationPackage
+{
+    std::string path;
+    Configuration configuration;
+    Notification notification;
+};
+
+using AvisoResponse =
+    std::variant<NotificationPackage<ConfiguredListener, AvisoNotification>, AvisoNoMatch, AvisoError>;
+
+template <typename Configuration, typename Notification>
+inline std::ostream& operator<<(std::ostream& os, const NotificationPackage<Configuration, Notification>& p) {
+    return os << "NotificationPackage{" << p.path << ", " << p.configuration << ", " << p.notification << "}";
+}
+
+std::ostream& operator<<(std::ostream& os, const AvisoResponse& r);
+
+class AvisoService {
+public:
+    using schema_path_t = std::string;
+    using key_prefix_t  = std::string;
+    using listener_t    = ConfiguredListener;
+    using revision_t    = int64_t;
+
+    using notification_t  = AvisoResponse;
+    using subscription_t  = AvisoRequest;
+    using subscriptions_t = std::vector<subscription_t>;
+
+    struct Entry
+    {
+        explicit Entry(const listener_t& listener) : auth_token{}, listener_{listener} {}
+
+        const listener_t& listener() const { return listener_; }
+        listener_t& listener() { return listener_; }
+
+        std::string auth_token;
+
+    private:
+        listener_t listener_;
+    };
+
+    using storage_t            = std::vector<Entry>;
+    using notify_callback_t    = std::function<void(const AvisoService::notification_t&)>;
+    using subscribe_callback_t = std::function<subscriptions_t()>;
+
+    AvisoService(notify_callback_t notify, subscribe_callback_t subscribe)
+        : executor_{[this](const std::chrono::system_clock::time_point& now) { this->operator()(now); }},
+          listeners_{},
+          notify_{notify},
+          subscribe_{subscribe} {};
+    AvisoService()                    = delete;
+    AvisoService(const AvisoService&) = delete;
+    ~AvisoService() { stop(); }
+
+    AvisoService& operator=(const AvisoService&) = delete;
+
+    void start();
+    void stop() { executor_.stop(); }
+    void terminate() { executor_.stop(); }
+
+    void operator()(const std::chrono::system_clock::time_point& now);
+
+private:
+    void register_listener(const AvisoSubscribe& request);
+    void unregister_listener(const std::string& unlisten_path);
+
+    executor::PeriodicTaskExecutor<std::function<void(const std::chrono::system_clock::time_point& now)>> executor_;
+    storage_t listeners_;
+
+    notify_callback_t notify_;
+    subscribe_callback_t subscribe_;
+};
+
+class AvisoController : private Controller<AvisoService> {
+public:
+    using base_t = Controller<AvisoService>;
+
+public:
+    AvisoController();
+
+    using base_t::get_notifications;
+    using base_t::notify;
+    using base_t::start;
+    using base_t::stop;
+    using base_t::subscribe;
+    using base_t::terminate;
+};
+
+} // namespace ecf::service::aviso
+
+#endif /* ecflow_service_Registry_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Client.cpp 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Client.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Client.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Client.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/aviso/etcd/Client.hpp"
+
+#include <cassert>
+#include <fstream>
+#include <iostream>
+#include <memory>
+#include <regex>
+
+#include <nlohmann/json.hpp>
+
+#include "ecflow/core/Message.hpp"
+#include "ecflow/service/Log.hpp"
+#include "ecflow/service/aviso/etcd/Range.hpp"
+
+namespace ecf::service::aviso::etcd {
+
+Client::Client(const std::string& address) : client_(address), address_(address), auth_token_() {
+}
+
+Client::Client(const std::string& address, const std::string& auth_token)
+    : client_(address),
+      address_(address),
+      auth_token_(auth_token) {
+}
+
+Client::~Client() = default;
+
+std::vector<std::pair<std::string, std::string>> Client::poll(std::string_view key_prefix, int64_t revision) {
+    using json = nlohmann::ordered_json;
+
+    httplib::Headers headers;
+
+    if (!auth_token_.empty()) {
+        SLOG(D, "EtcdClient: using authorization token");
+        headers.emplace("Authorization", "Bearer " + auth_token_);
+    }
+
+    auto range = Range(key_prefix);
+
+    std::string request_body =
+        json::object({{"key", range.base64_begin()}, {"range_end", range.base64_end()}, {"min_mod_revision", revision}})
+            .dump();
+    std::string content_type = "application/json";
+
+    httplib::Result result = client_.Post(endpoint_path, headers, request_body, content_type);
+    if (!result) {
+        throw std::runtime_error(Message("EtcdClient: Unable to retrieve result, due to ", result.error()).str());
+    }
+
+    if (result.value().status != 200) {
+        throw std::runtime_error(Message("EtcdClient: Failed to poll, due to ", result.value().reason).str());
+    }
+
+    json response_body;
+    try {
+        response_body = json::parse(std::begin(result.value().body), std::end(result.value().body));
+    }
+    catch (const json::parse_error& e) {
+        throw std::runtime_error(Message("EtcdClient: Unable to parse response, due to ", e.what()).str());
+    }
+
+    std::vector<std::pair<std::string, std::string>> entries;
+
+    if (response_body.contains("header")) {
+        auto latest_revision = response_body["header"]["revision"];
+        entries.emplace_back("latest_revision", latest_revision);
+    }
+
+    if (response_body.contains("kvs")) {
+        for (const auto& kv : response_body["kvs"]) {
+            auto k     = kv["key"];
+            auto key   = make_content_from<Base64>(k);
+            auto v     = kv["value"];
+            auto value = make_content_from<Base64>(v);
+
+            if (key.raw() != key_prefix) {
+                SLOG(D, "EtcdClient: Received key+value: " << key.raw() << "+" << value.raw());
+                entries.emplace_back(key.raw(), value.raw());
+            }
+        }
+    }
+    else {
+        SLOG(D, "EtcdClient: No new key+value found");
+    }
+
+    return entries;
+}
+
+} // namespace ecf::service::aviso::etcd
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Client.hpp 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Client.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Client.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Client.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,55 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_aviso_etcd_Client_HPP
+#define ecflow_service_aviso_etcd_Client_HPP
+
+#if defined(ECF_OPENSSL)
+    #include <openssl/ssl.h>
+    #if OPENSSL_VERSION_NUMBER < 0x1010100fL
+        #warning OpenSSL versions prior to 1.1.1 detected. Aviso ETCD HTTP client will be build without OpenSSL support!
+    #else
+        #define CPPHTTPLIB_OPENSSL_SUPPORT
+    #endif
+#endif
+
+#include <httplib.h>
+#include <memory>
+#include <string>
+#include <vector>
+
+namespace ecf::service::aviso::etcd {
+
+class Client {
+public:
+    Client(const std::string& address);
+    Client(const std::string& address, const std::string& auth_token);
+
+    Client(const Client&) = delete;
+    Client(Client&&)      = delete;
+
+    ~Client();
+
+    const std::string& address() const { return address_; }
+    const std::string& auth_token() const { return auth_token_; }
+
+    std::vector<std::pair<std::string, std::string>> poll(std::string_view key_prefix, int64_t revision);
+
+private:
+    httplib::Client client_;
+    std::string address_;
+    std::string auth_token_;
+
+    inline static const std::string endpoint_path = "/v3/kv/range";
+};
+
+} // namespace ecf::service::aviso::etcd
+
+#endif /* ecflow_service_aviso_etcd_Client_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Range.cpp 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Range.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Range.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Range.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,50 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/aviso/etcd/Range.hpp"
+
+#include <boost/algorithm/string.hpp>
+#include <boost/archive/iterators/base64_from_binary.hpp>
+#include <boost/archive/iterators/binary_from_base64.hpp>
+#include <boost/archive/iterators/transform_width.hpp>
+
+namespace ecf::service::aviso::etcd {
+
+std::string Content::decode_base64(const std::string& val) {
+    using namespace boost::archive::iterators;
+    using It = transform_width<binary_from_base64<std::string::const_iterator>, 8, 6>;
+    return boost::algorithm::trim_right_copy_if(std::string(It(std::begin(val)), It(std::end(val))),
+                                                [](char c) { return c == '\0'; });
+}
+
+std::string Content::decode_base64(std::string_view val) {
+    std::string v{val};
+    return decode_base64(v);
+}
+
+std::string Content::encode_base64(const std::string& val) {
+    using namespace boost::archive::iterators;
+    using It = base64_from_binary<transform_width<std::string::const_iterator, 6, 8>>;
+    auto tmp = std::string(It(std::begin(val)), It(std::end(val)));
+    return tmp.append((3 - val.size() % 3) % 3, '=');
+}
+
+std::string Content::encode_base64(std::string_view val) {
+    std::string v{val};
+    return encode_base64(v);
+}
+
+Range::key_t Range::increment_last_byte(key_t val) {
+    assert(!val.empty());
+    val[val.size() - 1]++;
+    return val;
+}
+
+} // namespace ecf::service::aviso::etcd
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Range.hpp 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Range.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/aviso/etcd/Range.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/aviso/etcd/Range.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,95 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_aviso_ectd_Range_HPP
+#define ecflow_service_aviso_ectd_Range_HPP
+
+#include <string>
+#include <string_view>
+
+namespace ecf::service::aviso::etcd {
+
+struct Raw;
+struct Base64;
+
+class Content {
+public:
+    using content_t      = std::string;
+    using content_view_t = std::string_view;
+
+    const content_t& raw() const { return raw_; }
+    content_t base64() const { return encode_base64(raw_); }
+
+    template <typename tag>
+    friend Content make_content_from(Content::content_view_t content);
+
+private:
+    static std::string decode_base64(const std::string& val);
+    static std::string decode_base64(std::string_view val);
+
+    static std::string encode_base64(const std::string& val);
+    static std::string encode_base64(std::string_view val);
+
+private:
+    explicit Content(content_view_t raw) : raw_{raw} {}
+
+    content_t raw_;
+};
+
+template <typename tag>
+inline Content make_content_from(Content::content_view_t content);
+
+template <>
+inline Content make_content_from<Raw>(Content::content_view_t content) {
+    return Content(content);
+}
+
+template <>
+inline Content make_content_from<Base64>(Content::content_view_t content) {
+    auto raw = Content::decode_base64(content);
+    return make_content_from<Raw>(raw);
+}
+
+template <typename tag>
+inline Content make_content_from(const Content::content_t& content);
+
+template <>
+inline Content make_content_from<Raw>(const Content::content_t& content) {
+    return make_content_from<Raw>(std::string_view{content});
+}
+
+template <>
+inline Content make_content_from<Base64>(const Content::content_t& content) {
+    return make_content_from<Base64>(std::string_view{content});
+}
+
+class Range {
+public:
+    using key_t      = std::string;
+    using key_view_t = std::string_view;
+
+    explicit Range(key_view_t key)
+        : range_bgn(make_content_from<Raw>(key)),
+          range_end(make_content_from<Raw>(increment_last_byte(range_bgn.raw()))) {}
+
+    key_t base64_begin() const { return range_bgn.base64(); }
+    key_t base64_end() const { return range_end.base64(); }
+
+private:
+    static key_t increment_last_byte(key_t val);
+
+private:
+    Content range_bgn;
+    Content range_end;
+};
+
+} // namespace ecf::service::aviso::etcd
+
+#endif /* ecflow_service_aviso_etcd_Range_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/executor/PeriodicTaskExecutor.hpp 5.13.0-1/libs/service/src/ecflow/service/executor/PeriodicTaskExecutor.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/executor/PeriodicTaskExecutor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/executor/PeriodicTaskExecutor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,85 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_executor_PeriodicTaskExecutor_HPP
+#define ecflow_service_executor_PeriodicTaskExecutor_HPP
+
+#include <atomic>
+#include <chrono>
+#include <stdexcept>
+#include <thread>
+#include <vector>
+
+namespace ecf::service::executor {
+
+struct InvalidExecutorArgument : public std::runtime_error
+{
+    using std::runtime_error::runtime_error;
+};
+
+template <typename TASK>
+class PeriodicTaskExecutor {
+public:
+    explicit PeriodicTaskExecutor(TASK task) : running_{false}, worker_{}, task_{std::move(task)} {}
+    PeriodicTaskExecutor(const PeriodicTaskExecutor&)            = delete;
+    PeriodicTaskExecutor(PeriodicTaskExecutor&&)                 = delete;
+    PeriodicTaskExecutor& operator=(const PeriodicTaskExecutor&) = delete;
+    PeriodicTaskExecutor& operator=(PeriodicTaskExecutor&&)      = delete;
+    ~PeriodicTaskExecutor() { stop(); }
+
+    void stop() {
+        if (running_) {
+            running_ = false;
+            worker_.join();
+        }
+    }
+
+    template <typename DURATION>
+    void start(DURATION expiry) {
+        if (expiry < liveness_) {
+            throw InvalidExecutorArgument("PeriodicTaskExecutor: expiry must be greater than liveness");
+        }
+
+        start_   = std::chrono::system_clock::now();
+        next_    = start_;
+        running_ = true;
+
+        worker_ = std::thread([this, expiry]() {
+            while (running_) {
+                auto now = std::chrono::system_clock::now();
+                if (now < next_) {
+                    std::this_thread::sleep_for(liveness_);
+                }
+                else {
+                    this->task_(now);
+                    if (!running_) {
+                        break;
+                    }
+                    next_ = now + expiry;
+                }
+            }
+        });
+    }
+
+private:
+    std::chrono::system_clock::duration liveness_ = std::chrono::milliseconds(250);
+    // the liveness is the amount of time to wait before checking if the executor should stop
+
+    std::chrono::system_clock::time_point start_;
+    std::chrono::system_clock::time_point next_;
+    std::atomic<bool> running_;
+
+    std::thread worker_;
+    TASK task_;
+};
+
+} // namespace ecf::service::executor
+
+#endif /* ecflow_service_executor_PeriodicTaskExecutor_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/mirror/Mirror.cpp 5.13.0-1/libs/service/src/ecflow/service/mirror/Mirror.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/mirror/Mirror.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/mirror/Mirror.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,49 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/mirror/Mirror.hpp"
+
+namespace ecf::service::mirror {
+
+/* MirrorRequest */
+
+std::ostream& operator<<(std::ostream& os, const MirrorRequest& r) {
+    os << "MirrorRequest{";
+    os << "path=" << r.path << ", ";
+    os << "host=" << r.host << ", ";
+    os << "port=" << r.port << ", ";
+    os << "polling=" << r.polling << ", ";
+    os << "ssl=" << r.ssl << ", ";
+    os << "auth=" << r.auth << "}";
+    return os;
+}
+
+/* MirrorNotification */
+
+std::ostream& operator<<(std::ostream& os, const MirrorNotification& n) {
+    os << "MirrorNotification{" << n.path() << ", " << n.status() << "}";
+    return os;
+}
+
+/* MirrorError */
+
+std::ostream& operator<<(std::ostream& os, const MirrorError& n) {
+    os << "MirrorError{" << n.path() << n.reason() << "}";
+    return os;
+}
+
+/* MirrorResponse */
+
+std::ostream& operator<<(std::ostream& os, const MirrorResponse& r) {
+    std::visit([&os](const auto& v) { os << v; }, r);
+    return os;
+}
+
+} // namespace ecf::service::mirror
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/mirror/Mirror.hpp 5.13.0-1/libs/service/src/ecflow/service/mirror/Mirror.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/mirror/Mirror.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/mirror/Mirror.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,96 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_mirror_Mirror_HPP
+#define ecflow_service_mirror_Mirror_HPP
+
+#include <string>
+#include <string_view>
+
+#include "ecflow/service/Controller.hpp"
+#include "ecflow/service/executor/PeriodicTaskExecutor.hpp"
+#include "ecflow/service/mirror/MirrorClient.hpp"
+
+namespace ecf::service::mirror {
+
+/**
+ *
+ * A MirrorRequest is a request to start listening for state notifications from remote ecFlow server.
+ *
+ */
+class MirrorRequest {
+public:
+    std::string path;
+    std::string host;
+    std::string port;
+    std::uint32_t polling;
+    bool ssl;
+    std::string auth;
+
+    friend std::ostream& operator<<(std::ostream&, const MirrorRequest&);
+};
+
+/**
+ *
+ * A MirrorNotification is a notification of a state change in a remote ecFlow server.
+ *
+ */
+class MirrorNotification {
+public:
+    MirrorNotification(std::string_view path, int status) : path_(path), status_(status) {}
+
+    const std::string& path() const { return path_; }
+    int status() const { return status_; }
+
+    friend std::ostream& operator<<(std::ostream&, const MirrorNotification&);
+
+private:
+    std::string path_;
+    int status_;
+};
+
+/**
+ *
+ * A MirrorError is a notification that an error occurred when contacting a remote ecFlow server.
+ *
+ */
+class MirrorError {
+public:
+    explicit MirrorError(std::string_view path, std::string_view reason)
+        : path_(path),
+          reason_{get_reason_line(reason)} {}
+
+    const std::string& path() const { return path_; }
+    const std::string& reason() const { return reason_; }
+
+    friend std::ostream& operator<<(std::ostream&, const MirrorError&);
+
+private:
+    inline std::string get_reason_line(std::string_view full_reason) {
+        auto selected = full_reason.substr(0, full_reason.find_first_of("\n"));
+        return std::string{"'"} + std::string{selected} + "'";
+    }
+
+    std::string path_;
+    std::string reason_;
+};
+
+/**
+ *
+ * A MirrorResponse is a notification of either state change or an error.
+ *
+ */
+using MirrorResponse = std::variant<MirrorNotification, MirrorError>;
+
+std::ostream& operator<<(std::ostream&, const MirrorResponse&);
+
+} // namespace ecf::service::mirror
+
+#endif /* ecflow_service_mirror_Mirror_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorClient.cpp 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorClient.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorClient.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorClient.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,81 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/mirror/MirrorClient.hpp"
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/Message.hpp"
+#include "ecflow/core/PasswordEncryption.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/service/Log.hpp"
+
+namespace ecf::service::mirror {
+/* MirrorClient */
+
+struct MirrorClient::Impl
+{
+    std::shared_ptr<Defs> defs_;
+    ClientInvoker invoker_;
+};
+
+MirrorClient::MirrorClient() : impl_(std::make_unique<Impl>()) {
+}
+
+MirrorClient::~MirrorClient() = default;
+
+int MirrorClient::get_node_status(const std::string& remote_host,
+                                  const std::string& remote_port,
+                                  const std::string& node_path,
+                                  bool ssl,
+                                  const std::string& remote_username,
+                                  const std::string& remote_password) const {
+    SLOG(D, "MirrorClient: Accessing " << remote_host << ":" << remote_port << ", path=" << node_path);
+    SLOG(D, "MirrorClient: Authentication Credentials:  " << remote_username << ":" << remote_password);
+
+    try {
+        impl_ = std::make_unique<Impl>();
+        impl_->invoker_.set_host_port(remote_host, remote_port);
+        if (ssl) {
+            impl_->invoker_.enable_ssl();
+        }
+        if (!remote_username.empty()) {
+            impl_->invoker_.set_user_name(remote_username);
+        }
+        if (!remote_password.empty()) {
+            // Extremely important: the password actually needs to be encrypted before being set in the invoker!
+            impl_->invoker_.set_password(PasswordEncryption::encrypt(remote_password, remote_username));
+        }
+
+        SLOG(D, "MirrorClient: retrieving the latest defs");
+        impl_->invoker_.sync(impl_->defs_);
+
+        if (!impl_->defs_) {
+            SLOG(E, "MirrorClient: unable to sync with remote defs");
+            throw std::runtime_error("MirrorClient: Failed to sync with remote defs");
+        }
+
+        auto node = impl_->defs_->findAbsNode(node_path);
+
+        if (!node) {
+            throw std::runtime_error(
+                Message("MirrorClient: Unable to find requested node (", node_path, ") in remote remote defs").str());
+        }
+
+        auto state = node->state();
+        SLOG(D, "MirrorClient: found node (" << node_path << "), with state " << state);
+        return state;
+    }
+    catch (std::exception& e) {
+        throw std::runtime_error(Message("MirrorClient: failure to sync remote defs, due to: ", e.what()));
+    }
+}
+
+} // namespace ecf::service::mirror
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorClient.hpp 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorClient.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorClient.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorClient.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_mirror_MirrorClient_HPP
+#define ecflow_service_mirror_MirrorClient_HPP
+
+#include <memory>
+#include <string>
+
+namespace ecf::service::mirror {
+
+class MirrorClient {
+public:
+    MirrorClient();
+    ~MirrorClient();
+
+    int get_node_status(const std::string& remote_host,
+                        const std::string& remote_port,
+                        const std::string& node_path,
+                        bool ssl,
+                        const std::string& remote_username,
+                        const std::string& remote_password) const;
+
+private:
+    struct Impl;
+    mutable std::unique_ptr<Impl> impl_;
+};
+
+} // namespace ecf::service::mirror
+
+#endif /* ecflow_service_mirror_MirrorClient_HPP */
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorService.cpp 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorService.cpp
--- 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorService.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorService.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,128 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/service/mirror/MirrorService.hpp"
+
+#include <thread>
+#include <utility>
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/Message.hpp"
+#include "ecflow/core/Overload.hpp"
+#include "ecflow/core/PasswordEncryption.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/service/Log.hpp"
+#include "ecflow/service/Registry.hpp"
+#include "ecflow/service/auth/Credentials.hpp"
+
+namespace ecf::service::mirror {
+
+/* MirrorService */
+
+void MirrorService::start() {
+
+    // Update list of listeners
+
+    auto new_subscriptions = subscribe_();
+    for (auto&& subscription : new_subscriptions) {
+        try {
+            register_listener(subscription);
+        }
+        catch (std::runtime_error& e) {
+            SLOG(E, "MirrorService: Unable to register listener: " << e.what());
+            // TODO[MB]: Must gracefully handle this error, by notifying the main thread and providing a reason
+        }
+    }
+
+    // Start polling...
+
+    std::uint32_t expiry = 40;
+
+    if (!listeners_.empty()) {
+        std::vector<std::uint32_t> polling_intervals;
+        auto found = std::max_element(std::begin(listeners_), std::end(listeners_), [](const auto& a, const auto& b) {
+            return a.mirror_request_.polling < b.mirror_request_.polling;
+        });
+        expiry     = found->mirror_request_.polling;
+    }
+
+    SLOG(D, "MirrorService: start polling, with polling interval: " << expiry << " s");
+    executor_.start(std::chrono::seconds{expiry});
+}
+
+void MirrorService::operator()(const std::chrono::system_clock::time_point& now) {
+
+    // Check notification for each listener
+    {
+        for (auto& entry : listeners_) {
+            SLOG(D,
+                 "MirrorService: Mirroring " << entry.mirror_request_.path << " node from "
+                                             << entry.mirror_request_.host << ":" << entry.mirror_request_.port);
+
+            auto remote_path = entry.mirror_request_.path;
+            auto remote_host = entry.mirror_request_.host;
+            auto remote_port = entry.mirror_request_.port;
+            auto ssl         = entry.mirror_request_.ssl;
+            auto remote_user = entry.remote_username_;
+            auto remote_pass = entry.remote_password_;
+
+            // Collect the latest remote status
+            try {
+                auto latest_status =
+                    mirror_.get_node_status(remote_host, remote_port, remote_path, ssl, remote_user, remote_pass);
+
+                SLOG(D, "MirrorService: Notifying remote node state: " << latest_status);
+                MirrorNotification notification{remote_path, latest_status};
+                notify_(notification);
+            }
+            catch (std::runtime_error& e) {
+                SLOG(W, "MirrorService: Failed to sync with remote node: " << e.what());
+                MirrorError error{remote_path, e.what()};
+                notify_(error);
+            }
+        }
+    }
+}
+
+void MirrorService::register_listener(const MirrorRequest& request) {
+    SLOG(D, "MirrorService: Registering Mirror: {" << request.path << "}");
+    Entry& inserted = listeners_.emplace_back(Entry{request, "", ""});
+    if (!request.auth.empty()) {
+        SLOG(D, "MirrorService: Loading auth {" << request.auth << "}");
+        try {
+            auto credentials = ecf::service::auth::Credentials::load(request.auth);
+            if (auto user = credentials.user(); user) {
+                inserted.remote_username_ = user->username;
+                inserted.remote_password_ = user->password;
+            }
+        }
+        catch (std::runtime_error& e) {
+            throw std::runtime_error("MirrorService: Unable to load auth credentials");
+        }
+    }
+}
+
+MirrorController::MirrorController()
+    : base_t{[this](const MirrorService::notification_t& notification) {
+                 this->notify(notification);
+
+                 if (auto* server = TheOneServer::server(); server) {
+                     // The following forces the server to increment the job generation count and traverse the defs
+                     server->increment_job_generation_count();
+                 }
+                 else {
+                     SLOG(E, "MirrorController: no server available, thus unable to increment job generation count");
+                 }
+             },
+             [this]() { return this->get_subscriptions(); }} {
+}
+
+} // namespace ecf::service::mirror
diff -pruN 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorService.hpp 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorService.hpp
--- 5.12.4-1/libs/service/src/ecflow/service/mirror/MirrorService.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/src/ecflow/service/mirror/MirrorService.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,98 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_service_mirror_MirrorService_HPP
+#define ecflow_service_mirror_MirrorService_HPP
+
+#include <optional>
+#include <string>
+
+#include "ecflow/service/Controller.hpp"
+#include "ecflow/service/executor/PeriodicTaskExecutor.hpp"
+#include "ecflow/service/mirror/Mirror.hpp"
+#include "ecflow/service/mirror/MirrorClient.hpp"
+
+namespace ecf::service::mirror {
+
+/**
+ *
+ * The MirrorService is a service (i.e. an object that executes a background worker thread)
+ * that listens for state changes in remote ecFlow servers.
+ *
+ */
+class MirrorService {
+public:
+    using notification_t  = MirrorResponse;
+    using subscription_t  = MirrorRequest;
+    using subscriptions_t = std::vector<subscription_t>;
+
+    struct Entry
+    {
+        MirrorRequest mirror_request_;
+        std::string remote_username_;
+        std::string remote_password_;
+    };
+
+    using storage_t            = std::vector<Entry>;
+    using notify_callback_t    = std::function<void(const notification_t& notification)>;
+    using subscribe_callback_t = std::function<subscriptions_t()>;
+
+    MirrorService(notify_callback_t notify, subscribe_callback_t subscribe)
+        : executor_{[this](const std::chrono::system_clock::time_point& now) { this->operator()(now); }},
+          listeners_{},
+          notify_{notify},
+          subscribe_{subscribe},
+          mirror_{} {};
+    MirrorService()                     = delete;
+    MirrorService(const MirrorService&) = delete;
+    ~MirrorService() { stop(); }
+
+    MirrorService& operator=(const MirrorService&) = delete;
+
+    void start();
+    void stop() { executor_.stop(); }
+    void terminate() { executor_.stop(); }
+
+    void operator()(const std::chrono::system_clock::time_point& now);
+
+private:
+    void register_listener(const MirrorRequest& request);
+
+    executor::PeriodicTaskExecutor<std::function<void(const std::chrono::system_clock::time_point& now)>> executor_;
+    storage_t listeners_;
+
+    notify_callback_t notify_;
+    subscribe_callback_t subscribe_;
+
+    MirrorClient mirror_;
+};
+
+/**
+ *
+ * The MirrorController is a controller for the MirrorService,
+ * and essentially defines the handlers for subscription and notification.
+ *
+ */
+class MirrorController : public Controller<MirrorService> {
+public:
+    using base_t = Controller<MirrorService>;
+
+    MirrorController();
+
+    using base_t::notify;
+    using base_t::start;
+    using base_t::stop;
+    using base_t::subscribe;
+    using base_t::terminate;
+};
+
+} // namespace ecf::service::mirror
+
+#endif /* ecflow_service_mirror_MirrorService_HPP */
diff -pruN 5.12.4-1/libs/service/test/TestContentProvider.cpp 5.13.0-1/libs/service/test/TestContentProvider.cpp
--- 5.12.4-1/libs/service/test/TestContentProvider.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/TestContentProvider.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,61 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "TestContentProvider.hpp"
+
+#include <array>
+#include <cstdio>
+#include <fstream>
+
+#include <boost/filesystem.hpp>
+
+namespace ecf::test {
+
+namespace {
+
+std::string make_temp_filename(std::string file_name_prefix) {
+    file_name_prefix += "XXXXXX";
+    std::array<char, 4096> file_name_template{};
+    std::copy(file_name_prefix.begin(), file_name_prefix.end(), file_name_template.data());
+    mkstemp(file_name_template.data());
+    return file_name_template.data();
+}
+
+void store_content_to_file(const std::string& file_path, const std::string& content) {
+    std::ofstream file(file_path);
+    if (file.is_open()) {
+        file << content;
+    }
+    else {
+        throw std::runtime_error("Failed to open temporary file: " + file_path);
+    }
+}
+
+void clear_content_from_file(const std::string& file_path) {
+    boost::filesystem::remove(file_path);
+}
+
+} // namespace
+
+TestContentProvider::TestContentProvider(const std::string& file_name_prefix) {
+    file_ = make_temp_filename(file_name_prefix);
+    store_content_to_file(file_, "");
+}
+
+TestContentProvider::TestContentProvider(const std::string& file_name_prefix, const std::string& content) {
+    file_ = make_temp_filename(file_name_prefix);
+    store_content_to_file(file_, content);
+}
+
+TestContentProvider::~TestContentProvider() {
+    clear_content_from_file(file_);
+}
+
+} // namespace ecf::test
diff -pruN 5.12.4-1/libs/service/test/TestContentProvider.hpp 5.13.0-1/libs/service/test/TestContentProvider.hpp
--- 5.12.4-1/libs/service/test/TestContentProvider.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/TestContentProvider.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,39 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef test_ecflow_service_aviso_TestContentProvider_HPP
+#define test_ecflow_service_aviso_TestContentProvider_HPP
+
+#include <string>
+
+namespace ecf::test {
+
+class TestContentProvider {
+public:
+    TestContentProvider()                                       = delete;
+    TestContentProvider(const TestContentProvider&)             = delete;
+    TestContentProvider(TestContentProvider&&)                  = delete;
+    TestContentProvider& operator=(const TestContentProvider&)  = delete;
+    TestContentProvider& operator=(const TestContentProvider&&) = delete;
+
+    explicit TestContentProvider(const std::string& file_name_prefix);
+    explicit TestContentProvider(const std::string& file_name_prefix, const std::string& content);
+
+    ~TestContentProvider();
+
+    [[nodiscard]] const std::string& file() const { return file_; }
+
+private:
+    std::string file_;
+};
+
+} // namespace ecf::test
+
+#endif // test_ecflow_service_aviso_TestContentProvider_HPP
diff -pruN 5.12.4-1/libs/service/test/auth/TestAuth.cpp 5.13.0-1/libs/service/test/auth/TestAuth.cpp
--- 5.12.4-1/libs/service/test/auth/TestAuth.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/auth/TestAuth.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,213 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestContentProvider.hpp"
+#include "ecflow/service/auth/Credentials.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Auth)
+
+BOOST_AUTO_TEST_SUITE(T_Credentials)
+
+BOOST_AUTO_TEST_CASE(can_create_default_credentials) {
+    using namespace ecf::service::auth;
+
+    Credentials credentials;
+
+    auto found = credentials.value("inexistent");
+    BOOST_CHECK(!found.has_value());
+}
+
+BOOST_AUTO_TEST_CASE(can_retrieve_existing_key) {
+    using namespace ecf::service::auth;
+
+    Credentials credentials;
+    credentials.add("key", "value");
+
+    auto found = credentials.value("key");
+    BOOST_CHECK(found.has_value());
+    BOOST_CHECK_EQUAL(found.value(), "value");
+}
+
+BOOST_AUTO_TEST_CASE(throw_exceptions_when_unable_to_parse_credentials) {
+    using namespace ecf::service::auth;
+
+    std::string content = R"(
+        {
+            INVALID JSON
+        }
+    )";
+
+    BOOST_CHECK_EXCEPTION(Credentials::load_content(content), std::runtime_error, [](const std::runtime_error& e) {
+        return std::string{e.what()}.find("Credentials: Unable to parse content, due to ") != std::string::npos;
+    });
+}
+
+BOOST_AUTO_TEST_CASE(throw_exceptions_when_invalid_content_found) {
+    using namespace ecf::service::auth;
+
+    // Doesn't provide neither 'key' nor 'username'+'password'
+    std::string content = R"(
+        {
+            "url": "http://address:1234",
+            "email": "user@host.int"
+        }
+    )";
+
+    BOOST_CHECK_EXCEPTION(Credentials::load_content(content), std::runtime_error, [](const std::runtime_error& e) {
+        return std::string{e.what()}.find("Credentials: Invalid content found") != std::string::npos;
+    });
+}
+
+BOOST_AUTO_TEST_CASE(can_load_credentials_with_key) {
+    using namespace ecf::service::auth;
+
+    // Doesn't provide neither 'key' nor 'username'+'password'
+    std::string content = R"(
+        {
+            "url": "http://address:1234",
+            "key": "00000000111111110000000011111111",
+            "email": "user@host.int"
+        }
+    )";
+
+    auto credentials = Credentials::load_content(content);
+
+    {
+        auto found = credentials.key();
+        BOOST_CHECK(found);
+        BOOST_CHECK_EQUAL(found->key, "00000000111111110000000011111111");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_load_credentials_with_username_and_password) {
+    using namespace ecf::service::auth;
+
+    // Doesn't provide neither 'key' nor 'username'+'password'
+    std::string content = R"(
+        {
+            "url": "http://address:1234",
+            "username": "user",
+            "password": "pass",
+            "email": "user@host.int"
+        }
+    )";
+
+    auto credentials = Credentials::load_content(content);
+
+    {
+        auto found = credentials.user();
+        BOOST_CHECK(found);
+        BOOST_CHECK_EQUAL(found->username, "user");
+        BOOST_CHECK_EQUAL(found->password, "pass");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_load_credentials_with_key_and_username_and_password) {
+    using namespace ecf::service::auth;
+
+    // Doesn't provide neither 'key' nor 'username'+'password'
+    std::string content = R"(
+        {
+            "url": "http://address:1234",
+            "key": "00000000111111110000000011111111",
+            "username": "user",
+            "password": "pass",
+            "email": "user@host.int"
+        }
+    )";
+
+    auto credentials = Credentials::load_content(content);
+
+    {
+        auto found = credentials.key();
+        BOOST_CHECK(found);
+        BOOST_CHECK_EQUAL(found->key, "00000000111111110000000011111111");
+    }
+
+    {
+        auto found = credentials.user();
+        BOOST_CHECK(found);
+        BOOST_CHECK_EQUAL(found->username, "user");
+        BOOST_CHECK_EQUAL(found->password, "pass");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_credentials_with_array_type) {
+    using namespace ecf::service::auth;
+
+    // Doesn't provide neither 'key' nor 'username'+'password'
+    std::string content = R"(
+        {
+            "url": "http://address:1234",
+            "key": ["00000000111111110000000011111111", "11111111000000001111111100000000"],
+            "email": "user@host.int"
+        }
+    )";
+
+    BOOST_CHECK_EXCEPTION(Credentials::load_content(content), std::runtime_error, [](const std::runtime_error& e) {
+        return std::string{e.what()}.find("Credentials: Unable to retrieve content, due to") != std::string::npos;
+    });
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_credentials_with_object_type) {
+    using namespace ecf::service::auth;
+
+    // Doesn't provide neither 'key' nor 'username'+'password'
+    std::string content = R"(
+        {
+            "url": "http://address:1234",
+            "key": {},
+            "email": "user@host.int"
+        }
+    )";
+
+    BOOST_CHECK_EXCEPTION(Credentials::load_content(content), std::runtime_error, [](const std::runtime_error& e) {
+        return std::string{e.what()}.find("Credentials: Unable to retrieve content, due to") != std::string::npos;
+    });
+}
+
+BOOST_AUTO_TEST_CASE(can_load_credentials_from_file) {
+    using namespace ecf::test;
+    using namespace ecf::service::auth;
+
+    // Doesn't provide neither 'key' nor 'username'+'password'
+    std::string content = R"(
+        {
+            "url": "http://address:1234",
+            "key": "00000000111111110000000011111111",
+            "username": "user",
+            "password": "pass",
+            "email": "user@host.int"
+        }
+    )";
+
+    TestContentProvider provider("credentials", content);
+
+    auto credentials = Credentials::load(provider.file());
+
+    {
+        auto found = credentials.key();
+        BOOST_CHECK(found);
+        BOOST_CHECK_EQUAL(found->key, "00000000111111110000000011111111");
+    }
+
+    {
+        auto found = credentials.user();
+        BOOST_CHECK(found);
+        BOOST_CHECK_EQUAL(found->username, "user");
+        BOOST_CHECK_EQUAL(found->password, "pass");
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/service/test/auth/TestAuth_main.cpp 5.13.0-1/libs/service/test/auth/TestAuth_main.cpp
--- 5.12.4-1/libs/service/test/auth/TestAuth_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/auth/TestAuth_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Aviso
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/service/test/aviso/TestAviso.cpp 5.13.0-1/libs/service/test/aviso/TestAviso.cpp
--- 5.12.4-1/libs/service/test/aviso/TestAviso.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/aviso/TestAviso.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,631 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/service/aviso/Aviso.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Aviso)
+
+BOOST_AUTO_TEST_SUITE(T_AvisoSubscribe)
+
+BOOST_AUTO_TEST_CASE(can_create_default_aviso_subscribe) {
+    using namespace ecf::service::aviso;
+    AvisoSubscribe subscribe{"path", "listener_cfg", "address", "schema", 60, 1, "auth"};
+    BOOST_CHECK_EQUAL(subscribe.path(), "path");
+    BOOST_CHECK_EQUAL(subscribe.listener_cfg(), "listener_cfg");
+    BOOST_CHECK_EQUAL(subscribe.address(), "address");
+    BOOST_CHECK_EQUAL(subscribe.schema(), "schema");
+    BOOST_CHECK_EQUAL(subscribe.polling(), static_cast<uint32_t>(60));
+    BOOST_CHECK_EQUAL(subscribe.revision(), static_cast<uint64_t>(1));
+    BOOST_CHECK_EQUAL(subscribe.auth(), "auth");
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_subscribe) {
+    using namespace ecf::service::aviso;
+    AvisoSubscribe subscribe{"path", "listener_cfg", "address", "schema", 60, 1, "auth"};
+
+    std::ostringstream oss;
+    oss << subscribe;
+    BOOST_CHECK(oss.str().find("AvisoSubscribe") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoUnsubscribe)
+
+BOOST_AUTO_TEST_CASE(can_create_default_aviso_unsubscribe) {
+    using namespace ecf::service::aviso;
+    AvisoUnsubscribe unsubscribe{"path"};
+    BOOST_CHECK_EQUAL(unsubscribe.path(), "path");
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_unsubscribe) {
+    using namespace ecf::service::aviso;
+    AvisoUnsubscribe unsubscribe{"path"};
+
+    std::ostringstream oss;
+    oss << unsubscribe;
+    BOOST_CHECK(oss.str().find("AvisoUnsubscribe") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoRequest)
+
+BOOST_AUTO_TEST_CASE(can_create_aviso_request_to_subscribe) {
+    using namespace ecf::service::aviso;
+    AvisoRequest request{AvisoSubscribe{"path", "listener_cfg", "address", "schema", 60, 1, "auth"}};
+    std::visit([](auto&& arg) { BOOST_CHECK_EQUAL(arg.path(), "path"); }, request);
+}
+
+BOOST_AUTO_TEST_CASE(can_create_aviso_request_to_unsubscribe) {
+    using namespace ecf::service::aviso;
+    AvisoRequest request{AvisoUnsubscribe{"path"}};
+    std::visit([](auto&& arg) { BOOST_CHECK_EQUAL(arg.path(), "path"); }, request);
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_request) {
+    using namespace ecf::service::aviso;
+    AvisoRequest request{AvisoSubscribe{"path", "listener_cfg", "address", "schema", 60, 1, "auth"}};
+
+    std::ostringstream oss;
+    oss << request;
+    BOOST_CHECK(oss.str().find("AvisoRequest") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoNotification)
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_aviso_notification) {
+    using namespace ecf::service::aviso;
+    AvisoNotification notification{"key", "value", 1};
+    notification.add_parameter("parameter1", "parameter_value1");
+    notification.add_parameter("parameter2", "parameter_value2");
+
+    BOOST_CHECK_EQUAL(notification.key(), "key");
+    BOOST_CHECK_EQUAL(notification.value(), "value");
+    BOOST_CHECK_EQUAL(notification.revision(), static_cast<uint64_t>(1));
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_notification) {
+    using namespace ecf::service::aviso;
+    AvisoNotification notification{"key", "value", 1};
+
+    std::ostringstream oss;
+    oss << notification;
+    BOOST_CHECK(oss.str().find("AvisoNotification") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoError)
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_aviso_no_match) {
+    using namespace ecf::service::aviso;
+    [[maybe_unused]] AvisoNoMatch no_match;
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_no_match) {
+    using namespace ecf::service::aviso;
+    AvisoNoMatch no_match;
+
+    std::ostringstream oss;
+    oss << no_match;
+    BOOST_CHECK(oss.str().find("AvisoNoMatch") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_aviso_error) {
+    using namespace ecf::service::aviso;
+    AvisoError error{"error"};
+    BOOST_CHECK_EQUAL(error.reason(), "error");
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_error) {
+    using namespace ecf::service::aviso;
+    AvisoError error{"error"};
+
+    std::ostringstream oss;
+    oss << error;
+    BOOST_CHECK(oss.str().find("AvisoError") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoListener)
+
+BOOST_AUTO_TEST_CASE(can_create_default_listener) {
+    using namespace ecf::service::aviso;
+    Listener listener;
+    BOOST_CHECK_EQUAL(listener.name(), "");
+    BOOST_CHECK_EQUAL(listener.base(), "");
+    BOOST_CHECK_EQUAL(listener.stem(), "");
+    BOOST_CHECK_EQUAL(listener.full(), "/");
+}
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_listener) {
+    using namespace ecf::service::aviso;
+    Listener listener("name", "/base", "stem");
+    BOOST_CHECK_EQUAL(listener.name(), "name");
+    BOOST_CHECK_EQUAL(listener.base(), "/base");
+    BOOST_CHECK_EQUAL(listener.stem(), "stem");
+    BOOST_CHECK_EQUAL(listener.full(), "/base/stem");
+}
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_configured_listener) {
+    using namespace ecf::service::aviso;
+    ConfiguredListener listener("http://unknown:1234", "path", "name", "/base", "stem", 2, 0);
+    BOOST_CHECK_EQUAL(listener.address(), "http://unknown:1234");
+    BOOST_CHECK_EQUAL(listener.path(), "path");
+    BOOST_CHECK_EQUAL(listener.name(), "name");
+    BOOST_CHECK_EQUAL(listener.base(), "/base");
+    BOOST_CHECK_EQUAL(listener.resolved_base(), "/base");
+    BOOST_CHECK_EQUAL(listener.stem(), "stem");
+    BOOST_CHECK_EQUAL(listener.full(), "/base/stem");
+    BOOST_CHECK_EQUAL(listener.polling(), static_cast<uint32_t>(2));
+    BOOST_CHECK_EQUAL(listener.revision(), static_cast<uint64_t>(0));
+}
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_configured_listener_with_placeholders) {
+    using namespace ecf::service::aviso;
+    ConfiguredListener listener("http://unknown:1234", "path", "name", "/{a}", "{b}/{c}", 2, 0);
+    listener.with_parameter("a", "aaa");
+    listener.with_parameter("b", "bbb");
+    listener.with_parameter("c", "ccc");
+    BOOST_CHECK_EQUAL(listener.address(), "http://unknown:1234");
+    BOOST_CHECK_EQUAL(listener.path(), "path");
+    BOOST_CHECK_EQUAL(listener.name(), "name");
+    BOOST_CHECK_EQUAL(listener.base(), "/{a}");
+    BOOST_CHECK_EQUAL(listener.resolved_base(), "/aaa");
+    BOOST_CHECK_EQUAL(listener.prefix(), "/aaa/");
+    BOOST_CHECK_EQUAL(listener.stem(), "{b}/{c}");
+    BOOST_CHECK_EQUAL(listener.full(), "/{a}/{b}/{c}");
+    BOOST_CHECK_EQUAL(listener.polling(), static_cast<uint32_t>(2));
+    BOOST_CHECK_EQUAL(listener.revision(), static_cast<uint64_t>(0));
+}
+
+BOOST_AUTO_TEST_CASE(can_detect_non_matching_key) {
+    using namespace ecf::service::aviso;
+    ConfiguredListener listener("http://unknown:1234", "path", "name", "/{a}", "{b}/{c}", 2, 0);
+    listener.with_parameter("a", "aaa");
+    listener.with_parameter("b", "bbb");
+    listener.with_parameter("c", 0);
+
+    auto match = listener.accepts("non-matching-key", "value", 0);
+    BOOST_CHECK(!match.has_value());
+}
+
+BOOST_AUTO_TEST_CASE(can_detect_matching_key) {
+    using namespace ecf::service::aviso;
+    ConfiguredListener listener("http://unknown:1234", "path", "name", "/{a}", "{b}/{c}/{d}/{e}", 2, 0);
+    listener.with_parameter("a", "aaa");
+    listener.with_parameter("b", "bbb");
+    listener.with_parameter("c", 0);
+    listener.with_parameter("e", std::vector<std::string>{"valid1", "valid2"});
+
+    {
+        auto match = listener.accepts("/aaa/bbb/0/dontcare/valid1", "value", 1);
+        BOOST_CHECK(match.has_value());
+        BOOST_CHECK_EQUAL(match.value().key(), "/aaa/bbb/0/dontcare/valid1");
+        BOOST_CHECK_EQUAL(match.value().value(), "value");
+        BOOST_CHECK_EQUAL(match.value().revision(), static_cast<uint64_t>(1));
+    }
+    {
+        auto match = listener.accepts("/aaa/bbb/0/dontcare/valid2", "value", 2);
+        BOOST_CHECK(match.has_value());
+        BOOST_CHECK_EQUAL(match.value().key(), "/aaa/bbb/0/dontcare/valid2");
+        BOOST_CHECK_EQUAL(match.value().value(), "value");
+        BOOST_CHECK_EQUAL(match.value().revision(), static_cast<uint64_t>(2));
+    }
+    {
+        auto match = listener.accepts("/aaa/bbb/0/dontcare/invalid", "value", 3);
+        BOOST_CHECK(!match.has_value());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_print_configured_listener) {
+    using namespace ecf::service::aviso;
+    ConfiguredListener listener("http://unknown:1234", "path", "name", "/{a}", "{b}/{c}", 2, 0);
+    listener.with_parameter("a", "aaa");
+    listener.with_parameter("b", "bbb");
+    listener.with_parameter("c", "ccc");
+
+    std::ostringstream oss;
+    oss << listener;
+    BOOST_CHECK(oss.str().find("ConfiguredListener") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_CASE(can_make_configured_listener) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+            {
+                "event": "dissemination",
+                "request": {
+                    "destination": "COM",
+                    "date": 20000101,
+                    "class": "od",
+                    "expver": ["0001", "0002"],
+                    "step": [0, 12]
+                }
+            }
+        )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+            {
+                "dissemination": {
+                    "endpoint": [
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                }
+            }
+        )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    ConfiguredListener listener =
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision);
+
+    BOOST_CHECK_EQUAL(listener.path(), path);
+    BOOST_CHECK_EQUAL(listener.name(), "dissemination");
+    BOOST_CHECK_EQUAL(listener.address(), address);
+    BOOST_CHECK_EQUAL(listener.base(), "/ec/diss/{destination}");
+    BOOST_CHECK_EQUAL(listener.stem(),
+                      "date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={"
+                      "stream},step={step}");
+    BOOST_CHECK_EQUAL(listener.polling(), static_cast<uint32_t>(60));
+    BOOST_CHECK_EQUAL(listener.revision(), static_cast<uint64_t>(1));
+}
+
+BOOST_AUTO_TEST_CASE(can_update_revision_in_configured_listener) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+            {
+                "event": "dissemination",
+                "request": {
+                    "destination": "COM",
+                    "date": 20000101,
+                    "class": "od",
+                    "expver": ["0001", "0002"],
+                    "step": [0, 12]
+                }
+            }
+        )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+            {
+                "dissemination": {
+                    "endpoint": [
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                }
+            }
+        )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    ConfiguredListener listener =
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision);
+
+    BOOST_CHECK_EQUAL(listener.revision(), static_cast<uint64_t>(1));
+
+    listener.update_revision(2);
+
+    BOOST_CHECK_EQUAL(listener.revision(), static_cast<uint64_t>(2));
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_listener_configuration_with_invalid_configuration_content) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+            {
+                INVALID CONTENT
+                "event": "dissemination",
+                "request": {
+                    "destination": "COM",
+                    "date": 20000101,
+                    "class": "od",
+                    "expver": ["0001", "0002"],
+                    "step": [0, 12]
+                }
+            }
+        )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+            {
+                "dissemination": {
+                    "endpoint": [
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                }
+            }
+        )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    BOOST_CHECK_EXCEPTION(
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision),
+        std::runtime_error,
+        [](const std::exception& e) {
+            auto reason = std::string(e.what());
+            return reason.find("Failed to parse listener configuration") != std::string::npos;
+        });
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_listener_configuration_without_event_specification) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+            {
+                "request": {
+                    "destination": "COM",
+                    "date": 20000101,
+                    "class": "od",
+                    "expver": ["0001", "0002"],
+                    "step": [0, 12]
+                }
+            }
+        )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+            {
+                "dissemination": {
+                    "endpoint": [
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                }
+            }
+        )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    BOOST_CHECK_EXCEPTION(
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision),
+        std::runtime_error,
+        [](const std::exception& e) {
+            auto reason = std::string(e.what());
+            return reason.find("Listener configuration does not specify 'event'") != std::string::npos;
+        });
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_listener_configuration_without_request_specification) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+            {
+                "event": "dissemination"
+            }
+        )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+            {
+                "dissemination": {
+                    "endpoint": [
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                }
+            }
+        )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    BOOST_CHECK_EXCEPTION(
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision),
+        std::runtime_error,
+        [](const std::exception& e) {
+            auto reason = std::string(e.what());
+            return reason.find("Listener configuration does not specify 'request'") != std::string::npos;
+        });
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_listener_configuration_with_invalid_schema_content) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+            {
+                "event": "dissemination",
+                "request": {
+                    "destination": "COM",
+                    "date": 20000101,
+                    "class": "od",
+                    "expver": ["0001", "0002"],
+                    "step": [0, 12]
+                }
+            }
+        )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+            {
+                INVALID CONTENT
+                "dissemination": {
+                    "endpoint": [
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                }
+            }
+        )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    BOOST_CHECK_EXCEPTION(
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision),
+        std::runtime_error,
+        [](const std::exception& e) {
+            auto reason = std::string(e.what());
+            return reason.find("Failed to load listener schema") != std::string::npos;
+        });
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_listener_configuration_with_invalid_event_kind) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+            {
+                "event": "invalid_kind_event",
+                "request": {
+                    "destination": "COM",
+                    "date": 20000101,
+                    "class": "od",
+                    "expver": ["0001", "0002"],
+                    "step": [0, 12]
+                }
+            }
+        )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+            {
+                "dissemination": {
+                    "endpoint": [
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                }
+            }
+        )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    BOOST_CHECK_EXCEPTION(
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision),
+        std::runtime_error,
+        [](const std::exception& e) {
+            auto reason = std::string(e.what());
+            return reason.find("Listener could not be found in schema") != std::string::npos;
+        });
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoSchema)
+
+BOOST_AUTO_TEST_CASE(can_load_aviso_schema_from_string) {
+    using namespace ecf::service::aviso;
+    std::string schema_content = R"(
+            {
+                "dissemination": {
+                    "endpoint":[
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                },
+                "mars": {
+                    "endpoint":[
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/mars",
+                            "stem":"date={date},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}"
+                        }
+                    ]
+                }
+            }
+        )";
+
+    ListenerSchema schema = ListenerSchema::load_from_string(schema_content);
+    BOOST_CHECK(schema.get_listener("dissemination").has_value());
+    BOOST_CHECK(schema.get_listener("mars").has_value());
+    BOOST_CHECK(!schema.get_listener("invalid").has_value());
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_schema_content) {
+    using namespace ecf::service::aviso;
+    std::string schema_content = R"(
+            {
+                INVALID CONTENT
+                "dissemination": {
+                    "endpoint":[
+                        {
+                            "engine":[
+                                "etcd_rest"
+                            ],
+                            "base":"/ec/diss/{destination}",
+                            "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                            "admin":"/ec/admin/{date}/{destination}"
+                        }
+                    ]
+                },
+
+            }
+        )";
+
+    BOOST_CHECK_EXCEPTION(
+        ListenerSchema::load_from_string(schema_content), std::runtime_error, [](const std::exception& e) {
+            auto reason = std::string(e.what());
+            return reason.find("Failed to parse listener schema") != std::string::npos;
+        });
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/service/test/aviso/TestAvisoService.cpp 5.13.0-1/libs/service/test/aviso/TestAvisoService.cpp
--- 5.12.4-1/libs/service/test/aviso/TestAvisoService.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/aviso/TestAvisoService.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,295 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestContentProvider.hpp"
+#include "ecflow/service/Registry.hpp"
+#include "ecflow/service/aviso/AvisoService.hpp"
+#include "ecflow/service/aviso/etcd/Client.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_AvisoService)
+
+BOOST_AUTO_TEST_SUITE(T_Etcd_Client)
+
+BOOST_AUTO_TEST_CASE(can_create_etcd_client) {
+    using namespace ecf::service::aviso;
+    using namespace ecf::service::aviso::etcd;
+
+    std::string address = "http://address:1234";
+    Client client{address};
+
+    BOOST_CHECK_EQUAL(client.address(), address);
+    BOOST_CHECK_EQUAL(client.auth_token(), "");
+}
+
+BOOST_AUTO_TEST_CASE(can_poll_using_etcd_client) {
+    using namespace ecf::service::aviso;
+    using namespace ecf::service::aviso::etcd;
+
+    std::string address = "http://address:1234";
+    Client client{address};
+    BOOST_CHECK_EXCEPTION(client.poll("/prefix", 1), std::runtime_error, [](const std::runtime_error& e) {
+        return std::string{e.what()}.find("EtcdClient: Unable to retrieve result, due to ") != std::string::npos;
+    });
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_NotificationPackage)
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_notification_package) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+             {
+                 "event": "dissemination",
+                 "request": {
+                     "destination": "COM",
+                     "date": 20000101,
+                     "class": "od",
+                     "expver": ["0001", "0002"],
+                     "step": [0, 12]
+                 }
+             }
+         )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+             {
+                 "dissemination": {
+                     "endpoint": [
+                         {
+                             "engine":[
+                                 "etcd_rest"
+                             ],
+                             "base":"/ec/diss/{destination}",
+                             "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                             "admin":"/ec/admin/{date}/{destination}"
+                         }
+                     ]
+                 }
+             }
+         )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    ConfiguredListener listener =
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision);
+
+    AvisoNotification notification{"key", "value", 42};
+
+    NotificationPackage<ConfiguredListener, AvisoNotification> package{"path", listener, notification};
+
+    std::ostringstream oss;
+    oss << package;
+    BOOST_CHECK(oss.str().find("NotificationPackage") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoResponse)
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_response_with_notification_package) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+             {
+                 "event": "dissemination",
+                 "request": {
+                     "destination": "COM",
+                     "date": 20000101,
+                     "class": "od",
+                     "expver": ["0001", "0002"],
+                     "step": [0, 12]
+                 }
+             }
+         )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+             {
+                 "dissemination": {
+                     "endpoint": [
+                         {
+                             "engine":[
+                                 "etcd_rest"
+                             ],
+                             "base":"/ec/diss/{destination}",
+                             "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                             "admin":"/ec/admin/{date}/{destination}"
+                         }
+                     ]
+                 }
+             }
+         )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    ConfiguredListener listener =
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision);
+
+    AvisoNotification notification{"key", "value", 42};
+
+    NotificationPackage<ConfiguredListener, AvisoNotification> package{"path", listener, notification};
+
+    AvisoResponse response = package;
+
+    std::ostringstream oss;
+    oss << response;
+    BOOST_CHECK(oss.str().find("NotificationPackage") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_response_with_no_match) {
+    using namespace ecf::service::aviso;
+
+    AvisoNoMatch no_match;
+    AvisoResponse response = no_match;
+
+    std::ostringstream oss;
+    oss << response;
+    BOOST_CHECK(oss.str().find("AvisoNoMatch") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_CASE(can_print_aviso_response_with_error) {
+    using namespace ecf::service::aviso;
+
+    AvisoError error{"error"};
+    AvisoResponse response = error;
+
+    std::ostringstream oss;
+    oss << response;
+    BOOST_CHECK(oss.str().find("AvisoError") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoService_Entry)
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_aviso_service_entry) {
+    using namespace ecf::service::aviso;
+
+    std::string path           = "/s1/f1/t1";
+    std::string listener_cfg   = R"(
+             {
+                 "event": "dissemination",
+                 "request": {
+                     "destination": "COM",
+                     "date": 20000101,
+                     "class": "od",
+                     "expver": ["0001", "0002"],
+                     "step": [0, 12]
+                 }
+             }
+         )";
+    std::string address        = "http://server:1234";
+    std::string schema_content = R"(
+             {
+                 "dissemination": {
+                     "endpoint": [
+                         {
+                             "engine":[
+                                 "etcd_rest"
+                             ],
+                             "base":"/ec/diss/{destination}",
+                             "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                             "admin":"/ec/admin/{date}/{destination}"
+                         }
+                     ]
+                 }
+             }
+         )";
+    uint32_t polling           = 60;
+    uint64_t revision          = 1;
+
+    ConfiguredListener listener =
+        ConfiguredListener::make_configured_listener(path, listener_cfg, address, schema_content, polling, revision);
+    {
+        AvisoService::Entry entry{listener};
+
+        BOOST_CHECK(entry.listener().address() == listener.address());
+        BOOST_CHECK(entry.listener().prefix() == listener.prefix());
+        BOOST_CHECK(entry.listener().path() == listener.path());
+    }
+    {
+        const AvisoService::Entry entry{listener};
+
+        BOOST_CHECK(entry.listener().address() == listener.address());
+        BOOST_CHECK(entry.listener().prefix() == listener.prefix());
+        BOOST_CHECK(entry.listener().path() == listener.path());
+    }
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_AvisoController)
+
+BOOST_AUTO_TEST_CASE(can_create_start_and_stop_aviso_controller) {
+    using namespace ecf::service::aviso;
+
+    std::string listener_cfg   = R"(
+             {
+                 "event": "dissemination",
+                 "request": {
+                     "destination": "COM"
+                 }
+             }
+         )";
+    std::string schema_content = R"(
+             {
+                 "dissemination": {
+                     "endpoint": [
+                         {
+                             "engine":[
+                                 "etcd_rest"
+                             ],
+                             "base":"/ec/diss/{destination}",
+                             "stem":"date={date},target={target},class={class},expver={expver},domain={domain},time={time},stream={stream},step={step}",
+                             "admin":"/ec/admin/{date}/{destination}"
+                         }
+                     ]
+                 }
+             }
+         )";
+    std::string auth_content   = R"(
+             {
+                 "url": "http://address:1234",
+                 "key": "00000000111111110000000011111111",
+                 "email": "user@host.int"
+             }
+         )";
+
+    ecf::test::TestContentProvider schema_content_provider{"aviso_schema_test", schema_content};
+    ecf::test::TestContentProvider auth_content_provider{"aviso_auth_test", auth_content};
+
+    ecf::service::TheOneServer::set_server(nullptr);
+
+    AvisoController controller;
+
+    // Subscribe to a listener for /s1/f1/t1
+    controller.subscribe(AvisoRequest{AvisoSubscribe{
+        "/s1/f1/t1", listener_cfg, "address", schema_content_provider.file(), 60, 1, auth_content_provider.file()}});
+
+    // Subscribe and unsubcribe to a listener for /s1/f1/t2
+    controller.subscribe(AvisoRequest{AvisoSubscribe{
+        "/s1/f1/t2", listener_cfg, "address", schema_content_provider.file(), 60, 1, auth_content_provider.file()}});
+    controller.subscribe(AvisoRequest{AvisoUnsubscribe{"/s1/f1/t2"}});
+
+    controller.start();
+
+    std::this_thread::sleep_for(std::chrono::milliseconds{500});
+
+    controller.stop();
+    controller.terminate();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/service/test/aviso/TestAviso_main.cpp 5.13.0-1/libs/service/test/aviso/TestAviso_main.cpp
--- 5.12.4-1/libs/service/test/aviso/TestAviso_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/aviso/TestAviso_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Aviso
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/service/test/executor/TestExecutor_main.cpp 5.13.0-1/libs/service/test/executor/TestExecutor_main.cpp
--- 5.12.4-1/libs/service/test/executor/TestExecutor_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/executor/TestExecutor_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Aviso
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/service/test/executor/TestPeriodicTaskExecutor.cpp 5.13.0-1/libs/service/test/executor/TestPeriodicTaskExecutor.cpp
--- 5.12.4-1/libs/service/test/executor/TestPeriodicTaskExecutor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/executor/TestPeriodicTaskExecutor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/service/executor/PeriodicTaskExecutor.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Aviso)
+
+BOOST_AUTO_TEST_SUITE(T_PeriodicTaskExecutor)
+
+BOOST_AUTO_TEST_CASE(test_with_invalid_expiry) {
+    ecf::service::executor::PeriodicTaskExecutor executor([](const std::chrono::system_clock::time_point& now) {});
+    BOOST_CHECK_THROW(executor.start(std::chrono::milliseconds(100)), ecf::service::executor::InvalidExecutorArgument);
+}
+
+BOOST_AUTO_TEST_CASE(test_start_stop) {
+    int counter = 0;
+    ecf::service::executor::PeriodicTaskExecutor executor(
+        [&counter](const std::chrono::system_clock::time_point& now) { ++counter; });
+    executor.start(std::chrono::seconds(2));
+    std::this_thread::sleep_for(std::chrono::seconds(7));
+    executor.stop();
+    BOOST_CHECK_EQUAL(counter, 4);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/service/test/mirror/TestMirror.cpp 5.13.0-1/libs/service/test/mirror/TestMirror.cpp
--- 5.12.4-1/libs/service/test/mirror/TestMirror.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/mirror/TestMirror.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,138 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/service/mirror/Mirror.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Mirror)
+
+BOOST_AUTO_TEST_SUITE(T_MirrorRequest)
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_mirror_request) {
+    using namespace ecf::service::mirror;
+
+    MirrorRequest request{"path", "host", "1234", 60, true, "auth"};
+
+    BOOST_CHECK_EQUAL(request.path, "path");
+    BOOST_CHECK_EQUAL(request.host, "host");
+    BOOST_CHECK_EQUAL(request.port, "1234");
+    BOOST_CHECK_EQUAL(request.polling, static_cast<uint32_t>(60));
+    BOOST_CHECK_EQUAL(request.ssl, true);
+    BOOST_CHECK_EQUAL(request.auth, "auth");
+}
+
+BOOST_AUTO_TEST_CASE(can_print_mirror_request) {
+    using namespace ecf::service::mirror;
+
+    MirrorRequest request{"path", "host", "1234", 60, true, "auth"};
+
+    std::ostringstream oss;
+    oss << request;
+    BOOST_CHECK(oss.str().find("MirrorRequest") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_MirrorNotification)
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_mirror_notification) {
+    using namespace ecf::service::mirror;
+
+    MirrorNotification notification{"path", 1};
+
+    BOOST_CHECK_EQUAL(notification.path(), "path");
+    BOOST_CHECK_EQUAL(notification.status(), 1);
+}
+
+BOOST_AUTO_TEST_CASE(can_print_mirror_notification) {
+    using namespace ecf::service::mirror;
+
+    MirrorNotification notification{"path", 1};
+
+    std::ostringstream oss;
+    oss << notification;
+    BOOST_CHECK(oss.str().find("MirrorNotification") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_MirrorError)
+
+BOOST_AUTO_TEST_CASE(can_create_parameterised_mirror_error) {
+    using namespace ecf::service::mirror;
+
+    MirrorError error{"path", "reason"};
+
+    BOOST_CHECK_EQUAL(error.path(), "path");
+    BOOST_CHECK_EQUAL(error.reason(), "'reason'");
+}
+
+BOOST_AUTO_TEST_CASE(can_print_mirror_error) {
+    using namespace ecf::service::mirror;
+
+    MirrorError error{"path", "reason"};
+
+    std::ostringstream oss;
+    oss << error;
+    BOOST_CHECK(oss.str().find("MirrorError") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE(T_MirrorError)
+
+BOOST_AUTO_TEST_CASE(can_create_mirror_response_with_notification) {
+    using namespace ecf::service::mirror;
+
+    MirrorNotification notification{"path", 1};
+    MirrorResponse response = notification;
+
+    BOOST_CHECK(std::holds_alternative<MirrorNotification>(response));
+    BOOST_CHECK_EQUAL(std::get<MirrorNotification>(response).path(), "path");
+    BOOST_CHECK_EQUAL(std::get<MirrorNotification>(response).status(), 1);
+}
+
+BOOST_AUTO_TEST_CASE(can_create_mirror_response_with_error) {
+    using namespace ecf::service::mirror;
+
+    MirrorError error{"path", "reason"};
+    MirrorResponse response = error;
+
+    BOOST_CHECK(std::holds_alternative<MirrorError>(response));
+    BOOST_CHECK_EQUAL(std::get<MirrorError>(response).path(), "path");
+    BOOST_CHECK_EQUAL(std::get<MirrorError>(response).reason(), "'reason'");
+}
+
+BOOST_AUTO_TEST_CASE(can_print_mirror_response_with_notification) {
+    using namespace ecf::service::mirror;
+
+    MirrorNotification notification{"path", 1};
+    MirrorResponse response = notification;
+
+    std::ostringstream oss;
+    oss << response;
+    BOOST_CHECK(oss.str().find("MirrorNotification") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_CASE(can_print_mirror_response_with_error) {
+    using namespace ecf::service::mirror;
+
+    MirrorError error{"path", "reason"};
+    MirrorResponse response = error;
+
+    std::ostringstream oss;
+    oss << response;
+    BOOST_CHECK(oss.str().find("MirrorError") != std::string::npos);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/service/test/mirror/TestMirrorClient.cpp 5.13.0-1/libs/service/test/mirror/TestMirrorClient.cpp
--- 5.12.4-1/libs/service/test/mirror/TestMirrorClient.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/mirror/TestMirrorClient.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,39 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/service/mirror/MirrorClient.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Mirror)
+
+BOOST_AUTO_TEST_SUITE(T_MirrorClient)
+
+BOOST_AUTO_TEST_CASE(can_create_default_mirror_client) {
+    using namespace ecf::service::mirror;
+    MirrorClient client;
+    BOOST_CHECK(true);
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_getting_status_with_invalid_credentials) {
+    using namespace ecf::service::mirror;
+    MirrorClient client;
+
+    BOOST_CHECK_EXCEPTION(
+        client.get_node_status("invalid_host", "1234", "/s1/f1/p1", true, "username", "password"),
+        std::runtime_error,
+        [](const std::runtime_error& e) {
+            return std::string(e.what()).find("failure to sync remote defs") != std::string::npos;
+        });
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/service/test/mirror/TestMirrorService.cpp 5.13.0-1/libs/service/test/mirror/TestMirrorService.cpp
--- 5.12.4-1/libs/service/test/mirror/TestMirrorService.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/mirror/TestMirrorService.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/service/mirror/MirrorService.hpp"
+
+BOOST_AUTO_TEST_SUITE(U_Mirror)
+
+BOOST_AUTO_TEST_SUITE(T_MirrorController)
+
+BOOST_AUTO_TEST_CASE(can_create_start_and_stop_mirror_controller) {
+    using namespace ecf::service::mirror;
+
+    MirrorController controller;
+
+    controller.subscribe(MirrorRequest{"path", "host", "1234", 60, true, "auth"});
+
+    controller.start();
+
+    std::this_thread::sleep_for(std::chrono::milliseconds(500));
+
+    controller.stop();
+    controller.terminate();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/service/test/mirror/TestMirror_main.cpp 5.13.0-1/libs/service/test/mirror/TestMirror_main.cpp
--- 5.12.4-1/libs/service/test/mirror/TestMirror_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/service/test/mirror/TestMirror_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Mirror
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/simulator/CMakeLists.txt 5.13.0-1/libs/simulator/CMakeLists.txt
--- 5.12.4-1/libs/simulator/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,92 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+set(srcs
+  # Headers
+  src/ecflow/simulator/Analyser.hpp
+  src/ecflow/simulator/AstAnalyserVisitor.hpp
+  src/ecflow/simulator/DefsAnalyserVisitor.hpp
+  src/ecflow/simulator/FlatAnalyserVisitor.hpp
+  src/ecflow/simulator/Simulator.hpp
+  src/ecflow/simulator/SimulatorVisitor.hpp
+  # Sources
+  src/ecflow/simulator/Analyser.cpp
+  src/ecflow/simulator/AstAnalyserVisitor.cpp
+  src/ecflow/simulator/DefsAnalyserVisitor.cpp
+  src/ecflow/simulator/FlatAnalyserVisitor.cpp
+  src/ecflow/simulator/Simulator.cpp
+  src/ecflow/simulator/SimulatorVisitor.cpp
+)
+ecbuild_add_library(
+  TARGET
+    libsimulator
+  NOINSTALL
+  TYPE STATIC
+  SOURCES
+    ${srcs}
+  PUBLIC_INCLUDES
+    src
+  PUBLIC_LIBS
+    ecflow_all
+)
+target_clangformat(libsimulator)
+
+set(test_srcs
+  # Headers
+  test/TestUtil.hpp
+  # Sources
+  test/TestAnalysis.cpp
+  test/TestAutoArchive.cpp
+  test/TestAutoCancel.cpp
+  test/TestAutoCancel.cpp
+  test/TestAutoRestore.cpp
+  test/TestMeter.cpp
+  test/TestRepeat.cpp
+  test/TestSimulator.cpp
+  test/TestSimulator_main.cpp # test entry point
+  test/TestTime.cpp
+  test/TestToday.cpp
+  test/TestUtil.cpp
+)
+ecbuild_add_test(
+  TARGET
+    s_simulator
+  LABELS
+    integration nightly
+  SOURCES
+    ${test_srcs}
+  LIBS
+    libsimulator
+    Threads::Threads
+  TEST_DEPENDS
+    u_base
+)
+target_clangformat(s_simulator CONDITION ENABLE_TESTS)
+
+if (ENABLE_ALL_TESTS)
+
+  ecbuild_add_test(
+    TARGET
+      s_simulator_single
+    LABELS
+      integration nightly
+    SOURCES
+      test/TestSingleSimulator.cpp
+      test/TestSingleSimulator_main.cpp # test entry point
+      test/TestUtil.cpp
+    LIBS
+      libsimulator
+      Threads::Threads
+    TEST_DEPENDS
+      u_base
+  )
+  target_clangformat(s_simulator_single CONDITION ENABLE_TESTS)
+
+endif()
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/Analyser.cpp 5.13.0-1/libs/simulator/src/ecflow/simulator/Analyser.cpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/Analyser.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/Analyser.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/simulator/Analyser.hpp"
+
+#include <fstream>
+
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/simulator/DefsAnalyserVisitor.hpp"
+#include "ecflow/simulator/FlatAnalyserVisitor.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+Analyser::Analyser() = default;
+
+void Analyser::run(Defs& theDefs) {
+    // Run flat analysis
+    {
+        FlatAnalyserVisitor visitor;
+        theDefs.acceptVisitTraversor(visitor);
+
+        std::string fileName = "defs.flat";
+
+        std::ofstream file(fileName.c_str());
+        if (!file.is_open())
+            throw std::runtime_error("Analyser::run: Failed to open file \"" + fileName + "\"");
+
+        file << visitor.report();
+    }
+
+    // run depth first analysis
+    {
+        DefsAnalyserVisitor visitor;
+        theDefs.acceptVisitTraversor(visitor);
+
+        std::string fileName = "defs.depth";
+
+        std::ofstream file(fileName.c_str(), ios::out);
+        if (!file.is_open())
+            throw std::runtime_error("Analyser::run: Failed to open file \"" + fileName + "\"");
+
+        file << visitor.report();
+        file.close();
+    }
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/Analyser.hpp 5.13.0-1/libs/simulator/src/ecflow/simulator/Analyser.hpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/Analyser.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/Analyser.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,27 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_simulator_Analyser_HPP
+#define ecflow_simulator_Analyser_HPP
+
+class Defs;
+
+namespace ecf {
+
+class Analyser {
+public:
+    Analyser();
+
+    static void run(Defs& theDefs);
+};
+
+} // namespace ecf
+
+#endif /* ecflow_simulator_Analyser_HPP */
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.cpp 5.13.0-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.cpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,83 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/simulator/AstAnalyserVisitor.hpp"
+
+#include "ecflow/node/ExprAst.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+AstAnalyserVisitor::AstAnalyserVisitor()  = default;
+AstAnalyserVisitor::~AstAnalyserVisitor() = default;
+
+void AstAnalyserVisitor::visitTop(AstTop*) {
+}
+void AstAnalyserVisitor::visitRoot(AstRoot*) {
+}
+void AstAnalyserVisitor::visitAnd(AstAnd*) {
+}
+void AstAnalyserVisitor::visitNot(AstNot*) {
+}
+void AstAnalyserVisitor::visitPlus(AstPlus*) {
+}
+void AstAnalyserVisitor::visitMinus(AstMinus*) {
+}
+void AstAnalyserVisitor::visitDivide(AstDivide*) {
+}
+void AstAnalyserVisitor::visitMultiply(AstMultiply*) {
+}
+void AstAnalyserVisitor::visitModulo(AstModulo*) {
+}
+void AstAnalyserVisitor::visitOr(AstOr*) {
+}
+void AstAnalyserVisitor::visitEqual(AstEqual*) {
+}
+void AstAnalyserVisitor::visitNotEqual(AstNotEqual*) {
+}
+void AstAnalyserVisitor::visitLessEqual(AstLessEqual*) {
+}
+void AstAnalyserVisitor::visitGreaterEqual(AstGreaterEqual*) {
+}
+void AstAnalyserVisitor::visitGreaterThan(AstGreaterThan*) {
+}
+void AstAnalyserVisitor::visitLessThan(AstLessThan*) {
+}
+void AstAnalyserVisitor::visitLeaf(AstLeaf*) {
+}
+void AstAnalyserVisitor::visitInteger(AstInteger*) {
+}
+void AstAnalyserVisitor::visitInstant(AstInstant*) {
+}
+void AstAnalyserVisitor::visitFunction(AstFunction*) {
+}
+void AstAnalyserVisitor::visitNodeState(AstNodeState*) {
+}
+void AstAnalyserVisitor::visitEventState(AstEventState*) {
+}
+
+void AstAnalyserVisitor::visitNode(AstNode* astNode) {
+    Node* refNode = astNode->referencedNode();
+    if (refNode)
+        dependentNodes_.insert(refNode);
+    else
+        dependentNodePaths_.insert(astNode->nodePath());
+}
+
+void AstAnalyserVisitor::visitVariable(AstVariable* astVar) {
+}
+void AstAnalyserVisitor::visitParentVariable(AstParentVariable* astVar) {
+}
+
+void AstAnalyserVisitor::visitFlag(AstFlag* astVar) {
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.hpp 5.13.0-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.hpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/AstAnalyserVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,64 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_simulator_AstAnalyserVisitor_HPP
+#define ecflow_simulator_AstAnalyserVisitor_HPP
+
+#include <set>
+
+#include "ecflow/node/ExprAstVisitor.hpp"
+
+class Node;
+
+namespace ecf {
+
+class AstAnalyserVisitor : public ExprAstVisitor {
+public:
+    AstAnalyserVisitor();
+    ~AstAnalyserVisitor() override;
+
+    const std::set<Node*>& dependentNodes() const { return dependentNodes_; }
+    const std::set<std::string>& dependentNodePaths() const { return dependentNodePaths_; }
+
+    void visitTop(AstTop*) override;
+    void visitRoot(AstRoot*) override;
+    void visitAnd(AstAnd*) override;
+    void visitNot(AstNot*) override;
+    void visitPlus(AstPlus*) override;
+    void visitMinus(AstMinus*) override;
+    void visitDivide(AstDivide*) override;
+    void visitMultiply(AstMultiply*) override;
+    void visitModulo(AstModulo*) override;
+    void visitOr(AstOr*) override;
+    void visitEqual(AstEqual*) override;
+    void visitNotEqual(AstNotEqual*) override;
+    void visitLessEqual(AstLessEqual*) override;
+    void visitGreaterEqual(AstGreaterEqual*) override;
+    void visitGreaterThan(AstGreaterThan*) override;
+    void visitLessThan(AstLessThan*) override;
+    void visitLeaf(AstLeaf*) override;
+    void visitInteger(AstInteger*) override;
+    void visitInstant(AstInstant*) override;
+    void visitFunction(AstFunction*) override;
+    void visitNodeState(AstNodeState*) override;
+    void visitEventState(AstEventState*) override;
+    void visitNode(AstNode*) override;
+    void visitVariable(AstVariable*) override;
+    void visitParentVariable(AstParentVariable*) override;
+    void visitFlag(AstFlag*) override;
+
+private:
+    std::set<Node*> dependentNodes_;
+    std::set<std::string> dependentNodePaths_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_simulator_AstAnalyserVisitor_HPP */
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.cpp 5.13.0-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.cpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,181 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/simulator/DefsAnalyserVisitor.hpp"
+
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/AstAnalyserVisitor.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+///////////////////////////////////////////////////////////////////////////////
+DefsAnalyserVisitor::DefsAnalyserVisitor() = default;
+
+void DefsAnalyserVisitor::visitDefs(Defs* d) {
+    for (suite_ptr s : d->suiteVec()) {
+        s->acceptVisitTraversor(*this);
+    }
+}
+
+void DefsAnalyserVisitor::visitSuite(Suite* s) {
+    visitNodeContainer(s);
+}
+void DefsAnalyserVisitor::visitFamily(Family* f) {
+    visitNodeContainer(f);
+}
+
+void DefsAnalyserVisitor::visitNodeContainer(NodeContainer* nc) {
+    std::set<Node*> dependentNodes;
+    analyse(nc, dependentNodes);
+
+    for (node_ptr t : nc->nodeVec()) {
+        t->acceptVisitTraversor(*this);
+    }
+}
+
+void DefsAnalyserVisitor::visitTask(Task* t) {
+    std::set<Node*> dependentNodes;
+    analyse(t, dependentNodes);
+}
+
+void DefsAnalyserVisitor::analyse(Node* node, std::set<Node*>& dependentNodes, bool dependent) {
+    // ***************************************************************
+    // Do a depth first search to find the root cause of the blockage
+    // ***************************************************************
+    // #ifdef DEBUG
+    //	if (dependent)  {
+    //		ss_ << "DefsAnalyserVisitor::analyse " << node->debugType() << Str::COLON() << node->absNodePath();
+    //		ss_ << " state(" << NState::toString(node->state()) << ")\n";
+    //	}
+    // #endif
+    if (analysedNodes_.find(node) != analysedNodes_.end())
+        return;
+    analysedNodes_.insert(node);
+    if (node->state() == NState::COMPLETE)
+        return;
+
+    if (node->state() == NState::QUEUED) {
+        std::vector<std::string> theReasonWhy;
+        node->why(theReasonWhy);
+        for (const auto& i : theReasonWhy) {
+            Indentor::indent(ss_) << "Reason: " << i << "\n";
+        }
+    }
+
+    /// Note a complete expression that does not evaluate, does *NOT* hold the node
+    /// It merly sets node to complete.
+    if (node->completeAst() && !node->evaluateComplete()) {
+        // Follow nodes referenced in the complete expressions
+        analyseExpressions(node, dependentNodes, false, dependent);
+
+        // follow child nodes
+        auto* nc = dynamic_cast<NodeContainer*>(node);
+        if (nc) {
+            for (node_ptr t : nc->nodeVec()) {
+                t->acceptVisitTraversor(*this);
+            }
+        }
+    }
+
+    if (node->triggerAst() && !node->evaluateTrigger()) {
+        // Follow nodes referenced in the trigger expressions
+        analyseExpressions(node, dependentNodes, true, dependent);
+
+        // follow child nodes
+        auto* nc = dynamic_cast<NodeContainer*>(node);
+        if (nc) {
+            for (node_ptr t : nc->nodeVec()) {
+                t->acceptVisitTraversor(*this);
+            }
+        }
+    }
+}
+
+void DefsAnalyserVisitor::analyseExpressions(Node* node,
+                                             std::set<Node*>& dependentNodes,
+                                             bool trigger,
+                                             bool dependent) {
+    Indentor in;
+    Indentor::indent(ss_);
+    if (dependent)
+        ss_ << "DEPENDENT ";
+    if (trigger) {
+        ss_ << node->debugNodePath() << " holding on trigger expression '" << node->triggerExpression() << "'\n";
+    }
+    else {
+        ss_ << node->debugNodePath() << " holding on complete expression '" << node->completeExpression() << "'\n";
+    }
+
+    AstAnalyserVisitor astVisitor;
+    if (trigger) {
+        node->triggerAst()->accept(astVisitor);
+        ss_ << *node->triggerAst();
+    }
+    else {
+        node->completeAst()->accept(astVisitor);
+        ss_ << *node->completeAst();
+    }
+
+    // Warn about NULL node references in the trigger expressions
+    for (const string& nodePath : astVisitor.dependentNodePaths()) {
+        Indentor in2;
+        Indentor::indent(ss_) << "'" << nodePath << "' is not defined in the expression\n";
+    }
+
+    // **** NOTE: Currently for COMPLETE expression will only follow trigger expressions
+    for (Node* triggerNode : astVisitor.dependentNodes()) {
+
+        Indentor in2;
+        Indentor::indent(ss_) << "EXPRESSION NODE " << triggerNode->debugNodePath();
+        ss_ << " state(" << NState::toString(triggerNode->state()) << ")";
+        if (triggerNode->triggerAst())
+            ss_ << " trigger(evaluation = " << triggerNode->evaluateTrigger() << "))";
+        if (analysedNodes_.find(triggerNode) != analysedNodes_.end())
+            ss_ << " analysed ";
+        if (dependentNodes.find(triggerNode) != dependentNodes.end())
+            ss_ << " ** ";
+        ss_ << "\n";
+
+        if (dependentNodes.find(triggerNode) != dependentNodes.end()) {
+            // possible deadlock make sure
+            if (triggerNode->triggerAst()) {
+                AstAnalyserVisitor visitor;
+                triggerNode->triggerAst()->accept(visitor);
+
+                //				cerr << "Node = " << node->absNodePath() << "\n";
+                //				cerr << "triggerNode = " << triggerNode->absNodePath() << "\n";
+                //				for(Node* n:visitor.dependentNodes() ) {
+                //					cerr << "triggerNode Node dependents = " << n->absNodePath() <<
+                //"\n";
+                //				}
+
+                if (visitor.dependentNodes().find(node) != visitor.dependentNodes().end()) {
+                    Indentor in3;
+                    Indentor::indent(ss_) << "Deadlock detected between:\n";
+                    Indentor in4;
+                    Indentor::indent(ss_) << node->debugNodePath() << "\n";
+                    Indentor::indent(ss_) << triggerNode->debugNodePath() << "\n";
+                }
+            }
+            continue;
+        }
+        dependentNodes.insert(triggerNode);
+        analyse(triggerNode, dependentNodes, true);
+    }
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.hpp 5.13.0-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.hpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/DefsAnalyserVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_simulator_DefsAnalyserVisitor_HPP
+#define ecflow_simulator_DefsAnalyserVisitor_HPP
+
+#include <set>
+#include <sstream>
+
+#include "ecflow/node/NodeTreeVisitor.hpp"
+
+class Node;
+
+namespace ecf {
+
+class DefsAnalyserVisitor final : public NodeTreeVisitor {
+public:
+    DefsAnalyserVisitor();
+    std::string report() const { return ss_.str(); }
+
+    bool traverseObjectStructureViaVisitors() const override { return true; }
+    void visitDefs(Defs*) override;
+    void visitSuite(Suite*) override;
+    void visitFamily(Family*) override;
+    void visitNodeContainer(NodeContainer*) override;
+    void visitTask(Task*) override;
+
+private:
+    void analyse(Node* n, std::set<Node*>& dependentNodes, bool dependent = false);
+    void analyseExpressions(Node* node, std::set<Node*>& dependentNodes, bool trigger, bool dependent);
+
+    std::stringstream ss_;
+    std::set<Node*> analysedNodes_; // The node we  analysed
+};
+
+} // namespace ecf
+
+#endif /* ecflow_simulator_DefsAnalyserVisitor_HPP */
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.cpp 5.13.0-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.cpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,116 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/simulator/FlatAnalyserVisitor.hpp"
+
+#include "ecflow/core/Indentor.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/ExprAst.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/AstAnalyserVisitor.hpp"
+
+using namespace std;
+
+namespace ecf {
+
+///////////////////////////////////////////////////////////////////////////////
+FlatAnalyserVisitor::FlatAnalyserVisitor() = default;
+
+void FlatAnalyserVisitor::visitDefs(Defs* d) {
+    for (suite_ptr s : d->suiteVec()) {
+        s->acceptVisitTraversor(*this);
+    }
+}
+
+void FlatAnalyserVisitor::visitSuite(Suite* s) {
+    visitNodeContainer(s);
+}
+void FlatAnalyserVisitor::visitFamily(Family* f) {
+    visitNodeContainer(f);
+}
+
+void FlatAnalyserVisitor::visitNodeContainer(NodeContainer* nc) {
+    if (nc->state() == NState::COMPLETE)
+        return;
+
+    Indentor in;
+    bool traverseChildren = analyse(nc);
+
+    // Dont bother traversing children if parent is holding on trigger/complete expression
+    if (traverseChildren) {
+        for (node_ptr t : nc->nodeVec()) {
+            t->acceptVisitTraversor(*this);
+        }
+    }
+}
+
+void FlatAnalyserVisitor::visitTask(Task* t) {
+    Indentor in;
+    analyse(t);
+}
+
+bool FlatAnalyserVisitor::analyse(Node* node) {
+    bool traverseChildren = true;
+
+    Indentor::indent(ss_) << node->debugType() << Str::COLON() << node->name() << " state("
+                          << NState::toString(node->state()) << ")";
+    if (node->state() != NState::COMPLETE) {
+
+        if (node->repeat().isInfinite()) {
+            ss_ << " may **NEVER** complete due to " << node->repeat().toString();
+        }
+        ss_ << "\n";
+
+        if (node->state() == NState::QUEUED) {
+            std::vector<std::string> theReasonWhy;
+            node->why(theReasonWhy);
+            for (const auto& i : theReasonWhy) {
+                Indentor::indent(ss_) << "Reason: " << i << "\n";
+            }
+        }
+
+        /// Note a complete expression that does not evaluate, does *NOT* hold the node
+        /// It merly sets node to complete.
+        if (node->completeAst() && !node->evaluateComplete()) {
+            Indentor::indent(ss_) << "holding on complete expression '" << node->completeExpression() << "'\n";
+
+            AstAnalyserVisitor astVisitor;
+            node->completeAst()->accept(astVisitor);
+            for (const string& nodePath : astVisitor.dependentNodePaths()) {
+                Indentor in;
+                Indentor::indent(ss_) << "'" << nodePath << "' is not defined in the expression\n";
+            }
+            ss_ << *node->completeAst();
+
+            traverseChildren = false;
+        }
+
+        if (node->triggerAst() && !node->evaluateTrigger()) {
+            Indentor::indent(ss_) << "holding on trigger expression '" << node->triggerExpression() << "'\n";
+
+            AstAnalyserVisitor astVisitor;
+            node->triggerAst()->accept(astVisitor);
+            for (const string& nodePath : astVisitor.dependentNodePaths()) {
+                Indentor in;
+                Indentor::indent(ss_) << "'" << nodePath << "' is not defined in the expression\n";
+            }
+            ss_ << *node->triggerAst();
+
+            traverseChildren = false;
+        }
+    }
+    ss_ << "\n";
+    return traverseChildren;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.hpp 5.13.0-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.hpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/FlatAnalyserVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_simulator_FlatAnalyserVisitor_HPP
+#define ecflow_simulator_FlatAnalyserVisitor_HPP
+
+#include <sstream>
+
+#include "ecflow/node/NodeTreeVisitor.hpp"
+
+class Node;
+
+namespace ecf {
+
+class FlatAnalyserVisitor final : public NodeTreeVisitor {
+public:
+    FlatAnalyserVisitor();
+    std::string report() const { return ss_.str(); }
+
+    bool traverseObjectStructureViaVisitors() const override { return true; }
+    void visitDefs(Defs*) override;
+    void visitSuite(Suite*) override;
+    void visitFamily(Family*) override;
+    void visitNodeContainer(NodeContainer*) override;
+    void visitTask(Task*) override;
+
+private:
+    bool analyse(Node* n);
+    std::stringstream ss_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_simulator_FlatAnalyserVisitor_HPP */
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/Simulator.cpp 5.13.0-1/libs/simulator/src/ecflow/simulator/Simulator.cpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/Simulator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/Simulator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,383 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/simulator/Simulator.hpp"
+
+#include <boost/date_time/posix_time/time_formatters.hpp> // requires boost date and time lib
+
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/core/CalendarUpdateParams.hpp"
+#include "ecflow/core/Log.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Jobs.hpp"
+#include "ecflow/node/JobsParam.hpp"
+#include "ecflow/node/Submittable.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/simulator/Analyser.hpp"
+#include "ecflow/simulator/SimulatorVisitor.hpp"
+
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+using namespace std;
+using namespace ecf;
+
+// #define DEBUG_LONG_RUNNING_SUITES 1
+
+namespace ecf {
+
+/// Class that allows multiple log files.
+class LogDestroyer {
+public:
+    LogDestroyer() = default;
+    ~LogDestroyer() { Log::destroy(); }
+};
+
+Simulator::Simulator() : print_style_(PrintStyle::STATE) {
+}
+
+bool Simulator::run(const std::string& theDefsFile, std::string& errorMsg) const {
+#ifdef DEBUG_LONG_RUNNING_SUITES
+    cout << "Simulator::run parsing file " << theDefsFile << endl;
+#endif
+
+    Defs theDefs;
+    std::string warningMsg;
+    if (!theDefs.restore(theDefsFile, errorMsg, warningMsg))
+        return false;
+    // cout << theDefs << "\n";
+    return run(theDefs, theDefsFile, errorMsg, false /* don't do check, allready done */);
+}
+
+bool Simulator::run(Defs& theDefs, const std::string& defs_filename, std::string& errorMsg, bool do_checks) const {
+#ifdef DEBUG_LONG_RUNNING_SUITES
+    std::cout << "Simulator::run " << defs_filename << " no of suites " << theDefs.suiteVec().size() << endl;
+#endif
+    // ****:NOTE:******
+    // ** This simulator relies on the defs checking to set event and meter usedInTrigger()
+    // ** to speed up simulator. However this is done in AstResolveVisitor.
+    // ** Which is called during checking:
+    // ** By default checking in done when reading a defs file from disk:
+    // ** However many test create Defs on the fly. These may not do_checks.
+    // ** Hence we do it here, since it is simulator specific.
+
+    //   Please note that when we use a clock attribute, for a specific date
+    //   then when we are using repeat, they can cause the suite to re-queue
+    //   and RESET the suite time, back to clock attribute time
+
+    if (do_checks) {
+        std::string warningMsg;
+        if (!theDefs.check(errorMsg, warningMsg)) {
+            return false;
+        }
+    }
+
+    // Allow new log to be created each time, by destroying the old log.
+    LogDestroyer destroyLog;
+
+    // Initialise the Log file, and destroy when done. This
+    // allows new log file to be created named after the definition file
+    std::string logFileName = defs_filename + ".log";
+    fs::remove(logFileName);
+    Log::create(logFileName);
+    // cout << "defs_filename " << defs_filename << "\n";
+    // cout << "***** after Log::create(logFileName)\n";
+
+    // Do the following:
+    // o call begin() for each suite
+    // o determine calendar increment. If no time dependencies use an hour increment
+    // o determine max simulation period. ie looks at size of repeats
+    // o If multiple suites and some suites have no tasks, mark them as complete, these may have server limits
+    // o If no tasks at all, no point in simulating
+    // o ********************************************************************************
+    //   Please note that when we use a clock attribute, for a specific date
+    //   then when we are using repeat, they can cause the suite to re-queue
+    //   and RESET the suite time, back to clock attribute time
+    //   *********************************************************************************
+    SimulatorVisitor simiVisitor(defs_filename);
+    theDefs.acceptVisitTraversor(simiVisitor);
+    if (!simiVisitor.errors_found().empty()) {
+        errorMsg += simiVisitor.errors_found();
+        return false;
+    }
+
+    // Let visitor determine calendar increment. i.e if no time dependencies we will use 1 hour increment
+    time_duration calendarIncrement                        = simiVisitor.calendarIncrement();
+    boost::posix_time::time_duration max_simulation_period = simiVisitor.maxSimulationPeriod();
+
+    std::stringstream ss;
+    ss << " time dependency(" << simiVisitor.hasTimeDependencies() << ") max_simulation_period("
+       << to_simple_string(max_simulation_period) << ") calendarIncrement(" << to_simple_string(calendarIncrement)
+       << ")";
+    std::string msg = ss.str();
+    log(Log::MSG, msg);
+#ifdef DEBUG_LONG_RUNNING_SUITES
+    cout << defs_filename << msg
+         << "   ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n";
+#endif
+
+    // Do we have autocancel, must be done before.
+    int hasAutoCancel = 0;
+    for (suite_ptr s : theDefs.suiteVec()) {
+        if (s->hasAutoCancel())
+            hasAutoCancel++;
+    }
+
+    // ==================================================================================
+    // Start simulation ...
+    // Assume: User has taken into account autocancel end time.
+    // ==================================================================================
+    CalendarUpdateParams calUpdateParams(calendarIncrement);
+    boost::posix_time::time_duration duration(0, 0, 0, 0);
+    while (duration <= max_simulation_period) {
+
+#ifdef DEBUG_LONG_RUNNING_SUITES
+        for (suite_ptr my_suite : theDefs.suiteVec()) {
+            cout << "duration: " << to_simple_string(duration) << " " << my_suite->calendar().toString()
+                 << " +++++++++++++++++++++++++++++++++++ " << endl;
+
+            // use following to snapshot definition state at a given point in time
+            //         {
+            //        	 boost::gregorian::date debug_date(2019,8,5);
+            //        	 ptime debug_time(debug_date, hours(10) );
+            //        	 if (my_suite->calendar().suiteTime() == debug_time) {
+            //        		 cout << theDefs.print(PrintStyle::MIGRATE) << endl;
+            //        	 }
+            //         }
+        }
+#endif
+
+        // Resolve dependencies and submit jobs
+        if (!doJobSubmission(theDefs, errorMsg))
+            return false;
+
+        // Increment calendar per suite. *MUST* use *COPY* as update_calendar() can remove suites (auto-cancel)
+        std::vector<suite_ptr> suiteVec = theDefs.suiteVec();
+        for (suite_ptr suite : suiteVec) {
+            boost::posix_time::time_duration max_duration_for_suite = simiVisitor.max_simulation_period(suite.get());
+            if (duration < max_duration_for_suite) {
+                theDefs.update_calendar(suite.get(), calUpdateParams);
+            }
+        }
+        duration += calendarIncrement;
+    }
+
+    // ==================================================================================
+    // END of simulation
+    // ==================================================================================
+    if (!theDefs.checkInvariants(errorMsg)) {
+        return false;
+    }
+
+    // Cater for suite, with no verify attributes, but which are not complete. testAnalysis.cpp
+    // Ignore suites with crons as they will never complete
+    // Ignore suites with autocancel, as suite may get deleted
+    if (!simiVisitor.foundCrons() && (hasAutoCancel == 0)) {
+        size_t completeSuiteCnt = 0;
+        for (suite_ptr s : theDefs.suiteVec()) {
+            if (s->state() == NState::COMPLETE)
+                completeSuiteCnt++;
+        }
+
+        if ((theDefs.suiteVec().size() != completeSuiteCnt)) {
+            std::stringstream mss;
+            mss << "\nDefs file " << defs_filename << "\n";
+            for (suite_ptr s : theDefs.suiteVec()) {
+                if (s->state() != NState::COMPLETE)
+                    mss << "  suite '/" << s->name() << "' has not completed\n";
+            }
+            errorMsg += mss.str();
+
+            run_analyser(theDefs, errorMsg);
+            return false;
+        }
+    }
+
+    if (theDefs.verification(errorMsg)) {
+        return true;
+    }
+
+    run_analyser(theDefs, errorMsg);
+    return false;
+}
+
+void Simulator::run_analyser(Defs& theDefs, std::string& errorMsg) const {
+    Analyser analyser;
+    analyser.run(theDefs);
+    errorMsg += "Please see files .flat and .depth for analysis\n";
+    errorMsg += theDefs.print(PrintStyle::MIGRATE);
+}
+
+bool Simulator::doJobSubmission(Defs& theDefs, std::string& errorMsg) const {
+    //   const std::vector<suite_ptr>& suiteVec = theDefs.suiteVec();
+    //   for(suite_ptr s: suiteVec) cout << s->debugNodePath() << " " << s->calendar().toString() <<  endl;
+
+    // For the simulation we ensure job submission takes less than 10 seconds
+    // Resolve dependencies and submit jobs
+    JobsParam jobsParam(10 /*submitJobsInterval */, false /*create jobs*/); // spawn jobs *will* be set to false
+    Jobs jobs(&theDefs);
+    if (!jobs.generate(jobsParam)) {
+        ecf::log(Log::ERR, jobsParam.getErrorMsg());
+        assert(false);
+        return false;
+    }
+
+    // #ifdef DEBUG_LONG_RUNNING_SUITES
+    //	cout << "Simulator::doJobSubmission jobsParam.submitted().size() " << jobsParam.submitted().size() << " level =
+    //" << level_ << endl; #endif
+
+    level_++;
+
+    // For those jobs that were submitted, Simulate client by going
+    // through the task events and meters and updating them and then
+    // re-checking for job submission. Finally mark task as complete
+    // This is important as there may be other task dependent on this.
+    for (Submittable* t : jobsParam.submitted()) {
+
+#ifdef DEBUG_LONG_RUNNING_SUITES
+        // If task repeating themselves, determine what is causing this:
+        std::map<Submittable*, int>::iterator i = taskIntMap_.find(t);
+        if (i == taskIntMap_.end())
+            taskIntMap_.insert(std::make_pair(t, 1));
+        else {
+            (*i).second++;
+            // Find top most node that has a repeat, check if its incrementing:
+            Node* nodeWithRepeat = NULL;
+            Node* theParent      = t->parent();
+            while (theParent) {
+                if (!theParent->repeat().empty())
+                    nodeWithRepeat = theParent;
+                theParent = theParent->parent();
+            }
+            // cout << t->suite()->calendar().toString();
+            if (nodeWithRepeat) {
+                cout << " level " << level_ << " submitted task " << t->debugNodePath() << " count = " << (*i).second
+                     << " HAS parent Repeating node " << nodeWithRepeat->debugNodePath() << " "
+                     << nodeWithRepeat->repeat().dump() << endl;
+            }
+            else { // cound be a cron
+                cout << " level " << level_ << " submitted task " << t->debugNodePath() << " count = " << (*i).second
+                     << endl;
+            }
+        }
+#endif
+
+#ifdef DEBUG_LONG_RUNNING_SUITES
+        cout << t->debugNodePath() << " completes at " << t->suite()->calendar().toString() << " level " << level_
+             << " parent state:" << endl;
+#endif
+
+        // If the task has any event used in the trigger expressions, then update event.
+        std::string msg;
+        for (Event& event : t->ref_events()) {
+            if (event.usedInTrigger()) { // event used in trigger/complete expression
+                // initial value, if the value taken by the event on begin/re-queue. Child command is expected to invert
+                // the event
+                if (event.initial_value())
+                    event.set_value(false); // initial value is set,   hence clear event
+                else
+                    event.set_value(true); // initial value is clear, hence set the event , (default)
+
+                msg.clear();
+                msg += Str::CHILD_CMD();
+                msg += "event ";
+                msg += event.name_or_number();
+                msg += " ";
+                msg += t->absNodePath();
+                log(Log::MSG, msg);
+
+                if (!doJobSubmission(theDefs, errorMsg)) {
+                    level_--;
+                    return false;
+                }
+            }
+            else {
+                // warn about events not used in any trigger or complete expressions
+                // 				cout << "submitted task " << t->debugNodePath() << " UN-USED event " <<
+                // event.toString() << "\n";
+            }
+        }
+
+        // if the task has any meters used in trigger expressions, then increment meters
+        for (Meter& meter : t->ref_meters()) {
+            if (meter.usedInTrigger()) { // meter used in trigger/complete expression
+                while (meter.value() < meter.max()) {
+                    meter.set_value(meter.value() + 1);
+
+                    msg.clear();
+                    msg += Str::CHILD_CMD();
+                    msg += "meter ";
+                    msg += meter.name();
+                    msg += " ";
+                    msg += t->absNodePath();
+                    log(Log::MSG, msg);
+
+                    if (!doJobSubmission(theDefs, errorMsg)) {
+                        level_--;
+                        return false;
+                    }
+                }
+            }
+            else {
+                // Meters that are not used in trigger are usually used to indicate progress.
+                meter.set_value(meter.max());
+            }
+        }
+
+        if (!update_for_queues(t, msg, t->ref_queues(), theDefs, errorMsg))
+            return false;
+        Node* parent = t->parent();
+        while (parent) {
+            if (!update_for_queues(t, msg, parent->ref_queues(), theDefs, errorMsg))
+                return false;
+            parent = parent->parent();
+        }
+
+        // any state change should be followed with a job submission
+        t->complete(); // mark task as complete
+    }
+
+    level_--;
+    return true;
+}
+
+bool Simulator::update_for_queues(Submittable* t,
+                                  std::string& msg,
+                                  std::vector<QueueAttr>& queues,
+                                  Defs& theDefs,
+                                  std::string& errorMsg) const {
+    for (QueueAttr& queue : queues) {
+        const std::vector<std::string>& queue_list = queue.list();
+        for (size_t i = 0; i < queue_list.size(); i++) {
+            std::string step = queue.active();
+            if (step != "<NULL>")
+                queue.complete(step);
+            if (queue.used_in_trigger()) {
+                msg.clear();
+                msg += Str::CHILD_CMD();
+                msg += "queue ";
+                msg += queue.name();
+                msg += " complete";
+                msg += " ";
+                msg += step;
+                msg += t->absNodePath();
+                log(Log::MSG, msg);
+
+                if (!doJobSubmission(theDefs, errorMsg)) {
+                    level_--;
+                    return false;
+                }
+            }
+        }
+    }
+    return true;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/Simulator.hpp 5.13.0-1/libs/simulator/src/ecflow/simulator/Simulator.hpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/Simulator.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/Simulator.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,67 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_simulator_Simulator_HPP
+#define ecflow_simulator_Simulator_HPP
+
+#include <map>
+#include <string>
+#include <vector>
+
+#include "ecflow/core/PrintStyle.hpp"
+
+class QueueAttr;
+class Defs;
+class Submittable;
+
+namespace ecf {
+
+// This class is used to simulate a definition file. This is usefull because:
+//   a/ Saves time over involving server and asking client to play definition file
+//   b/ Informs about any parser errors in the definition file
+//   c/ Informs about any deadlocks, i.e. if a suite does not complete
+//   d/ Simulates both real and hybrid clocks
+//   e/ Simulation will by default run for a year. Should really use start/end clock for accurate simulations
+class Simulator {
+public:
+    // For deterministic results simulate using clock(start) and endclock(finish)
+    // Otherwise default to run simulation for:
+    // No time dependencies: simulate for 24 hours
+    //    time || today // 24 hours
+    //    day           // 1 week
+    //    date          // 1 month
+    //    cron          // 1 year
+    //    repeat        // 1 year
+    Simulator();
+    Simulator(const Simulator&)            = delete;
+    Simulator& operator=(const Simulator&) = delete;
+
+    /// return true if all ok else returns false;
+    bool run(Defs&, const std::string& defs_filename, std::string& errorMsg, bool do_checks = true) const;
+    bool run(const std::string& theDefsFile, std::string& errorMsg) const;
+
+private:
+    bool doJobSubmission(Defs&, std::string& errorMsg) const;
+    void run_analyser(Defs& theDefs, std::string& errorMsg) const;
+
+    bool update_for_queues(Submittable* t,
+                           std::string& msg,
+                           std::vector<QueueAttr>& queues,
+                           Defs& theDefs,
+                           std::string& errormsg) const;
+
+    mutable std::map<Submittable*, int> taskIntMap_;
+    mutable int level_{0};
+    PrintStyle print_style_; // by default show state when writing defs to standard out. RAII
+};
+
+} // namespace ecf
+
+#endif /* ecflow_simulator_Simulator_HPP */
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.cpp 5.13.0-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.cpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,158 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/simulator/SimulatorVisitor.hpp"
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/core/Log.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+namespace ecf {
+
+// Please note: we can speed up simulation, by using a calendar increment of 1 hour
+// However this will *ONLY* work *IF*
+//   o All the time based attributes time,today,cron have no minutes, i.e only i hour resolution
+//   o The calendar start time, must also have hour resolution, otherwise time/cron based attributes
+//     will be missed. i.e we increment calendar start time , with calendar increment
+//     If calendar start time is minutes based, and increment in hour based, time attributes will be missed
+//     Note: today is different, to time/cron, as it does not require a exact match
+
+///////////////////////////////////////////////////////////////////////////////
+SimulatorVisitor::SimulatorVisitor(const std::string& defs_filename)
+    : defs_filename_(defs_filename),
+      foundTasks_(false),
+      foundCrons_(false),
+      foundTime_(false),
+      hasTimeDependencies_(false),
+      has_end_clock_(false),
+      max_sim_duration_(hours(24)),
+      max_suite_duration_(hours(24)),
+      ci_(hours(1)) {
+}
+
+void SimulatorVisitor::visitDefs(Defs* d) {
+    for (suite_ptr s : d->suiteVec()) {
+        s->acceptVisitTraversor(*this);
+    }
+}
+
+void SimulatorVisitor::visitSuite(Suite* s) {
+    /// begin , will cause creation of generated variables. The generated variables
+    /// are use in client scripts and used to locate the ecf files.
+    s->begin();
+
+    // Found time dependencies use calendar increment of one minute
+    if (s->hasTimeDependencies()) {
+        hasTimeDependencies_ = true;
+    }
+
+    if (s->clockAttr() && s->clock_end_attr()) {
+        max_suite_duration_ = s->clock_end_attr()->ptime() - s->clockAttr()->ptime();
+        has_end_clock_      = true; // no need to determine max_length, user specified
+    }
+
+    visitNodeContainer(s);
+
+    // IF the suite has no task  (i.e could consist of just limits, set suite to complete
+    // Since we rely on it for termination of tests
+    // make setting NState::COMPLETE is after begin(), which will set Node into the queued state
+    if (!foundTasks_) {
+        s->set_state(NState::COMPLETE);
+        std::stringstream ss;
+        ss << "The defs file " << defs_filename_ << " has a suite '/" << s->suite()->name()
+           << "' which has no tasks. Ignoring \n";
+        log(Log::WAR, ss.str());
+    }
+
+    // If we have cron/time with calendar increment of 1 hour, where calendar start time is in minutes
+    // we will miss the time/cron based attributes, hence use 1 minute resolution
+    if ((foundCrons_ || foundTime_) && ci_ == hours(1)) {
+        // simulation has not started so, suiteTime same as start time.
+        boost::posix_time::time_duration start_time = s->calendar().suiteTime().time_of_day();
+        if (start_time.minutes() != 0) {
+            // cout << " start_time " << start_time << "   " << defs_filename_ << "\n";
+            log(Log::WAR,
+                "Found cron or time based attributes, with 1 hour resolution, however suite calendar start time has "
+                "minute resolution, reverting to minute resolution for simulation.");
+            log(Log::WAR,
+                "To speed up resolution use suite calendar with hour setting only, i.e where minutes is zero");
+            ci_ = minutes(1);
+        }
+    }
+
+    // record the max simulation period for THIS suite. i.e different suites can have different simulation period
+    suite_duration_vec_.emplace_back(s, max_suite_duration_);
+
+    // make sure total simulation period cover all the suites.
+    if (max_suite_duration_ > max_sim_duration_) {
+        max_sim_duration_ = max_suite_duration_;
+    }
+}
+
+boost::posix_time::time_duration SimulatorVisitor::max_simulation_period(Suite* s) const {
+    size_t suite_duration_vec_size = suite_duration_vec_.size();
+    for (size_t i = 0; i < suite_duration_vec_size; i++) {
+        if (suite_duration_vec_[i].first == s)
+            return suite_duration_vec_[i].second;
+    }
+    return max_sim_duration_;
+}
+
+void SimulatorVisitor::visitFamily(Family* f) {
+    visitNodeContainer(f);
+}
+
+void SimulatorVisitor::visitNodeContainer(NodeContainer* nc) {
+    if (ci_ == hours(1))
+        nc->get_time_resolution_for_simulation(ci_);
+    if (!has_end_clock_)
+        nc->get_max_simulation_duration(max_suite_duration_);
+
+    if (!nc->crons().empty()) {
+        foundCrons_ = true;
+        std::stringstream ss;
+        ss << defs_filename_ << ": Found crons on NodeContainer\n";
+        log(Log::MSG, ss.str());
+    }
+
+    if (!nc->timeVec().empty()) {
+        foundTime_ = true;
+    }
+
+    for (node_ptr t : nc->nodeVec()) {
+        t->acceptVisitTraversor(*this);
+    }
+}
+
+void SimulatorVisitor::visitTask(Task* t) {
+    if (ci_ == hours(1))
+        t->get_time_resolution_for_simulation(ci_);
+    if (!has_end_clock_)
+        t->get_max_simulation_duration(max_suite_duration_);
+
+    foundTasks_ = true;
+
+    if (!t->crons().empty()) {
+        foundCrons_ = true;
+    }
+    if (!t->timeVec().empty()) {
+        foundTime_ = true;
+    }
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.hpp 5.13.0-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.hpp
--- 5.12.4-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/src/ecflow/simulator/SimulatorVisitor.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,82 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_simulator_SimulatorVisitor_HPP
+#define ecflow_simulator_SimulatorVisitor_HPP
+
+#include <vector>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+
+#include "ecflow/node/NodeTreeVisitor.hpp"
+
+class Defs;
+class Family;
+class NodeContainer;
+class Suite;
+class Task;
+
+namespace ecf {
+
+class SimulatorVisitor final : public NodeTreeVisitor {
+public:
+    explicit SimulatorVisitor(const std::string& defs_filename);
+
+    /// If we have crons and no endclock then show error message
+    const std::string& errors_found() const { return error_msg_; }
+
+    /// Crons run for ever. Detect them so that we can abort early
+    bool foundCrons() const { return foundCrons_; }
+
+    /// returns true if defs has time,date,today, date time based attributes
+    bool hasTimeDependencies() const { return hasTimeDependencies_; }
+
+    /// Determine the max simulation period in hours over all the suites.
+    /// We will default to a year( 8784 =  366 X 24)
+    /// However by going through and looking at the repeats, we can get a better idea
+    boost::posix_time::time_duration maxSimulationPeriod() const { return max_sim_duration_; }
+
+    /// return the max simulation period for the given suite.
+    /// Allow definition with multiple suite with different simulation periods
+    boost::posix_time::time_duration max_simulation_period(Suite* s) const;
+
+    // default calendar increment is one minute, however if we have no time dependencies,
+    // then simulation can be speeded up, i.e by using hour increment
+    const boost::posix_time::time_duration& calendarIncrement() const { return ci_; }
+
+    bool traverseObjectStructureViaVisitors() const override { return true; }
+    void visitDefs(Defs*) override;
+    void visitSuite(Suite*) override;
+    void visitFamily(Family*) override;
+    void visitNodeContainer(NodeContainer*) override;
+    void visitTask(Task*) override;
+
+private:
+    /// Commented out since, we need to find a way of truncating lon repeats
+    /// without changing repeat structure.
+    //	void analyse(Node* node);
+    //	int truncateRepeats_;  // allow for simulation to complete earlier. ***NOT USED, kept for reference *****
+
+    std::string defs_filename_;
+    std::string error_msg_;
+    bool foundTasks_;
+    bool foundCrons_;
+    bool foundTime_;
+    bool hasTimeDependencies_;
+    bool has_end_clock_;
+    boost::posix_time::time_duration max_sim_duration_;
+    boost::posix_time::time_duration max_suite_duration_;
+    boost::posix_time::time_duration ci_;
+    std::vector<std::pair<Suite*, boost::posix_time::time_duration>> suite_duration_vec_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_simulator_SimulatorVisitor_HPP */
diff -pruN 5.12.4-1/libs/simulator/test/TestAnalysis.cpp 5.13.0-1/libs/simulator/test/TestAnalysis.cpp
--- 5.12.4-1/libs/simulator/test/TestAnalysis.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestAnalysis.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,76 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_Analysis)
+
+/// Use this class to test single simulation of definition file that we want to add
+/// to Test Simulator. This is a separate exe
+
+BOOST_AUTO_TEST_CASE(test_analysys) {
+    cout << "Simulator:: ...test_analysys\n";
+    // suite suite
+    //   family family
+    //     task t1
+    //       trigger t2 == complete
+    //     task t2
+    //       trigger t1 == complete
+    //   endfamily
+    // endsuite
+
+    // This simulation is expected to fail, since we have a deadlock/ race condition
+    // It will prodice a defs.depth and defs.flat files. Make sure to remove them
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_analysys");
+        family_ptr fam  = suite->add_family("family");
+
+        task_ptr task1 = fam->add_task("t1");
+        task1->add_trigger("t2 == complete");
+
+        task_ptr task2 = fam->add_task("t2");
+        task2->add_trigger("t1 == complete");
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(!simulator.run(theDefs, findTestDataLocation("test_analysys.def"), errorMsg), errorMsg);
+
+    fs::remove("defs.depth");
+    fs::remove("defs.flat");
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_analysys.def") + ".log";
+    fs::remove(logFileName);
+
+    /// Destroy singleton's to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestAutoArchive.cpp 5.13.0-1/libs/simulator/test/TestAutoArchive.cpp
--- 5.12.4-1/libs/simulator/test/TestAutoArchive.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestAutoArchive.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,314 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+/// Simulate definition files that are created on then fly. This allows us to validate
+/// Defs file, to check for correctness
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_AutoArchive)
+
+BOOST_AUTO_TEST_CASE(test_autoarchive_suite) {
+    cout << "Simulator:: ...test_autoarchive_suite\n";
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autoarchive at hour resolution
+    Defs theDefs;
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
+                                                      File::test_data("libs/simulator/test", "libs/simulator")); // required for archive
+    suite_ptr s1, s2, s3;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        s1 = theDefs.add_suite("test_autoarchive_10_hours_relative");
+        s1->addClock(clockAttr);
+        s1->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(10, 0), true));
+        s1->add_family("family")->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        s2 = theDefs.add_suite("test_autoarchive_1_hours_real");
+        s2->addClock(clockAttr);
+        s2->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), false));
+        s2->add_family("family")->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        s3 = theDefs.add_suite("test_autoarchive_1_day_relative");
+        s3->addClock(clockAttr);
+        s3->add_autoarchive(ecf::AutoArchiveAttr(1));
+        s3->add_family("family")->add_task("t");
+        //       cout << theDefs << "\n";
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autoarchive_suite.def"), errorMsg), errorMsg);
+
+    // make sure autoarchive archives the suite.
+    BOOST_CHECK_MESSAGE(s1->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << s1->absNodePath() << " to be archived");
+    BOOST_CHECK_MESSAGE(s2->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << s2->absNodePath() << " to be archived");
+    BOOST_CHECK_MESSAGE(s3->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << s3->absNodePath() << " to be archived");
+
+    BOOST_CHECK_MESSAGE(fs::exists(s1->archive_path()), "Expected suite " << s1->absNodePath() << " to be archived");
+    BOOST_CHECK_MESSAGE(fs::exists(s2->archive_path()), "Expected suite " << s2->absNodePath() << " to be archived");
+    BOOST_CHECK_MESSAGE(fs::exists(s3->archive_path()), "Expected suite " << s3->absNodePath() << " to be archived");
+
+    BOOST_CHECK_MESSAGE(s1->nodeVec().empty(), "Expected suite " << s1->absNodePath() << " to be empty");
+    BOOST_CHECK_MESSAGE(s1->nodeVec().empty(), "Expected suite " << s2->absNodePath() << " to be empty");
+    BOOST_CHECK_MESSAGE(s1->nodeVec().empty(), "Expected suite " << s3->absNodePath() << " to be empty");
+
+    s1->restore();
+    s2->restore();
+    s3->restore();
+
+    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << s1->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(!s2->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << s2->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(!s3->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << s3->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(s1->get_flag().is_set(ecf::Flag::RESTORED),
+                        "Expected suite " << s1->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(s2->get_flag().is_set(ecf::Flag::RESTORED),
+                        "Expected suite " << s2->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(s3->get_flag().is_set(ecf::Flag::RESTORED),
+                        "Expected suite " << s3->absNodePath() << " to be restored");
+
+    BOOST_CHECK_MESSAGE(!fs::exists(s1->archive_path()), "Expected file " << s1->archive_path() << " to be removed");
+    BOOST_CHECK_MESSAGE(!fs::exists(s2->archive_path()), "Expected file " << s2->archive_path() << " to be removed");
+    BOOST_CHECK_MESSAGE(!fs::exists(s3->archive_path()), "Expected file " << s3->archive_path() << " to be removed");
+
+    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s1->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s2->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s3->absNodePath() << " to be restored");
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autoarchive_suite.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_autoarchive_ast_node_reset) {
+    cout << "Simulator:: ...test_autoarchive_ast_node_reset\n";
+
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autoarchive at hour resolution
+    Defs theDefs;
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
+                                                      File::test_data("libs/simulator/test", "libs/simulator")); // required for archive
+
+    suite_ptr suite_s2;
+    suite_ptr suite_s3;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("s1");
+        suite->addClock(clockAttr);
+        suite->addDefStatus(DState::COMPLETE);
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t")->add_trigger("/s2/family/t == complete");
+
+        task_ptr task2 = fam->add_task("t2");
+        task2->add_trigger("/s3/family/t == complete");
+        //    cout << theDefs << "\n";
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_s2 = theDefs.add_suite("s2");
+        suite_s2->addClock(clockAttr);
+        suite_s2->add_autoarchive(ecf::AutoArchiveAttr(0)); // archive on next calendar update
+        suite_s2->add_family("family")->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_s3 = theDefs.add_suite("s3");
+        suite_s3->addClock(clockAttr);
+        suite_s3->add_autoarchive(ecf::AutoArchiveAttr(0)); // archive on next calendar update
+        suite_s3->add_family("family")->add_task("t");
+    }
+
+    // Check number of AST nodes. The AST should be created on the fly
+    std::set<Node*> theSet;
+    theDefs.getAllAstNodes(theSet);
+    BOOST_CHECK_MESSAGE(theSet.size() == 2,
+                        "Expected to have 2 AST nodes in trigger/complete expressions but found " << theSet.size());
+
+    // Run the simulator
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autoarchive_ast_node_reset.def"), errorMsg),
+                        errorMsg);
+
+    // Auto archive should archive suite s2 and s3, leaving one suite i.e s1
+    const std::vector<suite_ptr>& suites = theDefs.suiteVec();
+    for (const auto& suite : suites) {
+        if (suite->name() == "s2" || suite->name() == "s3") {
+            BOOST_CHECK_MESSAGE(suite->get_flag().is_set(ecf::Flag::ARCHIVED),
+                                "Expected suite " << suite->absNodePath() << " to be archived");
+        }
+    }
+
+    // The references to nodes in suites s2, s3 should have been cleared in suite s1
+    {
+        std::set<Node*> theSet;
+        theDefs.getAllAstNodes(theSet);
+        BOOST_CHECK_MESSAGE(theSet.empty(),
+                            "Expected to have 0 AST nodes in trigger/complete expressions but found " << theSet.size());
+    }
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autocancel_ast_node_reset.def") + ".log";
+    fs::remove(logFileName);
+    fs::remove(suite_s2->archive_path()); // remove generated archive files
+    fs::remove(suite_s3->archive_path()); // remove generated archive files
+}
+
+BOOST_AUTO_TEST_CASE(test_autoarchive_family) {
+    cout << "Simulator:: ...test_autoarchive_family\n";
+    Defs theDefs;
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
+                                                      File::test_data("libs/simulator/test", "libs/simulator")); // required for archive
+
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autoarchive_family");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(10, 0), true));
+        task_ptr task = fam->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autoarchive_1_2_hours_real");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(2, 0), false));
+        task_ptr task = fam->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        ClockAttr end_clock(true);
+        end_clock.date(14, 10, 2009); // 14 October 2009 was a Wednesday
+
+        suite_ptr suite = theDefs.add_suite("test_autoarchive_1_2_day_relative");
+        suite->addClock(clockAttr);
+        suite->add_end_clock(end_clock);
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_autoarchive(ecf::AutoArchiveAttr(2)); // 2 days
+        fam->add_task("t");
+    }
+    // cout << theDefs << "\n";
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autoarchive_family.def"), errorMsg),
+                        errorMsg);
+
+    // make sure all familes has been archived
+    std::vector<Family*> famVec;
+    theDefs.getAllFamilies(famVec);
+    for (auto f : famVec) {
+        BOOST_CHECK_MESSAGE(f->get_flag().is_set(ecf::Flag::ARCHIVED),
+                            "Expected family " << f->absNodePath() << " to be archived");
+        BOOST_CHECK_MESSAGE(fs::exists(f->archive_path()), "Expected family " << f->absNodePath() << " to be archived");
+        BOOST_CHECK_MESSAGE(f->nodeVec().empty(), "Expected family " << f->absNodePath() << " to be empty");
+
+        f->restore();
+        BOOST_CHECK_MESSAGE(f->get_flag().is_set(ecf::Flag::RESTORED),
+                            "Expected family " << f->absNodePath() << " to be restored");
+        BOOST_CHECK_MESSAGE(!f->get_flag().is_set(ecf::Flag::ARCHIVED),
+                            "Expected family " << f->absNodePath() << " to be restored");
+        BOOST_CHECK_MESSAGE(!fs::exists(f->archive_path()), "Expected file " << f->absNodePath() << " to be removed");
+        BOOST_CHECK_MESSAGE(!f->nodeVec().empty(), "Expected family " << f->absNodePath() << " to be restored");
+    }
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autoarchive_family_and_task.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_two_autoarchive_in_hierarchy) {
+    cout << "Simulator:: ...test_two_autoarchive_in_hierarchy\n";
+    Defs theDefs;
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
+                                                      File::test_data("libs/simulator/test", "libs/simulator")); // required for archive
+
+    suite_ptr suite;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite = theDefs.add_suite("test_two_autoarchive_in_hierarchy");
+        suite->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(1, 0), true));
+        task_ptr task = fam->add_task("t");
+    }
+    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
+    //   cout << theDefs;
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_two_autoarchive_in_hierarchy.def"), errorMsg),
+                        errorMsg);
+
+    // Check ONLY the suite got archived an not family
+    BOOST_CHECK_MESSAGE(suite->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << suite->absNodePath() << " to be archived");
+    BOOST_CHECK_MESSAGE(fs::exists(suite->archive_path()),
+                        "Expected family " << suite->absNodePath() << " to be archived");
+    BOOST_CHECK_MESSAGE(suite->nodeVec().empty(), "Expected family " << suite->absNodePath() << " to be empty");
+
+    // The family should have been deleted
+    node_ptr fam = theDefs.findAbsNode("/test_two_autoarchive_in_hierarchy/family");
+    BOOST_CHECK_MESSAGE(!fam, "Expected family to be deleted");
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_two_autoarchive_in_hierarchy.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestAutoCancel.cpp 5.13.0-1/libs/simulator/test/TestAutoCancel.cpp
--- 5.12.4-1/libs/simulator/test/TestAutoCancel.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestAutoCancel.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,318 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/attribute/AutoCancelAttr.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+/// Simulate definition files that are created on then fly. This us to validate
+/// Defs file, to check for correctness
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_AutoCancel)
+
+BOOST_AUTO_TEST_CASE(test_autocancel_ast_node_reset) {
+    cout << "Simulator:: ...test_autocancel_ast_node_reset\n";
+
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autocancel at hour resolution
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("s1");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->add_trigger("/s2/family/t == complete");
+
+        task_ptr task2 = fam->add_task("t2");
+        task2->add_trigger("/s3/family/t == complete");
+        task2->add_complete("/s2/family == complete");
+
+        task_ptr task3 = fam->add_task("t3");
+        task3->add_trigger("/s3 == complete");
+        task3->add_complete("/s2 == complete");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+
+        suite_ptr suite = theDefs.add_suite("s2");
+        suite->addClock(clockAttr);
+        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("s3");
+        suite->addClock(clockAttr);
+        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t");
+    }
+
+    // Check number of AST nodes. The AST should be created on the fly
+    std::set<Node*> theSet;
+    theDefs.getAllAstNodes(theSet);
+    BOOST_CHECK_MESSAGE(theSet.size() == 5,
+                        "Expected to have 5 AST nodes in trigger/complete expressions but found " << theSet.size());
+
+    // Run the simulator
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_ast_node_reset.def"), errorMsg),
+                        errorMsg);
+
+    // Auto cancel should delete suite s2 and s3, leaving one suite i.e s1
+    BOOST_CHECK_MESSAGE(theDefs.suiteVec().size() == 1,
+                        "Expected to have 1 suites but found " << theDefs.suiteVec().size());
+
+    // The references to nodes in suites s2, s3 should have been cleared in suite s1
+    {
+        std::set<Node*> theSet;
+        theDefs.getAllAstNodes(theSet);
+        BOOST_CHECK_MESSAGE(theSet.empty(),
+                            "Expected to have 0 AST nodes in trigger/complete expressions but found " << theSet.size());
+    }
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autocancel_ast_node_reset.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_autocancel_suite) {
+    cout << "Simulator:: ...test_autocancel_suite\n";
+
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autocancel at hour resolution
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_10_hours_relative");
+        suite->addClock(clockAttr);
+        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(10, 0), true));
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_1_hours_real");
+        suite->addClock(clockAttr);
+        suite->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t");
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_1_day_relative");
+        suite->addClock(clockAttr);
+        suite->addAutoCancel(ecf::AutoCancelAttr(1));
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t");
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_suite.def"), errorMsg), errorMsg);
+
+    // make sure autocancel deletes the suite.
+    BOOST_CHECK_MESSAGE(theDefs.suiteVec().size() == 0,
+                        "Expected to have 0 suites but found " << theDefs.suiteVec().size());
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autocancel_suite.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_autocancel_family_and_task) {
+    cout << "Simulator:: ...test_autocancel_family_and_task\n";
+
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autocancel at hour resolution
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_9_10_hours_relative");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(10, 0), true));
+
+        task_ptr task = fam->add_task("t");
+        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(9, 0), true));
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_1_2_hours_real");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(2, 0), false));
+
+        task_ptr task = fam->add_task("t");
+        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        ClockAttr end_clock(true);
+        end_clock.date(14, 10, 2009); // 14 October 2009 was a Wednesday
+
+        suite_ptr suite = theDefs.add_suite("test_autocancel_1_2_day_relative");
+        suite->addClock(clockAttr);
+        suite->add_end_clock(end_clock);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addAutoCancel(ecf::AutoCancelAttr(2)); // 2 days
+
+        task_ptr task = fam->add_task("t");
+        task->addAutoCancel(ecf::AutoCancelAttr(1)); // 1 days
+    }
+    // cout << theDefs << "\n";
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_family_and_task.def"), errorMsg),
+                        errorMsg);
+
+    // make sure autocancel deletes the families.
+    std::vector<Family*> famVec;
+    theDefs.getAllFamilies(famVec);
+    BOOST_CHECK_MESSAGE(famVec.size() == 0,
+                        "Expected to have 0 families but found " << famVec.size() << "\n"
+                                                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autocancel_family_and_task.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_autocancel_task) {
+    cout << "Simulator:: ...test_autocancel_task\n";
+
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autocancel at hour resolution
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_10_hours_relative");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(10, 0), true));
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_1_hours_real");
+        suite->addClock(clockAttr);
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), false));
+    }
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autocancel_1_day_relative");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addAutoCancel(ecf::AutoCancelAttr(1));
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autocancel_task.def"), errorMsg), errorMsg);
+
+    // make sure autocancel deletes the tasks and leaves families intact.
+    std::vector<task_ptr> task_vec;
+    theDefs.get_all_tasks(task_vec);
+
+    std::vector<Family*> famVec;
+    theDefs.getAllFamilies(famVec);
+
+    BOOST_CHECK_MESSAGE(famVec.size() == 3, "Expected to have 3 families but found " << famVec.size());
+    BOOST_CHECK_MESSAGE(task_vec.size() == 0, "Expected to have 0 tasks but found " << task_vec.size());
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autocancel_task.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_two_autocancel_in_hierarchy) {
+    cout << "Simulator:: ...test_two_autocancel_in_hierarchy\n"; // ECFLOW-556
+
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autocancel at hour resolution
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_two_autocancel_in_hierarchy");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), true));
+        task_ptr task = fam->add_task("t");
+        task->addAutoCancel(ecf::AutoCancelAttr(ecf::TimeSlot(1, 0), true));
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_two_autocancel_in_hierarchy.def"), errorMsg),
+                        errorMsg);
+
+    std::vector<task_ptr> task_vec;
+    theDefs.get_all_tasks(task_vec);
+
+    std::vector<Family*> famVec;
+    theDefs.getAllFamilies(famVec);
+
+    BOOST_CHECK_MESSAGE(famVec.size() == 0, "Expected to have 0 families but found " << famVec.size());
+    BOOST_CHECK_MESSAGE(task_vec.size() == 0, "Expected to have 0 tasks but found " << task_vec.size());
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_two_autocancel_in_hierarchy.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestAutoRestore.cpp 5.13.0-1/libs/simulator/test/TestAutoRestore.cpp
--- 5.12.4-1/libs/simulator/test/TestAutoRestore.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestAutoRestore.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,172 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/attribute/AutoArchiveAttr.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/AutoRestoreAttr.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+/// Simulate definition files that are created on then fly. This allows us to validate
+/// Defs file, to check for correctness
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_AutoRestore)
+
+BOOST_AUTO_TEST_CASE(test_autorestore_suite) {
+    cout << "Simulator:: ...test_autorestore_suite\n";
+    // ****: Since we have no time dependencies the simulator calendar increment
+    // ****: is in hours. Hence autoarchive at hour resolution
+    Defs theDefs;
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
+                                                      File::test_data("libs/simulator/test", "libs/simulator")); // required for archive
+    string s1_path;
+    {
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr s1 = theDefs.add_suite("test_autorestore_suite");
+        s1->addClock(clockAttr);
+        s1->add_autoarchive(ecf::AutoArchiveAttr(0));
+        s1->add_family("family")->add_task("t");
+        s1_path = s1->absNodePath();
+    }
+    {
+        std::vector<std::string> nodes_to_restore;
+        nodes_to_restore.push_back(s1_path);
+        ClockAttr clockAttr(true);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr s3 = theDefs.add_suite("test_autorestore_suite_2");
+        s3->addClock(clockAttr);
+        task_ptr t1 = s3->add_family("family")->add_task("t");
+        t1->add_autorestore(ecf::AutoRestoreAttr(nodes_to_restore));
+        t1->add_trigger("/test_autorestore_suite == complete");
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autorestore_suite.def"), errorMsg), errorMsg);
+
+    //   PrintStyle::setStyle(PrintStyle::MIGRATE);
+    //   cout << theDefs;
+
+    // suite test_autorestore_suite, should have been archived then restored
+    suite_ptr s1 = theDefs.findSuite("test_autorestore_suite");
+    BOOST_REQUIRE_MESSAGE(s1, "Expected to find suite s1");
+    BOOST_CHECK_MESSAGE(s1->get_flag().is_set(ecf::Flag::RESTORED),
+                        "Expected suite " << s1->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(!s1->get_flag().is_set(ecf::Flag::ARCHIVED),
+                        "Expected suite " << s1->absNodePath() << " to be restored");
+    BOOST_CHECK_MESSAGE(!fs::exists(s1->archive_path()), "Expected file " << s1->archive_path() << " to be removed");
+    BOOST_CHECK_MESSAGE(!s1->nodeVec().empty(), "Expected suite " << s1->absNodePath() << " to be restored");
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autorestore_suite.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_autorestore_family) {
+    cout << "Simulator:: ...test_autorestore_family\n";
+
+    // *** Autoarchiving takes place in Defs::updatecalendar(..) which happens every 60/seconds
+    // *** Autorestore   takes place immediately after state change, hence if could occur before updateCalendar has run
+    // ***               hence in this test we use time attributes, to ensure the updateCalendar/autoarchive is run
+    // before
+    // ***               autorestore
+    Defs theDefs;
+    theDefs.set_server().add_or_update_user_variables(Str::ECF_HOME(),
+                                                      File::test_data("libs/simulator/test", "libs/simulator")); // required for archive
+
+    std::vector<std::string> vec;
+    {
+        ClockAttr clockAttr(false);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autoarchive_family");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_autoarchive(AutoArchiveAttr(0));
+        task_ptr task = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(1, 0, true));
+        vec.push_back(fam->absNodePath());
+    }
+    {
+        ClockAttr clockAttr(false);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_autoarchive_family_1");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->add_autoarchive(ecf::AutoArchiveAttr(ecf::TimeSlot(2, 0), false));
+        task_ptr task = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(1, 0, true));
+        vec.push_back(fam->absNodePath());
+    }
+    {
+        ClockAttr clockAttr(false);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        ClockAttr end_clock(false);
+        end_clock.date(14, 10, 2009); // 14 October 2009 was a Wednesday
+
+        suite_ptr suite = theDefs.add_suite("test_autoarchive_family_2");
+        suite->addClock(clockAttr);
+        suite->add_end_clock(end_clock);
+
+        family_ptr fam = suite->add_family("do_autorestore");
+        task_ptr t     = fam->add_task("t");
+        t->add_autorestore(ecf::AutoRestoreAttr(vec));
+        t->add_trigger(vec[0] + " == complete and " + vec[1] + " == complete");
+        t->addTime(ecf::TimeAttr(2, 0, true)); // make sure we finish 1 hour after, since restore is immediate
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_autorestore_family.def"), errorMsg),
+                        errorMsg);
+    // PrintStyle::setStyle(PrintStyle::MIGRATE);
+    // cout << theDefs;
+
+    // make sure all familes has been archived
+    std::vector<Family*> famVec;
+    theDefs.getAllFamilies(famVec);
+    for (auto f : famVec) {
+        if (f->name() == "do_autorestore")
+            continue;
+        BOOST_CHECK_MESSAGE(f->get_flag().is_set(ecf::Flag::RESTORED),
+                            "Expected family " << f->absNodePath() << " to be restored");
+        BOOST_CHECK_MESSAGE(!f->get_flag().is_set(ecf::Flag::ARCHIVED),
+                            "Expected family " << f->absNodePath() << " to be restored");
+        BOOST_CHECK_MESSAGE(!fs::exists(f->archive_path()), "Expected file " << f->absNodePath() << " to be removed");
+        BOOST_CHECK_MESSAGE(!f->nodeVec().empty(), "Expected family " << f->absNodePath() << " to be restored");
+    }
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_autorestore_family.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestMeter.cpp 5.13.0-1/libs/simulator/test/TestMeter.cpp
--- 5.12.4-1/libs/simulator/test/TestMeter.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestMeter.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,100 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+/// Simulate definition files that are created on then fly. This us to validate
+/// Defs file, to check for correctness
+
+BOOST_AUTO_TEST_SUITE(SimulatorTestSuite)
+
+BOOST_AUTO_TEST_CASE(test_meter) {
+    cout << "Simulator:: ...test_meter\n";
+
+    // suite suite
+    //   clock real <todays date>
+    //   family family
+    //     task fc
+    //       meter hour 0 240
+    //       task half
+    //         trigger fc:hour >= 120
+    //   endfamily
+    // endsuite
+
+    // Initialise clock with todays date  then create a time attribute + minutes
+    // such that the task should only run once, in the next minute
+    boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
+
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(theLocalTime);
+        suite_ptr suite = theDefs.add_suite("test_meter");
+        suite->addClock(clockAttr);
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        family_ptr fam = suite->add_family("family");
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        task_ptr fc = fam->add_task("fc");
+        fc->addMeter(Meter("hour", 0, 240, 240));
+        fc->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        task_ptr half = fam->add_task("half");
+        half->add_trigger("fc:hour >= 120");
+        half->addVerify(VerifyAttr(NState::COMPLETE, 1));
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_meter.def"), errorMsg), errorMsg);
+
+    // The simulator will set all the meter values, so final value must be the max value.
+    bool found_task = false;
+    std::vector<Task*> theServerTasks;
+    theDefs.getAllTasks(theServerTasks);
+    for (Task* t : theServerTasks) {
+        if (t->name() == "fc") {
+            found_task                       = true;
+            const std::vector<Meter>& meters = t->meters();
+            BOOST_REQUIRE_MESSAGE(meters.size() == 1, "Expected one meter but found " << meters.size());
+            BOOST_CHECK_MESSAGE(meters[0].value() == meters[0].max(),
+                                "Expected meter to have value of " << meters[0].max() << " but found "
+                                                                   << meters[0].value());
+        }
+    }
+    BOOST_REQUIRE_MESSAGE(found_task, "Failed to find task fc ");
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_meter.def") + ".log";
+    fs::remove(logFileName);
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestRepeat.cpp 5.13.0-1/libs/simulator/test/TestRepeat.cpp
--- 5.12.4-1/libs/simulator/test/TestRepeat.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestRepeat.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,508 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+/// Simulate definition files that are created on then fly. This us to validate
+/// Defs file, to check for correctness
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_Repeat)
+
+BOOST_AUTO_TEST_CASE(test_repeat_integer) {
+    cout << "Simulator:: ...test_repeat_integer\n";
+
+    // suite suite
+    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     repeat integer VAR 0 1 1     # run at 0, 1     2 times
+    //     task t<n>
+    //     ....
+    //   endfamily
+    // endsuite
+
+    // Each task/job should be run *4* times, according to the repeats
+    // Mimics nested loops
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("suite");
+        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat contents 2 times
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1));   // repeat contents 2 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 4)); // verify family repeats 2 times
+        int taskSize = 2;
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr t = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            t->addVerify(VerifyAttr(NState::COMPLETE, 4)); // Each task should run 4 times
+        }
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_integer.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_integer.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_integer_relative) {
+    cout << "Simulator:: ...test_repeat_integer_relative\n";
+
+    // suite suite
+    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     repeat integer VAR 0 1 1     # run at 0, 1     2 times
+    //     task t1
+    //       time +0;02
+    //   endfamily
+    // endsuite
+
+    // Each task/job should be run *4* times relative to Node times, according to the repeats
+    // Mimics nested loops
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true /*false means use hybrid clock*/);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_repeat_integer_relative");
+        suite->addClock(clockAttr);
+        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat contents 2 times
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat contents 2 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 4));
+
+        task_ptr t = fam->add_task("t1");
+        t->addTime(ecf::TimeAttr(TimeSlot(0, 2), true /*relative*/));
+        t->addVerify(VerifyAttr(NState::COMPLETE, 4)); // Each task should run 4 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_integer_relative.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_integer_relative.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date) {
+    cout << "Simulator:: ...test_repeat_date\n";
+    // suite suite
+    //   clock real <fixed date + time>
+    //   family family
+    //     repeat date YMD 20091001  20091015 1  # yyyymmdd
+    //     task t
+    //       time 10:00
+    //   endfamily
+    // endsuite
+
+    // Each task should be run 15 times, ie every day at 10.00 am from  1st Oct->15 October 15 times
+    Defs theDefs;
+    {
+        ClockAttr clockAttr;
+        clockAttr.date(1, 10, 2009);
+        suite_ptr suite = theDefs.add_suite("test_repeat_date");
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatDate("YMD", 20091001, 20091015, 1)); // repeat contents 15 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 15));
+
+        task_ptr task = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 15)); // task should complete 15 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_date.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_2) {
+    cout << "Simulator:: ...test_repeat_date_2\n";
+    // suite suite
+    //   clock real <fixed date + time>
+    //   family family
+    //     repeat date YMD 20091015 20091001 -1
+    //     task t
+    //        time 10:00
+    //     endfamily
+    // endsuite
+
+    // Each task should be run 15 times, ie every day at 10.00 am
+    Defs theDefs;
+    {
+        ClockAttr clockAttr;
+        clockAttr.date(1, 10, 2015);
+        suite_ptr suite = theDefs.add_suite("test_repeat_date");
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatDate("YMD", 20091015, 20091001, -1)); // repeat contents 15 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 15));
+
+        task_ptr task = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 15)); // task should complete 15 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_date.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_for_loop) {
+    cout << "Simulator:: ...test_repeat_date_for_loop\n";
+
+    // suite suite
+    //   clock real <todays date>
+    //   repeat date YMD 20091001  20091005 1  # yyyymmdd
+    //   family family
+    //     repeat date YMD 20091001  20091005 1  # yyyymmdd
+    //     task t
+    //       time 10:00
+    //   endfamily
+    // endsuite
+
+    // Each task should be run 5 * 5= 25 times, ie every day from from 1st Oct -> 5 Oct 5*5 times
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_repeat_date_for_loop");
+        suite->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 5));
+
+        // start at specific time other wise time dependent checks will not verify
+        ClockAttr clockAttr;
+        clockAttr.date(1, 10, 2009);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 25));
+
+        task_ptr task = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 25)); // task should complete 25 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date_for_loop.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_date_for_loop.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_for_loop2) {
+    cout << "Simulator:: ...test_repeat_date_for_loop2\n";
+
+    // suite suite
+    //   clock real <todays date>
+    //   repeat date YMD 20091001  20091005 1  # yyyymmdd
+    //   family family
+    //     repeat date YMD 20091001  20091005 1  # yyyymmdd
+    //     task t
+    //       time 10:00
+    //       time 11:00
+    //   endfamily
+    // endsuite
+
+    // Each task should be run 5 * 5 * 2 = 50 times, ie every day from from 1st Oct -> 5 Oct 5*5 times * 2 time slots
+    Defs theDefs;
+    {
+        // start at specific time other wise time dependent checks will not verify
+        suite_ptr suite = theDefs.add_suite("test_repeat_date_for_loop2");
+        suite->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 5));
+
+        ClockAttr clockAttr;
+        clockAttr.date(1, 10, 2009);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatDate("YMD", 20091001, 20091005, 1)); // repeat contents 5 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 25));
+
+        task_ptr task = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
+        task->addTime(ecf::TimeAttr(TimeSlot(11, 0)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 50)); // task should complete 50 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date_for_loop2.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_date_for_loop2.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_list) {
+    cout << "Simulator:: ...test_repeat_date_list\n";
+    // suite suite
+    //   clock real <fixed date + time>
+    //   family family
+    //     repeat datelist YMD 20091001 20181001 20101001 # yyyymmdd
+    //     task t
+    //       time 10:00
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        ClockAttr clockAttr;
+        clockAttr.date(1, 10, 2009);
+        suite_ptr suite = theDefs.add_suite("test_repeat_date_list");
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatDateList("YMD", {20091001, 20181001, 20101001}));
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 3));
+
+        task_ptr task = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(10, 0)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 15 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_date.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_date.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_with_cron) {
+    cout << "Simulator:: ...test_repeat_with_cron\n";
+    // suite s
+    //   clock real <today date>
+    //   endclock <today date> + 1 week
+    //   family f
+    //     repeat date YMD 20091001 20091004 1  # yyyymmdd
+    //     family plot
+    //       complete plot/finish == complete
+    //
+    //       task finish
+    //         trigger 1 == 0    # stops task from running
+    //         complete checkdata::done or checkdata == complete
+    //
+    //       task checkdata
+    //         event done
+    //         cron <today date> + 2 minutes     # cron that run forever
+    //      endfamily
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        boost::posix_time::ptime theLocalTime       = Calendar::second_clock_time();
+        boost::posix_time::ptime time_plus_2_minute = theLocalTime + minutes(2);
+        ClockAttr clockAttr(theLocalTime, false /* real clock*/);
+        ClockAttr end_clock(theLocalTime + hours(24 * 7), false /* real clock*/);
+
+        suite_ptr suite = theDefs.add_suite("test_repeat_with_cron");
+        suite->addClock(clockAttr);
+        suite->add_end_clock(end_clock);
+
+        family_ptr f = suite->add_family("f");
+        f->addRepeat(RepeatDate("YMD", 20091001, 20091004, 1)); // repeat contents 4 times
+        f->addVerify(VerifyAttr(NState::COMPLETE, 4));
+
+        family_ptr family_plot = f->add_family("plot");
+        family_plot->add_complete("plot/finish ==  complete");
+        family_plot->addVerify(VerifyAttr(NState::COMPLETE, 4));
+
+        task_ptr task_finish = family_plot->add_task("finish");
+        task_finish->add_trigger("1 == 0");
+        task_finish->add_complete("checkdata:done or checkdata == complete");
+        task_finish->addVerify(VerifyAttr(NState::COMPLETE, 4));
+
+        task_ptr task_checkdata = family_plot->add_task("checkdata");
+        task_checkdata->addEvent(Event(1, "done"));
+
+        CronAttr cronAttr;
+        cronAttr.addTimeSeries(ecf::TimeSeries(ecf::TimeSlot(time_plus_2_minute.time_of_day())));
+        task_checkdata->addCron(cronAttr);
+        task_checkdata->addVerify(VerifyAttr(NState::COMPLETE, 8));
+
+        //		cout << theDefs << "\n";
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_REQUIRE_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_with_cron.def"), errorMsg),
+                          errorMsg << "\n"
+                                   << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_with_cron.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_enumerated) {
+    cout << "Simulator:: ...test_repeat_enumerated\n";
+    // suite suite
+    //   family family
+    //     repeat enumerated ENUM "hello" "there" "bill" # run 3 times
+    //     task t1
+    //   endfamily
+    // endsuite
+
+    // Each task/job should be run 3 according to the repeats
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_repeat_enumerated");
+
+        std::vector<std::string> theEnums;
+        theEnums.emplace_back("hello"); // index 0
+        theEnums.emplace_back("there"); // index 1
+        theEnums.emplace_back("bill");  // index 2
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatEnumerated("ENUM", theEnums)); // repeat contents 3 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 3));
+
+        task_ptr task = fam->add_task("t1");
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3));
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_enumerated.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    std::vector<Task*> theServerTasks;
+    theDefs.getAllTasks(theServerTasks);
+    for (Task* t : theServerTasks) {
+        // verify repeat has the last value
+        auto* family         = dynamic_cast<Family*>(t->parent());
+        const Repeat& repeat = family->findRepeat("ENUM");
+        BOOST_REQUIRE_MESSAGE(!repeat.empty(), "Expected to find repeat on family " << family->absNodePath());
+        BOOST_REQUIRE_MESSAGE(!repeat.valid(), "Expected invalid repeat");
+        BOOST_REQUIRE_MESSAGE(repeat.value() == 3, "Expected to find repeat with value 3 but found " << repeat.value());
+        BOOST_REQUIRE_MESSAGE(repeat.last_valid_value() == 2,
+                              "Expected to find repeat with last valid value 2 but found "
+                                  << repeat.last_valid_value());
+    }
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_enumerated.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_string) {
+    cout << "Simulator:: ...test_repeat_string\n";
+    // suite suite
+    //   family family
+    //     repeat string STRING "hello" "there" # run 2 times
+    //     task t1
+    //   endfamily
+    // endsuite
+
+    // Each task/job should be run 3 according to the repeats
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_repeat_string");
+
+        std::vector<std::string> theStrings;
+        theStrings.emplace_back("hello"); // index 0
+        theStrings.emplace_back("there"); // index 1
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatString("STRING", theStrings)); // repeat contents 2 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 2));
+
+        task_ptr task = fam->add_task("t1");
+        task->addVerify(VerifyAttr(NState::COMPLETE, 2));
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_repeat_string.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    std::vector<Task*> theServerTasks;
+    theDefs.getAllTasks(theServerTasks);
+    for (Task* t : theServerTasks) {
+        // verify repeat has the last value
+        auto* family         = dynamic_cast<Family*>(t->parent());
+        const Repeat& repeat = family->findRepeat("STRING");
+        BOOST_REQUIRE_MESSAGE(!repeat.empty(), "Expected to find repeat on family " << family->absNodePath());
+        BOOST_REQUIRE_MESSAGE(!repeat.valid(), "Expected invalid repeat");
+        BOOST_REQUIRE_MESSAGE(repeat.value() == 2, "Expected to find repeat with value 2 but found " << repeat.value());
+        BOOST_REQUIRE_MESSAGE(repeat.last_valid_value() == 1,
+                              "Expected to find repeat with last valid value 1 but found "
+                                  << repeat.last_valid_value());
+    }
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_repeat_string.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestSimulator.cpp 5.13.0-1/libs/simulator/test/TestSimulator.cpp
--- 5.12.4-1/libs/simulator/test/TestSimulator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestSimulator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,98 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_Simulator)
+
+void simulate(const std::string& directory, bool pass) {
+    auto full_path = fs::absolute(directory);
+
+    BOOST_CHECK(fs::exists(full_path));
+    BOOST_CHECK(fs::is_directory(full_path));
+
+    // std::cout << "\nIn directory: " << full_path.directory_string() << "\n\n";
+    fs::directory_iterator end_iter;
+    for (fs::directory_iterator dir_itr(full_path); dir_itr != end_iter; ++dir_itr) {
+
+        try {
+            fs::path relPath(directory + "/" + dir_itr->path().filename().string());
+
+            // recurse down directories
+            if (is_directory(dir_itr->status())) {
+                simulate(relPath.string(), pass);
+                continue;
+            }
+
+            // Only simulate file with .def file extension, i.e. ignore log files.
+            // cout << "path = " << relPath << "\n";
+            if (File::getExt(relPath.filename().string()) != "def" &&
+                File::getExt(relPath.filename().string()) != "got")
+                continue;
+
+            // std::cout << "...............Simulating file " << relPath.string() << "\n";
+            Simulator simulator;
+            std::string errorMsg;
+            bool simPass = simulator.run(relPath.string(), errorMsg);
+            if (pass) {
+                // Test expected to pass
+                BOOST_CHECK_MESSAGE(simPass, "Simulator expected to pass for " << relPath << "\n" << errorMsg);
+            }
+            else {
+                // test expected to fail
+                BOOST_CHECK_MESSAGE(!simPass, "Simulator expected to fail for " << relPath << "\n" << errorMsg);
+            }
+
+            // remove generated log file. Comment out to debug
+            std::string logFileName = relPath.string() + ".log";
+            fs::remove(logFileName);
+        }
+        catch (const std::exception& ex) {
+            std::cout << dir_itr->path().filename() << " " << ex.what() << std::endl;
+        }
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_simulate_good_defs) {
+    cout << "Simulator:: ...test_simulate_good_defs\n";
+
+    std::string path = File::test_data("libs/simulator/test/data/good_defs", "libs/simulator");
+
+    // All the defs in this directory are expected to pass
+    simulate(path, true);
+}
+
+BOOST_AUTO_TEST_CASE(test_simulate_bad_defs) {
+    cout << "Simulator:: ...test_simulate_bad_defs\n";
+
+    std::string path = File::test_data("libs/simulator/test/data/bad_defs", "libs/simulator");
+
+    // All the defs in this directory are expected to fail
+    simulate(path, false);
+
+    /// Destroy System singleton to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestSimulator_main.cpp 5.13.0-1/libs/simulator/test/TestSimulator_main.cpp
--- 5.12.4-1/libs/simulator/test/TestSimulator_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestSimulator_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Simulator
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/simulator/test/TestSingleSimulator.cpp 5.13.0-1/libs/simulator/test/TestSingleSimulator.cpp
--- 5.12.4-1/libs/simulator/test/TestSingleSimulator.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestSingleSimulator.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,92 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/System.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_SingleSimulator)
+
+BOOST_AUTO_TEST_CASE(test_analysys, *boost::unit_test::disabled()) {
+    cout << "Simulator:: ...test_analysys\n";
+    // suite suite
+    //   family family
+    //     task t1
+    //       trigger t2 == complete
+    //     task t2
+    //       trigger t1 == complete
+    //   endfamily
+    // endsuite
+
+    // This simulation is expected to fail, since we have a deadlock/ race condition
+    // It will prodice a defs.depth and defs.flat files. Make sure to remove them
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_analysys");
+        family_ptr fam  = suite->add_family("family");
+
+        task_ptr task1 = fam->add_task("t1");
+        task1->add_trigger("t2 == complete");
+
+        task_ptr task2 = fam->add_task("t2");
+        task2->add_trigger("t1 == complete");
+
+        //    cout << theDefs << "\n";
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(!simulator.run(theDefs, findTestDataLocation("test_analysys.def"), errorMsg), errorMsg);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_analysys.def") + ".log";
+    fs::remove(logFileName);
+
+    // cout << theDefs << "\n";
+    fs::remove("defs.depth");
+    fs::remove("defs.flat");
+
+    /// Destroy singleton's to avoid valgrind from complaining
+    System::destroy();
+}
+
+BOOST_AUTO_TEST_CASE(test_single_from_file) {
+    cout << "Simulator:: ...test_single_from_file\n";
+
+    std::string path = File::test_data("libs/simulator/test/data/good_defs/day/family.def", "libs/simulator");
+
+    Simulator simulator;
+    std::string errorMsg;
+    bool passed = simulator.run(path, errorMsg);
+
+    BOOST_REQUIRE_MESSAGE(passed, path << " failed simulation \n" << errorMsg);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestSingleSimulator_main.cpp 5.13.0-1/libs/simulator/test/TestSingleSimulator_main.cpp
--- 5.12.4-1/libs/simulator/test/TestSingleSimulator_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestSingleSimulator_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_SingleSimulator
+#include <boost/test/included/unit_test.hpp>
diff -pruN 5.12.4-1/libs/simulator/test/TestTime.cpp 5.13.0-1/libs/simulator/test/TestTime.cpp
--- 5.12.4-1/libs/simulator/test/TestTime.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestTime.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,395 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+/// Simulate definition files that are created on then fly. This allows us to create
+/// tests with todays date/time this speeds up the testr, we can also validate
+/// Defs file, to check for correctness
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_Time)
+
+BOOST_AUTO_TEST_CASE(test_time) {
+    cout << "Simulator:: ...test_time\n";
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       time <start>
+    //   endfamily
+    // endsuite
+
+    // Initialise clock with todays date  then create a time attribute + minutes
+    // such that the task should only run once, in the next minute
+    boost::posix_time::ptime theLocalTime     = Calendar::second_clock_time();
+    boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
+
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_time");
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_minute.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // expect task to complete 1 time
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_time.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_time_series) {
+    cout << "Simulator:: ...test_time_series\n";
+
+    // suite suite
+    //   clock real <sunday>
+    //   family family
+    //     task t1
+    //     time 00:30 23:59 04:00  # should run 6 times 00:30 4:30 8:30 12:30 16:30 20:30
+    //   endfamily
+    // endsuite
+
+    // Initialise real clock on a Moday, such that task should _only_ run
+    // on Monday since we are using a hybrid clock
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true /*false means use hybrid clock*/);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_time_series");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        TimeSeries timeSeries(TimeSlot(00, 30), TimeSlot(23, 59), TimeSlot(4, 0), false /* relative */);
+
+        task->addTime(TimeAttr(timeSeries));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 6)); // expect task to complete 6 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time_series.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_time_series.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_time_and_date) {
+    cout << "Simulator:: ...test_time_and_date\n";
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       date  <today date>
+    //       time <start>
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        // Initialise clock with todays date  then create a time attribute + minutes
+        // such that the task should only run once, in the next minute
+        boost::posix_time::ptime theLocalTime     = Calendar::second_clock_time();
+        boost::gregorian::date todaysDate         = theLocalTime.date();
+        boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
+
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite_ptr suite = theDefs.add_suite("test_time_and_date");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addDate(DateAttr(todaysDate));
+        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_minute.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // expect task to complete 1 time
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time_and_date.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_time_and_date.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_time_and_tomorrows_date) {
+    cout << "Simulator:: ...test_time_and_tomorrows_date\n";
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       date  <tomorrows date>
+    //       time <start>
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        // Initialise clock with todays date  then create a time attribute + minutes
+        // such that the task should only run once, in the next minute
+        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
+        boost::gregorian::date tomorrows_date = theLocalTime.date();
+        tomorrows_date += days(1);
+        boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
+
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite_ptr suite = theDefs.add_suite("test_time_and_tomorrows_date");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addDate(DateAttr(tomorrows_date));
+        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_minute.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // expect task to complete 1 time
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_time_and_tomorrows_date.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_time_and_tomorrows_date.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_multiple_times_and_dates) {
+    cout << "Simulator:: ...test_multiple_times_and_dates\n";
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       date <today date>
+    //       date <tomorrows date>
+    //       time <start>
+    //       time <start>
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with todays date  then create a time attribute + minutes
+        // Note: we don't use:
+        //    boost::posix_time::ptime   theLocalTime =  Calendar::second_clock_time();
+        // because if run at late we can end up with illegal for the hour, ie. > 24
+
+        boost::gregorian::date todaysDate(2009, 2, 10);
+        ptime theLocalTime(todaysDate, hours(3));
+        boost::gregorian::date tomarrows_date           = todaysDate + date_duration(1);
+        boost::posix_time::time_duration td_plus_minute = theLocalTime.time_of_day() + minutes(1);
+        boost::posix_time::time_duration td_plus_hour   = theLocalTime.time_of_day() + hours(1);
+
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_dates");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addDate(DateAttr(todaysDate));
+        task->addDate(DateAttr(tomarrows_date));
+        task->addTime(TimeAttr(TimeSlot(td_plus_minute)));
+        task->addTime(TimeAttr(TimeSlot(td_plus_hour)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // expect task to complete 4 time
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_dates.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_multiple_times_and_dates.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_multiple_times_and_dates_hybrid) {
+    cout << "Simulator:: ...test_multiple_times_and_dates_hybrid\n";
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   clock hybrid <todays date>
+    //   family family
+    //     task t1
+    //       date  <today date>
+    //       date  <tomrrows date>
+    //       time <start>
+    //       time <start>
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with todays date  then create a time attribute + minutes
+        // such that the task should only run once, in the next minute
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2012, 2, 22), time_duration(10, 20, 0));
+        boost::gregorian::date todaysDate     = theLocalTime.date();
+        boost::gregorian::date tomorrows_date = todaysDate + date_duration(1);
+        boost::posix_time::time_duration td_plus_minute    = theLocalTime.time_of_day() + minutes(1);
+        boost::posix_time::time_duration td_plus_10_minute = theLocalTime.time_of_day() + minutes(10);
+
+        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_dates_hybrid");
+        suite->addClock(ClockAttr(theLocalTime, true)); // true means use hybrid clock
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addDate(DateAttr(todaysDate));
+        task->addDate(DateAttr(tomorrows_date));
+        task->addTime(TimeAttr(TimeSlot(td_plus_minute)));
+        task->addTime(TimeAttr(TimeSlot(td_plus_10_minute)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 2)); // expect task to complete 2 time
+                                                          // cout << theDefs << "\n";
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(
+        simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_dates_hybrid.def"), errorMsg),
+        errorMsg << "\n"
+                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_multiple_times_and_dates_hybrid.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_multiple_times_and_days) {
+    cout << "Simulator:: ...test_multiple_times_and_days\n";
+
+    // suite suite
+    //   clock real <sunday>
+    //   family family
+    //     rep integer 0 1 1 # repeat twice
+    //     task t1
+    //       day  monday
+    //       day  tuesday
+    //       time <start>
+    //       time <start>
+    //   endfamily
+    // endsuite
+
+    // Initialise real clock on a sunday, such that task should run on Monday & tuesday twice
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(false /*false means use real clock*/);
+        clockAttr.date(11, 10, 2009); // 11 October 2009 was a sunday
+        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_days");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        // fam->addRepeat( RepeatInteger("rep",0,1,1) );
+        task_ptr task = fam->add_task("t");
+        task->addDay(DayAttr(DayAttr::MONDAY));
+        task->addDay(DayAttr(DayAttr::TUESDAY));
+        task->addTime(TimeAttr(TimeSlot(10, 0)));
+        task->addTime(TimeAttr(TimeSlot(20, 0)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // expect task to complete 4 time
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_days.def"), errorMsg),
+                        errorMsg << "\n"
+                                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_multiple_times_and_days.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_multiple_times_and_days_hybrid) {
+    cout << "Simulator:: ...test_multiple_times_and_days_hybrid\n";
+
+    // suite suite
+    //   clock hybrid <monday>
+    //   family family
+    //     task t1
+    //       day  monday
+    //       day  tuesday
+    //       time <start>
+    //       time <start>
+    //   endfamily
+    // endsuite
+
+    // Initialise real clock on a Monday, such that task should _only_ run
+    // on Monday since we are using a hybrid clock
+    Defs theDefs;
+    {
+        ClockAttr clockAttr(true /*false means use hybrid clock*/);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite_ptr suite = theDefs.add_suite("test_multiple_times_and_days_hybrid");
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addDay(DayAttr(DayAttr::MONDAY));
+        task->addDay(DayAttr(DayAttr::TUESDAY));
+        task->addTime(TimeAttr(TimeSlot(10, 0)));
+        task->addTime(TimeAttr(TimeSlot(11, 0)));
+        task->addTime(TimeAttr(TimeSlot(20, 0)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // expect task to complete 3 times
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(
+        simulator.run(theDefs, findTestDataLocation("test_multiple_times_and_days_hybrid.def"), errorMsg),
+        errorMsg << "\n"
+                 << theDefs);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_multiple_times_and_days_hybrid.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestToday.cpp 5.13.0-1/libs/simulator/test/TestToday.cpp
--- 5.12.4-1/libs/simulator/test/TestToday.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestToday.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,160 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "TestUtil.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+#include "ecflow/simulator/Simulator.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+/// Simulate definition files that are created on then fly. This allows us to create
+/// tests with todays date/time this speeds up the testr, we can also validate
+/// Defs file, to check for correctness
+
+BOOST_AUTO_TEST_SUITE(S_Simulator)
+
+BOOST_AUTO_TEST_SUITE(T_Today)
+
+BOOST_AUTO_TEST_CASE(test_today) {
+    cout << "Simulator:: ...test_today\n";
+
+    // suite suite
+    //   clock real <fixed date>
+    //   family family
+    //     task t1
+    //       today <start>  # +1 minute
+    //       today <start>  # +2 minute
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock   then create a today attribute + minutes
+        // such that the task should only run once, in the next minute
+        ptime theLocalTime                        = boost::posix_time::ptime(date(2010, 6, 21), time_duration(1, 2, 0));
+        boost::posix_time::ptime time_plus_minute = theLocalTime + minutes(1);
+        boost::posix_time::ptime time_plus_10_minute = theLocalTime + minutes(10);
+
+        suite_ptr suite = theDefs.add_suite("test_today");
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_minute.time_of_day())));
+        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_10_minute.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 2)); // expect task to complete 2 time
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    bool result = simulator.run(theDefs, findTestDataLocation("test_today.def"), errorMsg);
+
+    BOOST_CHECK_MESSAGE(result, errorMsg);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_today.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_today_time_series) {
+    cout << "Simulator:: ...test_today_time_series\n";
+
+    // suite suite
+    //   clock real <monday>
+    //   family family
+    //     task t1
+    //       today 00:30 18:59 04:00  # should run 5 times 00:30 4:30 8:30 12:30 16:30
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_today_time_series");
+        ClockAttr clockAttr(true /*false means use hybrid clock*/);
+        clockAttr.date(12, 10, 2009); // 12 October 2009 was a Monday
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        TimeSeries timeSeries(TimeSlot(00, 30), TimeSlot(18, 59), TimeSlot(4, 0), false /* relative */);
+
+        task->addToday(TodayAttr(timeSeries));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 5));
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_today_time_series.def"), errorMsg), errorMsg);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_today_time_series.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_CASE(test_today_time_and_date) {
+    cout << "Simulator:: ...test_today_time_and_date\n";
+
+    // suite suite
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       date  <today date>
+    //       time  <start>
+    //       today <start>
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // To speed up simulation: start calendar with hour increment AND time attributes with hours only
+        //
+        // Task will only run if all time dependencies are satisfied
+        boost::posix_time::ptime theLocalTime   = ptime(date(2010, 2, 10), hours(15));
+        boost::gregorian::date todaysDate       = theLocalTime.date();
+        boost::posix_time::ptime time_plus_hour = theLocalTime + hours(1);
+
+        suite_ptr suite = theDefs.add_suite("test_today_time_and_date");
+        ClockAttr clockAttr(theLocalTime, false /*false means use real clock*/);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addDate(DateAttr(todaysDate));
+        task->addTime(ecf::TimeAttr(TimeSlot(time_plus_hour.time_of_day())));
+        task->addToday(ecf::TodayAttr(TimeSlot(time_plus_hour.time_of_day())));
+
+        task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+    }
+
+    Simulator simulator;
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(simulator.run(theDefs, findTestDataLocation("test_today_time_and_date.def"), errorMsg),
+                        errorMsg);
+
+    // remove generated log file. Comment out to debug
+    std::string logFileName = findTestDataLocation("test_today_time_and_date.def") + ".log";
+    fs::remove(logFileName);
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/simulator/test/TestUtil.cpp 5.13.0-1/libs/simulator/test/TestUtil.cpp
--- 5.12.4-1/libs/simulator/test/TestUtil.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestUtil.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "TestUtil.hpp"
+
+#include "ecflow/core/File.hpp"
+
+using namespace std;
+using namespace ecf;
+
+std::string findTestDataLocation(const std::string& defsFile) {
+    std::string testData = File::test_data("libs/simulator/test/data", "libs/simulator");
+    testData += "/";
+    testData += defsFile;
+    return testData;
+}
diff -pruN 5.12.4-1/libs/simulator/test/TestUtil.hpp 5.13.0-1/libs/simulator/test/TestUtil.hpp
--- 5.12.4-1/libs/simulator/test/TestUtil.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/TestUtil.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_simulator_test_TestUtil_HPP
+#define ecflow_simulator_test_TestUtil_HPP
+
+#include <string>
+
+/// Returns the location of the defs file, such thats it in the test data area
+std::string findTestDataLocation(const std::string& defsFile);
+
+#endif /* ecflow_simulator_test_TestUtil_HPP */
diff -pruN 5.12.4-1/libs/simulator/test/data/bad_defs/impossible_day.def 5.13.0-1/libs/simulator/test/data/bad_defs/impossible_day.def
--- 5.12.4-1/libs/simulator/test/data/bad_defs/impossible_day.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/bad_defs/impossible_day.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite csim_repeat_day3
+  clock real 04.08.2019            # Sunday
+  endclock   04.09.2019            # added endclock to avoid simulation for a year due to repeat
+  family f
+    repeat integer rep 0 1
+    family f1
+       day monday
+       task t1
+            day tuesday            # cant be free on Monday and Tuesday, 
+            time 10:00   
+            verify complete:0     
+    endfamily
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/bad_defs/today.def 5.13.0-1/libs/simulator/test/data/bad_defs/today.def
--- 5.12.4-1/libs/simulator/test/data/bad_defs/today.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/bad_defs/today.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+suite suiteName
+   family familyName0
+   		today 15:00
+   		today 23:59 00:00 00:30  # start should be less than finish
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/1628.def 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/1628.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/1628.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/1628.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+suite ecflow__1628
+  clock    real 20.04.2020     # Monday
+  endclock      27.04.2020     # Monday, add endclock otherwise we simulate for year due to repeat.
+
+  task t1 ;  day monday ;    verify complete:1      
+  task t2 ;  day tuesday ;   verify complete:1        
+  task t3 ;  day wednesday ; verify complete:1        
+  task t4 ;  day thursday ;  verify complete:1       
+  task t5 ;  day friday ;    verify complete:1       
+  task t6 ;  day saturday ;  verify complete:1        
+  task t7 ;  day sunday ;    verify complete:1  
+  
+  task t11 ;  day monday ;    day tuesday ;   verify complete:2        
+  task t21 ;  day tuesday ;   day monday ;    verify complete:2        
+  task t31 ;  day wednesday ; day tuesday ;   verify complete:2        
+  task t41 ;  day thursday ;  day wednesday ; verify complete:2        
+  task t51 ;  day friday ;    day thursday ;  verify complete:2        
+  task t61 ;  day saturday ;  day friday ;    verify complete:2        
+  task t71 ;  day sunday ;    day saturday ;  verify complete:2  
+
+  task t72 ;  day sunday ; day monday ; day tuesday ; day wednesday ; day thursday ; day friday ; day saturday ;  verify complete:7  
+
+  family fam
+    verify complete:2      
+    day sunday 
+    day tuesday  
+    time 08:00
+    task t1
+        verify complete:2 
+   endfamily
+        
+  family fam2
+    verify complete:14 
+    day sunday ; day monday ; day tuesday ; day wednesday ; day thursday ; day friday ; day saturday ; 
+    time 08:00
+    time 09:00
+    task t1
+        verify complete:14        
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/1638.def 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/1638.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/1638.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/1638.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,18 @@
+#5.4.0
+suite ECFLOW_1638
+  clock real 1.5.2020
+  endclock 3.5.2020
+  task t2
+    date 1.5.2010
+    date 1.5.2011
+    verify complete:0
+  task t3
+    time 23:00
+    verify complete:1
+  task t4
+    cron 23:00
+    verify complete:2
+  task t5
+    cron 10:00 20:00 01:00
+    verify complete:22
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-130.def 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-130.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-130.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-130.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+# 4.0.3
+suite radarlvl2
+  clock real 1.1.2014  # need to define a date otherwise log file/verify content varies according to the time 
+  # repeat day 1
+  family prod
+    task jradar_level2_cleanup
+      time 00:10 21:10 03:00
+      verify complete:8
+    task jradar_reflectivity_mosaic
+      event release_mosaic
+      time 00:20 23:20 01:00
+      verify complete:24
+    task jradar_reflectivity_ref2grb
+      trigger /radarlvl2/prod/jradar_reflectivity_mosaic:release_mosaic
+      verify complete:24
+      time 00:20 23:20 01:00
+    task jradar_canrad
+      time 00:05 23:55 00:10
+      verify complete:144
+    task jradar_level2
+      time 00:10 23:55 00:15
+      verify complete:96
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-1628.def 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-1628.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-1628.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-1628.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,108 @@
+suite ecflow_1628
+  clock real 20.04.2020     # Monday
+  family barrier
+    repeat enumerated YMD 1 2 3 4 5 6 7
+    verify complete:7
+    family start
+      complete start/0 == complete and start/1 == complete and start/2 == complete and start/3 == complete and start/4 == complete and start/5 == complete and start/6 == complete
+      family 0
+        verify complete:7
+        time 23:00
+        day monday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 1
+        verify complete:7
+        time 23:00
+        day tuesday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 2
+        verify complete:7
+        time 23:00
+        day wednesday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 3
+        verify complete:7
+        time 23:00
+        day thursday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 4
+        verify complete:7
+        time 23:00
+        day friday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 5
+        verify complete:7
+        time 23:00
+        day saturday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+      family 6
+        verify complete:7
+        time 23:00
+        day sunday
+        task t1
+        task t2
+           trigger ./t1 == complete
+        task t3
+           trigger ./t2 == complete
+        task t4
+           trigger ./t3 == complete
+        task t5
+           trigger ./t4 == complete
+      endfamily
+    endfamily
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-833.def 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-833.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-833.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/JIRA/ECFLOW-833.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,28 @@
+suite Icemap2_to_DB_ecflow_833
+  clock    real 04.12.2016     # Sunday
+  endclock      09.12.2016     # Saturday, and endclock otherwise we simulate for year due to repeat.
+  repeat enumerated VARIABLE first        
+
+  family icemap
+
+    verify complete:2  # after Monday@8am we re-queue due to future time dependency     
+    day monday
+    day thursday
+    time 08:00
+     
+    task from_Icemap2
+        verify complete:2        # task should complete twice
+
+    task load_to_DB
+        trigger from_Icemap2 == complete
+        verify complete:2        # task should complete twice
+
+    task sleep
+        trigger load_to_DB == complete
+        verify complete:2        # task should complete twice
+
+    task clean
+        trigger sleep == complete
+        verify complete:2        # task should complete twice
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/SingleDefsTest/test.def 5.13.0-1/libs/simulator/test/data/good_defs/SingleDefsTest/test.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/SingleDefsTest/test.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/SingleDefsTest/test.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+   suite suite
+      clock hybrid 6.11.2009 +54190
+      family family
+         task t
+            verify complete:3
+            time +00:01 00:03 00:01
+      endfamily
+   endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite cron              # use real clock otherwise the date will change
+   clock real 1.1.2006  # need to define a date otherwise log file content varies according to the time 
+   endclock   2.1.2006  # When to finish.
+   family cronFamily
+		task t
+  			 cron 10:00 20:00 01:00  
+  			 verify complete:11      # verify tasks complete 11 times. 		
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron2.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron2.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite cron2              # use real clock otherwise the date wont change
+   clock real 1.1.2017   # need to define a date otherwise log file content varies according to the time 
+   endclock   3.1.2017   # When to finish. 
+   family cronFamily
+		task t
+  			 cron -w 0,1 10:00 11:00 01:00          # run every Sunday & Monday at 10 and 11 am	
+  			 verify complete:4                      # task should complete 16 times	
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron3.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron3.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite cron3              # use real clock otherwise the date wont change
+   clock real  1.1.2006  # need to define a date otherwise log file content varies according to the time 
+   endclock   13.1.2006  # When to finish. 
+   family cronFamily
+		task t
+  			 cron -d 10,11,12   10:00 11:00 01:00   # run  10,11,12 of the month at 10am and 11 am		
+             verify complete:6                      # task should complete 6 times 
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron4.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron4.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron4.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron4.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite cron4             # use real clock otherwise the date wont change
+   clock real 1.1.2017  # need to define a date otherwise log file content varies according to the time 
+   endclock   1.2.2017  # When to finish. 
+   family cronFamily
+		task t
+  			 cron -m 1   10:00 11:00 01:00   # run every day at 10 and 11 for Jan	
+  			 verify complete:62              # Jan has 31 days hence expect task completeion 62 times
+   endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron5.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron5.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron5.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron5.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite cron5              # use real clock otherwise the date wont change
+   clock real 1.10.2009  # need to define a date otherwise log file content varies according to the time 
+   endclock   1.11.2009  # When to finish. 
+   family cronFamily
+		task t
+  			 cron -w 0  -m 10   10:00 11:00 01:00   # run every sunday in October at 10 and 11am
+  			 verify complete:8		                # 4 sundays in october hence expect 8 task completions
+   endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron6.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron6.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron6.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron6.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite cron6              
+  clock real  1.1.2006 # Define a start date for deterministic simulation 
+  endclock   17.1.2006 # When to finish. Otherwise we simulate for 1 year due to cron. Ok but wasteful.
+  family cronFamily
+    task t
+  	  cron -d 15,16  -m 1 10:00 11:00 01:00  # run 15,16 January at 10 and 11am	
+      verify complete:4	
+   endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron7.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron7.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/cron7.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/cron7.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,19 @@
+suite cron7           # use real clock otherwise the date wont change
+ clock real 1.1.2017  # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2018  # When to finish. 
+ family cronFamily
+  task t
+   cron -d 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:00 # run every day for a year
+   verify complete:365
+ endfamily
+endsuite
+
+suite leap_year       # use real clock otherwise the date wont change
+ clock real 1.1.2016  # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2017  # When to finish. 
+ family cronFamily
+  task t
+   cron -d 1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31 -m 1,2,3,4,5,6,7,8,9,10,11,12 10:00  # run every day for a year
+   verify complete:366 # leap year has 366 days
+ endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/last.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/last.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/last.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/last.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,98 @@
+suite cron            # use real clock otherwise the date wont change
+ clock real 1.1.2019  # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020  # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   cron -d L 10:00    # run on the last of the month
+   verify complete:12
+ endfamily
+endsuite
+
+suite cron1            # use real clock otherwise the date wont change
+ clock real 1.1.2019  # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020  # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   cron -w 0L 10:00    # run on the last sunday of each month
+   verify complete:12
+ endfamily
+endsuite
+
+suite cron2             # use real clock otherwise the date wont change
+ clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   cron -d 1,L 10:00    # run on the first and last of the month
+   verify complete:24
+ endfamily
+endsuite
+
+suite cron3             # use real clock otherwise the date wont change
+ clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   cron -w 0L,1L,2L,3L,4L,5L,6L 10:00  # run on the last Monday,Tuesdat..Saturday,Sunday of the month
+   verify complete:84
+ endfamily
+endsuite
+
+suite cron4             # use real clock otherwise the date wont change
+ clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   # run on the last thursday and Last of the month, this only occurs 3 times in a year
+   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
+   cron -w 4L -d L 10:00    
+    
+   # In 2019, thursday was last of month 3 times
+   verify complete:3   
+ endfamily
+endsuite
+
+suite cron5             # use real clock otherwise the date wont change
+ clock real 1.1.2019     # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020     # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   cron -w 0,1L -m 1  10:00 # run every sunday and last Monday of the month, in January
+   verify complete:5
+ endfamily
+endsuite
+
+suite cron6             # use real clock otherwise the date wont change
+ clock real 1.1.2019     # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020     # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
+   # There is *ONLY* one day in January, i.e Thursday 31 of january
+   cron -w 0,1,2,3,4,5,6L -d L -m 1 10:00 
+   verify complete:1
+ endfamily
+endsuite
+
+suite cron7              # use real clock otherwise the date wont change
+ clock real 1.1.2019     # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020     # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   # expect 0 days, since last of the month in January is a thursday, and thursday is missing from day of the week
+   cron -w 0,1,2,3,5,6L -d L -m 1  10:00  
+   verify complete:0
+ endfamily
+endsuite
+
+suite cron8             # use real clock otherwise the date wont change
+ clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   # run on the last saturday and Last of the month, this only occurs 2 times in a year
+   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
+   cron -w 6L -d L 10:00    
+   verify complete:2
+ endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/cron/last3.def 5.13.0-1/libs/simulator/test/data/good_defs/cron/last3.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/cron/last3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/cron/last3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite cron4             # use real clock otherwise the date wont change
+ clock real 1.1.2019    # need to define a date otherwise log file content varies according to the time 
+ endclock   1.1.2020    # When to finish. Cant use 31.12.2019, otherwise duration is 31.12.2019 - 1.1.2019 , short by one day
+ family cronFamily
+  task t
+   # run on the last saturday and Last of the month, this only occurs 2 times in a year
+   # Remember we *AND* accross -w, -d, -m or *OR* for each element in -w, -d,-m
+   cron -w 6L -d L 10:00    
+   verify complete:2
+ endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/Repeat.def 5.13.0-1/libs/simulator/test/data/good_defs/day/Repeat.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/Repeat.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/Repeat.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,29 @@
+suite csim_repeat_day
+  clock real 04.08.2019            # Sunday
+  endclock   13.08.2019            # added endclock to avoid simulation for a year due to repeat
+  family f
+    repeat integer rep 0 1
+    family f1
+       day monday                   # This acts like a guard over time attributes. They are not freed until day is free
+       task t1
+            time 10:00   
+            time 12:00   
+            verify complete:4      
+    endfamily
+  endfamily
+endsuite
+
+suite csim_repeat_day3
+  clock real 04.08.2019   # Sunday
+  endclock   31.08.2019   # added endclock to avoid simulation for a year due to repeat
+  family f
+    repeat integer rep 0 1
+    family f1
+       repeat integer rep 0 1
+       task t1
+            time 11:00   
+            day monday          
+            verify complete:4     
+    endfamily
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/day.def 5.13.0-1/libs/simulator/test/data/good_defs/day/day.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/day.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/day.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite day_suite
+ clock real 11.10.2009   # 11 October 2009 was a Sunday, task x should hold for a day
+ family family
+   verify complete:1     # family should complete once
+   task y
+     verify complete:1        # task should complete once
+   task x
+     trigger ./y == complete
+	  time 01:00
+ 	  day monday               # simulate for 1 week, due to day
+ 	  verify complete:1        # task should complete once
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/family.def 5.13.0-1/libs/simulator/test/data/good_defs/day/family.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/family.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/family.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite family
+  clock real 04.08.2019   # Sunday
+  endclock   13.08.2019   # added endclock to avoid simulation for a year due to repeat
+  family f1
+       time 10:00   
+       time 11:00   
+       task t1
+            day monday         # run at midnight 1 time  
+            verify complete:1    
+    endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/hybrid_day.def 5.13.0-1/libs/simulator/test/data/good_defs/day/hybrid_day.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/hybrid_day.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/hybrid_day.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite suite
+  clock hybrid 11.10.2009  # 11 october 2009 was a sunday, task x should complete on begin
+  endclock     13.10.2009  # end time
+  family family
+ 	verify complete:1
+ 	task y
+ 	  verify complete:1
+ 	task x
+	  trigger ./y == complete
+ 	  day monday
+ 	  verify complete:1
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/multiple_days.def 5.13.0-1/libs/simulator/test/data/good_defs/day/multiple_days.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/multiple_days.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/multiple_days.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite multiple
+  clock real 04.12.2016            # Sunday
+  endclock   09.12.2016            # Friday added endclock to avoid simulation for a year due to repeat
+  repeat enumerated VARIABLE first # with repeat max duration is 8760 hours, i.e 1 year
+  family f    
+    day monday                     
+    day thursday                    
+    task t                         # run monday and thursday morning
+       verify complete:2  
+    task t2
+       trigger ./t == complete
+       verify complete:2  
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/repeat2.def 5.13.0-1/libs/simulator/test/data/good_defs/day/repeat2.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/repeat2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/repeat2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite csim_repeat_day2
+  clock real 04.08.2019   # Sunday
+  endclock   13.08.2019   # added endclock to avoid simulation for a year due to repeat
+  family f
+    repeat integer rep 0 1
+    family f1
+       time 10:00   
+       time 11:00              # no guard so has no effect
+       task t1
+            day monday         # run at midnight, 2 times  
+            verify complete:2     
+    endfamily
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/repeat3.def 5.13.0-1/libs/simulator/test/data/good_defs/day/repeat3.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/repeat3.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/repeat3.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,13 @@
+suite csim_repeat_day2
+  clock real 04.08.2019        # Sunday
+  endclock   13.08.2019        # added endclock to avoid simulation for a year due to repeat
+  family f
+    repeat integer rep 0 1
+    family f1
+       time 08:00 20:00 01:00  # no guard so has no effect
+       task t1
+            day monday         # run at midnight, 2 times  
+            verify complete:2     
+    endfamily
+  endfamily
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/simple.def 5.13.0-1/libs/simulator/test/data/good_defs/day/simple.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/simple.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/simple.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite simple
+ clock real 19.04.2020   #  was a Sunday,  
+ family family
+   verify complete:1     # family should complete once
+   task t
+     day monday               # simulate for 1 week, due to day
+     verify complete:1        # task should complete once
+ endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/day/simple2.def 5.13.0-1/libs/simulator/test/data/good_defs/day/simple2.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/day/simple2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/day/simple2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite simple
+  clock    real 19.04.2020     # Sunday
+  endclock      27.04.2020     # Monday, add endclock otherwise we simulate for year due to repeat.
+      
+      family 0
+        verify complete:1
+        time 23:00
+        day monday
+        task t1
+        task t2
+           trigger ./t1 == complete
+      endfamily   
+endsuite
+
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/event/event.def 5.13.0-1/libs/simulator/test/data/good_defs/event/event.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/event/event.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/event/event.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+suite suite
+  clock real 5.1.2017        
+  family family
+     task t1
+        event event
+        event event_set set
+        verify complete:1
+     task t2
+        trigger t1:event
+        verify complete:1
+     task t3
+        trigger t2 == complete and t1:event_set == clear
+        verify complete:1
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/misc/defstatus.def 5.13.0-1/libs/simulator/test/data/good_defs/misc/defstatus.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/misc/defstatus.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/misc/defstatus.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite test_repeat_defstatus
+  clock real 04.12.2016             
+  defstatus complete       # this should cause node state complete down the hierarchy  
+  repeat integer VAR 0 1 1           
+  edit SLEEPTIME 1
+  edit ECF_INCLUDE $ECF_HOME/includes
+  verify complete:1
+  family family
+     verify complete:1
+     repeat integer VAR 0 2 1        
+     task t1
+       verify complete:1
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/misc/lifecycle.def 5.13.0-1/libs/simulator/test/data/good_defs/misc/lifecycle.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/misc/lifecycle.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/misc/lifecycle.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite suite1
+  family family1
+   	task a
+        event 1 myEvent
+        meter myMeter 0 100
+   	task b
+   		trigger a == complete
+   endfamily
+   family family2
+   		task aa
+   			trigger ../family1/a:myMeter >= 20 and ../family1/a:myEvent 
+   		task bb
+   			trigger ../family1/a:myMeter >= 50  or  ../family1/a:myEvent
+    endfamily
+endsuite
+
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/operations/loop.def 5.13.0-1/libs/simulator/test/data/good_defs/operations/loop.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/operations/loop.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/operations/loop.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,24 @@
+# This file was taken from one of operational suites
+  
+suite limits
+  defstatus complete
+  clock hybrid 0 # 01.07.2009 14:47
+  limit metis 6
+endsuite
+
+suite admin
+  #defstatus suspended
+  clock hybrid  22.12.2005   # run at midnight to ensure test is deterministice
+  inlimit /limits:metis
+  
+  family daily
+    repeat date YMD 20070115 20070118 1 #  run 4 times
+ 	verify complete:4
+    family check
+ 	  verify complete:4          # make sure it actually ran 4 times
+      task rcp
+        time 00:00 23:59 00:10   # Note: finish minute (59) is not a multiple of the increment 10, last time is 23:50
+ 	    verify complete:576       # 576 = 24(hours) * 6( completions per hour) * 4 times
+ 	endfamily
+  endfamily
+endsuite 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/operations/mars.def 5.13.0-1/libs/simulator/test/data/good_defs/operations/mars.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/operations/mars.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/operations/mars.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,10 @@
+suite mars
+  clock hybrid 01.07.2009  
+  family archive
+  	repeat integer fred 1 1 
+    task grib
+      verify complete:6        # 00:30 4:30 8:30 12:30 16:30 20:30
+      time 00:30 23:59 04:00   #
+   endfamily
+endsuite
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/operations/naw.def 5.13.0-1/libs/simulator/test/data/good_defs/operations/naw.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/operations/naw.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/operations/naw.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,208 @@
+#============================================================
+suite weather
+  clock hybrid -3542400 # 29.08.2009 16:54
+  # repeat day 1 # status 0   ************** DISABLED SO THAT SUITE CAN COMPLETE *****************
+  edit SMSTRIES '2'
+  edit SMSCMD 'smssubmit.x %SMSJOB% hades rdx'
+  edit SMSHOME '/vol/rdx_dir/mars_stats/sms'
+  edit SMSINCLUDE '/vol/rdx_dir/mars_stats/sms/include'
+  edit SMSFILES '/vol/rdx_dir/mars_stats/sms/weather'
+  edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+  edit ACCOUNT 'ecrmna'
+  edit OWNER 'naw'
+  edit EXPVER 'weather'
+  edit LOGDIR '/scratch/rd/rdx'
+  edit USER 'rdx'
+  edit QUEUE 'normal'
+  edit ECFS 'no'
+  family naw
+    family general
+      # time 06:00
+      task metgrams
+        defstatus complete
+      task equipot
+        defstatus complete
+    endfamily
+    family tephi
+      edit WSHOST 'linux_cluster'
+      edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %WSHOST% %USER%'
+      edit HOUR '00'
+      # time 05:35
+      task rd_tephi
+        defstatus complete
+        edit TDATE '2000110500'
+        edit EXPVER 'e4mb'
+      task tephi
+    endfamily
+    family main
+      edit WSHOST 'linux_cluster'
+      edit SCHOST 'c1a'
+      edit CPUTIME '30000'
+      edit MEM '800'
+      edit SMSLOGPORT '9314'
+      edit SMSLOGHOST 'c1a-batch'
+      edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSCMD '/home/rd/rdx/bin/smssubmit.x.nils %SMSJOB% %WSHOST% %USER%'
+      edit LOGDIR '/vol/explog/outputs'
+      family scm_quick
+        edit LONG 'no'
+        edit START12 'no'
+        task getmars_scm
+          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit LOGDIR '/c1a/rdx_dir/log'
+          # time 05:20
+        task getdata_scm
+          trigger getmars_scm eq complete
+          edit CLASS 'np'
+          edit NPES '8'
+          edit MEM '800'
+          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit LOGDIR '/c1a/rdx_dir/log'
+        task benson
+          trigger getdata_scm eq complete
+          edit QUEUE 'normal'
+        task chilbolton
+          trigger getdata_scm eq complete
+        task husbos
+          trigger getdata_scm eq complete
+        task belvoir_castle
+          trigger getdata_scm eq complete
+        task york
+          trigger getdata_scm eq complete
+        task welshpool
+          trigger getdata_scm eq complete
+          edit QUEUE 'normal'
+        task newmarket
+          trigger getdata_scm eq complete
+      endfamily
+      family scm
+        edit LONG 'yes'
+        edit START12 'no'
+        task getmars_scm
+          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit LOGDIR '/c1a/rdx_dir/log'
+          # time 06:45
+        task getdata_scm
+          trigger getmars_scm eq complete
+          edit CLASS 'np'
+          edit NPES '8'
+          edit MEM '800'
+          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit LOGDIR '/c1a/rdx_dir/log'
+          edit SMSPASS 'FREE'
+        task benson
+          trigger getdata_scm eq complete
+          edit SMSPASS 'FREE'
+        task chilbolton
+          trigger getdata_scm eq complete
+        task husbos
+          trigger getdata_scm eq complete
+          edit SMSPASS 'FREE'
+        task belvoir_castle
+          trigger getdata_scm eq complete
+        task york
+          trigger getdata_scm eq complete
+        task welshpool
+          trigger getdata_scm eq complete
+          edit SMSPASS 'FREE'
+        task newmarket
+          trigger getdata_scm eq complete
+        task cabauw
+          trigger getdata_scm eq complete
+        task arm_sgp
+          trigger getdata_scm eq complete
+        task vocals0850W
+          defstatus complete
+          trigger getdata_scm eq complete
+        task vocals0750W
+          defstatus complete
+          trigger getdata_scm eq complete
+        task web
+          trigger benson eq complete and chilbolton eq complete and husbos eq complete and belvoir_castle eq complete and york eq complete and welshpool eq complete and newmarket eq complete and cabauw eq complete and arm_sgp eq complete and vocals0850W eq complete and vocals0750W eq complete
+      endfamily
+    endfamily
+  endfamily
+endsuite
+suite weather12
+  clock hybrid -9244800 # 14.06.2009 16:54
+  # repeat day 1 # status 0  ************** DISABLED SO THAT SUITE CAN COMPLETE *****************
+  edit SMSTRIES '2'
+  edit SMSCMD 'smssubmit.x %SMSJOB% hades rdx'
+  edit SMSHOME '/vol/rdx_dir/mars_stats/sms'
+  edit SMSINCLUDE '/vol/rdx_dir/mars_stats/sms/include'
+  edit SMSFILES '/vol/rdx_dir/mars_stats/sms/weather'
+  edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+  edit ACCOUNT 'ecrmna'
+  edit OWNER 'naw'
+  edit EXPVER 'weather'
+  edit LOGDIR '/scratch/rd/rdx'
+  edit USER 'rdx'
+  edit QUEUE 'normal'
+  edit ECFS 'no'
+  family naw
+    family main
+      edit WSHOST 'linux_cluster'
+      edit SCHOST 'c1a'
+      edit CPUTIME '30000'
+      edit MEM '800'
+      edit SMSLOGPORT '9314'
+      edit SMSLOGHOST 'c1a-batch'
+      edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSCMD '/home/rd/rdx/bin/smssubmit.x.nils %SMSJOB% %WSHOST% %USER%'
+      edit LOGDIR '/vol/explog/outputs'
+      family scm
+        edit LONG 'yes'
+        edit START12 'yes'
+        task getmars_scm
+          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit LOGDIR '/c1a/rdx_dir/log'
+          edit SMSPASS 'FREE'
+          # time 17:45
+        task getdata_scm
+          trigger getmars_scm eq complete
+          edit CLASS 'np'
+          edit NPES '8'
+          edit MEM '800'
+          edit SMSKILL '/home/rd/rdx/bin/smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSCMD '/home/rd/rdx/bin/smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit LOGDIR '/c1a/rdx_dir/log'
+        task benson
+          trigger getdata_scm eq complete
+        task chilbolton
+          trigger getdata_scm eq complete
+        task husbos
+          trigger getdata_scm eq complete
+        task belvoir_castle
+          trigger getdata_scm eq complete
+        task york
+          trigger getdata_scm eq complete
+        task welshpool
+          trigger getdata_scm eq complete
+        task newmarket
+          trigger getdata_scm eq complete
+        task cabauw
+          defstatus complete
+          trigger getdata_scm eq complete
+          edit SMSPASS 'FREE'
+        task arm_sgp
+          defstatus complete
+          trigger getdata_scm eq complete
+        task vocals0850W
+          defstatus complete
+          trigger getdata_scm eq complete
+        task vocals0750W
+          defstatus complete
+          trigger getdata_scm eq complete
+        task web
+          trigger benson eq complete and chilbolton eq complete and husbos eq complete and belvoir_castle eq complete and york eq complete and welshpool eq complete and newmarket eq complete and cabauw eq complete and arm_sgp eq complete and vocals0750W eq complete and vocals0850W eq complete
+      endfamily
+    endfamily
+  endfamily
+endsuite
+#============================================================
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/operations/xbe.def 5.13.0-1/libs/simulator/test/data/good_defs/operations/xbe.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/operations/xbe.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/operations/xbe.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9134 @@
+#============================================================
+extern an
+extern an
+extern fc
+extern fc
+extern eps_sv
+extern eps_sv
+extern eps_fc
+extern eps_fc
+extern oceatm
+extern oceatm
+extern oce
+extern oce
+extern fpos
+extern fpos
+extern sens
+extern sens
+extern wam
+extern wam
+extern oc
+extern oc
+extern climplot
+extern climplot
+extern coup
+extern coup
+extern an
+extern an
+extern fc
+extern fc
+extern eps_sv
+extern eps_sv
+extern eps_fc
+extern eps_fc
+extern oceatm
+extern oceatm
+extern oce
+extern oce
+extern fpos
+extern fpos
+extern sens
+extern sens
+extern wam
+extern wam
+extern oc
+extern oc
+extern climplot
+extern climplot
+extern coup
+extern coup
+suite cu9
+  clock hybrid 0 # 27.11.2008 16:54
+  family a01d
+    edit SMSTRIES '1'
+    edit SMSFILES '/vol/msverify/sms/cu9/a01d'
+    edit SMSINCLUDE '/vol/msverify/sms/cu9/a01d/include'
+    edit SMSHOME '/vol/msverify/sms'
+    edit SMSOUT '/vol/msverify/sms'
+    edit SMSLOGPORT '9314'
+    edit SMSLOGHOST 'hpce-batch'
+    edit FSFAMILY ''
+    edit DELTA_DAY '0'
+    edit HOUR ''
+    edit MEMBER '0'
+    edit NPROCA '1'
+    edit NPROCB '1'
+    edit THREADS '1'
+    edit BRANCH ''
+    edit PROJECTS 'none'
+    edit PARALLEL '4'
+    edit DEBUG '0'
+    edit PROFILE '0'
+    edit DISPLAY 'define_your_own:0.0'
+    edit QUEUE 'normal'
+    edit SCHOST 'hpce'
+    edit WSHOST 'ecgate'
+    edit LOGHOST 'linux_cluster'
+    edit EXPVER 'a01d'
+    edit OWNER 'cu9'
+    edit USER 'xbe'
+    edit ACCOUNT 'betro3'
+    edit YMD '2008021112'
+    edit SECS '43200'
+    edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+    edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+    edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+    edit LOGDIR '/hpce/rdx_dir/msx'
+    family make
+      edit YMD '2008021112'
+      edit HOUR ''
+      edit FSFAMILY 'make'
+      task setup
+        edit QUEUE 'normal'
+      family libs
+        defstatus complete
+        trigger setup eq complete
+        edit CCSUBDIR '.'
+        task p4setup_ifs
+          edit SMSTRIES '2'
+        task p4diff_ifs
+          trigger p4setup_ifs eq complete
+        family compile
+          trigger p4setup_ifs eq complete
+          family ifsaux
+            defstatus complete
+            task libifsaux
+          endfamily
+          family surf
+            defstatus complete
+            trigger ifsaux eq complete
+            task libsurf
+          endfamily
+          family trans
+            defstatus complete
+            trigger ifsaux eq complete
+            task libtrans
+          endfamily
+          family ifs
+            defstatus complete
+            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( surf eq complete or surf eq unknown)
+            task libifs
+          endfamily
+          family wam
+            defstatus complete
+            trigger ifsaux eq complete
+            task libwam
+          endfamily
+          family odb
+            defstatus complete
+            family compiler
+              task libodbsqlcompiler
+            endfamily
+            family databases
+              trigger compiler eq complete
+              family CCMA
+                task libCCMA
+              endfamily
+              family ECMA
+                task libECMA
+              endfamily
+            endfamily
+            family corelibs
+              trigger ../ifsaux eq complete
+              family odb
+                task libodb
+              endfamily
+              family odbdummy
+                trigger odb/libodb eq complete
+                task libodbdummy
+              endfamily
+              family odbmain
+                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and ../../ifs eq complete
+                task libodbmain
+              endfamily
+              family odbport
+                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and odbmain/libodbmain eq complete and ../../ifs eq complete
+                task libodbport
+              endfamily
+            endfamily
+          endfamily
+          family ssa
+            defstatus complete
+            trigger ifsaux eq complete and ifs eq complete and odb/corelibs/odb/libodb eq complete
+            task libssa
+          endfamily
+          family obstat
+            defstatus complete
+            trigger ifsaux eq complete and odb/corelibs/odb/libodb eq complete
+            task libobstat
+          endfamily
+          family bl
+            defstatus complete
+            trigger ifsaux eq complete
+            task libbl95
+          endfamily
+          family scat
+            defstatus complete
+            trigger ifsaux eq complete
+            task libscat
+          endfamily
+          family satrad
+            defstatus complete
+            trigger ifsaux eq complete
+            task libsatrad
+          endfamily
+          family aeolus
+            defstatus complete
+            trigger ifsaux eq complete
+            task libaeolus
+          endfamily
+          family prepdata
+            defstatus complete
+            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( ifs eq complete or ifs eq unknown)
+            task libprepdata
+          endfamily
+        endfamily
+      endfamily
+      task links
+        trigger  ( setup eq complete or setup eq unknown) and  ( libs eq complete or libs eq unknown)
+        edit QUEUE 'normal'
+      task logfiles
+        trigger  ( links eq complete or links eq unknown)
+        edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+        edit LOGDIR '/hpce/rdx_dir/msx'
+    endfamily
+    family eps_varfc
+      limit SC 6
+      limit PIC 6
+      edit STREAM 'ENFO'
+      edit FSFAMILY 'mc'
+      edit HOUR ''
+      edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+      edit LOGDIR '/hpce/rdx_dir/msx'
+      family make
+        trigger ../make eq complete
+        edit YMD '2008021112'
+        edit HOUR '12'
+        task setup
+          edit QUEUE 'normal'
+        family bins
+          trigger ../../make/links eq complete and ./setup eq complete
+          task ifs
+          task wamabs
+            edit QUEUE 'normal'
+          task mc_tools
+          task prepdata
+          task ma_tools
+            defstatus complete
+        endfamily
+        family const
+          task datalinks
+            trigger ../setup eq complete
+          task wconstA
+            trigger ../bins/wamabs eq complete
+            edit WAMRESOL 'global100'
+            edit WAMNFRE '30'
+            edit WAMNANG '24'
+          task wconstB
+            trigger ./wconstA eq complete
+            edit WAMRESOL 'global100'
+            edit WAMNFRE '25'
+            edit WAMNANG '12'
+          task wconstC
+            trigger ./wconstB eq complete
+            edit WAMRESOL 'global300'
+            edit WAMNFRE '25'
+            edit WAMNANG '12'
+          task getsst
+            defstatus complete
+            trigger ../setup eq complete and ../../main/fc/inigroup/getini eq complete
+        endfamily
+        task logfiles
+          trigger bins eq complete and const eq complete
+          edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+          edit LOGDIR '/hpce/rdx_dir/msx'
+      endfamily
+      family main
+        family sv
+          defstatus complete
+          repeat string YMD  "2008021112" # status 0
+          edit EPSTYPE 'sv'
+          edit EPSSVTCSUB '1'
+          edit EPSSVOP '1'
+          task getini
+            trigger ../../make/const/datalinks eq complete
+            edit QUEUE 'normal'
+            edit INISTREAM 'DCDA'
+            edit INISTEP '6'
+            edit INITYPE 'fc'
+            edit PRIORITY '40'
+          task inidata_sv
+            trigger ../../make/bins/ifs eq complete and getini eq complete
+            edit QUEUE 'parallel'
+            edit NPES '16'
+            edit THREADS '4'
+            edit MEM '960'
+            edit CPUTIME '1000'
+          task svnh
+            trigger inidata_sv eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '0'
+            edit EPSTROP '0'
+            edit EPSHEM '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task svsh
+            trigger inidata_sv eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '0'
+            edit EPSTROP '0'
+            edit EPSHEM '2'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task targets
+            trigger ../../make/bins/mc_tools eq complete
+          task subspace
+            trigger svnh eq complete and svsh eq complete and targets eq complete
+          task sv1
+            trigger targets eq complete and subspace eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '1'
+            edit EPSTROP '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task sv2
+            trigger targets eq complete and subspace eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '2'
+            edit EPSTROP '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task sv3
+            trigger targets eq complete and subspace eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '3'
+            edit EPSTROP '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task sv4
+            trigger targets eq complete and subspace eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '4'
+            edit EPSTROP '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task sv5
+            trigger targets eq complete and subspace eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '5'
+            edit EPSTROP '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task sv6
+            trigger targets eq complete and subspace eq complete
+            edit FCLENGTH '48'
+            edit MEMBER '6'
+            edit EPSTROP '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task svnhevo
+            trigger svnh eq complete
+            edit FCLENGTH '48'
+            edit EPSHEM '1'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task svshevo
+            trigger svsh eq complete
+            edit FCLENGTH '48'
+            edit EPSHEM '2'
+            edit MEM '960'
+            edit NPES '16'
+            edit THREADS '2'
+            edit CPUTIME '6000'
+            edit QUEUE 'normal'
+          task svsave
+            trigger svnh eq complete and svsh eq complete and sv1 eq complete and sv2 eq complete and sv3 eq complete and sv4 eq complete and sv5 eq complete and sv6 eq complete and svnhevo eq complete and svshevo eq complete
+          task logfiles
+            trigger svsave eq complete
+            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+            edit LOGDIR '/hpce/rdx_dir/msx'
+        endfamily
+        family fc
+          family inigroup
+            repeat string YMD  "2008021112" # status 1
+            trigger  ( ../sv:YMD gt inigroup:YMD or ../sv eq complete) and  ( inigroup:YMD lt  ( ensemble:YMD + 2))
+            complete  ( inigroup:YMD eq  ~ 1)
+            task getini
+              trigger ../../../make/setup eq complete
+              edit QUEUE 'normal'
+              edit INISTREAM 'DA'
+              edit INISTEP '0'
+              edit INITYPE '4v'
+              edit PRIORITY '40'
+            task inidata
+              trigger ../../../make/bins/ifs eq complete and getini eq complete and ../../../make/const/getsst eq complete
+              edit EPSFCRES '399'
+              edit EPSFCLEV '62'
+              edit QUEUE 'parallel'
+              edit NPES '16'
+              edit THREADS '4'
+              edit MEM '960'
+              edit CPUTIME '1000'
+            task wavini
+              trigger ../../../make/const/wconstA eq complete
+              edit QUEUE 'normal'
+              edit PRIORITY '40'
+              edit MEM '900'
+              edit NPES '1'
+              edit THREADS '1'
+              edit CPUTIME '8000'
+            task wcold
+              defstatus complete
+              trigger inidata eq complete and wavini eq complete
+              edit QUEUE 'normal'
+              edit MEM '900'
+              edit NPES '8'
+              edit THREADS '1'
+              edit CPUTIME '3000'
+            task wavfcdata
+              trigger ./wcold eq complete and ../../../make eq complete and wavini eq complete
+            task getsvs
+              trigger ../../../make/bins/mc_tools eq complete
+              edit EPSTROP '1'
+            task getae
+              trigger ./getini eq complete and ./getsvs eq complete
+              event 1
+            task rot
+              trigger ./inidata eq complete and ./getae eq complete and ../../../make/bins/mc_tools eq complete
+              edit EPSTROP '1'
+            task geticp
+              defstatus complete
+              trigger getini eq complete
+            family pert_ic
+              inlimit PIC
+              trigger geticp eq complete and rot eq complete and ./inidata eq complete and ../../../make/bins/mc_tools eq complete
+              edit EPSTROP '1'
+              edit EPSFCLEV '62'
+              edit EPSFCRES '399'
+              family 000
+                edit MEMBER '0'
+                task pertinic
+              endfamily
+              family 001
+                edit MEMBER '1'
+                task pertinic
+              endfamily
+              family 002
+                edit MEMBER '2'
+                task pertinic
+              endfamily
+              family 003
+                edit MEMBER '3'
+                task pertinic
+              endfamily
+              family 004
+                edit MEMBER '4'
+                task pertinic
+              endfamily
+              family 005
+                edit MEMBER '5'
+                task pertinic
+              endfamily
+              family 006
+                edit MEMBER '6'
+                task pertinic
+              endfamily
+              family 007
+                edit MEMBER '7'
+                task pertinic
+              endfamily
+              family 008
+                edit MEMBER '8'
+                task pertinic
+              endfamily
+              family 009
+                edit MEMBER '9'
+                task pertinic
+              endfamily
+              family 010
+                edit MEMBER '10'
+                task pertinic
+              endfamily
+              family 011
+                edit MEMBER '11'
+                task pertinic
+              endfamily
+              family 012
+                edit MEMBER '12'
+                task pertinic
+              endfamily
+              family 013
+                edit MEMBER '13'
+                task pertinic
+              endfamily
+              family 014
+                edit MEMBER '14'
+                task pertinic
+              endfamily
+              family 015
+                edit MEMBER '15'
+                task pertinic
+              endfamily
+              family 016
+                edit MEMBER '16'
+                task pertinic
+              endfamily
+              family 017
+                edit MEMBER '17'
+                task pertinic
+              endfamily
+              family 018
+                edit MEMBER '18'
+                task pertinic
+              endfamily
+              family 019
+                edit MEMBER '19'
+                task pertinic
+              endfamily
+              family 020
+                edit MEMBER '20'
+                task pertinic
+              endfamily
+              family 021
+                edit MEMBER '21'
+                task pertinic
+              endfamily
+              family 022
+                edit MEMBER '22'
+                task pertinic
+              endfamily
+              family 023
+                edit MEMBER '23'
+                task pertinic
+              endfamily
+              family 024
+                edit MEMBER '24'
+                task pertinic
+              endfamily
+              family 025
+                edit MEMBER '25'
+                task pertinic
+              endfamily
+              family 026
+                edit MEMBER '26'
+                task pertinic
+              endfamily
+              family 027
+                edit MEMBER '27'
+                task pertinic
+              endfamily
+              family 028
+                edit MEMBER '28'
+                task pertinic
+              endfamily
+              family 029
+                edit MEMBER '29'
+                task pertinic
+              endfamily
+              family 030
+                edit MEMBER '30'
+                task pertinic
+              endfamily
+              family 031
+                edit MEMBER '31'
+                task pertinic
+              endfamily
+              family 032
+                edit MEMBER '32'
+                task pertinic
+              endfamily
+              family 033
+                edit MEMBER '33'
+                task pertinic
+              endfamily
+              family 034
+                edit MEMBER '34'
+                task pertinic
+              endfamily
+              family 035
+                edit MEMBER '35'
+                task pertinic
+              endfamily
+              family 036
+                edit MEMBER '36'
+                task pertinic
+              endfamily
+              family 037
+                edit MEMBER '37'
+                task pertinic
+              endfamily
+              family 038
+                edit MEMBER '38'
+                task pertinic
+              endfamily
+              family 039
+                edit MEMBER '39'
+                task pertinic
+              endfamily
+              family 040
+                edit MEMBER '40'
+                task pertinic
+              endfamily
+              family 041
+                edit MEMBER '41'
+                task pertinic
+              endfamily
+              family 042
+                edit MEMBER '42'
+                task pertinic
+              endfamily
+              family 043
+                edit MEMBER '43'
+                task pertinic
+              endfamily
+              family 044
+                edit MEMBER '44'
+                task pertinic
+              endfamily
+              family 045
+                edit MEMBER '45'
+                task pertinic
+              endfamily
+              family 046
+                edit MEMBER '46'
+                task pertinic
+              endfamily
+              family 047
+                edit MEMBER '47'
+                task pertinic
+              endfamily
+              family 048
+                edit MEMBER '48'
+                task pertinic
+              endfamily
+              family 049
+                edit MEMBER '49'
+                task pertinic
+              endfamily
+              family 050
+                edit MEMBER '50'
+                task pertinic
+              endfamily
+            endfamily
+            task cp_pert
+              trigger pert_ic eq complete
+            task logfiles
+              trigger wavfcdata eq complete and wavini eq complete and inidata eq complete and pert_ic eq complete and cp_pert eq complete and rot eq complete
+              edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+              edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+              edit LOGDIR '/hpce/rdx_dir/msx'
+          endfamily
+          family ensemble
+            inlimit SC
+            repeat string YMD  "2008021112" # status 1
+            trigger  (  ( inigroup:YMD gt ensemble:YMD) or  ( inigroup eq complete)) and  ( ensemble:YMD eq lag:YMD)
+            complete  ( ensemble:YMD eq  ~ 1)
+            edit RUNVARFC '1'
+            edit HC_REFDATE '0'
+            family cv
+              defstatus complete
+              trigger  ( ../inigroup:YMD gt ../ensemble:YMD) or  ( ../inigroup/pert_ic/000 eq complete)
+              edit EPSTYPE 'cv'
+              family control_1
+                edit SUBFSFAMILY '/cv001'
+                edit EPSMEMBER '1'
+                edit EPSWAMRESOL 'global100'
+                edit EPSWAMNFRE '30'
+                edit EPSWAMNANG '24'
+                edit EPSWAMNSTPW '1'
+                task getiniLeg
+                  edit EPSFCRES '399'
+                  edit EPSFCLEV '62'
+                  edit EPSFCGTYPE 'l_2'
+                  edit PRIORITY '40'
+                task modeleps
+                  trigger ./getiniLeg eq complete
+                  edit MEM '960'
+                  edit NPES '24'
+                  edit THREADS '4'
+                  edit STACK '550'
+                  edit QUEUE 'normal'
+                  edit CPUTIME '2700'
+                  edit EPSFCRES '399'
+                  edit EPSFCLEV '62'
+                  edit EPSFCGTYPE 'l_2'
+                  edit EPSNLEGS '1'
+                  edit EPSLEG '1'
+                  edit EPSINISTEP '240'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '216'
+                  edit TSTEP '1800'
+                  meter step 0 216 216
+              endfamily
+              family control_2
+                edit SUBFSFAMILY '/cv002'
+                edit EPSMEMBER '2'
+                edit EPSWAMRESOL 'global100'
+                edit EPSWAMNFRE '25'
+                edit EPSWAMNANG '12'
+                edit EPSWAMNSTPW '1'
+                task getiniLeg
+                  edit PRIORITY '40'
+                  edit EPSFCRES '399'
+                  edit EPSFCLEV '62'
+                task intHtoLB
+                  trigger ./getiniLeg eq complete
+                  edit QUEUE 'parallel'
+                  edit NPES '8'
+                  edit THREADS '2'
+                  edit MEM '1599'
+                  edit CPUTIME '200'
+                  edit EPSINISTEP '216'
+                  edit EPSFCRES '255'
+                  edit EPSFCLEV '62'
+                  edit EPSFCGTYPE 'l_2'
+                task modeleps
+                  trigger ./intHtoLB eq complete
+                  edit MEM '960'
+                  edit NPES '16'
+                  edit THREADS '2'
+                  edit STACK '550'
+                  edit QUEUE 'normal'
+                  edit CPUTIME 'INF'
+                  edit EPSNLEGS '1'
+                  edit EPSLEG '1'
+                  edit EPSFCRES '255'
+                  edit EPSFCLEV '62'
+                  edit EPSFCGTYPE 'l_2'
+                  edit EPSINISTEP '0'
+                  edit EPSINISTEP_PREVIOUS '0'
+                  edit FCLENGTH '216'
+                  edit TSTEP '2700'
+                  meter step 0 216 216
+              endfamily
+            endfamily
+            family cf
+              edit EPSTYPE 'cf'
+              family control
+                trigger  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/000 eq complete)
+                edit SUBFSFAMILY '/cf000'
+                edit EPSMEMBER '0'
+                family legA
+                  edit EPSCOUPLE '0'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                    edit EPSLEG '2'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                    edit EPSLEG '3'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit EPSFCLENGTH_B '0'
+                    edit EPSINISTEP_B '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+            endfamily
+            family pf
+              edit EPSTYPE 'pf'
+              family 001
+                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/001 eq complete))
+                edit SUBFSFAMILY '/001'
+                edit EPSMEMBER '1'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc0'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '1'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '1'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '1'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '1'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '1'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '1'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '1'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 002
+                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/002 eq complete))
+                edit SUBFSFAMILY '/002'
+                edit EPSMEMBER '2'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc0'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '2'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '2'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '2'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '2'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '2'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '2'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '2'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 003
+                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/003 eq complete))
+                edit SUBFSFAMILY '/003'
+                edit EPSMEMBER '3'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc0'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '3'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '3'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '3'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '3'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '3'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '3'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '3'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 004
+                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/004 eq complete))
+                edit SUBFSFAMILY '/004'
+                edit EPSMEMBER '4'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc0'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '4'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '4'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '4'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '4'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '4'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc0'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '4'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '4'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 005
+                trigger  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/005 eq complete))
+                edit SUBFSFAMILY '/005'
+                edit EPSMEMBER '5'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc1'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '5'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '5'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '5'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '5'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '5'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '5'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '5'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 006
+                trigger  ( ./001/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/006 eq complete))
+                edit SUBFSFAMILY '/006'
+                edit EPSMEMBER '6'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc1'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '6'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '6'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '6'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '6'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '6'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '6'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '6'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 007
+                trigger  ( ./002/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/007 eq complete))
+                edit SUBFSFAMILY '/007'
+                edit EPSMEMBER '7'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc1'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '7'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '7'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '7'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '7'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '7'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '7'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '7'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 008
+                trigger  ( ./003/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/008 eq complete))
+                edit SUBFSFAMILY '/008'
+                edit EPSMEMBER '8'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc1'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '8'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '8'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '8'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '8'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '8'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '8'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '8'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 009
+                trigger  ( ./004/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/009 eq complete))
+                edit SUBFSFAMILY '/009'
+                edit EPSMEMBER '9'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc1'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '9'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '9'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '9'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '9'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '9'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc1'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '9'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '9'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 010
+                trigger  ( ./005/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/010 eq complete))
+                edit SUBFSFAMILY '/010'
+                edit EPSMEMBER '10'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc2'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '10'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '10'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '10'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '10'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '10'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '10'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '10'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 011
+                trigger  ( ./006/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/011 eq complete))
+                edit SUBFSFAMILY '/011'
+                edit EPSMEMBER '11'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc2'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '11'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '11'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '11'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '11'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '11'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '11'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '11'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 012
+                trigger  ( ./007/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/012 eq complete))
+                edit SUBFSFAMILY '/012'
+                edit EPSMEMBER '12'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc2'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '12'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '12'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '12'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '12'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '12'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '12'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '12'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 013
+                trigger  ( ./008/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/013 eq complete))
+                edit SUBFSFAMILY '/013'
+                edit EPSMEMBER '13'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc2'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '13'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '13'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '13'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '13'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '13'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '13'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '13'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 014
+                trigger  ( ./009/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/014 eq complete))
+                edit SUBFSFAMILY '/014'
+                edit EPSMEMBER '14'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc2'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '14'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '14'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '14'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '14'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '14'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc2'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '14'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '14'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 015
+                trigger  ( ./010/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/015 eq complete))
+                edit SUBFSFAMILY '/015'
+                edit EPSMEMBER '15'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc3'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '15'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '15'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '15'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '15'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '15'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '15'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '15'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 016
+                trigger  ( ./011/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/016 eq complete))
+                edit SUBFSFAMILY '/016'
+                edit EPSMEMBER '16'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc3'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '16'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '16'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '16'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '16'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '16'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '16'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '16'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 017
+                trigger  ( ./012/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/017 eq complete))
+                edit SUBFSFAMILY '/017'
+                edit EPSMEMBER '17'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc3'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '17'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '17'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '17'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '17'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '17'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '17'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '17'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 018
+                trigger  ( ./013/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/018 eq complete))
+                edit SUBFSFAMILY '/018'
+                edit EPSMEMBER '18'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc3'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '18'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '18'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '18'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '18'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '18'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '18'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '18'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 019
+                trigger  ( ./014/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/019 eq complete))
+                edit SUBFSFAMILY '/019'
+                edit EPSMEMBER '19'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc3'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '19'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '19'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '19'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '19'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '19'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc3'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '19'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '19'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 020
+                trigger  ( ./015/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/020 eq complete))
+                edit SUBFSFAMILY '/020'
+                edit EPSMEMBER '20'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc4'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '20'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '20'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '20'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '20'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '20'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '20'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '20'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 021
+                trigger  ( ./016/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/021 eq complete))
+                edit SUBFSFAMILY '/021'
+                edit EPSMEMBER '21'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc4'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '21'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '21'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '21'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '21'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '21'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '21'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '21'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 022
+                trigger  ( ./017/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/022 eq complete))
+                edit SUBFSFAMILY '/022'
+                edit EPSMEMBER '22'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc4'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '22'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '22'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '22'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '22'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '22'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '22'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '22'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 023
+                trigger  ( ./018/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/023 eq complete))
+                edit SUBFSFAMILY '/023'
+                edit EPSMEMBER '23'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc4'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '23'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '23'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '23'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '23'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '23'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '23'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '23'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 024
+                trigger  ( ./019/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/024 eq complete))
+                edit SUBFSFAMILY '/024'
+                edit EPSMEMBER '24'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc4'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '24'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '24'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '24'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '24'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '24'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc4'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '24'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '24'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 025
+                trigger  ( ./020/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/025 eq complete))
+                edit SUBFSFAMILY '/025'
+                edit EPSMEMBER '25'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc5'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '25'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '25'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '25'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '25'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '25'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '25'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '25'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 026
+                trigger  ( ./021/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/026 eq complete))
+                edit SUBFSFAMILY '/026'
+                edit EPSMEMBER '26'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc5'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '26'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '26'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '26'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '26'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '26'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '26'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '26'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 027
+                trigger  ( ./022/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/027 eq complete))
+                edit SUBFSFAMILY '/027'
+                edit EPSMEMBER '27'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc5'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '27'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '27'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '27'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '27'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '27'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '27'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '27'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 028
+                trigger  ( ./023/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/028 eq complete))
+                edit SUBFSFAMILY '/028'
+                edit EPSMEMBER '28'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc5'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '28'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '28'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '28'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '28'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '28'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '28'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '28'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 029
+                trigger  ( ./024/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/029 eq complete))
+                edit SUBFSFAMILY '/029'
+                edit EPSMEMBER '29'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc5'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '29'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '29'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '29'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '29'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '29'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc5'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '29'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '29'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 030
+                trigger  ( ./025/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/030 eq complete))
+                edit SUBFSFAMILY '/030'
+                edit EPSMEMBER '30'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc6'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '30'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '30'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '30'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '30'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '30'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '30'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '30'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 031
+                trigger  ( ./026/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/031 eq complete))
+                edit SUBFSFAMILY '/031'
+                edit EPSMEMBER '31'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc6'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '31'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '31'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '31'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '31'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '31'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '31'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '31'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 032
+                trigger  ( ./027/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/032 eq complete))
+                edit SUBFSFAMILY '/032'
+                edit EPSMEMBER '32'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc6'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '32'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '32'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '32'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '32'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '32'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '32'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '32'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 033
+                trigger  ( ./028/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/033 eq complete))
+                edit SUBFSFAMILY '/033'
+                edit EPSMEMBER '33'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc6'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '33'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '33'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '33'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '33'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '33'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '33'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '33'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 034
+                trigger  ( ./029/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/034 eq complete))
+                edit SUBFSFAMILY '/034'
+                edit EPSMEMBER '34'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc6'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '34'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '34'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '34'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '34'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '34'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc6'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '34'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '34'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 035
+                trigger  ( ./030/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/035 eq complete))
+                edit SUBFSFAMILY '/035'
+                edit EPSMEMBER '35'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc7'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '35'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '35'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '35'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '35'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '35'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '35'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '35'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 036
+                trigger  ( ./031/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/036 eq complete))
+                edit SUBFSFAMILY '/036'
+                edit EPSMEMBER '36'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc7'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '36'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '36'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '36'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '36'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '36'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '36'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '36'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 037
+                trigger  ( ./032/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/037 eq complete))
+                edit SUBFSFAMILY '/037'
+                edit EPSMEMBER '37'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc7'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '37'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '37'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '37'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '37'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '37'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '37'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '37'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 038
+                trigger  ( ./033/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/038 eq complete))
+                edit SUBFSFAMILY '/038'
+                edit EPSMEMBER '38'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc7'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '38'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '38'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '38'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '38'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '38'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '38'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '38'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 039
+                trigger  ( ./034/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/039 eq complete))
+                edit SUBFSFAMILY '/039'
+                edit EPSMEMBER '39'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc7'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '39'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '39'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '39'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '39'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '39'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc7'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '39'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '39'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 040
+                trigger  ( ./035/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/040 eq complete))
+                edit SUBFSFAMILY '/040'
+                edit EPSMEMBER '40'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc8'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '40'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '40'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '40'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '40'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '40'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '40'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '40'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 041
+                trigger  ( ./036/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/041 eq complete))
+                edit SUBFSFAMILY '/041'
+                edit EPSMEMBER '41'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc8'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '41'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '41'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '41'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '41'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '41'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '41'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '41'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 042
+                trigger  ( ./037/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/042 eq complete))
+                edit SUBFSFAMILY '/042'
+                edit EPSMEMBER '42'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc8'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '42'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '42'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '42'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '42'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '42'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '42'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '42'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 043
+                trigger  ( ./038/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/043 eq complete))
+                edit SUBFSFAMILY '/043'
+                edit EPSMEMBER '43'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc8'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '43'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '43'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '43'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '43'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '43'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '43'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '43'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 044
+                trigger  ( ./039/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/044 eq complete))
+                edit SUBFSFAMILY '/044'
+                edit EPSMEMBER '44'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc8'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '44'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '44'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '44'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '44'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '44'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc8'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '44'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '44'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 045
+                trigger  ( ./040/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/045 eq complete))
+                edit SUBFSFAMILY '/045'
+                edit EPSMEMBER '45'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc9'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '45'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '45'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '45'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '45'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '45'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '45'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '45'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 046
+                trigger  ( ./041/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/046 eq complete))
+                edit SUBFSFAMILY '/046'
+                edit EPSMEMBER '46'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc9'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '46'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '46'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '46'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '46'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '46'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an1'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '46'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '46'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 047
+                trigger  ( ./042/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/047 eq complete))
+                edit SUBFSFAMILY '/047'
+                edit EPSMEMBER '47'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc9'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '47'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '47'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '47'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '47'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '47'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an2'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '47'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '47'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 048
+                trigger  ( ./043/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/048 eq complete))
+                edit SUBFSFAMILY '/048'
+                edit EPSMEMBER '48'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc9'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '48'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '48'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '48'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '48'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '48'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an3'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '48'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '48'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 049
+                trigger  ( ./044/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/049 eq complete))
+                edit SUBFSFAMILY '/049'
+                edit EPSMEMBER '49'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc9'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '49'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '49'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '49'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '49'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '49'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an4'
+                  edit FCGROUP 'fc9'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '49'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '49'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+              family 050
+                trigger  ( ./045/legB/modeleps eq complete) and  (  ( ../../inigroup:YMD gt ../../ensemble:YMD) or  ( ../../inigroup/pert_ic/050 eq complete))
+                edit SUBFSFAMILY '/050'
+                edit EPSMEMBER '50'
+                family legA
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc10'
+                  task getiniLeg
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '50'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                  task modeleps
+                    trigger ./getiniLeg eq complete
+                    edit MEM '960'
+                    edit NPES '24'
+                    edit CPUTIME '25000'
+                    edit THREADS '4'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '1'
+                    edit EPSMEMBER '50'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '240'
+                    edit EPSINISTEP_PREVIOUS '0'
+                    edit FCLENGTH '240'
+                    edit TSTEP '1800'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '30'
+                    edit EPSWAMNANG '24'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 240 240
+                endfamily
+                family legB
+                  trigger legA eq complete
+                  complete  ( 2 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc10'
+                  task getvarepsdata
+                    edit EPSLEG '2'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '50'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '399'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    complete  ( 2 gt 1)
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSMEMBER '50'
+                    edit EPSINISTEP '216'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    complete  ( 2 gt 1)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '2'
+                    edit EPSMEMBER '50'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '216'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global100'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    edit EPSFCLENGTH_A '240'
+                    meter step 0 0 0
+                endfamily
+                family legC
+                  trigger legB eq complete
+                  complete  ( 3 gt 1)
+                  edit EPSCOUPLE '0'
+                  edit OCGROUP 'an0'
+                  edit FCGROUP 'fc10'
+                  task getvarepsdata
+                    edit EPSLEG '3'
+                    edit PRIORITY '40'
+                    edit EPSMEMBER '50'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '255'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                  task intHtoL
+                    trigger ./getvarepsdata eq complete
+                    edit QUEUE 'parallel'
+                    edit NPES '8'
+                    edit THREADS '2'
+                    edit MEM '1599'
+                    edit CPUTIME '200'
+                    edit EPSINISTEP '168'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit FCLENGTH '0'
+                  task modeleps
+                    trigger  ( intHtoL eq complete)
+                    edit MEM '960'
+                    edit NPES '16'
+                    edit CPUTIME '4000'
+                    edit THREADS '2'
+                    edit STACK '550'
+                    edit QUEUE 'normal'
+                    edit EPSNLEGS '1'
+                    edit EPSLEG '3'
+                    edit EPSMEMBER '50'
+                    edit EPSFCRES '95'
+                    edit EPSFCLEV '62'
+                    edit EPSFCGTYPE 'l_2'
+                    edit EPSINISTEP '0'
+                    edit EPSINISTEP_PREVIOUS '168'
+                    edit FCLENGTH '0'
+                    edit TSTEP '2700'
+                    edit EPSWAMRESOL 'global300'
+                    edit EPSWAMNFRE '25'
+                    edit EPSWAMNANG '12'
+                    edit EPSWAMNSTPW '1'
+                    meter step 0 0 0
+                endfamily
+              endfamily
+            endfamily
+            task logfiles
+              trigger cv eq complete and cf eq complete and pf eq complete
+              edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+              edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+              edit LOGDIR '/hpce/rdx_dir/msx'
+          endfamily
+          family lag
+            repeat string YMD  "2008021112" # status 3
+            trigger  (  ( ensemble:YMD ge lag:YMD) or  ( ensemble eq complete or ensemble eq unknown)) and  (  ( inigroup:YMD gt lag:YMD) or  ( inigroup eq complete or inigroup eq unknown))
+            complete  ( lag:YMD eq  ~ 1)
+            family archive
+              edit SMSTRIES '1'
+              edit MEM_ARCH '400'
+              edit CPUTIME_ARCH '10000'
+              edit PRIORITY '45'
+              edit FCLENGTH '240'
+              family cv
+                defstatus complete
+                trigger cf eq complete
+                edit ARCHTYPE 'cv'
+                family arch000
+                  trigger  (  ( ../../../ensemble:YMD eq ../../../lag:YMD) and  ( ../../../ensemble/cv eq complete)) or  ( ../../../ensemble:YMD gt ../../../lag:YMD)
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '0'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+              endfamily
+              family cf
+                edit ARCHTYPE 'cf'
+                family arch000
+                  trigger  (  ( ../../../ensemble:YMD eq ../../../lag:YMD) and  ( ../../../ensemble/cf eq complete)) or  ( ../../../ensemble:YMD gt ../../../lag:YMD)
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '0'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+              endfamily
+              family pf
+                trigger cf eq complete and cv eq complete
+                edit ARCHTYPE 'pf'
+                family arch001
+                  trigger  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/001 eq complete and ../../../ensemble/pf/002 eq complete and ../../../ensemble/pf/003 eq complete and ../../../ensemble/pf/004 eq complete and ../../../ensemble/pf/005 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '1'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch002
+                  trigger arch001 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/006 eq complete and ../../../ensemble/pf/007 eq complete and ../../../ensemble/pf/008 eq complete and ../../../ensemble/pf/009 eq complete and ../../../ensemble/pf/010 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '2'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch003
+                  trigger arch002 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/011 eq complete and ../../../ensemble/pf/012 eq complete and ../../../ensemble/pf/013 eq complete and ../../../ensemble/pf/014 eq complete and ../../../ensemble/pf/015 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '3'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch004
+                  trigger arch003 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/016 eq complete and ../../../ensemble/pf/017 eq complete and ../../../ensemble/pf/018 eq complete and ../../../ensemble/pf/019 eq complete and ../../../ensemble/pf/020 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '4'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch005
+                  trigger arch004 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/021 eq complete and ../../../ensemble/pf/022 eq complete and ../../../ensemble/pf/023 eq complete and ../../../ensemble/pf/024 eq complete and ../../../ensemble/pf/025 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '5'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch006
+                  trigger arch005 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/026 eq complete and ../../../ensemble/pf/027 eq complete and ../../../ensemble/pf/028 eq complete and ../../../ensemble/pf/029 eq complete and ../../../ensemble/pf/030 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '6'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch007
+                  trigger arch006 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/031 eq complete and ../../../ensemble/pf/032 eq complete and ../../../ensemble/pf/033 eq complete and ../../../ensemble/pf/034 eq complete and ../../../ensemble/pf/035 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '7'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch008
+                  trigger arch007 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/036 eq complete and ../../../ensemble/pf/037 eq complete and ../../../ensemble/pf/038 eq complete and ../../../ensemble/pf/039 eq complete and ../../../ensemble/pf/040 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '8'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch009
+                  trigger arch008 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/041 eq complete and ../../../ensemble/pf/042 eq complete and ../../../ensemble/pf/043 eq complete and ../../../ensemble/pf/044 eq complete and ../../../ensemble/pf/045 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '9'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+                family arch010
+                  trigger arch009 eq complete and  ( ../../../ensemble:YMD gt ../../../lag:YMD or  ( ../../../ensemble/pf/046 eq complete and ../../../ensemble/pf/047 eq complete and ../../../ensemble/pf/048 eq complete and ../../../ensemble/pf/049 eq complete and ../../../ensemble/pf/050 eq complete))
+                  edit EPSCHUNKS '5'
+                  edit EPSARCHGRP '10'
+                  family arch
+                    task ml
+                      event fdb
+                    task pl
+                      trigger  ( ml eq complete or ml eq unknown)
+                      event fdb
+                    task sfc
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown)
+                      event fdb
+                    task pt
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown)
+                      event fdb
+                    task pv
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown)
+                      event fdb
+                    task hl
+                      defstatus complete
+                      trigger  ( ml eq complete or ml eq unknown) and  ( pl eq complete or pl eq unknown) and  ( sfc eq complete or sfc eq unknown) and  ( pt eq complete or pt eq unknown) and  ( pv eq complete or pv eq unknown)
+                      event fdb
+                    task wm_sfc_arc
+                      trigger sfc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                    task wm_ua_arc
+                      trigger wm_sfc_arc eq complete
+                      complete  (  ( 240 ge 768 and 1 ne 1) or  ( 240 lt 768))
+                      edit RUNVARFC '1'
+                  endfamily
+                  task cleanmc
+                    trigger arch eq complete
+                endfamily
+              endfamily
+              family icp
+                trigger ./pf eq complete
+                edit ARCHTYPE 'icp'
+                task ml
+                  event fdb
+                task cleanmc
+                  trigger ml eq complete
+              endfamily
+            endfamily
+            task flush
+              trigger archive/pf eq complete and archive/cf eq complete and archive/cv eq complete and archive/icp eq complete
+              edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+              edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+              edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+              edit LOGDIR '/vol/msexplog/outputs'
+              edit QUEUE 'expsms'
+            family ecfs
+              task save
+            endfamily
+            family plot
+              family prob
+                edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                edit LOGDIR '/vol/msexplog/outputs'
+                edit QUEUE 'expsms'
+                task plumea
+                  defstatus complete
+                task pb
+                  defstatus complete
+                  trigger ../../prob eq complete
+              endfamily
+            endfamily
+            family prob
+              defstatus complete
+              task rain
+              task temp
+              task wind
+            endfamily
+            task cleanvarfc
+              trigger archive eq complete and flush eq complete and ecfs eq complete and plot eq complete and prob eq complete
+            task logfiles
+              trigger cleanvarfc eq complete
+              edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+              edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+              edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+              edit LOGDIR '/hpce/rdx_dir/msx'
+          endfamily
+        endfamily
+      endfamily
+    endfamily
+    task wipefdb
+      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown)
+      edit YMD '2008021112'
+      edit HOUR ''
+      edit FSFAMILY 'cancel'
+    task cancel
+      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown) and  ( wipefdb eq complete or wipefdb eq unknown)
+      edit YMD '2008021112'
+      edit HOUR ''
+      edit FSFAMILY 'cancel'
+      edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+      edit LOGDIR '/vol/msexplog/outputs'
+      edit QUEUE 'expsms'
+  endfamily
+endsuite
+#============================================================
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/operations/xfi.def 5.13.0-1/libs/simulator/test/data/good_defs/operations/xfi.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/operations/xfi.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/operations/xfi.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,265 @@
+#============================================================
+suite trunk_test
+  clock hybrid 0 # 18.03.2008 16:54
+  edit USER 'fim'
+  edit SMSINCLUDE '/scratch/ms/fi/fim/hm_home/trunk_test/lib/sms'
+  edit SMSFILES '/scratch/ms/fi/fim/hm_home/trunk_test/lib/sms'
+  edit EXP 'trunk_test'
+  edit ARGS ''
+  edit ENVT ''
+  edit YMD ''
+  edit HH '0'
+  edit Env_system '/home/ms/fi/fim/hm_home/trunk_test/Env_system'
+  edit TARGETNODE '%SMSHOST%'
+  edit HM_REV '/home/ms/dk/nhz/harmonie_release/trunk'
+  edit R_HOST ''
+  edit SRC_DIR ''
+  edit ENSMBR '-1'
+  edit SMSTRIES '1'
+  edit SMSJOBOUT '/hpce/ms_dir/ms/fi/fim/HARMONIE%SMSNAME%.%SMSTRYNO%'
+  edit SMSCMD 'perl -S Submit.pl -o %SMSJOBOUT% %SMSJOB% >> mSMS.log 2>&1'
+  edit SKIPifDONE '0'
+  task InitRun
+  family Build
+    trigger  ( InitRun eq complete)
+    task Build_pack
+    family Utilities
+      task Make_gl
+      task Make_monitor
+      task Make_oulan
+      task Make_gl_ecgate
+    endfamily
+    task Archive_log
+  endfamily
+endsuite
+suite test_def
+  clock hybrid 0 # 09.10.2009 16:54
+  edit USER 'sniemela'
+  edit SMSINCLUDE '/usr/people/sms/usr_def/hirlam/test_def/scripts'
+  edit SMSFILES '/usr/people/sms/usr_def/hirlam/test_def/scripts'
+  edit EXP 'test_def'
+  edit ARGS ''
+  edit ENVT ''
+  edit YMD ''
+  edit HH '0'
+  edit Env_system '/home/users/sniemela/Harmonie/hm_home/test_def/Env_system'
+  edit TARGETNODE '%SMSHOST%'
+  edit HM_REV '/operative/hirlam/home/Harmonie/33h1'
+  edit R_HOST ''
+  edit SRC_DIR ''
+  edit PP ''
+  edit ENSMBR '-1'
+  edit SMSTRIES '1'
+  edit HM_WD '/home/users/sniemela/Harmonie/hm_home/test_def'
+  edit DTGBEG '2008090100'
+  edit DTGEND '2008090100'
+  edit _mSMS_DocURL ''
+  edit SMSJOBOUT '/home/sms/tmp/%SMSNAME%.%SMSTRYNO%'
+  edit SMSCMD 'ssh %SMSHOST% -l %USER% ". /etc/profile;bsub "< %SMSJOB% 1>%SMSJOBOUT% 2>&1 &'
+  edit SKIPifDONE '0'
+  edit KONE_VALINTA 'jumbo'
+  task Ping_HPC
+    edit SMSHOST 'sms.fmi.fi'
+    edit SMSCMD 'sh< %SMSJOB% 1>%SMSJOBOUT% 2>&1 &'
+    label HOST ""
+  task Prepare_SMS
+    trigger  ( Ping_HPC eq complete)
+    edit SMSHOST 'sms.fmi.fi'
+    edit SMSCMD 'sh< %SMSJOB% 1>%SMSJOBOUT% 2>&1 &'
+  task InitRun
+    trigger  ( Ping_HPC eq complete) and  ( Prepare_SMS eq complete)
+  family Build
+    trigger  ( InitRun eq complete)
+    task Build_pack
+    family Utilities
+      task Make_gl
+      task Make_monitor
+      task Make_oulan
+    endfamily
+    task Archive_log
+      trigger  ( Build_pack eq complete and Utilities eq complete)
+  endfamily
+  family MARS
+    trigger  ( InitRun eq complete)
+    task Empty
+  endfamily
+  family MakeCycleInput
+    repeat date YMD 20080901 20080901 1 # status 0
+    trigger  ( Build eq complete and  ( MakeCycleInput:YMD lt  ( Postprocessing:YMD + 3)))
+    family Hour
+      repeat integer HH 0 23 24 # status 0
+      trigger  ( ../InitRun eq complete)
+      complete  (  (  ( ../MakeCycleInput:YMD le 20080901) and  ( Hour:HH lt 00)) or  (  ( ../MakeCycleInput:YMD ge 20080901) and  ( Hour:HH)))
+      task Prepare_cycle
+      family Climate
+        trigger  ( Prepare_cycle eq complete)
+        task Empty
+      endfamily
+      family Boundaries
+        trigger  ( Climate eq complete)
+        task Boundary_strategy
+        family LBC0
+          task hir2aro
+            trigger  ( ../Boundary_strategy eq complete)
+        endfamily
+        family LBC1
+          task hir2aro
+            trigger  ( ../Boundary_strategy eq complete)
+        endfamily
+        family LBC2
+          task hir2aro
+            trigger  ( ../Boundary_strategy eq complete)
+        endfamily
+        family LBC3
+          task hir2aro
+            trigger  ( ../Boundary_strategy eq complete)
+        endfamily
+        family LBC4
+          task hir2aro
+            trigger  ( ../Boundary_strategy eq complete)
+        endfamily
+        family LBC5
+          task hir2aro
+            trigger  ( ../Boundary_strategy eq complete)
+        endfamily
+        family LBC6
+          task hir2aro
+            trigger  ( ../Boundary_strategy eq complete)
+        endfamily
+      endfamily
+      family Observations
+        trigger  ( Climate eq complete and ../../MARS eq complete)
+        task Empty
+      endfamily
+      task Archive_log
+        trigger  ( Boundaries eq complete and Observations eq complete)
+    endfamily
+  endfamily
+  family Date
+    repeat date YMD 20080901 20080901 1 # status 0
+    trigger  ( Build eq complete)
+    family Hour
+      repeat integer HH 0 23 24 # status 0
+      complete  (  (  ( ../Date:YMD le 20080901) and  ( Hour:HH lt 00)) or  (  ( ../Date:YMD ge 20080901) and  ( Hour:HH gt 00)))
+      family Cycle
+        trigger  (  ( ../../MakeCycleInput eq complete) or  ( ../../MakeCycleInput:YMD gt ../../Date:YMD) or  (  ( ../../MakeCycleInput:YMD eq ../../Date:YMD) and  ( ../../MakeCycleInput/Hour:HH gt ../Hour:HH)) or  (  ( ../../MakeCycleInput:YMD eq ../../Date:YMD) and  ( ../../MakeCycleInput/Hour:HH eq ../Hour:HH)))
+        family StartData
+          trigger  (  ( ../../../MakeCycleInput eq complete) or  ( ../../../MakeCycleInput:YMD gt ../../../Date:YMD) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH gt ../../Hour:HH)) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH eq ../../Hour:HH) and  ( ../../../MakeCycleInput/Hour/Boundaries/LBC0 eq complete)))
+          task Prep_ini_surfex
+          task FirstGuess
+        endfamily
+        family Analysis
+          trigger  ( StartData eq complete and  (  ( ../../../MakeCycleInput eq complete) or  ( ../../../MakeCycleInput:YMD gt ../../../Date:YMD) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH gt ../../Hour:HH)) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH eq ../../Hour:HH) and  ( ../../../MakeCycleInput/Hour/Observations eq complete))))
+          family AnSFC
+            task Empty
+          endfamily
+          family AnUA
+            task Empty
+          endfamily
+        endfamily
+        family Forecasting
+          trigger  (  ( StartData eq complete and Analysis eq complete) and  (  ( ../../../MakeCycleInput eq complete) or  ( ../../../MakeCycleInput:YMD gt ../../../Date:YMD) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH gt ../../Hour:HH)) or  (  ( ../../../MakeCycleInput:YMD eq ../../../Date:YMD) and  ( ../../../MakeCycleInput/Hour:HH eq ../../Hour:HH) and  ( ../../../MakeCycleInput/Hour/Boundaries eq complete))))
+          task Forecast
+          task Archive_fc
+            trigger  ( Forecast eq complete)
+        endfamily
+      endfamily
+      task Archive_log
+        trigger  ( Cycle eq complete)
+      task LogProgress
+        trigger  ( Cycle eq complete)
+    endfamily
+  endfamily
+  family Postprocessing
+    repeat date YMD 20080901 20080901 1 # status 0
+    trigger  ( Build eq complete)
+    family Hour
+      repeat integer HH 0 23 24 # status 0
+      trigger  (  ( ../Date eq complete) or  ( ../Date:YMD gt ../Postprocessing:YMD) or  (  ( ../Date:YMD eq ../Postprocessing:YMD) and  ( ../Date/Hour:HH gt Hour:HH)))
+      complete  (  (  ( ../Postprocessing:YMD le 20080901) and  ( Hour:HH lt 00)) or  (  ( ../Postprocessing:YMD ge 20080901) and  ( Hour:HH gt 00)))
+      family Extract4ver
+        family fldextr0
+          task Run_fldver
+        endfamily
+        family fldextr1
+          task Run_fldver
+        endfamily
+        family fldextr2
+          task Run_fldver
+        endfamily
+        family fldextr3
+          task Run_fldver
+        endfamily
+        family fldextr4
+          task Run_fldver
+        endfamily
+        family fldextr5
+          task Run_fldver
+        endfamily
+        family fldextr6
+          task Run_fldver
+        endfamily
+      endfamily
+      task Gather_extract
+        trigger  ( Extract4ver eq complete)
+      family Postp_family
+        family Postp0
+          task Postpp
+        endfamily
+        family Postp1
+          task Postpp
+        endfamily
+        family Postp2
+          task Postpp
+        endfamily
+        family Postp3
+          task Postpp
+        endfamily
+        family Postp4
+          task Postpp
+        endfamily
+        family Postp5
+          task Postpp
+        endfamily
+        family Postp6
+          task Postpp
+        endfamily
+      endfamily
+      family Grib_family
+        trigger  ( Postp_family eq complete)
+        family Grib0
+          task Makegrib
+        endfamily
+        family Grib1
+          task Makegrib
+        endfamily
+        family Grib2
+          task Makegrib
+        endfamily
+        family Grib3
+          task Makegrib
+        endfamily
+        family Grib4
+          task Makegrib
+        endfamily
+        family Grib5
+          task Makegrib
+        endfamily
+        family Grib6
+          task Makegrib
+        endfamily
+      endfamily
+      task Cleancycle
+        trigger  ( Postp_family eq complete and Gather_extract eq complete and Grib_family eq complete)
+      family ECMWF
+        task Empty
+      endfamily
+      task Archive_log
+        trigger  ( ECMWF eq complete and Cleancycle eq complete)
+      task LogProgress
+        trigger  ( ECMWF eq complete and Cleancycle eq complete)
+        edit PP 'PP'
+    endfamily
+  endfamily
+endsuite
+#============================================================
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/operations/xpt.def 5.13.0-1/libs/simulator/test/data/good_defs/operations/xpt.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/operations/xpt.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/operations/xpt.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,2562 @@
+#============================================================
+extern an
+extern an
+extern fc
+extern fc
+extern eps_sv
+extern eps_sv
+extern eps_fc
+extern eps_fc
+extern eps_varfc
+extern eps_varfc
+extern oceatm
+extern oceatm
+extern oce
+extern oce
+extern fpos
+extern fpos
+extern sens
+extern sens
+extern wam
+extern wam
+extern oc
+extern oc
+extern climplot
+extern climplot
+extern an
+extern an
+extern fc
+extern fc
+extern eps_sv
+extern eps_sv
+extern eps_fc
+extern eps_fc
+extern eps_varfc
+extern eps_varfc
+extern oceatm
+extern oceatm
+extern oce
+extern oce
+extern fpos
+extern fpos
+extern sens
+extern sens
+extern wam
+extern wam
+extern oc
+extern oc
+extern climplot
+extern climplot
+suite ptb
+  clock hybrid 0 # 03.11.2008 16:55
+  family a020
+    edit SMSTRIES '1'
+    edit SMSFILES '/vol/msverify/sms/ptb/a020'
+    edit SMSINCLUDE '/vol/msverify/sms/ptb/a020/include'
+    edit SMSHOME '/vol/msverify/sms'
+    edit SMSOUT '/vol/msverify/sms'
+    edit SMSLOGPORT '9314'
+    edit SMSLOGHOST 'hpce-batch'
+    edit FSFAMILY ''
+    edit DELTA_DAY '0'
+    edit HOUR ''
+    edit MEMBER '0'
+    edit NPROCA '1'
+    edit NPROCB '1'
+    edit THREADS '1'
+    edit BRANCH ''
+    edit PARALLEL '4'
+    edit DEBUG '0'
+    edit PROFILE '0'
+    edit DISPLAY 'define_your_own:0.0'
+    edit QUEUE 'normal'
+    edit SCHOST 'hpce'
+    edit WSHOST 'ecgate'
+    edit LOGHOST 'ecgate'
+    edit EXPVER 'a020'
+    edit OWNER 'ptb'
+    edit USER 'xpt'
+    edit ACCOUNT 'ptearth'
+    edit YMD '19900101'
+    edit SECS '0'
+    edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+    edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+    edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+    edit LOGDIR '/hpce/rdx_dir/msx'
+    family make
+      edit YMD '19900101'
+      edit HOUR '00'
+      edit FSFAMILY 'make'
+      task setup
+        edit QUEUE 'normal'
+      family libs
+        defstatus complete
+        trigger setup eq complete
+        edit CCSUBDIR '.'
+        task p4setup_ifs
+          edit SMSTRIES '2'
+        task p4diff_ifs
+          trigger p4setup_ifs eq complete
+        family compile
+          trigger p4setup_ifs eq complete
+          family ifsaux
+            defstatus complete
+            task libifsaux
+          endfamily
+          family surf
+            defstatus complete
+            trigger ifsaux eq complete
+            task libsurf
+          endfamily
+          family trans
+            defstatus complete
+            trigger ifsaux eq complete
+            task libtrans
+          endfamily
+          family ifs
+            defstatus complete
+            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( surf eq complete or surf eq unknown)
+            task libifs
+          endfamily
+          family wam
+            defstatus complete
+            trigger ifsaux eq complete
+            task libwam
+          endfamily
+          family odb
+            defstatus complete
+            family compiler
+              task libodbsqlcompiler
+            endfamily
+            family databases
+              trigger compiler eq complete
+              family CCMA
+                task libCCMA
+              endfamily
+              family ECMA
+                task libECMA
+              endfamily
+            endfamily
+            family corelibs
+              trigger ../ifsaux eq complete
+              family odb
+                task libodb
+              endfamily
+              family odbdummy
+                trigger odb/libodb eq complete
+                task libodbdummy
+              endfamily
+              family odbmain
+                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and ../../ifs eq complete
+                task libodbmain
+              endfamily
+              family odbport
+                trigger odb/libodb eq complete and odbdummy/libodbdummy eq complete and odbmain/libodbmain eq complete and ../../ifs eq complete
+                task libodbport
+              endfamily
+            endfamily
+          endfamily
+          family ssa
+            defstatus complete
+            trigger ifsaux eq complete and ifs eq complete and odb/corelibs/odb/libodb eq complete
+            task libssa
+          endfamily
+          family obstat
+            defstatus complete
+            trigger ifsaux eq complete and odb/corelibs/odb/libodb eq complete
+            task libobstat
+          endfamily
+          family bl
+            defstatus complete
+            trigger ifsaux eq complete
+            task libbl95
+          endfamily
+          family scat
+            defstatus complete
+            trigger ifsaux eq complete
+            task libscat
+          endfamily
+          family satrad
+            defstatus complete
+            trigger ifsaux eq complete
+            task libsatrad
+          endfamily
+          family aeolus
+            defstatus complete
+            trigger ifsaux eq complete
+            task libaeolus
+          endfamily
+          family prepdata
+            defstatus complete
+            trigger  ( ifsaux eq complete or ifsaux eq unknown) and  ( trans eq complete or trans eq unknown) and  ( ifs eq complete or ifs eq unknown)
+            task libprepdata
+          endfamily
+        endfamily
+      endfamily
+      task links
+        trigger  ( setup eq complete or setup eq unknown) and  ( libs eq complete or libs eq unknown)
+        edit QUEUE 'normal'
+      task logfiles
+        trigger  ( links eq complete or links eq unknown)
+        edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+        edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+        edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+        edit LOGDIR '/hpce/rdx_dir/msx'
+    endfamily
+    family coup
+      edit VERSION 'a020'
+      edit STREAM 'MMSF'
+      edit EPSTYPE 'fc'
+      edit EMOS_BASE '00'
+      edit DATEMASK '*.*.*'
+      edit FIRST_DAY '0'
+      edit YMD '19690101'
+      edit USE_YMD 'true'
+      edit FCCHUNK '1'
+      edit OCESUITE '0'
+      edit ORIGIN 'ECMF'
+      edit SMSTRIES '1'
+      edit DELTA_DAY '0'
+      edit USER_PRIORITY '50'
+      edit PRIORITY '50'
+      edit EMOS_TYPE 'fc'
+      edit EMOS_TIME_STEP_H '0000'
+      edit EMOS_STREAM 'DA'
+      edit FSFAMILY 'coup'
+      edit FCNPES '1'
+      edit MEMBER '0'
+      edit COUP 'true'
+      edit RUNBACK '0'
+      edit OCASSIMTOTAL '3'
+      edit OCCONTROLTOTAL '1'
+      edit OCNEWPERTORDER 'yes'
+      edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+      edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+      edit LOGDIR '/hpce/rdx_dir/msx'
+      edit HOUR '00'
+      edit CHUNK '0'
+      edit RUNCOUPLE '0'
+      edit FCLENGTH '0'
+      edit FCGROUP 'fc0'
+      edit OCGROUP 'an0'
+      edit OCTOTAL '3'
+      edit FCTOTAL '1'
+      edit OCSUITENO '1'
+      edit CFCTOTDONE '0'
+      edit FCTOTDONE '0'
+      edit CFCEXTOTDONE '0'
+      edit FCEXTOTDONE '0'
+      family limits
+        defstatus complete
+        limit mars 1
+        limit cpmodel 1
+        limit fdbclean 1
+        limit ws 1
+        limit PIC 6
+      endfamily
+      family make
+        trigger /ptb/a020/make eq complete
+        task setup
+        task links
+          trigger setup eq complete
+        task datalinks
+          trigger links eq complete
+        task ocsetup
+          trigger datalinks eq complete
+        task libsoc
+          trigger ./ocsetup eq complete
+        task oclinks
+          trigger ./libsoc eq complete
+        task prepdata
+          trigger oclinks eq complete
+        task mc_tools
+          trigger prepdata eq complete
+        task sc_tools
+          trigger mc_tools eq complete
+        task tools
+          defstatus complete
+          trigger oclinks eq complete
+          edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+          edit LOGDIR '/vol/msexplog/outputs'
+          edit QUEUE 'expsms'
+        task octools
+          defstatus complete
+          trigger tools eq complete
+          edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+          edit LOGDIR '/vol/msexplog/outputs'
+          edit QUEUE 'expsms'
+        task build_seasplot
+          defstatus complete
+          trigger octools eq complete
+          edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+          edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+          edit LOGDIR '/vol/msexplog/outputs'
+          edit QUEUE 'expsms'
+        family couple
+          trigger mc_tools eq complete
+          task ifs
+            trigger ../oclinks eq complete
+          task oasis
+          task wamabs
+        endfamily
+        family const
+          task wconst
+            trigger ../couple eq complete
+        endfamily
+        family control
+          defstatus complete
+          trigger const eq complete
+          edit FSFAMILY 'control'
+          task ocean
+            trigger ../libsoc eq complete
+          task forcing
+            trigger ocean eq complete
+          task getcouple
+            defstatus complete
+            trigger forcing eq complete
+            edit RUNCOUPLE '1'
+            edit FCGROUP 'fc0'
+        endfamily
+        family assim
+          trigger control eq complete and const eq complete
+          edit FSFAMILY 'assim'
+          task ocean
+            trigger ../libsoc eq complete
+          task forcing
+            trigger ocean eq complete
+          task getcouple
+            trigger forcing eq complete
+            edit RUNCOUPLE '1'
+            edit FCGROUP 'fc0'
+        endfamily
+        task logfiles
+          trigger setup eq complete and links eq complete and datalinks eq complete and ocsetup eq complete and libsoc eq complete and oclinks eq complete and tools eq complete and sc_tools eq complete and octools eq complete and build_seasplot eq complete and couple eq complete and const eq complete and control eq complete and assim eq complete
+          edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+          edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+          edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+          edit LOGDIR '/hpce/rdx_dir/msx'
+          edit LOGTASK 'make'
+      endfamily
+      family fcdate
+        trigger make eq complete
+        family main
+          repeat enumerated YMD  "19690101" "19690102" # status 19690102
+          edit LOGTASK 'fcdate/main'
+          family control0
+            defstatus complete
+            edit FSFAMILY 'control'
+            edit OCTOTAL '1'
+            edit OCGROUP 'an0'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit SUBFSFAMILY '_an0_fc0'
+            edit FCGROUP 'fc0'
+            task getini
+            task inidata
+              trigger getini eq complete
+              edit NPES '12'
+              edit ININPES '12'
+              edit MEM '900'
+              edit THREADS '2'
+              edit CPUTIME '1000'
+            task oceini
+            family eps_sv
+              defstatus complete
+              edit MOFCSV 'true'
+              family svevo
+                edit DELTA_DAY '-2'
+                task getini
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+              endfamily
+              family svini
+                edit DELTA_DAY '0'
+                task getini
+                  trigger ../svevo eq complete
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task targets
+                  trigger svsh eq complete
+                  edit FCLENGTH '48'
+                task subspace
+                  trigger svnh eq complete and svsh eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                task sv1
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '1'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv2
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '2'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv3
+                  trigger sv1 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '3'
+                task sv4
+                  trigger sv2 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '4'
+                task sv5
+                  trigger sv3 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '5'
+                task sv6
+                  trigger sv4 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '6'
+              endfamily
+            endfamily
+            family eps_pert
+              task getae
+                defstatus complete
+                trigger ../eps_sv eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task getsvs
+                defstatus complete
+                trigger getae eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task ocrot
+                defstatus complete
+                trigger getsvs eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task geticp
+                trigger ../getini eq complete
+              family pert_ic
+                inlimit /ptb/a020/coup/limits:PIC
+                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
+                edit EPSTROP '0'
+                family 000
+                  edit MEMBER '0'
+                  task pertinic
+                endfamily
+                family 001
+                  edit MEMBER '1'
+                  task pertinic
+                endfamily
+                family 002
+                  edit MEMBER '2'
+                  task pertinic
+                endfamily
+                family 003
+                  edit MEMBER '3'
+                  task pertinic
+                endfamily
+                family 004
+                  edit MEMBER '4'
+                  task pertinic
+                endfamily
+                family 005
+                  edit MEMBER '5'
+                  task pertinic
+                endfamily
+                family 006
+                  edit MEMBER '6'
+                  task pertinic
+                endfamily
+                family 007
+                  edit MEMBER '7'
+                  task pertinic
+                endfamily
+                family 008
+                  edit MEMBER '8'
+                  task pertinic
+                endfamily
+                family 009
+                  edit MEMBER '9'
+                  task pertinic
+                endfamily
+                family 010
+                  edit MEMBER '10'
+                  task pertinic
+                endfamily
+                family 011
+                  edit MEMBER '11'
+                  task pertinic
+                endfamily
+                family 012
+                  edit MEMBER '12'
+                  task pertinic
+                endfamily
+                family 013
+                  edit MEMBER '13'
+                  task pertinic
+                endfamily
+                family 014
+                  edit MEMBER '14'
+                  task pertinic
+                endfamily
+                family 015
+                  edit MEMBER '15'
+                  task pertinic
+                endfamily
+                family 016
+                  edit MEMBER '16'
+                  task pertinic
+                endfamily
+                family 017
+                  edit MEMBER '17'
+                  task pertinic
+                endfamily
+                family 018
+                  edit MEMBER '18'
+                  task pertinic
+                endfamily
+                family 019
+                  edit MEMBER '19'
+                  task pertinic
+                endfamily
+                family 020
+                  edit MEMBER '20'
+                  task pertinic
+                endfamily
+                family 021
+                  edit MEMBER '21'
+                  task pertinic
+                endfamily
+                family 022
+                  edit MEMBER '22'
+                  task pertinic
+                endfamily
+                family 023
+                  edit MEMBER '23'
+                  task pertinic
+                endfamily
+                family 024
+                  edit MEMBER '24'
+                  task pertinic
+                endfamily
+                family 025
+                  edit MEMBER '25'
+                  task pertinic
+                endfamily
+                family 026
+                  edit MEMBER '26'
+                  task pertinic
+                endfamily
+                family 027
+                  edit MEMBER '27'
+                  task pertinic
+                endfamily
+                family 028
+                  edit MEMBER '28'
+                  task pertinic
+                endfamily
+                family 029
+                  edit MEMBER '29'
+                  task pertinic
+                endfamily
+                family 030
+                  edit MEMBER '30'
+                  task pertinic
+                endfamily
+                family 031
+                  edit MEMBER '31'
+                  task pertinic
+                endfamily
+                family 032
+                  edit MEMBER '32'
+                  task pertinic
+                endfamily
+                family 033
+                  edit MEMBER '33'
+                  task pertinic
+                endfamily
+                family 034
+                  edit MEMBER '34'
+                  task pertinic
+                endfamily
+                family 035
+                  edit MEMBER '35'
+                  task pertinic
+                endfamily
+                family 036
+                  edit MEMBER '36'
+                  task pertinic
+                endfamily
+                family 037
+                  edit MEMBER '37'
+                  task pertinic
+                endfamily
+                family 038
+                  edit MEMBER '38'
+                  task pertinic
+                endfamily
+                family 039
+                  edit MEMBER '39'
+                  task pertinic
+                endfamily
+                family 040
+                  edit MEMBER '40'
+                  task pertinic
+                endfamily
+                family 041
+                  edit MEMBER '41'
+                  task pertinic
+                endfamily
+                family 042
+                  edit MEMBER '42'
+                  task pertinic
+                endfamily
+                family 043
+                  edit MEMBER '43'
+                  task pertinic
+                endfamily
+                family 044
+                  edit MEMBER '44'
+                  task pertinic
+                endfamily
+                family 045
+                  edit MEMBER '45'
+                  task pertinic
+                endfamily
+                family 046
+                  edit MEMBER '46'
+                  task pertinic
+                endfamily
+                family 047
+                  edit MEMBER '47'
+                  task pertinic
+                endfamily
+                family 048
+                  edit MEMBER '48'
+                  task pertinic
+                endfamily
+                family 049
+                  edit MEMBER '49'
+                  task pertinic
+                endfamily
+                family 050
+                  edit MEMBER '50'
+                  task pertinic
+                endfamily
+              endfamily
+            endfamily
+            task ocwavini
+              edit SMSTRIES '2'
+              edit MEM '300'
+              edit NPES '1'
+              edit CPUTIME '400'
+            task ocwcold
+              defstatus complete
+              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
+              edit MEM '800'
+              edit NPES '1'
+              edit THREADS '8'
+              edit CPUTIME '2000'
+            task ocwavfcdata
+              trigger ./ocwcold eq complete and ocwavini eq complete
+            family fc0
+              edit OCFCPERT '0'
+              edit FCGROUP 'fc0'
+              edit SUBFSFAMILY '_an0_fc0'
+              task iniocean
+                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
+              task iniatmos
+                trigger  ( /ptb/a020/coup/fcdate/main/control0/inidata eq complete and /ptb/a020/coup/fcdate/main/control0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/control0/eps_pert eq complete)
+                edit FCCHUNK '1'
+              task cpmodel1
+                inlimit /ptb/a020/coup/limits:cpmodel
+                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/control0/inidata eq complete and /ptb/a020/coup/fcdate/main/control0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/control0/eps_pert eq complete)
+                edit FCCHUNKSUB '1'
+                edit MEM '1300'
+                edit NPES '1'
+                edit THREADS '8'
+                edit EC_SMT 'yes'
+                edit CPUTIME '360000'
+                meter step -1 24 24
+              task extrafields
+                trigger cpmodel1 eq complete
+              task mm_sfc
+                trigger extrafields eq complete
+              task mm_ua
+                trigger mm_sfc eq complete
+            endfamily
+          endfamily
+          family assim0
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an0'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit SUBFSFAMILY '_an0_fc0'
+            edit FCGROUP 'fc0'
+            task getini
+            task inidata
+              trigger getini eq complete
+              edit NPES '12'
+              edit ININPES '12'
+              edit MEM '900'
+              edit THREADS '2'
+              edit CPUTIME '1000'
+            task oceini
+            family eps_sv
+              defstatus complete
+              edit MOFCSV 'true'
+              family svevo
+                edit DELTA_DAY '-2'
+                task getini
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+              endfamily
+              family svini
+                edit DELTA_DAY '0'
+                task getini
+                  trigger ../svevo eq complete
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task targets
+                  trigger svsh eq complete
+                  edit FCLENGTH '48'
+                task subspace
+                  trigger svnh eq complete and svsh eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                task sv1
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '1'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv2
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '2'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv3
+                  trigger sv1 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '3'
+                task sv4
+                  trigger sv2 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '4'
+                task sv5
+                  trigger sv3 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '5'
+                task sv6
+                  trigger sv4 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '6'
+              endfamily
+            endfamily
+            family eps_pert
+              task getae
+                defstatus complete
+                trigger ../eps_sv eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task getsvs
+                defstatus complete
+                trigger getae eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task ocrot
+                defstatus complete
+                trigger getsvs eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task geticp
+                trigger ../getini eq complete
+              family pert_ic
+                inlimit /ptb/a020/coup/limits:PIC
+                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
+                edit EPSTROP '0'
+                family 000
+                  edit MEMBER '0'
+                  task pertinic
+                endfamily
+                family 001
+                  edit MEMBER '1'
+                  task pertinic
+                endfamily
+                family 002
+                  edit MEMBER '2'
+                  task pertinic
+                endfamily
+                family 003
+                  edit MEMBER '3'
+                  task pertinic
+                endfamily
+                family 004
+                  edit MEMBER '4'
+                  task pertinic
+                endfamily
+                family 005
+                  edit MEMBER '5'
+                  task pertinic
+                endfamily
+                family 006
+                  edit MEMBER '6'
+                  task pertinic
+                endfamily
+                family 007
+                  edit MEMBER '7'
+                  task pertinic
+                endfamily
+                family 008
+                  edit MEMBER '8'
+                  task pertinic
+                endfamily
+                family 009
+                  edit MEMBER '9'
+                  task pertinic
+                endfamily
+                family 010
+                  edit MEMBER '10'
+                  task pertinic
+                endfamily
+                family 011
+                  edit MEMBER '11'
+                  task pertinic
+                endfamily
+                family 012
+                  edit MEMBER '12'
+                  task pertinic
+                endfamily
+                family 013
+                  edit MEMBER '13'
+                  task pertinic
+                endfamily
+                family 014
+                  edit MEMBER '14'
+                  task pertinic
+                endfamily
+                family 015
+                  edit MEMBER '15'
+                  task pertinic
+                endfamily
+                family 016
+                  edit MEMBER '16'
+                  task pertinic
+                endfamily
+                family 017
+                  edit MEMBER '17'
+                  task pertinic
+                endfamily
+                family 018
+                  edit MEMBER '18'
+                  task pertinic
+                endfamily
+                family 019
+                  edit MEMBER '19'
+                  task pertinic
+                endfamily
+                family 020
+                  edit MEMBER '20'
+                  task pertinic
+                endfamily
+                family 021
+                  edit MEMBER '21'
+                  task pertinic
+                endfamily
+                family 022
+                  edit MEMBER '22'
+                  task pertinic
+                endfamily
+                family 023
+                  edit MEMBER '23'
+                  task pertinic
+                endfamily
+                family 024
+                  edit MEMBER '24'
+                  task pertinic
+                endfamily
+                family 025
+                  edit MEMBER '25'
+                  task pertinic
+                endfamily
+                family 026
+                  edit MEMBER '26'
+                  task pertinic
+                endfamily
+                family 027
+                  edit MEMBER '27'
+                  task pertinic
+                endfamily
+                family 028
+                  edit MEMBER '28'
+                  task pertinic
+                endfamily
+                family 029
+                  edit MEMBER '29'
+                  task pertinic
+                endfamily
+                family 030
+                  edit MEMBER '30'
+                  task pertinic
+                endfamily
+                family 031
+                  edit MEMBER '31'
+                  task pertinic
+                endfamily
+                family 032
+                  edit MEMBER '32'
+                  task pertinic
+                endfamily
+                family 033
+                  edit MEMBER '33'
+                  task pertinic
+                endfamily
+                family 034
+                  edit MEMBER '34'
+                  task pertinic
+                endfamily
+                family 035
+                  edit MEMBER '35'
+                  task pertinic
+                endfamily
+                family 036
+                  edit MEMBER '36'
+                  task pertinic
+                endfamily
+                family 037
+                  edit MEMBER '37'
+                  task pertinic
+                endfamily
+                family 038
+                  edit MEMBER '38'
+                  task pertinic
+                endfamily
+                family 039
+                  edit MEMBER '39'
+                  task pertinic
+                endfamily
+                family 040
+                  edit MEMBER '40'
+                  task pertinic
+                endfamily
+                family 041
+                  edit MEMBER '41'
+                  task pertinic
+                endfamily
+                family 042
+                  edit MEMBER '42'
+                  task pertinic
+                endfamily
+                family 043
+                  edit MEMBER '43'
+                  task pertinic
+                endfamily
+                family 044
+                  edit MEMBER '44'
+                  task pertinic
+                endfamily
+                family 045
+                  edit MEMBER '45'
+                  task pertinic
+                endfamily
+                family 046
+                  edit MEMBER '46'
+                  task pertinic
+                endfamily
+                family 047
+                  edit MEMBER '47'
+                  task pertinic
+                endfamily
+                family 048
+                  edit MEMBER '48'
+                  task pertinic
+                endfamily
+                family 049
+                  edit MEMBER '49'
+                  task pertinic
+                endfamily
+                family 050
+                  edit MEMBER '50'
+                  task pertinic
+                endfamily
+              endfamily
+            endfamily
+            task ocwavini
+              edit SMSTRIES '2'
+              edit MEM '300'
+              edit NPES '1'
+              edit CPUTIME '400'
+            task ocwcold
+              defstatus complete
+              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
+              edit MEM '800'
+              edit NPES '1'
+              edit THREADS '8'
+              edit CPUTIME '2000'
+            task ocwavfcdata
+              trigger ./ocwcold eq complete and ocwavini eq complete
+            family fc0
+              edit OCFCPERT '0'
+              edit FCGROUP 'fc0'
+              edit SUBFSFAMILY '_an0_fc0'
+              task iniocean
+                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
+              task iniatmos
+                trigger  ( /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
+                edit FCCHUNK '1'
+              task cpmodel1
+                inlimit /ptb/a020/coup/limits:cpmodel
+                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
+                edit FCCHUNKSUB '1'
+                edit MEM '1300'
+                edit NPES '1'
+                edit THREADS '8'
+                edit EC_SMT 'yes'
+                edit CPUTIME '360000'
+                meter step -1 24 24
+              task extrafields
+                trigger cpmodel1 eq complete
+              task mm_sfc
+                trigger extrafields eq complete
+              task mm_ua
+                trigger mm_sfc eq complete
+            endfamily
+          endfamily
+          family assim1
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an1'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit SUBFSFAMILY '_an1_fc1'
+            edit FCGROUP 'fc1'
+            task getini
+              defstatus complete
+            task inidata
+              defstatus complete
+              trigger getini eq complete
+              edit NPES '12'
+              edit ININPES '12'
+              edit MEM '900'
+              edit THREADS '2'
+              edit CPUTIME '1000'
+            task oceini
+            family eps_sv
+              defstatus complete
+              edit MOFCSV 'true'
+              family svevo
+                edit DELTA_DAY '-2'
+                task getini
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+              endfamily
+              family svini
+                edit DELTA_DAY '0'
+                task getini
+                  trigger ../svevo eq complete
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task targets
+                  trigger svsh eq complete
+                  edit FCLENGTH '48'
+                task subspace
+                  trigger svnh eq complete and svsh eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                task sv1
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '1'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv2
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '2'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv3
+                  trigger sv1 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '3'
+                task sv4
+                  trigger sv2 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '4'
+                task sv5
+                  trigger sv3 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '5'
+                task sv6
+                  trigger sv4 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '6'
+              endfamily
+            endfamily
+            family eps_pert
+              defstatus complete
+              task getae
+                defstatus complete
+                trigger ../eps_sv eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task getsvs
+                defstatus complete
+                trigger getae eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task ocrot
+                defstatus complete
+                trigger getsvs eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task geticp
+                trigger ../getini eq complete
+              family pert_ic
+                inlimit /ptb/a020/coup/limits:PIC
+                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
+                edit EPSTROP '0'
+                family 000
+                  edit MEMBER '0'
+                  task pertinic
+                endfamily
+                family 001
+                  edit MEMBER '1'
+                  task pertinic
+                endfamily
+                family 002
+                  edit MEMBER '2'
+                  task pertinic
+                endfamily
+                family 003
+                  edit MEMBER '3'
+                  task pertinic
+                endfamily
+                family 004
+                  edit MEMBER '4'
+                  task pertinic
+                endfamily
+                family 005
+                  edit MEMBER '5'
+                  task pertinic
+                endfamily
+                family 006
+                  edit MEMBER '6'
+                  task pertinic
+                endfamily
+                family 007
+                  edit MEMBER '7'
+                  task pertinic
+                endfamily
+                family 008
+                  edit MEMBER '8'
+                  task pertinic
+                endfamily
+                family 009
+                  edit MEMBER '9'
+                  task pertinic
+                endfamily
+                family 010
+                  edit MEMBER '10'
+                  task pertinic
+                endfamily
+                family 011
+                  edit MEMBER '11'
+                  task pertinic
+                endfamily
+                family 012
+                  edit MEMBER '12'
+                  task pertinic
+                endfamily
+                family 013
+                  edit MEMBER '13'
+                  task pertinic
+                endfamily
+                family 014
+                  edit MEMBER '14'
+                  task pertinic
+                endfamily
+                family 015
+                  edit MEMBER '15'
+                  task pertinic
+                endfamily
+                family 016
+                  edit MEMBER '16'
+                  task pertinic
+                endfamily
+                family 017
+                  edit MEMBER '17'
+                  task pertinic
+                endfamily
+                family 018
+                  edit MEMBER '18'
+                  task pertinic
+                endfamily
+                family 019
+                  edit MEMBER '19'
+                  task pertinic
+                endfamily
+                family 020
+                  edit MEMBER '20'
+                  task pertinic
+                endfamily
+                family 021
+                  edit MEMBER '21'
+                  task pertinic
+                endfamily
+                family 022
+                  edit MEMBER '22'
+                  task pertinic
+                endfamily
+                family 023
+                  edit MEMBER '23'
+                  task pertinic
+                endfamily
+                family 024
+                  edit MEMBER '24'
+                  task pertinic
+                endfamily
+                family 025
+                  edit MEMBER '25'
+                  task pertinic
+                endfamily
+                family 026
+                  edit MEMBER '26'
+                  task pertinic
+                endfamily
+                family 027
+                  edit MEMBER '27'
+                  task pertinic
+                endfamily
+                family 028
+                  edit MEMBER '28'
+                  task pertinic
+                endfamily
+                family 029
+                  edit MEMBER '29'
+                  task pertinic
+                endfamily
+                family 030
+                  edit MEMBER '30'
+                  task pertinic
+                endfamily
+                family 031
+                  edit MEMBER '31'
+                  task pertinic
+                endfamily
+                family 032
+                  edit MEMBER '32'
+                  task pertinic
+                endfamily
+                family 033
+                  edit MEMBER '33'
+                  task pertinic
+                endfamily
+                family 034
+                  edit MEMBER '34'
+                  task pertinic
+                endfamily
+                family 035
+                  edit MEMBER '35'
+                  task pertinic
+                endfamily
+                family 036
+                  edit MEMBER '36'
+                  task pertinic
+                endfamily
+                family 037
+                  edit MEMBER '37'
+                  task pertinic
+                endfamily
+                family 038
+                  edit MEMBER '38'
+                  task pertinic
+                endfamily
+                family 039
+                  edit MEMBER '39'
+                  task pertinic
+                endfamily
+                family 040
+                  edit MEMBER '40'
+                  task pertinic
+                endfamily
+                family 041
+                  edit MEMBER '41'
+                  task pertinic
+                endfamily
+                family 042
+                  edit MEMBER '42'
+                  task pertinic
+                endfamily
+                family 043
+                  edit MEMBER '43'
+                  task pertinic
+                endfamily
+                family 044
+                  edit MEMBER '44'
+                  task pertinic
+                endfamily
+                family 045
+                  edit MEMBER '45'
+                  task pertinic
+                endfamily
+                family 046
+                  edit MEMBER '46'
+                  task pertinic
+                endfamily
+                family 047
+                  edit MEMBER '47'
+                  task pertinic
+                endfamily
+                family 048
+                  edit MEMBER '48'
+                  task pertinic
+                endfamily
+                family 049
+                  edit MEMBER '49'
+                  task pertinic
+                endfamily
+                family 050
+                  edit MEMBER '50'
+                  task pertinic
+                endfamily
+              endfamily
+            endfamily
+            task ocwavini
+              defstatus complete
+              edit SMSTRIES '2'
+              edit MEM '300'
+              edit NPES '1'
+              edit CPUTIME '400'
+            task ocwcold
+              defstatus complete
+              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
+              edit MEM '800'
+              edit NPES '1'
+              edit THREADS '8'
+              edit CPUTIME '2000'
+            task ocwavfcdata
+              defstatus complete
+              trigger ./ocwcold eq complete and ocwavini eq complete
+            family fc1
+              edit OCFCPERT '1'
+              edit FCGROUP 'fc1'
+              edit SUBFSFAMILY '_an1_fc1'
+              task iniocean
+                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
+              task iniatmos
+                trigger  ( /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
+                edit FCCHUNK '1'
+              task cpmodel1
+                inlimit /ptb/a020/coup/limits:cpmodel
+                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
+                edit FCCHUNKSUB '1'
+                edit MEM '1300'
+                edit NPES '1'
+                edit THREADS '8'
+                edit EC_SMT 'yes'
+                edit CPUTIME '360000'
+                meter step -1 24 24
+              task extrafields
+                trigger cpmodel1 eq complete
+              task mm_sfc
+                trigger extrafields eq complete
+              task mm_ua
+                trigger mm_sfc eq complete
+            endfamily
+          endfamily
+          family assim2
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an2'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit SUBFSFAMILY '_an2_fc2'
+            edit FCGROUP 'fc2'
+            task getini
+              defstatus complete
+            task inidata
+              defstatus complete
+              trigger getini eq complete
+              edit NPES '12'
+              edit ININPES '12'
+              edit MEM '900'
+              edit THREADS '2'
+              edit CPUTIME '1000'
+            task oceini
+            family eps_sv
+              defstatus complete
+              edit MOFCSV 'true'
+              family svevo
+                edit DELTA_DAY '-2'
+                task getini
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+              endfamily
+              family svini
+                edit DELTA_DAY '0'
+                task getini
+                  trigger ../svevo eq complete
+                  edit PRIORITY '40'
+                task inidata
+                  trigger getini eq complete
+                  edit NPES '12'
+                  edit ININPES '12'
+                  edit MEM '900'
+                  edit THREADS '2'
+                  edit CPUTIME '1000'
+                task svnh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task svsh
+                  trigger inidata eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB '0'
+                  edit EPSTROP '0'
+                  edit MEMBER '0'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task targets
+                  trigger svsh eq complete
+                  edit FCLENGTH '48'
+                task subspace
+                  trigger svnh eq complete and svsh eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                task sv1
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '1'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv2
+                  trigger targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '2'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                task sv3
+                  trigger sv1 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '3'
+                task sv4
+                  trigger sv2 eq complete and targets eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '4'
+                task sv5
+                  trigger sv3 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '5'
+                task sv6
+                  trigger sv4 eq complete and targets eq complete and subspace eq complete
+                  edit FCLENGTH '48'
+                  edit MEM '1600'
+                  edit NPES '8'
+                  edit THREADS '4'
+                  edit CPUTIME '16000'
+                  edit EC_SMT 'no'
+                  edit EPSSVDIAB 'true'
+                  edit EPSTROP '1'
+                  edit MEMBER '6'
+              endfamily
+            endfamily
+            family eps_pert
+              defstatus complete
+              task getae
+                defstatus complete
+                trigger ../eps_sv eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task getsvs
+                defstatus complete
+                trigger getae eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task ocrot
+                defstatus complete
+                trigger getsvs eq complete
+                edit EPSSVDIAB 'true'
+                edit EPSTROP '1'
+              task geticp
+                trigger ../getini eq complete
+              family pert_ic
+                inlimit /ptb/a020/coup/limits:PIC
+                trigger geticp eq complete and ocrot eq complete and ../inidata eq complete
+                edit EPSTROP '0'
+                family 000
+                  edit MEMBER '0'
+                  task pertinic
+                endfamily
+                family 001
+                  edit MEMBER '1'
+                  task pertinic
+                endfamily
+                family 002
+                  edit MEMBER '2'
+                  task pertinic
+                endfamily
+                family 003
+                  edit MEMBER '3'
+                  task pertinic
+                endfamily
+                family 004
+                  edit MEMBER '4'
+                  task pertinic
+                endfamily
+                family 005
+                  edit MEMBER '5'
+                  task pertinic
+                endfamily
+                family 006
+                  edit MEMBER '6'
+                  task pertinic
+                endfamily
+                family 007
+                  edit MEMBER '7'
+                  task pertinic
+                endfamily
+                family 008
+                  edit MEMBER '8'
+                  task pertinic
+                endfamily
+                family 009
+                  edit MEMBER '9'
+                  task pertinic
+                endfamily
+                family 010
+                  edit MEMBER '10'
+                  task pertinic
+                endfamily
+                family 011
+                  edit MEMBER '11'
+                  task pertinic
+                endfamily
+                family 012
+                  edit MEMBER '12'
+                  task pertinic
+                endfamily
+                family 013
+                  edit MEMBER '13'
+                  task pertinic
+                endfamily
+                family 014
+                  edit MEMBER '14'
+                  task pertinic
+                endfamily
+                family 015
+                  edit MEMBER '15'
+                  task pertinic
+                endfamily
+                family 016
+                  edit MEMBER '16'
+                  task pertinic
+                endfamily
+                family 017
+                  edit MEMBER '17'
+                  task pertinic
+                endfamily
+                family 018
+                  edit MEMBER '18'
+                  task pertinic
+                endfamily
+                family 019
+                  edit MEMBER '19'
+                  task pertinic
+                endfamily
+                family 020
+                  edit MEMBER '20'
+                  task pertinic
+                endfamily
+                family 021
+                  edit MEMBER '21'
+                  task pertinic
+                endfamily
+                family 022
+                  edit MEMBER '22'
+                  task pertinic
+                endfamily
+                family 023
+                  edit MEMBER '23'
+                  task pertinic
+                endfamily
+                family 024
+                  edit MEMBER '24'
+                  task pertinic
+                endfamily
+                family 025
+                  edit MEMBER '25'
+                  task pertinic
+                endfamily
+                family 026
+                  edit MEMBER '26'
+                  task pertinic
+                endfamily
+                family 027
+                  edit MEMBER '27'
+                  task pertinic
+                endfamily
+                family 028
+                  edit MEMBER '28'
+                  task pertinic
+                endfamily
+                family 029
+                  edit MEMBER '29'
+                  task pertinic
+                endfamily
+                family 030
+                  edit MEMBER '30'
+                  task pertinic
+                endfamily
+                family 031
+                  edit MEMBER '31'
+                  task pertinic
+                endfamily
+                family 032
+                  edit MEMBER '32'
+                  task pertinic
+                endfamily
+                family 033
+                  edit MEMBER '33'
+                  task pertinic
+                endfamily
+                family 034
+                  edit MEMBER '34'
+                  task pertinic
+                endfamily
+                family 035
+                  edit MEMBER '35'
+                  task pertinic
+                endfamily
+                family 036
+                  edit MEMBER '36'
+                  task pertinic
+                endfamily
+                family 037
+                  edit MEMBER '37'
+                  task pertinic
+                endfamily
+                family 038
+                  edit MEMBER '38'
+                  task pertinic
+                endfamily
+                family 039
+                  edit MEMBER '39'
+                  task pertinic
+                endfamily
+                family 040
+                  edit MEMBER '40'
+                  task pertinic
+                endfamily
+                family 041
+                  edit MEMBER '41'
+                  task pertinic
+                endfamily
+                family 042
+                  edit MEMBER '42'
+                  task pertinic
+                endfamily
+                family 043
+                  edit MEMBER '43'
+                  task pertinic
+                endfamily
+                family 044
+                  edit MEMBER '44'
+                  task pertinic
+                endfamily
+                family 045
+                  edit MEMBER '45'
+                  task pertinic
+                endfamily
+                family 046
+                  edit MEMBER '46'
+                  task pertinic
+                endfamily
+                family 047
+                  edit MEMBER '47'
+                  task pertinic
+                endfamily
+                family 048
+                  edit MEMBER '48'
+                  task pertinic
+                endfamily
+                family 049
+                  edit MEMBER '49'
+                  task pertinic
+                endfamily
+                family 050
+                  edit MEMBER '50'
+                  task pertinic
+                endfamily
+              endfamily
+            endfamily
+            task ocwavini
+              defstatus complete
+              edit SMSTRIES '2'
+              edit MEM '300'
+              edit NPES '1'
+              edit CPUTIME '400'
+            task ocwcold
+              defstatus complete
+              trigger inidata eq complete and ocwavini eq complete and eps_pert eq complete
+              edit MEM '800'
+              edit NPES '1'
+              edit THREADS '8'
+              edit CPUTIME '2000'
+            task ocwavfcdata
+              defstatus complete
+              trigger ./ocwcold eq complete and ocwavini eq complete
+            family fc2
+              edit OCFCPERT '2'
+              edit FCGROUP 'fc2'
+              edit SUBFSFAMILY '_an2_fc2'
+              task iniocean
+                trigger  ( ../oceini eq complete and  ( ../getini eq active or ../getini eq complete))
+              task iniatmos
+                trigger  ( /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
+                edit FCCHUNK '1'
+              task cpmodel1
+                inlimit /ptb/a020/coup/limits:cpmodel
+                trigger  ( iniocean eq complete and iniatmos eq complete and /ptb/a020/coup/fcdate/main/assim0/inidata eq complete and /ptb/a020/coup/fcdate/main/assim0/ocwavfcdata eq complete and /ptb/a020/coup/fcdate/main/assim0/eps_pert eq complete)
+                edit FCCHUNKSUB '1'
+                edit MEM '1300'
+                edit NPES '1'
+                edit THREADS '8'
+                edit EC_SMT 'yes'
+                edit CPUTIME '360000'
+                meter step -1 24 24
+              task extrafields
+                trigger cpmodel1 eq complete
+              task mm_sfc
+                trigger extrafields eq complete
+              task mm_ua
+                trigger mm_sfc eq complete
+            endfamily
+          endfamily
+          task logfiles
+            trigger control0 eq complete and assim0 eq complete and assim1 eq complete and assim2 eq complete
+            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+            edit LOGDIR '/hpce/rdx_dir/msx'
+            edit MOVE_TO_ECFS 'no'
+        endfamily
+        family lag
+          repeat enumerated YMD  "19690101" "19690102" # status 19690102
+          edit LOGTASK 'fcdate/lag'
+          family control0
+            defstatus complete
+            edit FSFAMILY 'control'
+            edit OCTOTAL '1'
+            edit OCGROUP 'an0'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit FCGROUP 'fc0'
+            edit RUNFC '0'
+            family archive
+              inlimit /ptb/a020/coup/limits:mars
+              edit OCNEWPERTORDER 'yes'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              task preparcoup
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/control0/fc0 eq complete)))
+              task arcfc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+            endfamily
+            family restarts
+              trigger archive eq complete
+              edit FCCHUNKSUB '1'
+              family fc0
+                edit OCFCPERT '0'
+                edit FCGROUP 'fc0'
+                task saverestarts
+              endfamily
+            endfamily
+            task ocflush
+              trigger archive eq complete and restarts eq complete
+            family process
+              family fc0
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/control0/fc0 eq complete)
+                edit OCFCPERT '0'
+                edit FCGROUP 'fc0'
+                task nino_oc
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_daily
+                  trigger nino_oc eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_atmos
+                  trigger nino_daily eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task tcyc
+                  trigger ../../archive eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+              endfamily
+            endfamily
+          endfamily
+          family assim0
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an0'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit FCGROUP 'fc0'
+            edit RUNFC '0'
+            family archive
+              inlimit /ptb/a020/coup/limits:mars
+              edit OCNEWPERTORDER 'yes'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              task preparcoup
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/assim0/fc0 eq complete)))
+              task arcfc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+            endfamily
+            family restarts
+              trigger archive eq complete
+              edit FCCHUNKSUB '1'
+              family fc0
+                edit OCFCPERT '0'
+                edit FCGROUP 'fc0'
+                task saverestarts
+              endfamily
+            endfamily
+            task ocflush
+              trigger archive eq complete and restarts eq complete
+            family process
+              family fc0
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/assim0/fc0 eq complete)
+                edit OCFCPERT '0'
+                edit FCGROUP 'fc0'
+                task nino_oc
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_daily
+                  trigger nino_oc eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_atmos
+                  trigger nino_daily eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task tcyc
+                  trigger ../../archive eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+              endfamily
+            endfamily
+          endfamily
+          family assim1
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an1'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit FCGROUP 'fc1'
+            edit RUNFC '0'
+            family archive
+              inlimit /ptb/a020/coup/limits:mars
+              edit OCNEWPERTORDER 'yes'
+              edit FCGROUP 'fc1'
+              edit FCCHUNK '1'
+              task preparcoup
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/assim1/fc1 eq complete)))
+              task arcfc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+            endfamily
+            family restarts
+              trigger archive eq complete
+              edit FCCHUNKSUB '1'
+              family fc1
+                edit OCFCPERT '1'
+                edit FCGROUP 'fc1'
+                task saverestarts
+              endfamily
+            endfamily
+            task ocflush
+              trigger archive eq complete and restarts eq complete
+            family process
+              family fc1
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/assim1/fc1 eq complete)
+                edit OCFCPERT '1'
+                edit FCGROUP 'fc1'
+                task nino_oc
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_daily
+                  trigger nino_oc eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_atmos
+                  trigger nino_daily eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task tcyc
+                  trigger ../../archive eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+              endfamily
+            endfamily
+          endfamily
+          family assim2
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an2'
+            edit FCTOTAL '1'
+            edit RUNCOUPLE '1'
+            edit FCLENGTH '24'
+            edit FCGROUP 'fc2'
+            edit RUNFC '0'
+            family archive
+              inlimit /ptb/a020/coup/limits:mars
+              edit OCNEWPERTORDER 'yes'
+              edit FCGROUP 'fc2'
+              edit FCCHUNK '1'
+              task preparcoup
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and  (  ( /ptb/a020/coup/fcdate/main/assim2/fc2 eq complete)))
+              task arcfc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_sfc_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+              task mm_ua_arc
+                trigger preparcoup eq complete
+                event fdb
+                label files ""
+            endfamily
+            family restarts
+              trigger archive eq complete
+              edit FCCHUNKSUB '1'
+              family fc2
+                edit OCFCPERT '2'
+                edit FCGROUP 'fc2'
+                task saverestarts
+              endfamily
+            endfamily
+            task ocflush
+              trigger archive eq complete and restarts eq complete
+            family process
+              family fc2
+                trigger  ( /ptb/a020/coup/fcdate/main:YMD gt /ptb/a020/coup/fcdate/lag:YMD) or  ( /ptb/a020/coup/fcdate/main:YMD eq /ptb/a020/coup/fcdate/lag:YMD and /ptb/a020/coup/fcdate/main/assim2/fc2 eq complete)
+                edit OCFCPERT '2'
+                edit FCGROUP 'fc2'
+                task nino_oc
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_daily
+                  trigger nino_oc eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task nino_atmos
+                  trigger nino_daily eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+                task tcyc
+                  trigger ../../archive eq complete
+                  edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+                  edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+                  edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+                  edit LOGDIR '/vol/msexplog/outputs'
+                  edit QUEUE 'expsms'
+              endfamily
+            endfamily
+          endfamily
+          task logfiles
+            trigger control0 eq complete and assim0 eq complete and assim1 eq complete and assim2 eq complete
+            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+            edit LOGDIR '/hpce/rdx_dir/msx'
+            edit MOVE_TO_ECFS 'no'
+        endfamily
+        family clean
+          repeat enumerated YMD  "19690101" "19690102" # status 19690102
+          edit LOGTASK 'fcdate/clean'
+          family control0
+            defstatus complete
+            edit FSFAMILY 'control'
+            edit OCTOTAL '1'
+            edit OCGROUP 'an0'
+            edit RUNCOUPLE '1'
+            edit FCTOTAL '1'
+            edit FCTOT '1'
+            family fc0
+              edit OCFCPERT '0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              task saveoce
+                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/control0 eq complete) and  ( /ptb/a020/coup/fcdate/main/control0 eq complete))))
+              task occleanfdb
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger saveoce eq complete
+                edit ICPDATA '1'
+              task occleanfdbicp
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger occleanfdb eq complete
+              task occleandirs
+                trigger occleanfdb eq complete and occleanfdbicp eq complete
+            endfamily
+          endfamily
+          family assim0
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an0'
+            edit RUNCOUPLE '1'
+            edit FCTOTAL '1'
+            edit FCTOT '3'
+            family fc0
+              edit OCFCPERT '0'
+              edit FCGROUP 'fc0'
+              edit FCCHUNK '1'
+              task saveoce
+                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/assim0 eq complete) and  ( /ptb/a020/coup/fcdate/main/assim0 eq complete))))
+              task occleanfdb
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger saveoce eq complete
+                edit ICPDATA '1'
+              task occleanfdbicp
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger occleanfdb eq complete and ../../assim1 eq complete and ../../assim2 eq complete
+              task occleandirs
+                trigger occleanfdb eq complete and ../../assim1 eq complete and ../../assim2 eq complete and occleanfdbicp eq complete
+            endfamily
+          endfamily
+          family assim1
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an1'
+            edit RUNCOUPLE '1'
+            edit FCTOTAL '1'
+            edit FCTOT '3'
+            family fc1
+              edit OCFCPERT '1'
+              edit FCGROUP 'fc1'
+              edit FCCHUNK '1'
+              task saveoce
+                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/assim1 eq complete) and  ( /ptb/a020/coup/fcdate/main/assim1 eq complete))))
+              task occleanfdb
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger saveoce eq complete
+                edit ICPDATA '1'
+              task occleanfdbicp
+                defstatus complete
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger occleanfdb eq complete
+              task occleandirs
+                trigger occleanfdb eq complete and occleanfdbicp eq complete
+            endfamily
+          endfamily
+          family assim2
+            edit FSFAMILY 'assim'
+            edit OCGROUP 'an2'
+            edit RUNCOUPLE '1'
+            edit FCTOTAL '1'
+            edit FCTOT '3'
+            family fc2
+              edit OCFCPERT '2'
+              edit FCGROUP 'fc2'
+              edit FCCHUNK '1'
+              task saveoce
+                trigger  (  (  ( /ptb/a020/coup/fcdate/lag:YMD gt /ptb/a020/coup/fcdate/clean:YMD) or  ( /ptb/a020/coup/fcdate/lag:YMD eq /ptb/a020/coup/fcdate/clean:YMD and  ( /ptb/a020/coup/fcdate/lag/assim2 eq complete) and  ( /ptb/a020/coup/fcdate/main/assim2 eq complete))))
+              task occleanfdb
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger saveoce eq complete
+                edit ICPDATA '1'
+              task occleanfdbicp
+                defstatus complete
+                inlimit /ptb/a020/coup/limits:fdbclean
+                trigger occleanfdb eq complete
+              task occleandirs
+                trigger occleanfdb eq complete and occleanfdbicp eq complete
+            endfamily
+          endfamily
+          task logfiles
+            trigger control0 eq complete and assim0 eq complete and assim1 eq complete and assim2 eq complete
+            edit SMSCMD 'smssubmit.x %SMSJOB% %SCHOST% %USER%'
+            edit SMSKILL 'smskill %USER% %SCHOST% %SMSRID% %SMSJOB%'
+            edit SMSSTATUSCMD 'smscheck %SCHOST% %EXPVER% %SMSJOB%'
+            edit LOGDIR '/hpce/rdx_dir/msx'
+            edit MOVE_TO_ECFS 'no'
+        endfamily
+      endfamily
+    endfamily
+    task wipefdb
+      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown)
+      edit YMD '19900101'
+      edit HOUR '00'
+      edit FSFAMILY 'cancel'
+    task cancel
+      trigger  ( an eq complete or an eq unknown) and  ( fc eq complete or fc eq unknown) and  ( eps_sv eq complete or eps_sv eq unknown) and  ( eps_fc eq complete or eps_fc eq unknown) and  ( eps_varfc eq complete or eps_varfc eq unknown) and  ( oceatm eq complete or oceatm eq unknown) and  ( oce eq complete or oce eq unknown) and  ( fpos eq complete or fpos eq unknown) and  ( sens eq complete or sens eq unknown) and  ( wam eq complete or wam eq unknown) and  ( oc eq complete or oc eq unknown) and  ( climplot eq complete or climplot eq unknown) and  ( coup eq complete or coup eq unknown) and  ( wipefdb eq complete or wipefdb eq unknown)
+      edit YMD '19900101'
+      edit HOUR '00'
+      edit FSFAMILY 'cancel'
+      edit SMSCMD 'smssubmit.x %SMSJOB% %WSHOST% %USER%'
+      edit SMSKILL 'smskill %USER% %WSHOST% %SMSRID% %SMSJOB%'
+      edit SMSSTATUSCMD 'smscheck %WSHOST% %EXPVER% %SMSJOB%'
+      edit LOGDIR '/vol/msexplog/outputs'
+      edit QUEUE 'expsms'
+  endfamily
+endsuite
+#============================================================
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/queue/queue.def 5.13.0-1/libs/simulator/test/data/good_defs/queue/queue.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/queue/queue.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/queue/queue.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite test_queue
+   queue q1 1 2 3 4
+   task t1
+      verify complete:1  
+   task t2
+      trigger /test_queue:q1 == 4
+      verify complete:1  
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/queue/queue2.def 5.13.0-1/libs/simulator/test/data/good_defs/queue/queue2.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/queue/queue2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/queue/queue2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,18 @@
+suite test_queue
+   task t1
+      queue q1 1 2 3 4
+      verify complete:1  
+   task t2
+      trigger /test_queue/t1:q1 == 4
+        verify complete:1  
+   family f1
+      queue q2 1 2 3 4
+      task t1
+        verify complete:1  
+   endfamily
+   family f2
+      task t1
+        verify complete:1  
+        trigger /test_queue/f1:q2 > 3
+   endfamily  
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/hybrid_time.def 5.13.0-1/libs/simulator/test/data/good_defs/time/hybrid_time.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/hybrid_time.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/hybrid_time.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suite
+  clock hybrid 6.11.2009 +54190
+  family family
+     task t
+        verify complete:3
+        time +00:01 00:03 00:01
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_time_and_dates_hybrid.def 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_time_and_dates_hybrid.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_time_and_dates_hybrid.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_time_and_dates_hybrid.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite suite
+  clock hybrid 5.1.2017
+  family family
+    task t1
+      date  05.01.2017
+      date  06.01.2017
+      time 10:00
+      time 11:00
+      verify complete:2  # because hybrid will be for 24 hrs only
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days.def 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite suite
+  clock real 8.1.2017    # sunday
+  family family
+     task t1
+        day  monday      # day means simulator will run for a 1 week unless endclock used
+        day  tuesday
+        time 09:00
+        time 10:00
+        verify complete:4
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days_hybrid.def 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days_hybrid.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days_hybrid.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_time_and_days_hybrid.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+suite suite
+  clock hybrid 12.10.2010  # monday
+  family family
+    task t1
+      day  monday
+      day  tuesday
+      time 09:00
+      time 10:00
+      time 11:00
+      verify complete:3  # because hybrid will be for 24 hrs only, i.e monday
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_times_and_dates.def 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_times_and_dates.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/multiple_times_and_dates.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/multiple_times_and_dates.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+suite suite
+  clock real 5.1.2017
+  family family
+    task t1
+      date  05.01.2017     # date means simulator will run for a month unless endclock used
+      date  06.01.2017
+      time  13:00
+      time  14:00
+      verify complete:4
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/time.def 5.13.0-1/libs/simulator/test/data/good_defs/time/time.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/time.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/time.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suite
+  clock real 5.1.2017        
+  family family
+     task t1
+        time 13:00       # with time attribute simulator will run for 24 hours
+        verify complete:1
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/time_and_date.def 5.13.0-1/libs/simulator/test/data/good_defs/time/time_and_date.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/time_and_date.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/time_and_date.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite suite     
+  clock real 5.1.2017
+  family family
+    task t1
+      date 05.01.2017      # simulator will run for a month, unless endclock used
+      time 14:00
+      verify complete:1
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/time_and_tomorrows_date.def 5.13.0-1/libs/simulator/test/data/good_defs/time/time_and_tomorrows_date.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/time_and_tomorrows_date.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/time_and_tomorrows_date.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+suite suite
+  clock real 5.1.2017
+  family family
+    task t1
+      date  06.01.2017    # date means simulator will run for a month unless endclock used
+      time  15:00
+      verify complete:1
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/time/time_series.def 5.13.0-1/libs/simulator/test/data/good_defs/time/time_series.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/time/time_series.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/time/time_series.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,8 @@
+suite suite
+  clock real 12.10.2009 # 12 October 2009 was a Monday
+  family family
+     task t1                   # with time attribute simulator will run for 24 hours
+       time 00:30 23:59 04:00  # should run 6 times 00:30 4:30 8:30 12:30 16:30 20:30
+       verify complete:6
+  endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/today/today.def 5.13.0-1/libs/simulator/test/data/good_defs/today/today.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/today/today.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/today/today.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,7 @@
+suite suiteName
+   clock real 1.10.2009 # need to define a date , otherwise we start at current time, and hence test will vary
+   endclock  2.10.2009  # End time, otherwise will simulate for a year, when we have time dependencies
+   task t1
+      today 15:00                   
+      verify complete:1  
+endsuite
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/today/today2.def 5.13.0-1/libs/simulator/test/data/good_defs/today/today2.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/today/today2.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/today/today2.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,16 @@
+suite s1
+   clock real 1.10.2009  # need to define a date , otherwise we start at current time, and hence test will vary
+   endclock  2.10.2009  # End time, otherwise will simulate for a year, when we have time dependencies
+   task t1                   
+      today 20:00                         
+      verify complete:1
+   task t2
+      today 15:00            
+      today 16:00                         
+      today 17:00                         
+      today 18:00                         
+      today 19:00                         
+      today 20:00                         
+      verify complete:6
+endsuite
+
diff -pruN 5.12.4-1/libs/simulator/test/data/good_defs/today/today_range.def 5.13.0-1/libs/simulator/test/data/good_defs/today/today_range.def
--- 5.12.4-1/libs/simulator/test/data/good_defs/today/today_range.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/simulator/test/data/good_defs/today/today_range.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,14 @@
+suite suiteName
+   clock real 1.10.2009  # need to define a date , otherwise we start at current time, and hence test will vary
+   endclock   2.10.2009  # End time, otherwise will simulate for a year, when we have time dependencies
+   task t1
+      today 10:00 11:00 01:00
+      verify complete:2     
+   task t2
+      today 10:00 11:00 00:30
+      verify complete:3    
+   task t3
+      today 09:00
+      today 10:00 11:00 00:30
+      verify complete:4   
+endsuite
diff -pruN 5.12.4-1/libs/test/CMakeLists.txt 5.13.0-1/libs/test/CMakeLists.txt
--- 5.12.4-1/libs/test/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,124 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+set(srcs
+  # Headers
+  src/ServerTestHarness.hpp
+  src/TestFixture.hpp
+  src/ZombieUtil.hpp
+  # Sources
+  src/ServerTestHarness.cpp
+  src/TestFixture.cpp
+  src/ZombieUtill.cpp
+)
+
+ecbuild_add_library(
+  TARGET
+    libharness
+  NOINSTALL
+  TYPE STATIC
+  SOURCES
+    ${srcs}
+  PUBLIC_INCLUDES
+    src
+    ../base/test
+  PUBLIC_LIBS
+    ecflow_all
+)
+target_clangformat(libharness)
+
+# =================================================================
+# test
+
+if (ENABLE_ALL_TESTS)
+
+  set(test_srcs
+    Test_main.cpp # test entry point
+    TestAbortCmd.cpp
+    TestAlias.cpp
+    TestClkSync.cpp
+    TestComplete.cpp
+    TestCron.cpp
+    TestCtsWaitCmd.cpp
+    TestDayDate.cpp
+    TestEcfNoScriptCmd.cpp
+    TestEcfScriptCmd.cpp
+    TestEvents.cpp
+    TestFileCmd.cpp
+    TestHandle.cpp
+    TestInitAddVariable.cpp
+    TestKillCmd.cpp
+    TestLate.cpp
+    TestLimit.cpp
+    TestOrderCmd.cpp
+    TestQueueCmd.cpp
+    TestRepeat.cpp
+    TestRequeueNode.cpp
+    TestServer.cpp
+    TestSpecificIssues.cpp
+    TestSuspend.cpp
+    TestTime.cpp
+    TestToday.cpp
+    TestTrigger.cpp
+    TestWhyCmd.cpp
+  )
+
+  ecbuild_add_test(
+    TARGET
+      s_test
+    LABELS
+      integration
+      nightly
+    SOURCES
+      ${test_srcs}
+    LIBS
+      libharness
+      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    TEST_DEPENDS
+      s_client
+  )
+  target_clangformat(s_test CONDITION ENABLE_TESTS)
+
+  ecbuild_add_test(
+    TARGET
+      s_zombies
+    LABELS
+      integration
+      nightly
+    SOURCES
+      TestZombies.cpp
+      TestZombies_main.cpp # test entry point
+    LIBS
+      libharness
+      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    TEST_DEPENDS
+      s_test
+  )
+  target_clangformat(s_zombies CONDITION ENABLE_TESTS)
+
+  # This test runs forever, hence not suitable as unit test.
+  ecbuild_add_test(
+    TARGET
+      s_single
+    LABELS
+      integration
+      manual
+    SOURCES
+      TestSingle.cpp
+      TestSingle_main.cpp # test entry point
+    LIBS
+      libharness
+      $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+    TEST_DEPENDS
+      s_client
+  )
+  target_clangformat(s_single CONDITION ENABLE_TESTS)
+
+endif()
diff -pruN 5.12.4-1/libs/test/TestAbortCmd.cpp 5.13.0-1/libs/test/TestAbortCmd.cpp
--- 5.12.4-1/libs/test/TestAbortCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestAbortCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,94 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_AbortCmd)
+
+// Test the abort command. This will test the abort command and the
+// retry behaviour. i.e if a task is aborted, and the variable ECF_TRIES
+// is defined. Then providing its value is less the the task's try number
+// we should do an immediate job submission.
+BOOST_AUTO_TEST_CASE(test_abort_cmd) {
+    DurationTimer timer;
+    cout << "Test:: ...test_abort_cmd " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in ecf includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_task_abort_cmd
+    //   edit ECF_TRIES '4'
+    //   family family0
+    //     task abort
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_abort_cmd");
+        suite->addVariable(Variable("ECF_TRIES", "4"));
+        family_ptr fam0 = suite->add_family("family0");
+        task_ptr abort  = fam0->add_task("abort");
+        abort->addVerify(VerifyAttr(NState::ABORTED, 3));  // task should abort 3 times & succeed on 4th attempt
+        abort->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
+    }
+
+    // Create a custom ecf file for test_task_abort_cmd/family0/abort to invoke the child abort command
+    std::string templateEcfFile;
+    templateEcfFile += "%include <head.h>\n";
+    templateEcfFile += "\n";
+    templateEcfFile += "echo do some work\n";
+    templateEcfFile += "if [ %ECF_TRYNO% -le 3 ] ; then\n";
+    templateEcfFile += "   %ECF_CLIENT_EXE_PATH% --abort=\"expected abort at task try no %ECF_TRYNO%\"\n";
+    templateEcfFile += "   trap 0       # Remove all traps\n";
+    templateEcfFile += "   exit 0       # End the shell before child command complete\n";
+    templateEcfFile += "fi\n";
+    templateEcfFile += "\n";
+    templateEcfFile += "%include <tail.h>\n";
+
+    // The test harness will create corresponding directory structure
+    // Override the default ECF file, with our custom ECF_ file
+    std::map<std::string, std::string> taskEcfFileMap;
+    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "abort"), templateEcfFile));
+
+    // Avoid standard verification since we expect to abort many times
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_abort_cmd.def"), taskEcfFileMap);
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestAlias.cpp 5.13.0-1/libs/test/TestAlias.cpp
--- 5.12.4-1/libs/test/TestAlias.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestAlias.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,243 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <limits> // for std::numeric_limits<int>::max()
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/base/cts/user/CFileCmd.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/NOrder.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Alias.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///
+///    This test will TEST:
+///       o Alias creation and running
+///       o Alias ordering
+///       o Alias deletion
+///    Will indirectly test the Alias memento's
+///
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Alias)
+
+void wait_for_alias_to_complete(const std::string& alias_path) {
+    AssertTimer assertTimer(10, false); // Bomb out after 10 seconds, fall back if test fail
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "Could not get the defs from server\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs  = TestFixture::client().defs();
+        node_ptr alias = defs->findAbsNode(alias_path);
+        BOOST_REQUIRE_MESSAGE(alias.get(),
+                              "Could not locate created alias at path " << alias_path << "\n"
+                                                                        << TestFixture::client().errorMsg());
+        if (alias->state() == NState::COMPLETE)
+            break;
+        sleep(2);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_alias) {
+    DurationTimer timer;
+    cout << "Test:: ...test_alias " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in ecf includes
+    //                     Allows test to run without requiring installation
+    Defs theDefs;
+    task_ptr task_a;
+    {
+        suite_ptr suite = theDefs.add_suite("test_alias");
+        suite->add_variable("SLEEPTIME", "0");
+        task_a = suite->add_task("task_a");
+        task_a->addMeter(Meter("meter", 0, 20, 20));
+        task_a->addEvent(Event(1, "event"));
+        task_a->addLabel(Label("task_a_label", "Label1"));
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_alias.def"));
+
+    // After the task has completed create a Alias
+    TestFixture::client().set_throw_on_error(false);
+
+    // Get the ecf script from the current task and use it to create alias
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().file(
+                              task_a->absNodePath(), CFileCmd::toString(CFileCmd::ECF), "10000") == 0,
+                          "Expected to retreive script\n"
+                              << TestFixture::client().errorMsg());
+    std::string script = TestFixture::client().get_string();
+    BOOST_CHECK_MESSAGE(!script.empty(), "script for task " << task_a->absNodePath() << " is empty");
+
+    // TEST Alias CREATION and running =============================================================================
+    // Split the file into line
+    std::vector<std::string> script_lines;
+    Str::split(script, script_lines, "\n");
+
+    NameValueVec used_variables;
+    int result = TestFixture::client().edit_script_submit(
+        task_a->absNodePath(), used_variables, script_lines, true /*create alias*/, true /*run alias*/);
+    BOOST_REQUIRE_MESSAGE(result == 0,
+                          "Expected alias creation and run to succeed\n"
+                              << TestFixture::client().errorMsg());
+    std::string alias0_path = task_a->absNodePath() + "/alias0";
+
+    // Wait for alias to complete.
+    wait_for_alias_to_complete(alias0_path);
+
+    // #ifdef DEBUG
+    //    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0, "Could not get the defs from server\n" <<
+    //    TestFixture::client().errorMsg()); defs_ptr defs = TestFixture::client().defs(); PrintStyle
+    //    style(PrintStyle::STATE); std::cout << *defs;
+    // #endif
+
+    // TEST ORDERING:: Create another alias, but don't run it.
+    // =============================================================================
+    result = TestFixture::client().edit_script_submit(
+        task_a->absNodePath(), used_variables, script_lines, true /*create alias*/, false /*run alias*/);
+    BOOST_REQUIRE_MESSAGE(result == 0, "Expected alias creation succeed\n" << TestFixture::client().errorMsg());
+    {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "Could not get the defs from server\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        std::vector<alias_ptr> aliases;
+        defs->get_all_aliases(aliases);
+        BOOST_REQUIRE_MESSAGE(aliases.size() == 2, "Expected 2 aliases\n" << TestFixture::client().errorMsg());
+    }
+
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::DOWN)) == 0,
+                          "Expected order NOrder::DOWN to succeed\n"
+                              << TestFixture::client().errorMsg());
+    {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "Could not get the defs from server\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
+        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
+
+        std::vector<std::string> expected;
+        expected.push_back("alias1");
+        expected.push_back("alias0");
+        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                              "NOrder::DOWN expected "
+                                  << ecf::algorithm::join(expected) << " but found "
+                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+    }
+
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::UP)) == 0,
+                          "Expected order NOrder::UP to succeed\n"
+                              << TestFixture::client().errorMsg());
+    {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "Could not get the defs from server\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
+        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
+
+        std::vector<std::string> expected;
+        expected.push_back("alias0");
+        expected.push_back("alias1");
+        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                              "NOrder::UP expected "
+                                  << ecf::algorithm::join(expected) << " but found "
+                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+    }
+
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::ORDER)) == 0,
+                          "Expected order NOrder::ORDER to succeed\n"
+                              << TestFixture::client().errorMsg());
+    {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "Could not get the defs from server\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
+        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
+
+        std::vector<std::string> expected;
+        expected.push_back("alias1");
+        expected.push_back("alias0");
+        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                              "NOrder::ORDER expected "
+                                  << ecf::algorithm::join(expected) << " but found "
+                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+    }
+
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().order(alias0_path, NOrder::toString(NOrder::ALPHA)) == 0,
+                          "Expected order NOrder::ALPHA to succeed\n"
+                              << TestFixture::client().errorMsg());
+    {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "Could not get the defs from server\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        Task* task    = defs->findAbsNode(task_a->absNodePath())->isTask();
+        BOOST_REQUIRE_MESSAGE(task, "expected to find Task");
+
+        std::vector<std::string> expected;
+        expected.push_back("alias0");
+        expected.push_back("alias1");
+        BOOST_REQUIRE_MESSAGE(ecf::algorithm::transform_to_name_vector(task->aliases()) == expected,
+                              "NOrder::ALPHA expected "
+                                  << ecf::algorithm::join(expected) << " but found "
+                                  << ecf::algorithm::join(ecf::algorithm::transform_to_name_vector(task->aliases())));
+    }
+
+    // TEST Alias DELETION =============================================================================
+    std::string alias1_path = task_a->absNodePath() + "/alias1";
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_node(alias0_path) == 0,
+                          "delete alias0 failed\n"
+                              << TestFixture::client().errorMsg());
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_node(alias1_path) == 0,
+                          "delete alias1 failed\n"
+                              << TestFixture::client().errorMsg());
+
+    // Get the defs from the server
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                          "Could not get the defs from server\n"
+                              << TestFixture::client().errorMsg());
+    defs_ptr defs = TestFixture::client().defs();
+    std::vector<alias_ptr> aliases;
+    defs->get_all_aliases(aliases);
+    BOOST_REQUIRE_MESSAGE(aliases.empty(), "Alias deletion falied\n" << TestFixture::client().errorMsg());
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestClkSync.cpp 5.13.0-1/libs/test/TestClkSync.cpp
--- 5.12.4-1/libs/test/TestClkSync.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestClkSync.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,168 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_ClkSync)
+
+BOOST_AUTO_TEST_CASE(test_clk_sync) {
+    // This test is used to test sync'ing of the suite calendars
+    // The default clock type is *real*. We will create a suite with a hybrid clock attribute
+    // For the suite calendar, we do not persist the clock type(hybrid/real), since this can be
+    // obtained from the clock attribute. Hence a hybrid calendar in the server, will arrive as
+    // real calendar at the client side. (i.e via the memento). It is then up to the client
+    // to update the calendar with clock type stored in the clock attribute.
+    // See:void Suite::set_memento( const SuiteCalendarMemento* memento )
+    // This test(implicitly) will check that after an incremental sync that suite calendar and
+    // suite clock attribute, that both are of the same clock type.
+    // This is done in ServerTestHarness via invariant checking.
+
+    DurationTimer timer;
+    cout << "Test:: ...test_clk_sync " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in ecf includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    //  suite test_clk_sync
+    //    clocl hybrid
+    //    task a
+    //       meter myMeter 0 100
+    //  endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_clk_sync");
+        suite->addClock(ClockAttr(true)); // add hybrid clock
+        task_ptr task_a = suite->add_task("a");
+        task_a->addMeter(Meter("myMeter", 0, 100, 100));
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_clk_sync.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_suite_calendar_sync) {
+    DurationTimer timer;
+    cout << "Test:: ...test_suite_calendar_sync " << flush;
+    TestClean clean_at_start_and_end;
+
+    // When using ECF_SSL sync is to slow.
+    if (getenv("ECF_SSL")) {
+        cout << " ignore test undel ECF_SSL\n";
+        return;
+    }
+
+    // Test that sync_local(true), sync's the suite clock/calendar.
+    Defs theDefs;
+    {
+        boost::posix_time::ptime today = Calendar::second_clock_time();
+        suite_ptr suite                = theDefs.add_suite("test_suite_calendar_sync");
+        family_ptr fam                 = suite->add_family("family");
+        task_ptr task                  = fam->add_task("t1");
+
+        // Don't use hybrid for day dependency as that will force node to complete if days is not the same
+        ClockAttr clockAttr(today, false);
+        suite->addClock(clockAttr);
+
+        // ** add tomorrow days so that node stays queued, hence EXPECT no job and no output **
+        task->addDay(DayAttr(today.date() + boost::gregorian::date_duration(1)));
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_suite_calendar_sync.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Get full defs, so that next sync_local does incremental update
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
+                          CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
+    std::stringstream ss;
+    ss << "\nStart time"
+       << "\n  sync_full: suite time : " << TestFixture::client().defs()->suiteVec()[0]->calendar().toString()
+       << " cal_count(" << TestFixture::client().defs()->updateCalendarCount() << ")\n";
+
+    for (size_t i = 0; i < 3; i++) {
+        // Occasionally we get a random failure.
+        // It is suspected that BETWEEN the two calls below, one off
+        //    Suite::updateCalendar() or Suite::resolveDependencies() is called in the server:
+        // Unfortunately the data required to confirm this is not available on the client side: i.e.
+        //  - Defs::updateCalendarCount_ not persisted with incremental clk sync
+        //  - Suite::calendar_change_no_
+        // To minimise this, avoid sleep that is same as job submission interval
+
+        sleep(TestFixture::job_submission_interval() + 1); // expect 1 minute increment in suite_time.
+
+        ss << "loop:" << i << "\n";
+
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local(true /*sync suite clock*/) == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        boost::posix_time::ptime sync_clock_suiteTime =
+            TestFixture::client().defs()->suiteVec()[0]->calendar().suiteTime();
+        ss << "   Sync clock suite time:" << to_simple_string(sync_clock_suiteTime) << " full_sync("
+           << TestFixture::client().server_reply().full_sync() << ")"
+           << " in_sync(" << TestFixture::client().server_reply().in_sync() << ") cal_count("
+           << TestFixture::client().defs()->updateCalendarCount() << ")\n";
+
+        // suiteVec is now invalidated
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
+                              CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
+        boost::posix_time::ptime sync_full_suiteTime =
+            TestFixture::client().defs()->suiteVec()[0]->calendar().suiteTime();
+        ss << "   Sync full suite time :" << to_simple_string(sync_full_suiteTime) << " full_sync("
+           << TestFixture::client().server_reply().full_sync() << ")"
+           << " in_sync(" << TestFixture::client().server_reply().in_sync() << ") cal_count("
+           << TestFixture::client().defs()->updateCalendarCount() << ")\n";
+
+        BOOST_REQUIRE_MESSAGE(sync_clock_suiteTime == sync_full_suiteTime,
+                              ss.str() << "\nloop:" << i << " waited for " << TestFixture::job_submission_interval() + 1
+                                       << "s for each loop"
+                                          "\n"
+                                       << TestFixture::client().defs());
+    }
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestComplete.cpp 5.13.0-1/libs/test/TestComplete.cpp
--- 5.12.4-1/libs/test/TestComplete.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestComplete.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,172 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Complete)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+//
+// This test shows the use of repeat and complete. this shows how
+// we can repeat a family without waiting for all the children to
+// complete. See page 65 of user manual
+//
+// As protection against user, a family should not complete
+// if any of its children are still in ACTIVE or SUBMIITED state.
+//
+// **************************************************************************
+// Note: When we use a complete expression. Node resolution will set complete
+//      hierarchically
+// **************************************************************************
+BOOST_AUTO_TEST_CASE(test_complete) {
+    DurationTimer timer;
+    cout << "Test:: ...test_complete " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_complete
+    //   family family
+    //     repeat integer YMD 0 1
+    //     complete ./family/check:nofiles  # repeat family with waiting for children to complete
+    //     task check
+    //       event 1 nofiles
+    //     task t1
+    //       trigger check==complete
+    //       task t2
+    //     trigger t2 == complete   #  never runs
+    //   endfamily
+    // endsuite
+    std::string eventName = "nofiles";
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_complete");
+        family_ptr fam  = suite->add_family("family");
+        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat family 2 times
+        fam->add_complete("/test_complete/family/check:nofiles");
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 2)); // family should complete 2 times
+
+        task_ptr task_check = fam->add_task("check");
+        task_check->addEvent(Event(1, eventName));
+        task_check->addVerify(VerifyAttr(NState::COMPLETE, 2));
+
+        task_ptr task_t1 = fam->add_task("t1");
+        task_t1->add_trigger("check == complete");
+        task_t1->addVerify(VerifyAttr(NState::COMPLETE, 2));
+
+        task_ptr task_t2 = fam->add_task("t2");
+        task_t2->add_trigger("t2 == complete");
+        task_t2->addVerify(VerifyAttr(NState::COMPLETE, 2));
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_complete.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_complete_does_not_hold) {
+    DurationTimer timer;
+    cout << "Test:: ...test_complete_does_not_hold " << flush;
+
+    /// This test shows that a complete expression should not hold a node
+    /// A complete should complete a node, and not hold it
+
+    // suite test_complete
+    //   family family
+    //     complete 1 == 0            # impossible expression that never evaluates
+    //     task t1                    # task t1 should still run
+    //     task t2
+    //         complete 1 == 0        # impossible expression that never evaluates
+    //         trigger t1 == complete # task t2 should still run
+    //     endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_complete_does_not_hold");
+        family_ptr fam  = suite->add_family("family");
+        fam->add_complete("1 == 0");
+        task_ptr t1 = fam->add_task("t1");
+        t1->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        task_ptr t2 = fam->add_task("t2");
+        t2->add_trigger("t1 == complete");
+        t2->add_complete("1 == 0");
+        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_complete_does_not_hold.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_complete_with_empty_family) {
+    DurationTimer timer;
+    cout << "Test:: ...test_complete_with_empty_family " << flush;
+
+    // Test a family with a complete expression and that has no children
+
+    // suite test_complete_with_empty_family
+    //   family empty
+    //      complete /test_complete_with_empty_family/family/t1 == complete and
+    //               /test_complete_with_empty_family/family/t2 == complete
+    //   family family
+    //       task t1
+    //       task t2
+    //     endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite  = theDefs.add_suite("test_complete_with_empty_family");
+        family_ptr empty = suite->add_family("empty");
+        empty->add_complete("/test_complete_with_empty_family/family/t1 == complete and "
+                            "/test_complete_with_empty_family/family/t2 == complete");
+        empty->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        family_ptr fam = suite->add_family("family");
+        fam->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        fam->add_task("t2")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_complete_with_empty_family.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestCron.cpp 5.13.0-1/libs/test/TestCron.cpp
--- 5.12.4-1/libs/test/TestCron.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestCron.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,144 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Cron)
+
+static void wait_for_cron(int max_time_to_wait, const std::string& path) {
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    TestFixture::client().set_throw_on_error(false);
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        if (defs) {
+            node_ptr node = defs->findAbsNode(path);
+            BOOST_REQUIRE_MESSAGE(node, "Could not find task at path " << path);
+            if (node) {
+                const std::vector<VerifyAttr>& verifys = node->verifys();
+                BOOST_REQUIRE_MESSAGE(verifys.size() == 1, "Expected 1 verify");
+                if (!verifys.empty()) {
+                    if (verifys[0].actual() == verifys[0].expected()) {
+                        break;
+                    }
+                }
+            }
+        }
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                                  "wait_for_cron: Test wait " << assertTimer.duration()
+                                                              << " taking longer than time constraint of "
+                                                              << assertTimer.timeConstraint() << " aborting\n"
+                                                              << *defs);
+            break;
+        }
+        sleep(1);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_cron_time_series) {
+    DurationTimer timer;
+    cout << "Test:: ...test_cron_time_series " << flush;
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_cron_time_series
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       cron <start> <finish> <incr>
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    std::string path;
+    {
+        // Initialise clock with todays date and time, then create a cron attribute
+        // with a time series, so that task runs 3 times
+
+        // Note: we don't use:
+        //    boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
+        // Because this can fail with:
+        //    Test:: ...test_cron_time_series unknown location(0): fatal error in
+        //             "test_cron_time_series": std::out_of_range:
+        //             TimeSeries::TimeSeries: Invalid time series: Start time(23:58) is greater than end time(00:02)
+        // i.e
+        // if the test is started at 23:58, then adding the end time of by doing start_time + 5 will fail the check
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
+        boost::posix_time::ptime time2        = theLocalTime + minutes(5);
+
+        suite_ptr suite = theDefs.add_suite("test_cron_time_series");
+        ClockAttr clockAttr(theLocalTime, false);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
+
+        CronAttr cronAttr;
+        cronAttr.addTimeSeries(
+            ecf::TimeSlot(time1.time_of_day()), ecf::TimeSlot(time2.time_of_day()), ecf::TimeSlot(0, 2));
+        task->addCron(cronAttr);
+
+        path = task->absNodePath();
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.add_default_sleep_time(
+        false); // avoid missing time steps due to submit->active->complete > job submission interval
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_cron_time_series.def"),
+                          1 /* timeout ignored*/,
+                          false /*waitForTestCompletion*/);
+
+    // crons are *infinite*, just wait for cron to complete 3 times
+    wait_for_cron(40, path);
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestCtsWaitCmd.cpp 5.13.0-1/libs/test/TestCtsWaitCmd.cpp
--- 5.12.4-1/libs/test/TestCtsWaitCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestCtsWaitCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,226 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_CtsWaitCmd)
+
+static void create_defs(Defs& theDefs, const std::string& suite_name) {
+    // suite test_wait_cmd
+    //   family family0
+    //       task wait
+    //   family family1
+    //       task a
+    //       task b
+    //   endfamily
+    //   family family2
+    //          task aa
+    //          task bb
+    //    endfamily
+    // endsuite
+    suite_ptr suite = theDefs.add_suite(suite_name);
+    family_ptr fam0 = suite->add_family("family0");
+    task_ptr wait   = fam0->add_task("wait");
+    wait->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
+
+    family_ptr fam1 = suite->add_family("family1");
+    fam1->add_task("a");
+    fam1->add_task("b");
+
+    family_ptr fam2 = suite->add_family("family2");
+    fam2->add_task("aa");
+    fam2->add_task("bb");
+}
+
+static bool wait_for_state(std::vector<std::pair<std::string, NState::State>>& path_state_vec, int max_time_to_wait) {
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs      = TestFixture::client().defs();
+        bool all_states_ok = true;
+        for (size_t i = 0; i < path_state_vec.size(); ++i) {
+            node_ptr node = defs->findAbsNode(path_state_vec[i].first);
+            BOOST_REQUIRE_MESSAGE(node,
+                                  "Could not find path '" << path_state_vec[i].first << "' in the defs\n"
+                                                          << *defs);
+            if (node->state() != path_state_vec[i].second) {
+                all_states_ok = false;
+                break;
+            }
+        }
+        if (all_states_ok)
+            return true;
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                                  "wait_for_state: Test wait " << assertTimer.duration()
+                                                               << " taking longer than time constraint of "
+                                                               << assertTimer.timeConstraint() << " aborting\n"
+                                                               << *defs);
+            break;
+        }
+        sleep(1);
+    }
+    return false;
+}
+
+// Test the wait command. The Wait command is a child command.
+// The wait command is provided an expression. This expression is evaluated
+// in the server. If the evaluate returns false then the client should
+// blocks until the evaluation is true.
+// In this case the job associated with task 'wait' should block until the expression evaluates
+// to true, which should be after the completion of all other tasks
+BOOST_AUTO_TEST_CASE(test_wait_cmd) {
+    DurationTimer timer;
+    cout << "Test:: ...test_wait_cmd " << flush;
+    TestClean clean_at_start_and_end;
+
+    Defs theDefs;
+    create_defs(theDefs, "test_wait_cmd");
+
+    // Create a custom sms file for test_wait_cmd/family0/wait to invoke the child wait command
+    // with an expression that forces it to block, until all other tasks complete
+    std::string templateEcfFileForWait;
+    templateEcfFileForWait += "%include <head.h>\n";
+    templateEcfFileForWait += "\n";
+    templateEcfFileForWait += "echo do some work\n";
+    templateEcfFileForWait += "%ECF_CLIENT_EXE_PATH% --wait=\"../family1/a eq complete and ../family1/b eq complete "
+                              "and ../family2/aa eq complete and ../family2/bb eq complete\"\n";
+    templateEcfFileForWait += "\n";
+    templateEcfFileForWait += "%include <tail.h>\n";
+
+    // The test harness will create corresponding directory structure
+    // Override the default ECF_ file, with our custom ECF_ file
+    std::map<std::string, std::string> taskEcfFileMap;
+    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "wait"), templateEcfFileForWait));
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_wait_cmd.def"), taskEcfFileMap);
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_wait_cmd_parse_fail) {
+    DurationTimer timer;
+    cout << "Test:: ...test_wait_cmd_parse_fail " << flush;
+
+    // This time we add a wait expression that
+    // should fail to parse, and we should return an error
+    // The error should captured by the trap in .ecf script, which will
+    // then abort the task
+    Defs theDefs;
+    create_defs(theDefs, "test_wait_cmd_parse_fail");
+
+    // Create a custom ecf file for test_wait_cmd/family0/wait to invoke the child wait command
+    std::string templateEcfFileForWait;
+    templateEcfFileForWait += "%include <head.h>\n";
+    templateEcfFileForWait += "\n";
+    templateEcfFileForWait += "echo do some work\n";
+    templateEcfFileForWait += "%ECF_CLIENT_EXE_PATH% --wait=\"(((((((((../family1/a eq complete and ../family1/b eq "
+                              "complete and ../family2/aa eq complete and ../family2/bb eq complete\"\n";
+    templateEcfFileForWait += "\n";
+    templateEcfFileForWait += "%include <tail.h>\n";
+
+    std::map<std::string, std::string> taskEcfFileMap;
+    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "wait"), templateEcfFileForWait));
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_wait_cmd_parse_fail.def"),
+                          taskEcfFileMap,
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    // wait for family1 and family2 to complete
+    std::vector<std::pair<std::string, NState::State>> path_state_vec;
+    path_state_vec.push_back(std::make_pair(std::string("/test_wait_cmd_parse_fail/family1"), NState::COMPLETE));
+    path_state_vec.push_back(std::make_pair(std::string("/test_wait_cmd_parse_fail/family2"), NState::COMPLETE));
+    wait_for_state(path_state_vec, 10);
+
+    // wait for 'wait' task to abort
+    path_state_vec.clear();
+    path_state_vec.push_back(std::make_pair(std::string("/test_wait_cmd_parse_fail/family0/wait"), NState::ABORTED));
+    wait_for_state(path_state_vec, 10);
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_wait_cmd_non_existant_paths) {
+    DurationTimer timer;
+    cout << "Test:: ...test_wait_cmd_non_existant_paths " << flush;
+
+    // This time we add a wait expression that should fail
+    // because the paths referenced in the expression don't exist
+    Defs theDefs;
+    create_defs(theDefs, "test_wait_cmd_non_existant_paths");
+
+    // Create a custom ecf file for test_wait_cmd/family0/wait to invoke the child wait command
+    // NOTE: ../family1/FRED does not exist
+    std::string templateEcfFileForWait;
+    templateEcfFileForWait += "%include <head.h>\n";
+    templateEcfFileForWait += "\n";
+    templateEcfFileForWait += "echo do some work\n";
+    templateEcfFileForWait += "%ECF_CLIENT_EXE_PATH% --wait=\"../family1/FRED eq complete and ../family1/b eq complete "
+                              "and ../family2/aa eq complete and ../family2/bb eq complete\"\n";
+    templateEcfFileForWait += "\n";
+    templateEcfFileForWait += "%include <tail.h>\n";
+
+    std::map<std::string, std::string> taskEcfFileMap;
+    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "wait"), templateEcfFileForWait));
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_wait_cmd_non_existant_paths.def"),
+                          taskEcfFileMap,
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    // wait for family1 and family2 to complete
+    std::vector<std::pair<std::string, NState::State>> path_state_vec;
+    path_state_vec.push_back(
+        std::make_pair(std::string("/test_wait_cmd_non_existant_paths/family1"), NState::COMPLETE));
+    path_state_vec.push_back(
+        std::make_pair(std::string("/test_wait_cmd_non_existant_paths/family2"), NState::COMPLETE));
+    wait_for_state(path_state_vec, 10);
+
+    // wait for 'wait' task to abort
+    path_state_vec.clear();
+    path_state_vec.push_back(
+        std::make_pair(std::string("/test_wait_cmd_non_existant_paths/family0/wait"), NState::ABORTED));
+    wait_for_state(path_state_vec, 10);
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestDayDate.cpp 5.13.0-1/libs/test/TestDayDate.cpp
--- 5.12.4-1/libs/test/TestDayDate.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestDayDate.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,141 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_DayDate)
+
+BOOST_AUTO_TEST_CASE(test_day_at_midnight) {
+    // See ECFLOW-337 versus ECFLOW-1550
+    DurationTimer timer;
+    cout << "Test:: ...test_day_at_midnight " << flush;
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_time_real_series
+    //  edit SLEEPTIME 1
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <date>
+    //  family family
+    //     day  monday
+    //     time 23:59
+    //     task t1
+    //     task t2   # will stray into Tuesday but should still run
+    //     task t3   # will stray into Tuesday but should still run
+    //     endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_day_at_midnight");
+        ClockAttr clockAttr(boost::posix_time::ptime(date(2019, 9, 9), time_duration(23, 58, 0)),
+                            false); // Monday @ 23:58
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addTime(ecf::TimeAttr("23:59"));
+        fam->addDay(DayAttr(DayAttr::MONDAY));
+        fam->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        task_ptr t2 = fam->add_task("t2");
+        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        t2->add_trigger("t1 == complete");
+
+        task_ptr t3 = fam->add_task("t3");
+        t3->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        t3->add_trigger("t2 == complete");
+    }
+    // cout << "\n" << theDefs;
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_day_at_midnight.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_date_at_midnight) {
+    // See ECFLOW-337 versus ECFLOW-1550
+    DurationTimer timer;
+    cout << "Test:: ...test_date_at_midnight " << flush;
+    TestClean clean_at_start_and_end;
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_time_real_series
+    //  edit SLEEPTIME 1
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  clock real <date>
+    //  family family
+    //     date 9.9.2019 # Monday
+    //     time 23:59
+    //     task t1
+    //     task t2   # will stray into Tuesday but should still run
+    //     task t3   # will stray into Tuesday but should still run
+    //     endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_date_at_midnight");
+        ClockAttr clockAttr(boost::posix_time::ptime(date(2019, 9, 9), time_duration(23, 58, 0)),
+                            false); // Monday @ 23:58
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        fam->addTime(ecf::TimeAttr("23:59"));
+        fam->addDate(DateAttr("9.9.2019"));
+        fam->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        task_ptr t2 = fam->add_task("t2");
+        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        t2->add_trigger("t1 == complete");
+
+        task_ptr t3 = fam->add_task("t3");
+        t3->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        t3->add_trigger("t2 == complete");
+    }
+    // cout << "\n" << theDefs;
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_date_at_midnight.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestEcfNoScriptCmd.cpp 5.13.0-1/libs/test/TestEcfNoScriptCmd.cpp
--- 5.12.4-1/libs/test/TestEcfNoScriptCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestEcfNoScriptCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,81 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_EcfNoScriptCmd)
+
+BOOST_AUTO_TEST_CASE(test_ecf_no_script) {
+    // This test is used to case where we ONLY want to execute ECF_JOB_CMD WITHOUT processing .ecf script.
+    // For this ECF_NO_SCRIPT must be set to any value.
+    // The ECF_JOB_CMD must then encompass ecflow_client --init/complete and the environment settings
+    // Additionally the user can see the output by directing the word done to ECF_JOBOUT
+    // Although ServerTestHarness creates the .ecf file, they are ignored when ECF_NO_SCRIPT is specified.
+
+    DurationTimer timer;
+    cout << "Test:: ...test_ecf_no_script " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    //  suite test_ecf_no_script_cmd
+    //       edit ECF_NO_SCRIPT 1
+    //       edit ECF_JOB_CMD "export ECF_PASS=%ECF_PASS%;...."
+    //       task t1
+    //       task t2
+    //      endfamily
+    //  endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_ecf_no_script");
+        suite->add_variable("ECF_NO_SCRIPT", "1");
+        std::string ecf_job_cmd = "export ECF_PASS=%ECF_PASS%;export ECF_PORT=%ECF_PORT%;export "
+                                  "ECF_HOST=%ECF_HOST%;export ECF_NAME=%ECF_NAME%;export ECF_TRYNO=%ECF_TRYNO%;";
+        ecf_job_cmd += "%ECF_CLIENT_EXE_PATH% --init=$$; echo 'test test_ecf_no_script' >> %ECF_JOBOUT%; "
+                       "%ECF_CLIENT_EXE_PATH% --complete";
+        suite->add_variable("ECF_JOB_CMD", ecf_job_cmd);
+        suite->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        suite->add_task("t2")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        // cout << theDefs;
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_ecf_no_script.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestEcfScriptCmd.cpp 5.13.0-1/libs/test/TestEcfScriptCmd.cpp
--- 5.12.4-1/libs/test/TestEcfScriptCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestEcfScriptCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_EcfScriptCmd)
+
+BOOST_AUTO_TEST_CASE(test_ECF_SCRIPT_CMD) {
+    DurationTimer timer;
+    cout << "Test:: ...test_ECF_SCRIPT_CMD " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    //  suite test_ECF_SCRIPT_CMD
+    //    family family
+    //      task check
+    //          edit ECF_SCRIPT_CMD "cat $ECF_HOME/test_ECF_SCRIPT_CMD/family/check.ecf"
+    //      task t1
+    //          trigger check == complete
+    //          edit ECF_SCRIPT_CMD "cat $ECF_HOME/test_ECF_SCRIPT_CMD/family/t1.ecf"
+    //    endfamily
+    //  endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_ECF_SCRIPT_CMD");
+        family_ptr fam  = suite->add_family("family");
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        task_ptr task_check = fam->add_task("check");
+        task_check->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        task_check->add_variable("ECF_SCRIPT_CMD",
+                                 "cat " + TestFixture::smshome() + task_check->absNodePath() + File::ECF_EXTN());
+
+        task_ptr task_t1 = fam->add_task("t1");
+        task_t1->add_trigger("check == complete");
+        task_t1->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        task_t1->add_variable("ECF_SCRIPT_CMD",
+                              "cat " + TestFixture::smshome() + task_t1->absNodePath() + File::ECF_EXTN());
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_ECF_SCRIPT_CMD.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestEvents.cpp 5.13.0-1/libs/test/TestEvents.cpp
--- 5.12.4-1/libs/test/TestEvents.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestEvents.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,170 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Events)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+
+BOOST_AUTO_TEST_CASE(test_event_and_query) {
+    DurationTimer timer;
+    cout << "Test:: ...test_event_and_query " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    //  suite test_events
+    //    family family1
+    //        task a
+    //          event 1 myEvent          # initial value is clear(default), child command is expected to set
+    //          event ecflow_1527 set    # initial value is set,            child command is expected to clear
+    //          meter myMeter 0 100
+    //          label task_a_label Label1
+    //        task b
+    //           trigger a:myEvent and a:ecflow_1527 == clear
+    //           label task_b_label label1
+    //     endfamily
+    //     family family2
+    //           task aa
+    //              trigger ../family1/a:myMeter >= 90 and ../family1/a:myEvent
+    //           task bb
+    //              trigger ../family1/a:myMeter >= 50  or  ../family1/a:myEvent
+    //      endfamily
+    //  endsuite
+    Defs theDefs;
+    task_ptr task_a;
+    task_ptr task_b;
+    suite_ptr suite;
+    {
+        suite = theDefs.add_suite("test_events");
+        suite->addLimit(Limit("limit_x", 15)); // just to test query ; limit
+        {
+            family_ptr fam = suite->add_family("family1");
+            task_a         = fam->add_task("a");
+            task_a->addMeter(Meter("myMeter", 0, 100, 100));                // ServerTestHarness will add correct ecf
+            task_a->addEvent(Event(1, "myEvent"));                          // ServerTestHarness will add correct ecf
+            task_a->addEvent(Event("ecflow_1527", true /*initial value*/)); // ServerTestHarness will add correct ecf
+            task_a->addLabel(Label("task_a_label", "task_a_label_value"));  // ServerTestHarness will add correct ecf
+            task_a->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+            task_b = fam->add_task("b");
+            task_b->add_trigger("a:myEvent and a:ecflow_1527 == clear");
+            task_b->addLabel(Label(
+                "task_b_label", "task_b_label_value", "new_label_value")); // ServerTestHarness will add correct ecf
+            task_b->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+        {
+            family_ptr fam2  = suite->add_family("family2");
+            task_ptr task_aa = fam2->add_task("aa");
+            task_ptr task_bb = fam2->add_task("bb");
+            task_aa->add_trigger("../family1/a:myMeter >= 90 and ../family1/a:myEvent");
+            task_aa->addVerify(VerifyAttr(NState::COMPLETE, 1));
+            task_bb->add_trigger("../family1/a:myMeter >= 50  or  ../family1/a:myEvent");
+            task_bb->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+        // cout << theDefs;
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_events.def"));
+
+    TestFixture::client().set_child_path(task_a->absNodePath()); // simulate call from a job, to see logging of job/task
+                                                                 // calling TestFixture::client().query()
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("meter", task_a->absNodePath(), "myMeter") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "100",
+                        "Expected query of meter to return 100 but found " << TestFixture::client().get_string());
+
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("event", task_a->absNodePath(), "myEvent") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "set",
+                        "Expected query of event to return 'set' but found " << TestFixture::client().get_string());
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("event", task_a->absNodePath(), "ecflow_1527") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "clear",
+                        "Expected query of event to return 'clear' but found " << TestFixture::client().get_string());
+
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("variable", task_a->absNodePath(), "ECF_TRYNO") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "1",
+                        "Expected query of variable(ECF_TRYNO) to return '1' but found "
+                            << TestFixture::client().get_string());
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("variable", task_a->absNodePath(), "ECF_PORT") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == TestFixture::client().port(),
+                        "Expected query of variable(ECF_PORT) to return "
+                            << TestFixture::client().port() << " but found " << TestFixture::client().get_string());
+
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("trigger", task_a->absNodePath(), "b == complete") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "true",
+                        "Expected query of trigger to return 'true' but found " << TestFixture::client().get_string());
+
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("label", task_a->absNodePath(), "task_a_label") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "task_a_label_value",
+                        "Expected query of label to return 'task_a_label_value' but found "
+                            << TestFixture::client().get_string());
+
+    BOOST_CHECK_MESSAGE(TestFixture::client().query("label", task_b->absNodePath(), "task_b_label") == 0,
+                        "query command failed " << TestFixture::client().errorMsg());
+    BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "new_label_value",
+                        "Expected query of label to return 'new_label_value' but found "
+                            << TestFixture::client().get_string());
+
+    // Added since in 5.2.0 (only 5.2.0 server supports this behaviour)
+    if (!getenv("ECF_DISABLE_TEST_FOR_OLD_SERVERS")) {
+        BOOST_CHECK_MESSAGE(TestFixture::client().query("limit", suite->absNodePath(), "limit_x") == 0,
+                            "query command failed " << TestFixture::client().errorMsg());
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "0",
+                            "Expected query of limit to return '0' but found " << TestFixture::client().get_string());
+
+        BOOST_CHECK_MESSAGE(TestFixture::client().query("limit_max", suite->absNodePath(), "limit_x") == 0,
+                            "query command failed " << TestFixture::client().errorMsg());
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_string() == "15",
+                            "Expected query of limit_max to return '15' but found "
+                                << TestFixture::client().get_string());
+    }
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestFileCmd.cpp 5.13.0-1/libs/test/TestFileCmd.cpp
--- 5.12.4-1/libs/test/TestFileCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestFileCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,139 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/base/cts/user/CFileCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///
+/// \note This is used to INVOKE a SINGLE test. Easier for debugging
+///
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_FileCmd)
+
+BOOST_AUTO_TEST_CASE(test_file_cmd) {
+    DurationTimer timer;
+    cout << "Test:: ...test_file_cmd " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocate-able
+    // suite test_file_cmd
+    //  edit SLEEPTIME 1
+    //  edit ECF_INCLUDE $ECF_HOME/includes
+    //  family family
+    //     task t1
+    //     task t2
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_file_cmd");
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        family_ptr fam = suite->add_family("family");
+        int taskSize   = 2; // on linux 1024 tasks take ~4 seconds for job submission
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files AND will generate man files for node containers
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.generateManFileForNodeContainers();
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_file_cmd.def"));
+
+    // Now invoke the file command to extract <ecffile,job file,job output, manual >
+    // If the requests succeeded the client needs to create a temporary file, and populate it with
+    // the contents of the string returned from the server
+    TestFixture::client().set_throw_on_error(false);
+
+    std::vector<Node*> nodeVec;
+    theDefs.getAllNodes(nodeVec);
+
+    for (Node* node : nodeVec) {
+
+        string nodePath                            = node->absNodePath();
+        std::vector<CFileCmd::File_t> fileTypesVec = CFileCmd::fileTypesVec();
+        for (size_t i = 0; i < fileTypesVec.size(); i++) {
+
+            string file_type                 = CFileCmd::toString(fileTypesVec[i]);
+            std::vector<std::string> theArgs = CtsApi::file(nodePath, file_type, "10000");
+            std::string args;
+            for (size_t x = 0; x < theArgs.size(); x++) {
+                args += theArgs[x];
+                args += " ";
+            }
+
+            int theResult = TestFixture::client().file(nodePath, file_type, "10000");
+            //         cout << "nodePath = " << nodePath << " fileType = " << file_type << " args passed = " << args <<
+            //         " pass = " << theResult << "\n";
+
+            /// Expect KILL and STAT file types to fail, i.e since we have not called those commands
+            if (fileTypesVec[i] == CFileCmd::KILL || fileTypesVec[i] == CFileCmd::STAT) {
+                BOOST_CHECK_MESSAGE(theResult == 1,
+                                    args << " Expected " << CFileCmd::toString(fileTypesVec[i]) << " to fail");
+                continue;
+            }
+
+            if (node->isSubmittable() || fileTypesVec[i] == CFileCmd::MANUAL) {
+                // For suite and families only manual is valid
+                BOOST_CHECK_MESSAGE(theResult == 0,
+                                    args << " failed for Node should return 0.\n"
+                                         << TestFixture::client().errorMsg());
+                BOOST_CHECK_MESSAGE(!TestFixture::client().get_string().empty(), " file contents empty for  " << args);
+            }
+            else {
+                // Should fail
+                BOOST_CHECK_MESSAGE(theResult != 0,
+                                    args << " Expected failure for node " << node->debugNodePath()
+                                         << " with file= " << CFileCmd::toString(fileTypesVec[i]));
+                if (theResult == 0) {
+                    std::cout << "Found file contents:''\n";
+                    std::cout << TestFixture::client().get_string();
+                    std::cout << "''\n";
+                }
+            }
+        }
+    }
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestHandle.cpp 5.13.0-1/libs/test/TestHandle.cpp
--- 5.12.4-1/libs/test/TestHandle.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestHandle.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,418 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <limits> // for std::numeric_limits<int>::max()
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///
+/// \note This is used to INVOKE a SINGLE test.
+/// Making it easier for Easier for debugging and development
+///
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Handle)
+
+BOOST_AUTO_TEST_CASE(test_handle) {
+    DurationTimer timer;
+    cout << "Test:: ...test_handle " << flush;
+    TestClean clean_at_start_and_end;
+
+    Defs theDefs;
+    {
+        for (int s = 0; s < 7; s++) {
+            suite_ptr suite = theDefs.add_suite("s" + ecf::convert_to<std::string>(s));
+            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
+            for (int t = 0; t < 2; t++) {
+                suite->add_task("t" + ecf::convert_to<std::string>(t));
+            }
+        }
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_handle.def"),
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    std::vector<std::string> suites_s0_s1_s2;
+    suites_s0_s1_s2.push_back("s0");
+    suites_s0_s1_s2.push_back("s1");
+    suites_s0_s1_s2.push_back("s2");
+    std::vector<std::string> suites_s3_s4;
+    suites_s3_s4.push_back("s3");
+    suites_s3_s4.push_back("s4");
+    std::vector<std::string> suites_s0_s1_s2_s3_s4;
+    suites_s0_s1_s2_s3_s4.push_back("s0");
+    suites_s0_s1_s2_s3_s4.push_back("s1");
+    suites_s0_s1_s2_s3_s4.push_back("s2"), suites_s0_s1_s2_s3_s4.push_back("s3"), suites_s0_s1_s2_s3_s4.push_back("s4");
+    ;
+    std::vector<std::pair<unsigned int, std::vector<std::string>>> ch_suites;
+
+    {
+        // register suites s0,s1,s2
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
+
+        // get the handle associated with the registered suites
+        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
+
+        // Check the sync_local() does a full sync for our handle
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after registering");
+
+        // Now check the suites were registered, correctly
+        TestFixture::client().ch_suites();
+        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
+        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
+        BOOST_CHECK_MESSAGE(ch_suites.size() == 1, "Expected to have registered a single set");
+        BOOST_CHECK_MESSAGE(ch_suites[0].first == client_handle,
+                            "Expected first client handle to be: " << client_handle << ", but found "
+                                                                   << ch_suites[0].first);
+        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2");
+
+        // Now drop the handle and Check handle was dropped
+        TestFixture::client().ch_drop(client_handle);
+        TestFixture::client().ch_suites();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have no registered suites");
+    }
+
+    {
+        // register suites s0,s1,s2
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
+
+        // get the handle associated with the registered suites
+        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
+        BOOST_CHECK_MESSAGE(client_handle == 1, "Expected to have handle 1");
+
+        // Check the sync_local() does a full sync for our handle. *THIS* should also clear the handle_changed flag
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after registering");
+
+        // add additional suites & check suites were added to our handle. Sync_local should returna full_sync()
+        std::vector<std::string> added_suites;
+        added_suites.push_back("s3");
+        added_suites.push_back("s4");
+        TestFixture::client().ch_add(client_handle, added_suites);
+
+        TestFixture::client().ch_suites();
+        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
+        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
+        BOOST_CHECK_MESSAGE(ch_suites.size() == 1, "Expected to have registered a single set");
+        BOOST_CHECK_MESSAGE(ch_suites[0].first == client_handle,
+                            "Expected first client handle to be: " << client_handle << ", but found "
+                                                                   << ch_suites[0].first);
+        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2_s3_s4, "Expected suites s0,s1,s2,s3,s4");
+
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after adding suites.");
+
+        // remove the added suites, and check they were removed
+        TestFixture::client().ch_remove(client_handle, added_suites);
+
+        TestFixture::client().ch_suites();
+        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
+        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
+        BOOST_CHECK_MESSAGE(ch_suites.size() == 1, "Expected to have registered a single set");
+        BOOST_CHECK_MESSAGE(ch_suites[0].first == client_handle,
+                            "Expected first client handle to be: " << client_handle << ", but found "
+                                                                   << ch_suites[0].first);
+        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2");
+
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after removing suites");
+
+        // Now drop the handle and check handle was dropped
+        TestFixture::client().ch_drop(client_handle);
+        TestFixture::client().ch_suites();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have no registered suites");
+    }
+
+    {
+        // register suites s0,s1,s2
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
+
+        // register suite s3,s4
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s3_s4);
+
+        // get all the registered suites
+        TestFixture::client().ch_suites();
+        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
+        BOOST_CHECK_MESSAGE(!ch_suites.empty(), "Expected to have registered suites");
+        BOOST_CHECK_MESSAGE(ch_suites.size() == 2, "Expected to have 2 registered sets");
+        BOOST_CHECK_MESSAGE(ch_suites[0].first == 1,
+                            "Expected first client handle to be 1, but found " << ch_suites[0].first);
+        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2, in first handle");
+        BOOST_CHECK_MESSAGE(ch_suites[1].first == 2,
+                            "Expected second client handle to be 2, but found " << ch_suites[1].first);
+        BOOST_CHECK_MESSAGE(ch_suites[1].second == suites_s3_s4, "Expected suites s3,s4 , in second handle");
+
+        // Drop all handles
+        for (size_t i = 0; i < ch_suites.size(); i++)
+            TestFixture::client().ch_drop(ch_suites[i].first);
+        TestFixture::client().ch_suites();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have no registered suites");
+    }
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_handle_sync) {
+    DurationTimer timer;
+    cout << "Test:: ...test_handle_sync " << flush;
+    TestClean clean_at_start_and_end;
+
+    Defs theDefs;
+    {
+        for (int s = 0; s < 7; s++) {
+            suite_ptr suite = theDefs.add_suite("s" + ecf::convert_to<std::string>(s));
+            suite->addDefStatus(DState::SUSPENDED);
+            for (int t = 0; t < 2; t++) {
+                suite->add_task("t" + ecf::convert_to<std::string>(t));
+            }
+        }
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_handle_sync.def"),
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    std::vector<std::string> suites_s0_s1_s2;
+    suites_s0_s1_s2.push_back("s0");
+    suites_s0_s1_s2.push_back("s1");
+    suites_s0_s1_s2.push_back("s2");
+    std::vector<std::pair<unsigned int, std::vector<std::string>>> ch_suites;
+
+    {
+        // register suites s0,s1,s2
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
+        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
+        TestFixture::client().news_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after registering");
+        TestFixture::client().sync_local(); // sync for any changes to get full update before test starts
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after registering");
+        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3,
+                            "Expected 3 suites back from sync, after registering 3 suites "
+                                << *TestFixture::client().defs());
+
+        // make a change to a suite not in our handle, that does not cause state propagation.
+        // State propagation changes the defs state. The defs state is sync regardless
+        TestFixture::client().suspend("/s3");
+        TestFixture::client().news_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().get_news(),
+                            "Expected no change since suite s3 is not in our handle");
+
+        // make a change to a suite *not* in our handle, that *does* cause state propagation.
+        TestFixture::client().force("/s3/t0", "aborted");
+        TestFixture::client().news_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(),
+                            "Expected change via state propagation to defs, even though s3 not in our handle");
+
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
+                            "Expected incremental change, not a full update");
+
+        // make a change to a suite in our handle
+        TestFixture::client().force("/s0", "complete");
+        TestFixture::client().news_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news since state changed");
+
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
+                            "Expected incremental change, not a full update");
+
+        TestFixture::client().ch_drop(client_handle);
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have no registered suites");
+    }
+
+    {
+        // register suites s0,s1,s2
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
+        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
+        TestFixture::client().news_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after registering");
+        TestFixture::client().sync_local(); // sync for any changes to get full update before test starts
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after registering");
+
+        // make a small change to a suite *IN* our handle
+        TestFixture::client().force("/s1", "complete");
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
+                            "Expected incremental change, not a full update");
+
+        // Change the order
+        TestFixture::client().order("/s0", "alpha");
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental update");
+
+        TestFixture::client().ch_drop(client_handle);
+        TestFixture::client().suites();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have no registered suites");
+    }
+
+    {
+        // register suites s0,s1,s2
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
+        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
+        TestFixture::client().news_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after registering");
+        TestFixture::client().sync_local(); // sync for any changes to get full update **before** test starts
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after registering");
+
+        // make a small change to a suite *IN* our handle
+        TestFixture::client().force("/s1", "unknown");
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(),
+                            "Expected incremental change, not a full update");
+
+        // DELETE suite s2, i.e make a change that should force a *FULL* update
+        TestFixture::client().delete_node("/s2", true /*force*/);
+        TestFixture::client().news_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().get_news(), "Expected news after deleting node");
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(), "Expected full update");
+
+        // Check that suite s2 is STILL in our handle.
+        // delete suites STAY registered until they are explicitly deleted
+        TestFixture::client().ch_suites();
+        ch_suites = TestFixture::client().server_reply().get_client_handle_suites();
+        BOOST_CHECK_MESSAGE(ch_suites[0].second == suites_s0_s1_s2, "Expected suites s0,s1,s2, in handle");
+
+        TestFixture::client().ch_drop(client_handle);
+        TestFixture::client().ch_suites();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have no registered suites");
+    }
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_handle_add_remove_add) {
+    DurationTimer timer;
+    cout << "Test:: ...test_handle_add_remove_add " << flush;
+    TestClean clean_at_start_and_end;
+
+    defs_ptr theDefs = Defs::create();
+    {
+        for (int s = 0; s < 3; s++) {
+            suite_ptr suite = theDefs->add_suite("s" + ecf::convert_to<std::string>(s));
+            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
+            for (int t = 0; t < 2; t++) {
+                suite->add_task("t" + ecf::convert_to<std::string>(t));
+            }
+        }
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    // ADD
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(*theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_handle_sync.def"),
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    TestFixture::client().set_throw_on_error(true);
+    std::vector<std::string> suites_s0_s1_s2;
+    suites_s0_s1_s2.push_back("s0");
+    suites_s0_s1_s2.push_back("s1");
+    suites_s0_s1_s2.push_back("s2");
+
+    {
+        // register suites s0
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_s0_s1_s2);
+        unsigned int client_handle = TestFixture::client().server_reply().client_handle();
+        BOOST_CHECK_MESSAGE(client_handle == 1, "Expected handle of value 1 but found " << client_handle);
+
+        // Get the registered suites
+        TestFixture::client().ch_suites();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have registered suites");
+
+        // Check the sync_local() does a full sync for our handle
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after registering");
+        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3,
+                            "Expected 3 suites back from sync " << *TestFixture::client().defs());
+
+        // DELETE suites. They should stay *registered*
+        TestFixture::client().delete_node("/s0");
+        TestFixture::client().delete_node("/s1");
+        TestFixture::client().delete_node("/s2");
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after deleting suite");
+        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 0,
+                            "Expected 0 suites back from sync " << *TestFixture::client().defs());
+
+        // Check suites are still registered. Only explicit drop can remove registered suites
+        TestFixture::client().ch_suites();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have registered suites");
+
+        // RELOAD the defs, which includes s0,s1,s2:: THIS SHOULD GET RE_ADDED TO OUR EXISTING HANDLE's
+        // The handle references to the suites should get *refreshed*
+        TestFixture::client().load(theDefs);
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() since client handle should be refreshed with new suite_pts");
+        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3,
+                            "Expected 3 suites back from sync " << *TestFixture::client().defs());
+
+        TestFixture::client().ch_drop(client_handle);
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().get_client_handle_suites().empty(),
+                            "Expected to have no registered suites");
+    }
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestInitAddVariable.cpp 5.13.0-1/libs/test/TestInitAddVariable.cpp
--- 5.12.4-1/libs/test/TestInitAddVariable.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestInitAddVariable.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,106 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_InitAddVariable)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+BOOST_AUTO_TEST_CASE(test_init_add_variable) {
+    // Added since in 5.2.0 (only 5.2.0 server supports this behaviour)
+    if (getenv("ECF_DISABLE_TEST_FOR_OLD_SERVERS")) {
+        std::cout << "\n    Disable test_init_add_variable for old server , re-enable when 5.2.0 is minimum version\n";
+        return;
+    }
+
+    DurationTimer timer;
+    cout << "Test:: ...test_init_add_variable " << flush;
+    TestClean clean_at_start_and_end;
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_server_job_submission
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   edit INIT_ADD_VARIABLES --add "NAME1=1" "NAME2=2"
+    //   edit COMPLETE_DEL_VARIABLES --remove NAME1 NAME2
+    //   family family
+    //     task t1     # can't place trigger on t1, otherwise we have dead lock. Variables added at ACTIVE, but trigger
+    //     expression resolved at QUEUE time task t2
+    //       trigger t1:NAME1 == 1 and t1:NAME2 == 2
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_init_add_variable");
+        suite->add_variable("INIT_ADD_VARIABLES", "--add NAME1=1 NAME2=2");
+        suite->add_variable("COMPLETE_DEL_VARIABLES", "--remove NAME1 NAME2");
+        family_ptr fam = suite->add_family("family");
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        task_ptr t1 = fam->add_task("t1");
+        t1->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        t1->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval()));
+
+        task_ptr t2 = fam->add_task("t2");
+        t2->add_trigger("t1 == active and ./t1:NAME1 == 1 and ./t1:NAME2 == 2");
+        t2->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        theDefs.auto_add_externs(); // since NAME1 and NAME2 not defined
+    }
+    // cout << theDefs;
+
+    // The test harness will create corresponding directory structure and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_init_add_variable.def"));
+
+    TestFixture::client().sync_local();
+    BOOST_CHECK_MESSAGE(TestFixture::client().defs(), "Expected defs");
+
+    {
+        node_ptr t1 = TestFixture::client().defs()->findAbsNode("/test_init_add_variable/family/t1");
+        BOOST_CHECK_MESSAGE(t1, "Expected task to be found");
+        const Variable& v1 = t1->findVariable("NAME1");
+        const Variable& v2 = t1->findVariable("NAME2");
+        BOOST_CHECK_MESSAGE(v1.empty() && v2.empty(), "Expected not to find variables NAME1 and NAME2");
+    }
+    {
+        node_ptr t2 = TestFixture::client().defs()->findAbsNode("/test_init_add_variable/family/t2");
+        BOOST_CHECK_MESSAGE(t2, "Expected task to be found");
+        const Variable& v1 = t2->findVariable("NAME1");
+        const Variable& v2 = t2->findVariable("NAME2");
+        BOOST_CHECK_MESSAGE(v1.empty() && v2.empty(), "Expected not to find variables NAME1 and NAME2");
+    }
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestKillCmd.cpp 5.13.0-1/libs/test/TestKillCmd.cpp
--- 5.12.4-1/libs/test/TestKillCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestKillCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,149 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///
+/// \note This is used to INVOKE a SINGLE test. Easier for debugging
+///
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_KillCmd)
+
+// forward declare functions
+static bool kill_cmd(bool kill_task);
+static bool waitForTaskState(NState::State state, int max_time_to_wait);
+
+// test:: test the kill command. Create a task that runs a long time
+// The associated job is then killed. This should leave task in aborted state
+BOOST_AUTO_TEST_CASE(test_kill_cmd) {
+    DurationTimer timer;
+    cout << "Test:: ...test_kill_cmd " << flush;
+    TestClean clean_at_start_and_end;
+    BOOST_REQUIRE_MESSAGE(kill_cmd(true), " kill of task '/test_kill_cmd/family/t0' failed");
+    cout << timer.duration() << "\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_hierarchical_kill_cmd) {
+    DurationTimer timer;
+    cout << "Test:: ...test_hierarchical_kill_cmd " << flush;
+    TestClean clean_at_start_and_end;
+    BOOST_REQUIRE_MESSAGE(kill_cmd(false), "kill of suite '/test_kill_cmd' failed");
+    cout << timer.duration() << "\n";
+}
+
+static bool kill_cmd(bool kill_task) {
+    /// Create dir location for log file.
+    std::string defs_location = ServerTestHarness::testDataDefsLocation("test_kill_cmd.def");
+    fs::path new_path         = defs_location;
+    if (!fs::exists(new_path.parent_path())) {
+        File::createMissingDirectories(new_path.parent_path().string());
+    }
+
+    Defs theDefs;
+    std::string kill_path;
+    {
+        suite_ptr suite;
+        if (kill_task)
+            suite = theDefs.add_suite("test_kill_task");
+        else
+            suite = theDefs.add_suite("test_kill_suite");
+        suite->addVariable(Variable("ECF_TRIES", "1")); // do not try again
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t0");
+        task->addMeter(Meter("meter", 0, 200, 100)); // Make sure it run long enough, to receive kill, on slow systems
+        task->addVerify(VerifyAttr(NState::ABORTED, 1)); // task should abort 1 times
+        if (kill_task)
+            kill_path = task->absNodePath();
+        else
+            kill_path = suite->absNodePath();
+    }
+
+    // *******************************************************************
+    // Important: The following will *not* work:
+    //    theDefs.set_server().add_or_update_variables("ECF_TRIES","1");                     // Override ECF_TRIES so
+    //    don't try to restart aborted jobs theDefs.set_server().add_or_update_variables("ECF_KILL_CMD","kill -15
+    //    %ECF_RID%"); // Provide a mechanism to kill the running job
+    // Since calling the begin command in the server,
+    // will update the defs with the server environment, and hence overriding
+    // any env variable of the same name, set here. Hence just use addVariable as above.
+    // *************************************************************************
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, defs_location, 1 /*timeout*/, false /* don't wait for test to finish */);
+
+    // cout << "test_kill_cmd Waiting for task to become active\n";
+    TestFixture::client().set_throw_on_error(false);
+    (void)waitForTaskState(NState::ACTIVE, 10);
+
+    // cout << "test_kill_cmd Now kill the active jobs\n";
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().kill(kill_path) == 0,
+                          CtsApi::to_string(CtsApi::kill(kill_path)) << " failed should return 0.\n"
+                                                                     << TestFixture::client().errorMsg());
+
+    // cout << "test_kill_cmd Wait for the task to be aborted\n";
+    return waitForTaskState(NState::ABORTED, 20);
+}
+
+static bool waitForTaskState(NState::State state, int max_time_to_wait) {
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        vector<Task*> tasks;
+        defs->getAllTasks(tasks);
+        for (Task* task : tasks) {
+            if (task->state() == state) {
+                return true;
+            }
+        }
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                                  "waitForTaskState "
+                                      << NState::toString(state) << " Test wait " << assertTimer.duration()
+                                      << " taking longer than time constraint of " << assertTimer.timeConstraint()
+                                      << " aborting\n"
+                                      << *defs);
+            break;
+        }
+        sleep(2);
+    }
+    return false;
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestLate.cpp 5.13.0-1/libs/test/TestLate.cpp
--- 5.12.4-1/libs/test/TestLate.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestLate.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,132 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <limits> // for std::numeric_limits<int>::max()
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/LateAttr.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Late)
+
+BOOST_AUTO_TEST_CASE(test_late) {
+    DurationTimer timer;
+    cout << "Test:: ...test_late " << flush;
+    TestClean clean_at_start_and_end;
+
+    /// This test will sleep longer than the job submission interval
+    /// which cause the task to be late
+    /// as the active time has been set for 1 minute.
+    /// The check for lateness is ONLY done are server poll time.
+    /// Hence the task run time must be at least twice the poll time.
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_late");
+        suite->add_variable(
+            "SLEEPTIME",
+            ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2)); // this will cause the late
+
+        task_ptr task = suite->add_task("t1");
+        ecf::LateAttr lateAttr;
+        lateAttr.addComplete(ecf::TimeSlot(0, 1), true);
+
+        task->addLate(lateAttr);
+
+        suite->add_task("t2")->add_trigger(task->absNodePath() + "<flag>late");
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_late.def"));
+
+    TestFixture::client().set_throw_on_error(true);
+    TestFixture::client().sync_local();
+    BOOST_CHECK_MESSAGE(TestFixture::client().defs(), "Expected defs");
+
+    node_ptr node = TestFixture::client().defs()->findAbsNode("/test_late/t1");
+    BOOST_REQUIRE_MESSAGE(node, "Expected task to be found");
+
+    ecf::LateAttr* late = node->get_late();
+    BOOST_CHECK_MESSAGE(late->isLate(), "Expected late to be set");
+    BOOST_CHECK_MESSAGE(node->flag().is_set(ecf::Flag::LATE), "Expected late flag to be set");
+
+    node_ptr t2 = TestFixture::client().defs()->findAbsNode("/test_late/t2");
+    BOOST_REQUIRE_MESSAGE(t2, "Expected task to be found");
+    BOOST_CHECK_MESSAGE(t2->state() == NState::COMPLETE, "Expected late trigger to work");
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_late_hierarchically) {
+    // ECFLOW-610
+    DurationTimer timer;
+    cout << "Test:: ...test_late_hierarchically " << flush;
+    TestClean clean_at_start_and_end;
+
+    /// This test will sleep longer than the job submission interval
+    /// which cause the task to be late
+    /// as the active time has been set for 1 minute.
+    /// The check for lateness is ONLY done are server poll time.
+    /// Hence the task run time must be at least twice the poll time.
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_late_hierarchically");
+        suite->add_variable(
+            "SLEEPTIME",
+            ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2)); // this will cause the late
+        ecf::LateAttr lateAttr;
+        lateAttr.addComplete(ecf::TimeSlot(0, 1), true);
+        suite->addLate(lateAttr);
+
+        family_ptr fam = suite->add_family("f1");
+        fam->add_task("t1");
+        fam->add_task("t2");
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_late_hierarchically.def"));
+
+    TestFixture::client().set_throw_on_error(true);
+    TestFixture::client().sync_local();
+    BOOST_CHECK_MESSAGE(TestFixture::client().defs(), "Expected defs");
+
+    node_ptr t1 = TestFixture::client().defs()->findAbsNode("/test_late_hierarchically/f1/t1");
+    BOOST_CHECK_MESSAGE(t1, "Expected task to be found");
+    BOOST_CHECK_MESSAGE(t1->flag().is_set(ecf::Flag::LATE), "Expected late flag to be set");
+
+    node_ptr t2 = TestFixture::client().defs()->findAbsNode("/test_late_hierarchically/f1/t2");
+    BOOST_CHECK_MESSAGE(t2, "Expected task to be found");
+    BOOST_CHECK_MESSAGE(t2->flag().is_set(ecf::Flag::LATE), "Expected late flag to be set");
+
+    // cout << TestFixture::client().defs() << "\n";
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestLimit.cpp 5.13.0-1/libs/test/TestLimit.cpp
--- 5.12.4-1/libs/test/TestLimit.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestLimit.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,113 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Limit)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+BOOST_AUTO_TEST_CASE(test_limit) {
+    DurationTimer timer;
+    cout << "Test:: ...test_limit " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Test the ecf file can be found via ECF_SCRIPT
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // Create the defs file
+    // suite test_limit
+    //   limit disk 50
+    //   limit fast 1
+    //   edit ECF_HOME data/ECF_HOME    # added by test harness
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     inlimit /suite1:fast
+    //     task t1
+    //     task t2
+    //     task t3
+    //   endfamily
+    //   family family2
+    //     inlimit /suite1:disk 20
+    //     task t1
+    //     task t2
+    //     task t3
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        std::string suiteName   = "test_limit";
+        std::string pathToLimit = "/" + suiteName;
+
+        suite_ptr suite = theDefs.add_suite(suiteName);
+        suite->addLimit(Limit("fast", 1));
+        suite->addLimit(Limit("disk", 50));
+
+        family_ptr fam = suite->add_family("family");
+        fam->addInLimit(InLimit("fast", pathToLimit));
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        int taskSize = 3;
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+
+        family_ptr fam2 = suite->add_family("family2");
+        fam2->addInLimit(InLimit("disk", pathToLimit, 20));
+        fam2->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam2->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_limit.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestOrderCmd.cpp 5.13.0-1/libs/test/TestOrderCmd.cpp
--- 5.12.4-1/libs/test/TestOrderCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestOrderCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,252 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <limits> // for std::numeric_limits<int>::max()
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///
+/// \note This is used to INVOKE a SINGLE test.
+/// Making it easier for Easier for debugging and development
+///
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_OrderCmd)
+
+std::vector<std::string> to_string_vec(const std::vector<suite_ptr>& sv) {
+    std::vector<std::string> r;
+    r.reserve(sv.size());
+    for (size_t i = 0; i < sv.size(); i++)
+        r.push_back(sv[i]->name());
+    return r;
+}
+
+std::vector<std::string> to_string_vec(const std::vector<node_ptr>& sv) {
+    std::vector<std::string> r;
+    r.reserve(sv.size());
+    for (size_t i = 0; i < sv.size(); i++)
+        r.push_back(sv[i]->name());
+    return r;
+}
+
+void test_ordering() {
+
+    TestFixture::client().set_throw_on_error(true);
+    std::vector<std::string> str_a_b_c;
+    str_a_b_c.push_back("a");
+    str_a_b_c.push_back("b");
+    str_a_b_c.push_back("c");
+    std::vector<std::string> str_c_b_a;
+    str_c_b_a.push_back("c");
+    str_c_b_a.push_back("b");
+    str_c_b_a.push_back("a");
+    std::vector<std::string> str_b_c_a;
+    str_b_c_a.push_back("b");
+    str_b_c_a.push_back("c");
+    str_b_c_a.push_back("a");
+    std::vector<std::string> str_b_a_c;
+    str_b_a_c.push_back("b");
+    str_b_a_c.push_back("a");
+    str_b_a_c.push_back("c");
+    std::vector<std::string> str_a_c_b;
+    str_a_c_b.push_back("a");
+    str_a_c_b.push_back("c");
+    str_a_c_b.push_back("b");
+    TestFixture::client().sync_local(); // First sync_local will do a full sync
+    {
+        // TEST SUITE ORDERING
+        TestFixture::client().order("/a", NOrder::toString(NOrder::ORDER));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_c_b_a,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a", NOrder::toString(NOrder::ALPHA));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_a_b_c,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a", NOrder::toString(NOrder::BOTTOM));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_b_c_a,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a", NOrder::toString(NOrder::ALPHA));
+        TestFixture::client().order("/a", NOrder::toString(NOrder::DOWN));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_b_a_c,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a", NOrder::toString(NOrder::ALPHA));
+        TestFixture::client().order("/c", NOrder::toString(NOrder::UP));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()) == str_a_c_b,
+                            "Order not as expected");
+    }
+    {
+        // TEST FAMILY ordering
+        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ORDER));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_c_b_a,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ALPHA));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_a_b_c,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a/a", NOrder::toString(NOrder::BOTTOM));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_b_c_a,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ALPHA));
+        TestFixture::client().order("/a/a", NOrder::toString(NOrder::DOWN));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_b_a_c,
+                            "Order not as expected");
+
+        TestFixture::client().order("/a/a", NOrder::toString(NOrder::ALPHA));
+        TestFixture::client().order("/a/c", NOrder::toString(NOrder::UP));
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(!TestFixture::client().server_reply().full_sync(), "Expected incremental sync");
+        BOOST_CHECK_MESSAGE(to_string_vec(TestFixture::client().defs()->suiteVec()[0]->nodeVec()) == str_a_c_b,
+                            "Order not as expected");
+    }
+}
+
+BOOST_AUTO_TEST_CASE(test_change_order) {
+    DurationTimer timer;
+    cout << "Test:: ...test_change_order " << flush;
+    TestClean clean_at_start_and_end;
+
+    /// NOT: We *DONT* need to run the jobs for this TEST
+    std::vector<std::string> str_a_b_c;
+    str_a_b_c.push_back("a");
+    str_a_b_c.push_back("b");
+    str_a_b_c.push_back("c");
+    Defs theDefs;
+    {
+        for (size_t s = 0; s < str_a_b_c.size(); s++) {
+            suite_ptr suite = theDefs.add_suite(str_a_b_c[s]);
+            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
+            for (size_t f = 0; f < str_a_b_c.size(); f++) {
+                family_ptr fam = suite->add_family(str_a_b_c[f]);
+                for (size_t t = 0; t < str_a_b_c.size(); t++) {
+                    fam->add_task(str_a_b_c[t]);
+                }
+            }
+        }
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_change_order.def"),
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    test_ordering();
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_handle_change_order) {
+    DurationTimer timer;
+    cout << "Test:: ...test_handle_change_order " << flush;
+    TestClean clean_at_start_and_end;
+
+    std::vector<std::string> str_a_b_c;
+    str_a_b_c.push_back("a");
+    str_a_b_c.push_back("b");
+    str_a_b_c.push_back("c");
+    std::vector<std::string> suite_a_b_c_d_e;
+    suite_a_b_c_d_e.push_back("a");
+    suite_a_b_c_d_e.push_back("b");
+    suite_a_b_c_d_e.push_back("c");
+    suite_a_b_c_d_e.push_back("d");
+    suite_a_b_c_d_e.push_back("e");
+    Defs theDefs;
+    {
+        for (size_t s = 0; s < suite_a_b_c_d_e.size(); s++) {
+            suite_ptr suite = theDefs.add_suite(suite_a_b_c_d_e[s]);
+            suite->addDefStatus(DState::SUSPENDED); // NO NEED to run jobs for this test:
+            for (size_t f = 0; f < str_a_b_c.size(); f++) {
+                family_ptr fam = suite->add_family(str_a_b_c[f]);
+                for (size_t t = 0; t < str_a_b_c.size(); t++) {
+                    fam->add_task(str_a_b_c[t]);
+                }
+            }
+        }
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_change_order.def"),
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    TestFixture::client().set_throw_on_error(true);
+    TestFixture::client().sync_local(); // First sync_local will do a full sync
+    {
+        // register suites a,b,c
+        std::vector<std::string> suites_a_b_c;
+        suites_a_b_c.push_back("a");
+        suites_a_b_c.push_back("b");
+        suites_a_b_c.push_back("c");
+        TestFixture::client().ch_register(false /*add new suites to handle*/, suites_a_b_c);
+
+        // Check the sync_local() does a full sync for our handle
+        TestFixture::client().sync_local();
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().in_sync(), "Expected to be in sync after syn_local()");
+        BOOST_CHECK_MESSAGE(TestFixture::client().server_reply().full_sync(),
+                            "Expected a full_sync() after registering");
+        BOOST_CHECK_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 3, "Expected sync to return 3 suites.");
+    }
+
+    // Do same test, this time sync_local will only return suite a,b,c (i.e suite d,e not registered and hence left out)
+    // Ording should still be applied to the whole suite.
+    test_ordering();
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestQueueCmd.cpp 5.13.0-1/libs/test/TestQueueCmd.cpp
--- 5.12.4-1/libs/test/TestQueueCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestQueueCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,102 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_QueueCmd)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+
+BOOST_AUTO_TEST_CASE(test_queue) {
+    DurationTimer timer;
+    cout << "Test:: ...test_queue " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_queue
+    //   family f1
+    //     queue q1 1 2 3
+    //     task t
+    //   endfamily
+    //   family f2
+    //     task a
+    //       queue q2 1 2 3
+    //     task b
+    //       trigger /test_queue/f1:q1 > 1
+    //     task c
+    //       trigger /test_queue/f2/a:q2 > 1
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        std::vector<std::string> queue_items;
+        queue_items.emplace_back("1");
+        queue_items.emplace_back("2");
+        queue_items.emplace_back("3");
+        suite_ptr suite = theDefs.add_suite("test_queue");
+        {
+            family_ptr f1 = suite->add_family("f1");
+            QueueAttr q1("q1", queue_items);
+            f1->add_queue(q1);
+            f1->add_task("t")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+            family_ptr f2 = suite->add_family("f2");
+            task_ptr a    = f2->add_task("a");
+            QueueAttr q2("q2", queue_items);
+            a->add_queue(q2);
+
+            task_ptr b = f2->add_task("b");
+            b->add_trigger("/test_queue/f1:q1 > 1");
+            b->addVerify(VerifyAttr(NState::COMPLETE, 1));
+            task_ptr c = f2->add_task("c");
+            c->add_trigger("/test_queue/f2/a:q2 > 1");
+            c->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+        // cout << theDefs;
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_queue.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestRepeat.cpp 5.13.0-1/libs/test/TestRepeat.cpp
--- 5.12.4-1/libs/test/TestRepeat.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestRepeat.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,359 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/base/WhyCmd.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Repeat)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+BOOST_AUTO_TEST_CASE(test_repeat_integer) {
+    DurationTimer timer;
+    cout << "Test:: ...test_repeat_integer " << flush;
+    TestClean clean_at_start_and_end;
+
+    // ********************************************************************************
+    // IMPORTANT: A family will only complete when it has reached the end of the repeats
+    // *********************************************************************************
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_repeat_integer
+    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     repeat integer VAR 0 2 1     # run at 0, 1     2 times
+    //     task t<n>
+    //     ....
+    //   endfamily
+    // endsuite
+
+    // Each task/job should be run *4* times, according to the repeats
+    // Mimics nested loops
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_repeat_integer");
+        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat suite 2 times,
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat family 2 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 4));
+        int taskSize = 2; // on linux 1024 tasks take ~4 seconds for job submission
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // task should complete 4 times
+        }
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_integer.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date) {
+    DurationTimer timer;
+    cout << "Test:: ...test_repeat_date " << flush;
+    TestClean clean_at_start_and_end;
+
+    // ********************************************************************************
+    // IMPORTANT: A family will only complete when it has reached the end of the repeats
+    // *********************************************************************************
+    // suite test_repeat_date
+    // family family
+    //   repeat date DATE 20110630 20110632
+    //   task t<n>
+    //      ....
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_repeat_date");
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatDate("DATE", 20110630, 20110704));
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 5));
+        int taskSize = 2;
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 5));
+        }
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_date.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_date_list) {
+    DurationTimer timer;
+    cout << "Test:: ...test_repeat_date_list " << flush;
+    TestClean clean_at_start_and_end;
+
+    // ********************************************************************************
+    // IMPORTANT: A family will only complete when it has reached the end of the repeats
+    // *********************************************************************************
+    // suite test_repeat_date
+    // family family
+    //   repeat datelist DATE 20110630 20110632
+    //   task t<n>
+    //   ....
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_repeat_date_list");
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatDateList("DATE", {20110630, 20110704}));
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 2));
+        int taskSize = 2;
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 2));
+        }
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_date.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_enumerator) {
+    DurationTimer timer;
+    cout << "Test:: ...test_repeat_enumerator " << flush;
+    TestClean clean_at_start_and_end;
+
+    // ********************************************************************************
+    // IMPORTANT: A family will only complete when it has reached the end of the repeats
+    // *********************************************************************************
+    // suite test_repeat_enumerator
+    //   family top
+    //     family plot
+    //       family iasi_plots
+    //         repeat enumerated month "200801" "200802"
+    //         task t1
+    //       endfamily
+    //     endfamily
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        suite_ptr suite       = theDefs.add_suite("test_repeat_enumerator");
+        family_ptr top        = suite->add_family("top");
+        family_ptr plot       = top->add_family("plot");
+        family_ptr iasi_plots = plot->add_family("iasi_plots");
+        vector<string> months;
+        months.reserve(12);
+        months.push_back("200801");
+        months.push_back("200802");
+        iasi_plots->addRepeat(RepeatEnumerated("month", months));
+        task_ptr t1 = iasi_plots->add_task("t1");
+        t1->addVerify(VerifyAttr(NState::COMPLETE, 2));
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_enumerator.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_repeat_defstatus) {
+    DurationTimer timer;
+    cout << "Test:: ...test_repeat_defstatus " << flush;
+    TestClean clean_at_start_and_end;
+
+    // TEST SHOULD COMPLETE STRAIGHT AWAY SINCE WE HAVE A DEFSTATUS COMPLETE
+    // since the complete state is set on all children of suite.
+
+    // Create the defs file corresponding to the text below
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_repeat_defstatus
+    //   defstatus complete
+    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     repeat integer VAR 0 2 1     # run at 0, 1     2 times
+    //     task t<n>
+    //     ....
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_repeat_defstatus");
+        suite->addDefStatus(DState::COMPLETE);
+        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1));
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1));
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        int taskSize = 2; // on linux 1024 tasks take ~4 seconds for job submission
+        for (int i = 0; i < taskSize; i++) {
+
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_repeat_defstatus.def"));
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+// #define DEBUG_ME 1
+BOOST_AUTO_TEST_CASE(test_repeat_clears_user_edit) {
+    // Tests code:: Node::requeueOrSetMostSignificantStateUpNodeTree()
+    // In *PARTICULAR* THE REQUE caused by the repeat, this ensures we clear NO_REQUE_IF_SINGLE_TIME_DEP
+    // So that the effect of manual run/force complete are negated via automated re-queue caused by a REPEAT
+
+    DurationTimer timer;
+    cout << "Test:: ...test_repeat_clears_user_edit " << flush;
+    TestClean clean_at_start_and_end;
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_repeat_clears_user_edit
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     repeat integer VAR 0 3     # run at 0,1,2    i.e 3 times
+    //     task t<n>
+    //       time <current time>
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    task_ptr task;
+    {
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+        boost::posix_time::ptime time1        = theLocalTime + minutes(3);
+
+        suite_ptr suite = theDefs.add_suite("test_repeat_clears_user_edit");
+        ClockAttr clockAttr(theLocalTime, false);
+        suite->addClock(clockAttr);
+
+        suite->addDefStatus(DState::SUSPENDED);
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatInteger("VAR", 0, 2, 1)); // repeat family 3 times
+        task = fam->add_task("t1");
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3));
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_repeat_integer.def"),
+                          40,
+                          false /* waitFortestcompletion */);
+
+#ifdef DEBUG_ME
+    PrintStyle style(PrintStyle::STATE);
+    TestFixture::client().sync_local();
+    defs_ptr server_defs = TestFixture::client().defs();
+    cout << "At start ============================================\n";
+    cout << server_defs << "\n";
+#endif
+
+    // USER EDIT, on task with a time. The force complete will expire the time.
+    // Forcing a task with the time attribute, to complete state, should invalidate/expire the time,
+    // Hence it should hold indefinitely, or until it is re-queued manually, or automatically via a Repeat/cron.
+    // This Test ensures the the *REQUEUE* via the repeat, resets the time based attribute
+    TestFixture::client().force(task->absNodePath(), "complete", true);
+    TestFixture::client().force(task->absNodePath(), "complete", true);
+
+#ifdef DEBUG_ME
+    TestFixture::client().sync_local();
+    server_defs = TestFixture::client().defs();
+    cout << "After 2 force complete ============================================\n";
+    cout << server_defs << "\n";
+
+    node_ptr the_task = server_defs->findAbsNode(task->absNodePath());
+    BOOST_REQUIRE_MESSAGE(the_task, "Task " << task->absNodePath() << " not found");
+    WhyCmd whyCmd(server_defs, the_task->absNodePath());
+    std::string reason = whyCmd.why();
+    cout << "Why command ============================================\n";
+    std::cout << reason << "\n\n";
+#endif
+
+    // resume the suspend suite
+    TestFixture::client().resume("/test_repeat_clears_user_edit");
+
+#ifdef DEBUG_ME
+    TestFixture::client().sync_local();
+    server_defs = TestFixture::client().defs();
+    cout << "At Resume ============================================\n";
+    cout << server_defs << "\n";
+#endif
+
+    // Wait for final LOOP of the repeat, and test to finish
+    int timeout             = 20;
+    bool verifyAttrInServer = true;
+    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
+    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return defs after wait of 20 seconds");
+
+#ifdef DEBUG_ME
+    cout << "At test finish ============================================\n";
+    cout << serverDefs << "\n";
+#endif
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestRequeueNode.cpp 5.13.0-1/libs/test/TestRequeueNode.cpp
--- 5.12.4-1/libs/test/TestRequeueNode.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestRequeueNode.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,113 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_RequeueNode)
+
+BOOST_AUTO_TEST_CASE(test_requeue_node) {
+    DurationTimer timer;
+    cout << "Test:: ...test_requeue_node " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_repeat_integer
+    //   repeat integer VAR 0 1 1          # run at 0, 1    2 times
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     repeat integer VAR 0 2 1     # run at 0, 1     2 times
+    //     task t<n>
+    //     ....
+    //   endfamily
+    // endsuite
+
+    // Each task/job should be run *4* times, according to the repeats Mimics nested loops
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_requeue_node");
+        suite->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat suite 2 times
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 2));
+        family_ptr fam = suite->add_family("family");
+        fam->addRepeat(RepeatInteger("VAR", 0, 1, 1)); // repeat family 2 times
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 4));
+        int taskSize = 2; // on linux 1024 tasks take ~4 seconds for job submission
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 4)); // task should complete 4 times
+        }
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_requeue_node.def"));
+
+    // Now re-queue the whole suite
+    TestFixture::client().set_throw_on_error(true);
+    TestFixture::client().requeue("/test_requeue_node");
+
+    // Wait for test to finish
+    int timeout             = 30;
+    bool verifyAttrInServer = false;
+    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
+    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return server after re-queue");
+
+    // cout << "Printing Defs \n";
+    // std::cout << *serverDefs.get();
+
+    // since we requeue, each task should have completed 8 times
+    std::vector<Task*> taskVec;
+    serverDefs->getAllTasks(taskVec);
+    for (Task* t : taskVec) {
+        for (const VerifyAttr& v : t->verifys()) {
+            if (v.state() == NState::COMPLETE) {
+                BOOST_CHECK_MESSAGE(v.actual() == 8,
+                                    "Expected task " << t->absNodePath()
+                                                     << " to complete 8 times, due to reque, but it completed only "
+                                                     << v.actual() << " times\n");
+            }
+        }
+    }
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestServer.cpp 5.13.0-1/libs/test/TestServer.cpp
--- 5.12.4-1/libs/test/TestServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,155 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Server)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+BOOST_AUTO_TEST_CASE(test_server_job_submission) {
+    DurationTimer timer;
+    cout << "Test:: ...test_server_job_submission " << flush;
+    TestClean clean_at_start_and_end;
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_server_job_submission
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     task t<n>
+    //     ....
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_server_job_submission");
+        family_ptr fam  = suite->add_family("family");
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        int taskSize = 3; // on linux 1024 tasks take ~4 seconds for job submission
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+    }
+
+    // The test harness will create corresponding directory structure and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_server_job_submission.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_restore_defs_from_check_pt) {
+    DurationTimer timer;
+    cout << "Test:: ...test_restore_defs_from_check_pt " << flush;
+    TestClean clean_at_start_and_end;
+    // **********************************************************************
+    // In order for this test to work, we need to disable the automatic
+    // check pointing done by the server. Otherwise it will interfere with
+    // this test. This is re-enabled at the end of the test
+    // ************************************************************************
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_restore_defs_from_check_pt");
+        suite->addTask(Task::create("t1"));
+        theDefs.addSuite(suite);
+    }
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_restore_defs_from_check_pt.def"));
+
+    TestFixture::client().set_throw_on_error(false);
+
+    // Disable server check pointing
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().checkPtDefs(ecf::CheckPt::NEVER) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::NEVER) << " failed should return 0\n"
+                                                                   << TestFixture::client().errorMsg());
+
+    Host h;
+    std::string check_pt_file_name = h.ecf_checkpt_file(TestFixture::port());
+
+    // make sure we have a valid definition with at least one suite before start
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0, "Expected getDefs() to succeed\n");
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 1, "Expected 1 suite at the start\n");
+
+    // Check pt, make sure file exist on disk and has a non zero file size\n";
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().checkPtDefs() == 0,
+                          "Expected Check-pt to succeed.\n"
+                              << TestFixture::client().errorMsg());
+    BOOST_REQUIRE_MESSAGE(fs::exists(check_pt_file_name),
+                          CtsApi::checkPtDefs() << " failed file(" << check_pt_file_name << ") not saved");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(check_pt_file_name) != 0,
+                          "Expected check point file(" << check_pt_file_name << ") to have file size > 0");
+
+    // Make sure restore from check pt, only works if server is halted and there are no suites\n";
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().restoreDefsFromCheckPt() == 1,
+                          "Expected restoreDefsFromCheckPt to *FAIL* since server not halted\n");
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().haltServer() == 0,
+                          "Expected halt server to succeed\n"
+                              << TestFixture::client().errorMsg());
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().restoreDefsFromCheckPt() == 1,
+                          "Expected restoreDefsFromCheckPt to *FAIL* since definition not deleted yet\n");
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_all() == 0,
+                          "Expected delete all nodes to succeed\n"
+                              << TestFixture::client().errorMsg());
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
+                          "Expected getDefs() to succeed, i.e expected empty defs\n");
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().defs()->suiteVec().empty(), "Expected no suites, after delete_all()\n");
+
+    // make sure check pt file still exists, sanity test\n";
+    BOOST_REQUIRE_MESSAGE(fs::exists(check_pt_file_name),
+                          CtsApi::checkPtDefs() << " failed file(" << check_pt_file_name << ") not saved");
+    BOOST_REQUIRE_MESSAGE(fs::file_size(check_pt_file_name) != 0,
+                          "Expected check point file(" << check_pt_file_name << ") to have file size > 0");
+
+    // make sure restore actually worked, by retrieving the definition and counting the suites\n";
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().restoreDefsFromCheckPt() == 0,
+                          "Expected restoreDefsFromCheckPt to *SUCCEED*, since server halted and defs deleted \n"
+                              << TestFixture::client().errorMsg());
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
+                          "Get defs failed should return 0\n"
+                              << TestFixture::client().errorMsg());
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().defs()->suiteVec().size() == 1,
+                          "Restore from check pt did not work. expected 1 suite but found "
+                              << TestFixture::client().defs()->suiteVec().size());
+
+    // restore default check pointing, for test that follow
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().checkPtDefs(ecf::CheckPt::ON_TIME, 120) == 0,
+                          CtsApi::checkPtDefs(ecf::CheckPt::ON_TIME) << " failed should return 0\n"
+                                                                     << TestFixture::client().errorMsg());
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestSingle.cpp 5.13.0-1/libs/test/TestSingle.cpp
--- 5.12.4-1/libs/test/TestSingle.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestSingle.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,260 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <limits> // for std::numeric_limits<int>::max()
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///
+/// \note This is used to INVOKE a SINGLE test.
+/// Making it easier for Easier for debugging and development
+///
+
+BOOST_AUTO_TEST_SUITE(TestSingleSuite)
+
+BOOST_AUTO_TEST_CASE(test_stress) {
+    // at 4000 : limit reached os cannot create more than 3946 process
+    //   Job creation failed for task /test_stress/family/t3996 could not create child process
+    int no_of_tasks_to_run                       = 250;
+    int run_test_for_n_seconds                   = 240;
+    int max_time_for_suspended_suite_to_complete = 60;
+
+    DurationTimer timer;
+    std::string test_name      = "test_stress";
+    std::string test_name_path = "/" + test_name;
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite(test_name);
+        family_ptr fam  = suite->add_family("family");
+        for (int i = 0; i < no_of_tasks_to_run; i++) {
+            task_ptr t = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            t->addRepeat(RepeatDay(1));
+            t->addEvent(Event("event"));
+            t->addLabel(Label("name", "value"));
+            t->addMeter(Meter("meter", 0, 10));
+        }
+    }
+
+    // BOOST_REQUIRE_MESSAGE(TestFixture::job_submission_interval()==60,"Job submission interval not set correctly
+    // expected 60 but found " << TestFixture::job_submission_interval());
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation(test_name + ".def"),
+                          120 /*timeout ignored*/,
+                          false /*don't wait for test completion */);
+
+    cout << "Timing test for " << run_test_for_n_seconds << "... seconds  no_of_tasks_to_run " << no_of_tasks_to_run
+         << endl;
+
+    TestFixture::client().set_throw_on_error(false);
+    sleep(run_test_for_n_seconds);
+    cout << "   suspending suite, to let jobs complete" << endl;
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                          "sync_local failed should return 0\n"
+                              << TestFixture::client().errorMsg());
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().suspend(test_name_path) == 0,
+                          "suspend failed should return 0\n"
+                              << TestFixture::client().errorMsg());
+
+    cout << "   Waiting " << max_time_for_suspended_suite_to_complete << " seconds for all jobs to complete" << endl;
+    AssertTimer assertTimer(max_time_for_suspended_suite_to_complete,
+                            false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        sleep(3);
+
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        if (defs) {
+            int no_of_active_tasks    = 0;
+            int no_of_submitted_tasks = 0;
+            std::vector<Task*> vec;
+            defs->getAllTasks(vec);
+            for (size_t i = 0; i < vec.size(); i++) {
+                if (vec[i]->get_state().first == NState::ACTIVE)
+                    no_of_active_tasks++;
+                else if (vec[i]->get_state().first == NState::SUBMITTED)
+                    no_of_submitted_tasks++;
+            }
+            cout << "   still active:" << no_of_active_tasks << "  still submitted:" << no_of_submitted_tasks << endl;
+            if (no_of_active_tasks == 0 && no_of_submitted_tasks == 0)
+                break;
+        }
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                                  "   test_stress : Test wait " << assertTimer.duration()
+                                                                << " taking longer than time constraint of "
+                                                                << assertTimer.timeConstraint() << " aborting\n");
+            break;
+        }
+    }
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+// DO NOT delete
+// This is used to test large defs. and hence server performance & memory leaks
+// Be sure to comment out defstatus suspended in mega.def
+// BOOST_AUTO_TEST_CASE( test_mega_def )
+//{
+//   DurationTimer timer;
+//
+//   // location to mega.def and left over log file
+//   std::string log_file = File::test_data("ANode/parser/test/data/single_defs/mega.def_log","parser");
+//   std::string path = File::test_data("ANode/parser/test/data/single_defs/mega.def","parser");
+//
+//   cout << "Test:: ..." << path << " log file: " << log_file << flush;
+//
+//   // Remove the log file.
+//   fs::remove(log_file);
+//
+//   // parse in file
+//   Defs theDefs;
+//   std::string errorMsg,warningMsg;
+//   BOOST_REQUIRE_MESSAGE(theDefs.restore(path,errorMsg,warningMsg),errorMsg);
+//
+//   ServerTestHarness serverTestHarness;
+//   serverTestHarness.check_task_duration_less_than_server_poll(false); // Add variable
+//   CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL
+//   serverTestHarness.run(theDefs,path,std::numeric_limits<int>::max()/*timeout*/  );
+//
+//   cout << timer.duration() << "\n";
+//}
+
+// DO NOT delete
+// This is used to test with thousands of labels
+// BOOST_AUTO_TEST_CASE( test_large_client_labels_calls )
+//{
+//   DurationTimer timer;
+//   cout << "Test:: ...test_large_client_labels_calls "<< flush;
+//   TestClean clean_at_start_and_end;
+//
+//   //# Note: we have to use relative paths, since these tests are relocatable
+//   // suite test_large_client_labels_calls
+//   //   family family
+//   //       task t1
+//   //          label name "value"
+//   //    endfamily
+//   // endsuite
+//   Defs theDefs;
+//   {
+//      suite_ptr suite = theDefs.add_suite("test_large_client_labels_calls");
+//      family_ptr fam = suite->add_family("family");
+//      task_ptr t1 = fam->add_task("t1");
+//      t1->addLabel( Label("name","value"));
+//   }
+//
+//   // Create a custom ecf file for test_large_client_labels_calls/family/t1 to invoke label commands
+//   std::string templateEcfFile;
+//   templateEcfFile += "%include <head.h>\n";
+//   templateEcfFile += "\n";
+//   templateEcfFile += "echo do some work\n";
+//   templateEcfFile += "i=1\n";
+//   templateEcfFile += "while [ \"$i\" -le 10000 ] \n";
+//   templateEcfFile += "do\n";
+//   templateEcfFile += "  %ECF_CLIENT_EXE_PATH% --label=name
+//   \"1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890\"\n";
+//   templateEcfFile += "  i=$((i+1))\n";
+//   templateEcfFile += "done\n";
+//   templateEcfFile += "\n";
+//   templateEcfFile += "%include <tail.h>\n";
+//
+//   // The test harness will create corresponding directory structure
+//   // Override the default ECF file, with our custom ECF_ file
+//   std::map<std::string,std::string> taskEcfFileMap;
+//   taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs,"t1"),templateEcfFile));
+//
+//    // Avoid standard verification since we expect to abort many times
+//   ServerTestHarness serverTestHarness;
+//   serverTestHarness.run(theDefs,ServerTestHarness::testDataDefsLocation("test_large_client_labels_calls.def"),
+//   taskEcfFileMap,1000000);
+//
+//   cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n" <<
+//   endl;
+//}
+//
+
+//// DO NOT delete
+/// The following  test verifies that the job generation is largely linear.
+/// Job submission interval was 3 seconds. In release mode.
+///
+/// Test duration is highly dependent on the OS/process handling.
+/// No of tasks     Job generation    Peak request/sec in server
+///   10                  -
+///   100                 -
+///   500                 -                     364
+///   1000               4                      450
+///   1500               6                      550
+///   2000               9                      880
+///   3000               15                     800
+///   4000               24                     923
+///   5000               29                     800
+///   6000               37                     900
+// void time_for_tasks(int tasks) {
+//
+//    std::string test_name = "test_stress_" + ecf::convert_to<std::string>(tasks);
+//    cout << "Test:: ..." << test_name  << flush;
+//
+//    Defs theDefs;
+//    {
+//       suite_ptr suite = theDefs.add_suite( test_name );
+//       family_ptr fam = suite->add_family("fam" );
+//       for(int i = 0; i < tasks; i++) {
+//          fam->add_task( "t" + ecf::convert_to<std::string>(i));
+//       }
+//       //      suite->addRepeat( RepeatDate("YMD",19000101,99991201,1) );
+//    }
+//
+//    ServerTestHarness serverTestHarness;
+//    serverTestHarness.check_task_duration_less_than_server_poll(false); // Add variable
+//    CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL DurationTimer timer;
+//    serverTestHarness.run(theDefs,ServerTestHarness::testDataDefsLocation(test_name + ".def"),
+//    std::numeric_limits<int>::max()/*timeout*/  ); cout << "  " << timer.duration() << "s\n";
+// }
+//
+//// Use to stress test server. i.e continually fire client requests.
+// BOOST_AUTO_TEST_CASE( test_stress )
+//{
+//    time_for_tasks(10);
+//    time_for_tasks(100);
+//    time_for_tasks(500);
+//    time_for_tasks(1000);
+//    time_for_tasks(1500);
+//    time_for_tasks(2000);
+//    time_for_tasks(3000);
+//    time_for_tasks(4000);
+//    time_for_tasks(5000);
+// }
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestSingle_main.cpp 5.13.0-1/libs/test/TestSingle_main.cpp
--- 5.12.4-1/libs/test/TestSingle_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestSingle_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Single
+#include <boost/test/included/unit_test.hpp>
+
+#include "TestFixture.hpp"
+
+// Global test fixture.
+//
+// Note: Due to boost deficiency this can't be easily accessed, so TestFixture makes use of global data.
+//
+BOOST_GLOBAL_FIXTURE(TestFixture);
diff -pruN 5.12.4-1/libs/test/TestSpecificIssues.cpp 5.13.0-1/libs/test/TestSpecificIssues.cpp
--- 5.12.4-1/libs/test/TestSpecificIssues.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestSpecificIssues.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,92 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_SpecificIssues)
+
+BOOST_AUTO_TEST_CASE(test_ECFLOW_1589) {
+    // Test ECF_JOB_CMD where task *completes* but the ECF_JOB_CMD still fails. i.e ECFLOW-1589
+
+    DurationTimer timer;
+    cout << "Test:: ...test_ECFLOW_1589 " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    //  suite test_ECFLOW_1589
+    //     task t1
+    //  endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_ECFLOW_1589");
+        suite->add_task("t1")->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        // cout << theDefs;
+    }
+
+    // Create a custom ecf file for test_task_abort_cmd/family0/abort to invoke the child abort command
+    std::string templateEcfFile;
+    templateEcfFile += "%include <head.h>\n";
+    templateEcfFile += "\n";
+    templateEcfFile += "echo do some work\n";
+    templateEcfFile += "\n";
+    templateEcfFile += "%include <bad_tail.h>\n"; // this will exit 1
+
+    // The test harness will create corresponding directory structure
+    // Override the default ECF file, with our custom ECF_ file
+    std::map<std::string, std::string> taskEcfFileMap;
+    taskEcfFileMap.insert(std::make_pair(TestFixture::taskAbsNodePath(theDefs, "t1"), templateEcfFile));
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_ECFLOW_1589.def"), taskEcfFileMap);
+
+    // Since the job will call exit 1, i.e from bad_tail.h, we expect ecf::Flag::JOBCMD_FAILED
+    // and since task t1 has *ALREADY* completed we expect ecf::Flag::ZOMBIE
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                          "sync_local failed should return 0\n"
+                              << TestFixture::client().errorMsg());
+    defs_ptr defs = TestFixture::client().defs();
+    // cout << defs;
+    node_ptr task = defs->findAbsNode("/test_ECFLOW_1589/t1");
+    BOOST_REQUIRE_MESSAGE(task, "Expected to find task\n");
+    BOOST_CHECK_MESSAGE(task->flag().is_set(ecf::Flag::ZOMBIE), "expected zombie flag to be set\n");
+    BOOST_CHECK_MESSAGE(task->flag().is_set(ecf::Flag::JOBCMD_FAILED),
+                        "expected JOBCMD_FAILED failed flag to be set\n");
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestSuspend.cpp 5.13.0-1/libs/test/TestSuspend.cpp
--- 5.12.4-1/libs/test/TestSuspend.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestSuspend.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,239 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+#if defined(_AIX)
+static int timeout = 30;
+#else
+static int timeout = 20;
+#endif
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Suspend)
+
+static void waitForTimeDependenciesToBeFree(int max_time_to_wait) {
+    // wait for a period of time, while time dependencies fire.
+    TestFixture::client().set_throw_on_error(false);
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        vector<Task*> tasks;
+        defs->getAllTasks(tasks);
+        size_t taskTimeDepIsFree = 0;
+        for (Task* task : tasks) {
+            size_t attSetFree = 0;
+            for (const ecf::TimeAttr& timeAttr : task->timeVec()) {
+                if (timeAttr.isFree(task->suite()->calendar()))
+                    attSetFree++;
+            }
+            if (attSetFree == task->timeVec().size())
+                taskTimeDepIsFree++;
+        }
+        if (taskTimeDepIsFree == tasks.size())
+            break;
+
+        BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                              "waitForTimeDependenciesToBeFree Test wait "
+                                  << assertTimer.duration() << " taking longer than time constraint of "
+                                  << assertTimer.timeConstraint() << " aborting");
+        sleep(1);
+    }
+}
+
+// test:: suspend/shutdown. During suspend the time dependencies should still
+// be handled. When the server/node is restarted/resumed the task should
+// be submitted straight away.(i.e providing no trigger/complete dependencies)
+BOOST_AUTO_TEST_CASE(test_shutdown) {
+    DurationTimer timer;
+    cout << "Test:: ...test_shutdown " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    Defs theDefs;
+    {
+        // Initialise clock with today's date and time, then create a time attribute
+        // with today's time + minute Avoid adding directly to TimeSlot
+        // i.e. if local time is 9:59, and we create a TimeSlot like
+        //     task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
+        // The minute will be 62, which is illegal and will not parse
+        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
+
+        // For each 2 seconds of poll in the server update calendar by 1 minute
+        // Note: if we use 1 seconds poll to update calendar by 1 minute, then
+        //       we will find that state change happens at job submission interval,
+        //       and hence skews time series.  Which can leave state in a queued state,
+        //       and hence test never completes
+        suite_ptr suite = theDefs.add_suite("test_shutdown");
+        ClockAttr clockAttr(theLocalTime);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        int taskSize   = 2; // on linux 1024 tasks take ~4 seconds for job submission
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+
+            boost::posix_time::ptime time1 = theLocalTime + minutes(1 + i);
+            task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
+
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
+        }
+    }
+
+    // The test harness will create corresponding directory structure and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_shutdown.def"),
+                          1,
+                          false /* don't wait for test to finish */);
+
+    // Shutdown the server. The time dependencies *should* still be handled
+    // *** If this test fails, in that we fail to restart() server it will mess up
+    // *** any following test.
+    TestFixture::client().set_throw_on_error(false);
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().shutdownServer() == 0,
+                          CtsApi::shutdownServer() << " failed should return 0.\n"
+                                                   << TestFixture::client().errorMsg());
+
+    // wait for a period of time, while time dependencies fire.
+    (void)waitForTimeDependenciesToBeFree(timeout);
+
+    // restart server, all jobs should be launched straight away
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().restartServer() == 0,
+                          CtsApi::restartServer() << " failed should return 0.\n"
+                                                  << TestFixture::client().errorMsg());
+
+    // Wait for submitted jobs in restart server to complete
+    bool verifyAttrInServer = true;
+    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
+    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return server after restartServer");
+
+    // cout << "Printing Defs \n";
+    // std::cout << *serverDefs.get();
+
+    cout << timer.duration() << " update-calendar-count(" << serverDefs->updateCalendarCount() << ")\n";
+}
+
+// test:: suspend/shutdown. During suspend the time dependencies should still
+// be handled. When the server/node is restarted/resumed the task should
+// be submitted straight away.(i.e providing no trigger/complete dependencies)
+BOOST_AUTO_TEST_CASE(test_suspend_node) {
+    DurationTimer timer;
+    cout << "Test:: ...test_suspend_node " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+    Defs theDefs;
+    {
+        // Initialise clock with today's date and time, then create a time attribute
+        // with today's time + minute Avoid adding directly to TimeSlot
+        // i.e. if local time is 9:59, and we create a TimeSlot like
+        //     task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
+        // The minute will be 62, which is illegal and will not parse
+        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
+
+        suite_ptr suite = theDefs.add_suite("test_suspend_node");
+        ClockAttr clockAttr(theLocalTime);
+        suite->addClock(clockAttr);
+
+        task_ptr t1                    = suite->add_task("t1");
+        boost::posix_time::ptime time1 = theLocalTime + minutes(1);
+        t1->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
+
+        task_ptr t2                    = suite->add_task("t2");
+        boost::posix_time::ptime time2 = theLocalTime + minutes(2);
+        t2->addTime(ecf::TimeAttr(ecf::TimeSlot(time2.time_of_day())));
+
+        family_ptr fam = suite->add_family("family");
+        for (int i = 0; i < 2; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
+
+            boost::posix_time::ptime time3 = theLocalTime + minutes(1 + i);
+            task->addTime(ecf::TimeAttr(ecf::TimeSlot(time3.time_of_day())));
+        }
+    }
+
+    // The test harness will create corresponding directory structure and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_suspend_node.def"),
+                          1,
+                          false /* don't wait for test to finish */);
+
+    // SUSPEND the family. The time dependencies *should* still be handled
+    TestFixture::client().set_throw_on_error(false);
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().suspend("/test_suspend_node/family") == 0,
+                          CtsApi::to_string(CtsApi::suspend("/test_suspend_node/family"))
+                              << " failed should return 0.\n"
+                              << TestFixture::client().errorMsg());
+
+    // wait for a period of time, while time dependencies fire.
+    waitForTimeDependenciesToBeFree(timeout);
+
+    // RESUME the family, all jobs should be launched straight away, since time dependencies should be free
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().resume("/test_suspend_node/family") == 0,
+                          CtsApi::to_string(CtsApi::resume("/test_suspend_node/family"))
+                              << " failed should return 0.\n"
+                              << TestFixture::client().errorMsg());
+
+    // Wait for submitted jobs to complete
+    bool verifyAttrInServer = true;
+    defs_ptr serverDefs     = serverTestHarness.testWaiter(theDefs, timeout, verifyAttrInServer);
+    BOOST_REQUIRE_MESSAGE(serverDefs.get(), " Failed to return server after restartServer");
+
+    // cout << "Printing Defs \n";
+    // std::cout << *serverDefs.get();
+
+    cout << timer.duration() << " update-calendar-count(" << serverDefs->updateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestTime.cpp 5.13.0-1/libs/test/TestTime.cpp
--- 5.12.4-1/libs/test/TestTime.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestTime.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,431 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Time)
+
+BOOST_AUTO_TEST_CASE(test_single_real_time) {
+    DurationTimer timer;
+    cout << "Test:: ...test_single_real_time " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       time 10:00
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with fixed date and time, then create a time attribute
+        // with todays time + minute
+        // Avoid adding directly to TimeSlot
+        // i.e if local time is 9:59 and we create a TimeSlot like
+        //       task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
+        // The the minute will be 62, which is illegal and will not parse
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
+
+        // For each 2 seconds of poll in the server update calendar by 1 minute
+        // Note: if we use 1 seconds poll to update calendar by 1 minute, then
+        //       we will find that state change happens at job submission interval,
+        //       and hence skews time series.  Which can leave state in a queued state,
+        //       and hence test never completes
+        suite_ptr suite = theDefs.add_suite("test_single_real_time");
+        ClockAttr clockAttr(theLocalTime, false);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_single_real_time.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_single_time_trigger) {
+    // ECFLOW-833
+    DurationTimer timer;
+    cout << "Test:: ...test_single_time_trigger " << flush;
+    TestClean clean_at_start_and_end;
+
+    // Create the defs file corresponding to the text below
+    // ECF_HOME variable is automatically added by the test harness.
+    // ECF_INCLUDE variable is automatically added by the test harness.
+    // SLEEPTIME variable is automatically added by the test harness.
+    // ECF_CLIENT_EXE_PATH variable is automatically added by the test harness.
+    //                     This is substituted in sms includes
+    //                     Allows test to run without requiring installation
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       trigger /suite:TIME == 1001
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with fixed date and time, then create a time attribute
+        // with todays time + minute
+        // Avoid adding directly to TimeSlot
+        // i.e if local time is 9:59 and we create a TimeSlot like
+        //       task->addTime( ecf::TimeAttr( ecf::TimeSlot(theTm.tm_hour,theTm.tm_min+3) )  );
+        // The the minute will be 62, which is illegal and will not parse
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+
+        // For each 2 seconds of poll in the server update calendar by 1 minute
+        // Note: if we use 1 seconds poll to update calendar by 1 minute, then
+        //       we will find that state change happens at job submission interval,
+        //       and hence skews time series.  Which can leave state in a queued state,
+        //       and hence test never completes
+        suite_ptr suite = theDefs.add_suite("test_single_time_trigger");
+        ClockAttr clockAttr(theLocalTime, false);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        std::stringstream ss;
+        ss << "/test_single_time_trigger:TIME == "
+           << "1001";
+        task->add_trigger(ss.str());
+        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_single_time_trigger.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_time_multiple_single_slot) {
+    DurationTimer timer;
+    cout << "Test:: ...test_time_multiple_single_slot " << flush;
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step.
+    // *sometimes* just submitted->active can take many times job submission interval.
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_time_multiple_single_slot
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       time 10:01
+    //       time 10:04
+    //       time 10:07
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with todays date and time, then create a time attribute
+        // with todays time + minute.
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
+        boost::posix_time::ptime time2        = time1 + minutes(TestFixture::job_submission_interval());
+        boost::posix_time::ptime time3        = time2 + minutes(TestFixture::job_submission_interval());
+
+        suite_ptr suite = theDefs.add_suite("test_time_multiple_single_slot");
+        ClockAttr clockAttr(theLocalTime, false);
+        suite->addClock(clockAttr);
+        suite->add_variable("SLEEPTIME", "1");
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time2.time_of_day())));
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time3.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_multiple_single_slot.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_time_relative_time_series) {
+    DurationTimer timer;
+    cout << "Test:: ...test_time_relative_time_series " << flush;
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_time_relative_time_series
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       time +<start> <finish> incr
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with todays date and time, then create a time attribute
+        // with a time series, so that task runs 3 times relative to suite start
+        suite_ptr suite = theDefs.add_suite("test_time_relative_time_series");
+        ClockAttr clockAttr(Calendar::second_clock_time(), false);
+        suite->addClock(clockAttr);
+        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() - 2));
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(
+            ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 7), ecf::TimeSlot(0, 3), true /*relative to suite start*/
+            ));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_relative_time_series.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_time_real_series) {
+    DurationTimer timer;
+    cout << "Test:: ...test_time_real_series " << flush;
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_time_real_series
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <date>
+    //   family family
+    //     task t1
+    //       time <start> <finish> <incr>
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with todays date and time, then create a time attribute
+        // with a time series, so that task runs 3 times
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
+        boost::posix_time::ptime time2        = time1 + minutes(TestFixture::job_submission_interval() * 2);
+
+        suite_ptr suite = theDefs.add_suite("test_time_real_series");
+        suite->add_variable("SLEEPTIME", "1");
+
+        ClockAttr clockAttr(theLocalTime, false);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day()),
+                                    ecf::TimeSlot(time2.time_of_day()),
+                                    ecf::TimeSlot(0, TestFixture::job_submission_interval())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
+                                                          // 1 +    7  + 13
+                                                          // 1 + (2*n) + (2*n) = 1 + 4n
+        // start = 1, finish = 13, when n=3, when n = job submission interval
+        // to complete 3 times, we must use interval of n*2
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    // serverTestHarness.add_default_sleep_time(false); // avoid missing time steps due to submit->active->complete >
+    // job submission interval
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_real_series.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_single_real_time_near_midnight) {
+    DurationTimer timer;
+    cout << "Test:: ...test_single_real_time_near_midnight " << flush;
+    TestClean clean_at_start_and_end;
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite suite
+    //   edit SLEEPTIME 4
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       time 23:59
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // ECFLOW-130
+        // Make sure job completes after midnight.
+        // The task SHOULD stay complete and *NOT* requeue
+        // Since TestHarness requires suite completion, we dont need to do anything.
+        boost::posix_time::ptime time_start  = boost::posix_time::ptime(date(2010, 6, 21), time_duration(23, 59, 0));
+        boost::posix_time::ptime clock_start = time_start - minutes(1);
+
+        suite_ptr suite = theDefs.add_suite("test_single_real_time_near_midnight");
+        ClockAttr clockAttr(clock_start, false);
+        suite->addClock(clockAttr);
+        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2));
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time_start.time_of_day())));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 1)); // task should complete 1 times
+    }
+
+    // The test harness will create corresponding directory structure and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_single_real_time_near_midnight.def"));
+
+#ifdef DEBUG_ME
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                          "Could not get the defs from server\n"
+                              << TestFixture::client().errorMsg());
+    defs_ptr defs = TestFixture::client().defs();
+    PrintStyle style(PrintStyle::STATE);
+    std::cout << *defs;
+#endif
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_time_real_series_near_midnight) {
+    DurationTimer timer;
+    cout << "Test:: ...test_time_real_series_near_midnight " << flush;
+    int the_server_version = TestFixture::server_version();
+    if (the_server_version == 403) {
+        cout << " SKIPPING, This test does not work with 403, current server version is " << the_server_version << "\n";
+        return;
+    }
+
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_time_real_series
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <date>
+    //   family family
+    //     task t1
+    //       time <start> <finish> <incr>
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // ECFLOW-130
+        // make sure that last job, *runs* and completes after midnight.
+        // It should stay complete and not requeue.
+        // Test harness, will check suite task->family->suite completes, hence no need to do anything
+        boost::posix_time::ptime last_time   = boost::posix_time::ptime(date(2010, 6, 21), time_duration(23, 59, 0));
+        boost::posix_time::ptime first_time  = last_time - minutes(TestFixture::job_submission_interval() * 2);
+        boost::posix_time::ptime clock_start = first_time - minutes(1);
+
+        suite_ptr suite = theDefs.add_suite("test_time_real_series_near_midnight");
+        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() * 2));
+
+        ClockAttr clockAttr(clock_start, false);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(first_time.time_of_day()),
+                                    ecf::TimeSlot(last_time.time_of_day()),
+                                    ecf::TimeSlot(0, TestFixture::job_submission_interval() * 2)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 2)); // task should complete 2 times
+    }
+
+    // The test harness will create corresponding directory structure and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_time_real_series_near_midnight.def"));
+
+#ifdef DEBUG_ME
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                          "Could not get the defs from server\n"
+                              << TestFixture::client().errorMsg());
+    defs_ptr defs = TestFixture::client().defs();
+    PrintStyle style(PrintStyle::STATE);
+    std::cout << *defs;
+#endif
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestToday.cpp 5.13.0-1/libs/test/TestToday.cpp
--- 5.12.4-1/libs/test/TestToday.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestToday.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,190 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Today)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+BOOST_AUTO_TEST_CASE(test_today_single_slot) {
+    DurationTimer timer;
+    cout << "Test:: ...test_today_single_slot " << flush;
+    TestClean clean_at_start_and_end;
+
+    // **************************************************************************
+    // It does not really make sense to have multiple today attributes
+    // since as soon as one today has expired the task is free to run
+    // suite test_today_mutiple_single_slot
+    //    edit SLEEPTIME 1
+    //    edit ECF_INCLUDE $ECF_HOME/includes
+    //    clock real <todays date>
+    //    family family
+    //       task t1
+    //          today 10.01  // after 10.01, the node is free, for 10.02,10.03
+    //          today 10.04
+    //    endfamily
+    // endsuite
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_today_single_slot
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       today 11.12
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with todays date and time, then create a today attribute
+        // one hour past the clock todays time. The node should be free to run.
+        boost::posix_time::ptime theLocalTime    = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+        boost::posix_time::ptime time_minus_hour = theLocalTime - hours(1);
+
+        suite_ptr suite = theDefs.add_suite("test_today_single_slot");
+        ClockAttr clockAttr(theLocalTime, false, true /*positive gain*/);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addToday(ecf::TodayAttr(ecf::TimeSlot(time_minus_hour.time_of_day())));
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard sms files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_today_single_slot.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_today_relative_time_series) {
+    DurationTimer timer;
+    cout << "Test:: ...test_today_relative_time_series " << flush;
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_today_relative_time_series
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       today <start> <finish> <incr>
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with todays date and time, then create a today attribute
+        // with a time series, so that task runs 3 times
+        suite_ptr suite = theDefs.add_suite("test_today_relative_time_series");
+        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() - 1));
+        ClockAttr clockAttr(Calendar::second_clock_time(), false);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t");
+        task->addToday(ecf::TodayAttr(
+            ecf::TimeSlot(0, 1), ecf::TimeSlot(0, 7), ecf::TimeSlot(0, 3), true /*relative to suite start*/
+            ));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_today_relative_time_series.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_today_real_time_series) {
+    DurationTimer timer;
+    cout << "Test:: ...test_today_real_time_series " << flush;
+    TestClean clean_at_start_and_end;
+
+    // SLOW SYSTEMS
+    // for each time attribute leave GAP of 3 * job submission interval
+    // on slow systems submitted->active->complete > TestFixture::job_submission_interval()
+    // Also the task duration must be greater than job_submission_interval,  otherwise
+    // we will get multiple invocation for the same time step
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_today_real_time_series
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   clock real <todays date>
+    //   family family
+    //     task t1
+    //       today 10:01 10:07 00:03
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        // Initialise clock with a fixed date and time, then create a today attribute
+        // with a time series, so that task runs 3 times
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(10, 0, 0));
+        boost::posix_time::ptime time1        = theLocalTime + minutes(1);
+        boost::posix_time::ptime time2        = theLocalTime + minutes(7);
+
+        suite_ptr suite = theDefs.add_suite("test_today_real_time_series");
+        ClockAttr clockAttr(theLocalTime, false);
+        suite->addClock(clockAttr);
+        suite->add_variable("SLEEPTIME", ecf::convert_to<std::string>(TestFixture::job_submission_interval() - 1));
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        family_ptr fam = suite->add_family("family");
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        task_ptr task = fam->add_task("t");
+        task->addToday(ecf::TodayAttr(
+            ecf::TimeSlot(time1.time_of_day()), ecf::TimeSlot(time2.time_of_day()), ecf::TimeSlot(0, 3)));
+        task->addVerify(VerifyAttr(NState::COMPLETE, 3)); // task should complete 3 times
+    }
+
+    // The test harness will create corresponding directory structure
+    // and populate with standard ecf files.
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_today_real_time_series.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestTrigger.cpp 5.13.0-1/libs/test/TestTrigger.cpp
--- 5.12.4-1/libs/test/TestTrigger.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestTrigger.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,143 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <cstdlib>
+#include <fstream>
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "ecflow/attribute/VerifyAttr.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Trigger)
+
+// In the test case we will dynamically create all the test data.
+// The data is created dynamically so that we can stress test the server
+// This test does not have any time dependencies in the def file.
+BOOST_AUTO_TEST_CASE(test_triggers_and_meters) {
+    DurationTimer timer;
+    cout << "Test:: ...test_triggers_and_meters " << flush;
+    TestClean clean_at_start_and_end;
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_triggers_and_meters
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     task model
+    //       meter file 0 100 100
+    //       task t0
+    //         trigger model:file ge 10
+    //       task t1
+    //         trigger model:file ge 20
+    //       task t2
+    //         trigger model:file ge 30
+    //       ....
+    //   endfamily
+    // endsuite
+    std::string meterName = "file";
+    std::string taskName  = "model";
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_triggers_and_meters");
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        family_ptr fam = suite->add_family("family");
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+
+        task_ptr taskModel = fam->add_task(taskName);
+        taskModel->addMeter(Meter(meterName, 0, 100, 100)); // ServerTestHarness will add correct ecf
+
+        int taskSize = 9; // on linux 1024 tasks take ~4 seconds for job submission
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i * 10 + 10));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+            task->add_trigger(taskName + Str::COLON() + meterName + " ge " + ecf::convert_to<std::string>(i * 10 + 10));
+        }
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_triggers_and_meters.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_triggers_with_limits) {
+    // One family is in the limits, another is without. Bit of hack
+    // But shows use of limits in triggers
+    DurationTimer timer;
+    cout << "Test:: ...test_triggers_with_limits " << flush;
+    TestClean clean_at_start_and_end;
+
+    // # Note: we have to use relative paths, since these tests are relocatable
+    // suite test_triggers_with_limits
+    //   limit limit 10
+    //   edit SLEEPTIME 1
+    //   edit ECF_INCLUDE $ECF_HOME/includes
+    //   family family
+    //     inlimit /test_triggers_and_meters:limit 3
+    //     task model
+    //     task t0
+    //     task t1
+    //     task t2
+    //   endfamily
+    //   family other
+    //     trigger /test_triggers_with_limits:limit >1
+    //     task t1
+    //     task t2
+    //   endfamily
+    // endsuite
+    Defs theDefs;
+    {
+        suite_ptr suite = theDefs.add_suite("test_triggers_with_limits");
+        suite->addLimit(Limit("limit", 10));
+        suite->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        family_ptr fam = suite->add_family("family");
+        fam->addInLimit(InLimit("limit", "/test_triggers_with_limits", 3));
+        fam->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        int taskSize = 10;
+        for (int i = 0; i < taskSize; i++) {
+            task_ptr task = fam->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+
+        family_ptr fam2 = suite->add_family("other");
+        fam2->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        fam2->add_trigger("/test_triggers_with_limits:limit > 1");
+        for (int i = 0; i < 3; i++) {
+            task_ptr task = fam2->add_task("t" + ecf::convert_to<std::string>(i));
+            task->addVerify(VerifyAttr(NState::COMPLETE, 1));
+        }
+    }
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs, ServerTestHarness::testDataDefsLocation("test_triggers_and_meters.def"));
+
+    cout << timer.duration() << " update-calendar-count(" << serverTestHarness.serverUpdateCalendarCount() << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestWhyCmd.cpp 5.13.0-1/libs/test/TestWhyCmd.cpp
--- 5.12.4-1/libs/test/TestWhyCmd.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestWhyCmd.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,540 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ecflow/base/WhyCmd.hpp"
+#include "ecflow/base/cts/ClientToServerCmd.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Limit.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_WhyCmd)
+
+static unsigned int waitForWhy(const std::string& path, const std::string& why, int max_time_to_wait) {
+    unsigned int updateCalendarCount = 0;
+    TestFixture::client().set_throw_on_error(false);
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+
+        /// Why command relies on the Suite serializing the calendar. If this is changed we need to get the full defs
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+
+        /// called to test that sync suite clock works
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local(true /*sync suite clock*/) == 0,
+                              "sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr server_defs = TestFixture::client().defs();
+        updateCalendarCount  = server_defs->updateCalendarCount();
+
+        WhyCmd whyCmd(server_defs, path);
+        std::string reason = whyCmd.why();
+        // std::cout << reason;
+
+        if (reason.find(why) != std::string::npos) {
+            // see the reason why job is not running
+            std::cout << reason;
+            break;
+        }
+
+        BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                              "waitForWhy Test wait " << assertTimer.duration()
+                                                      << " taking longer than time constraint of "
+                                                      << assertTimer.timeConstraint() << " aborting\n"
+                                                      << *server_defs);
+        sleep(1);
+    }
+    return updateCalendarCount;
+}
+
+BOOST_AUTO_TEST_CASE(test_why_day) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_day " << flush;
+    TestClean clean_at_start_and_end;
+
+    Defs theDefs;
+    {
+        boost::posix_time::ptime today = Calendar::second_clock_time();
+        suite_ptr suite                = Suite::create("test_why_day");
+        family_ptr fam                 = Family::create("family");
+        task_ptr task                  = Task::create("t1");
+
+        // Dont use hybrid for day dependency as that will force node to complete if days is not the same
+        ClockAttr clockAttr(today, false);
+        suite->addClock(clockAttr);
+
+        // ** add tomorrow days so that node stays queued **
+        task->addDay(DayAttr(today.date() + boost::gregorian::date_duration(1)));
+
+        fam->addTask(task);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_day.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // The job should not be submitted and should stay queued since the day does not match
+    // running the why command, should report dependency on day
+    unsigned int updateCalendarCount = waitForWhy("/test_why_day/family/t1", "day", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_date) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_date " << flush;
+
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_why_date");
+        family_ptr fam  = Family::create("family");
+        task_ptr task   = Task::create("t1");
+
+        // Don't use hybrid for date dependency as that will force node to complete if date is not the same
+        boost::posix_time::ptime today = Calendar::second_clock_time();
+        ClockAttr clockAttr(today, false);
+        suite->addClock(clockAttr);
+
+        // ** add tomorrow date so that node stays queued **
+        task->addDate(DateAttr(today.date() + boost::gregorian::date_duration(1)));
+        fam->addTask(task);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_date.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // The job should not be submitted and should stay queued since the day does not match
+    // running the why command, should report dependency on day
+    unsigned int updateCalendarCount = waitForWhy("/test_why_date/family/t1", "date", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_time) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_time " << flush;
+
+    Defs theDefs;
+    {
+        boost::posix_time::ptime theLocalTime = Calendar::second_clock_time();
+        boost::posix_time::ptime time1        = theLocalTime - hours(1);
+
+        suite_ptr suite = Suite::create("test_why_time");
+        family_ptr fam  = Family::create("family");
+        task_ptr task   = Task::create("t1");
+
+        ClockAttr clockAttr(theLocalTime);
+        suite->addClock(clockAttr);
+
+        task->addTime(ecf::TimeAttr(ecf::TimeSlot(time1.time_of_day())));
+        fam->addTask(task);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_time.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // The job should not be submitted and should stay queued since the time does not match
+    // running the why command, should report dependency on time
+    unsigned int updateCalendarCount = waitForWhy("/test_why_time/family/t1", "time", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_today) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_today " << flush;
+
+    Defs theDefs;
+    {
+        // IMPORTANT: A Node with a today attribute is *free* to run *IF* the suite
+        //            calendar time is greater than the today date.
+        //            Hence if we start this test just before midnight i.e 11.20,
+        //            and add hour , then the today time would be 00:20
+        //            *i.e node is free to run*
+        // This is not what we want for this test. i.e we depend on node being queued
+        // in order to test the why command. Also the following tests, start
+        // by deleting all nodes. This will fail due to active/submitted tasks
+        // Hence can *NOT* use:
+        // boost::posix_time::ptime theLocalTime =  Calendar::second_clock_time();
+        // boost::posix_time::ptime time1 =  theLocalTime + hours(1);
+
+        // Use a hard coded a time, to avoid failure if test is run just before midnight
+        boost::posix_time::ptime theLocalTime(date(2010, 2, 10), hours(1));
+        boost::posix_time::ptime time1 = theLocalTime + hours(1);
+
+        suite_ptr suite = theDefs.add_suite("test_why_today");
+        ClockAttr clockAttr(theLocalTime);
+        suite->addClock(clockAttr);
+
+        family_ptr fam = suite->add_family("family");
+        task_ptr task  = fam->add_task("t1");
+        task->addToday(ecf::TodayAttr(ecf::TimeSlot(time1.time_of_day())));
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_today.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // The job should not be submitted and should stay queued since the time does not match
+    // running the why command, should report dependency on time
+    unsigned int updateCalendarCount = waitForWhy("/test_why_today/family/t1", "today", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_cron) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_cron " << flush;
+
+    Defs theDefs;
+    {
+        boost::posix_time::ptime theLocalTime = boost::posix_time::ptime(date(2010, 6, 21), time_duration(11, 0, 0));
+        boost::posix_time::ptime time1        = theLocalTime - hours(3);
+        boost::posix_time::ptime time2        = theLocalTime - hours(1);
+        boost::gregorian::date todaysDate     = theLocalTime.date();
+
+        suite_ptr suite = Suite::create("test_why_cron");
+        family_ptr fam  = Family::create("family");
+        task_ptr task   = Task::create("t1");
+
+        ClockAttr clockAttr(theLocalTime, false /*real*/);
+        suite->addClock(clockAttr);
+
+        // ** IMPORTANT **, for a date in the future we must match day of week,
+        // ***************  day of month, and year, i.e the results are ANDED
+        // ***************  this can lead to unexpected time in the future
+        // ***************  if all 3 dependencies are present, as *below*
+        ecf::CronAttr cronAttr;
+        ecf::TimeSlot start(time1.time_of_day());  // in the past
+        ecf::TimeSlot finish(time2.time_of_day()); // in the past
+        ecf::TimeSlot incr(0, 5);
+        cronAttr.addTimeSeries(start, finish, incr);
+
+        std::vector<int> weekDays;
+        weekDays.push_back(todaysDate.day_of_week().as_number());
+        std::vector<int> daysOfMonth;
+        daysOfMonth.push_back(todaysDate.day());
+        std::vector<int> months;
+        months.push_back(todaysDate.month());
+        cronAttr.addWeekDays(weekDays);
+        cronAttr.addDaysOfMonth(daysOfMonth);
+        cronAttr.addMonths(months);
+
+        task->addCron(cronAttr);
+
+        fam->addTask(task);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_cron.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // The job should not be submitted and should stay queued we are past the cron time
+    // running the why command, should report dependency on cron
+    unsigned int updateCalendarCount = waitForWhy("/test_why_cron/family/t1", "cron", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_limit) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_limit " << flush;
+
+    // Testing for limits requires that we have least some jobs are submitted.
+    // we need to kill these jobs, at the end of test.
+
+    // suite test_why_limit
+    //   limit disk 50
+    //   family family
+    //     inlimit /suite1:disk 50
+    //     task t0
+    //     task t1
+    //     task t2
+    //     task t3
+    //     task t4
+    //     task t5
+    //   endfamily
+    // endsuite
+
+    Defs theDefs;
+    {
+        std::string suiteName   = "test_why_limit";
+        std::string pathToLimit = "/" + suiteName;
+        suite_ptr suite         = theDefs.add_suite(suiteName);
+        suite->addVariable(Variable("ECF_TRIES", "1"));
+        suite->addLimit(Limit("disk", 50));
+
+        family_ptr fam = suite->add_family("family");
+        fam->addInLimit(InLimit("disk", pathToLimit, 50));
+        int taskSize = 6;
+        for (int i = 0; i < taskSize; i++) {
+            fam->addTask(Task::create("t" + ecf::convert_to<std::string>(i)));
+        }
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_limit.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Only one job should be submitted, at a time, we will query on task t5, which
+    // should still be queued because the limit is full
+    // running the why command, should report dependency on limit
+    waitForWhy("/test_why_limit/family/t5", "limit", 10);
+
+    // The main check is over. Wait for jobs to complete
+    int updateCalendarCount = 0;
+    TestFixture::client().set_throw_on_error(false);
+    {
+        AssertTimer assertTimer(50, false); // Bomb out after n seconds, fall back if test fail
+        while (1) {
+            BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
+                                  CtsApi::get() << " failed should return 0\n"
+                                                << TestFixture::client().errorMsg());
+            defs_ptr defs       = TestFixture::client().defs();
+            updateCalendarCount = defs->updateCalendarCount();
+            bool wait           = false;
+            vector<Task*> tasks;
+            defs->getAllTasks(tasks);
+            for (Task* task : tasks) {
+                if (task->state() != NState::COMPLETE)
+                    wait = true;
+            }
+            if (!wait)
+                break;
+            if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+                cout << "waitFor jobs to complete, wait time of " << assertTimer.duration()
+                     << " taking longer than time constraint of " << assertTimer.timeConstraint()
+                     << " aborting, ......breaking out\n"
+                     << *defs << "\n";
+            }
+            sleep(1);
+        }
+    }
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_trigger) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_trigger " << flush;
+
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_why_trigger");
+        family_ptr fam  = Family::create("family");
+        task_ptr task   = Task::create("t1");
+        task->add_trigger("1 == 0");
+        fam->addTask(task);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_trigger.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Waiting for a trigger expression which will never evaluate
+    unsigned int updateCalendarCount = waitForWhy("/test_why_trigger/family/t1", "expression", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_meter) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_meter " << flush;
+
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_why_meter");
+        family_ptr fam  = Family::create("family");
+        fam->addMeter(Meter("meter", 0, 100, 100));
+        task_ptr task = Task::create("t1");
+        task->add_trigger("/test_why_meter/family:meter > 20");
+        fam->addTask(task);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_meter.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Waiting for a trigger expression which references a meter.
+    unsigned int updateCalendarCount = waitForWhy("/test_why_meter/family/t1", "/test_why_meter/family:meter", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_event) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_event " << flush;
+
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_why_event");
+        family_ptr fam  = Family::create("family");
+        task_ptr t1     = Task::create("t1");
+        task_ptr t2     = Task::create("t2");
+        t2->addEvent(Event(1, "theEvent"));
+        t2->add_trigger("1 == 0"); // make sure task t2 never runs
+        t1->add_trigger("/test_why_event/family/t2:theEvent == set");
+        fam->addTask(t1);
+        fam->addTask(t2);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_event.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Task t1, should stay queued because the event on task t2 is never set.
+    unsigned int updateCalendarCount =
+        waitForWhy("/test_why_event/family/t1", "/test_why_event/family/t2:theEvent", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_user_var) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_user_var " << flush;
+
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_why_user_var");
+        family_ptr fam  = Family::create("family");
+        task_ptr t1     = Task::create("t1");
+        suite->addVariable(Variable("user_var", "10"));
+        t1->add_trigger("/test_why_user_var:user_var eq 100");
+        fam->addTask(t1);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_user_var.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Task t1, should stay queued because the user variable 'user_var' value  = 10, is not 100
+    unsigned int updateCalendarCount = waitForWhy("/test_why_user_var/family/t1", "/test_why_user_var:user_var", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_gen_var) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_gen_var " << flush;
+
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_why_gen_var");
+        family_ptr fam  = Family::create("family");
+        task_ptr t1     = Task::create("t1");
+        t1->add_trigger("/test_why_gen_var/family/t1:ECF_TRYNO eq 100");
+        fam->addTask(t1);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_gen_var.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Task t1, should stay queued because the generated variable 'ECF_TRYNO' value  = 0, is not 100
+    unsigned int updateCalendarCount =
+        waitForWhy("/test_why_gen_var/family/t1", "/test_why_gen_var/family/t1:ECF_TRYNO", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_CASE(test_why_repeat) {
+    DurationTimer timer;
+    cout << "Test:: ...test_why_repeat " << flush;
+
+    Defs theDefs;
+    {
+        suite_ptr suite = Suite::create("test_why_repeat");
+        family_ptr fam  = Family::create("family");
+        task_ptr t1     = Task::create("t1");
+        suite->addRepeat(RepeatInteger("suite_repeat_var", 0, 3, 1));
+        fam->addRepeat(RepeatInteger("family_repeat_var", 0, 3, 1));
+        t1->add_trigger(
+            "/test_why_repeat/family:family_repeat_var eq 100  or /test_why_repeat:suite_repeat_var eq 100");
+        fam->addTask(t1);
+        suite->addFamily(fam);
+        theDefs.addSuite(suite);
+    }
+
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation("test_why_repeat.def"),
+                          1 /*timeout*/,
+                          false /* waitForTestCompletion*/);
+
+    // Task t1, should stay queued because the repeat variable on the suite and family do not match
+    unsigned int updateCalendarCount =
+        waitForWhy("/test_why_repeat/family/t1", "/test_why_repeat/family:family_repeat_var", 10);
+
+    cout << " " << timer.duration() << " update-calendar-count(" << updateCalendarCount << ")\n";
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestZombies.cpp 5.13.0-1/libs/test/TestZombies.cpp
--- 5.12.4-1/libs/test/TestZombies.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestZombies.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,1228 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <limits> // for std::numeric_limits<int>::max()
+
+#include <boost/date_time/posix_time/posix_time_types.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ServerTestHarness.hpp"
+#include "TestFixture.hpp"
+#include "ZombieUtil.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+using namespace boost::gregorian;
+using namespace boost::posix_time;
+
+///
+/// \note This is used to INVOKE a SINGLE test.
+/// Making it easier for Easier for debugging and development
+///
+
+// ****************************************************************
+// In the test below we create two sets of process. One of these
+// being a zombie. The test below create a list of user Zombies.
+//   In the cases where these test fail
+//   The dump of zombies shows that only One call was made.(i.e the initial creation of the Zombie)
+//   and that the proces-id is not defined.
+//   This implies that at test start, that not all process were started.
+//   ??Note sure why?? This can be seen by enabling debug in TaskCmds which
+//   shows that the Task INIT command was never received ???
+// Updated these test to detect STALE *user* zombies & remove them
+// i.e. where we have created a user Zombie but there is no associated process ??
+// *******************************************************************
+
+#define DO_TEST1 1
+#define DO_TEST2 1
+#define DO_TEST3 1
+#define DO_TEST4 1
+#define DO_TEST5 1
+#define DO_TEST6 1
+#define DO_TEST7 1
+#define DO_TEST8 1
+#define DO_TEST9 1
+#define DO_TEST10 1
+#define DO_TEST11 1
+#define DO_TEST12 1
+
+static bool ecf_debug_enabled = false; // allow environment(ECF_DEBUG_ZOMBIES) to enable debug
+
+BOOST_AUTO_TEST_SUITE(S_Test)
+
+BOOST_AUTO_TEST_SUITE(T_Zombies)
+
+enum WaitType { SINGLE, ALL };
+static int timeout      = 32;
+static int NUM_OF_TASKS = 5;
+
+static std::string dump_tasks(const vector<Task*>& tasks) {
+    std::stringstream ss;
+    ss << "     task status: no of tasks(" << tasks.size() << ")\n";
+    for (const Task* task : tasks) {
+        ss << "      " << task->absNodePath() << " " << NState::toString(task->state())
+           << " passwd:" << task->jobsPassword() << " pid:" << task->process_or_remote_id()
+           << " flag:" << task->get_flag().to_string();
+        if (task->state() == NState::ABORTED)
+            ss << " " << task->abortedReason();
+        ss << "\n";
+    }
+    ss << "\n";
+    return ss.str();
+}
+
+static std::string dump_task_status() {
+    TestFixture::client().sync_local();
+    defs_ptr defs = TestFixture::client().defs();
+    vector<Task*> tasks;
+    defs->getAllTasks(tasks);
+    return dump_tasks(tasks);
+}
+
+static void dump_zombies() {
+    TestFixture::client().zombieGet();
+    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+    std::cout << Zombie::pretty_print(zombies, 6);
+    std::cout << dump_task_status();
+}
+
+static bool waitForTaskStates(WaitType num_of_tasks, NState::State state1, NState::State state2, int max_time_to_wait) {
+    std::string wait_type_str = (num_of_tasks == SINGLE) ? "SINGLE" : "ALL";
+    if (ecf_debug_enabled) {
+        if (num_of_tasks == SINGLE) {
+            if (state1 == state2)
+                std::cout << "\n   Waiting for SINGLE task to reach state " << NState::toString(state1) << "\n";
+            else
+                std::cout << "\n   Waiting for SINGLE task to reach state " << NState::toString(state1) << " || "
+                          << NState::toString(state2) << "\n";
+        }
+        else {
+            if (state1 == state2)
+                std::cout << "\n   Waiting for ALL tasks to reach state " << NState::toString(state1) << "\n";
+            else
+                std::cout << "\n   Waiting for ALL tasks to reach state " << NState::toString(state1) << " || "
+                          << NState::toString(state2) << "\n";
+        }
+    }
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().sync_local() == 0,
+                              "waitForTaskStates:*error* sync_local failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        defs_ptr defs = TestFixture::client().defs();
+        vector<Task*> tasks;
+        defs->getAllTasks(tasks);
+        if (num_of_tasks == SINGLE) {
+            for (Task* task : tasks) {
+                if (task->state() == state1 || task->state() == state2) {
+                    if (ecf_debug_enabled) {
+                        if (task->state() == state1)
+                            std::cout << "    Found at least one Task with state " << NState::toString(state1)
+                                      << " returning\n";
+                        if (state1 != state2 && task->state() == state2)
+                            std::cout << "    Found at least one Task with state " << NState::toString(state2)
+                                      << " returning\n";
+                        dump_zombies();
+                    }
+                    return true;
+                }
+            }
+        }
+        else {
+            size_t count = 0;
+            for (Task* task : tasks) {
+                if (task->state() == state1 || task->state() == state2)
+                    count++;
+            }
+            if (count == tasks.size()) {
+                if (ecf_debug_enabled) {
+                    if (state2 == state1)
+                        std::cout << "    All tasks(" << tasks.size() << ") have reached state "
+                                  << NState::toString(state1) << " returning\n";
+                    else
+                        std::cout << "    All tasks(" << tasks.size() << ") have reached state "
+                                  << NState::toString(state1) << " || " << NState::toString(state2) << " returning\n";
+                    dump_tasks(tasks);
+                    dump_zombies();
+                }
+                return true;
+            }
+        }
+
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            if (ecf_debug_enabled) {
+                dump_zombies();
+                dump_tasks(tasks);
+                std::cout << "waitForTaskState " << wait_type_str << " reach state " << NState::toString(state1)
+                          << " || " << NState::toString(state2) << " Test taking longer than time constraint of "
+                          << assertTimer.timeConstraint() << " returning false\n";
+            }
+            break;
+        }
+        sleep(1);
+    }
+    dump_zombies();
+    return false;
+}
+
+static bool waitForTaskState(WaitType wait_type, NState::State state1, int max_time_to_wait) {
+    return waitForTaskStates(wait_type, state1, state1, max_time_to_wait);
+}
+
+static bool waitForZombieCreation(size_t no_of_zombies, int max_time_to_wait) {
+    if (ecf_debug_enabled)
+        std::cout << "\n   Waiting for " << no_of_zombies
+                  << " zombies to be created. max_time_to_wait:" << max_time_to_wait << "s\n";
+
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
+                              "zombieGet failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        if (zombies.size() >= no_of_zombies) {
+            if (ecf_debug_enabled) {
+                std::cout << Zombie::pretty_print(zombies, 3);
+                std::cout << "     Found " << no_of_zombies << " zombies. returning after " << assertTimer.duration()
+                          << "s\n";
+            }
+            return true;
+        }
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            if (zombies.size() > 0) {
+                if (ecf_debug_enabled) {
+                    std::cout << "   *Timeout* out found only " << zombies.size() << " zombies."
+                              << " Quit waiting.\n";
+                    std::cout << Zombie::pretty_print(zombies, 3);
+                }
+                return true;
+            }
+
+            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                                  "\n*error* waitForZombieCreation expected "
+                                      << no_of_zombies << " zombies but found "
+                                      << TestFixture::client().server_reply().zombies().size()
+                                      << " : Test taking longer than time constraint of "
+                                      << assertTimer.timeConstraint() << "s aborting\n"
+                                      << dump_task_status());
+            break;
+        }
+        sleep(1);
+    }
+    return false;
+}
+
+static void remove_stale_zombies() {
+    // Remove those zombies that have only *ZERO* calls hence PID is empty
+    // There is no associated process/child command that has updated the zombie
+    if (ecf_debug_enabled)
+        cout << "\n   remove_stale_zombies\n";
+
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
+                          "*error* zombieGet failed should return 0\n"
+                              << TestFixture::client().errorMsg());
+    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+    for (const Zombie& z : zombies) {
+        if (z.process_or_remote_id().empty()) {
+            cout << "\n      **** removing_stale_zombies ***** " << z << "\n";
+            cout << "        Typically happens when a submitted job, never creates a process ?\n";
+            cout << "        Since the process never communicated back, the pid is empty.\n";
+            TestFixture::client().zombieRemove(z);
+        }
+    }
+}
+
+static void wait_for_zombies_of_type(Child::ZombieType zt, int no_of_tasks, int max_time_to_wait) {
+    if (ecf_debug_enabled)
+        cout << "\n   wait_for_zombies_of_type: " << Child::to_string(zt) << " no_of_tasks:" << no_of_tasks
+             << " max_time_to_wait:" << max_time_to_wait << "s\n";
+
+    std::vector<Zombie> zombies;
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
+                              "*error* zombieGet failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        zombies           = TestFixture::client().server_reply().zombies();
+        int no_of_zombies = 0;
+        for (const Zombie& z : zombies) {
+            if (z.type() == zt)
+                no_of_zombies++;
+        }
+        if (no_of_zombies >= no_of_tasks)
+            break;
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            // BOOST_WARN_MESSAGE(assertTimer.duration() <  assertTimer.timeConstraint(),
+            std::cout << "wait_for_zombies_of_type. Expected " << no_of_tasks << " " << Child::to_string(zt)
+                      << " zombies, but found " << no_of_zombies << "\nTest taking longer than time constraint of "
+                      << assertTimer.timeConstraint() << "\n"
+                      << Zombie::pretty_print(zombies, 6) << "\n"
+                      << dump_task_status() << "\n"
+                      << "... breaking out\n";
+            return;
+        }
+        sleep(1);
+    }
+
+    if (ecf_debug_enabled) {
+        cout << Zombie::pretty_print(zombies, 6) << "\n";
+        cout << dump_task_status();
+    }
+}
+
+static void check_expected_no_of_zombies(size_t expected) {
+    if (ecf_debug_enabled)
+        cout << "   check_expected_no_of_zombies: " << expected << "\n";
+    TestFixture::client().zombieGet();
+    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+
+    BOOST_CHECK_MESSAGE(zombies.size() == expected,
+                        "*error* Expected " << expected << " zombies but got " << zombies.size());
+    if (zombies.size() != expected) {
+        std::cout << Zombie::pretty_print(zombies, 6);
+    }
+}
+
+static void check_expected_no_of_zombies_range(size_t min_expected, size_t max_expected) {
+    if (ecf_debug_enabled)
+        cout << "   check_expected_no_of_zombies_range: min:" << min_expected << " max:" << max_expected << "\n";
+    TestFixture::client().zombieGet();
+    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+
+    bool in_range = (zombies.size() >= min_expected && zombies.size() <= max_expected);
+    BOOST_CHECK_MESSAGE(in_range,
+                        "*error* Expected range(" << min_expected << "-" << max_expected << ") zombies but got "
+                                                  << zombies.size());
+    if (!in_range) {
+        std::cout << Zombie::pretty_print(zombies, 6);
+    }
+}
+
+static int check_at_least_one_zombie() {
+    TestFixture::client().zombieGet();
+    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+    if (ecf_debug_enabled) {
+        std::cout << "\n   check_at_least_one_zombie: actual " << zombies.size() << "\n";
+        std::cout << Zombie::pretty_print(zombies, 6);
+    }
+    BOOST_CHECK_MESSAGE(zombies.size() >= 1, "*error* Expected at least one zombies but got nothing\n");
+    return zombies.size();
+}
+
+static bool wait_for_zombie_termination(int max_time_to_wait) {
+    if (ecf_debug_enabled)
+        std::cout << "\n   wait_for_zombie_termination: max_time_to_wait:" << max_time_to_wait << "\n";
+
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        TestFixture::client().zombieGet();
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        if (zombies.empty()) {
+            if (ecf_debug_enabled)
+                cout << "      zombies empty. Waited for " << assertTimer.duration() << "s returning\n";
+            break;
+        }
+
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            if (ecf_debug_enabled) {
+                std::cout << "      wait_for_zombie_termination: taking longer than time constraint of "
+                          << assertTimer.timeConstraint() << " returning\n";
+                std::cout << Zombie::pretty_print(zombies, 6);
+            }
+            return false;
+        }
+        sleep(1);
+    }
+    return true;
+}
+
+static void wait_for_zombies_child_cmd(WaitType wait_type,
+                                       ecf::Child::CmdType child_cmd,
+                                       int max_time_to_wait,
+                                       bool do_delete = false) {
+    if (ecf_debug_enabled) {
+        std::cout << "\n   Waiting for ";
+        if (wait_type == SINGLE)
+            std::cout << "SINGLE";
+        else
+            std::cout << "ALL";
+        std::cout << "  child (" << Child::to_string(child_cmd) << ") cmd; ";
+        if (do_delete)
+            std::cout << " then DELETE zombies ";
+        std::cout << "=============================================================================================\n";
+    }
+
+    bool child_type_found = false;
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        TestFixture::client().zombieGet();
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        if (ecf_debug_enabled)
+            std::cout << "    Get zombies returned " << zombies.size() << "\n";
+
+        if (zombies.empty() && child_type_found && do_delete) {
+            if (ecf_debug_enabled)
+                std::cout << "   No zombies. (do_delete) was set returning\n";
+            return;
+        }
+
+        size_t completed_zombies = 0;
+        for (const Zombie& z : zombies) {
+            if (ecf_debug_enabled)
+                std::cout << "   " << z << "\n";
+            if (z.last_child_cmd() == child_cmd) {
+                child_type_found = true;
+                completed_zombies++;
+                if (wait_type == SINGLE) {
+                    if (ecf_debug_enabled) {
+                        std::cout << "   " << z << "\n";
+                        std::cout << "   Found SINGLE zombie of correct child type returning\n";
+                    }
+                    return;
+                }
+            }
+        }
+
+        if (completed_zombies == zombies.size() && child_type_found) {
+            if (ecf_debug_enabled) {
+                std::cout << "   Found ALL(" << completed_zombies << ") zombies of child type "
+                          << Child::to_string(child_cmd) << "\n";
+                std::cout << Zombie::pretty_print(zombies, 6);
+            }
+            if (do_delete) {
+                for (const Zombie& z : zombies) {
+                    if (ecf_debug_enabled)
+                        std::cout << "   deleteing " << z << "\n";
+                    TestFixture::client().zombieRemove(z);
+                }
+            }
+            return;
+        }
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            std::cout << Zombie::pretty_print(zombies, 3);
+            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                                  "*error* wait_for_zombies_child_cmd Test wait "
+                                      << assertTimer.duration() << " taking longer than time constraint of "
+                                      << assertTimer.timeConstraint() << " aborting\n");
+        }
+        sleep(1);
+    }
+}
+
+static void wait_for_no_zombies(int max_time_to_wait) {
+    if (ecf_debug_enabled)
+        std::cout << "\n   wait_for_no_zombies, for " << max_time_to_wait << "s\n";
+
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        TestFixture::client().zombieGet();
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        if (ecf_debug_enabled) {
+            std::cout << "      Get zombies returned " << zombies.size() << "\n";
+            if (!zombies.empty())
+                std::cout << Zombie::pretty_print(zombies, 6) << "\n";
+        }
+        if (zombies.empty()) {
+            if (ecf_debug_enabled)
+                std::cout << "      returning after " << assertTimer.duration() << "s\n";
+            return;
+        }
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            std::cout << "\n" << Zombie::pretty_print(zombies, 6);
+            BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(),
+                                  "*error* wait_for_no_zombies Test wait "
+                                      << assertTimer.duration() << " taking longer than time constraint of "
+                                      << assertTimer.timeConstraint() << " aborting\n");
+        }
+        sleep(2);
+    }
+}
+
+static void populate_defs(Defs& theDefs, const std::string& suite_name) {
+    suite_ptr suite = theDefs.add_suite(suite_name);
+    suite->addVariable(Variable("SLEEPTIME", "5")); // sleep for longer than normal to allow for creation of zombies
+    family_ptr family = suite->add_family("f");
+    for (int i = 0; i < NUM_OF_TASKS; i++) {
+        family->add_task("t" + ecf::convert_to<std::string>(i));
+    }
+    suite->add_variable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL", "_any_");
+}
+
+static void
+create_and_start_test(Defs& theDefs, const std::string& suite_name, const std::string& create_zombies_with) {
+    if (ecf_debug_enabled) {
+        std::cout << "   create_and_start_test  " << suite_name << "  using  " << create_zombies_with << "\n";
+    }
+
+    /// Avoid side effects from previous test, by removing all zombies
+    TestFixture::client().zombieGet();
+    if (!TestFixture::client().server_reply().zombies().empty()) {
+        (void)ZombieUtil::do_zombie_user_action(
+            User::REMOVE, TestFixture::client().server_reply().zombies().size(), timeout);
+    }
+
+    if (ecf_debug_enabled)
+        std::cout << "   creating server test harness\n";
+
+    // The test harness will create corresponding directory structure & default ecf file
+    ServerTestHarness serverTestHarness;
+    serverTestHarness.run(theDefs,
+                          ServerTestHarness::testDataDefsLocation(suite_name + ".def"),
+                          1 /*timeout*/,
+                          false /* don't wait for test to finish */);
+
+    // Wait for a single task to reach state submitted or active, before creating zombies
+    waitForTaskStates(SINGLE, NState::SUBMITTED, NState::ACTIVE, timeout);
+
+    // ******************************************************************************
+    // IMPORTANT: If Job generation takes to long i.e >= next poll then it will TIMEOUT.
+    //            Hence use the number of submitted/active tasks, as the expected number of zombies.
+    //            This must be done before creating zombies by changing state.
+    // *******************************************************************************
+    size_t number_submitted_or_active = 0;
+    TestFixture::client().sync_local();
+    defs_ptr defs = TestFixture::client().defs();
+    vector<Task*> tasks;
+    defs->getAllTasks(tasks);
+    for (const auto& task : tasks) {
+        if (task->state() == NState::SUBMITTED || task->state() == NState::ACTIVE)
+            number_submitted_or_active++;
+    }
+    if (ecf_debug_enabled)
+        std::cout << "   found " << number_submitted_or_active << " in submitted or active state\n";
+
+    if (create_zombies_with == "delete") {
+        if (ecf_debug_enabled)
+            std::cout << "   create USER zombies by deleting all the nodes in the server\n";
+        TestFixture::client().delete_all(true /* force */);
+    }
+    else if (create_zombies_with == "begin") {
+        /// Begin with force, Should create user zombies. WILL only catch those task that are submitted
+        /// It may well be that job submission, may only get a subset, others, which come for submission *later*
+        /// on will be ECF zombies.
+        /// Note: If we wait for SUMBITTED, then we get the case, where we have two task jobs
+        ///       with same password, BUT different process id ??????
+        ///       i.e The begin has regenerate the job file, so we get job started twice.
+        ///       This should be trapped by the server, as Task should be active
+        if (ecf_debug_enabled) {
+            std::cout
+                << "   Calling begin_all_suites, now have 2 sets of jobs, The first/original set are now zombies\n";
+            std::cout << "   - Second set of jobs can fail on creation with (Text File busy),\n";
+            std::cout
+                << "     since server is creating a new job file, whilst zombie process in running the same job file\n";
+            std::cout << "   - The first set can fail, because process not created, but server and has created 2nd job "
+                         "file(same path),\n";
+            std::cout << "     but not made it executable yet. Hence expect (exited with status 126) i.e exe' found "
+                         "but not executable\n";
+        }
+        TestFixture::client().set_throw_on_error(false);
+        if (TestFixture::client().begin_all_suites(true /* force */) == 1) {
+            std::cout << "   Begin raised exception: because " << TestFixture::client().errorMsg() << " ***\n";
+        }
+        TestFixture::client().set_throw_on_error(true);
+    }
+    else if (create_zombies_with == "queued") {
+        if (ecf_debug_enabled) {
+            std::cout << "   Creating zombies by setting all tasks to queued\n";
+            std::cout
+                << "   This should increment the try number, avoiding (Text File busy) and (exited with status 126)\n";
+            std::cout
+                << "   Zombies(first set) will have try_no:1 and the queued tasks(second set) will have try number2\n";
+        }
+        std::vector<Task*> tasks;
+        theDefs.getAllTasks(tasks);
+        std::vector<std::string> paths;
+        for (auto task : tasks)
+            paths.emplace_back(task->absNodePath());
+
+        TestFixture::client().set_throw_on_error(false);
+        if (TestFixture::client().force(paths, "queued") == 1) {
+            std::cout << "   force queued raised exception: because " << TestFixture::client().errorMsg() << " ***\n";
+        }
+        TestFixture::client().set_throw_on_error(true);
+    }
+    else if (create_zombies_with == "complete") {
+
+        if (ecf_debug_enabled)
+            std::cout << "   create USER zombies by calling complete\n";
+        std::string path = "/" + suite_name;
+        TestFixture::client().force(path, "complete", true /*recursive*/);
+    }
+    else if (create_zombies_with == "aborted") {
+
+        if (ecf_debug_enabled)
+            std::cout << "   create USER zombies by calling abort\n";
+        std::string path = "/" + suite_name;
+        TestFixture::client().force(path, "aborted", true /*recursive*/);
+    }
+    else {
+        BOOST_REQUIRE_MESSAGE(false, "*error* Create zombies via " << create_zombies_with << " unrecognised");
+    }
+
+    /// When jobs try to communicate with server via child commands they will block the Child commands
+    if (waitForZombieCreation(number_submitted_or_active, timeout)) {
+
+        /// Check we have zombies and they are of type USER
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        BOOST_CHECK_MESSAGE(zombies.size() > 0, "*error* NO zombies created");
+        for (const Zombie& z : zombies) {
+            if (create_zombies_with == "begin") {
+                BOOST_CHECK_MESSAGE(z.type() == Child::USER,
+                                    "*error* Creating zombies via begin, Expected 'user' zombie type but got: " << z);
+            }
+            else if (create_zombies_with == "queued") {
+                BOOST_CHECK_MESSAGE(z.type() == Child::USER,
+                                    "*error* Creating zombies via queued, Expected 'user' zombie type but got: " << z);
+            }
+            else if (create_zombies_with == "delete") {
+                BOOST_CHECK_MESSAGE(
+                    z.type() == Child::USER || z.type() == Child::PATH,
+                    "*error* Creating zombies via delete, Expected 'user | path' zombie type but got: " << z);
+            }
+            else if (create_zombies_with == "complete") {
+                BOOST_CHECK_MESSAGE(z.type() == Child::USER, "*error* Expected 'user' zombie type but got: " << z);
+            }
+            else if (create_zombies_with == "aborted") {
+                BOOST_CHECK_MESSAGE(z.type() == Child::USER, "*error* Expected 'user' zombie type but got: " << z);
+            }
+            else {
+                BOOST_CHECK_MESSAGE(z.type() == Child::ECF, "*error* Expected 'ecf' zombie type but got: " << z);
+            }
+        }
+    }
+    if (ecf_debug_enabled) {
+        cout << dump_task_status();
+    }
+}
+
+static void create_and_start_test(const std::string& suite_name,
+                                  const std::string& create_zombies_with,
+                                  bool add_delay_before_init = false) {
+
+    if (ecf_debug_enabled) {
+        TestFixture::client().get_log_path();
+        std::cout << "\n   Creating defs, log path " << TestFixture::client().get_string() << "\n";
+    }
+    Defs theDefs;
+    populate_defs(theDefs, suite_name);
+    if (add_delay_before_init) {
+        suite_ptr suite = theDefs.findSuite(suite_name);
+        suite->add_variable("ADD_DELAY_BEFORE_INIT", "sleep 1"); // add delay before --init
+        if (ecf_debug_enabled)
+            std::cout << "   adding a delay of 1 second before --init is called\n";
+    }
+    create_and_start_test(theDefs, suite_name, create_zombies_with);
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+BOOST_AUTO_TEST_CASE(enable_debug_for_ECF_TRY_NO_Greater_than_one) {
+    BOOST_CHECK_MESSAGE(true, "dummy test");
+
+    if (getenv("ECF_DEBUG_ZOMBIES")) {
+        ecf_debug_enabled = true;
+        cout << "Test:: ... debug_enabled" << endl;
+    }
+}
+
+#ifdef DO_TEST1
+BOOST_AUTO_TEST_CASE(test_path_zombie_creation) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    cout << "Test:: ...test_path_zombie_creation " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    // User zombies will be converted to path zombies by the server
+    create_and_start_test("test_path_zombie_creation", "delete"); // create zombie via delete
+
+    // The job generation can timeout, hence we may not have submitted the full number of tasks & hence expected zombies
+    // can vary
+    check_expected_no_of_zombies_range(1, NUM_OF_TASKS);
+
+    // The server will automatically change existing zombie to be of type PATH
+    // when no task nodes exists
+    // *Note* in test environment the client invoker will try connecting to the server
+    // ****** for 5 seconds, after that an error is returned. This will cause the
+    // ****** job to abort.
+    wait_for_zombies_of_type(Child::PATH, NUM_OF_TASKS, timeout);
+
+    // Fob all the zombies. This will UNBLOCK the child commands allowing them to complete
+    // Fobing does *NOT* alter node tree state, however COMPLETE should auto delete the zombie
+    // Hence after this command, the number of fobed zombies may *NOT* be the same
+    // as the number of tasks. Since the fobed zombies are auto deleted when a complete
+    // child command is received.
+    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
+    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
+
+    // Wait for zombies to be deleted in the server
+    if (!wait_for_zombie_termination(timeout)) {
+        remove_stale_zombies();
+    }
+
+    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
+    check_expected_no_of_zombies(0);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST2
+BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fob) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    cout << "Test:: ...test_user_zombies_for_delete_fob " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    // User zombies will be converted to path zombies by the server
+    create_and_start_test(
+        "test_user_zombies_for_delete_fob", "delete", true /* add a delay before init */); // create zombie via delete
+
+    // expect at least one zombie
+    (void)check_at_least_one_zombie();
+
+    // Fob all the zombies. This will UNBLOCK the child commands allowing them to finish
+    // Fobing does *NOT* alter node tree state, however COMPLETE should auto delete the zombie
+    // Hence after this command, the number of fobed zombies may *NOT* be the same
+    // as the number of tasks. Since the fobed zombies are auto deleted when a complete
+    // child command is recieved.
+    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
+    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
+
+    // Wait for zombies to be deleted in the server
+    if (!wait_for_zombie_termination(timeout)) {
+        remove_stale_zombies(); // see notes above
+    }
+
+    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
+    check_expected_no_of_zombies(0);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST3
+BOOST_AUTO_TEST_CASE(test_user_zombies_for_delete_fail) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    cout << "Test:: ...test_user_zombies_for_delete_fail " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    // User zombies will be converted to path zombies by the server
+    create_and_start_test("test_user_zombies_for_delete_fail", "delete");
+
+    check_at_least_one_zombie();
+
+    // Fail all the zombies. This will UNBLOCK and terminate the child commands allowing them to finish
+    int no_of_failed_zombies = ZombieUtil::do_zombie_user_action(User::FAIL, NUM_OF_TASKS, timeout);
+    BOOST_CHECK_MESSAGE(no_of_failed_zombies > 0, "*error* Expected > 0 Failed zombies but found none");
+
+    check_at_least_one_zombie();
+
+    // Wait for zombies to abort, then remove all the zombies
+    wait_for_zombies_child_cmd(ALL, ecf::Child::ABORT, timeout, true /* delete */);
+
+    check_expected_no_of_zombies(0);
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+// test_zombies_attr_for_begin/f/t1 user 26 ZzD/ycIW <pid> 1 calls(1) BLOCK INIT
+
+#ifdef DO_TEST4
+BOOST_AUTO_TEST_CASE(test_user_zombies_for_begin) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    cout << "Test:: ...test_user_zombies_for_begin " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    // Note: if when we start to create zombies and some tasks are still queued *NOT* all will be zombies.
+    create_and_start_test("test_user_zombies_for_begin", "begin");
+
+    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete or abort
+    /// The second set can still abort, if the first set are busy with job file. look for '(Text file busy)'
+    /// Previously we had tried again, but fix for ECFLOW-1216, means we now don't try again,hence allow abort
+    BOOST_REQUIRE_MESSAGE(waitForTaskStates(ALL, NState::COMPLETE, NState::ABORTED, timeout),
+                          "*error* Expected non-zombie tasks to complete or abort");
+
+    // Note: if when we started to create zombies and some tasks are still queued *NOT* all will be zombies.
+    int no_of_zombies = check_at_least_one_zombie();
+
+    // Fob all the zombies. This will UNBLOCK the child commands allowing them to finish
+    // Hence after this command, the number of fobed zombies may *NOT* be the same
+    // as the number of tasks. Since the fobed zombies are auto deleted when a complete
+    // child command is received.
+    //
+    /// When we have two sets of completes, we just fob, automatically. See TaskCmd::authenticate
+    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, no_of_zombies, timeout);
+    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
+
+    // Fobing does *NOT* alter node tree state, however child COMPLETE should auto delete the zombie
+    if (!wait_for_zombie_termination(timeout)) {
+        remove_stale_zombies(); // see notes above
+    }
+
+    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
+    check_expected_no_of_zombies(0);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST5
+BOOST_AUTO_TEST_CASE(test_zombies_attr) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_zombies_attr";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    create_and_start_test(
+        suite_name, "queued", true /* add a delay before init */); // create zombies re-queuing submitted/active tasks
+
+    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete or abort
+    /// Creating zombies by queuing submitted/active tasks, increments try number of the second set.
+    /// This avoid text file busy,(i.e by using begin/requeue creating a job file, whilst its already running)
+    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
+                          "*error* Expected non-zombie tasks to complete");
+
+    check_at_least_one_zombie();
+
+    /// *** Fobbing will not change state of the node tree ****
+    if (ecf_debug_enabled)
+        std::cout << "   Add a zombie attribute 'user:fob::' to the suite, which fobs all child commands\n";
+    TestFixture::client().alter("/" + suite_name, "add", "zombie", "user:fob::");
+
+    // Fobbing causes auto deletion of zombies, when the Child complete is reached
+    if (!wait_for_zombie_termination(timeout)) {
+        remove_stale_zombies(); // see notes above
+    }
+
+    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was recieved
+    check_expected_no_of_zombies(0);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST6
+BOOST_AUTO_TEST_CASE(test_user_zombies_for_adopt) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_user_zombies_for_adopt";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    // Using "queued" to create zombies will mean we update try_no, zombies will not share output.
+    // This avoid'(Text file busy)'
+    create_and_start_test(suite_name, "queued", true /* add delay before init */);
+
+    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete
+    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
+                          "*error* Expected non-zombie tasks to complete");
+
+    check_at_least_one_zombie();
+
+    /// Adopt all the zombies. This will UNBLOCK the child commands allowing them to finish
+    /// This test below fail on AIX, its too fast , task's may already be adopted and hence don't fail
+    int no_of_adopted_zombied = ZombieUtil::do_zombie_user_action(User::ADOPT, NUM_OF_TASKS, timeout);
+    if (ecf_debug_enabled)
+        cout << "   found " << no_of_adopted_zombied << " zombies for adoption\n";
+
+    /// The blocked zombies are free, start with blocked init command
+    (void)waitForTaskState(SINGLE, NState::ACTIVE, timeout);
+
+    /// Now wait for all tasks to complete
+    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
+                          "*error* Expected zombie tasks to complete");
+
+    remove_stale_zombies(); // see notes above
+
+    // After adoption the zombies should be removed
+    check_expected_no_of_zombies(0);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST7
+BOOST_AUTO_TEST_CASE(test_zombies_attr_for_adopt) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_zombies_attr_for_adopt";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    create_and_start_test(suite_name, "queued", true /* add a delay before init */);
+
+    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete
+    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
+                          "*error* Expected non-zombie tasks to complete");
+
+    // expected 5 zombies, ie because we have NUM_OF_TASKS tasks. These should all be blocking
+    check_at_least_one_zombie();
+
+    if (ecf_debug_enabled)
+        std::cout << "   Add a zombie attribute 'user:adopt::' to the suite, which *ADOPTS* all zombies allowing them "
+                     "to complete\n";
+    TestFixture::client().alter("/" + suite_name, "add", "zombie", "user:adopt::");
+
+    if (ecf_debug_enabled)
+        dump_zombies();
+
+    /// The blocked zombies are free, start with blocked init command
+    /// This may fail on AIX, its too fast , task's may already be complete, dont fail
+    (void)waitForTaskState(SINGLE, NState::ACTIVE, timeout);
+
+    /// Now wait for all tasks to complete. ** They may be complete from last process set **
+    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
+                          "*error* Expected all zombie task to complete after adopt");
+
+    remove_stale_zombies(); // see notes above
+
+    // After adoption the zombies should be removed
+    check_expected_no_of_zombies(0);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST8
+BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_complete) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_user_zombie_creation_via_complete";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    create_and_start_test(suite_name, "complete");
+
+    /// Since we have set tasks to complete, we should only have *ONE* set of zombies
+    check_at_least_one_zombie();
+
+    // Fob all the zombies child commands allowing them to finish
+    (void)ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
+
+    // Wait for zombies to complete, they should get removed automatically
+    wait_for_no_zombies(timeout);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST9
+BOOST_AUTO_TEST_CASE(test_user_zombie_creation_via_abort) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_user_zombie_creation_via_abort";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    create_and_start_test(suite_name, "aborted");
+
+    /// Since we have set tasks to complete, we should only have *ONE* set of zombies
+    check_at_least_one_zombie();
+
+    // Fob all the zombies child commands allowing them to finish
+    (void)ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
+
+    // Wait for zombies to complete, they should get removed automatically
+    wait_for_no_zombies(timeout);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST10
+BOOST_AUTO_TEST_CASE(test_zombie_inheritance) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_zombie_inheritance";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // Add zombie attribute, make sure it inherited
+    Defs theDefs;
+    populate_defs(theDefs, suite_name);
+    suite_ptr suite = theDefs.findSuite(suite_name);
+    suite->addZombie(ZombieAttr(ecf::Child::USER, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
+    suite->addZombie(ZombieAttr(ecf::Child::ECF, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
+    suite->addZombie(ZombieAttr(ecf::Child::ECF_PID, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
+    suite->addZombie(ZombieAttr(ecf::Child::ECF_PID_PASSWD, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
+    suite->addZombie(ZombieAttr(ecf::Child::ECF_PASSWD, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
+    suite->addZombie(ZombieAttr(ecf::Child::PATH, std::vector<ecf::Child::CmdType>(), ecf::User::FOB, -1));
+
+    create_and_start_test(theDefs, suite_name, "complete");
+
+    /// Since we have set tasks to complete, we should only have *ONE* set of zombies
+    // expect NUM_OF_TASKS zombies, ie because we have NUM_OF_TASKS tasks
+    TestFixture::client().set_throw_on_error(true);
+    TestFixture::client().zombieGet();
+    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+    BOOST_CHECK_MESSAGE(!zombies.empty(), "No zombies found");
+    for (const Zombie& z : zombies) {
+        BOOST_CHECK_MESSAGE(z.user_action() == ecf::User::FOB,
+                            "*error* Expected zombies with user action of type FOB but found "
+                                << User::to_string(z.user_action()));
+        break;
+    }
+
+    // Wait for zombies to complete, they should get removed automatically
+    wait_for_no_zombies(timeout);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST11
+static int wait_for_killed_zombies(int no_of_tasks, int max_time_to_wait) {
+    if (ecf_debug_enabled)
+        std::cout << "\n   wait_for_killed_zombies\n";
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (1) {
+        int killed = 0;
+        TestFixture::client().zombieGet();
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        for (const Zombie& z : zombies) {
+            if (z.kill())
+                killed++;
+        }
+        if (ecf_debug_enabled)
+            std::cout << "   found " << killed << " killed zombies\n";
+
+        if (killed == no_of_tasks)
+            return killed;
+
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            cout << "   wait_for_killed_zombies Test wait " << assertTimer.duration()
+                 << " taking longer than time constraint of " << assertTimer.timeConstraint() << " breaking out\n"
+                 << Zombie::pretty_print(zombies, 6) << "\n";
+            return killed;
+        }
+        sleep(2);
+    }
+    return 0;
+}
+
+BOOST_AUTO_TEST_CASE(test_zombie_kill) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_zombie_kill";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // This command creates user zombies up front, these may not have a pid, if task in submitted state
+    create_and_start_test(suite_name, "complete");
+
+    check_at_least_one_zombie();
+
+    // kill all the zombies, i.e kill -15 on the script
+    // This will be trapped by the signal and hence will call abort
+    (void)ZombieUtil::do_zombie_user_action(User::KILL, NUM_OF_TASKS, timeout);
+
+    // wait for kill zombies. This should eventually lead to process terminating
+    int killed = wait_for_killed_zombies(NUM_OF_TASKS, timeout);
+    BOOST_CHECK_MESSAGE(killed > 0, "*error* Expected " << NUM_OF_TASKS << " killed ");
+
+    {
+        // wait for process to be killed: killing is a separate process, we could well
+        // have got to the complete, before the process is killed.
+        // Once the complete is fobed it terminate the process.
+        AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
+        while (1) {
+            int completed = 0;
+            int aborted   = 0;
+            TestFixture::client().zombieGet();
+            std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+            for (const Zombie& z : zombies) {
+                if (z.last_child_cmd() == ecf::Child::ABORT)
+                    aborted++;
+                if (z.last_child_cmd() == ecf::Child::COMPLETE)
+                    completed++;
+            }
+            if (aborted + completed == NUM_OF_TASKS)
+                break;
+            if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+                cout << "   wait for for abort:  found " << aborted + completed
+                     << " aborted & completed tasks. Test wait " << assertTimer.duration()
+                     << " taking longer than time constraint of " << assertTimer.timeConstraint() << " breaking out\n"
+                     << Zombie::pretty_print(zombies, 6) << "\n";
+                break;
+            }
+            sleep(1);
+        }
+    }
+    {
+        bool task_became_blocked = false;
+        // wait for process to be die
+        AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
+        while (1) {
+            TestFixture::client().zombieGet();
+            std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+            for (const Zombie& z : zombies) {
+                if (z.block()) { // something went wrong, fob so don't leave process hanging
+                    TestFixture::client().zombieFob(z);
+                    task_became_blocked = true;
+                    cout << "Zombies blocking ?? " << z << "\n";
+                }
+            }
+            if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+                if (task_became_blocked) {
+                    cout << "   Task became blocked, fobing" << assertTimer.duration()
+                         << " taking longer than time constraint of " << assertTimer.timeConstraint()
+                         << " breaking out\n"
+                         << Zombie::pretty_print(zombies, 6) << "\n";
+                }
+                break;
+            }
+            sleep(1);
+        }
+    }
+
+    // remove the killed zombies
+    (void)ZombieUtil::do_zombie_user_action(User::REMOVE, NUM_OF_TASKS, timeout, false);
+
+    wait_for_no_zombies(timeout);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+#ifdef DO_TEST12
+
+static void remove_all_user_zombies() {
+    if (ecf_debug_enabled) {
+        cout << "\n   remove_all_user_zombies\n";
+        dump_zombies();
+    }
+
+    int removed_count = 0;
+    AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
+    while (removed_count < NUM_OF_TASKS) {
+        TestFixture::client().zombieGet();
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        for (const Zombie& z : zombies) {
+            if (z.type() == ecf::Child::USER) {
+                TestFixture::client().zombieRemove(z); // This should be immediate, and is not remembered
+                removed_count++;
+            }
+        }
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            cout << "      removed " << removed_count
+                 << " user zombies. Quit waiting, to remove all zombies of type USER\n";
+            cout << Zombie::pretty_print(zombies, 6);
+            return;
+        }
+        sleep(1);
+    }
+    if (ecf_debug_enabled)
+        dump_zombies();
+}
+BOOST_AUTO_TEST_CASE(test_ecf_zombie_type_creation) {
+    if (ecf_debug_enabled)
+        std::cout << "\n\n=============================================================================\n";
+    DurationTimer timer;
+    std::string suite_name = "test_ecf_zombie_type_creation";
+    cout << "Test:: ..." << suite_name << " " << flush;
+    if (ecf_debug_enabled)
+        cout << "\n";
+    TestClean clean_at_start_and_end;
+
+    // some systems are really quick, where tasks are already active, when we make them zombies, then the next
+    // client command in the zombie is: --complete. This distorts the test. Since if the real task is complete and
+    // we get a zombie with --complete, the server lets it through and the zombie process terminates.
+    // To get round this we will introduce a delay, before we get --init
+    create_and_start_test(suite_name, "queued", true /* add a delay before init */);
+
+    /// We have two *sets* of jobs, Wait for ALL the tasks(non zombies) to complete
+    BOOST_REQUIRE_MESSAGE(waitForTaskState(ALL, NState::COMPLETE, timeout),
+                          "*error* Expected non-zombie tasks to complete");
+
+    // wait and remove all *USER* zombies.
+    remove_all_user_zombies();
+
+    // wait of at least *ONE* zombie of type *ECF*
+    wait_for_zombies_of_type(Child::ECF, NUM_OF_TASKS, timeout);
+
+    int no_of_fobed_zombies = ZombieUtil::do_zombie_user_action(User::FOB, NUM_OF_TASKS, timeout);
+    BOOST_CHECK_MESSAGE(no_of_fobed_zombies > 0, "*error* Expected some fobed zombies but found none ?");
+
+    // Fobing does *NOT* alter node tree state, however child COMPLETE should auto delete the zombie
+    if (!wait_for_zombie_termination(timeout)) {
+        remove_stale_zombies(); // see notes above
+    }
+
+    // The fob should have forced removal of zombies, in the server. when the COMPLETE child command was received
+    check_expected_no_of_zombies(0);
+
+    cout << timer.duration() << "s\n";
+}
+#endif
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/test/TestZombies_main.cpp 5.13.0-1/libs/test/TestZombies_main.cpp
--- 5.12.4-1/libs/test/TestZombies_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/TestZombies_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_Zombies
+#include <boost/test/included/unit_test.hpp>
+
+#include "TestFixture.hpp"
+
+// Global test fixture.
+//
+// Note: Due to boost deficiency this can't be easily accessed, so TestFixture makes use of global data.
+//
+BOOST_GLOBAL_FIXTURE(TestFixture);
diff -pruN 5.12.4-1/libs/test/Test_main.cpp 5.13.0-1/libs/test/Test_main.cpp
--- 5.12.4-1/libs/test/Test_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/Test_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test
+#include <boost/test/included/unit_test.hpp>
+
+#include "TestFixture.hpp"
+
+// Global test fixture.
+//
+// Note: Due to boost deficiency this can't be easily accessed, so TestFixture makes use of global data.
+//
+BOOST_GLOBAL_FIXTURE(TestFixture);
diff -pruN 5.12.4-1/libs/test/data/.gitignore 5.13.0-1/libs/test/data/.gitignore
--- 5.12.4-1/libs/test/data/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/data/.gitignore	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,9 @@
+/ECF_HOME_debug
+/ECF_HOME_release
+/ECF_HOME_release_clang/
+/ECF_HOME_release_gnu/
+/ECF_HOME_release_intel/
+/ECF_HOME_debug_gnu/
+/ECF_HOME_release_gnu_python3/
+/ECF_HOME_release_gnu_shared/
+/ECF_HOME_release_gnu_ssl/
diff -pruN 5.12.4-1/libs/test/data/includes/bad_tail.h 5.13.0-1/libs/test/data/includes/bad_tail.h
--- 5.12.4-1/libs/test/data/includes/bad_tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/data/includes/bad_tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,30 @@
+#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #5 $
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# wait for background process to stop.
+# If we did not have background jobs, closly called foreround jobs
+# may arrive out of order at the server, causing unnecessary zombies
+# The wait should prevent this.
+wait
+
+# record shell time, see head.h
+%ecfmicro !
+finish_time=$(date +%s)
+!ecfmicro %
+echo "Job End: Time duration: $((finish_time - start_time)) secs."
+
+# Notify ECF of a normal end
+%ECF_CLIENT_EXE_PATH% --complete %COMPLETE_DEL_VARIABLES:%
+trap 0                          # Remove all traps
+exit 1                          # End the shell
+
diff -pruN 5.12.4-1/libs/test/data/includes/head.h 5.13.0-1/libs/test/data/includes/head.h
--- 5.12.4-1/libs/test/data/includes/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/data/includes/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,98 @@
+#!/bin/ksh
+#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #5 $ 
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0 
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+# In applying this licence, ECMWF does not waive the privileges and immunities 
+# granted to it by virtue of its status as an intergovernmental organisation 
+# nor does it submit to any jurisdiction. 
+#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+%manual
+#This is the manual from the head.h file
+%end
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+set -o pipefail # fail if last(rightmost) command exits with a non-zero status
+
+# record JOB time
+%ecfmicro !
+job_start_time=$(date +%s)
+!ecfmicro %
+
+# Defines the three variables that are needed for any
+# communication with ECF
+
+export ECF_PORT=%ECF_PORT%    # The port number on the ecflow server
+export ECF_HOST=%ECF_HOST:%   # The hostname where the server is running
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+#export ECF_DEBUG_CLIENT=1
+if [[ "%ECF_SSL:%" != "" ]] ; then
+   export ECF_SSL=%ECF_SSL:%   # if server is SSL make sure client is
+fi
+
+# SANITY Check, typically only valid for new platforms. make sure hostname is resolvable to an IP address
+# on Mac we get
+#   Host User-MacBook-Pro.local not found: 3(NXDOMAIN)
+# Should be using 'dig user-MacBook-Pro.local'
+os_name=$(uname -s)
+if [[ $os_name = Linux ]] ; then
+   host %ECF_HOST%
+fi
+
+# to debug client communication with the server, enable this environment
+#export ECF_DEBUG_CLIENT=1
+
+# Typically we dont set this, however the zombie automated test require this.
+# it allows us to disambiguate a zombie from a real job.
+export ECF_RID=$$
+
+# Tell ECF_ we have stated
+# The ECF_ variable ECF_RID will be set to parameter of smsinit
+# Here we give the current PID.
+
+
+
+# Defined a error hanlder
+ERROR() {
+	echo "ERROR() called"
+	set +e        # Clear -e flag, so we don't fail
+	wait          # wait for background process to stop
+   # when the following signals arrive do nothing, stops recursive signals/error function being called
+	trap 0 1 2 3 4 5 6 7 8 10 12 13 15
+   # Notify ECF_ that something went wrong
+	%ECF_CLIENT_EXE_PATH% --abort
+	trap 0        # Remove the trap
+	exit 0        # End the script
+}
+
+# Trap any calls to exit and errors caught by the -e flag
+
+trap ERROR 0
+
+# Trap any signal that may cause the script to fail
+
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
+
+%ADD_DELAY_BEFORE_INIT:% # ADD_DELAY_BEFORE_INIT is used by some tests, to slow things down on fast systems
+
+# record INIT time
+%ecfmicro !
+init_start_time=$(date +%s)
+!ecfmicro %
+
+%ECF_CLIENT_EXE_PATH% --init=$$ %INIT_ADD_VARIABLES:%
+
+# record TIME between init and complete
+%ecfmicro !
+start_time=$(date +%s)
+!ecfmicro %
+echo "Job start: *INIT* took : $((start_time - init_start_time)) secs"
diff -pruN 5.12.4-1/libs/test/data/includes/tail.h 5.13.0-1/libs/test/data/includes/tail.h
--- 5.12.4-1/libs/test/data/includes/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/data/includes/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,37 @@
+#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+# Name        :
+# Author      : Avi
+# Revision    : $Revision: #5 $ 
+#
+# Copyright 2009- ECMWF.
+# This software is licensed under the terms of the Apache Licence version 2.0 
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+# In applying this licence, ECMWF does not waive the privileges and immunities 
+# granted to it by virtue of its status as an intergovernmental organisation 
+# nor does it submit to any jurisdiction. 
+#/////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
+
+# wait for background process to stop.
+# If we did not have background jobs, closly called foreround jobs
+# may arrive out of order at the server, causing unnecessary zombies
+# The wait should prevent this.
+wait
+
+# record time between init and complete see head.h
+%ecfmicro !
+finish_time=$(date +%s)
+!ecfmicro %
+echo "Job End: Time duration: $((finish_time - start_time)) secs *BETWEEN* init and complete"
+
+# Notify ECF of a normal end
+%ECF_CLIENT_EXE_PATH% --complete %COMPLETE_DEL_VARIABLES:%
+
+%ecfmicro !
+job_finish_time=$(date +%s)
+!ecfmicro %
+echo "Job End: *COMPLETE*  took    : $((job_finish_time - finish_time)) secs"
+echo "Job End: *JOB* duration took : $((job_finish_time - job_start_time)) secs"
+
+trap 0                          # Remove all traps
+exit 0                          # End the shell
+
diff -pruN 5.12.4-1/libs/test/samples/cron.def 5.13.0-1/libs/test/samples/cron.def
--- 5.12.4-1/libs/test/samples/cron.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/samples/cron.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,105 @@
+suite cron
+
+   clock real  # Need real clock otherwise crons would be complete
+   task cron0
+      cron 00:25 23:59 00:30
+      
+   task cron1
+      cron -w 0 , 1, 2 -m 5, 6, 7 , 8,9,10      10:00  20:00  01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
+
+   task cron1_1
+      cron -w 0,1,2 -m 9,10  10:00  14:00  01:00  
+      
+   task cron2
+         cron 23:00                              # run every day at 23:00
+         
+   task cron3
+      cron 10:00 20:00 01:00                  # run every hour between 10am and 8pm
+      
+   task cron4
+      cron -w 0,1 10:00                       # run every sunday and monday at 10am
+      
+   task cron5
+      cron -d 10,11,12 12:00                  # run 10th, 11th and 12th of each month at noon
+      
+   task cron6
+      cron -m 1,2,3 12:00                     # run on Jan,Feb and March every day at noon.
+      
+   task cron7
+      cron -w 0,6 12:00
+      
+   task cron8
+      cron -w 0,1,2,3,4,5,6 12:00
+      
+   task cron9
+      cron -w 0 -m 5,6,7,8 10:00 20:00 01:00  # run every sunday, between May-Aug, every hour between 10am and 8pm
+   
+   task cron10
+      cron -w 0,1,2 -d 1,20,24 -m 5,6,7,8 10:00 20:00 01:00  #  
+
+
+   task cron11
+      cron 00:00 23:59 00:01  #  run every minute
+      
+   family f1
+      cron -d 22 12:00
+      task t1
+      task t2
+   endfamily
+   family f2
+      cron -d 8 12:00
+      task t1
+      task t2
+   endfamily
+   
+   family t1
+      task t1
+         cron 00:01
+         cron 23:59
+         
+     task t2
+         cron 09:00
+         cron 12:00
+
+     task t3
+         cron 12:00
+         cron 18:00
+
+     task t4
+         cron 18:00
+         cron 23:00
+         
+     task t5
+         cron 10:00
+    task t6
+         cron 11:00
+    task t7
+         cron 12:00
+    task t8
+         cron 13:00
+    task t9
+         cron 14:00
+    task t10
+         cron 15:00
+    task t11
+         cron 16:00
+    task t12
+         cron 17:00
+    task t13
+         cron 18:00
+    task t14
+         cron 19:00
+    task t15
+         cron 20:00
+    task t16
+         cron 21:00
+    task t17
+         cron 22:00
+    task t18
+         cron 23:00
+    task t19
+         cron 23:00
+    task t20
+         cron 00:00   
+   endfamily          
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/test/samples/time.def 5.13.0-1/libs/test/samples/time.def
--- 5.12.4-1/libs/test/samples/time.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/samples/time.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,84 @@
+suite time
+  clock real
+  family time_range
+   task t
+     time 07:00 23:00 00:30
+   task t2
+     cron 09:00 23:00 00:05
+   task t3
+     time 13:00
+   task t4
+     time 23:00
+   task t5
+      time 07:00
+      time 08:00
+      time 09:00
+      time 10:00
+      time 13:00
+      time 14:00
+      time 15:00
+      time 16:00
+      time 17:00
+    task every_minute
+     time 00:01 23:59 00:01
+     edit SLEEP 90          # task takes longer than one minute
+  endfamily
+   family t1
+      task t1
+         time 00:01
+         time 23:59
+         
+     task t2
+         time 09:00
+         time 12:00
+
+     task t3
+         time 12:00
+         time 18:00
+
+     task t4
+         time 18:00
+         time 23:00
+         
+     task t5_1
+         time 08:00
+    task t5
+         time 10:00
+    task t6
+         time 11:00
+    task t7
+         time 12:00
+    task t8
+         time 13:00
+         time 15:00
+    task t9
+         time 14:00
+    task t10
+         time 15:00
+    task t11
+         time 16:00
+         time 17:00
+         time 18:00
+         time 19:00
+         trigger 1 == 0
+    task t12
+         time 17:00
+    task t13
+         time 18:00
+    task t14
+         time 19:00
+    task t15
+         time 20:00
+    task t16
+         time 21:00
+    task t17
+         time 22:00
+    task t18
+         time 23:00
+    task t19
+         time 23:00
+         trigger 1 == 0
+    task t20
+         time 00:00
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/test/samples/today.def 5.13.0-1/libs/test/samples/today.def
--- 5.12.4-1/libs/test/samples/today.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/samples/today.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,75 @@
+suite today
+  clock real
+  family time_range
+   task t
+     today 07:00 23:00 00:30
+   task t2
+     today 09:00 23:00 00:05
+   task t3
+     today 13:00
+   task t4
+     today 23:00
+   task t5
+      today 09:00
+      today 13:00
+      today 14:00
+      today 15:00
+      today 16:00
+      today 17:00
+  endfamily
+   family t1
+      task t1
+         today 00:01
+         today 23:59
+      task t1_1
+         today 09:01
+         today 09:30
+     task t2
+         today 09:00
+         today 12:00
+     task t3
+         today 12:00
+         today 18:00
+     task t4
+         today 18:00
+         today 23:00
+     task t5
+         today 10:00
+     task t5_1
+         today 08:00    
+    task t6
+         today 11:00
+         today 11:30
+    task t7
+         today 12:00
+         today 12:30
+         today 13:30
+         today 14:30
+    task t8
+         today 13:00
+    task t9
+         today 14:00
+    task t10
+         today 15:00
+    task t11
+         today 16:00
+    task t12
+         today 17:00
+    task t13
+         today 18:00
+    task t14
+         today 19:00
+    task t15
+         today 20:00
+    task t16
+         today 21:00
+    task t17
+         today 22:00
+    task t18
+         today 23:00
+    task t19
+         today 23:00
+    task t20
+         today 00:00
+   endfamily
+endsuite
\ No newline at end of file
diff -pruN 5.12.4-1/libs/test/src/ServerTestHarness.cpp 5.13.0-1/libs/test/src/ServerTestHarness.cpp
--- 5.12.4-1/libs/test/src/ServerTestHarness.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/src/ServerTestHarness.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,583 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ServerTestHarness.hpp"
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestFixture.hpp"
+#include "ecflow/attribute/QueueAttr.hpp"
+#include "ecflow/base/WhyCmd.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/core/DurationTimer.hpp"
+#include "ecflow/core/Ecf.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Family.hpp"
+#include "ecflow/node/Suite.hpp"
+#include "ecflow/node/Task.hpp"
+
+using namespace std;
+using namespace ecf;
+
+// #define DEBUG_TEST_WAITER 1
+// #define DEBUG_TEST_WAITER_DEFS 1
+// #define DEBUG_TEST_HARNESS 1
+// #define DEBUG_DIFF 1
+
+ServerTestHarness::ServerTestHarness() : print_style_(PrintStyle::STATE) {
+}
+
+void ServerTestHarness::run(Defs& theClientDefs,
+                            const std::string& defs_filename,
+                            const std::map<std::string, std::string>& customTaskSmsMap,
+                            int timeout,
+                            bool waitForTestCompletion) {
+    defs_filename_ = defs_filename;
+
+    /// RUN the TEST
+    defs_ptr serverDefs = doRun(theClientDefs, customTaskSmsMap, timeout, waitForTestCompletion);
+}
+
+void ServerTestHarness::run(Defs& defs, const std::string& defs_filename, int timeout, bool waitForTestCompletion) {
+    std::map<std::string, std::string> customTaskSmsMap;
+    run(defs, defs_filename, customTaskSmsMap, timeout, waitForTestCompletion);
+}
+
+struct null_deleter
+{
+    void operator()(void const*) const {}
+};
+
+defs_ptr ServerTestHarness::doRun(Defs& theClientDefs,
+                                  const std::map<std::string, std::string>& customTaskSmsMap,
+                                  int timeout,
+                                  bool waitForTestCompletion) {
+#ifdef DEBUG_TEST_HARNESS
+    cout << "ServerTestHarness::doRun " << defs_filename_ << " timeout=" << timeout
+         << "  waitForTestCompletion = " << waitForTestCompletion << "\n";
+#endif
+    BOOST_REQUIRE_MESSAGE(!theClientDefs.suiteVec().empty(), "No suite defined");
+
+#ifdef DEBUG_TEST_HARNESS
+    cout << "   ServerTestHarness::doRun: Get the client exe. This can be client exe on another platform hence cant "
+            "run here\n";
+#endif
+    std::string theClientExePath = TestFixture::theClientExePath();
+    BOOST_REQUIRE_MESSAGE(!theClientExePath.empty(), " The client program could not be found");
+
+#ifdef DEBUG_TEST_HARNESS
+    cout << "   ServerTestHarness::doRun: Create ECF directory structure corresponding to Node tree\n";
+#endif
+    // Automatically add variable ECF_HOME to each suite, before saving to disk
+    // This is needed to locate ECF_FILE includes
+    std::string ecf_home = testDataLocation(defs_filename_);
+
+    // Most test just define one suite, however the mega.def has up to 26 suites
+    // If set this can be used to choose which suite to begin.
+    std::string suiteName;
+
+    // ECF_CLIENT_EXE_PATH allows dependence on client exe without installation
+    // Allow user to add SLEEPTIME, otherwise add a default
+    int customSmsCnt    = 0;
+    auto taskSmsMapSize = static_cast<int>(customTaskSmsMap.size());
+    for (suite_ptr s : theClientDefs.suiteVec()) {
+
+        // Always override these to correctly locate files.
+        s->addVariable(Variable(Str::ECF_HOME(), ecf_home));
+        s->addVariable(Variable("ECF_CLIENT_EXE_PATH", theClientExePath));
+        s->addVariable(Variable(Str::ECF_INCLUDE(), TestFixture::includes()));
+
+        if (s->findVariable("SLEEPTIME").empty())
+            s->addVariable(Variable("SLEEPTIME", "1"));
+
+        if (check_task_duration_less_than_server_poll_) {
+            if (s->findVariable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL").empty())
+                s->addVariable(Variable("CHECK_TASK_DURATION_LESS_THAN_SERVER_POLL", "_any_"));
+        }
+        suiteName = s->name();
+
+        // recursively create directory structure from ECF_HOME and populate tasks with sms files
+        createDirAndEcfFiles(s.get(), ecf_home, customTaskSmsMap, customSmsCnt);
+    }
+    BOOST_REQUIRE_MESSAGE(customSmsCnt == taskSmsMapSize,
+                          "customSmsCnt:"
+                              << customSmsCnt << " does not match " << taskSmsMapSize
+                              << " createDirAndEcfFiles did not create all sms file corresponding to tasks");
+
+    // If the defs has more than one suite, then start them all.
+    if (theClientDefs.suiteVec().size() != 1) {
+        suiteName.clear();
+#ifdef DEBUG_TEST_HARNESS
+        cout << "   ServerTestHarness::doRun: defs has " << theClientDefs.suiteVec().size()
+             << " suites hence will begin all of them\n";
+#endif
+    }
+
+    bool load_defs_from_disk = true;
+    {
+#ifdef DEBUG_TEST_HARNESS
+        cout << "   ServerTestHarness::doRun: Save the Defs file to disk. " << defs_filename_ << "\n";
+#endif
+        std::ofstream theClientDefsFile(defs_filename_.c_str());
+        if (theClientDefsFile.fail()) {
+            // The file is *not on disk*, just use in memory defs
+            load_defs_from_disk = false;
+        }
+        else {
+            PrintStyle style(PrintStyle::DEFS); // needed for output
+            theClientDefsFile << theClientDefs;
+        }
+    }
+
+    // Set the location of the new log file. Close the current log file and create new log file
+    // The defs file name should have been set to the test location
+    // The log file is CLEARED so that previous run is ignored
+    std::string new_log_file_path = defs_filename_ + "_log";
+#ifdef DEBUG_TEST_HARNESS
+    cout << "   ServerTestHarness::new_log_file_path = " << new_log_file_path << "\n";
+#endif
+    TestFixture::client().new_log(new_log_file_path);
+    TestFixture::client().clearLog();
+
+#ifdef DEBUG_TEST_HARNESS
+    cout << "   ServerTestHarness::doRun: Delete all nodes in server. Using force to allow as many tests as possible\n";
+#endif
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().delete_all(true /*force, even if it creates zombies*/) == 0,
+                          CtsApi::to_string(CtsApi::delete_node())
+                              << " failed should return 0. Should Delete ALL existing defs in the server\n"
+                              << TestFixture::client().errorMsg());
+
+#ifdef DEBUG_TEST_HARNESS
+    cout << "   ServerTestHarness::doRun: Load new defs in the server\n";
+#endif
+    if (load_defs_from_disk) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().loadDefs(defs_filename_) == 0,
+                              "load defs failed should return 0. Should Load defs file "
+                                  << defs_filename_ << " into the server from current working directory\n"
+                                  << TestFixture::client().errorMsg());
+    }
+    else {
+        // load expects a defs_ptr
+        defs_ptr defs(&theClientDefs, null_deleter());
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().load(defs) == 0,
+                              "load defs failed should return 0. Should Load defs file "
+                                  << defs_filename_ << " into the server\n"
+                                  << TestFixture::client().errorMsg());
+    }
+
+#ifdef DEBUG_TEST_HARNESS
+    cout << "   ServerTestHarness::doRun: Restart server \n";
+#endif
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().restartServer() == 0,
+                          CtsApi::restartServer()
+                              << " failed should return 0. Should restart the server via a client command\n"
+                              << TestFixture::client().errorMsg());
+
+#ifdef DEBUG_TEST_HARNESS
+    cout << "   ServerTestHarness::doRun: Calling begin on suite " << suiteName << "\n";
+#endif
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().begin(suiteName) == 0,
+                          CtsApi::begin(suiteName)
+                              << " failed should return 0. Should Begin the suite " << suiteName << "\n"
+                              << TestFixture::client().errorMsg());
+
+    if (waitForTestCompletion) {
+#ifdef DEBUG_TEST_HARNESS
+        cout << "   ServerTestHarness::doRun: Waiting for test to finish\n";
+#endif
+        return testWaiter(theClientDefs, timeout, true /* test against verification attributes on defs */);
+    }
+    return defs_ptr();
+}
+
+static void test_invariants(defs_ptr the_defs, const std::string& title) {
+    std::string errorMsg;
+    BOOST_CHECK_MESSAGE(the_defs->checkInvariants(errorMsg), title << " Invariants failed " << errorMsg);
+}
+
+bool verify_attribute_verification() {
+    // In  version 4.0.1: We changed the way families changed states. i.e families will now change to state complete
+    // before being requeued. See ECFLOW-96 Families with loops(cron/repeat) should log complete
+    // This meant that when we run the migration tests, i.e new client with old server (with new test)
+    // It would fail some the test, during verify attribute verification. ie. where we count the number of times
+    // a node completes. To enable these tests to still run, we will disable verify attribute verification
+    return true;
+}
+
+defs_ptr ServerTestHarness::testWaiter(const Defs& theClientDefs, int timeout, bool verifyAttr) {
+#ifdef DEBUG_TEST_WAITER
+    cout << "ServerTestHarness::testWaiter \n";
+#endif
+
+#ifdef DEBUG_DIFF
+    std::string dump_defs_filename = "test.def";
+    int counter                    = 0;
+#endif
+    DebugEquality debug_equality; // only as affect in DEBUG build
+
+    BOOST_REQUIRE_MESSAGE(TestFixture::client().client_handle() == 0,
+                          "Client handle expected to be zero but found " << TestFixture::client().client_handle());
+
+    /// This function will test sync'ing. by getting the sync and full defs, then comparing them
+    AssertTimer assertTimer(timeout, false); // Bomb out after n seconds, fall back if test fail
+
+    // test the incremental changes
+    defs_ptr incremental_defs;
+    defs_ptr full_defs;
+
+    int sleepTime         = (theClientDefs.suiteVec().size() == 1) ? TestFixture::job_submission_interval() : 10;
+    int sleep_fudgeFactor = TestFixture::job_submission_interval();
+
+    // How do we terminate this test?
+    // The test succeeds if the suite state is complete,
+    while (true) {
+#ifdef DEBUG_TEST_WAITER
+        std::cout << "sleepTime = " << sleepTime << "\n";
+#endif
+        sleep(sleepTime);    // avoid calling get excessively, by using sleep
+        DurationTimer timer; // automatically adjust sleep time
+
+        bool server_changed = false;
+        if (!full_defs.get()) {
+            server_changed = true;
+            // ********************************************************************************
+            // Calling getDefs will also force a flush of the log file. This is required since we
+            // copy the log file locally on the shared file system for cross platform testing
+            // ******************************************************************************
+            BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
+                                  CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
+            full_defs        = TestFixture::client().defs();
+            incremental_defs = TestFixture::client().defs();
+            BOOST_REQUIRE_MESSAGE(full_defs.get(), "get command failed to get node tree from server");
+            BOOST_REQUIRE_MESSAGE(incremental_defs.get(), "get command failed to get node tree from server");
+
+            // Ensure that when suite was loaded in server, that others suites were discarded
+            BOOST_CHECK_MESSAGE(theClientDefs.suiteVec().size() == full_defs->suiteVec().size(),
+                                "mismatch in client suite count " << theClientDefs.suiteVec().size() << " and server "
+                                                                  << full_defs->suiteVec().size());
+            test_invariants(full_defs, "First time for getting full defs");
+        }
+        else {
+            BOOST_CHECK_MESSAGE(TestFixture::client().news(full_defs) == 0,
+                                "news failed should return 0 " << TestFixture::client().errorMsg());
+            server_changed = TestFixture::client().get_news();
+            //			std::cout << "server_changed = " << server_changed << "\n";
+            if (server_changed) {
+
+                // Get the incremental changes **FIRST** and compare this with the full defs later on
+                BOOST_REQUIRE_MESSAGE(TestFixture::client().sync(incremental_defs) == 0,
+                                      "sync failed should return 0 " << TestFixture::client().errorMsg());
+                BOOST_CHECK_MESSAGE(TestFixture::client().in_sync(),
+                                    "in_sync expected to return true, when we have changes in server");
+                test_invariants(incremental_defs, "After syncing with incremental defs.");
+
+                // get the FULL defs
+                BOOST_REQUIRE_MESSAGE(TestFixture::client().getDefs() == 0,
+                                      CtsApi::get() << " failed should return 0 " << TestFixture::client().errorMsg());
+                full_defs = TestFixture::client().defs();
+                BOOST_REQUIRE_MESSAGE(full_defs.get(), "get command failed to get node tree from server");
+                test_invariants(full_defs, "After getting the full defs.");
+
+                // **** NOTE ****: There could have been state change between the calls:
+                // **************: 	 TestFixture::client().sync(incremental_defs)
+                // **************:    TestFixture::client().getDefs()
+                // **************: hence we can only compare, incremental and full defs if
+                // **************: state and modification numbers are the same:
+                BOOST_REQUIRE_MESSAGE(incremental_defs.get() != full_defs.get(), " Expected two different defs trees ");
+                if (incremental_defs->state_change_no() == full_defs->state_change_no() &&
+                    incremental_defs->modify_change_no() == full_defs->modify_change_no()) {
+                    BOOST_CHECK_MESSAGE(
+                        *full_defs == *incremental_defs,
+                        "Full and incremental defs should be the same. (state_change_no,modify_change_no) ("
+                            << incremental_defs->state_change_no() << "," << incremental_defs->modify_change_no()
+                            << ")");
+                }
+                else {
+#ifdef DEBUG_TEST_WAITER
+                    std::cout << "***** ServerTestHarness::testWaiter: State change between getting incremental and "
+                                 "full defs\n";
+#endif
+                }
+            }
+        }
+
+        int hasAutoCancel       = 0;
+        size_t completeSuiteCnt = 0;
+        if (server_changed) {
+
+#ifdef DEBUG_DIFF
+            {
+                counter++;
+                std::string filename = dump_defs_filename + ecf::convert_to<std::string>(counter);
+                std::ofstream theFile(filename.c_str());
+
+                std::vector<Task*> tasks;
+                full_defs->getAllTasks(tasks);
+                int unknown            = 0;
+                int complete           = 0;
+                int queued             = 0;
+                int aborted            = 0;
+                int submitted          = 0;
+                int active             = 0;
+                size_t password_size   = 0;
+                size_t process_id_size = 0;
+                for (size_t i = 0; i < tasks.size(); i++) {
+                    switch (tasks[i]->state()) {
+                        case NState::UNKNOWN:
+                            unknown++;
+                            break;
+                        case NState::COMPLETE:
+                            complete++;
+                            break;
+                        case NState::QUEUED:
+                            queued++;
+                            break;
+                        case NState::ABORTED:
+                            aborted++;
+                            break;
+                        case NState::SUBMITTED:
+                            submitted++;
+                            break;
+                        case NState::ACTIVE:
+                            active++;
+                            break;
+                    }
+                    password_size += tasks[i]->jobsPassword().size();
+                    process_id_size += tasks[i]->process_or_remote_id().size();
+                }
+                theFile << "task password_size(" << password_size << ") process_id_size(" << process_id_size
+                        << ")   total = " << (password_size + process_id_size) << endl;
+                theFile << "unknown: " << unknown << "\n";
+                theFile << "complete: " << complete << "\n";
+                theFile << "queued: " << queued << "\n";
+                theFile << "aborted: " << aborted << "\n";
+                theFile << "submitted: " << submitted << "\n";
+                theFile << "active: " << active << "\n";
+                theFile << *full_defs.get();
+            }
+#endif
+            std::string errorMsg;
+            BOOST_REQUIRE_MESSAGE(full_defs->checkInvariants(errorMsg), "Invariants failed " << errorMsg);
+
+            // record the number of times that the server updated the calendar. Allow debug of time dependencies
+            serverUpdateCalendarCount_ = full_defs->updateCalendarCount();
+
+            for (suite_ptr s : full_defs->suiteVec()) {
+                if (s->state() == NState::COMPLETE)
+                    completeSuiteCnt++;
+                if (s->hasAutoCancel())
+                    hasAutoCancel++;
+            }
+
+#ifdef DEBUG_TEST_WAITER_DEFS
+            cout << "\nPrinting Defs "
+                    "==================================================================================\n";
+            std::cout << *full_defs.get();
+            cout << "completeSuiteCnt = " << completeSuiteCnt
+                 << " full_defs->suiteVec().size() = " << full_defs->suiteVec().size()
+                 << " hasAutoCancel = " << hasAutoCancel << "\n";
+#endif
+            if ((full_defs->suiteVec().size() == completeSuiteCnt) && (hasAutoCancel == 0)) {
+
+                if (verifyAttr && verify_attribute_verification()) {
+                    // Do verification of expected state changes
+                    string localErrorMessage;
+                    BOOST_REQUIRE_MESSAGE(full_defs->verification(localErrorMessage),
+                                          localErrorMessage << "\n"
+                                                            << *full_defs.get());
+                }
+                return full_defs;
+            }
+        }
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+            // Give clues why we are not finishing on time, by using Why and by dumping out node tree
+            cout << "Test time " << assertTimer.duration() << " taking longer than time constraint of "
+                 << assertTimer.timeConstraint() << " aborting\n";
+            cout << "   completeSuiteCnt = " << completeSuiteCnt << "\n";
+            cout << "   full_defs->suiteVec().size() = " << full_defs->suiteVec().size() << "\n";
+            cout << "   hasAutoCancel = " << hasAutoCancel << "\n";
+            std::cout << "update-calendar-count(" << serverUpdateCalendarCount_ << ")\n";
+            std::cout << "WHY:\n";
+            WhyCmd reason(full_defs, "" /* do a top down why */);
+            std::cout << reason.why() << "\n";
+        }
+        BOOST_REQUIRE_MESSAGE(assertTimer.duration() < assertTimer.timeConstraint(), "\n" << *full_defs);
+        if (assertTimer.duration() >= assertTimer.timeConstraint())
+            break; // fix warning on AIX
+
+        // auto adjust sleep time.
+        sleepTime = timer.duration() + sleep_fudgeFactor;
+    }
+    return defs_ptr();
+}
+
+void ServerTestHarness::createDirAndEcfFiles(NodeContainer* nc,
+                                             const std::string& smshome,
+                                             const std::map<std::string, std::string>& customTaskSmsMap,
+                                             int& customSmsCnt) const {
+    std::string directory = smshome + nc->absNodePath();
+#ifdef DEBUG_TEST_HARNESS
+    cout << "creating directory  " << directory << "\n";
+#endif
+
+    if (!fs::exists(smshome))
+        fs::create_directory(smshome);
+    if (!fs::exists(directory))
+        fs::create_directory(directory);
+
+    if (generateManFileForNodeContainers_) {
+        std::string manFileName = smshome + nc->absNodePath() + File::MAN_EXTN();
+        std::ofstream theManFile(manFileName.c_str());
+        theManFile << "%manual\n";
+        theManFile << "This file auto generated by ServerTestHarness::createDirAndEcfFiles for all Node Containers\n";
+        theManFile << "%end\n";
+    }
+
+    for (node_ptr n : nc->nodeVec()) {
+
+        Task* t = n->isTask();
+        if (t) {
+            std::string ecf_file = smshome + t->absNodePath() + File::ECF_EXTN();
+#ifdef DEBUG_TEST_HARNESS
+            cout << "creating ecf file  " << ecf_file << "\n";
+#endif
+            // Create ECF file with default template or custom  file.
+            std::ofstream theEcfFile(ecf_file.c_str());
+            auto it = customTaskSmsMap.find(t->absNodePath());
+            if (it == customTaskSmsMap.end())
+                theEcfFile << getDefaultTemplateEcfFile(t);
+            else {
+                theEcfFile << (*it).second;
+                customSmsCnt++;
+            }
+        }
+        else {
+            Family* f = n->isFamily();
+            assert(f);
+            createDirAndEcfFiles(f, smshome, customTaskSmsMap, customSmsCnt);
+        }
+    }
+}
+
+static void add_queue(std::string& content, const std::vector<QueueAttr>& queues) {
+    for (const QueueAttr& queue : queues) {
+        content += "\n";
+        content += "for i in";
+        const std::vector<std::string>& queue_list = queue.list();
+        for (const auto& i : queue_list) {
+            content += " ";
+            content += i;
+        }
+        content += "\n";
+        content += "do\n";
+        content += "   step=$(%ECF_CLIENT_EXE_PATH% --queue=" + queue.name() + " active )\n";
+        content += "   echo $step\n";
+        content += "   sleep %SLEEPTIME%\n";
+        content += "   %ECF_CLIENT_EXE_PATH% --queue=" + queue.name() + " complete $step\n";
+        content += "done\n";
+    }
+}
+
+std::string ServerTestHarness::getDefaultTemplateEcfFile(Task* t) const {
+    std::string templateEcfFile;
+
+    templateEcfFile += "%manual\n";
+    templateEcfFile += "This is the default ecf script file used for testing\n";
+    templateEcfFile += "%end\n";
+    templateEcfFile += "%comment\n";
+    templateEcfFile += "# Using angle brackets should use ECF_INCLUDE\n";
+    templateEcfFile += "%end\n";
+    templateEcfFile += "%include <head.h>\n";
+    templateEcfFile += "\n";
+    for (const Event& e : t->events()) {
+        // if initial value is set, then child cmd clears
+        // else if initial value is clear, then child cmd sets (default)
+        if (e.initial_value())
+            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --event=" + e.name_or_number() + " clear\n";
+        else
+            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --event=" + e.name_or_number() + "\n";
+    }
+    for (const Meter& m : t->meters()) {
+        templateEcfFile += "for i in";
+        int min   = m.min();
+        int max   = m.max();
+        int delta = abs(max - min) / 10;
+        for (int i = min + delta; i <= max; i = i + delta) {
+            templateEcfFile += " ";
+            templateEcfFile += ecf::convert_to<std::string>(i);
+        }
+        templateEcfFile += "\n";
+        templateEcfFile += "do\n";
+        templateEcfFile += "   %ECF_CLIENT_EXE_PATH% --meter=" + m.name() + " $i\n";
+        templateEcfFile += "   sleep %SLEEPTIME%\n";
+        templateEcfFile += "done\n";
+    }
+    /// labels require at least 2 arguments,
+    for (const Label& label : t->labels()) {
+        if (!label.new_value().empty()) {
+            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --label=" + label.name() + " " + label.new_value() + "\n";
+        }
+        else if (!label.value().empty()) {
+            templateEcfFile += "%ECF_CLIENT_EXE_PATH% --label=" + label.name() + " " + label.value() + "\n";
+        }
+    }
+
+    /// Queues
+    add_queue(templateEcfFile, t->queues());
+    Node* parent = t->parent();
+    while (parent) {
+        add_queue(templateEcfFile, parent->queues());
+        parent = parent->parent();
+    }
+
+    if (add_default_sleep_time_ && t->events().empty() && t->meters().empty() && t->queues().empty()) {
+        templateEcfFile += "\n# SLEEPTIME is defined the Client Defs.def file. Test variable substitution\n";
+        templateEcfFile += "sleep %SLEEPTIME%\n";
+    }
+    templateEcfFile += "\n%include <tail.h>\n";
+    return templateEcfFile;
+}
+
+std::string ServerTestHarness::testDataDefsLocation(const std::string& defsFile) {
+    // DefsFile is of the form base_name.def"
+    // We want to place the defs and log file in the same location as its test directory
+    //   test/data/ECF_HOME/base_name/base_name.def
+    std::string testData = testDataLocation(defsFile) + "/" + defsFile;
+    return testData;
+}
+
+std::string ServerTestHarness::testDataLocation(const std::string& defsFile) {
+    // DefsFile is of the form:
+    //   base_name.def
+    //   /tmp/path/base_name.def
+    //
+    // We want to place the defs and log file in the same location as its test directory
+    //   test/data/ECF_HOME/base_name
+    //
+    std::string base_name = defsFile;
+    size_t slash_pos      = defsFile.rfind('/', defsFile.length());
+    if (slash_pos != std::string::npos) {
+        base_name = base_name.erase(0, slash_pos + 1);
+    }
+
+    size_t dot_pos = base_name.rfind('.', base_name.length());
+    assert(dot_pos != std::string::npos); // missing '.'
+    base_name = base_name.substr(0, dot_pos);
+
+    std::string testData = TestFixture::smshome() + "/" + base_name;
+    return testData;
+}
diff -pruN 5.12.4-1/libs/test/src/ServerTestHarness.hpp 5.13.0-1/libs/test/src/ServerTestHarness.hpp
--- 5.12.4-1/libs/test/src/ServerTestHarness.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/src/ServerTestHarness.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,119 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_test_harness_ServerTestHarness_HPP
+#define ecflow_test_harness_ServerTestHarness_HPP
+
+#include <map>
+#include <string>
+
+#include "ZombieUtil.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/node/NodeFwd.hpp"
+
+// This class provides a test harness for running defs file in a client server environment
+// To avoid Address in use errors, we can have client/server use a different port number
+// This is more important when doing instrumentation in HP-UX, as that can take a long time.
+//
+// The Server is started/stopped by use of the Global text Fixture
+// See class TestFixture.hpp
+//
+class ServerTestHarness {
+    ServerTestHarness(const ServerTestHarness&)                  = delete;
+    const ServerTestHarness& operator=(const ServerTestHarness&) = delete;
+
+public:
+    // if standardVerification is true, we test task goes through normal life cycle
+    // changes. else we compare the log file states with golden log file
+    // Comparing log files across platforms is not reliable, and ignored
+    ServerTestHarness();
+
+    /// generate man files for Suite and family nodes
+    void generateManFileForNodeContainers() { generateManFileForNodeContainers_ = true; }
+
+    /// Enable/disable checking for server poll being to small.
+    /// This test creates dummy .ecf files. Since these tests are run with the server poll
+    /// which is less than 60, we need the task duration between submit->active->complete duration to be less
+    /// the server poll. Tests with time dependencies of one minute separation will be missed.\n"
+    /// Make this configurable since for large defs, when we have 1000's of tasks the
+    /// task duration times are not deterministic
+    void check_task_duration_less_than_server_poll(bool f) { check_task_duration_less_than_server_poll_ = f; }
+
+    /// Sometimes on slow systems we want to disable sleep time.
+    /// since the time duration between submit->active->complete is greater than job submission interval
+    /// and hence time slots get missed.
+    /// The Default is to add the sleep time always for events and meters and when there is NO events or meters
+    /// This flags is used for the *specific* case when there is *no* events/meters.
+    void add_default_sleep_time(bool f) { add_default_sleep_time_ = f; }
+
+    // Run the following defs file in the test harness.
+    // If no map is provided then a default sms file is fabricated, otherwise
+    // the map allows a sms file string to be associated with a task path
+    // map.first = absolute task path
+    // map.second =  sms file string
+#if defined(_AIX)
+    void run(Defs&,
+             const std::string& defs_file,
+             const std::map<std::string, std::string>&,
+             int timeout                = 120,
+             bool waitForTestCompletion = true);
+    void run(Defs&, const std::string& defs_file, int timeout = 120, bool waitForTestCompletion = true);
+#elif defined(HPUX)
+    void run(Defs&,
+             const std::string& defs_file,
+             const std::map<std::string, std::string>&,
+             int timeout                = 100,
+             bool waitForTestCompletion = true);
+    void run(Defs&, const std::string& defs_file, int timeout = 100, bool waitForTestCompletion = true);
+#else
+    void run(Defs&,
+             const std::string& defs_file,
+             const std::map<std::string, std::string>&,
+             int timeout                = 40,
+             bool waitForTestCompletion = true);
+    void run(Defs&, const std::string& defs_file, int timeout = 40, bool waitForTestCompletion = true);
+#endif
+
+    /// Returns the location of the defs file, such thats it in the test data area
+    static std::string testDataDefsLocation(const std::string& defsFile);
+
+    /// The test data location
+    static std::string testDataLocation(const std::string& defsFile);
+
+    /// This function is used for waiting for test to finish
+    /// returns the defs from the server at test completeion
+    defs_ptr testWaiter(const Defs& theClientDefs, // The defs on the client side
+                        int timeout,               // How long should we wait for test to finish
+                        bool verifyAttr);          // Test verification use verify attributes on defs
+
+    /// for debug return the number of times the calendar was updated in the server
+    unsigned int serverUpdateCalendarCount() const { return serverUpdateCalendarCount_; }
+
+private:
+    defs_ptr doRun(Defs&, const std::map<std::string, std::string>&, int sleepTime, bool waitForTestCompletion);
+
+    void createDirAndEcfFiles(NodeContainer* nc,
+                              const std::string& smshome,
+                              const std::map<std::string, std::string>& taskSmsMap,
+                              int& customSmsCnt) const;
+
+    /// default ecf file will cater for events and meters
+    std::string getDefaultTemplateEcfFile(Task* t) const;
+
+private:
+    bool generateManFileForNodeContainers_{false};
+    bool check_task_duration_less_than_server_poll_{true};
+    bool add_default_sleep_time_{true};
+    int serverUpdateCalendarCount_{0};
+    std::string defs_filename_;
+    PrintStyle print_style_; // by default show state when writing defs to standard out. RAII
+};
+
+#endif /* ecflow_test_harness_ServerTestHarness_HPP */
diff -pruN 5.12.4-1/libs/test/src/TestFixture.cpp 5.13.0-1/libs/test/src/TestFixture.cpp
--- 5.12.4-1/libs/test/src/TestFixture.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/src/TestFixture.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,427 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "TestFixture.hpp"
+
+#include <cstdlib> // for getenv()
+#include <fstream> // for ofstream
+#include <iostream>
+
+#include "TestHelper.hpp"
+#include "ecflow/base/cts/user/CtsApi.hpp"
+#include "ecflow/client/ClientEnvironment.hpp" // needed for static ClientEnvironment::hostSpecified(); ONLY
+#include "ecflow/client/Rtt.hpp"
+#include "ecflow/core/EcfPortLock.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Filesystem.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Task.hpp"
+
+#ifdef DEBUG
+std::string rtt_filename = "rtt.dat";
+#else
+std::string rtt_filename = "rtt_d.dat";
+#endif
+std::string TestFixture::scratchSmsHome_ = "";
+std::string TestFixture::host_;
+std::string TestFixture::port_;
+std::string TestFixture::test_dir_;
+std::string TestFixture::project_test_dir_ = "libs/test";
+
+using namespace std;
+using namespace ecf;
+
+// ************************************************************************************************
+// For test purpose the server can be started:
+//  1/ By this test fixture
+//  2/ Externally but on the same machine. by defining env variable: export ECF_HOST=localhost
+//     WHY? To test for memory leak. (i.e. with valgrind)
+//  3/ Externally but on a different platform. by defining env variable: export ECF_HOST=itanium
+//     In this case we NEED to copy the test data, so that it is
+//     accessible by the client AND server
+//
+//  When invoking the server Externally _MUST_ use   .
+//     ./Server/bin/gcc.<version>/debug/server --ecfinterval=2
+//        The --ecfinterval=2 is _important_ or test will take a long time
+// ************************************************************************************************
+
+// Uncomment to preserve the files for test
+// #define DEBUG_HOST_SERVER 1
+#define DEBUG_LOCAL_SERVER 1
+
+TestFixture::TestFixture(const std::string& project_test_dir) : print_style_(PrintStyle::STATE) {
+    init(project_test_dir);
+}
+
+TestFixture::TestFixture() : print_style_(PrintStyle::STATE) {
+    init("libs/test");
+}
+
+ClientInvoker& TestFixture::client() {
+    static ClientInvoker theClient_;
+    return theClient_;
+}
+
+void TestFixture::init(const std::string& project_test_dir) {
+    TestFixture::project_test_dir_ = project_test_dir;
+    auto test_dir                  = local_ecf_home();
+    std::cout << "TestFixture::TestFixture() project_test_dir      :" << project_test_dir << "\n";
+    std::cout << "TestFixture::TestFixture() local_ecf_home        :" << test_dir << "\n";
+    std::cout << "TestFixture::TestFixture() jobSubmissionInterval :" << job_submission_interval() << "\n";
+    std::cout << "TestFixture::TestFixture() cwd                   :" << fs::current_path() << "\n";
+
+    if (!fs::exists(test_dir)) {
+        fs::create_directories(test_dir);
+    }
+
+    // client side file for recording all ClientInvoker round trip times
+    fs::remove(rtt_filename);
+    Rtt::create(rtt_filename);
+
+    // ********************************************************
+    // Note: Global fixture Constructor cannot use BOOST macro
+    // ********************************************************
+
+    // Let first see if we need do anything. If ECF_HOST is specified (ie the name
+    // of the machine, which has the ecflow server), only then do we need to do anything.
+    // The server must have access to the file system specified by ECF_HOME.
+    // This becomes an issue when the server is on a different machine
+    host_ = ClientEnvironment::hostSpecified();
+    port_ = ClientEnvironment::portSpecified(); // returns ECF_PORT, otherwise Str::DEFAULT_PORT_NUMBER
+#ifdef ECF_OPENSSL
+    if (getenv("ECF_SSL"))
+        std::cout << "   Openssl enabled\n";
+#endif
+    if (!host_.empty() && host_ != Str::LOCALHOST()) {
+
+        client().set_host_port(host_, port_);
+        std::cout << "   EXTERNAL SERVER running on _ANOTHER_ PLATFORM, assuming " << host_ << ":" << port_
+                  << " copying test data ...\n";
+
+        // Must use a file system accessible from the server. Use $SCRATCH
+        // Duplicate test data, required to scratch area and reset ECF_HOME
+        char* scratchEnv = getenv("SCRATCH");
+        assert(scratchEnv != NULL);
+        std::string theSCRATCHArea(scratchEnv);
+        assert(!theSCRATCHArea.empty());
+
+        theSCRATCHArea += "/test_dir";
+        test_dir_ = theSCRATCHArea; // test_dir_ needed in destructor
+        if (fs::exists(test_dir_)) {
+            fs::remove_all(test_dir_);
+        }
+        theSCRATCHArea += "/ECF_HOME";
+        scratchSmsHome_ = theSCRATCHArea;
+
+        BOOST_REQUIRE_MESSAGE(File::createDirectories(theSCRATCHArea),
+                              "File::createDirectories(theSCRATCHArea) failed");
+        BOOST_REQUIRE_MESSAGE(fs::exists(theSCRATCHArea), "theSCRATCHArea does not exist");
+
+        // Ensure that local includes data exists. This needs to be copied to SCRATCH
+        BOOST_REQUIRE_MESSAGE(fs::exists(includes()), "The includes dir does not exist does not exist");
+
+        // Copy over the includes directory to the SCRATCH area.
+        std::string scratchIncludes = test_dir_ + "/";
+        std::string do_copy         = "cp -r " + includes() + " " + scratchIncludes;
+        if (system(do_copy.c_str()) != 0)
+            assert(false);
+
+        // clear log file
+        clearLog();
+    }
+    else if (!host_.empty() && host_ == Str::LOCALHOST()) {
+
+        client().set_host_port(host_, port_);
+        std::cout << "   EXTERNAL SERVER running on _SAME_ PLATFORM. Assuming " << client().host() << ":"
+                  << client().port() << "\n";
+
+        // Print the server stats before we start + checks if it is up and running::
+        client().set_cli(true); // so server stats are written to standard out
+        if (client().stats() != 0) {
+            std::cout << "   ClientInvoker " << CtsApi::stats() << " failed: " << client().errorMsg()
+                      << ". Is the server running?\n";
+            assert(false);
+        }
+        client().set_cli(false);
+
+        // log file may have been deleted, by previous tests. Create a new log file
+        std::string the_log_file = TestFixture::pathToLogFile();
+        if (!fs::exists(the_log_file)) {
+            std::cout << "   Log file " << the_log_file << " does NOT exist, attempting to recreate\n";
+            std::cout << "   Creating new log(via remote server) file " << the_log_file << "\n";
+            if (0 == client().new_log(the_log_file)) {
+                client().logMsg("Created new log file. msg sent to force new log file to be written to disk");
+            }
+            else
+                cout << "   Log file " << TestFixture::pathToLogFile() << " creation failed " << client().errorMsg()
+                     << "\n";
+        }
+        else
+            cout << "   Log file " << the_log_file << " already exists\n";
+    }
+    else {
+        // For local host start by removing log file. Server invocation should create a new log file
+        fs::remove(fs::path(pathToLogFile()));
+        host_ = Str::LOCALHOST();
+
+        // Create a unique port number, allowing debug and release to run at the same time
+        // Note: linux64 and linux64intel, can run on same machine, on different workspace
+        // Hence the lock file is not sufficient. Hence we will make a client server call.
+        cout << "Find free port to start server, starting with port " << port_ << "\n";
+        auto the_port = ecf::convert_to<int>(port_);
+        while (!EcfPortLock::is_free(the_port))
+            the_port++;
+        port_ = ClientInvoker::find_free_port(the_port, true /*show debug output */);
+        EcfPortLock::create(port_);
+
+        // host_ is empty update to localhost, **since** port may have changed, update ClinetInvoker
+        client().set_host_port(host_, port_);
+
+        // Remove the generated check point files, at start of test, otherwise server will load check point file
+        Host h;
+        fs::remove(h.ecf_checkpt_file(port_));
+        fs::remove(h.ecf_backup_checkpt_file(port_));
+
+        std::string theServerInvokePath = File::find_ecf_server_path();
+        assert(!theServerInvokePath.empty());
+        theServerInvokePath += " --port=" + port_;
+        theServerInvokePath += " --ecfinterval=" + ecf::convert_to<std::string>(job_submission_interval());
+        theServerInvokePath += "&";
+        if (system(theServerInvokePath.c_str()) != 0)
+            assert(false); // " Server invoke failed "
+
+        std::cout << "   ECF_HOST not specified, starting LOCAL " << theServerInvokePath << "\n";
+    }
+
+    /// Ping the server to see if its running
+    /// Assume remote/local server started on the default port
+    /// Either way, we wait for 60 seconds for server, for it to respond to pings
+    /// This is important when server is started locally. We must wait for it to come alive.
+    if (!client().wait_for_server_reply()) {
+        cout << "   Ping server on " << client().host() << Str::COLON() << client().port()
+             << " failed. Is the server running ? " << client().errorMsg() << "\n";
+        assert(false);
+    }
+    cout << "   Ping OK: server running on:  " << client().host() << Str::COLON() << client().port() << "\n";
+
+    // Log file must exist, otherwise test will not work. Log file required for comparison
+    if (!fs::exists(TestFixture::pathToLogFile())) {
+        cout << "   Log file " << TestFixture::pathToLogFile() << " does not exist *************************** \n";
+        assert(false);
+    }
+
+    // Check host and port match
+    assert(host_ == client().host());
+    assert(port_ == client().port());
+}
+
+TestFixture::~TestFixture() {
+    // Note: Global fixture Destructor cannot use BOOST macro
+    std::cout << "TestFixture::~TestFixture() " << client().host() << ":" << client().port() << "\n";
+
+    // destructors should not allow exception propagation
+    try {
+#ifndef DEBUG_HOST_SERVER
+        if (!host_.empty() && fs::exists(test_dir_)) {
+            fs::remove_all(test_dir_);
+        }
+#endif
+#ifndef DEBUG_LOCAL_SERVER
+        if (fs::exists(local_ecf_home())) {
+            fs::remove_all(local_ecf_home());
+        }
+#endif
+
+        std::cout << "   Print the server suites\n";
+        client().set_cli(true);             // so server stats are written to standard out
+        client().set_throw_on_error(false); // destructors should not allow exception propagation
+        if (client().suites() != 0) {
+            std::cout << "TestFixture::~TestFixture(): ClientInvoker " << CtsApi::suites()
+                      << " failed: " << client().errorMsg() << "\n";
+        }
+
+        std::cout << "   Print the server stats\n";
+        if (client().stats() != 0) {
+            std::cout << "TestFixture::~TestFixture(): ClientInvoker " << CtsApi::stats()
+                      << " failed: " << client().errorMsg() << "\n";
+        }
+
+        std::cout << "   Kill the server, as all suites are complete. will work for local or external\n";
+        if (client().terminateServer() != 0) {
+            std::cout << "TestFixture::~TestFixture():  ClientInvoker " << CtsApi::terminateServer()
+                      << " failed: " << client().errorMsg() << "\n";
+            EcfPortLock::remove(port_);
+            assert(false);
+        }
+        sleep(1); // allow time to update log file
+
+        std::cout << "   Remove the generated check point files, at end of test\n";
+        Host host;
+        fs::remove(host.ecf_log_file(port_));
+        fs::remove(host.ecf_checkpt_file(port_));
+        fs::remove(host.ecf_backup_checkpt_file(port_));
+
+        std::cout << "   remove the lock file\n";
+        EcfPortLock::remove(port_);
+
+        std::cout << "   Rtt::destroy(), so that we flush the rtt_filename\n";
+        Rtt::destroy();
+
+        cout << "\nTiming: *NOTE*: The child commands *NOT* recorded. Since its a separate exe(ecflow_client), called "
+                "via .ecf script\n";
+        cout << Rtt::analyis(rtt_filename); // report round trip times
+        fs::remove(rtt_filename);
+    }
+    catch (std::exception& ex) {
+        std::cout << "TestFixture::~TestFixture() caught exception " << ex.what() << "\n";
+    }
+    catch (...) {
+        std::cout << "TestFixture::~TestFixture() caught unknown exception\n";
+    }
+
+    std::cout << "TestFixture::~TestFixture() END\n";
+}
+
+int TestFixture::job_submission_interval() {
+    int jobSubmissionInterval = 3;
+#if defined(HPUX) || defined(_AIX)
+    jobSubmissionInterval += 3;
+#endif
+    return jobSubmissionInterval;
+}
+
+std::string TestFixture::smshome() {
+    if (serverOnLocalMachine())
+        return local_ecf_home();
+    return scratchSmsHome_;
+}
+
+bool TestFixture::serverOnLocalMachine() {
+    return (host_.empty() || host_ == Str::LOCALHOST());
+}
+
+std::string TestFixture::theClientExePath() {
+    if (serverOnLocalMachine())
+        return File::find_ecf_client_path();
+
+    char* client_path_p = getenv("ECF_CLIENT_EXE_PATH");
+    if (client_path_p == nullptr) {
+
+        // Try this before complaining
+        std::string path = "/usr/local/apps/ecflow/current/bin/ecflow_client";
+        if (fs::exists(path))
+            return path;
+
+        cout << "Please set ECF_CLIENT_EXE_PATH. This needs to be set to path to the client executable\n";
+        cout << "The client must be the one that was built on the same platform as the server\n";
+        assert(false);
+    }
+    return string(client_path_p);
+}
+
+void TestFixture::clearLog() {
+
+    // Can't remove log on remote server, just clear the log file
+    client().clearLog();
+}
+
+std::string TestFixture::pathToLogFile() {
+    if (serverOnLocalMachine()) {
+        Host host;
+        return host.ecf_log_file(port_);
+    }
+
+    char* pathToRemoteLog_p = getenv("ECF_LOG");
+    if (pathToRemoteLog_p == nullptr) {
+        cout << "TestFixture::pathToLogFile(): assert failed\n";
+        cout << "Please set ECF_LOG. This needs to be set to path to the log file\n";
+        cout << "that can be seen by the client and server\n";
+        assert(false);
+    }
+    return std::string(pathToRemoteLog_p);
+}
+
+std::string TestFixture::local_ecf_home() {
+    std::string compiler = "unknown";
+#if defined(_AIX)
+    compiler = "aix";
+#elif defined(HPUX)
+    compiler = "hpux";
+#else
+    #if defined(__clang__)
+    compiler = "clang";
+    #elif defined(__INTEL_COMPILER)
+    compiler = "intel";
+    #elif defined(_CRAYC)
+    compiler = "cray";
+    #else
+    compiler = "gnu";
+    #endif
+#endif
+
+    std::string build_type = "unknown";
+#ifdef DEBUG
+    build_type = "debug";
+#else
+    build_type = "release";
+#endif
+
+    std::string rel_path = "data/ECF_HOME_" + build_type + "_" + compiler;
+
+    // Allow post-fix to be added, to allow test to run in parallel
+    if (const char* custom_postfix = getenv("TEST_ECF_HOME_POSTFIX"); custom_postfix) {
+        rel_path += custom_postfix;
+    }
+
+    std::string absolute_path = File::test_data_in_current_dir(rel_path);
+    return absolute_path;
+}
+
+std::string TestFixture::includes() {
+    // Get to the root source directory
+    std::string includes_path = File::root_source_dir();
+    includes_path += "/";
+    includes_path += project_test_dir_;
+    includes_path += "/data/includes";
+    // std::cout << "includes_path = " << includes_path << " ==============================================\n";
+    return includes_path;
+}
+
+/// Given a task name like "a" find the find the first task matching that name
+/// and returns is abs node path
+std::string TestFixture::taskAbsNodePath(const Defs& theDefs, const std::string& taskName) {
+    std::vector<Task*> vec;
+    theDefs.getAllTasks(vec);
+    for (Task* t : vec) {
+        if (t->name() == taskName)
+            return t->absNodePath();
+    }
+
+    cout << "TestFixture::taskAbsNodePath: assert failed: Could not find task " << taskName << "\n";
+    assert(false); // could not find the task ??
+    return string();
+}
+
+int TestFixture::server_version() {
+    client().server_version();
+    std::string the_server_version_str = TestFixture::client().get_string();
+    // cout << "\nserver_version_str = " << the_server_version_str << "\n";
+    BOOST_REQUIRE_MESSAGE(Str::replace_all(the_server_version_str, ".", ""),
+                          "failed to find '.' in server version string " << TestFixture::client().get_string());
+
+    // Could 4.0.8rc1
+    Str::replace_all(the_server_version_str, "rc1", "");
+    Str::replace_all(the_server_version_str, "rc2", "");
+    auto the_server_version = ecf::convert_to<int>(the_server_version_str);
+    return the_server_version;
+}
diff -pruN 5.12.4-1/libs/test/src/TestFixture.hpp 5.13.0-1/libs/test/src/TestFixture.hpp
--- 5.12.4-1/libs/test/src/TestFixture.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/src/TestFixture.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,106 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_test_harness_TestFixture_HPP
+#define ecflow_test_harness_TestFixture_HPP
+
+///
+/// \brief This Fixture facilitates the test of client/server on different platforms
+///
+/// In order to carry out the test, we must have a common file system.
+/// We will use $SCRATCH as this is accessible by both client and server.
+/// This means copying over the test data
+///
+/// When TextFixture is GLOBAL, then we can't seem to call any of the
+/// BOOST_REQUIRE_MESSAGE() macro in constructor/descructor as this causes a crash
+/// i.e order of initialisation issues
+///
+
+#include <string>
+
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/PrintStyle.hpp"
+
+class Defs;
+
+//
+// Need to use static data, since with boost global fixture, its not possible to access
+// the global test fixture in each of the test cases
+//
+struct TestFixture
+{
+
+    // Constructor will invoke the server, destructor will kill the server
+    // Since this class is static, the constructor/destructor cannot call
+    // any of BOOST MACRO, since the unit test will not be there.
+    // When running across platforms will will assume server is already running
+    explicit TestFixture(const std::string& project_test_dir /* Test or view */);
+    TestFixture();
+    ~TestFixture();
+
+    // Configure the server with the job submission interval.
+    // i.e for each 'n' seconds of job submission interval the calendar
+    // is typically incremented by 1 minute. Hence speeding up the
+    // time and thus the testing. See Calendar for further details
+    static int job_submission_interval();
+
+    /// The location of ECF home will vary. If client/server on same machines we
+    /// return test data location. Otherwise we need return a common file system location
+    /// that was created in the constructor
+    static std::string smshome();
+
+    /// Will end up checking to see if ECF_HOST is specified. This specifies the name
+    /// of the machine that is running the server. Otherwise return true
+    static bool serverOnLocalMachine();
+
+    /// If running locally returns  location of client exe, if a server is on a remote
+    /// machine, we need to determine its location.
+    // Several options:
+    //    a/ Search for hard code path
+    //    b/ Ask server about test data, i.e. client exe path, log file location , etc
+    //       More flexible
+    static std::string theClientExePath();
+
+    /// When multiple tests are run , we need to clear the log file
+    static void clearLog();
+
+    /// When local just returns ecf.log, when remote return path to log file
+    static std::string pathToLogFile();
+
+    /// Given a task name like "a" find the find the first task matching that name
+    /// and returns is abs node path
+    static std::string taskAbsNodePath(const Defs& theDefs, const std::string& taskName);
+
+    /// Location of the includes used in the ecf file
+    static std::string includes();
+
+    /// returns the server version as an integer.
+    /// This allows as to ignore some tests, when testing old servers.(with new clients).
+    static int server_version();
+
+    // Use for all comms with server
+    static ClientInvoker& client();
+    static std::string port() { return port_; }
+
+private:
+    static std::string local_ecf_home();
+
+    void init(const std::string& project_test_dir);
+
+private:
+    static std::string scratchSmsHome_;
+    static std::string host_;
+    static std::string port_;
+    static std::string test_dir_;         // used when we have an external server, different platform
+    static std::string project_test_dir_; // "Test" or "view"
+    PrintStyle print_style_;              // by default show state when writing defs to standard out. RAII
+};
+
+#endif /* ecflow_test_harness_TestFixture_HPP */
diff -pruN 5.12.4-1/libs/test/src/ZombieUtil.hpp 5.13.0-1/libs/test/src/ZombieUtil.hpp
--- 5.12.4-1/libs/test/src/ZombieUtil.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/src/ZombieUtil.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_test_harness_ZombieUtil_HPP
+#define ecflow_test_harness_ZombieUtil_HPP
+
+#include "ecflow/core/Child.hpp"
+#include "ecflow/core/User.hpp"
+
+class ClientInvoker;
+
+class ZombieUtil {
+private:
+    ZombieUtil(const ZombieUtil&)                  = delete;
+    const ZombieUtil& operator=(const ZombieUtil&) = delete;
+
+public:
+    static void test_clean_up(int timeout);
+    static int do_zombie_user_action(ecf::User::Action uc,
+                                     int expected_action_cnt,
+                                     int max_time_to_wait,
+                                     bool fail_if_to_long = true);
+};
+
+class TestClean {
+private:
+    TestClean(const TestClean&)                  = delete;
+    const TestClean& operator=(const TestClean&) = delete;
+
+public:
+    explicit TestClean(int timeout = 25) : timeout_(timeout) { ZombieUtil::test_clean_up(timeout); }
+    ~TestClean() { ZombieUtil::test_clean_up(timeout_); }
+
+private:
+    int timeout_;
+};
+
+#endif /* ecflow_test_harness_ZombieUtil_HPP */
diff -pruN 5.12.4-1/libs/test/src/ZombieUtill.cpp 5.13.0-1/libs/test/src/ZombieUtill.cpp
--- 5.12.4-1/libs/test/src/ZombieUtill.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/test/src/ZombieUtill.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,173 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestFixture.hpp"
+#include "ZombieUtil.hpp"
+#include "ecflow/attribute/Zombie.hpp"
+#include "ecflow/core/AssertTimer.hpp"
+
+using namespace std;
+using namespace ecf;
+
+void ZombieUtil::test_clean_up(int timeout) {
+
+    // try to tidy up. Avoid leaving zombie process that mess up tests
+    TestFixture::client().zombieGet();
+    std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+    if (!zombies.empty()) {
+        cout << "\nZombieUtil::test_clean_up: Found Zombies:\n";
+        cout << "Client Environment:\n" << TestFixture::client().to_string() << "\n";
+        cout << Zombie::pretty_print(zombies, 9) << "\n, attempting to *fob* then *remove* ...\n";
+
+        int no_fobed =
+            do_zombie_user_action(User::FOB, zombies.size(), timeout, false /* don't fail if it takes to long */);
+
+        // In order to FOB, we must wait, till a child command, talks to the server.
+        if (no_fobed) {
+            int wait = 5;
+#if defined(HPUX) || defined(_AIX)
+            wait += 5; // On these platforms wait longer,
+#endif
+            cout << "   Fobed " << no_fobed << " left over zombies. sleeping for " << wait
+                 << "s before attempting to remove\n";
+            sleep(wait);
+        }
+        (void)do_zombie_user_action(User::REMOVE, no_fobed, timeout, false /* don't fail if it takes to long */);
+    }
+}
+
+int ZombieUtil::do_zombie_user_action(User::Action uc,
+                                      int expected_action_cnt,
+                                      int max_time_to_wait,
+                                      bool fail_if_to_long) {
+    /// return the number of zombies set to user action;
+    bool ecf_debug_zombies = false;
+    if (getenv("ECF_DEBUG_ZOMBIES")) {
+        ecf_debug_zombies = true;
+        cout << "\n   do_zombie_user_action " << User::to_string(uc) << " expected_action_cnt " << expected_action_cnt
+             << "\n";
+    }
+
+    int action_set = 0;
+    std::vector<Zombie> action_set_zombies;
+    AssertTimer assertTimer(max_time_to_wait, false); // Bomb out after n seconds, fall back if test fail
+    while (true) {
+        BOOST_REQUIRE_MESSAGE(TestFixture::client().zombieGet() == 0,
+                              "zombieGet failed should return 0\n"
+                                  << TestFixture::client().errorMsg());
+        std::vector<Zombie> zombies = TestFixture::client().server_reply().zombies();
+        bool continue_looping       = false;
+        for (const Zombie& z : zombies) {
+            switch (uc) {
+                case User::FOB: {
+                    if (!z.fob()) {
+                        TestFixture::client().zombieFob(z); // UNBLOCK, child commands, allow zombie to complete, will
+                                                            // clear server_reply().zombies()
+                        continue_looping = true;
+                        action_set++;
+                        action_set_zombies.push_back(z);
+                    }
+                    break;
+                }
+                case User::FAIL: {
+                    if (!z.fail()) {
+                        TestFixture::client().zombieFail(z); // UNBLOCK, child commands, allow zombie to complete, will
+                                                             // clear server_reply().zombies()
+                        continue_looping = true;
+                        action_set++;
+                        action_set_zombies.push_back(z);
+                    }
+                    break;
+                }
+                case User::ADOPT: {
+                    if (!z.adopt()) {
+                        TestFixture::client().zombieAdopt(z); // UNBLOCK, child commands, allow zombie to complete, will
+                                                              // clear server_reply().zombies()
+                        continue_looping = true;
+                        action_set++;
+                        action_set_zombies.push_back(z);
+                    }
+                    break;
+                }
+                case User::REMOVE: {
+                    if (!z.remove()) {                         // should always return false
+                        TestFixture::client().zombieRemove(z); // This should be immediate, and is not remembered
+                        continue_looping = true;
+                        action_set++;
+                        action_set_zombies.push_back(z);
+                    }
+                    break;
+                }
+                case User::BLOCK: {
+                    if (!z.block()) {
+                        TestFixture::client().zombieBlock(z);
+                        continue_looping = true;
+                        action_set++;
+                        action_set_zombies.push_back(z);
+                    }
+                    break;
+                }
+                case User::KILL: {
+                    if (!z.kill()) {
+                        TestFixture::client().zombieKill(z);
+                        continue_looping = true;
+                        action_set++;
+                        action_set_zombies.push_back(z);
+                    }
+                    break;
+                }
+            }
+        }
+
+        if (expected_action_cnt == action_set) {
+            break; // return
+        }
+
+        if (!continue_looping && action_set > 0) {
+            if (expected_action_cnt == 0)
+                break; // return, some clients set this as 0
+        }
+
+        // make sure test does not take too long.
+        if (assertTimer.duration() >= assertTimer.timeConstraint()) {
+
+            if (expected_action_cnt > 0 && action_set > 0) {
+                if (ecf_debug_zombies)
+                    cout << "   timeing out after action_set = " << action_set
+                         << " expected_action_cnt = " << expected_action_cnt << "\n";
+                break;
+            }
+
+            std::stringstream ss;
+            ss << "do_zombie_user_action:\nExpected " << expected_action_cnt << " zombies with user action "
+               << User::to_string(uc) << " but found " << action_set << "\naction set zombies\n"
+               << Zombie::pretty_print(action_set_zombies, 6) << ", Test taking longer than time constraint of "
+               << assertTimer.timeConstraint();
+            if (fail_if_to_long) {
+                BOOST_REQUIRE_MESSAGE(false, ss.str() << " aborting\n" << Zombie::pretty_print(zombies, 6));
+            }
+            else {
+                cout << ss.str() << " breaking out\n" << Zombie::pretty_print(zombies, 6) << "\n";
+                break;
+            }
+        }
+        sleep(1);
+    }
+
+    if (ecf_debug_zombies) {
+        cout << "   " << action_set << " zombies set to user action " << User::to_string(uc) << " returning\n";
+        cout << Zombie::pretty_print(action_set_zombies, 6);
+    }
+    return action_set;
+}
diff -pruN 5.12.4-1/libs/udp/CMakeLists.txt 5.13.0-1/libs/udp/CMakeLists.txt
--- 5.12.4-1/libs/udp/CMakeLists.txt	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/CMakeLists.txt	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,104 @@
+#
+# Copyright 2009- ECMWF.
+#
+# This software is licensed under the terms of the Apache Licence version 2.0
+# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+# In applying this licence, ECMWF does not waive the privileges and immunities
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
+#
+
+# ==============================================================================
+# ECFLOW UDP server
+
+set(SERVER_TARGET ecflow_udp)
+
+set(${SERVER_TARGET}_srcs
+  # Sources
+  src/ecflow/udp/UDPServerMain.cpp
+)
+
+ecbuild_add_executable(
+  TARGET ${SERVER_TARGET}
+  SOURCES ${${SERVER_TARGET}_srcs}
+  INCLUDES
+    src
+  LIBS
+    ecflow_all
+)
+set_target_properties(${SERVER_TARGET} PROPERTIES
+  INSTALL_RPATH ""
+)
+target_clangformat(${SERVER_TARGET})
+
+
+# ==============================================================================
+# ECFLOW UDP Client
+
+set(CLIENT_TARGET ecflow_udp_client)
+
+set(${CLIENT_TARGET}_srcs
+  # HEADERS
+  src/ecflow/udp/UDPClient.hpp
+  # SOURCES
+  src/ecflow/udp/UDPClientMain.cpp
+)
+
+ecbuild_add_executable(
+  TARGET ${CLIENT_TARGET}
+  SOURCES ${${CLIENT_TARGET}_srcs}
+  INCLUDES
+    src
+  LIBS
+    pthread
+    Boost::boost
+    Boost::filesystem
+)
+set_target_properties(${CLIENT_TARGET} PROPERTIES
+  INSTALL_RPATH ""
+)
+
+target_clangformat(${CLIENT_TARGET})
+
+# ==============================================================================
+# ECFLOW UDP Test(s)
+
+set(TEST_TARGET s_udp)
+
+list(APPEND ${TEST_TARGET}_srcs
+  # HEADERS
+  test/TestSupport.hpp
+  # SOURCES
+  test/TestUDP_main.cpp
+  test/TestUDPServer.cpp
+)
+
+ecbuild_add_test(
+  TARGET
+    ${TEST_TARGET}
+  LABELS
+    integration nightly
+  SOURCES
+    ${${TEST_TARGET}_srcs}
+  LIBS
+    ${LIB_TARGET}
+    ecflow_all
+    Boost::boost
+    Boost::unit_test_framework
+    $<$<BOOL:${OPENSSL_FOUND}>:OpenSSL::SSL>
+  DEPENDS
+    ecflow_server # the server is launched to support tests
+    ${SERVER_TARGET}
+  DEFINITIONS
+    ${BOOST_TEST_DYN_LINK}
+  INCLUDES
+    src
+  WORKING_DIRECTORY
+    ${CMAKE_CURRENT_BINARY_DIR}/test_sandbox
+  ENVIRONMENT
+    "PATH=${CMAKE_BINARY_DIR}/bin:$ENV{PATH}"
+)
+
+target_clangformat(${TEST_TARGET} CONDITION ENABLE_TESTS)
+
+file(COPY test/data/reference.def DESTINATION ${CMAKE_CURRENT_BINARY_DIR}/test_sandbox/data)
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/ClientAPI.cpp 5.13.0-1/libs/udp/src/ecflow/udp/ClientAPI.cpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/ClientAPI.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/ClientAPI.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,89 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/udp/ClientAPI.hpp"
+
+#include "ecflow/client/ClientInvoker.hpp"
+
+namespace ecf {
+
+template <typename F>
+void ClientAPI::try_invoke(F f) const {
+    try {
+        f(invoker_);
+    }
+    catch (std::runtime_error& e) {
+        throw ClientAPIException(std::string("Client error detected: ") + e.what());
+    }
+    catch (...) {
+        throw ClientAPIException("Unknown client error detected");
+    }
+}
+
+ClientAPI::ClientAPI() : invoker_(std::make_unique<ClientInvoker>()) {
+}
+
+ClientAPI::~ClientAPI() = default;
+
+void ClientAPI::user_set_name(const std::string& username) {
+    invoker_->set_user_name(username);
+}
+
+void ClientAPI::user_set_password(const std::string& password) {
+    invoker_->set_password(password);
+}
+
+void ClientAPI::user_update_meter(const std::string& path, const std::string& name, const std::string& value) const {
+    try_invoke([&path, &name, &value](const auto& invoker) { invoker->alter(path, "change", "meter", name, value); });
+}
+
+void ClientAPI::user_update_label(const std::string& path, const std::string& name, const std::string& value) const {
+    try_invoke([&path, &name, &value](const auto& invoker) { invoker->alter(path, "change", "label", name, value); });
+}
+
+void ClientAPI::user_clear_event(const std::string& path, const std::string& name) const {
+    try_invoke([&path, &name](const auto& invoker) { invoker->alter(path, "change", "event", name, "clear"); });
+}
+void ClientAPI::user_set_event(const std::string& path, const std::string& name) const {
+    try_invoke([&path, &name](const auto& invoker) { invoker->alter(path, "change", "event", name, "set"); });
+}
+
+void ClientAPI::child_set_remote_id(const std::string& pid) {
+    invoker_->set_child_pid(pid);
+}
+
+void ClientAPI::child_set_password(const std::string& password) {
+    invoker_->set_child_password(password);
+}
+
+void ClientAPI::child_set_try_no(int try_no) {
+    invoker_->set_child_try_no(try_no);
+}
+
+void ClientAPI::child_update_meter(const std::string& path, const std::string& name, const std::string& value) const {
+    invoker_->set_child_path(path);
+    try_invoke([name, value](const auto& invoker) { invoker->meterTask(name, value); });
+}
+
+void ClientAPI::child_update_label(const std::string& path, const std::string& name, const std::string& value) const {
+    invoker_->set_child_path(path);
+    try_invoke([name, value](const auto& invoker) { invoker->labelTask(name, std::vector<std::string>{value}); });
+}
+
+void ClientAPI::child_clear_event(const std::string& path, const std::string& name) const {
+    invoker_->set_child_path(path);
+    try_invoke([name](const auto& invoker) { invoker->eventTask(name, "clear"); });
+}
+void ClientAPI::child_set_event(const std::string& path, const std::string& name) const {
+    invoker_->set_child_path(path);
+    try_invoke([name](const auto& invoker) { invoker->eventTask(name, "set"); });
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/ClientAPI.hpp 5.13.0-1/libs/udp/src/ecflow/udp/ClientAPI.hpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/ClientAPI.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/ClientAPI.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,73 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_ClientApi_HPP
+#define ecflow_udp_ClientApi_HPP
+
+#include <memory>
+#include <stdexcept>
+#include <string>
+
+// Forward Declaration
+class ClientInvoker;
+
+namespace ecf {
+
+struct ClientAPIException : public std::runtime_error
+{
+    explicit ClientAPIException(const char* msg) : std::runtime_error(msg) {}
+    explicit ClientAPIException(const std::string& msg) : std::runtime_error(msg) {}
+};
+
+/**
+ * The ClientAPI enables the operations available to ecFlow UDP clients.
+ */
+class ClientAPI {
+public:
+    ClientAPI();
+    ClientAPI(const ClientAPI&) = delete;
+    ClientAPI(ClientAPI&&)      = delete;
+    ~ClientAPI();
+
+    /// Define the User Name
+    void user_set_name(const std::string& username);
+
+    /// Define the User Password
+    void user_set_password(const std::string& password);
+
+    void user_update_meter(const std::string& path, const std::string& name, const std::string& value) const;
+    void user_update_label(const std::string& path, const std::string& name, const std::string& value) const;
+    void user_clear_event(const std::string& path, const std::string& name) const;
+    void user_set_event(const std::string& path, const std::string& name) const;
+
+    /// Define the Remote Id (i.e. ECF_RID) for a child Task request
+    void child_set_remote_id(const std::string& pid);
+    /// Define the Password (i.e. ECF_PASS) for a child Task request
+    void child_set_password(const std::string& password);
+    /// Define the Try Number (i.e. ECF_TRYNO) for a child Task request
+    void child_set_try_no(int try_no);
+
+    // Notice that, in the following functions, path represents ECF_NAME for a Task request
+    void child_update_meter(const std::string& path, const std::string& name, const std::string& value) const;
+    void child_update_label(const std::string& path, const std::string& name, const std::string& value) const;
+    void child_clear_event(const std::string& path, const std::string& name) const;
+    void child_set_event(const std::string& path, const std::string& name) const;
+
+private:
+    template <typename F>
+    void try_invoke(F f) const;
+
+private:
+    std::unique_ptr<ClientInvoker> invoker_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_udp_ClientApi_HPP */
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/RequestHandler.cpp 5.13.0-1/libs/udp/src/ecflow/udp/RequestHandler.cpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/RequestHandler.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/RequestHandler.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,429 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/udp/RequestHandler.hpp"
+
+#include <string>
+#include <vector>
+
+#include <nlohmann/json.hpp>
+
+#include "ecflow/core/Converter.hpp"
+#include "ecflow/udp/ClientAPI.hpp"
+#include "ecflow/udp/Trace.hpp"
+
+namespace ecf {
+
+namespace /* __anonymous__ */ {
+
+/// The interface of a `command`
+class BasicCommand {
+public:
+    virtual void execute(ClientAPI& ctx) = 0;
+    virtual ~BasicCommand()              = default;
+};
+
+/// The default implementation of a `command`, enables CRTP-based mixins
+template <typename COMMAND>
+class DefaultCommand : public BasicCommand {
+public:
+    void execute(ClientAPI& client) final { static_cast<COMMAND*>(this)->actually_execute(client); }
+};
+
+/// The `command` to update an ecFlow meter (issued by an ecFlow user)
+class CommandUserAlterMeter : public DefaultCommand<CommandUserAlterMeter> {
+public:
+    explicit CommandUserAlterMeter(std::string path, std::string name, int value)
+        : path_{std::move(path)},
+          name_{std::move(name)},
+          value_{value} {};
+    void actually_execute(const ClientAPI& client) const {
+        client.user_update_meter(path_, name_, std::to_string(value_));
+    };
+
+    static constexpr const char* COMMAND_TAG = "alter_meter";
+
+private:
+    std::string path_;
+    std::string name_;
+    int value_;
+};
+
+/// The `command` to update an ecFlow label (issued by an ecFlow user)
+class CommandUserAlterLabel : public DefaultCommand<CommandUserAlterLabel> {
+public:
+    explicit CommandUserAlterLabel(std::string path, std::string name, std::string value)
+        : path_{std::move(path)},
+          name_{std::move(name)},
+          value_{std::move(value)} {};
+    void actually_execute(const ClientAPI& client) const { client.user_update_label(path_, name_, value_); };
+
+    static constexpr const char* COMMAND_TAG = "alter_label";
+
+private:
+    std::string path_;
+    std::string name_;
+    std::string value_;
+};
+
+/// The `command` to update an ecFlow event (issued by an ecFlow user)
+class CommandUserAlterEvent : public DefaultCommand<CommandUserAlterEvent> {
+public:
+    explicit CommandUserAlterEvent(std::string path, std::string name, bool value)
+        : path_{std::move(path)},
+          name_{std::move(name)},
+          value_{value} {};
+    void actually_execute(const ClientAPI& client) const {
+        if (value_) {
+            client.user_set_event(path_, name_);
+        }
+        else {
+            client.user_clear_event(path_, name_);
+        }
+    };
+
+    static constexpr const char* COMMAND_TAG = "alter_event";
+
+private:
+    std::string path_;
+    std::string name_;
+    bool value_;
+};
+
+/// The `command` to update an ecFlow meter (issued by an ecFlow child process)
+class CommandChildUpdateMeter : public DefaultCommand<CommandChildUpdateMeter> {
+public:
+    explicit CommandChildUpdateMeter(std::string path, std::string name, int value)
+        : path_{std::move(path)},
+          name_{std::move(name)},
+          value_{value} {};
+    void actually_execute(const ClientAPI& client) const {
+        client.child_update_meter(path_, name_, std::to_string(value_));
+    };
+
+    static constexpr const char* COMMAND_TAG = "meter";
+
+private:
+    std::string path_;
+    std::string name_;
+    int value_;
+};
+
+/// The `command` to update an ecFlow label (issued by an ecFlow child process)
+class CommandChildUpdateLabel : public DefaultCommand<CommandChildUpdateLabel> {
+public:
+    explicit CommandChildUpdateLabel(std::string path, std::string name, std::string value)
+        : path_{std::move(path)},
+          name_{std::move(name)},
+          value_{std::move(value)} {};
+    void actually_execute(const ClientAPI& client) const { client.child_update_label(path_, name_, value_); };
+
+    static constexpr const char* COMMAND_TAG = "label";
+
+private:
+    std::string path_;
+    std::string name_;
+    std::string value_;
+};
+
+/// The `command` to update an ecFlow event (issued by an ecFlow child process)
+class CommandChildUpdateEvent : public DefaultCommand<CommandChildUpdateEvent> {
+public:
+    explicit CommandChildUpdateEvent(std::string path, std::string name, bool value)
+        : path_{std::move(path)},
+          name_{std::move(name)},
+          value_{value} {};
+    void actually_execute(const ClientAPI& client) const {
+        if (value_) {
+            client.child_set_event(path_, name_);
+        }
+        else {
+            client.child_clear_event(path_, name_);
+        }
+    };
+
+    static constexpr const char* COMMAND_TAG = "event";
+
+private:
+    std::string path_;
+    std::string name_;
+    bool value_;
+};
+
+/// The actual (type erased) `command`
+class Command {
+public:
+    //
+    // (1) Declaring a user-defined constructor effectively disables a default constructor
+    // (2) Since the std::unique_ptr data member has a deleted copy-constructor,
+    //     the implicitly deplared copy-constructor of Command is also deleted
+    // (3) An implicitly declared move-constructor makes Command a move-only class
+    //
+
+    template <typename COMMAND, typename... ARGS>
+    static Command make_command(ARGS&&... args) {
+        return Command{std::make_unique<COMMAND>(std::forward<ARGS>(args)...)};
+    }
+
+    void execute(ClientAPI& client) const { impl_->execute(client); }
+
+private:
+    explicit Command(std::unique_ptr<BasicCommand>&& impl) : impl_{std::move(impl)} {}
+
+    std::unique_ptr<BasicCommand> impl_;
+};
+
+/// The `command` build interface
+class CommandBuilder {
+public:
+    virtual ~CommandBuilder()                 = default;
+    virtual const char* name()                = 0;
+    virtual Command build(nlohmann::json obj) = 0;
+};
+
+/// The builder for a `command` to update an ecFlow label (issued by an ecFlow user)
+class CommandUserAlterLabelBuilder : public CommandBuilder {
+public:
+    const char* name() override { return CommandUserAlterLabel::COMMAND_TAG; };
+    Command build(nlohmann::json obj) override {
+        assert(obj.at("command") == name());
+
+        std::string name  = obj.at("name");
+        std::string path  = obj.at("path");
+        std::string value = obj.at("value");
+
+        return Command::make_command<CommandUserAlterLabel>(path, name, value);
+    }
+};
+
+/// The builder for a `command` to update an ecFlow meter (issued by an ecFlow user)
+class CommandUserAlterMeterBuilder : public CommandBuilder {
+public:
+    const char* name() override { return CommandUserAlterMeter::COMMAND_TAG; };
+    Command build(nlohmann::json obj) override {
+        assert(obj.at("command") == name());
+
+        std::string name  = obj.at("name");
+        std::string path  = obj.at("path");
+        std::string value = obj.at("value");
+
+        auto meter_value = ecf::convert_to<int>(value);
+
+        return Command::make_command<CommandUserAlterMeter>(path, name, meter_value);
+    }
+};
+
+/// The builder for a `command` to update an ecFlow event (issued by an ecFlow user)
+class CommandUserAlterEventBuilder : public CommandBuilder {
+public:
+    const char* name() override { return CommandUserAlterEvent::COMMAND_TAG; };
+    Command build(nlohmann::json obj) override {
+        assert(obj.at("command") == name());
+
+        std::string name  = obj.at("name");
+        std::string path  = obj.at("path");
+        std::string value = obj.at("value");
+
+        bool event_value;
+        if (value == "1") {
+            event_value = true;
+        }
+        else if (value == "0") {
+            event_value = false;
+        }
+        else {
+            throw std::runtime_error("Unexpected Event value");
+        }
+
+        return Command::make_command<CommandUserAlterEvent>(path, name, event_value);
+    }
+};
+
+/// The builder for a `command` to update an ecFlow label (issued by an ecFlow child process)
+class CommandChildUpdateLabelBuilder : public CommandBuilder {
+public:
+    const char* name() override { return CommandChildUpdateLabel::COMMAND_TAG; };
+    Command build(nlohmann::json obj) override {
+        assert(obj.at("command") == name());
+
+        std::string name  = obj.at("name");
+        std::string path  = obj.at("path");
+        std::string value = obj.at("value");
+
+        TRACE_NFO("CommandChildUpdateLabelBuilder", "update to label ", path, ":", name, " to value: ", value)
+
+        return Command::make_command<CommandChildUpdateLabel>(path, name, value);
+    }
+};
+
+/// The builder for a `command` to update an ecFlow meter (issued by an ecFlow child process)
+class CommandChildUpdateMeterBuilder : public CommandBuilder {
+public:
+    const char* name() override { return CommandChildUpdateMeter::COMMAND_TAG; };
+    Command build(nlohmann::json obj) override {
+        assert(obj.at("command") == name());
+
+        std::string name  = obj.at("name");
+        std::string path  = obj.at("path");
+        std::string value = obj.at("value");
+
+        auto meter_value = ecf::convert_to<int>(value);
+
+        TRACE_NFO("CommandChildUpdateLabelBuilder", "update to meter ", path, ":", name, " to value: ", meter_value)
+
+        return Command::make_command<CommandChildUpdateMeter>(path, name, meter_value);
+    }
+};
+
+/// The builder for a `command` to update an ecFlow event (issued by an ecFlow child process)
+class CommandChildUpdateEventBuilder : public CommandBuilder {
+public:
+    const char* name() override { return CommandChildUpdateEvent::COMMAND_TAG; };
+    Command build(nlohmann::json obj) override {
+        assert(obj.at("command") == name());
+
+        std::string name  = obj.at("name");
+        std::string path  = obj.at("path");
+        std::string value = obj.at("value");
+
+        bool event_value;
+        if (value == "1") {
+            event_value = true;
+        }
+        else if (value == "0") {
+            event_value = false;
+        }
+        else {
+            throw std::runtime_error("Unexpected Event value");
+        }
+
+        TRACE_NFO("CommandChildUpdateLabelBuilder", "update to event ", path, ":", name, " to value: ", event_value)
+
+        return Command::make_command<CommandChildUpdateEvent>(path, name, event_value);
+    }
+};
+
+/// The factory of `command`; creates commands based on JSON data
+class CommandFactory {
+public:
+    CommandFactory() : builders_{} {
+        builders_.push_back(std::make_unique<CommandUserAlterLabelBuilder>());
+        builders_.push_back(std::make_unique<CommandUserAlterMeterBuilder>());
+        builders_.push_back(std::make_unique<CommandUserAlterEventBuilder>());
+        builders_.push_back(std::make_unique<CommandChildUpdateLabelBuilder>());
+        builders_.push_back(std::make_unique<CommandChildUpdateMeterBuilder>());
+        builders_.push_back(std::make_unique<CommandChildUpdateEventBuilder>());
+    };
+
+    Command make_command_from(nlohmann::json obj) {
+        std::string name = obj.at("command");
+        auto found       = std::find_if(std::begin(builders_), std::end(builders_), [&name](const auto& builder) {
+            return builder->name() == name;
+        });
+
+        if (found == std::end(builders_)) {
+            throw std::runtime_error("Unknown command detected");
+        }
+
+        return found->get()->build(obj);
+    }
+
+    std::vector<std::unique_ptr<CommandBuilder>> builders_;
+};
+
+class JSONRequestHandler {
+public:
+    JSONRequestHandler() : client_{} {}
+
+    void handle(const nlohmann::json& request) {
+        try {
+            std::string method_type = request.at("method");
+
+            // process "header"
+            if (request.contains("header")) {
+                nlohmann::json header = request.at("header");
+                configure_authentication(header);
+            }
+
+            // process "data"
+            if (method_type == "put") {
+                auto payload = request.at("payload");
+
+                Command command = command_factory_.make_command_from(payload);
+                command.execute(client_);
+            }
+            else {
+                TRACE_ERR("JSONRequestHandler", "unknown method: ", method_type)
+            }
+        }
+        catch (nlohmann::json::exception& e) {
+            TRACE_ERR("JSONRequestHandler", "JSON format error: ", e.what())
+            return;
+        }
+        catch (ClientAPIException& e) {
+            TRACE_ERR("JSONRequestHandler", "Client invocation error: ", e.what())
+            return;
+        }
+        catch (...) {
+            TRACE_ERR("JSONRequestHandler", "Unknown error detected handling request")
+            return;
+        }
+
+        TRACE_NFO("JSONRequestHandler", "request handled successfully")
+    }
+
+    void configure_authentication(const nlohmann::json& header) {
+        for (const auto& [key, value] : header.items()) {
+
+            if (key == "user_name") {
+                client_.user_set_name(value);
+            }
+            else if (key == "user_password") {
+                client_.user_set_password(value);
+            }
+            else if (key == "task_rid") {
+                client_.child_set_remote_id(value);
+            }
+            else if (key == "task_password") {
+                client_.child_set_password(value);
+            }
+            else if (key == "task_try_no") {
+                client_.child_set_try_no(value);
+            }
+            else {
+                TRACE_ERR("JSONRequestHandler", "unknown header: ", key, ", ignored.")
+            }
+        }
+    }
+
+private:
+    ClientAPI client_;
+    CommandFactory command_factory_;
+};
+
+} // namespace
+
+void RequestHandler::handle(const RequestHandler::inbound_t& request) const {
+    try {
+        TRACE_NFO("RequestHandler", "Processing request: ", request)
+
+        nlohmann::json inbound = nlohmann::json::parse(request);
+        JSONRequestHandler handler;
+        handler.handle(inbound);
+    }
+    catch (nlohmann::json::exception& e) {
+        TRACE_ERR("RequestHandler", "Unable to parse JSON request")
+    }
+    catch (...) {
+        TRACE_ERR("RequestHandler", "Unknown error detected")
+    }
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/RequestHandler.hpp 5.13.0-1/libs/udp/src/ecflow/udp/RequestHandler.hpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/RequestHandler.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/RequestHandler.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_RequestHandler_HPP
+#define ecflow_udp_RequestHandler_HPP
+
+#include <string>
+
+namespace ecf {
+
+/**
+ * Enables the handling of all requests by a ecFlow UDP server
+ */
+struct RequestHandler
+{
+public:
+    using inbound_t = std::string;
+
+public:
+    void handle(const inbound_t& request) const;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_udp_RequestHandler_HPP */
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/Trace.cpp 5.13.0-1/libs/udp/src/ecflow/udp/Trace.cpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/Trace.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/Trace.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,29 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/udp/Trace.hpp"
+
+#include <iostream>
+
+namespace ecf::log {
+
+Trace::Trace() : output_{std::cout}, verbose_{false} {
+}
+
+void Trace::store(const std::string& entry) const {
+    output_ << entry << std::endl;
+}
+
+Trace& getTrace() {
+    static Trace instance;
+    return instance;
+}
+
+} // namespace ecf::log
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/Trace.hpp 5.13.0-1/libs/udp/src/ecflow/udp/Trace.hpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/Trace.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/Trace.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_Trace_HPP
+#define ecflow_udp_Trace_HPP
+
+#include <sstream>
+#include <string>
+
+namespace ecf::log {
+
+class Trace {
+public:
+    Trace();
+    ~Trace() = default;
+
+    inline void setVerbose(bool verbose) { verbose_ = verbose; }
+
+    template <typename... ARGS>
+    void add(const std::string& qualifier, const std::string& location, ARGS... args) const {
+        if (verbose_) {
+            std::ostringstream os;
+            os << "   " << location << " (" << qualifier << "): ";
+            ((os << args), ...);
+            store(os.str());
+        }
+    }
+
+private:
+    void store(const std::string& entry) const;
+
+    std::ostream& output_;
+    bool verbose_;
+};
+
+Trace& getTrace();
+
+} // namespace ecf::log
+
+#define TRACE_VERBOSE(verbose) \
+    { ecf::log::getTrace().setVerbose(verbose); }
+
+#define TRACE_NFO(location, ...) \
+    { ecf::log::getTrace().add("info", location, __VA_ARGS__); }
+
+#define TRACE_ERR(location, ...) \
+    { ecf::log::getTrace().add("error", location, __VA_ARGS__); }
+
+#define TRACE_FATAL(location, ...) \
+    { ecf::log::getTrace().add("error", location, __VA_ARGS__); }
+
+#endif /* ecflow_udp_Trace_HPP */
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPClient.hpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPClient.hpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPClient.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPClient.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,95 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_UDPClient_HPP
+#define ecflow_udp_UDPClient_HPP
+
+#include <string>
+
+#include <boost/asio.hpp>
+
+namespace ecf {
+
+namespace internal_detail {
+
+/**
+ * The UDP connection implemented using Boost.ASIO, sends a single Datagram in a "fire and forget" protocol.
+ */
+class BaseUDPConnection {
+public:
+    BaseUDPConnection(boost::asio::io_service& io_service,
+                      boost::asio::ip::udp::endpoint server_endpoint,
+                      const std::string& request)
+        : socket_(io_service),
+          server_endpoint_(std::move(server_endpoint)) {
+        // Open socket connection
+        socket_.open(boost::asio::ip::udp::v4());
+        // Start 'protocol'...
+        start(request);
+    }
+
+private:
+    void start(const std::string& request) {
+        std::array<char, 65'507> request_buffer{};
+        std::copy_n(std::begin(request), request.size() + 1, std::begin(request_buffer));
+
+        // Send request
+        socket_.async_send_to(boost::asio::buffer(request_buffer, request.size() + 1),
+                              server_endpoint_,
+                              [this](const boost::system::error_code& error, size_t bytes_transferred) {
+                                  this->handle_send(error, bytes_transferred);
+                              });
+    }
+
+    void handle_send(const boost::system::error_code& error, std::size_t bytes_transferred [[maybe_unused]]) {
+        if (error) {
+            throw std::runtime_error("Unable to send request to ecFlow UDP");
+        }
+    }
+
+    boost::asio::ip::udp::socket socket_;
+
+    boost::asio::ip::udp::endpoint server_endpoint_;
+};
+
+} // namespace internal_detail
+
+/**
+ * The UDP client implemented using Boost.ASIO.
+ */
+class BaseUDPClient {
+public:
+    using hostname_t = std::string;
+    using port_t     = std::string;
+    using data_t     = std::string;
+
+public:
+    BaseUDPClient(hostname_t host, port_t port) : host_{std::move(host)}, port_{std::move(port)} {}
+
+    void send(const data_t& data) {
+        boost::asio::io_service io_service;
+        boost::asio::ip::udp::resolver resolver(io_service);
+        boost::asio::ip::udp::resolver::query query(boost::asio::ip::udp::v4(), host_, port_);
+        boost::asio::ip::udp::endpoint server_endpoint = *resolver.resolve(query);
+
+        internal_detail::BaseUDPConnection connection(io_service, server_endpoint, data);
+        io_service.run();
+    }
+
+private:
+    hostname_t host_;
+    port_t port_;
+};
+
+using UDPClient = BaseUDPClient;
+
+} // namespace ecf
+
+#endif /* ecflow_udp_UDPClient_HPP */
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPClientMain.cpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPClientMain.cpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPClientMain.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPClientMain.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,40 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <utility>
+
+#include "ecflow/udp/UDPClient.hpp"
+
+int main(int argc, char* argv[]) {
+    if (argc != 4) {
+        std::cerr << "Usage: udp_client <host> <port> <request>" << std::endl;
+        return EXIT_FAILURE;
+    }
+
+    try {
+        std::string host    = argv[1];
+        std::string port    = argv[2];
+        std::string request = argv[3];
+
+        ecf::UDPClient client(host, port);
+        client.send(request);
+    }
+    catch (std::exception& e) {
+        std::cerr << e.what() << std::endl;
+        return EXIT_FAILURE;
+    }
+    catch (...) {
+        std::cerr << "Unknown error..." << std::endl;
+        return EXIT_FAILURE;
+    }
+
+    return EXIT_SUCCESS;
+}
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPServer.hpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPServer.hpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPServer.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPServer.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_UDPServer_HPP
+#define ecflow_udp_UDPServer_HPP
+
+#include <string>
+
+#include <boost/asio.hpp>
+
+#include "ecflow/udp/RequestHandler.hpp"
+
+namespace ecf {
+
+namespace internal_detail {
+
+template <typename HANDLER>
+class BaseUdpServerConnection {
+public:
+    BaseUdpServerConnection(HANDLER handler,
+                            boost::asio::io_service& io_service,
+                            const boost::asio::ip::udp::endpoint& server_endpoint)
+        : handler_{std::move(handler)},
+          socket_(io_service, server_endpoint),
+          client_endpoint_{},
+          buffer_{} {
+        start();
+    }
+
+private:
+    void start() {
+        // Receive request
+        socket_.async_receive_from(boost::asio::buffer(buffer_),
+                                   client_endpoint_,
+                                   [this](const boost::system::error_code& error, size_t bytes_transferred) {
+                                       this->handleReceive(error, bytes_transferred);
+                                   });
+    }
+
+    void handleReceive(const boost::system::error_code& error, std::size_t bytes_transferred) {
+        if (!error) {
+            // Take inbound request from (inbound) buffer...
+            std::string request;
+            std::copy_n(std::begin(buffer_), bytes_transferred, std::back_inserter(request));
+
+            // Process request
+            handler_.handle(request);
+        }
+        else {
+            std::cerr << "    BaseUDPServer (error): failure when receiving message" << std::endl;
+        }
+
+        start();
+    }
+
+private:
+    HANDLER handler_;
+    boost::asio::ip::udp::socket socket_;
+
+    // Used as information passed between async calls
+    boost::asio::ip::udp::endpoint client_endpoint_;
+    std::array<char, 65'507> buffer_;
+};
+
+} // namespace internal_detail
+
+/**
+ * The UDP server listens for network packets, and delegates the requests to the given HANDLER
+ */
+template <typename HANDLER>
+class BaseUdpServer {
+public:
+    BaseUdpServer(HANDLER handler, uint16_t port)
+        : io_service_{},
+          server_endpoint_{boost::asio::ip::udp::v4(), port},
+          connection_{handler, io_service_, server_endpoint_} {}
+    BaseUdpServer(const BaseUdpServer&) = delete;
+    BaseUdpServer(BaseUdpServer&&)      = delete;
+
+    void run() { io_service_.run(); }
+
+private:
+    boost::asio::io_service io_service_;
+    boost::asio::ip::udp::endpoint server_endpoint_;
+    internal_detail::BaseUdpServerConnection<HANDLER> connection_;
+};
+
+using UDPServer = BaseUdpServer<RequestHandler>;
+
+} // namespace ecf
+
+#endif /* ecflow_udp_UDPServer_HPP */
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.cpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.cpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,51 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/udp/UDPServerEnvironment.hpp"
+
+#include <cstdio>
+
+namespace ecf {
+
+namespace /* __anonymous__ */ {
+
+// all variables to be collected
+const char* const variables[] = {UDPServerEnvironment::ECF_UDP_VERBOSE,
+                                 UDPServerEnvironment::ECF_UDP_PORT,
+                                 UDPServerEnvironment::ECF_HOST,
+                                 UDPServerEnvironment::ECF_PORT};
+
+// the options related to each of the variables
+const std::unordered_map<std::string, std::string> options_map = {{UDPServerEnvironment::ECF_UDP_VERBOSE, "verbose"},
+                                                                  {UDPServerEnvironment::ECF_UDP_PORT, "port"},
+                                                                  {UDPServerEnvironment::ECF_HOST, "ecflow_host"},
+                                                                  {UDPServerEnvironment::ECF_PORT, "ecflow_port"}};
+
+} // namespace
+
+UDPServerEnvironment::UDPServerEnvironment() : environment_{} {
+    for (auto variable : variables) {
+        if (const char* value = ::getenv(variable); value) {
+            environment_[variable] = value;
+        }
+    }
+}
+
+std::string UDPServerEnvironment::as_configuration_file() const {
+    std::ostringstream os;
+    for (const auto& entry : environment_) {
+        if (auto found = options_map.find(entry.first); found != std::end(options_map)) {
+            os << found->second << "=" << entry.second << std::endl;
+        }
+    }
+    return os.str();
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.hpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.hpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerEnvironment.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,62 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_UDPServerEnvironment_HPP
+#define ecflow_udp_UDPServerEnvironment_HPP
+
+#include <optional>
+#include <string>
+#include <unordered_map>
+#include <vector>
+
+#include "ecflow/core/Converter.hpp"
+
+namespace ecf {
+
+/**
+ * Allows to collect information about environment variables related to ecFlow UDP,
+ * and eventually customizes the options used to launch the server.
+ */
+class UDPServerEnvironment {
+private:
+    using storage_t = std::unordered_map<std::string, std::string>;
+
+public:
+    UDPServerEnvironment();
+
+    bool get_variable(const std::string& key) const {
+        auto found = environment_.find(key);
+        return found != std::end(environment_);
+    }
+
+    template <typename U, std::enable_if_t<!std::is_same_v<bool, U>, bool> = true>
+    std::optional<U> get_variable(const std::string& key) const {
+        auto found = environment_.find(key);
+        if (found != std::end(environment_)) {
+            return ecf::convert_to<U>(found->second);
+        }
+        return {};
+    }
+
+    std::string as_configuration_file() const;
+
+public:
+    static constexpr const char* ECF_UDP_VERBOSE = "ECF_UDP_VERBOSE";
+    static constexpr const char* ECF_UDP_PORT    = "ECF_UDP_PORT";
+    static constexpr const char* ECF_HOST        = "ECF_HOST";
+    static constexpr const char* ECF_PORT        = "ECF_PORT";
+
+private:
+    storage_t environment_;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_udp_UDPServerEnvironment_HPP */
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerMain.cpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerMain.cpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerMain.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerMain.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,104 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <iostream>
+#include <string>
+
+#include "ecflow/core/ecflow_version.h"
+#include "ecflow/udp/RequestHandler.hpp"
+#include "ecflow/udp/Trace.hpp"
+#include "ecflow/udp/UDPServer.hpp"
+#include "ecflow/udp/UDPServerOptions.hpp"
+
+static std::string ecflow_udp_server_version() {
+#ifdef DEBUG
+    const std::string TAG = " (debug) ";
+#else
+    const std::string TAG = " ";
+#endif
+
+    std::ostringstream oss;
+    oss << "Ecflow UDP" << TAG << "version(" << ECFLOW_RELEASE << "." << ECFLOW_MAJOR << "." << ECFLOW_MINOR << ")";
+    return oss.str();
+}
+
+static void run_server(uint16_t port) {
+    ecf::RequestHandler handler;
+    ecf::UDPServer server{handler, port};
+    server.run();
+}
+
+static int launch_server(const ecf::UDPServerOptions& options) {
+    bool verbose = options.has_verbose();
+    TRACE_VERBOSE(verbose)
+
+    auto port = options.get_option<size_t>(ecf::UDPServerOptions::OPTION_PORT);
+    TRACE_NFO("UDPServerMain", "starting server on port ", port)
+
+    try {
+        run_server(static_cast<uint16_t>(port));
+    }
+    catch (const std::exception& e) {
+        TRACE_FATAL("UDPServerMain", e.what())
+        return EXIT_FAILURE;
+    }
+    catch (...) {
+        TRACE_FATAL("UDPServerMain", "unknown error detected")
+        return EXIT_FAILURE;
+    }
+
+    return EXIT_SUCCESS;
+}
+
+int main(int argc, char* argv[]) try {
+
+    ecf::UDPServerOptions options(argc, const_cast<const char**>(argv));
+
+    if (options.has_help()) {
+        std::cout << std::endl << "  ecFlow UDP" << std::endl << std::endl;
+        std::cout << options.get_description() << std::endl;
+        return EXIT_SUCCESS;
+    }
+    if (options.has_version()) {
+        std::cout << ecflow_udp_server_version() << std::endl;
+        return EXIT_SUCCESS;
+    }
+
+    {
+        // Ensure the Client uses the ecFlow host+port
+        auto ecflow_host = options.get_optional_option<std::string>(ecf::UDPServerOptions::OPTION_ECFLOW_HOST);
+        auto ecflow_port = options.get_optional_option<size_t>(ecf::UDPServerOptions::OPTION_ECFLOW_PORT);
+        if (ecflow_host) {
+            setenv("ECF_HOST", ecflow_host.value().c_str(), 1);
+        }
+        if (ecflow_port) {
+            setenv("ECF_PORT", std::to_string(ecflow_port.value()).c_str(), 1);
+        }
+        // Avoid that the Client automatically uses environment passwords
+        unsetenv("ECF_PASSWD");
+        unsetenv("ECF_CUSTOM_PASSWD");
+
+        launch_server(options);
+    }
+
+    return EXIT_SUCCESS;
+}
+catch (ecf::InvalidCLIOption& e) {
+    std::cout << "Error: Invalid CLI option detected: " << e.what() << std::endl;
+    return EXIT_FAILURE;
+}
+catch (std::exception& e) {
+    std::cout << "Error: Unexpected problem detected: " << e.what() << std::endl;
+    return EXIT_FAILURE;
+}
+catch (...) {
+    std::cout << "Error: Unknown problem detected. Cowardly giving up!..." << std::endl;
+    return EXIT_FAILURE;
+}
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerOptions.cpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerOptions.cpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerOptions.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerOptions.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,98 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include "ecflow/udp/UDPServerOptions.hpp"
+
+#include "ecflow/udp/UDPServerEnvironment.hpp"
+
+namespace ecf {
+
+InvalidCLIOption::~InvalidCLIOption() = default;
+
+namespace {
+
+template <typename... Args>
+std::string as_string(Args... args) {
+    std::ostringstream os;
+    ((os << args), ...);
+    return os.str();
+}
+
+} // namespace
+
+UDPServerOptions::UDPServerOptions(int argc, const char* argv[]) : general{create_options()}, variables{} {
+
+    po::options_description all_options("All");
+    all_options.add(general);
+
+    try {
+        // Collect command line options
+        po::command_line_parser parser{argc, argv};
+        parser.options(all_options)
+            .style(po::command_line_style::default_style | po::command_line_style::allow_slash_for_short);
+        auto cli_options = parser.run();
+        po::store(cli_options, variables);
+
+        // Collect environment options
+        // note: by being processed later, environment options don't override cli options)
+        UDPServerEnvironment environment;
+        std::stringstream ss;
+        ss << environment.as_configuration_file();
+        auto env_options = po::parse_config_file(ss, all_options, true);
+        po::store(env_options, variables);
+
+        ensure_valid_options(variables);
+
+        po::notify(variables);
+    }
+    catch (const po::error& error) {
+        throw InvalidCLIOption(error.what());
+    }
+    catch (const InvalidCLIOption& error) {
+        throw error;
+    }
+}
+
+void UDPServerOptions::ensure_valid_options(const po::variables_map& variables) {
+    if (variables.count(OPTION_HELP) > 0) {
+        // Nothing to do, help will be displayed even if other options are provided
+        return;
+    }
+
+    if (variables.count(OPTION_VERSION) > 0) {
+        // Nothing to do, version will be displayed even if other options are provided
+        return;
+    }
+
+    // Add all necessary options validation here!...
+}
+
+po::options_description UDPServerOptions::create_options() {
+    po::options_description general{"General"};
+    // clang-format off
+    general.add_options()
+        (as_string(OPTION_HELP, ",h").c_str(),
+                        "Display options help")
+        (as_string(OPTION_VERSION, ",v").c_str(),
+                        "Display version information")
+        (as_string(OPTION_VERBOSE).c_str(),
+                        "Display debug information during execution")
+        (as_string(OPTION_PORT, ",p").c_str(), po::value<size_t>()->default_value(8080),
+                        "The port to listen for UDP packets")
+        (as_string(OPTION_ECFLOW_HOST).c_str(), po::value<std::string>(),
+                        "The ecFlow server port to forward requests")
+        (as_string(OPTION_ECFLOW_PORT).c_str(), po::value<size_t>()->default_value(3141),
+                        "The ecFlow server port to forward requests");
+    // clang-format on
+
+    return general;
+}
+
+} // namespace ecf
diff -pruN 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerOptions.hpp 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerOptions.hpp
--- 5.12.4-1/libs/udp/src/ecflow/udp/UDPServerOptions.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/src/ecflow/udp/UDPServerOptions.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,79 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_UDPServerOptions_HPP
+#define ecflow_udp_UDPServerOptions_HPP
+
+#include <optional>
+#include <string>
+
+#include <boost/program_options.hpp>
+
+namespace po = boost::program_options;
+
+namespace ecf {
+
+class InvalidCLIOption : public std::logic_error {
+public:
+    explicit InvalidCLIOption(const std::string& error) : logic_error(error) {}
+    InvalidCLIOption(const InvalidCLIOption&) = default;
+    virtual ~InvalidCLIOption();
+};
+
+/**
+ * Processes the CLI options used by ecFlow UDP server, including any environment variables that need to be considered.
+ */
+class UDPServerOptions {
+public:
+    UDPServerOptions(int argc, const char* argv[]);
+
+    ~UDPServerOptions() = default;
+
+    bool get_option(const std::string& option) const { return variables.count(option) > 0; }
+
+    template <typename U, std::enable_if_t<!std::is_same_v<bool, U>, bool> = true>
+    const U& get_option(const std::string& option) const {
+        return variables[option].template as<U>();
+    }
+
+    template <typename U, std::enable_if_t<!std::is_same_v<bool, U>, bool> = true>
+    std::optional<U> get_optional_option(const std::string& option) const {
+        if (variables.count(option) > 0) {
+            return variables[option].template as<U>();
+        }
+        return std::nullopt;
+    }
+
+    bool has_help() const { return get_option(OPTION_HELP); }
+    bool has_version() const { return get_option(OPTION_VERSION); }
+    bool has_verbose() const { return get_option(OPTION_VERBOSE); }
+
+    const po::options_description& get_description() const { return general; }
+
+    static po::options_description create_options();
+
+public:
+    static inline const char* OPTION_HELP        = "help";
+    static inline const char* OPTION_VERSION     = "version";
+    static inline const char* OPTION_VERBOSE     = "verbose";
+    static inline const char* OPTION_PORT        = "port";
+    static inline const char* OPTION_ECFLOW_HOST = "ecflow_host";
+    static inline const char* OPTION_ECFLOW_PORT = "ecflow_port";
+
+private:
+    static void ensure_valid_options(const po::variables_map& variables);
+
+    po::options_description general;
+    po::variables_map variables;
+};
+
+} // namespace ecf
+
+#endif /* ecflow_udp_UDPServerOptions_HPP */
diff -pruN 5.12.4-1/libs/udp/test/TestSupport.hpp 5.13.0-1/libs/udp/test/TestSupport.hpp
--- 5.12.4-1/libs/udp/test/TestSupport.hpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/test/TestSupport.hpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,294 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#ifndef ecflow_udp_test_TestSupport_HPP
+#define ecflow_udp_test_TestSupport_HPP
+
+#include <memory>
+#include <thread>
+
+#include <boost/asio.hpp>
+#include <boost/process.hpp>
+#include <boost/test/unit_test.hpp>
+
+#include "ecflow/attribute/NodeAttr.hpp"
+#include "ecflow/client/ClientInvoker.hpp"
+#include "ecflow/core/EcfPortLock.hpp"
+#include "ecflow/core/File.hpp"
+#include "ecflow/core/Host.hpp"
+#include "ecflow/core/Str.hpp"
+#include "ecflow/node/Defs.hpp"
+#include "ecflow/node/Node.hpp"
+#include "ecflow/udp/UDPClient.hpp"
+
+namespace bp = boost::process;
+
+namespace ecf::test {
+
+template <typename SERVER>
+class BaseMockServer {
+public:
+    using hostname_t = std::string;
+    using port_t     = uint16_t;
+
+    template <typename... Args>
+    BaseMockServer(hostname_t host, port_t port, Args... args) : host_{std::move(host)},
+                                                                 port_{port},
+                                                                 server_{} {
+        BOOST_REQUIRE_MESSAGE(!host_.empty(), "determiner host name");
+        BOOST_REQUIRE_MESSAGE(port_ > 0, "port is be larger than 0");
+
+        server_ = SERVER::launch(host_, port_, std::forward<Args>(args)...);
+        std::cout << "   MOCK: " << SERVER::designation << " has been started!" << std::endl;
+    }
+    BaseMockServer(const BaseMockServer&) = delete;
+    BaseMockServer(BaseMockServer&&)      = delete;
+
+    ~BaseMockServer() {
+        server_.terminate();
+        SERVER::cleanup(host_, port_);
+        std::cout << "   MOCK: " << SERVER::designation << " has been terminated!" << std::endl;
+    }
+
+    const hostname_t& host() const { return host_; }
+    uint16_t port() const { return port_; }
+
+private:
+    hostname_t host_;
+    uint16_t port_;
+
+    bp::child server_;
+};
+
+/**
+ * A "mock" ecFlow server, launches the server on a separate process, and enables checking changes in Defs state
+ */
+class MockServer : public BaseMockServer<MockServer> {
+public:
+    explicit MockServer(port_t port) : BaseMockServer<MockServer>(ecf::Host{}.name(), port) {}
+
+    void load_definition(const std::string& defs) const {
+        ClientInvoker client(ecf::Str::LOCALHOST(), port());
+        try {
+            BOOST_REQUIRE_MESSAGE(fs::exists(defs), "definitions file exists at: " + defs);
+            auto error = client.loadDefs(defs);
+            BOOST_REQUIRE_MESSAGE(!error, "load definitions, without error ");
+        }
+        catch (std::exception& e) {
+            BOOST_REQUIRE_MESSAGE(
+                false, "load definitions, without throwing exception (but threw: " + std::string(e.what()) + ")");
+        }
+
+        std::cout << "   MOCK: reference ecFlow suite has been loaded" << std::endl;
+    }
+
+    Meter get_meter(const std::string& path, const std::string& name) const {
+        node_ptr node = get_node_at(path);
+        return get_attribute_by_name(node->meters(), name);
+    }
+
+    Label get_label(const std::string& path, const std::string& name) const {
+        node_ptr node = get_node_at(path);
+        return get_attribute_by_name(node->labels(), name);
+    }
+
+    Event get_event(const std::string& path, const std::string& name) const {
+        node_ptr node = get_node_at(path);
+        return get_attribute_by_name(node->events(), name);
+    }
+
+private:
+    node_ptr get_node_at(const std::string& path) const {
+        std::cout << "   Creating ecflow_client connected to " << host() << ":" << port() << std::endl;
+        ClientInvoker client(ecf::Str::LOCALHOST(), port());
+
+        // load all definitions
+        std::shared_ptr<Defs> defs = nullptr;
+        client.sync(defs);
+
+        // select node at intended path
+        node_ptr node = defs->findAbsNode(path);
+        BOOST_REQUIRE_MESSAGE(node, "unable to find node");
+
+        return node;
+    }
+
+    template <typename ATTRIBUTE>
+    static ATTRIBUTE get_attribute_by_name(const std::vector<ATTRIBUTE>& attribs, const std::string& name) {
+        auto found = std::find_if(
+            std::begin(attribs), std::end(attribs), [&name](const ATTRIBUTE& attrib) { return attrib.name() == name; });
+        BOOST_REQUIRE_MESSAGE(found != std::end(attribs), "unable to find attribute");
+        return *found;
+    }
+
+public:
+    static constexpr const char* designation = "ecFlow server";
+
+    static bp::child launch(const hostname_t& host, port_t port) {
+        // Just for precaution, in case a previous run didn't clean up...
+        cleanup(host, port);
+
+        std::string invoke_command = ecf::File::find_ecf_server_path();
+
+        BOOST_REQUIRE_MESSAGE(!invoke_command.empty(), "The server program could not be found");
+        BOOST_REQUIRE_MESSAGE(fs::exists(invoke_command), "Server exe does not exist at:" << invoke_command);
+
+        invoke_command += " --port ";
+        invoke_command += std::to_string(port);
+        invoke_command += " -d &";
+
+        std::cout << "Launching ecflow_server @" << host << ":" << port << ", with: " << invoke_command << std::endl;
+
+        bp::child child(invoke_command);
+
+        ClientInvoker client(ecf::Str::LOCALHOST(), port);
+        if (!client.wait_for_server_reply(5)) {
+            BOOST_REQUIRE_MESSAGE(false, "could not launch ecflow server");
+        }
+
+        return child;
+    }
+
+    static void cleanup(const hostname_t& host, port_t port) {
+        // Clean up temporary files created by the server instance
+        std::string temporaries[]{host + '.' + std::to_string(port) + ".ecf.check",
+                                  host + '.' + std::to_string(port) + ".ecf.check.b",
+                                  host + '.' + std::to_string(port) + ".ecf.log"};
+        for (const auto& t : temporaries) {
+            fs::remove(t);
+        }
+    }
+};
+
+/**
+ * A "mock" ecFlow UDP server, launches the server on a separate process, and enables triggering operations
+ */
+class MockUDPServer : public BaseMockServer<MockUDPServer> {
+public:
+    explicit MockUDPServer(port_t port, port_t ecflow_port)
+        : BaseMockServer<MockUDPServer>("localhost", port, ecflow_port) {}
+
+    void update_label(const std::string& path, const std::string& name, const std::string& value) {
+        auto request = format_request(path, "alter_label", name, value);
+        send(request);
+    }
+
+    void update_meter(const std::string& path, const std::string& name, int value) {
+        auto request = format_request(path, "alter_meter", name, value);
+        send(request);
+    }
+
+    void clear_event(const std::string& path, const std::string& name) {
+        auto request = format_request(path, "alter_event", name, "0");
+        send(request);
+    }
+    void set_event(const std::string& path, const std::string& name) {
+        auto request = format_request(path, "alter_event", name, "1");
+        send(request);
+    }
+
+    void send(const std::string& request) {
+        std::cout << "   MOCK: UDP Client sending request: " << request << std::endl;
+        sendRequest(port(), request);
+    }
+
+private:
+    template <typename V>
+    static std::string
+    format_request(const std::string& path, const std::string& command, const std::string& name, V value) {
+        std::ostringstream oss;
+        // clang-format off
+        oss << R"({)"
+                << R"("method":"put",)"
+                << R"("payload":)"
+                << R"({)"
+                    << R"("command":")" << command << R"(",)"
+                    << R"("path":")" << path << R"(",)"
+                    << R"("name":")" << name << R"(",)"
+                    << R"("value":")"<< value << R"(")"
+                << R"(})"
+            << R"(})";
+        // clang-format on
+        return oss.str();
+    }
+
+    static void sendRequest(uint16_t port, const std::string& request) {
+        const std::string host = "localhost";
+        std::cout << "   Creating ecflow_udp client connected to " << host << ":" << port << std::endl;
+        ecf::UDPClient client(host, std::to_string(port));
+        client.send(request);
+
+        // Wait for request to flow...
+        std::this_thread::sleep_for(std::chrono::milliseconds(50));
+    }
+
+public:
+    static constexpr const char* designation = "ecFlow UDP";
+
+    static bp::child launch(const hostname_t& host, port_t port, port_t ecflow_port) {
+
+        std::string invoke_command = ecf::File::root_build_dir() + "/bin/ecflow_udp";
+        invoke_command += " --port ";
+        invoke_command += std::to_string(port);
+        invoke_command += " --ecflow_port ";
+        invoke_command += std::to_string(ecflow_port);
+        invoke_command += " --verbose";
+
+        std::cout << "   Launching ecflow_udp @" << host << ":" << port << ", with: " << invoke_command << std::endl;
+
+        bp::child server(invoke_command);
+
+        // Wait for server to start...
+        std::this_thread::sleep_for(std::chrono::milliseconds(2000));
+
+        return server;
+    }
+
+    static void cleanup(const hostname_t& host, port_t port) {
+        // No clean up needed for ecFlow UDP
+    }
+};
+
+/**
+ * This fixture provisions the tests with both an ecFlow server and an ecFlow UDP server.
+ */
+struct EnableServersFixture
+{
+    EnableServersFixture() : EnableServersFixture(get_ecflow_server_port(), get_ecflow_udp_port()) {}
+    ~EnableServersFixture() = default;
+
+    ecf::test::MockServer ecflow_server;
+    ecf::test::MockUDPServer ecflow_udp;
+
+private:
+    static MockServer::port_t get_ecflow_server_port() {
+        MockServer::port_t selected_port = 3199;
+        std::cout << "   Attempting to use port: " << selected_port << std::endl;
+        while (!EcfPortLock::is_free(selected_port)) {
+            std::cout << "   Selected port: " << selected_port << " is not available." << std::endl;
+            ++selected_port;
+            std::cout << "   Attempting to use port: " << selected_port << std::endl;
+        }
+        std::cout << "   Found free port: " << selected_port << "\n";
+        return selected_port;
+    }
+    static MockServer::port_t get_ecflow_udp_port() { return 3198; }
+
+    EnableServersFixture(MockServer::port_t ecflow_server_port, MockServer::port_t ecflow_udp_port)
+        : ecflow_server(ecflow_server_port),
+          ecflow_udp(ecflow_udp_port, ecflow_server_port) {
+        // Load 'reference' suite for tests...
+        ecflow_server.load_definition("data/reference.def");
+    }
+};
+
+} // namespace ecf::test
+
+#endif /* ecflow_udp_test_TestSupport_HPP */
diff -pruN 5.12.4-1/libs/udp/test/TestUDPServer.cpp 5.13.0-1/libs/udp/test/TestUDPServer.cpp
--- 5.12.4-1/libs/udp/test/TestUDPServer.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/test/TestUDPServer.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,170 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#include <boost/test/unit_test.hpp>
+
+#include "TestSupport.hpp"
+
+namespace ut = boost::unit_test;
+
+BOOST_FIXTURE_TEST_SUITE(S_UDP, ecf::test::EnableServersFixture)
+
+BOOST_AUTO_TEST_SUITE(T_UDPServer)
+
+BOOST_AUTO_TEST_CASE(can_update_events) {
+    // Family f2
+    {
+        auto event = ecflow_server.get_event("/s1/f2", "event_at_f2");
+        BOOST_TEST(!event.value());
+
+        ecflow_udp.set_event("/s1/f2", "event_at_f2");
+        event = ecflow_server.get_event("/s1/f2", "event_at_f2");
+        BOOST_TEST(event.value());
+
+        ecflow_udp.clear_event("/s1/f2", "event_at_f2");
+        event = ecflow_server.get_event("/s1/f2", "event_at_f2");
+        BOOST_TEST(!event.value());
+    }
+    // Family f3
+    {
+        auto event = ecflow_server.get_event("/s1/f2/f3", "event_at_f3");
+        BOOST_TEST(!event.value());
+
+        ecflow_udp.set_event("/s1/f2/f3", "event_at_f3");
+        event = ecflow_server.get_event("/s1/f2/f3", "event_at_f3");
+        BOOST_TEST(event.value());
+
+        ecflow_udp.clear_event("/s1/f2/f3", "event_at_f3");
+        event = ecflow_server.get_event("/s1/f2/f3", "event_at_f3");
+        BOOST_TEST(!event.value());
+    }
+    // Task t4
+    {
+        auto event = ecflow_server.get_event("/s1/f2/f3/t4", "event_at_t4");
+        BOOST_TEST(!event.value());
+
+        ecflow_udp.set_event("/s1/f2/f3/t4", "event_at_t4");
+        event = ecflow_server.get_event("/s1/f2/f3/t4", "event_at_t4");
+        BOOST_TEST(event.value());
+
+        ecflow_udp.clear_event("/s1/f2/f3/t4", "event_at_t4");
+        event = ecflow_server.get_event("/s1/f2/f3/t4", "event_at_t4");
+        BOOST_TEST(!event.value());
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_update_labels) {
+    // Family f2
+    {
+        auto label = ecflow_server.get_label("/s1/f2", "label_at_f2");
+        BOOST_TEST(label.new_value() == "");
+    }
+    {
+        ecflow_udp.update_label("/s1/f2", "label_at_f2", "some_value");
+        auto label = ecflow_server.get_label("/s1/f2", "label_at_f2");
+        BOOST_TEST(label.new_value() == "some_value");
+    }
+    // Family f3
+    {
+        auto label = ecflow_server.get_label("/s1/f2/f3", "label_at_f3");
+        BOOST_TEST(label.new_value() == "");
+    }
+    {
+        ecflow_udp.update_label("/s1/f2/f3", "label_at_f3", "another_value");
+        auto label = ecflow_server.get_label("/s1/f2/f3", "label_at_f3");
+        BOOST_TEST(label.new_value() == "another_value");
+    }
+    // Task t4
+    {
+        auto label = ecflow_server.get_label("/s1/f2/f3/t4", "label_at_t4");
+        BOOST_TEST(label.new_value() == "");
+    }
+    std::string values[] = {"a", "b", "c", "d"};
+    for (auto value : values) {
+        ecflow_udp.update_label("/s1/f2/f3/t4", "label_at_t4", value);
+        auto label = ecflow_server.get_label("/s1/f2/f3/t4", "label_at_t4");
+        BOOST_TEST(label.new_value() == value);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_update_meters) {
+    // Family f2
+    {
+        auto meter = ecflow_server.get_meter("/s1/f2", "meter_at_f2");
+        BOOST_TEST(meter.value() == 0);
+    }
+    {
+        ecflow_udp.update_meter("/s1/f2", "meter_at_f2", 49);
+        auto meter = ecflow_server.get_meter("/s1/f2", "meter_at_f2");
+        BOOST_TEST(meter.value() == 49);
+    }
+    // Family f3
+    {
+        auto meter = ecflow_server.get_meter("/s1/f2/f3", "meter_at_f3");
+        BOOST_TEST(meter.value() == 0);
+    }
+    {
+        ecflow_udp.update_meter("/s1/f2/f3", "meter_at_f3", 50);
+        auto meter = ecflow_server.get_meter("/s1/f2/f3", "meter_at_f3");
+        BOOST_TEST(meter.value() == 50);
+    }
+    // Task t4
+    {
+        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
+        BOOST_TEST(meter.value() == 0);
+    }
+    int values[] = {0, 10, 25, 50, 75, 100};
+    for (auto value : values) {
+        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", value);
+        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
+        BOOST_TEST(meter.value() == value);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_update_meter_outside_valid_range) {
+    {
+        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", 50);
+        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
+        BOOST_TEST(meter.value() == 50);
+    }
+    {
+        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", -1);
+        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
+        BOOST_TEST(meter.value() == 50);
+    }
+    {
+        ecflow_udp.update_meter("/s1/f2/f3/t4", "meter_at_t4", 101);
+        auto meter = ecflow_server.get_meter("/s1/f2/f3/t4", "meter_at_t4");
+        BOOST_TEST(meter.value() == 50);
+    }
+}
+
+BOOST_AUTO_TEST_CASE(can_handle_invalid_json_request) {
+    ecflow_udp.send(R"()");
+    ecflow_udp.send(R"({})");
+    ecflow_udp.send(R"({"method": "invalid", "data": {}})");
+    ecflow_udp.send(R"({"method": "put", "data": {}})");
+    ecflow_udp.send(R"({"method": "put", "data": {"type": "invalid"}})");
+    ecflow_udp.send(R"({"method": "put", "data": {"type": "label"}})");
+    ecflow_udp.send(R"({"method": "put", "data": {"type": "label", "name": "a_name"}})");
+    ecflow_udp.send(R"({"method": "put", "data": {"type": "label", "name": "a_name", "path": "a_path}})");
+    ecflow_udp.send(R"({"method": "put", "data": {"type": "meter"}})");
+    ecflow_udp.send(R"({"method": "put", "data": {"type": "meter", "name": "a_name"}})");
+    ecflow_udp.send(R"({"method": "put", "data": {"type": "meter", "name": "a_name", "path": "a_path}})");
+}
+
+BOOST_AUTO_TEST_CASE(can_authenticate_requests) {
+
+    ecflow_udp.send(R"()");
+}
+
+BOOST_AUTO_TEST_SUITE_END()
+
+BOOST_AUTO_TEST_SUITE_END()
diff -pruN 5.12.4-1/libs/udp/test/TestUDP_main.cpp 5.13.0-1/libs/udp/test/TestUDP_main.cpp
--- 5.12.4-1/libs/udp/test/TestUDP_main.cpp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/test/TestUDP_main.cpp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+/*
+ * Copyright 2009- ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation
+ * nor does it submit to any jurisdiction.
+ */
+
+#define BOOST_TEST_MODULE Test_UDP
+#include <boost/test/unit_test.hpp>
diff -pruN 5.12.4-1/libs/udp/test/data/reference.def 5.13.0-1/libs/udp/test/data/reference.def
--- 5.12.4-1/libs/udp/test/data/reference.def	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/libs/udp/test/data/reference.def	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,21 @@
+ 
+#
+# The defs used to test ecflow_udp
+#
+
+suite s1
+  family f2
+    event event_at_f2
+    label label_at_f2 ""
+    meter meter_at_f2 0 100 80
+    family f3
+      event event_at_f3
+      label label_at_f3 ""
+      meter meter_at_f3 0 100 80
+      task t4
+        event event_at_t4
+        label label_at_t4 ""
+        meter meter_at_t4 0 100 80
+    endfamily
+  endfamily
+endsuite
diff -pruN 5.12.4-1/releng/bamboo/macosx1010-flags.cmake 5.13.0-1/releng/bamboo/macosx1010-flags.cmake
--- 5.12.4-1/releng/bamboo/macosx1010-flags.cmake	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/bamboo/macosx1010-flags.cmake	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,6 @@
+message("> invoking file ecflow/bamboo/macosx1010-flag.cmake")
+# On mac appears no static python boost lib, hence use shared for everything
+#SET( ENABLE_STATIC_BOOST_LIBS   OFF CACHE BOOL "Use dynamic boost libs")
+SET( ENABLE_PYTHON_PTR_REGISTER  ON CACHE BOOL "Register shared ptr to python converters")
+
+message("> ENABLE_PYTHON_PTR_REGISTER = ${ENABLE_PYTHON_PTR_REGISTER} =========================================== ")
diff -pruN 5.12.4-1/releng/build_scripts/clean.sh 5.13.0-1/releng/build_scripts/clean.sh
--- 5.12.4-1/releng/build_scripts/clean.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/clean.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,69 @@
+#!/bin/sh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+cd $WK
+
+# Remove the bin directories
+rm -rf ACore/bin
+rm -rf ANattr/bin
+rm -rf ANode/bin 
+rm -rf ANode/parser/bin 
+rm -rf Base/bin
+rm -rf CSim/bin
+rm -rf Client/bin 
+rm -rf Server/bin 
+rm -rf Test/bin
+rm -rf Pyext/bin 
+   
+# remove generated files
+rm -rf Doc/online/_build/*
+rm -rf Test/data/ECF_HOME_debug*
+rm -rf Test/data/ECF_HOME_release*
+rm -rf ANode/parser/test/data/single_defs/mega.def_log
+rm -rf Pyext/test/data/CUSTOMER
+rm -rf Pyext/test.def
+rm -rf Pyext/build
+rm -rf Pyext/timestamp
+rm -rf bin
+rm -rf build
+rm -rf RemoteSystemsTempFiles
+rm -rf *.dat
+rm -rf *.log
+
+find . -name \*~ -exec rm -rf \*~ {} \; -print
+find . -name \*.mk -exec rm -rf \*.mk {} \; -print
+find . -name \*.o -exec rm -rf \*.mk {} \; -print
+find . -name \*.so -exec rm -rf \*.so {} \; -print
+find . -name \*.tmp -exec rm -rf \*.tmp {} \; -print
+find . -name \*.job\* -exec rm -rf \*.job\* {} \; -print
+find . -name \*.check -exec rm -rf \*.check {} \; -print
+find . -name \*.flat -exec rm -rf \*.flat {} \; -print
+find . -name \*.depth -exec rm -rf \*.depth {} \; -print
+find . -name \*.out -exec rm -rf \*.out {} \; -print
+find . -name \*.pyc -exec rm -rf \*.pyc {} \; -print
+find . -name t\*.1 -exec rm -rf t\*.1 {} \; -print
+find . -name gmon.out -exec rm -rf gmon.out {} \; -print
+find . -name gnuplot.dat -exec rm -rf gnuplot.dat {} \; -print
+find . -name gnuplot.script -exec rm -rf gnuplot.script {} \; -print
+find . -name ecflow.html -exec rm -rf ecflow.html {} \; -print
+find . -name core -exec rm -rf core {} \; -print
+find . -name callgrind.out.\* -exec rm -rf callgrind.out.\* {} \; -print
+find . -name massif.out.\* -exec rm -rf massif.out.* {} \; -print
+
+for file in `hostname`.*.ecf.* ; do
+    echo $file
+    rm -rf $file
+done
+
+# remove any defs file at the workspace level. There should not be any
+rm -rf *.def
+   
+# Remove any lock file create by tests which used EcfPortLock.hpp
+rm -rf *.lock
+
diff -pruN 5.12.4-1/releng/build_scripts/ecflow_asan.supp 5.13.0-1/releng/build_scripts/ecflow_asan.supp
--- 5.12.4-1/releng/build_scripts/ecflow_asan.supp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/ecflow_asan.supp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,3 @@
+#interceptor_via_fun:NameOfCFunctionToSuppress
+#interceptor_via_fun:-[ClassName objCMethodToSuppress:]
+#interceptor_via_lib:NameOfTheLibraryToSuppress
diff -pruN 5.12.4-1/releng/build_scripts/ecflow_lsan.supp 5.13.0-1/releng/build_scripts/ecflow_lsan.supp
--- 5.12.4-1/releng/build_scripts/ecflow_lsan.supp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/ecflow_lsan.supp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,11 @@
+# Needed for python ONLY
+# https://github.com/google/sanitizers/wiki/AddressSanitizerLeakSanitizer#suppressions
+leak:__interceptor_fopen64 
+leak:list_resize 
+leak:_PyString_Resize
+leak:type_new 
+leak:__interceptor_calloc
+leak:__interceptor_malloc
+leak:boost::python::objects::function_object
+leak:boost::python::api::object
+leak:init_module_ecflow
diff -pruN 5.12.4-1/releng/build_scripts/eclipse_c++_code_style.xml 5.13.0-1/releng/build_scripts/eclipse_c++_code_style.xml
--- 5.12.4-1/releng/build_scripts/eclipse_c++_code_style.xml	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/eclipse_c++_code_style.xml	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,155 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<profiles version="1">
+<profile kind="CodeFormatterProfile" name="eclipse_c++_code_style" version="1">
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_method_declaration" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_for" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_in_empty_block" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.lineSplit" value="100"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_base_types" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.keep_else_statement_on_same_line" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_switchstatements_compare_to_switch" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_brace_in_array_initializer" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_method_declaration_parameters" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_if" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_exception_specification" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_parenthesized_expression" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_base_types" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_body_declarations_compare_to_access_specifier" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_exception_specification" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_template_arguments" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_block" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_method_declaration" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.use_tabs_only_for_leading_indentations" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_labeled_statement" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_case" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_array_initializer" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_enum_declarations" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_expressions_in_array_initializer" value="18"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_declarator_list" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_bracket" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_for" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_prefix_operator" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.tabulation.size" value="3"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_else_in_if_statement" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_enumerator_list" value="48"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_parenthesized_expression" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_parens_in_method_declaration" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_declarator_list" value="16"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_switch" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_parenthesized_expression" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_empty_lines" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_switchstatements_compare_to_cases" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.keep_empty_array_initializer_on_one_line" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_method_declaration" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.put_empty_statement_on_new_line" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_switch" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_cast" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_braces_in_array_initializer" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.brace_position_for_method_declaration" value="next_line"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_while" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_question_in_conditional" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_semicolon" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_angle_bracket_in_template_arguments" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_base_clause" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_breaks_compare_to_cases" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_unary_operator" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_declarator_list" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_arguments_in_method_invocation" value="18"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_while" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_brackets" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_bracket" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_parameters_in_method_declaration" value="18"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_closing_brace_in_array_initializer" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.number_of_empty_lines_to_preserve" value="1"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_method_invocation" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_brace_in_array_initializer" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_semicolon_in_for" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.brace_position_for_block" value="end_of_line"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_conditional" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.brace_position_for_type_declaration" value="end_of_line"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_assignment_operator" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_angle_bracket_in_template_arguments" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_expression_list" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_angle_bracket_in_template_parameters" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.continuation_indentation" value="3"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_expression_list" value="0"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_method_declaration" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_template_parameters" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_default" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_binary_operator" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_conditional_expression" value="16"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_parens_in_method_invocation" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_array_initializer" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_if" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.format_guardian_clause_on_one_line" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_cast" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_access_specifier_compare_to_type_header" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_type_declaration" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_labeled_statement" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.continuation_indentation_for_array_initializer" value="2"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_method_declaration_parameters" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_semicolon_in_for" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_method_invocation" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_body_declarations_compare_to_namespace_header" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_brace_in_block" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_assignment_operator" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_compact_if" value="0"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_array_initializer" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_at_end_of_file_if_missing" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_template_parameters" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_expression_list" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_question_in_conditional" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_exception_specification" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_binary_operator" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_identifier_in_function_declaration" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_base_clause_in_type_declaration" value="16"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_method_declaration_throws" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_between_empty_parens_in_exception_specification" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_method_invocation_arguments" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_declaration_compare_to_template_header" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_unary_operator" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_switch" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_statements_compare_to_body" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_method_declaration_throws" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indent_statements_compare_to_block" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_template_arguments" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_catch_in_try_statement" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.alignment_for_throws_clause_in_method_declaration" value="18"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_method_invocation" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_paren_in_cast" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_paren_in_catch" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_angle_bracket_in_template_parameters" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.tabulation.char" value="space"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_angle_bracket_in_template_parameters" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_while" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_comma_in_method_invocation_arguments" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.brace_position_for_block_in_case" value="end_of_line"/>
+<setting id="org.eclipse.cdt.core.formatter.compact_else_if" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_postfix_operator" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_base_clause" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_after_template_declaration" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_catch" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.keep_then_statement_on_same_line" value="true"/>
+<setting id="org.eclipse.cdt.core.formatter.brace_position_for_switch" value="end_of_line"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_if" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_paren_in_switch" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.keep_imple_if_on_one_line" value="false"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_after_opening_brace_in_array_initializer" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.indentation.size" value="3"/>
+<setting id="org.eclipse.cdt.core.formatter.brace_position_for_namespace_declaration" value="end_of_line"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_colon_in_conditional" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_comma_in_enum_declarations" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_prefix_operator" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_angle_bracket_in_template_arguments" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.brace_position_for_array_initializer" value="end_of_line"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_colon_in_case" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_catch" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_brace_in_namespace_declaration" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_postfix_operator" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_closing_bracket" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_new_line_before_while_in_do_statement" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_before_opening_paren_in_for" value="do not insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_closing_angle_bracket_in_template_parameters" value="insert"/>
+<setting id="org.eclipse.cdt.core.formatter.insert_space_after_opening_angle_bracket_in_template_arguments" value="do not insert"/>
+</profile>
+</profiles>
diff -pruN 5.12.4-1/releng/build_scripts/iwyu/boost.imp 5.13.0-1/releng/build_scripts/iwyu/boost.imp
--- 5.12.4-1/releng/build_scripts/iwyu/boost.imp	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/iwyu/boost.imp	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,23 @@
+[
+{ symbol: ["std::stringstream", "private", "<sstream>", "public"] },
+
+{ include: ["@<boost/date_time/posix_time/.*>",    "public", "<boost/date_time/posix_time/posix_time.hpp>",       "public"] },
+{ include: ["@<boost/date_time/posix_time/.*>",    "public", "<boost/date_time/posix_time/posix_time_types.hpp>", "public"] },
+
+{ include : ["<boost/preprocessor/comparison/not_equal.hpp>",          "private", "<boost/test/unit_test.hpp>",      "public"] },  
+{ include : ["<boost/preprocessor/control/iif.hpp>",                   "private", "<boost/test/unit_test.hpp>",      "public"] },      
+{ include : ["<boost/preprocessor/logical/bool.hpp>",                  "private", "<boost/test/unit_test.hpp>",      "public"] },                      
+{ include : ["<boost/preprocessor/logical/compl.hpp>",                 "private", "<boost/test/unit_test.hpp>",      "public"] },                       
+{ include : ["<boost/test/tools/old/interface.hpp>",                   "private", "<boost/test/unit_test.hpp>",      "public"] },                        
+{ include : ["<boost/test/unit_test_suite.hpp>",                       "private", "<boost/test/unit_test.hpp>",      "public"] },                            
+{ include : ["<boost/test/utils/basic_cstring/basic_cstring.hpp>",     "private", "<boost/test/unit_test.hpp>",      "public"] },           
+{ include : ["<boost/test/utils/basic_cstring/basic_cstring_fwd.hpp>", "private", "<boost/test/unit_test.hpp>",      "public"] },      
+{ include : ["<boost/test/utils/lazy_ostream.hpp>",                    "private", "<boost/test/unit_test.hpp>",      "public"] },      
+
+{ include: ["@<boost/bind/.*>", private, "<boost/bind.hpp>", public ] },
+{ include: ["@<boost/format/.*>", private, "<boost/format.hpp>", public ] },
+{ include: ["@<boost/filesystem/.*>", private, "<boost/filesystem.hpp>", public ] },
+{ include: ["@<boost/function/.*>", private, "<boost/function.hpp>", public ] }
+
+]                
+                                
\ No newline at end of file
diff -pruN 5.12.4-1/releng/build_scripts/mac.sh 5.13.0-1/releng/build_scripts/mac.sh
--- 5.12.4-1/releng/build_scripts/mac.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/mac.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,258 @@
+#/bin/bash
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+# GDB setup:
+# https://www.thomasvitale.com/how-to-setup-gdb-and-eclipse-to-debug-c-files-on-macos-sierra/
+#
+# Using lldb-mi debugger
+#https://wiki.eclipse.org/CDT/User/FAQ#How_do_I_get_the_LLDB_debugger.3F
+#
+
+# ====================================================================
+show_error_and_exit() {
+   echo "mac.sh expects at least one argument"
+   echo " mac.sh [ options] "
+   echo ""
+   echo "   debug          - make a DEBUG build"
+   echo "   make           - run make after cmake"
+   echo "   test           - enable all tests"
+   echo "   gcc            - use gcc instead of clang(default)"
+   echo "   no_test        - disable all tests"
+   echo "   xcode          - enable xcode project"
+   echo "   ctest          - all ctest -R <test> -V"
+   echo "   clang          - build with clang compiler"
+   echo "   shared         - build with shared boost libs"
+   echo "   no_gui         - Don't build the gui"
+   echo "   no_ssl         - build without using openssl"
+   echo "   log            - enable debug output"
+   exit 1
+}
+
+# ====================================================================================
+# Build type to Release    
+mode_arg=release
+compiler=clang
+
+no_test_arg=
+make_arg=
+shared_arg=
+test_arg=
+ctest_arg=
+no_gui_arg=
+no_ssl_arg=
+log_arg=
+clean_arg=
+install_arg=
+asan_arg=
+msan_arg=
+ubsan_arg=
+xcode_arg=
+
+
+while [[ "$#" != 0 ]] ; do   
+
+   if [[ "$1" = debug || "$1" = release ]] ; then
+      mode_arg=$1
+   elif  [[ "$1" = make ]] ; then
+      make_arg=$1
+      shift
+      while [[ "$#" != 0 ]] ; do
+         make_arg="$make_arg $1"
+         shift
+      done
+      break
+   elif [[ "$1" = clean ]] ;   then clean_arg=$1 ;
+   elif [[ "$1" = install ]] ; then install_arg=$1 ;
+   elif [[ "$1" = shared ]] ;  then shared_arg=$1 ;
+   elif [[ "$1" = gcc ]] ;     then compiler=$1 ;
+   elif [[ "$1" = clang ]] ;   then compiler=$1 ;
+   elif [[ "$1" = no_gui ]] ;  then no_gui_arg=$1 ;
+   elif [[ "$1" = no_ssl ]] ;  then no_ssl_arg=$1 ;
+   elif [[ "$1" = log ]]   ;   then log_arg=$1 ;
+   elif [[ "$1" = test ]] ;    then test_arg=$1 ;
+   elif [[ "$1" = asan ]]  ;   then asan_arg=$1 ;
+   elif [[ "$1" = msan ]]  ;   then msan_arg=$1 ;
+   elif [[ "$1" = ubsan ]]  ;  then ubsan_arg=$1 ;
+   elif [[ "$1" = no_test ]]  ;  then no_test_arg=$1 ;
+   elif [[ "$1" = xcode ]]  ;  then xcode_arg=$1 ;
+   elif [[ "$1" = ctest ]] ;   then  
+      ctest_arg=$1 ; 
+      shift
+      while [[ "$#" != 0 ]] ; do
+         ctest_arg="$ctest_arg $1"
+         shift
+      done
+      break
+   else
+     show_error_and_exit
+   fi
+
+   # shift remove last argument
+   shift
+done
+
+
+# ====================================================================================
+# default to Release  
+cmake_build_type=
+if [[ $mode_arg = debug ]] ; then
+    cmake_build_type=Debug
+else
+    cmake_build_type=Release
+fi
+
+CXX_FLAGS="-fvisibility=hidden -fvisibility-inlines-hidden -Wno-deprecated-declarations"
+CXX_LINK_FLAGS=""
+
+cmake_extra_options=""
+if [[ "$compiler" = clang ]] ; then
+    # relies on brew install
+    # brew install cmake
+    # brew install qt
+    #
+    # the brew version of boost was built with -fvisibility=hidden -fvisibility-inlines-hidden
+    # We need same flags, otherwise large warning messages
+    # brew install boost
+    # brew install boost-python3
+    #
+    # https://medium.com/@timmykko/using-openssl-library-with-macos-sierra-7807cfd47892
+    # brew install openssl  # however this may not set the right links
+    #
+    # Do the following if config steps fails with cannot find openssl
+    # ln -s /usr/local/opt/openssl/include/openssl /usr/local/include
+    #
+    # ln -s /usr/local/opt/openssl/lib/libssl.1.1.1.dylib /usr/local/lib/
+    #
+    # to list the clang default system search path use:
+    # clang -x c -v -E /dev/null
+   cmake_extra_options="$cmake_extra_options -DBOOST_ROOT=/usr/local"
+   CXX_FLAGS="$CXX_FLAGS -ftemplate-depth=512"
+else
+   # brew install gcc
+   # manually installed boost, built with brew gcc
+   # If you get errors like:
+   #   dyld: Symbol not found: ___emutls_get_address
+   #   Referenced from: /usr/local/opt/gcc/lib/gcc/10/libstdc++.6.dylib
+   #   Expected in: /usr/lib/libSystem.B.dylib
+   # then try:
+   #   brew link --overwrite gcc
+   cmake_extra_options="$cmake_extra_options -DBOOST_ROOT=${HOME}/boost/boost_1_73_0"
+   cmake_extra_options="$cmake_extra_options -DCMAKE_C_COMPILER=/usr/local/opt/gcc@10/bin/gcc-10"
+   cmake_extra_options="$cmake_extra_options -DCMAKE_CXX_COMPILER=/usr/local/opt/gcc@10/bin/g++-10"
+fi
+
+if [[ "$asan_arg" = asan ]] ; then
+
+   CXX_FLAGS="$CXX_FLAGS -fsanitize=address -fno-omit-frame-pointer"
+   CXX_LINK_FLAGS="$CXX_LINK_FLAGS -fsanitize=address"
+   export ECF_TEST_SANITIZER_AS=1  # enable address sanitizer tests
+   
+   #cmake_extra_options="$cmake_extra_options -CMAKE_CXX_LINK_EXECUTABLE= "
+   #cmake -DCMAKE_LINKER=/path/to/linker -DCMAKE_CXX_LINK_EXECUTABLE="<CMAKE_LINKER> <FLAGS> <CMAKE_CXX_LINK_FLAGS> <LINK_FLAGS> <OBJECTS> -o <TARGET> <LINK_LIBRARIES>"
+   #cmake_extra_options="$cmake_extra_options -DCMAKE_BUILD_TYPE=ASAN"
+   cmake_extra_options="$cmake_extra_options -DCMAKE_LINKER=/Library/Developer/CommandLineTools/usr/bin/clang"
+fi
+if [[ "$ubsan_arg" = ubsan ]] ; then
+   #CXX_FLAGS="$CXX_FLAGS -fsanitize=undefined -fsanitize-minimal-runtime -fno-omit-frame-pointer -fno-sanitize-recover=all" # exit after all errors minimal info
+   #CXX_FLAGS="$CXX_FLAGS -fsanitize=undefined -fno-omit-frame-pointer -fno-sanitize-recover=all"                           # exit on first error, max info
+   CXX_FLAGS="$CXX_FLAGS -fsanitize=undefined -fno-omit-frame-pointer"                                                     # report error, max info, no exit on error
+   CXX_LINK_FLAGS="$CXX_LINK_FLAGS -fsanitize=undefined"
+   export ECF_TEST_SANITIZER_UB=1  # enable undefined behaviour tests
+   cmake_extra_options="$cmake_extra_options -DCMAKE_LINKER=/Library/Developer/CommandLineTools/usr/bin/clang"
+fi
+if [[ "$msan_arg" = msan ]] ; then
+   CXX_FLAGS="$CXX_FLAGS -fsanitize=memory -fno-omit-frame-pointer -fsanitize-memory-track-origins"
+   CXX_LINK_FLAGS="$CXX_LINK_FLAGS -fsanitize=memory"
+   cmake_extra_options="$cmake_extra_options -DCMAKE_LINKER=/Library/Developer/CommandLineTools/usr/bin/clang"
+fi
+
+
+if [[ "$shared_arg" = shared ]] ; then
+   cmake_extra_options="$cmake_extra_options -DENABLE_STATIC_BOOST_LIBS=OFF"
+fi
+
+if [[ "$no_test_arg" = no_test ]] ; then
+   cmake_extra_options="$cmake_extra_options -DENABLE_TESTS=OFF"
+fi
+
+log_options=
+if [[ $log_arg = log ]] ; then
+    log_options="-DECBUILD_LOG_LEVEL=DEBUG"
+fi
+
+gui_options=
+if [[ $no_gui_arg = no_gui ]] ; then
+    gui_options="-DENABLE_UI=OFF"
+fi
+
+ssl_options="-DOPENSSL_ROOT_DIR=/usr/local/opt/openssl"
+if [[ $no_ssl_arg = no_ssl ]] ; then
+    ssl_options="-DENABLE_SSL=OFF"
+fi
+
+test_options=
+if [[ $test_arg = test ]] ; then
+   test_options="-DENABLE_ALL_TESTS=ON"
+fi
+
+bdir_root=${HOME}/git/ecflow/bdir
+
+if [[ "$xcode_arg" = xcode ]] ; then
+   cmake_extra_options="$cmake_extra_options -GXcode"
+   bdir_root=${HOME}/git/ecflow/bdir_xcode
+fi
+
+bdir=${bdir_root}/$mode_arg/$compiler
+
+if [[ $clean_arg = clean ]] ; then
+   rm -rf ${bdir_root}
+fi
+mkdir -p $bdir
+cd $bdir
+
+if [[ "$ctest_arg" != "" ]] ; then
+
+    if [[ "$asan_arg" = asan ]] ; then
+      ASAN_OPTIONS=detect_leaks=1
+    fi
+    
+    $ctest_arg 
+    exit 0
+fi
+
+
+# ====================================================================================
+# Use for local install
+version=$(awk '/^project/ && /ecflow/ && /VERSION/ {for (I=1;I<=NF;I++) if ($I == "VERSION") {print $(I+1)};}' ${HOME}/git/ecflow/CMakeLists.txt) 
+#echo $version
+
+# ====================================================================================
+# default to install in $HOME/install, otherwise if install passed, /usr/local/opt  
+install_prefix=${HOME}/install/ecflow/${version}
+if [[ $install_arg = install ]] ; then
+    install_prefix=/usr/local/opt/ecflow/${version}
+fi
+
+cmake ${HOME}/git/ecflow \
+      -DCMAKE_MODULE_PATH=${HOME}/git/ecbuild/cmake \
+      -DCMAKE_CXX_FLAGS="$CXX_FLAGS" \
+      -DCMAKE_EXE_LINKER_FLAGS="$CXX_LINK_FLAGS" \
+      -DCMAKE_BUILD_TYPE=$cmake_build_type \
+      -DCMAKE_PREFIX_PATH=/usr/local/opt/qt \
+      -DCMAKE_INSTALL_PREFIX=${install_prefix} \
+      ${cmake_extra_options} \
+      ${gui_options} \
+      ${ssl_options} \
+      ${log_options} \
+      ${test_options}  
+      
+# =============================================================================================
+if [[ "$make_arg" != "" ]] ; then
+    $make_arg 
+fi
+
diff -pruN 5.12.4-1/releng/build_scripts/massif.sh 5.13.0-1/releng/build_scripts/massif.sh
--- 5.12.4-1/releng/build_scripts/massif.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/massif.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,33 @@
+#!/bin/sh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+cd $WK
+
+# if argument is release test the release version else stick with debug
+mode=debug
+if test "$1" = release
+then
+   mode=release
+fi
+
+
+compiler=gcc-$(gcc -dumpversion)
+echo "valgrind: variant=$mode compiler=$compiler"
+
+valgrind --tool=massif ACore/bin/$compiler/$mode/u_acore
+valgrind --tool=massif ANattr/bin/$compiler/$mode/u_anattr
+valgrind --tool=massif ANode/bin/$compiler/$mode/u_anode
+valgrind --tool=massif ANode/parser/bin/$compiler/$mode/u_aparser
+valgrind --tool=massif Base/bin/$compiler/$mode/u_base
+valgrind --tool=massif Client/bin/$compiler/$mode/s_client
+valgrind --tool=massif Server/bin/$compiler/$mode/u_server
+valgrind --tool=massif Test/bin/$compiler/$mode/s_test
+valgrind --tool=massif Simulator/bin/$compiler/$mode/c_csim
+#valgrind --tool=massif ANode/parser/bin/$compiler/$mode/perf_aparser
+
diff -pruN 5.12.4-1/releng/build_scripts/migrate.sh 5.13.0-1/releng/build_scripts/migrate.sh
--- 5.12.4-1/releng/build_scripts/migrate.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/migrate.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+
+
+prepare_migration() {
+   module load ecflow
+   while read nick host port
+   do
+     LOG="--host=$host --port=$port"
+     ecflow_client $LOG --ping || continue
+     version=$(ecflow_client $LOG --server_version)
+     echo $nick $host $port $version
+     /usr/local/apps/ecflow/$version/bin/ecflow_client $LOG --migrate > $host.$port.mig
+   done < /usr/local/apps/ecflow/current/lib/servers
+}
+
+prepare_migration
diff -pruN 5.12.4-1/releng/build_scripts/nightly/experiment/exp.ecf 5.13.0-1/releng/build_scripts/nightly/experiment/exp.ecf
--- 5.12.4-1/releng/build_scripts/nightly/experiment/exp.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/nightly/experiment/exp.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+import os, time, signal
+import ecflow
+ 
+print "PYTHONPATH====================================================="
+print os.environ['PYTHONPATH'].split(os.pathsep)
+
+def create_client():
+   print "Creating Client"
+   ci = ecflow.Client()
+   ci.set_host_port("%ECF_HOST%","%ECF_PORT%")
+   ci.set_child_pid(os.getpid())
+   ci.set_child_path("%ECF_NAME%")
+   ci.set_child_password("%ECF_PASS%")
+   ci.set_child_try_no(%ECF_TRYNO%)
+   
+   print "Only wait 20 seconds, if the server cannot be contacted (note default is 24 hours) before failing"
+   ci.set_child_timeout(20) 
+   ci.set_zombie_child_timeout(20) 
+   return ci
+   
+def signal_handler(signum, frame):
+    print 'Aborting: Signal handler called with signal ', signum
+    ci = create_client()
+    ci.child_abort("Signal handler called with signal " + str(signum));
+    
+signal.signal (signal.SIGINT,  signal_handler) 
+signal.signal (signal.SIGHUP,  signal_handler)
+signal.signal (signal.SIGQUIT, signal_handler)
+signal.signal (signal.SIGILL,  signal_handler)
+signal.signal (signal.SIGTRAP, signal_handler)
+signal.signal (signal.SIGIOT,  signal_handler)
+signal.signal (signal.SIGBUS,  signal_handler)
+signal.signal (signal.SIGFPE,  signal_handler)
+signal.signal (signal.SIGUSR1, signal_handler)
+signal.signal (signal.SIGUSR2, signal_handler)
+signal.signal (signal.SIGPIPE, signal_handler)
+signal.signal (signal.SIGTERM, signal_handler)
+signal.signal (signal.SIGXCPU, signal_handler)
+signal.signal (signal.SIGPWR,  signal_handler)
+
+
+ci = create_client();
+try:
+   ci.child_init();
+   print "child init ok"
+  
+   for i in range(1,10):
+      print "At value " + str(i)
+      ci.child_meter('meter',i)
+      ci.child_label('label_name', "value_" + str(i))
+      time.sleep(1)
+      
+   ci.child_event('event_fred')
+   print "Finished event,meter and label child commands"
+   
+   ci.child_complete()
+except:
+   ci.child_abort()
+   
\ No newline at end of file
diff -pruN 5.12.4-1/releng/build_scripts/nightly/experiment/exp2.ecf 5.13.0-1/releng/build_scripts/nightly/experiment/exp2.ecf
--- 5.12.4-1/releng/build_scripts/nightly/experiment/exp2.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/nightly/experiment/exp2.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,72 @@
+# ====================================================================
+# The class Client can be placed in head.py, since it is 
+# common to all jobs
+# ====================================================================
+import os, time, signal, sys
+import ecflow
+ 
+print "PYTHONPATH====================================================="
+print os.environ['PYTHONPATH'].split(os.pathsep)
+
+class Client(object):
+   def __init__(self):
+      print "Creating Client"
+      self.ci = ecflow.Client()
+      self.ci.set_host_port("%ECF_HOST%","%ECF_PORT%")
+      self.ci.set_child_pid(os.getpid())
+      self.ci.set_child_path("%ECF_NAME%")
+      self.ci.set_child_password("%ECF_PASS%")
+      self.ci.set_child_try_no(%ECF_TRYNO%)
+   
+      print "Only wait 20 seconds, if the server cannot be contacted (note default is 24 hours) before failing"
+      self.ci.set_child_timeout(20) 
+      self.ci.set_zombie_child_timeout(10) 
+    
+      signal.signal(signal.SIGINT,  self.signal_handler) 
+      signal.signal(signal.SIGHUP,  self.signal_handler)
+      signal.signal(signal.SIGQUIT, self.signal_handler)
+      signal.signal(signal.SIGILL,  self.signal_handler)
+      signal.signal(signal.SIGTRAP, self.signal_handler)
+      signal.signal(signal.SIGIOT,  self.signal_handler)
+      signal.signal(signal.SIGBUS,  self.signal_handler)
+      signal.signal(signal.SIGFPE,  self.signal_handler)
+      signal.signal(signal.SIGUSR1, self.signal_handler)
+      signal.signal(signal.SIGUSR2, self.signal_handler)
+      signal.signal(signal.SIGPIPE, self.signal_handler)
+      signal.signal(signal.SIGTERM, self.signal_handler)
+      signal.signal(signal.SIGXCPU, self.signal_handler)
+      signal.signal(signal.SIGPWR,  self.signal_handler)
+    
+   def signal_handler(self,signum, frame):
+      print 'Aborting: Signal handler called with signal ', signum
+      self.ci.child_abort("Signal handler called with signal " + str(signum));
+    
+   def __enter__(self):
+      self.ci.child_init()
+      return self.ci
+    
+   def __exit__(self,ex_type,value,tb):
+      print "Client:__exit__: ex_type:" + str(ex_type) + " value:" + str(value) + "\n" + str(tb)
+      if ex_type is not None:
+         self.ci.child_abort("Aborted with exception type " + str(ex_type) + str(value))
+         return False
+      self.ci.child_complete()
+      return False
+        
+        
+        
+# =============================================================================
+# Job specific code:
+#    This uses Client, to job start/finish/abort and signal trapping
+with Client() as ci:
+
+   # This will also handle call to sys.exit(), i.e Client.__exit__ will still be called.
+   for i in range(1,100):
+      print "At value " + str(i)
+      ci.child_meter('meter',i)
+      ci.child_label('label_name', "value_" + str(i))
+      time.sleep(1)
+      
+   ci.child_event('event_fred')
+   print "Finished event,meter and label child commands"
+  
\ No newline at end of file
diff -pruN 5.12.4-1/releng/build_scripts/nightly/experiment/exp3.ecf 5.13.0-1/releng/build_scripts/nightly/experiment/exp3.ecf
--- 5.12.4-1/releng/build_scripts/nightly/experiment/exp3.ecf	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/nightly/experiment/exp3.ecf	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,27 @@
+%manual
+DESCRIPTION
+Reproducing bug task. A ssh command is run into other server that tries to update the value of a "missing label" in this task.
+%end
+%include <head.h>
+
+for (( n = 1 ; n <= 500 ; n++ )); do
+  #print "iteration n=$n"
+  ksh -c "module load ecflow; env ECF_HOST=%ECF_HOST% ECF_PORT=%ECF_PORT% ecflow_client --label=label $n" &
+done
+
+#export ECF_DEBUG_CLIENT=1
+#export ECF_HOST=%ECF_HOST%
+#export ECF_PORT=%ECF_PORT%
+#for (( n = 1 ; n <= 500 ; n++ ));do
+#  ecflow_client --label=label "label_number_$n"
+#done
+
+#for (( n = 1 ; n <= 200 ; n++ )); do
+#  print "sleeping" $n
+#  ecflow_client --label=sleeping $n
+#  sleep 1
+#done
+
+wait
+%include <tail.h>
+
diff -pruN 5.12.4-1/releng/build_scripts/nightly/export_WK.h 5.13.0-1/releng/build_scripts/nightly/export_WK.h
--- 5.12.4-1/releng/build_scripts/nightly/export_WK.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/nightly/export_WK.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,12 @@
+# =========================================================
+# We do ***not** want to hard wire version in the definition
+# This will allow us to change version without having to
+# modify the definition
+# use [[ ]] for string comparison
+# =========================================================
+if [[ "%LOCAL_HOST:%" != ""  ]] ; then
+   export WK=%WK%
+else
+   # When building on remote platform.
+   export WK=%ROOT_WK:%/ecflow
+fi
diff -pruN 5.12.4-1/releng/build_scripts/nightly/head.h 5.13.0-1/releng/build_scripts/nightly/head.h
--- 5.12.4-1/releng/build_scripts/nightly/head.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/nightly/head.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,134 @@
+#!/bin/ksh
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+set -o pipefail # fail if last(rightmost) command exits with a non-zero status
+
+# ----------------------------------------------------------------------
+# LXOP: specific ??
+# ----------------------------------------------------------------------
+HOST=${HOST:=$(uname -n)}
+if [[ $HOST = lxop* ]]; then
+# QSUB -q %QUEUE:test%
+  ln -sf $(echo ${PBS_NODEFILE:=} | sed -e 's:aux:spool:').OU %ECF_JOBOUT%.running
+fi
+
+# ============================================================================
+# Defines the variables that are needed for any communication with ECF
+#
+# Note: We do *NOT* _export_ ECF_PORT,ECF_HOST,ECF_RID to avoid interferences
+# from the ecflow regression tests. which also use ecflow_client, instead we explicitly
+# set the host,port and rid on each ecflow_client call,
+# i.e  --host=%ECF_HOST% --port=%ECF_PORT%
+# This is only required because we are using ecflow to test ecflow
+#
+# The typical head.h file would just export these variables
+# =============================================================================
+export ECF_NAME=%ECF_NAME%    # The name of this current task
+export ECF_PASS=%ECF_PASS%    # A unique password
+export ECF_TRYNO=%ECF_TRYNO%  # Current try number of the task
+export PID_RID=$$
+
+# =============================================================================
+
+# Shorten normal timeout for child commands to one hour
+export ECF_TIMEOUT=3600
+
+#==================================================================================================
+
+export BOOST_ROOT=%BOOST_DIR%/%BOOST_VERSION%
+ECFLOW_INSTALL_PATH=%ECFLOW_LAST_INSTALLED_VERSION%
+
+#==================================================================================================
+
+# Used to locate ecrcp,git,python and ecflow_client
+export PATH=/usr/local/bin:/usr/bin:$ECFLOW_INSTALL_PATH/bin:$PATH
+
+# ==================================================================================================
+# make sure path to the python interpreter is accessible.
+# Boost: This can be hard coded in site-config.jam i.e via using python Or amend the path here
+# cmake: allow cmake to work out python path
+
+if [[ %ARCH% = linux64 ]] ; then
+   #
+   # NOTE: /usr/local/bin provides path to 2.7 PYTHON interpreter
+   #       *MAKE* sure it becomes *BEFORE* /usr/bin as that points to python 2.6
+   #        This is what 'using python' will pick up and add to the include path
+   #
+   export PATH=/usr/local/apps/python/2.7/bin:$PATH
+
+elif [[ %ARCH% = opensuse113  ]] ; then
+
+   export PATH=/usr/local/apps/python/2.7/bin:$PATH
+#export PATH=/usr/local/bin:$PATH
+
+elif [[ %ARCH% = redhat  ]] ; then
+
+   export PATH=/usr/local/apps/python/2.7/bin:$PATH
+
+elif [[ %ARCH% = opensuse103  ]] ; then
+
+   #
+   # NOTE: /usr/local/apps/python/2.7.2-01/bin/ provides path to PYTHON interpreter
+   #       This is what 'using python' will pick up and add to the include path
+   #
+   export PATH=/usr/local/apps/python/2.7.2-01/bin/:/usr/local/bin:$PATH
+
+elif [[ %ARCH% = linux64intel  ]] ; then
+
+   #
+   # NOTE: /usr/local/apps/python/2.7/bin/ provides path to PYTHON interpreter
+   #       This is what 'using python' will pick up and add to the include path
+   #
+   export PATH=/usr/local/apps/python/2.7/bin/:/usr/local/bin:$PATH
+
+elif [[ %ARCH% = opensuse103  ]] ; then
+
+   #
+   # NOTE: /usr/local/apps/python/2.7.2-01/bin/ provides path to PYTHON interpreter
+   #       This is what 'using python' will pick up and add to the include path
+   #
+   export PATH=/usr/local/apps/gcc/4.2.1/ILP32/bin:/usr/local/apps/python/2.7/bin:$PATH
+fi
+
+
+# -----------------------------------------------------------------------
+# Check paths especially for python
+echo "ECF_INCLUDE = %ECF_INCLUDE%"
+which ecflow_client
+which python
+ulimit
+
+####################################################################################
+# Tell ecFlow we have stated
+ecflow_client --init=$PID_RID --host=%ECF_HOST% --port=%ECF_PORT%
+
+
+# Defined a error hanlder
+ERROR() {
+   # Clear -e flag, so we don't fail
+   set +e
+   wait
+   ecflow_client --abort=trap  --host=%ECF_HOST% --port=%ECF_PORT%
+
+   echo "environment was:"; printenv | sort
+   trap 0                      # Remove the trap
+   exit 0                      # End the script
+}
+
+
+# Trap any calls to exit and errors caught by the -e flag
+trap ERROR 0
+
+
+# Trap any signal that may cause the script to fail
+trap '{ echo "Killed by a signal"; ERROR ; }' 1 2 3 4 5 6 7 8 10 12 13 15
+
+
+# Enable module capability for korn shell
+# The alternative is to source .profile, in ECF_JOB_CMD, however that affect all jobs
+source /usr/local/apps/module/init/ksh
+
+%MODULE_LOAD_GIT:module load git%
+
+# last line of head.h
diff -pruN 5.12.4-1/releng/build_scripts/nightly/quick_install.sh 5.13.0-1/releng/build_scripts/nightly/quick_install.sh
--- 5.12.4-1/releng/build_scripts/nightly/quick_install.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/nightly/quick_install.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,195 @@
+#!/bin/sh
+# assumes:
+# - $WK is defined to be root of ecflow tree
+# - ecflow is installed to: Linux  - /tmp/${USER}/install/cmake/ecflow/${ECFLOW_VERSION} 
+#                           Darwin - $(HOME)/install/ecflow/${ECFLOW_VERSION} 
+#   Linux Install using: cd $WK; ./cmake.sh make -j8 install
+#   mac   Install using: cd $WK; build_scripts/mac.sh make -j8 install
+# - metabuilder is at $WK/../metabuilder
+
+# Alter the command below to either
+# a/ use the system installed version, everywhere, avoid mismatch between different releases
+# b/ Test the latest release, requires compatible client/server versions
+
+set -e # stop the shell on first error
+set -u # fail when using an undefined variable
+set -x # echo script lines as they are executed
+set -o pipefail # fail if last(rightmost) command exits with a non-zero status
+
+cd $WK
+export ECF_PORT=4041
+PYTHON=python3
+
+os_variant=$(uname -s)
+if [[ $os_variant = Darwin ]] ; then
+
+   # we assume $PATH and $PYTHONPATH have been set to locate ecflow_client/ecflow.so
+   ECF_HOST=localhost
+   export ECF_PORT=4040
+   ECF_CLIENT_EXE_PATH=$(which ecflow_client)
+
+else
+   ECFLOW_VERSION=$(awk '/^project/ && /ecflow/ && /VERSION/ {for (I=1;I<=NF;I++) if ($I == "VERSION") {print $(I+1)};}' $WK/CMakeLists.txt)      
+   install_prefix="/tmp/${USER}/install/cmake"
+   export PATH=${install_prefix}/ecflow/${ECFLOW_VERSION}/bin:$PATH
+   if [[ $PYTHON == "python3" ]] ; then
+      #module load python3
+  
+      python_dot_version=$(python3 -c 'import sys;print(sys.version_info[0],".",sys.version_info[1],sep="")')
+      export PYTHONPATH=${install_prefix}/ecflow/${ECFLOW_VERSION}/lib/python${python_dot_version}/site-packages
+   else
+      export PYTHONPATH=${install_prefix}/ecflow/${ECFLOW_VERSION}/lib/python2.7/site-packages
+   fi
+   
+   ECF_CLIENT_EXE_PATH=${install_prefix}/ecflow/${ECFLOW_VERSION}/bin/ecflow_client
+fi
+
+# =======================================================================
+# SSL
+# =======================================================================
+#export ECF_DEBUG_CLIENT=1
+#export ECF_SSL=`hostname`.${ECF_PORT} # use server specific <host>.<port>.*** certificates
+#export ECF_SSL=1                      # use non server specific  certificates
+
+
+# =======================================================================
+# Kill the server
+# =======================================================================
+which ecflow_client
+ecflow_client --version
+set +e # disable error
+ecflow_client --terminate=yes >> /dev/null
+set -e # stop the shell on first error
+
+set +e # ignore error 
+count=0
+while [ 1 ] ; do   
+    ecflow_client --ping 2> /dev/null
+    if [[ $? == 1 ]] ; then
+        echo "server terminates after $count seconds"
+        break
+    fi
+    sleep 1
+    count=$((count + 1))
+    #echo $count
+    if [ "$count" -gt "3" ] ; then
+        echo "Timed out after 3 seconds"
+        break
+    fi
+done
+set -e  # re-enable error
+
+# =======================================================================
+# Create build scripts files. Must be before python $WK/build_scripts/nightly/build.py
+# =======================================================================
+cd $SCRATCH
+rm -rf nightly
+cp -r $WK/build_scripts/nightly .
+cd nightly
+
+# =======================================================================
+# Clean start
+# =======================================================================
+rm -rf `hostname`.${ECF_PORT}.*
+
+# =======================================================================
+# CUSTOM USER, this needs a ECF_CUSTOM_PASSWD, used for client and server
+# =======================================================================
+test_custom_user=0
+if [[ $test_custom_user -eq 1 ]] ; then
+   export ECF_CUSTOM_PASSWD=$SCRATCH/nightly/$(hostname).${ECF_PORT}.ecf.custom_passwd
+   export ECF_USER=fred # custom user fred
+cat << EOF > ${ECF_CUSTOM_PASSWD}
+4.5.0  
+# <user> <host> <port> <passwd>
+$ECF_USER $(hostname) ${ECF_PORT} my_passwd
+EOF
+fi
+
+# =======================================================================
+# PASSWD access, file used for client and server
+# =======================================================================
+test_passwd_file=0
+if [[ $test_passwd_file == 1 ]] ; then
+   export ECF_PASSWD=$SCRATCH/nightly/$(hostname).${ECF_PORT}.ecf.passwd
+cat << EOF > ${ECF_PASSWD}
+4.5.0  
+# <user> <host> <port> <passwd>
+$USER $(hostname) ${ECF_PORT} my_passwd
+EOF
+fi
+
+
+# =======================================================================
+# Start server. 
+# =======================================================================
+#export ECF_TASK_THRESHOLD=1 # 1000 milliseconds = 1 second, enable to test slow job creation
+ecflow_server&
+
+# wait for server to start
+set +e # ignore error 
+count=0
+while [ 1 ] ; do   
+    ecflow_client --ping 2> /dev/null
+    if [[ $? == 0 ]] ; then
+        echo "server up and running after $count seconds"
+        break;
+    fi
+    sleep 1
+    count=$((count + 1))
+    #echo $count
+    if [ "$count" -gt "4" ] ; then
+        echo "Timed out after 4 seconds"
+        exit 1
+    fi
+done
+set -e  # re-enable error 
+
+ecflow_client --server_version
+
+# =======================================================================
+# start with a clean slate
+# =======================================================================
+ecflow_client --restart
+ecflow_client --delete=_all_ yes
+
+# ======================================================================
+# ecflow metabuilder, this needs PYTHONPATH for local ecflow
+# ======================================================================
+cd $WK/../metabuilder
+git checkout develop
+$PYTHON ./clean.py -s ecflow 
+$PYTHON ./generate.py -s ecflow
+$PYTHON ./reload.py -s ecflow
+#git checkout master
+
+
+# ========================================================================
+# Generate test suites, based on definitions known to be good 
+# ========================================================================
+cd $WK
+#$PYTHON Pyext/samples/TestBench.py ANode/parser/test/data/good_defs/JIRA/ecflow_337_.def
+#$PYTHON Pyext/samples/TestBench.py ANode/parser/test/data/good_defs/JIRA/ecflow_1550.def
+
+for defs_file in $(find ANode/parser/test/data/good_defs -type f); do
+   echo "->$defs_file"
+   $PYTHON Pyext/samples/TestBench.py $defs_file
+done
+ 
+# Use python3 for ecflow 5 series
+# Use the installed ecflow for ecflow_client, to stop mixing of ecflow 4/5
+# must be done after since TestBench.py will use build dir
+ecflow_client --alter change variable ECF_CLIENT_EXE_PATH "$ECF_CLIENT_EXE_PATH" /
+ecflow_client --order=/ecflow alpha      #  sort suites  
+ecflow_client --order=/ecflow top    
+  
+# =======================================================================
+# START the GUI, kill first
+# =======================================================================
+ps -ef | grep -v awk | awk '/ecflow_ui/ {print $2}' | xargs kill -9 || true
+
+export ECFLOWUI_DEVELOP_MODE=1      # enable special menu to diff ecflowui defs and downloaded defs
+#export ECFLOWUI_SESSION_MANAGER=1  # to minimise output for debug, use session with a single server
+#ecflow_ui.x > ecflow_ui.log 2>&1 & 
+#ecflow_ui -confd ${HOME}/.ecflow5_ui &
+ecflow_ui&
diff -pruN 5.12.4-1/releng/build_scripts/nightly/tail.h 5.13.0-1/releng/build_scripts/nightly/tail.h
--- 5.12.4-1/releng/build_scripts/nightly/tail.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/nightly/tail.h	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,15 @@
+
+if [[ $HOST = lxop* ]]; then
+  ln -sf $(echo ${PBS_NODEFILE:=} | sed -e 's:aux:spool:').OU %ECF_JOBOUT%
+fi
+
+# Notify ecFlow of a normal end
+#
+# we call wait to let all background process stop
+# Also even if we had foreground process, the complete message
+# could arrive at the server before say, a --label command
+# This would result in zombies. To avoid this we use wait
+wait
+ecflow_client --complete  --host=%ECF_HOST% --port=%ECF_PORT%
+trap 0                 # Remove all traps
+exit 0                 # End the shell
diff -pruN 5.12.4-1/releng/build_scripts/profile.sh 5.13.0-1/releng/build_scripts/profile.sh
--- 5.12.4-1/releng/build_scripts/profile.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/profile.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,59 @@
+#!/bin/sh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+# will run gprof
+
+echo "building profile versions";
+cd $WK
+bjam -j2 -q variant=profile
+
+ 
+compiler=gcc-$(gcc -dumpversion)
+echo "gprof: variant=profile compiler=$compiler"
+
+#
+cd $WK/ACore
+bin/$compiler/profile/u_acore
+gprof bin/$compiler/profile/u_acore   gmon.out   >   gprof.out
+
+cd $WK/ANattr
+bin/$compiler/profile/u_anattr
+gprof bin/$compiler/profile/u_anattr gmon.out   >   gprof.out
+
+cd $WK/ANode
+bin/$compiler/profile/u_anode
+gprof bin/$compiler/profile/u_anode gmon.out   >   gprof.out
+
+cd $WK/ANode/parser
+bin/$compiler/profile/u_aparser
+gprof bin/$compiler/profile/u_aparser gmon.out   >   gprof.out
+
+cd $WK/Base
+bin/$compiler/profile/u_base
+gprof bin/$compiler/profile/u_base gmon.out   >   gprof.out
+
+cd $WK/Client
+bin/$compiler/profile/s_client
+gprof bin/$compiler/profile/s_client gmon.out   >   gprof.out
+
+cd $WK/Server
+bin/$compiler/profile/u_server
+gprof bin/$compiler/profile/u_server gmon.out   >   gprof.out
+
+cd $WK/Test
+bin/$compiler/profile/test
+gprof bin/$compiler/profile/test gmon.out   >   gprof.out
+
+cd $WK/CSim
+bin/$compiler/profile/c_csim
+gprof bin/$compiler/profile/c_csim gmon.out   >   gprof.out
+
+cd $WK/ANode/parser
+bin/$compiler/profile/perf_aparser
+gprof bin/$compiler/profile/perf_aparser gmon.out   >   gprof.out
diff -pruN 5.12.4-1/releng/build_scripts/rmbin.sh 5.13.0-1/releng/build_scripts/rmbin.sh
--- 5.12.4-1/releng/build_scripts/rmbin.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/rmbin.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,22 @@
+#!/bin/sh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+cd $WK
+ 
+rm -rf ACore/bin
+rm -rf ANattr/bin
+rm -rf ANode/bin 
+rm -rf ANode/parser/bin 
+rm -rf Base/bin
+rm -rf CSim/bin
+rm -rf Client/bin 
+rm -rf Server/bin 
+rm -rf Test/bin
+rm -rf Pyext/bin 
+   
\ No newline at end of file
diff -pruN 5.12.4-1/releng/build_scripts/run-clang-tidy.py 5.13.0-1/releng/build_scripts/run-clang-tidy.py
--- 5.12.4-1/releng/build_scripts/run-clang-tidy.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/run-clang-tidy.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,314 @@
+#!/usr/bin/env python
+# https://github.com/llvm-mirror/clang-tools-extra/blob/master/clang-tidy/tool/run-clang-tidy.py
+#===- run-clang-tidy.py - Parallel clang-tidy runner ---------*- python -*--===#
+#
+#                     The LLVM Compiler Infrastructure
+#
+# This file is distributed under the University of Illinois Open Source
+# License. See LICENSE.TXT for details.
+#
+#===------------------------------------------------------------------------===#
+# FIXME: Integrate with clang-tidy-diff.py
+# NOTE: Original in: https://github.com/llvm-mirror/clang-tools-extra/blob/master/clang-tidy/tool/run-clang-tidy.py
+
+"""
+Parallel clang-tidy runner
+==========================
+
+Runs clang-tidy over all files in a compilation database. Requires clang-tidy
+and clang-apply-replacements in $PATH.
+
+Example invocations.
+- Run clang-tidy on all files in the current working directory with a default
+  set of checks and show warnings in the cpp files and all project headers.
+    run-clang-tidy.py $PWD
+
+- Fix all header guards.
+    run-clang-tidy.py -fix -checks=-*,llvm-header-guard
+
+- Fix all header guards included from clang-tidy and header guards
+  for clang-tidy headers.
+    run-clang-tidy.py -fix -checks=-*,llvm-header-guard extra/clang-tidy \
+                      -header-filter=extra/clang-tidy
+
+Compilation database setup:
+http://clang.llvm.org/docs/HowToSetupToolingForLLVM.html
+"""
+
+from __future__ import print_function
+
+import argparse
+import glob
+import json
+import multiprocessing
+import os
+import re
+import shutil
+import subprocess
+import sys
+import tempfile
+import threading
+import traceback
+import yaml
+
+is_py2 = sys.version[0] == '2'
+
+if is_py2:
+    import Queue as queue
+else:
+    import queue as queue
+
+def find_compilation_database(path):
+  """Adjusts the directory until a compilation database is found."""
+  result = './'
+  while not os.path.isfile(os.path.join(result, path)):
+    if os.path.realpath(result) == '/':
+      print('Error: could not find compilation database.')
+      sys.exit(1)
+    result += '../'
+  return os.path.realpath(result)
+
+
+def make_absolute(f, directory):
+  if os.path.isabs(f):
+    return f
+  return os.path.normpath(os.path.join(directory, f))
+
+
+def get_tidy_invocation(f, clang_tidy_binary, checks, tmpdir, build_path,
+                        header_filter, extra_arg, extra_arg_before, quiet,
+                        config):
+  """Gets a command line for clang-tidy."""
+  start = [clang_tidy_binary]
+  if header_filter is not None:
+    start.append('-header-filter=' + header_filter)
+  else:
+    # Show warnings in all in-project headers by default.
+    start.append('-header-filter=^' + build_path + '/.*')
+  if checks:
+    start.append('-checks=' + checks)
+  if tmpdir is not None:
+    start.append('-export-fixes')
+    # Get a temporary file. We immediately close the handle so clang-tidy can
+    # overwrite it.
+    (handle, name) = tempfile.mkstemp(suffix='.yaml', dir=tmpdir)
+    os.close(handle)
+    start.append(name)
+  for arg in extra_arg:
+      start.append('-extra-arg=%s' % arg)
+  for arg in extra_arg_before:
+      start.append('-extra-arg-before=%s' % arg)
+  start.append('-p=' + build_path)
+  if quiet:
+      start.append('-quiet')
+  if config:
+      start.append('-config=' + config)
+  start.append(f)
+  return start
+
+
+def merge_replacement_files(tmpdir, mergefile):
+  """Merge all replacement files in a directory into a single file"""
+  # The fixes suggested by clang-tidy >= 4.0.0 are given under
+  # the top level key 'Diagnostics' in the output yaml files
+  mergekey="Diagnostics"
+  merged=[]
+  for replacefile in glob.iglob(os.path.join(tmpdir, '*.yaml')):
+    content = yaml.safe_load(open(replacefile, 'r'))
+    if not content:
+      continue # Skip empty files.
+    merged.extend(content.get(mergekey, []))
+
+  if merged:
+    # MainSourceFile: The key is required by the definition inside
+    # include/clang/Tooling/ReplacementsYaml.h, but the value
+    # is actually never used inside clang-apply-replacements,
+    # so we set it to '' here.
+    output = { 'MainSourceFile': '', mergekey: merged }
+    with open(mergefile, 'w') as out:
+      yaml.safe_dump(output, out)
+  else:
+    # Empty the file:
+    open(mergefile, 'w').close()
+
+
+def check_clang_apply_replacements_binary(args):
+  """Checks if invoking supplied clang-apply-replacements binary works."""
+  try:
+    subprocess.check_call([args.clang_apply_replacements_binary, '--version'])
+  except:
+    print('Unable to run clang-apply-replacements. Is clang-apply-replacements '
+          'binary correctly specified?', file=sys.stderr)
+    traceback.print_exc()
+    sys.exit(1)
+
+
+def apply_fixes(args, tmpdir):
+  """Calls clang-apply-fixes on a given directory."""
+  invocation = [args.clang_apply_replacements_binary]
+  if args.format:
+    invocation.append('-format')
+  if args.style:
+    invocation.append('-style=' + args.style)
+  invocation.append(tmpdir)
+  subprocess.call(invocation)
+
+
+def run_tidy(args, tmpdir, build_path, queue, failed_files):
+  """Takes filenames out of queue and runs clang-tidy on them."""
+  while True:
+    name = queue.get()
+    invocation = get_tidy_invocation(name, args.clang_tidy_binary, args.checks,
+                                     tmpdir, build_path, args.header_filter,
+                                     args.extra_arg, args.extra_arg_before,
+                                     args.quiet, args.config)
+    sys.stdout.write(' '.join(invocation) + '\n')
+    return_code = subprocess.call(invocation)
+    if return_code != 0:
+      failed_files.append(name)
+    queue.task_done()
+
+
+def main():
+  parser = argparse.ArgumentParser(description='Runs clang-tidy over all files '
+                                   'in a compilation database. Requires '
+                                   'clang-tidy and clang-apply-replacements in '
+                                   '$PATH.')
+  parser.add_argument('-clang-tidy-binary', metavar='PATH',
+                      default='clang-tidy',
+                      help='path to clang-tidy binary')
+  parser.add_argument('-clang-apply-replacements-binary', metavar='PATH',
+                      default='clang-apply-replacements',
+                      help='path to clang-apply-replacements binary')
+  parser.add_argument('-checks', default=None,
+                      help='checks filter, when not specified, use clang-tidy '
+                      'default')
+  parser.add_argument('-config', default=None,
+                      help='Specifies a configuration in YAML/JSON format: '
+                      '  -config="{Checks: \'*\', '
+                      '                       CheckOptions: [{key: x, '
+                      '                                       value: y}]}" '
+                      'When the value is empty, clang-tidy will '
+                      'attempt to find a file named .clang-tidy for '
+                      'each source file in its parent directories.')
+  parser.add_argument('-header-filter', default=None,
+                      help='regular expression matching the names of the '
+                      'headers to output diagnostics from. Diagnostics from '
+                      'the main file of each translation unit are always '
+                      'displayed.')
+  parser.add_argument('-export-fixes', metavar='filename', dest='export_fixes',
+                      help='Create a yaml file to store suggested fixes in, '
+                      'which can be applied with clang-apply-replacements.')
+  parser.add_argument('-j', type=int, default=0,
+                      help='number of tidy instances to be run in parallel.')
+  parser.add_argument('files', nargs='*', default=['.*'],
+                      help='files to be processed (regex on path)')
+  parser.add_argument('-fix', action='store_true', help='apply fix-its')
+  parser.add_argument('-format', action='store_true', help='Reformat code '
+                      'after applying fixes')
+  parser.add_argument('-style', default='file', help='The style of reformat '
+                      'code after applying fixes')
+  parser.add_argument('-p', dest='build_path',
+                      help='Path used to read a compile command database.')
+  parser.add_argument('-extra-arg', dest='extra_arg',
+                      action='append', default=[],
+                      help='Additional argument to append to the compiler '
+                      'command line.')
+  parser.add_argument('-extra-arg-before', dest='extra_arg_before',
+                      action='append', default=[],
+                      help='Additional argument to prepend to the compiler '
+                      'command line.')
+  parser.add_argument('-quiet', action='store_true',
+                      help='Run clang-tidy in quiet mode')
+  args = parser.parse_args()
+
+  db_path = 'compile_commands.json'
+
+  if args.build_path is not None:
+    build_path = args.build_path
+  else:
+    # Find our database
+    build_path = find_compilation_database(db_path)
+
+  try:
+    invocation = [args.clang_tidy_binary, '-list-checks']
+    invocation.append('-p=' + build_path)
+    if args.checks:
+      invocation.append('-checks=' + args.checks)
+    invocation.append('-')
+    subprocess.check_call(invocation)
+  except:
+    print("Unable to run clang-tidy.", file=sys.stderr)
+    sys.exit(1)
+
+  # Load the database and extract all files.
+  database = json.load(open(os.path.join(build_path, db_path)))
+  files = [make_absolute(entry['file'], entry['directory'])
+           for entry in database]
+
+  max_task = args.j
+  if max_task == 0:
+    max_task = multiprocessing.cpu_count()
+
+  tmpdir = None
+  if args.fix or args.export_fixes:
+    check_clang_apply_replacements_binary(args)
+    tmpdir = tempfile.mkdtemp()
+
+  # Build up a big regexy filter from all command line arguments.
+  file_name_re = re.compile('|'.join(args.files))
+
+  return_code = 0
+  try:
+    # Spin up a bunch of tidy-launching threads.
+    task_queue = queue.Queue(max_task)
+    # List of files with a non-zero return code.
+    failed_files = []
+    for _ in range(max_task):
+      t = threading.Thread(target=run_tidy,
+                           args=(args, tmpdir, build_path, task_queue, failed_files))
+      t.daemon = True
+      t.start()
+
+    # Fill the queue with files.
+    for name in files:
+      if file_name_re.search(name):
+        task_queue.put(name)
+
+    # Wait for all threads to be done.
+    task_queue.join()
+    if len(failed_files):
+      return_code = 1
+
+  except KeyboardInterrupt:
+    # This is a sad hack. Unfortunately subprocess goes
+    # bonkers with ctrl-c and we start forking merrily.
+    print('\nCtrl-C detected, goodbye.')
+    if tmpdir:
+      shutil.rmtree(tmpdir)
+    os.kill(0, 9)
+
+  if args.export_fixes:
+    print('Writing fixes to ' + args.export_fixes + ' ...')
+    try:
+      merge_replacement_files(tmpdir, args.export_fixes)
+    except:
+      print('Error exporting fixes.\n', file=sys.stderr)
+      traceback.print_exc()
+      return_code=1
+
+  if args.fix:
+    print('Applying fixes ...')
+    try:
+      apply_fixes(args, tmpdir)
+    except:
+      print('Error applying fixes.\n', file=sys.stderr)
+      traceback.print_exc()
+      return_code=1
+
+  if tmpdir:
+    shutil.rmtree(tmpdir)
+  sys.exit(return_code)
+
+if __name__ == '__main__':
+  main()
\ No newline at end of file
diff -pruN 5.12.4-1/releng/build_scripts/shell_client.sh 5.13.0-1/releng/build_scripts/shell_client.sh
--- 5.12.4-1/releng/build_scripts/shell_client.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/shell_client.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,41 @@
+#!/bin/sh
+
+function meter_payload() {
+   # $1 path_to_task
+   # $2 password
+   # $3 process_id
+   # $4 try no
+   # $5 meter_name
+   # $6 meter value
+   
+    boost_preamble="22 serialization::archive 10 0 0 0 1 2"
+    meter_cmd="8 MeterCmd 1 0 0 0 0 0 0"
+    
+    path_to_task=$1
+    password=$2
+    process_id=$3
+    try_no=$4
+    meter_name=$5
+    meter_value=$6
+    
+    path_to_task_size=$(echo ${#path_to_task}) 
+    password_size=$(expr length  $password  )  
+    process_id_size=$(expr length  $process_id )  
+    meter_name_size=$(expr length  $meter_name )  
+    
+    data="$boost_preamble $meter_cmd $path_to_task_size $path_to_task $password_size $password $process_id_size $process_id $try_no $meter_name_size $meter_name $meter_value"
+    header=$(printf '%8.8s' $(echo "obase=16; ${#data}" | bc) )
+     
+    payload=$header$data
+    return "$payload"
+}
+
+path_to_task="/all_trigger_examples/a"
+password="F5Q0eiJu"
+process_id="24053"
+try_no="1"
+meter_name=METER
+meter_value="10"
+
+payload=$(meter_payload $path_to_task $password $process_id $try_no $meter_name $meter_value)
+echo "$payload"
diff -pruN 5.12.4-1/releng/build_scripts/test.sh 5.13.0-1/releng/build_scripts/test.sh
--- 5.12.4-1/releng/build_scripts/test.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/test.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,232 @@
+#!/bin/sh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+#===================================================================
+# Run all the ecflow tests, note use !/bin/bash to keep rpm happy, it uses bash
+#===================================================================
+
+if [ "$#" -gt 4 ] ; then
+   echo "Maximum of 3 arguments expected"
+   echo " arg1-mode    (optional) default = release  [ release | debug | profile ]"
+   echo " arg2-compiler(optional) default = linux/gcc-$(gcc -dumpversion)"
+   echo " arg3-safe    (optional) default = no  [ no | safe ] safe means only run deterministic tests"
+   echo " arg5-link    (optional) default = static [ static | shared ] use boost static/shared directory to reference tests"
+   echo " arg5-ssl     (optional) default = off [ off | ssl ] ssl means test ssl version of ecflow"
+   exit 1
+fi
+
+link=static
+mode=release
+compiler_arg=
+safe=no
+ssl=off
+while [ "$#" -ne 0 ] ; do   
+   if [ "$1" = debug -o "$1" = release -o "$1" = profile ] ; then
+      mode=$1
+   elif [ "$1" = safe ] ;   then safe=yes ;
+   elif [ "$1" = ssl ] ;    then ssl=on ;
+   elif [ "$1" = shared ] ; then link=shared ;
+   else
+      compiler_arg=$1
+   fi
+   # shift remove last argument
+   shift
+done
+
+if [ ${#mode} -eq 0 ] ; then
+   echo "test expects mode i.e. debug or release"
+   exit 1
+fi
+
+link_dir=
+if [ ${link} = static ] ; then
+   link_dir=/link-static
+fi
+
+echo "mode=$mode compiler=$compiler_arg safe=$safe ssl=$ssl link=$link link_dir=$link_dir"
+
+#======================================================================
+# remove python test, so that they are rerun
+rm -rf Pyext/bin/*.test   
+
+# Remove any lock file create by tests which used EcfPortLock.hpp
+# ** However DO *NOT* remove this locks for in ecflow test.ecf
+# ** as they allow the debug and release test to run at the same time.
+rm -rf *.lock
+ 
+# Check that a command is in the PATH.
+test_path ()
+{
+    if `command -v command 1>/dev/null 2>/dev/null`; then
+        command -v $1 1>/dev/null 2>/dev/null
+    else
+        hash $1 1>/dev/null 2>/dev/null
+    fi
+}
+
+# Check that the OS name, as returned by "uname", is as given.
+test_uname ()
+{
+    if test_path uname; then
+        test `uname` = $*
+    fi
+}
+
+unset ECF_PORT
+OPEN_SSL=
+
+if test_uname Linux ; then
+
+   TOOLSET=
+   CXXFLAGS=
+   compiler=gcc-$(gcc -dumpversion)
+   
+   # When on cray check PE_ENV for environment
+   if [ "$PE_ENV" = INTEL -o "$PE_ENV" = CRAY -o "$PE_ENV" = GNU ]
+   then
+       CXXFLAGS=cxxflags=-fPIC
+       TOOLSET=toolset=gcc
+       if [ "$PE_ENV" = INTEL ] ; then
+          compiler=intel-linux
+          TOOLSET=toolset=intel
+       fi
+       if [ "$PE_ENV" = CRAY ] ; then
+          compiler=cray
+          TOOLSET=toolset=cray
+       fi
+   fi   
+   
+   # Allow the compiler to be overridden on linux
+   if [ ${#compiler_arg} -ne 0 ] ; then
+      compiler=$compiler_arg
+   fi
+
+   exe_path=$compiler/${mode}${link_dir}
+   
+   if [ "$ssl" = on ] ; then
+      exe_path="$exe_path/ssl-on"
+      OPEN_SSL="ssl=on"
+   fi
+   
+   echo "*****************************************"
+   echo "Testing: $exe_path"
+   echo "*****************************************"
+
+   ACore/bin/$exe_path/u_acore      --log_level=message $TEST_OPTS
+   ANattr/bin/$exe_path/u_anattr    --log_level=message $TEST_OPTS
+   ANode/bin/$exe_path/u_anode      --log_level=message $TEST_OPTS
+   ANode/parser/bin/$exe_path/u_aparser  --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      ANode/parser/bin/$exe_path/perf_aparser --log_level=message $TEST_OPTS
+   fi
+   Base/bin/$exe_path/u_base         --log_level=message $TEST_OPTS
+   
+   if [ "$safe" = no ] ; then
+      # run python/C++ test
+      cd Pyext
+      $BOOST_ROOT/b2 $TOOLSET "$CXXFLAGS" variant=$mode link=$link $OPEN_SSL test-all $TEST_OPTS
+      cd ..
+   fi
+   
+   Client/bin/$exe_path/s_client     --log_level=message $TEST_OPTS
+   Server/bin/$exe_path/u_server     --log_level=message $TEST_OPTS
+   CSim/bin/$exe_path/c_csim         --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      Test/bin/$exe_path/s_test          --log_level=message $TEST_OPTS
+      Test/bin/$exe_path/s_test_zombies  --log_level=message $TEST_OPTS
+   fi
+   
+elif test_uname Darwin ; then
+
+   TOOLSET=
+   CXXFLAGS=cxxflags="-Wno-deprecated-declarations -Wno-maybe-uninitialized -fvisibility-inlines-hidden -fvisibility=hidden"
+   compiler=gcc-$(/usr/local/opt/gcc@10/bin/gcc-10 -dumpversion)
+   
+   exe_path=$compiler/${mode}${link_dir}
+   
+   echo "*****************************************"
+   echo "Testing: $exe_path"
+   echo "*****************************************"
+
+   ACore/bin/$exe_path/u_acore          --log_level=message $TEST_OPTS
+   ANattr/bin/$exe_path/u_anattr        --log_level=message $TEST_OPTS
+   ANode/bin/$exe_path/u_anode          --log_level=message $TEST_OPTS
+   ANode/parser/bin/$exe_path/u_aparser --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      ANode/parser/bin/$exe_path/perf_aparser --log_level=message $TEST_OPTS
+   fi
+   Base/bin/$exe_path/u_base         --log_level=message $TEST_OPTS
+   
+   if [ "$safe" = no ] ; then
+      # run python/C++ test
+      cd Pyext
+      $BOOST_ROOT/b2 $TOOLSET "$CXXFLAGS" variant=$mode link=$link $OPEN_SSL test-all $TEST_OPTS
+      cd ..
+   fi
+   
+   Client/bin/$exe_path/s_client     --log_level=message $TEST_OPTS
+   Server/bin/$exe_path/u_server     --log_level=message $TEST_OPTS
+   CSim/bin/$exe_path/c_csim         --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      Test/bin/$exe_path/s_test          --log_level=message $TEST_OPTS
+      Test/bin/$exe_path/s_test_zombies  --log_level=message $TEST_OPTS
+   fi
+   
+elif test_uname HP-UX ; then
+
+   echo "Testing: variant=$mode"
+   ACore/bin/acc/$mode/threading-multi/u_acore  --log_level=message $TEST_OPTS
+   ANattr/bin/acc/$mode/threading-multi/u_anattr  --log_level=message $TEST_OPTS
+   ANode/bin/acc/$mode/threading-multi/u_anode  --log_level=message $TEST_OPTS
+   ANode/parser/bin/acc/$mode/threading-multi/u_aparser  --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      ANode/parser/bin/acc/$mode/threading-multi/perf_aparser  --log_level=message $TEST_OPTS
+   fi
+   Base/bin/acc/$mode/threading-multi/u_base  --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      # run python/C++ test, use test to bypass 'with' statement tests
+      cd Pyext
+      $BOOST_ROOT/b2 variant=$mode test $TEST_OPTS
+      cd ..
+   fi
+   exit 1
+   Client/bin/acc/$mode/threading-multi/s_client  --log_level=message $TEST_OPTS
+   Server/bin/acc/$mode/threading-multi/u_server  --log_level=message $TEST_OPTS
+   CSim/bin/acc/$mode/threading-multi/c_csim  --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      Test/bin/acc/$mode/threading-multi/s_test  --log_level=message $TEST_OPTS
+      Test/bin/acc/$mode/threading-multi/s_test_zombies  --log_level=message $TEST_OPTS
+   fi
+   
+elif test_uname AIX ; then
+
+   echo "Testing: $ARCH variant=$mode"
+   
+   ACore/bin/vacpp/$mode/threading-multi/u_acore  --log_level=message $TEST_OPTS
+   ANattr/bin/vacpp/$mode/threading-multi/u_anattr  --log_level=message $TEST_OPTS
+   ANode/bin/vacpp/$mode/threading-multi/u_anode  --log_level=message $TEST_OPTS
+   ANode/parser/bin/vacpp/$mode/threading-multi/u_aparser  --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      ANode/parser/bin/vacpp/$mode/threading-multi/perf_aparser  --log_level=message $TEST_OPTS
+   fi
+   Base/bin/vacpp/$mode/threading-multi/u_base  --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      # run python/C++ test
+      cd Pyext
+      $BOOST_ROOT/b2 variant=$mode test-all $TEST_OPTS
+      cd ..
+   fi
+   Client/bin/vacpp/$mode/threading-multi/s_client  --log_level=message $TEST_OPTS
+   Server/bin/vacpp/$mode/threading-multi/u_server  --log_level=message $TEST_OPTS
+   CSim/bin/vacpp/$mode/threading-multi/c_csim  --log_level=message $TEST_OPTS
+   if [ "$safe" = no ] ; then
+      Test/bin/vacpp/$mode/threading-multi/s_test  --log_level=message $TEST_OPTS
+      Test/bin/vacpp/$mode/threading-multi/s_test_zombies  --log_level=message $TEST_OPTS
+   fi
+fi
diff -pruN 5.12.4-1/releng/build_scripts/test_bench/test_bench.py 5.13.0-1/releng/build_scripts/test_bench/test_bench.py
--- 5.12.4-1/releng/build_scripts/test_bench/test_bench.py	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/test_bench/test_bench.py	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,45 @@
+# Used to build ecflow, incrementally and nightly
+import os
+import ecflow 
+
+# =====================================================================================
+# Load the defs from disk
+# =====================================================================================
+generated_defs_file = os.getenv("WK") + "/build_scripts/test_bench/test_force_cmd.def"
+defs = ecflow.Defs(generated_defs_file)
+ 
+# =====================================================================================
+# Generated scripts in $SCRATCH
+# This assumes the ECF_HOME and ECF_INCLUDE have not been defined
+# =====================================================================================
+for suite in defs.suites:
+    suite.add_variable("ECF_HOME", os.getenv("WK") + "/build_scripts/test_bench/test_force_cmd")
+    suite.add_variable("ECF_INCLUDE", os.getenv("WK") + "/build_scripts/test_bench/test_force_cmd/includes")
+
+defs.generate_scripts()
+
+
+# ====================================================================================
+# Check job generation     
+# ====================================================================================
+job_ctrl = ecflow.JobCreationCtrl()  # no set_node_path() hence check job generation for all tasks
+defs.check_job_creation(job_ctrl)
+assert len(job_ctrl.get_error_msg()) == 0, job_ctrl.get_error_msg()
+
+
+# =====================================================================================
+# delete the definition in the server, load/replace a new definition
+# Assumes server already started
+# ======================================================================================
+ci = ecflow.Client("localhost","4141")
+try:
+    ci.restart_server();
+   
+    ci.delete_all(True)           # clear out the server
+    ci.load(defs)             # load the definition into the server
+    
+    #ci.replace("/suite",defs,True,True)     
+    ci.begin_all_suites()   # need only begin once 
+ 
+except RuntimeError as e:
+    print("failed: " + str(e))
diff -pruN 5.12.4-1/releng/build_scripts/val.sh 5.13.0-1/releng/build_scripts/val.sh
--- 5.12.4-1/releng/build_scripts/val.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/val.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,53 @@
+#!/bin/sh
+
+## Copyright 2009- ECMWF.
+## This software is licensed under the terms of the Apache Licence version 2.0 
+## which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+## In applying this licence, ECMWF does not waive the privileges and immunities 
+## granted to it by virtue of its status as an intergovernmental organisation 
+## nor does it submit to any jurisdiction. 
+
+# This script will run valgrind on all the automated test
+# Assume WK is defined
+
+#===========================================================================
+# load the latest valgrind
+module load valgrind/3.14.0
+#===========================================================================
+
+cd $WK
+
+# if argument is release test the release version else stick with debug
+mode=debug
+if test "$1" = release
+then
+   mode=release
+fi
+
+compiler=gcc-$(gcc -dumpversion)
+
+echo "valgrind: variant=$mode compiler=$compiler"
+
+#
+# Use valgrind which is newer than standard installation
+#
+# Note: To valgrind the server, start it separately on a different shell and define ECF_HOST=localhost
+# export ECF_HOST=localhost
+# valgrind Server/bin/$compiler/$mode/ecflow_server --interval=3
+# Then restart this shell
+   
+
+# Use the valgrind option --track-origins=yes to have it track the origin of uninitialized values. 
+# This will make it slower and take more memory, but can be very helpful if you need to track down 
+# the origin of an uninitialized value.
+
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ACore/bin/$compiler/$mode/u_acore
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ANattr/bin/$compiler/$mode/u_anattr
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ANode/bin/$compiler/$mode/u_anode
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes ANode/parser/bin/$compiler/$mode/u_aparser
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes Base/bin/$compiler/$mode/u_base
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes Client/bin/$compiler/$mode/s_client
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes Server/bin/$compiler/$mode/u_server
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --num-callers=30 --error-exitcode=1 --partial-loads-ok=yes Test/bin/$compiler/$mode/s_test
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --num-callers=30 --error-exitcode=1 --partial-loads-ok=yes Test/bin/$compiler/$mode/s_test_zombies
+valgrind --num-callers=24 --leak-check=full --show-reachable=yes --error-exitcode=1 --partial-loads-ok=yes CSim/bin/$compiler/$mode/c_csim
diff -pruN 5.12.4-1/releng/build_scripts/wait_for_server_reply.sh 5.13.0-1/releng/build_scripts/wait_for_server_reply.sh
--- 5.12.4-1/releng/build_scripts/wait_for_server_reply.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.13.0-1/releng/build_scripts/wait_for_server_reply.sh	2024-06-20 10:11:46.000000000 +0000
@@ -0,0 +1,22 @@
+#!/bin/sh
+
+# wait for server to start
+set +e # ignore error 
+count=0
+while [ 1 ] ; do   
+    sleep 3
+    ecflow_client --ping 2> /dev/null
+    if [[ $? == 0 ]] ; then
+        echo "server up and running"
+        break;
+    fi
+    count=$((count + 1))
+    #echo $count
+    if [ "$count" -gt "2" ] ; then
+        echo "Timed out after 60 seconds"
+        exit 1
+    fi
+done
+set -e  # re-enable error 
+
+ 
\ No newline at end of file
diff -pruN 5.12.4-1/share/ecflow/etc/ecflowview_attribute_conf.json 5.13.0-1/share/ecflow/etc/ecflowview_attribute_conf.json
--- 5.12.4-1/share/ecflow/etc/ecflowview_attribute_conf.json	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/share/ecflow/etc/ecflowview_attribute_conf.json	2024-06-20 10:11:46.000000000 +0000
@@ -58,6 +58,12 @@
         },
         "queue" : {
             "label": "Queues"
+        },
+        "aviso" : {
+          "label" : "Avisos"
+        },
+        "mirror" : {
+          "label" : "Mirrors"
         }
-	}
+    }
 }
diff -pruN 5.12.4-1/share/ecflow/etc/ecflowview_icon_conf.json 5.13.0-1/share/ecflow/etc/ecflowview_icon_conf.json
--- 5.12.4-1/share/ecflow/etc/ecflowview_icon_conf.json	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/share/ecflow/etc/ecflowview_icon_conf.json	2024-06-20 10:11:46.000000000 +0000
@@ -131,6 +131,14 @@
                 "icon"  : {
                     "default" : "icon_checkpt_err.svg"
                 }
+            },
+            "remote_err" : {
+                "label" : "Remote error",
+                "tooltip" : "Error accessing remote resource",
+                "shortDesc" : "Error accessing remote resource",
+                "icon"  : {
+                  "default" : "icon_remote_err.svg"
             }
+        }
      }
 }
diff -pruN 5.12.4-1/share/ecflow/etc/ecflowview_menus.json 5.13.0-1/share/ecflow/etc/ecflowview_menus.json
--- 5.12.4-1/share/ecflow/etc/ecflowview_menus.json	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/share/ecflow/etc/ecflowview_menus.json	2024-06-20 10:11:46.000000000 +0000
@@ -101,7 +101,7 @@
         {
             "menu"           : "Node",
             "name"           : "Suspend",
-            "visible_for"    : "not suspended and node",
+            "visible_for"    : "not suspended and node and (not has_mirror)",
             "command"        : "ecflow_client --suspend <full_name>",
             "status_tip"     : "__cmd__",
             "shortcut"       : "Ctrl+S"
@@ -110,7 +110,7 @@
         {
             "menu"           : "Node",
             "name"           : "Resume",
-            "visible_for"    : "suspended and node",
+            "visible_for"    : "suspended and node and (not has_mirror)",
             "command"        : "ecflow_client --resume <full_name>",
             "status_tip"     : "__cmd__",
             "shortcut"       : "Ctrl+R"
@@ -120,7 +120,7 @@
             "menu"           : "Node",
             "name"           : "Rerun",
             "visible_for"    : "task",
-            "enabled_for"    : "(not active) and (not submitted)",
+            "enabled_for"    : "(not active) and (not submitted) and (not has_mirror)",
             "command"        : "ecflow_client --force queued <full_name>",
             "status_tip"     : "__cmd__",
             "shortcut"       : "Ctrl+U"
@@ -130,7 +130,7 @@
             "menu"           : "Node",
             "name"           : "Set complete",
             "visible_for"    : "task or alias",
-            "enabled_for"    : "submitted or active or unknown or queued or aborted or suspended",
+            "enabled_for"    : "(submitted or active or unknown or queued or aborted or suspended) and (not has_mirror)",
             "command"        : "ecflow_client --force=complete <full_name>",
             "question_for"   : "submitted or active",
             "question"       : "Have you checked that the job is not active anymore (jobstatus)?",
@@ -143,7 +143,7 @@
             "menu"           : "Node",
             "name"           : "Set aborted",
             "visible_for"    : "task or alias",
-            "enabled_for"    : "submitted or active or unknown or queued or complete or suspended",
+            "enabled_for"    : "(submitted or active or unknown or queued or complete or suspended) and (not has_mirror)",
             "command"        : "ecflow_client --force=aborted <full_name>",
             "question_for"   : "submitted or active",
             "question"       : "Have you checked that the job is not active anymore (jobstatus)?",
@@ -156,7 +156,7 @@
             "menu"           : "Node",
             "name"           : "Execute",
             "visible_for"    : "task or alias",
-            "enabled_for"    : "(not active) and (not submitted)",
+            "enabled_for"    : "(not active) and (not submitted) and (not has_mirror)",
             "command"        : "ecflow_client --run <full_name>",
             "status_tip"     : "__cmd__",
             "shortcut"       : "Ctrl+E"
@@ -166,7 +166,7 @@
             "menu"           : "Node",
             "name"           : "Requeue",
             "visible_for"    : "task or suite or family",
-            "enabled_for"    : "(not active) and (not submitted)",
+            "enabled_for"    : "(not active) and (not submitted) and (not has_mirror)",
             "command"        : "ecflow_client --requeue=force <full_name>",
             "warning"        : "This command can potentially lead to creating zombies when active nodes are present in the current subtree.",
             "question"       : "Confirm requeuing of <full_name>",
@@ -179,7 +179,7 @@
             "menu"           : "Node",
             "name"           : "Requeue aborted",
             "visible_for"    : "suite or family",
-            "enabled_for"    : "aborted or suspended",
+            "enabled_for"    : "aborted or suspended and (not has_mirror)",
             "command"        : "ecflow_client --requeue=abort <full_name>",
             "question"       : "Confirm requeuing of aborted tasks from <full_name>",           
             "question_control" : "menu.confirm.confirmRequeueAborted",
diff -pruN 5.12.4-1/share/ecflow/etc/ecflowview_query_conf.json 5.13.0-1/share/ecflow/etc/ecflowview_query_conf.json
--- 5.12.4-1/share/ecflow/etc/ecflowview_query_conf.json	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/share/ecflow/etc/ecflowview_query_conf.json	2024-06-20 10:11:46.000000000 +0000
@@ -30,7 +30,7 @@
 
         "attribute"  : {
             "type"  : "list",
-            "values" : "date|event|label|limit|limiter|meter|repeat|time|trigger|variable"
+            "values" : "date|event|label|limit|limiter|meter|repeat|time|trigger|variable|mirror|aviso"
         },
 
         "event" : {
@@ -57,6 +57,54 @@
                 "label" : "Label value"
             }
         },
+        "mirror" : {
+            "mirror_name" : {
+                "type" : "string",
+                "label" : "Mirror name"
+            },
+            "mirror_remote_path" : {
+                "type" : "string",
+                "label" : "Mirror remote path"
+            },
+            "mirror_remote_host" : {
+                "type" : "string",
+                "label" : "Mirror remote host"
+            },
+            "mirror_remote_port" : {
+                "type" : "string",
+                "label" : "Mirror remote port"
+            },
+            "mirror_polling" : {
+                "type" : "string",
+                "label" : "Mirror polling"
+            }
+        },
+        "aviso" : {
+            "aviso_name" : {
+                "type" : "string",
+                "label" : "Aviso name"
+            },
+            "aviso_listener" : {
+                "type" : "string",
+                "label" : "Aviso listener"
+            },
+            "aviso_url" : {
+                "type" : "string",
+                "label" : "Aviso URL"
+            },
+            "aviso_schema" : {
+                "type" : "string",
+                "label" : "Aviso schema"
+            },
+            "aviso_polling" : {
+                "type" : "string",
+                "label" : "Aviso polling"
+            },
+            "aviso_auth" : {
+                "type" : "string",
+                "label" : "Aviso authentication"
+            }
+        },
         "meter" : {
             "meter_name" : {
                 "type" : "string",
diff -pruN 5.12.4-1/tools/ecflow_standalone.c 5.13.0-1/tools/ecflow_standalone.c
--- 5.12.4-1/tools/ecflow_standalone.c	2024-04-25 06:04:28.000000000 +0000
+++ 5.13.0-1/tools/ecflow_standalone.c	2024-06-20 10:11:46.000000000 +0000
@@ -84,6 +84,15 @@ char *nameof(char *name) {
   return s;
 }
 
+pid_t do_setsid(void) {
+#if defined(linux) || defined(__APPLE__) || defined(__MACH__) || defined(hpux) || defined(solaris) || defined(SGI) || \
+    defined(SVR4) || defined(AIX) || defined(SYG) || defined(alpha) || defined(__NVCOMPILER)
+    return setsid();
+#else
+    return setsid(0);
+#endif
+}
+
 int main(int argc, char** argv)
 {
   char *infile = NULL;             /* Temporary input file        */
@@ -183,11 +192,7 @@ int main(int argc, char** argv)
      for (n=3; n<65535 ;n++) fclose(n); */
 
   /* create a new session from the child process */
-#if defined(linux) || defined(__APPLE__) || defined(__MACH__) || defined(hpux) || defined(solaris) || defined(SGI) || defined(SVR4) || defined(AIX) || defined(SYG) || defined(alpha)
-  if( setsid() == -1 )
-#else
-  if( setsid(0) == -1 )
-#endif
+  if( do_setsid() == -1 )
   {
     perror("STANDALONE-SETSID");
     exit(1);
